(****************************************************************)
(*  This file contains expressions for the basis of hexagon     *)
(*  functions in Region II, through weight five.                *)
(*                                                              *)
(*  There are 30 functions presented here. The notation is      *)
(*                                                              *)
(*      FuvwRegII = F(u,v,w), FuwvRegI = F(u,w,v), etc.         *)
(*                                                              *)
(*  where F is one of,                                          *)
(*                                                              *)
(*    Weight 3: Phi6tilde = \tilde{\Phi}_ 6                     *)
(*    Weight 4: F1 = F_ 1, Omega2 = \Omega_2                    *)
(*    Weight 5: G, H1 = H_ 1, J1 = J_ 1, K1 = K_ 1,             *)
(*              N, O, Qep = Q_{ep}, M1 = M_ 1                   *)
(*                                                              *)
(*  We denote by G[{w1,...,wn},z] the multiple polylogarithm    *)
(*  with weight vector {w1,...,wn} and argument z.              *)
(****************************************************************)



Phi6tildeuvwRegII = -(Pi^2*G[{0}, yu^(-1)])/6 - (Pi^2*G[{0}, yv^(-1)])/6 + 
     (Pi^2*G[{0}, yw])/6 - G[{0}, yu^(-1)]*G[{0, 1}, yu^(-1)] - 
     G[{0}, yv^(-1)]*G[{0, 1}, yu^(-1)] + G[{0}, yw]*G[{0, 1}, yu^(-1)] - 
     G[{0}, yu^(-1)]*G[{0, 1}, yv^(-1)] - G[{0}, yv^(-1)]*
      G[{0, 1}, yv^(-1)] + G[{0}, yw]*G[{0, 1}, yv^(-1)] - 
     G[{0}, yu^(-1)]*G[{0, 1}, yw] - G[{0}, yv^(-1)]*G[{0, 1}, yw] + 
     G[{0}, yw]*G[{0, 1}, yw] + 2*G[{yu}, yv^(-1)]*G[{0, 1}, yw] + 
     G[{0}, yu^(-1)]*G[{0, yu^(-1)}, yw] + G[{0}, yv^(-1)]*
      G[{0, yu^(-1)}, yw] - G[{0}, yw]*G[{0, yu^(-1)}, yw] - 
     2*G[{1}, yv^(-1)]*G[{0, yu^(-1)}, yw] + G[{0}, yu^(-1)]*
      G[{0, yu}, yv^(-1)] + G[{0}, yv^(-1)]*G[{0, yu}, yv^(-1)] - 
     G[{0}, yw]*G[{0, yu}, yv^(-1)] + G[{0}, yu^(-1)]*G[{0, yv^(-1)}, yw] + 
     G[{0}, yv^(-1)]*G[{0, yv^(-1)}, yw] - G[{0}, yw]*G[{0, yv^(-1)}, yw] - 
     2*G[{1}, yu^(-1)]*G[{0, yv^(-1)}, yw] - G[{0}, yu^(-1)]*
      G[{0, 1/(yu*yv)}, yw] - G[{0}, yv^(-1)]*G[{0, 1/(yu*yv)}, yw] + 
     G[{0}, yw]*G[{0, 1/(yu*yv)}, yw] + 2*G[{1}, yu^(-1)]*
      G[{0, 1/(yu*yv)}, yw] + 2*G[{1}, yv^(-1)]*G[{0, 1/(yu*yv)}, yw] - 
     2*G[{yu}, yv^(-1)]*G[{0, 1/(yu*yv)}, yw] - 2*G[{0, 0, 1}, yw] + 
     2*G[{0, 0, yu^(-1)}, yw] + 2*G[{0, 0, yv^(-1)}, yw] - 
     2*G[{0, 0, 1/(yu*yv)}, yw] + 2*G[{0, 1, 1}, yu^(-1)] + 
     2*G[{0, 1, 1}, yv^(-1)] - 2*G[{0, 1, 1}, yw] + 
     2*G[{0, yu^(-1), yu^(-1)}, yw] - 2*G[{0, yu, yu}, yv^(-1)] + 
     2*G[{0, yv^(-1), yv^(-1)}, yw] + 2*G[{0, 1/(yu*yv), 1}, yw] - 
     2*G[{0, 1/(yu*yv), yu^(-1)}, yw] - 2*G[{0, 1/(yu*yv), yv^(-1)}, yw] - 
     2*Zeta[3]
 
Omega2uvwRegII = (-7*Pi^4)/360 + (Pi^2*G[{1}, yu^(-1)]^2)/12 - 
     (Pi^2*G[{1}, yu^(-1)]*G[{1}, yv^(-1)])/6 + (Pi^2*G[{1}, yv^(-1)]^2)/12 - 
     (Pi^2*G[{0}, yu^(-1)]*G[{1}, yw])/6 - (Pi^2*G[{0}, yv^(-1)]*G[{1}, yw])/
      6 + (Pi^2*G[{0}, yw]*G[{1}, yw])/6 + (Pi^2*G[{1}, yu^(-1)]*G[{1}, yw])/
      6 + (Pi^2*G[{1}, yv^(-1)]*G[{1}, yw])/6 + G[{1}, yu^(-1)]^2*
      G[{1}, yv^(-1)]*G[{1}, yw] - G[{1}, yu^(-1)]*G[{1}, yv^(-1)]^2*
      G[{1}, yw] + (G[{0}, yu^(-1)]*G[{1}, yu^(-1)]*G[{1}, yw]^2)/2 + 
     (G[{0}, yv^(-1)]*G[{1}, yu^(-1)]*G[{1}, yw]^2)/2 - 
     (G[{0}, yw]*G[{1}, yu^(-1)]*G[{1}, yw]^2)/2 - 
     (G[{1}, yu^(-1)]^2*G[{1}, yw]^2)/4 + 
     (G[{0}, yu^(-1)]*G[{1}, yv^(-1)]*G[{1}, yw]^2)/2 + 
     (G[{0}, yv^(-1)]*G[{1}, yv^(-1)]*G[{1}, yw]^2)/2 - 
     (G[{0}, yw]*G[{1}, yv^(-1)]*G[{1}, yw]^2)/2 - 
     (G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*G[{1}, yw]^2)/2 - 
     (G[{1}, yv^(-1)]^2*G[{1}, yw]^2)/4 + (G[{0}, yu^(-1)]*G[{1}, yw]^3)/3 + 
     (G[{0}, yv^(-1)]*G[{1}, yw]^3)/3 - (G[{0}, yw]*G[{1}, yw]^3)/3 + 
     (G[{1}, yu^(-1)]*G[{1}, yw]^3)/6 + (G[{1}, yv^(-1)]*G[{1}, yw]^3)/6 + 
     G[{1}, yw]^4/4 - G[{1}, yu^(-1)]^2*G[{1}, yw]*G[{yu}, yv^(-1)] + 
     2*G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*G[{1}, yw]*G[{yu}, yv^(-1)] - 
     G[{1}, yv^(-1)]^2*G[{1}, yw]*G[{yu}, yv^(-1)] - 
     G[{0}, yu^(-1)]*G[{1}, yw]^2*G[{yu}, yv^(-1)] - 
     G[{0}, yv^(-1)]*G[{1}, yw]^2*G[{yu}, yv^(-1)] + 
     G[{0}, yw]*G[{1}, yw]^2*G[{yu}, yv^(-1)] - 
     G[{1}, yw]^3*G[{yu}, yv^(-1)] + G[{1}, yw]^2*G[{yu}, yv^(-1)]^2 + 
     (Pi^2*G[{0}, yu^(-1)]*G[{1/(yu*yv)}, yw])/6 + 
     (Pi^2*G[{0}, yv^(-1)]*G[{1/(yu*yv)}, yw])/6 - 
     (Pi^2*G[{0}, yw]*G[{1/(yu*yv)}, yw])/6 - 
     (Pi^2*G[{1}, yu^(-1)]*G[{1/(yu*yv)}, yw])/6 - 
     (Pi^2*G[{1}, yv^(-1)]*G[{1/(yu*yv)}, yw])/6 - 
     G[{1}, yu^(-1)]^2*G[{1}, yv^(-1)]*G[{1/(yu*yv)}, yw] + 
     G[{1}, yu^(-1)]*G[{1}, yv^(-1)]^2*G[{1/(yu*yv)}, yw] - 
     G[{0}, yu^(-1)]*G[{1}, yu^(-1)]*G[{1}, yw]*G[{1/(yu*yv)}, yw] - 
     G[{0}, yv^(-1)]*G[{1}, yu^(-1)]*G[{1}, yw]*G[{1/(yu*yv)}, yw] + 
     G[{0}, yw]*G[{1}, yu^(-1)]*G[{1}, yw]*G[{1/(yu*yv)}, yw] + 
     (G[{1}, yu^(-1)]^2*G[{1}, yw]*G[{1/(yu*yv)}, yw])/2 - 
     G[{0}, yu^(-1)]*G[{1}, yv^(-1)]*G[{1}, yw]*G[{1/(yu*yv)}, yw] - 
     G[{0}, yv^(-1)]*G[{1}, yv^(-1)]*G[{1}, yw]*G[{1/(yu*yv)}, yw] + 
     G[{0}, yw]*G[{1}, yv^(-1)]*G[{1}, yw]*G[{1/(yu*yv)}, yw] + 
     G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*G[{1}, yw]*G[{1/(yu*yv)}, yw] + 
     (G[{1}, yv^(-1)]^2*G[{1}, yw]*G[{1/(yu*yv)}, yw])/2 - 
     G[{0}, yu^(-1)]*G[{1}, yw]^2*G[{1/(yu*yv)}, yw] - 
     G[{0}, yv^(-1)]*G[{1}, yw]^2*G[{1/(yu*yv)}, yw] + 
     G[{0}, yw]*G[{1}, yw]^2*G[{1/(yu*yv)}, yw] - 
     (G[{1}, yu^(-1)]*G[{1}, yw]^2*G[{1/(yu*yv)}, yw])/2 - 
     (G[{1}, yv^(-1)]*G[{1}, yw]^2*G[{1/(yu*yv)}, yw])/2 - 
     G[{1}, yw]^3*G[{1/(yu*yv)}, yw] + 
     (Pi^2*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw])/6 + 
     G[{0}, yu^(-1)]*G[{1}, yu^(-1)]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw] + 
     G[{0}, yv^(-1)]*G[{1}, yu^(-1)]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw] - 
     G[{0}, yw]*G[{1}, yu^(-1)]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw] - 
     (G[{1}, yu^(-1)]^2*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw])/2 - 
     G[{0}, yu^(-1)]*G[{1}, yv^(-1)]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw] - 
     G[{0}, yv^(-1)]*G[{1}, yv^(-1)]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw] + 
     G[{0}, yw]*G[{1}, yv^(-1)]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw] - 
     G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw] + 
     (3*G[{1}, yv^(-1)]^2*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw])/2 - 
     G[{0}, yu^(-1)]*G[{1}, yw]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw] - 
     G[{0}, yv^(-1)]*G[{1}, yw]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw] + 
     G[{0}, yw]*G[{1}, yw]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw] + 
     G[{1}, yu^(-1)]*G[{1}, yw]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw] + 
     G[{1}, yv^(-1)]*G[{1}, yw]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw] + 
     G[{0}, yu^(-1)]*G[{yu^(-1)}, yw]^2*G[{1/(yu*yv)}, yw] + 
     G[{0}, yv^(-1)]*G[{yu^(-1)}, yw]^2*G[{1/(yu*yv)}, yw] - 
     G[{0}, yw]*G[{yu^(-1)}, yw]^2*G[{1/(yu*yv)}, yw] - 
     2*G[{1}, yv^(-1)]*G[{yu^(-1)}, yw]^2*G[{1/(yu*yv)}, yw] + 
     (2*G[{yu^(-1)}, yw]^3*G[{1/(yu*yv)}, yw])/3 + 
     G[{1}, yu^(-1)]^2*G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw] - 
     2*G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw] + 
     G[{1}, yv^(-1)]^2*G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw] + 
     2*G[{0}, yu^(-1)]*G[{1}, yw]*G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw] + 
     2*G[{0}, yv^(-1)]*G[{1}, yw]*G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw] - 
     2*G[{0}, yw]*G[{1}, yw]*G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw] + 
     3*G[{1}, yw]^2*G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw] - 
     2*G[{1}, yw]*G[{yu}, yv^(-1)]^2*G[{1/(yu*yv)}, yw] + 
     (Pi^2*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw])/6 - 
     G[{0}, yu^(-1)]*G[{1}, yu^(-1)]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw] - 
     G[{0}, yv^(-1)]*G[{1}, yu^(-1)]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw] + 
     G[{0}, yw]*G[{1}, yu^(-1)]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw] + 
     (3*G[{1}, yu^(-1)]^2*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw])/2 + 
     G[{0}, yu^(-1)]*G[{1}, yv^(-1)]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw] + 
     G[{0}, yv^(-1)]*G[{1}, yv^(-1)]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw] - 
     G[{0}, yw]*G[{1}, yv^(-1)]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw] - 
     G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw] - 
     (G[{1}, yv^(-1)]^2*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw])/2 - 
     G[{0}, yu^(-1)]*G[{1}, yw]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw] - 
     G[{0}, yv^(-1)]*G[{1}, yw]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw] + 
     G[{0}, yw]*G[{1}, yw]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw] + 
     G[{1}, yu^(-1)]*G[{1}, yw]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw] + 
     G[{1}, yv^(-1)]*G[{1}, yw]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw] + 
     G[{0}, yu^(-1)]*G[{yv^(-1)}, yw]^2*G[{1/(yu*yv)}, yw] + 
     G[{0}, yv^(-1)]*G[{yv^(-1)}, yw]^2*G[{1/(yu*yv)}, yw] - 
     G[{0}, yw]*G[{yv^(-1)}, yw]^2*G[{1/(yu*yv)}, yw] - 
     2*G[{1}, yu^(-1)]*G[{yv^(-1)}, yw]^2*G[{1/(yu*yv)}, yw] + 
     (2*G[{yv^(-1)}, yw]^3*G[{1/(yu*yv)}, yw])/3 + 
     (G[{0}, yu^(-1)]*G[{1}, yu^(-1)]*G[{1/(yu*yv)}, yw]^2)/2 + 
     (G[{0}, yv^(-1)]*G[{1}, yu^(-1)]*G[{1/(yu*yv)}, yw]^2)/2 - 
     (G[{0}, yw]*G[{1}, yu^(-1)]*G[{1/(yu*yv)}, yw]^2)/2 - 
     (3*G[{1}, yu^(-1)]^2*G[{1/(yu*yv)}, yw]^2)/4 + 
     (G[{0}, yu^(-1)]*G[{1}, yv^(-1)]*G[{1/(yu*yv)}, yw]^2)/2 + 
     (G[{0}, yv^(-1)]*G[{1}, yv^(-1)]*G[{1/(yu*yv)}, yw]^2)/2 - 
     (G[{0}, yw]*G[{1}, yv^(-1)]*G[{1/(yu*yv)}, yw]^2)/2 + 
     (G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*G[{1/(yu*yv)}, yw]^2)/2 - 
     (3*G[{1}, yv^(-1)]^2*G[{1/(yu*yv)}, yw]^2)/4 + 
     G[{0}, yu^(-1)]*G[{1}, yw]*G[{1/(yu*yv)}, yw]^2 + 
     G[{0}, yv^(-1)]*G[{1}, yw]*G[{1/(yu*yv)}, yw]^2 - 
     G[{0}, yw]*G[{1}, yw]*G[{1/(yu*yv)}, yw]^2 - 
     (G[{1}, yu^(-1)]*G[{1}, yw]*G[{1/(yu*yv)}, yw]^2)/2 - 
     (G[{1}, yv^(-1)]*G[{1}, yw]*G[{1/(yu*yv)}, yw]^2)/2 + 
     (G[{1}, yw]^2*G[{1/(yu*yv)}, yw]^2)/2 - 
     (G[{0}, yu^(-1)]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2)/2 - 
     (G[{0}, yv^(-1)]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2)/2 + 
     (G[{0}, yw]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2)/2 + 
     G[{1}, yv^(-1)]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2 - 
     (G[{yu^(-1)}, yw]^2*G[{1/(yu*yv)}, yw]^2)/2 - 
     G[{0}, yu^(-1)]*G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw]^2 - 
     G[{0}, yv^(-1)]*G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw]^2 + 
     G[{0}, yw]*G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw]^2 - 
     G[{1}, yw]*G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw]^2 + 
     G[{yu}, yv^(-1)]^2*G[{1/(yu*yv)}, yw]^2 - 
     (G[{0}, yu^(-1)]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2)/2 - 
     (G[{0}, yv^(-1)]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2)/2 + 
     (G[{0}, yw]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2)/2 + 
     G[{1}, yu^(-1)]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2 - 
     (G[{yv^(-1)}, yw]^2*G[{1/(yu*yv)}, yw]^2)/2 + 
     (G[{1}, yu^(-1)]*G[{1/(yu*yv)}, yw]^3)/6 + 
     (G[{1}, yv^(-1)]*G[{1/(yu*yv)}, yw]^3)/6 + 
     (G[{1}, yw]*G[{1/(yu*yv)}, yw]^3)/3 - 
     (G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]^3)/6 - 
     (G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw]^3)/3 - 
     (G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]^3)/6 - (Pi^2*G[{0, 1}, yu^(-1)])/
      6 + (G[{1}, yu^(-1)]^2*G[{0, 1}, yu^(-1)])/2 - 
     G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*G[{0, 1}, yu^(-1)] + 
     (G[{1}, yv^(-1)]^2*G[{0, 1}, yu^(-1)])/2 - G[{0}, yu^(-1)]*G[{1}, yw]*
      G[{0, 1}, yu^(-1)] - G[{0}, yv^(-1)]*G[{1}, yw]*G[{0, 1}, yu^(-1)] + 
     G[{0}, yw]*G[{1}, yw]*G[{0, 1}, yu^(-1)] + G[{1}, yu^(-1)]*G[{1}, yw]*
      G[{0, 1}, yu^(-1)] - G[{1}, yv^(-1)]*G[{1}, yw]*G[{0, 1}, yu^(-1)] - 
     (G[{1}, yw]^2*G[{0, 1}, yu^(-1)])/2 + 2*G[{1}, yw]*G[{yu}, yv^(-1)]*
      G[{0, 1}, yu^(-1)] + G[{0}, yu^(-1)]*G[{1/(yu*yv)}, yw]*
      G[{0, 1}, yu^(-1)] + G[{0}, yv^(-1)]*G[{1/(yu*yv)}, yw]*
      G[{0, 1}, yu^(-1)] - G[{0}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1}, yu^(-1)] - 
     G[{1}, yu^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, 1}, yu^(-1)] + 
     G[{1}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, 1}, yu^(-1)] + 
     G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1}, yu^(-1)] - 
     2*G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, 1}, yu^(-1)] + 
     (G[{1/(yu*yv)}, yw]^2*G[{0, 1}, yu^(-1)])/2 - (Pi^2*G[{0, 1}, yv^(-1)])/
      6 - (G[{1}, yu^(-1)]^2*G[{0, 1}, yv^(-1)])/2 + 
     (G[{1}, yv^(-1)]^2*G[{0, 1}, yv^(-1)])/2 - G[{0}, yu^(-1)]*G[{1}, yw]*
      G[{0, 1}, yv^(-1)] - G[{0}, yv^(-1)]*G[{1}, yw]*G[{0, 1}, yv^(-1)] + 
     G[{0}, yw]*G[{1}, yw]*G[{0, 1}, yv^(-1)] + G[{1}, yv^(-1)]*G[{1}, yw]*
      G[{0, 1}, yv^(-1)] - (G[{1}, yw]^2*G[{0, 1}, yv^(-1)])/2 + 
     2*G[{1}, yw]*G[{yu}, yv^(-1)]*G[{0, 1}, yv^(-1)] + 
     G[{0}, yu^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, 1}, yv^(-1)] + 
     G[{0}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, 1}, yv^(-1)] - 
     G[{0}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1}, yv^(-1)] - 
     G[{1}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, 1}, yv^(-1)] + 
     G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1}, yv^(-1)] - 
     2*G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, 1}, yv^(-1)] + 
     (G[{1/(yu*yv)}, yw]^2*G[{0, 1}, yv^(-1)])/2 - (Pi^2*G[{0, 1}, yw])/6 - 
     G[{0}, yu^(-1)]*G[{1}, yw]*G[{0, 1}, yw] - G[{0}, yv^(-1)]*G[{1}, yw]*
      G[{0, 1}, yw] + G[{0}, yw]*G[{1}, yw]*G[{0, 1}, yw] + 
     G[{1}, yu^(-1)]*G[{1}, yw]*G[{0, 1}, yw] + G[{1}, yv^(-1)]*G[{1}, yw]*
      G[{0, 1}, yw] + G[{0}, yu^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, 1}, yw] + 
     G[{0}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, 1}, yw] - 
     G[{0}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1}, yw] - 
     G[{1}, yu^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, 1}, yw] - 
     G[{1}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, 1}, yw] - 
     G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1}, yw] - 
     G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1}, yw] - 
     G[{0, 1}, yu^(-1)]*G[{0, 1}, yw] - G[{0, 1}, yv^(-1)]*G[{0, 1}, yw] + 
     G[{0, 1}, yw]^2/2 + G[{0}, yu^(-1)]*G[{1}, yw]*G[{0, yu^(-1)}, yw] + 
     G[{0}, yv^(-1)]*G[{1}, yw]*G[{0, yu^(-1)}, yw] - 
     G[{0}, yw]*G[{1}, yw]*G[{0, yu^(-1)}, yw] - G[{1}, yu^(-1)]*G[{1}, yw]*
      G[{0, yu^(-1)}, yw] - G[{1}, yv^(-1)]*G[{1}, yw]*G[{0, yu^(-1)}, yw] - 
     G[{0}, yu^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1)}, yw] - 
     G[{0}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1)}, yw] + 
     G[{0}, yw]*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1)}, yw] + 
     G[{1}, yu^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1)}, yw] + 
     G[{1}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1)}, yw] + 
     G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1)}, yw] + 
     G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1)}, yw] + 
     (G[{1}, yu^(-1)]^2*G[{0, yu}, yv^(-1)])/2 - 
     (G[{1}, yv^(-1)]^2*G[{0, yu}, yv^(-1)])/2 + G[{0}, yu^(-1)]*G[{1}, yw]*
      G[{0, yu}, yv^(-1)] + G[{0}, yv^(-1)]*G[{1}, yw]*G[{0, yu}, yv^(-1)] - 
     G[{0}, yw]*G[{1}, yw]*G[{0, yu}, yv^(-1)] - G[{1}, yv^(-1)]*G[{1}, yw]*
      G[{0, yu}, yv^(-1)] + (G[{1}, yw]^2*G[{0, yu}, yv^(-1)])/2 - 
     2*G[{1}, yw]*G[{yu}, yv^(-1)]*G[{0, yu}, yv^(-1)] - 
     G[{0}, yu^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, yu}, yv^(-1)] - 
     G[{0}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, yu}, yv^(-1)] + 
     G[{0}, yw]*G[{1/(yu*yv)}, yw]*G[{0, yu}, yv^(-1)] + 
     G[{1}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, yu}, yv^(-1)] - 
     G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{0, yu}, yv^(-1)] + 
     2*G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, yu}, yv^(-1)] - 
     (G[{1/(yu*yv)}, yw]^2*G[{0, yu}, yv^(-1)])/2 - 
     G[{0, 1}, yu^(-1)]*G[{0, yu}, yv^(-1)] - G[{0, 1}, yv^(-1)]*
      G[{0, yu}, yv^(-1)] + G[{0, 1}, yw]*G[{0, yu}, yv^(-1)] + 
     G[{0, yu}, yv^(-1)]^2/2 + G[{0}, yu^(-1)]*G[{1}, yw]*
      G[{0, yv^(-1)}, yw] + G[{0}, yv^(-1)]*G[{1}, yw]*G[{0, yv^(-1)}, yw] - 
     G[{0}, yw]*G[{1}, yw]*G[{0, yv^(-1)}, yw] - G[{1}, yu^(-1)]*G[{1}, yw]*
      G[{0, yv^(-1)}, yw] - G[{1}, yv^(-1)]*G[{1}, yw]*G[{0, yv^(-1)}, yw] - 
     G[{0}, yu^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, yv^(-1)}, yw] - 
     G[{0}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, yv^(-1)}, yw] + 
     G[{0}, yw]*G[{1/(yu*yv)}, yw]*G[{0, yv^(-1)}, yw] + 
     G[{1}, yu^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, yv^(-1)}, yw] + 
     G[{1}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, yv^(-1)}, yw] + 
     G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{0, yv^(-1)}, yw] + 
     G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{0, yv^(-1)}, yw] + 
     (Pi^2*G[{0, 1/(yu*yv)}, yw])/6 - G[{0}, yu^(-1)]*G[{1}, yw]*
      G[{0, 1/(yu*yv)}, yw] - G[{0}, yv^(-1)]*G[{1}, yw]*
      G[{0, 1/(yu*yv)}, yw] + G[{0}, yw]*G[{1}, yw]*G[{0, 1/(yu*yv)}, yw] + 
     G[{1}, yu^(-1)]*G[{1}, yw]*G[{0, 1/(yu*yv)}, yw] + 
     G[{1}, yv^(-1)]*G[{1}, yw]*G[{0, 1/(yu*yv)}, yw] + 
     G[{0}, yu^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv)}, yw] + 
     G[{0}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv)}, yw] - 
     G[{0}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv)}, yw] - 
     G[{1}, yu^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv)}, yw] - 
     G[{1}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv)}, yw] - 
     G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv)}, yw] - 
     G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv)}, yw] + 
     G[{0, 1}, yu^(-1)]*G[{0, 1/(yu*yv)}, yw] + G[{0, 1}, yv^(-1)]*
      G[{0, 1/(yu*yv)}, yw] - G[{0, 1}, yw]*G[{0, 1/(yu*yv)}, yw] + 
     G[{0, yu^(-1)}, yw]*G[{0, 1/(yu*yv)}, yw] - G[{0, yu}, yv^(-1)]*
      G[{0, 1/(yu*yv)}, yw] + G[{0, yv^(-1)}, yw]*G[{0, 1/(yu*yv)}, yw] - 
     G[{0, 1/(yu*yv)}, yw]^2/2 - (Pi^2*G[{1, yu^(-1)}, yw])/6 - 
     G[{0}, yu^(-1)]*G[{1}, yu^(-1)]*G[{1, yu^(-1)}, yw] - 
     G[{0}, yv^(-1)]*G[{1}, yu^(-1)]*G[{1, yu^(-1)}, yw] + 
     G[{0}, yw]*G[{1}, yu^(-1)]*G[{1, yu^(-1)}, yw] + 
     (G[{1}, yu^(-1)]^2*G[{1, yu^(-1)}, yw])/2 + 
     G[{0}, yu^(-1)]*G[{1}, yv^(-1)]*G[{1, yu^(-1)}, yw] + 
     G[{0}, yv^(-1)]*G[{1}, yv^(-1)]*G[{1, yu^(-1)}, yw] - 
     G[{0}, yw]*G[{1}, yv^(-1)]*G[{1, yu^(-1)}, yw] + 
     G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*G[{1, yu^(-1)}, yw] - 
     (3*G[{1}, yv^(-1)]^2*G[{1, yu^(-1)}, yw])/2 + G[{0}, yu^(-1)]*G[{1}, yw]*
      G[{1, yu^(-1)}, yw] + G[{0}, yv^(-1)]*G[{1}, yw]*G[{1, yu^(-1)}, yw] - 
     G[{0}, yw]*G[{1}, yw]*G[{1, yu^(-1)}, yw] - G[{1}, yu^(-1)]*G[{1}, yw]*
      G[{1, yu^(-1)}, yw] - G[{1}, yv^(-1)]*G[{1}, yw]*G[{1, yu^(-1)}, yw] + 
     2*G[{0}, yu^(-1)]*G[{1/(yu*yv)}, yw]*G[{1, yu^(-1)}, yw] + 
     2*G[{0}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{1, yu^(-1)}, yw] - 
     2*G[{0}, yw]*G[{1/(yu*yv)}, yw]*G[{1, yu^(-1)}, yw] - 
     G[{1}, yu^(-1)]*G[{1/(yu*yv)}, yw]*G[{1, yu^(-1)}, yw] - 
     3*G[{1}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{1, yu^(-1)}, yw] - 
     G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{1, yu^(-1)}, yw] - 
     G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{1, yu^(-1)}, yw] + 
     (G[{1/(yu*yv)}, yw]^2*G[{1, yu^(-1)}, yw])/2 + 
     G[{0, 1}, yw]*G[{1, yu^(-1)}, yw] - G[{0, yu^(-1)}, yw]*
      G[{1, yu^(-1)}, yw] - G[{0, yv^(-1)}, yw]*G[{1, yu^(-1)}, yw] + 
     G[{0, 1/(yu*yv)}, yw]*G[{1, yu^(-1)}, yw] + G[{1, yu^(-1)}, yw]^2/2 - 
     2*G[{1}, yu^(-1)]*G[{1}, yw]*G[{1, yu}, yv^(-1)] + 
     2*G[{1}, yv^(-1)]*G[{1}, yw]*G[{1, yu}, yv^(-1)] + 
     2*G[{1}, yu^(-1)]*G[{1/(yu*yv)}, yw]*G[{1, yu}, yv^(-1)] - 
     2*G[{1}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{1, yu}, yv^(-1)] - 
     (Pi^2*G[{1, yv^(-1)}, yw])/6 + G[{0}, yu^(-1)]*G[{1}, yu^(-1)]*
      G[{1, yv^(-1)}, yw] + G[{0}, yv^(-1)]*G[{1}, yu^(-1)]*
      G[{1, yv^(-1)}, yw] - G[{0}, yw]*G[{1}, yu^(-1)]*G[{1, yv^(-1)}, yw] - 
     (3*G[{1}, yu^(-1)]^2*G[{1, yv^(-1)}, yw])/2 - 
     G[{0}, yu^(-1)]*G[{1}, yv^(-1)]*G[{1, yv^(-1)}, yw] - 
     G[{0}, yv^(-1)]*G[{1}, yv^(-1)]*G[{1, yv^(-1)}, yw] + 
     G[{0}, yw]*G[{1}, yv^(-1)]*G[{1, yv^(-1)}, yw] + 
     G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*G[{1, yv^(-1)}, yw] + 
     (G[{1}, yv^(-1)]^2*G[{1, yv^(-1)}, yw])/2 + G[{0}, yu^(-1)]*G[{1}, yw]*
      G[{1, yv^(-1)}, yw] + G[{0}, yv^(-1)]*G[{1}, yw]*G[{1, yv^(-1)}, yw] - 
     G[{0}, yw]*G[{1}, yw]*G[{1, yv^(-1)}, yw] - G[{1}, yu^(-1)]*G[{1}, yw]*
      G[{1, yv^(-1)}, yw] - G[{1}, yv^(-1)]*G[{1}, yw]*G[{1, yv^(-1)}, yw] + 
     2*G[{0}, yu^(-1)]*G[{1/(yu*yv)}, yw]*G[{1, yv^(-1)}, yw] + 
     2*G[{0}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{1, yv^(-1)}, yw] - 
     2*G[{0}, yw]*G[{1/(yu*yv)}, yw]*G[{1, yv^(-1)}, yw] - 
     3*G[{1}, yu^(-1)]*G[{1/(yu*yv)}, yw]*G[{1, yv^(-1)}, yw] - 
     G[{1}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{1, yv^(-1)}, yw] - 
     G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{1, yv^(-1)}, yw] - 
     G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{1, yv^(-1)}, yw] + 
     (G[{1/(yu*yv)}, yw]^2*G[{1, yv^(-1)}, yw])/2 + 
     G[{0, 1}, yw]*G[{1, yv^(-1)}, yw] - G[{0, yu^(-1)}, yw]*
      G[{1, yv^(-1)}, yw] - G[{0, yv^(-1)}, yw]*G[{1, yv^(-1)}, yw] + 
     G[{0, 1/(yu*yv)}, yw]*G[{1, yv^(-1)}, yw] + G[{1, yu^(-1)}, yw]*
      G[{1, yv^(-1)}, yw] + G[{1, yv^(-1)}, yw]^2/2 + 
     G[{1}, yu^(-1)]^2*G[{1, 1/(yu*yv)}, yw] - 2*G[{1}, yu^(-1)]*
      G[{1}, yv^(-1)]*G[{1, 1/(yu*yv)}, yw] + G[{1}, yv^(-1)]^2*
      G[{1, 1/(yu*yv)}, yw] + 2*G[{1}, yu^(-1)]*G[{1}, yw]*
      G[{1, 1/(yu*yv)}, yw] + 2*G[{1}, yv^(-1)]*G[{1}, yw]*
      G[{1, 1/(yu*yv)}, yw] + 2*G[{1}, yw]^2*G[{1, 1/(yu*yv)}, yw] - 
     4*G[{1}, yw]*G[{yu}, yv^(-1)]*G[{1, 1/(yu*yv)}, yw] - 
     2*G[{0}, yu^(-1)]*G[{1/(yu*yv)}, yw]*G[{1, 1/(yu*yv)}, yw] - 
     2*G[{0}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{1, 1/(yu*yv)}, yw] + 
     2*G[{0}, yw]*G[{1/(yu*yv)}, yw]*G[{1, 1/(yu*yv)}, yw] + 
     2*G[{1}, yu^(-1)]*G[{1/(yu*yv)}, yw]*G[{1, 1/(yu*yv)}, yw] + 
     2*G[{1}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{1, 1/(yu*yv)}, yw] - 
     G[{1/(yu*yv)}, yw]^2*G[{1, 1/(yu*yv)}, yw] - 2*G[{0, 1}, yu^(-1)]*
      G[{1, 1/(yu*yv)}, yw] - 2*G[{0, 1}, yv^(-1)]*G[{1, 1/(yu*yv)}, yw] + 
     2*G[{0, yu}, yv^(-1)]*G[{1, 1/(yu*yv)}, yw] - 2*G[{1, yu^(-1)}, yw]*
      G[{1, 1/(yu*yv)}, yw] - 2*G[{1, yv^(-1)}, yw]*G[{1, 1/(yu*yv)}, yw] + 
     2*G[{1, 1/(yu*yv)}, yw]^2 - (Pi^2*G[{yu^(-1), 1/(yu*yv)}, yw])/6 - 
     G[{0}, yu^(-1)]*G[{1}, yu^(-1)]*G[{yu^(-1), 1/(yu*yv)}, yw] - 
     G[{0}, yv^(-1)]*G[{1}, yu^(-1)]*G[{yu^(-1), 1/(yu*yv)}, yw] + 
     G[{0}, yw]*G[{1}, yu^(-1)]*G[{yu^(-1), 1/(yu*yv)}, yw] + 
     (G[{1}, yu^(-1)]^2*G[{yu^(-1), 1/(yu*yv)}, yw])/2 + 
     G[{0}, yu^(-1)]*G[{1}, yv^(-1)]*G[{yu^(-1), 1/(yu*yv)}, yw] + 
     G[{0}, yv^(-1)]*G[{1}, yv^(-1)]*G[{yu^(-1), 1/(yu*yv)}, yw] - 
     G[{0}, yw]*G[{1}, yv^(-1)]*G[{yu^(-1), 1/(yu*yv)}, yw] + 
     G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*G[{yu^(-1), 1/(yu*yv)}, yw] - 
     (3*G[{1}, yv^(-1)]^2*G[{yu^(-1), 1/(yu*yv)}, yw])/2 + 
     G[{0}, yu^(-1)]*G[{1}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw] + 
     G[{0}, yv^(-1)]*G[{1}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw] - 
     G[{0}, yw]*G[{1}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw] - 
     G[{1}, yu^(-1)]*G[{1}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw] - 
     G[{1}, yv^(-1)]*G[{1}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw] - 
     2*G[{0}, yu^(-1)]*G[{yu^(-1)}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw] - 
     2*G[{0}, yv^(-1)]*G[{yu^(-1)}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw] + 
     2*G[{0}, yw]*G[{yu^(-1)}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw] + 
     4*G[{1}, yv^(-1)]*G[{yu^(-1)}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw] - 
     2*G[{yu^(-1)}, yw]^2*G[{yu^(-1), 1/(yu*yv)}, yw] + 
     G[{1}, yu^(-1)]*G[{1/(yu*yv)}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw] - 
     G[{1}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw] + 
     G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw] + 
     G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw] + 
     (G[{1/(yu*yv)}, yw]^2*G[{yu^(-1), 1/(yu*yv)}, yw])/2 + 
     G[{0, 1}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw] - G[{0, yu^(-1)}, yw]*
      G[{yu^(-1), 1/(yu*yv)}, yw] - G[{0, yv^(-1)}, yw]*
      G[{yu^(-1), 1/(yu*yv)}, yw] + G[{0, 1/(yu*yv)}, yw]*
      G[{yu^(-1), 1/(yu*yv)}, yw] + G[{1, yu^(-1)}, yw]*
      G[{yu^(-1), 1/(yu*yv)}, yw] + G[{1, yv^(-1)}, yw]*
      G[{yu^(-1), 1/(yu*yv)}, yw] - G[{yu^(-1), 1/(yu*yv)}, yw]^2/2 - 
     (Pi^2*G[{yv^(-1), 1/(yu*yv)}, yw])/6 + G[{0}, yu^(-1)]*G[{1}, yu^(-1)]*
      G[{yv^(-1), 1/(yu*yv)}, yw] + G[{0}, yv^(-1)]*G[{1}, yu^(-1)]*
      G[{yv^(-1), 1/(yu*yv)}, yw] - G[{0}, yw]*G[{1}, yu^(-1)]*
      G[{yv^(-1), 1/(yu*yv)}, yw] - (3*G[{1}, yu^(-1)]^2*
       G[{yv^(-1), 1/(yu*yv)}, yw])/2 - G[{0}, yu^(-1)]*G[{1}, yv^(-1)]*
      G[{yv^(-1), 1/(yu*yv)}, yw] - G[{0}, yv^(-1)]*G[{1}, yv^(-1)]*
      G[{yv^(-1), 1/(yu*yv)}, yw] + G[{0}, yw]*G[{1}, yv^(-1)]*
      G[{yv^(-1), 1/(yu*yv)}, yw] + G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*
      G[{yv^(-1), 1/(yu*yv)}, yw] + 
     (G[{1}, yv^(-1)]^2*G[{yv^(-1), 1/(yu*yv)}, yw])/2 + 
     G[{0}, yu^(-1)]*G[{1}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw] + 
     G[{0}, yv^(-1)]*G[{1}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw] - 
     G[{0}, yw]*G[{1}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw] - 
     G[{1}, yu^(-1)]*G[{1}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw] - 
     G[{1}, yv^(-1)]*G[{1}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw] - 
     2*G[{0}, yu^(-1)]*G[{yv^(-1)}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw] - 
     2*G[{0}, yv^(-1)]*G[{yv^(-1)}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw] + 
     2*G[{0}, yw]*G[{yv^(-1)}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw] + 
     4*G[{1}, yu^(-1)]*G[{yv^(-1)}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw] - 
     2*G[{yv^(-1)}, yw]^2*G[{yv^(-1), 1/(yu*yv)}, yw] - 
     G[{1}, yu^(-1)]*G[{1/(yu*yv)}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw] + 
     G[{1}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw] - 
     G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw] + 
     G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw] + 
     (G[{1/(yu*yv)}, yw]^2*G[{yv^(-1), 1/(yu*yv)}, yw])/2 + 
     G[{0, 1}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw] - G[{0, yu^(-1)}, yw]*
      G[{yv^(-1), 1/(yu*yv)}, yw] - G[{0, yv^(-1)}, yw]*
      G[{yv^(-1), 1/(yu*yv)}, yw] + G[{0, 1/(yu*yv)}, yw]*
      G[{yv^(-1), 1/(yu*yv)}, yw] + G[{1, yu^(-1)}, yw]*
      G[{yv^(-1), 1/(yu*yv)}, yw] + G[{1, yv^(-1)}, yw]*
      G[{yv^(-1), 1/(yu*yv)}, yw] - G[{yu^(-1), 1/(yu*yv)}, yw]*
      G[{yv^(-1), 1/(yu*yv)}, yw] - G[{yv^(-1), 1/(yu*yv)}, yw]^2/2 - 
     G[{1}, yu^(-1)]*G[{0, 0, 1}, yu^(-1)] + G[{1}, yv^(-1)]*
      G[{0, 0, 1}, yu^(-1)] - G[{1}, yw]*G[{0, 0, 1}, yu^(-1)] + 
     G[{1/(yu*yv)}, yw]*G[{0, 0, 1}, yu^(-1)] - G[{1}, yv^(-1)]*
      G[{0, 0, 1}, yv^(-1)] - G[{1}, yw]*G[{0, 0, 1}, yv^(-1)] + 
     G[{1/(yu*yv)}, yw]*G[{0, 0, 1}, yv^(-1)] - 
     2*G[{1}, yw]*G[{0, 0, 1}, yw] + 2*G[{1/(yu*yv)}, yw]*G[{0, 0, 1}, yw] + 
     2*G[{1}, yw]*G[{0, 0, yu^(-1)}, yw] - 2*G[{1/(yu*yv)}, yw]*
      G[{0, 0, yu^(-1)}, yw] + G[{1}, yv^(-1)]*G[{0, 0, yu}, yv^(-1)] + 
     G[{1}, yw]*G[{0, 0, yu}, yv^(-1)] - G[{1/(yu*yv)}, yw]*
      G[{0, 0, yu}, yv^(-1)] + 2*G[{1}, yw]*G[{0, 0, yv^(-1)}, yw] - 
     2*G[{1/(yu*yv)}, yw]*G[{0, 0, yv^(-1)}, yw] - 
     2*G[{1}, yw]*G[{0, 0, 1/(yu*yv)}, yw] + 2*G[{1/(yu*yv)}, yw]*
      G[{0, 0, 1/(yu*yv)}, yw] - G[{1}, yu^(-1)]*G[{0, 1, 1}, yu^(-1)] + 
     G[{1}, yv^(-1)]*G[{0, 1, 1}, yu^(-1)] + 
     G[{1}, yw]*G[{0, 1, 1}, yu^(-1)] - G[{1/(yu*yv)}, yw]*
      G[{0, 1, 1}, yu^(-1)] + G[{1}, yu^(-1)]*G[{0, 1, 1}, yv^(-1)] - 
     G[{1}, yv^(-1)]*G[{0, 1, 1}, yv^(-1)] + 
     G[{1}, yw]*G[{0, 1, 1}, yv^(-1)] - G[{1/(yu*yv)}, yw]*
      G[{0, 1, 1}, yv^(-1)] + 2*G[{0}, yu^(-1)]*G[{0, 1, 1}, yw] + 
     2*G[{0}, yv^(-1)]*G[{0, 1, 1}, yw] - 2*G[{0}, yw]*G[{0, 1, 1}, yw] - 
     G[{1}, yu^(-1)]*G[{0, 1, 1}, yw] - G[{1}, yv^(-1)]*G[{0, 1, 1}, yw] - 
     2*G[{yu}, yv^(-1)]*G[{0, 1, 1}, yw] - G[{0}, yu^(-1)]*
      G[{0, 1, yu^(-1)}, yw] - G[{0}, yv^(-1)]*G[{0, 1, yu^(-1)}, yw] + 
     G[{0}, yw]*G[{0, 1, yu^(-1)}, yw] + 2*G[{1}, yv^(-1)]*
      G[{0, 1, yu^(-1)}, yw] - 2*G[{1}, yw]*G[{0, 1, yu^(-1)}, yw] + 
     2*G[{1/(yu*yv)}, yw]*G[{0, 1, yu^(-1)}, yw] - 
     2*G[{1}, yw]*G[{0, 1, yu}, yv^(-1)] + 2*G[{1/(yu*yv)}, yw]*
      G[{0, 1, yu}, yv^(-1)] - G[{0}, yu^(-1)]*G[{0, 1, yv^(-1)}, yw] - 
     G[{0}, yv^(-1)]*G[{0, 1, yv^(-1)}, yw] + 
     G[{0}, yw]*G[{0, 1, yv^(-1)}, yw] + 2*G[{1}, yu^(-1)]*
      G[{0, 1, yv^(-1)}, yw] - 2*G[{1}, yw]*G[{0, 1, yv^(-1)}, yw] + 
     2*G[{1/(yu*yv)}, yw]*G[{0, 1, yv^(-1)}, yw] - 
     G[{1}, yu^(-1)]*G[{0, 1, 1/(yu*yv)}, yw] - G[{1}, yv^(-1)]*
      G[{0, 1, 1/(yu*yv)}, yw] + 2*G[{yu}, yv^(-1)]*G[{0, 1, 1/(yu*yv)}, 
       yw] - G[{0}, yu^(-1)]*G[{0, yu^(-1), 1}, yw] - 
     G[{0}, yv^(-1)]*G[{0, yu^(-1), 1}, yw] + 
     G[{0}, yw]*G[{0, yu^(-1), 1}, yw] + G[{1}, yu^(-1)]*
      G[{0, yu^(-1), 1}, yw] + G[{1}, yv^(-1)]*G[{0, yu^(-1), 1}, yw] + 
     2*G[{1}, yw]*G[{0, yu^(-1), yu^(-1)}, yw] - 2*G[{1/(yu*yv)}, yw]*
      G[{0, yu^(-1), yu^(-1)}, yw] + 2*G[{1}, yw]*G[{0, yu^(-1), yv^(-1)}, 
       yw] - 2*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1), yv^(-1)}, yw] + 
     G[{0}, yu^(-1)]*G[{0, yu^(-1), 1/(yu*yv)}, yw] + 
     G[{0}, yv^(-1)]*G[{0, yu^(-1), 1/(yu*yv)}, yw] - 
     G[{0}, yw]*G[{0, yu^(-1), 1/(yu*yv)}, yw] - 
     G[{1}, yu^(-1)]*G[{0, yu^(-1), 1/(yu*yv)}, yw] - 
     G[{1}, yv^(-1)]*G[{0, yu^(-1), 1/(yu*yv)}, yw] - 
     G[{1}, yu^(-1)]*G[{0, yu, 1}, yv^(-1)] + G[{1}, yv^(-1)]*
      G[{0, yu, 1}, yv^(-1)] - G[{1}, yw]*G[{0, yu, 1}, yv^(-1)] + 
     G[{1/(yu*yv)}, yw]*G[{0, yu, 1}, yv^(-1)] + 
     2*G[{1}, yw]*G[{0, yu, yu}, yv^(-1)] - 2*G[{1/(yu*yv)}, yw]*
      G[{0, yu, yu}, yv^(-1)] - G[{0}, yu^(-1)]*G[{0, yv^(-1), 1}, yw] - 
     G[{0}, yv^(-1)]*G[{0, yv^(-1), 1}, yw] + 
     G[{0}, yw]*G[{0, yv^(-1), 1}, yw] + G[{1}, yu^(-1)]*
      G[{0, yv^(-1), 1}, yw] + G[{1}, yv^(-1)]*G[{0, yv^(-1), 1}, yw] + 
     2*G[{1}, yw]*G[{0, yv^(-1), yu^(-1)}, yw] - 2*G[{1/(yu*yv)}, yw]*
      G[{0, yv^(-1), yu^(-1)}, yw] + 2*G[{1}, yw]*G[{0, yv^(-1), yv^(-1)}, 
       yw] - 2*G[{1/(yu*yv)}, yw]*G[{0, yv^(-1), yv^(-1)}, yw] + 
     G[{0}, yu^(-1)]*G[{0, yv^(-1), 1/(yu*yv)}, yw] + 
     G[{0}, yv^(-1)]*G[{0, yv^(-1), 1/(yu*yv)}, yw] - 
     G[{0}, yw]*G[{0, yv^(-1), 1/(yu*yv)}, yw] - 
     G[{1}, yu^(-1)]*G[{0, yv^(-1), 1/(yu*yv)}, yw] - 
     G[{1}, yv^(-1)]*G[{0, yv^(-1), 1/(yu*yv)}, yw] - 
     G[{1}, yu^(-1)]*G[{0, 1/(yu*yv), 1}, yw] - G[{1}, yv^(-1)]*
      G[{0, 1/(yu*yv), 1}, yw] + 2*G[{yu}, yv^(-1)]*G[{0, 1/(yu*yv), 1}, 
       yw] + G[{0}, yu^(-1)]*G[{0, 1/(yu*yv), yu^(-1)}, yw] + 
     G[{0}, yv^(-1)]*G[{0, 1/(yu*yv), yu^(-1)}, yw] - 
     G[{0}, yw]*G[{0, 1/(yu*yv), yu^(-1)}, yw] - 2*G[{1}, yv^(-1)]*
      G[{0, 1/(yu*yv), yu^(-1)}, yw] - 2*G[{1}, yw]*
      G[{0, 1/(yu*yv), yu^(-1)}, yw] + 2*G[{1/(yu*yv)}, yw]*
      G[{0, 1/(yu*yv), yu^(-1)}, yw] + G[{0}, yu^(-1)]*
      G[{0, 1/(yu*yv), yv^(-1)}, yw] + G[{0}, yv^(-1)]*
      G[{0, 1/(yu*yv), yv^(-1)}, yw] - G[{0}, yw]*G[{0, 1/(yu*yv), yv^(-1)}, 
       yw] - 2*G[{1}, yu^(-1)]*G[{0, 1/(yu*yv), yv^(-1)}, yw] - 
     2*G[{1}, yw]*G[{0, 1/(yu*yv), yv^(-1)}, yw] + 2*G[{1/(yu*yv)}, yw]*
      G[{0, 1/(yu*yv), yv^(-1)}, yw] - 2*G[{0}, yu^(-1)]*
      G[{0, 1/(yu*yv), 1/(yu*yv)}, yw] - 2*G[{0}, yv^(-1)]*
      G[{0, 1/(yu*yv), 1/(yu*yv)}, yw] + 2*G[{0}, yw]*
      G[{0, 1/(yu*yv), 1/(yu*yv)}, yw] + 3*G[{1}, yu^(-1)]*
      G[{0, 1/(yu*yv), 1/(yu*yv)}, yw] + 3*G[{1}, yv^(-1)]*
      G[{0, 1/(yu*yv), 1/(yu*yv)}, yw] - 2*G[{yu}, yv^(-1)]*
      G[{0, 1/(yu*yv), 1/(yu*yv)}, yw] - 3*G[{0}, yu^(-1)]*
      G[{1, 1, yu^(-1)}, yw] - 3*G[{0}, yv^(-1)]*G[{1, 1, yu^(-1)}, yw] + 
     3*G[{0}, yw]*G[{1, 1, yu^(-1)}, yw] + 2*G[{1}, yu^(-1)]*
      G[{1, 1, yu^(-1)}, yw] + 4*G[{1}, yv^(-1)]*G[{1, 1, yu^(-1)}, yw] + 
     G[{1/(yu*yv)}, yw]*G[{1, 1, yu^(-1)}, yw] - 3*G[{0}, yu^(-1)]*
      G[{1, 1, yv^(-1)}, yw] - 3*G[{0}, yv^(-1)]*G[{1, 1, yv^(-1)}, yw] + 
     3*G[{0}, yw]*G[{1, 1, yv^(-1)}, yw] + 4*G[{1}, yu^(-1)]*
      G[{1, 1, yv^(-1)}, yw] + 2*G[{1}, yv^(-1)]*G[{1, 1, yv^(-1)}, yw] + 
     G[{1/(yu*yv)}, yw]*G[{1, 1, yv^(-1)}, yw] + 2*G[{0}, yu^(-1)]*
      G[{1, 1, 1/(yu*yv)}, yw] + 2*G[{0}, yv^(-1)]*G[{1, 1, 1/(yu*yv)}, yw] - 
     2*G[{0}, yw]*G[{1, 1, 1/(yu*yv)}, yw] - 4*G[{1}, yu^(-1)]*
      G[{1, 1, 1/(yu*yv)}, yw] - 4*G[{1}, yv^(-1)]*G[{1, 1, 1/(yu*yv)}, yw] - 
     4*G[{1}, yw]*G[{1, 1, 1/(yu*yv)}, yw] + 4*G[{yu}, yv^(-1)]*
      G[{1, 1, 1/(yu*yv)}, yw] - 2*G[{1/(yu*yv)}, yw]*
      G[{1, 1, 1/(yu*yv)}, yw] - 2*G[{0}, yu^(-1)]*G[{1, yu^(-1), yu^(-1)}, 
       yw] - 2*G[{0}, yv^(-1)]*G[{1, yu^(-1), yu^(-1)}, yw] + 
     2*G[{0}, yw]*G[{1, yu^(-1), yu^(-1)}, yw] + 4*G[{1}, yv^(-1)]*
      G[{1, yu^(-1), yu^(-1)}, yw] + 4*G[{1/(yu*yv)}, yw]*
      G[{1, yu^(-1), yu^(-1)}, yw] + 2*G[{1/(yu*yv)}, yw]*
      G[{1, yu^(-1), yv^(-1)}, yw] - G[{0}, yu^(-1)]*
      G[{1, yu^(-1), 1/(yu*yv)}, yw] - G[{0}, yv^(-1)]*
      G[{1, yu^(-1), 1/(yu*yv)}, yw] + G[{0}, yw]*G[{1, yu^(-1), 1/(yu*yv)}, 
       yw] + 2*G[{1}, yv^(-1)]*G[{1, yu^(-1), 1/(yu*yv)}, yw] - 
     G[{1/(yu*yv)}, yw]*G[{1, yu^(-1), 1/(yu*yv)}, yw] + 
     2*G[{1/(yu*yv)}, yw]*G[{1, yv^(-1), yu^(-1)}, yw] - 
     2*G[{0}, yu^(-1)]*G[{1, yv^(-1), yv^(-1)}, yw] - 
     2*G[{0}, yv^(-1)]*G[{1, yv^(-1), yv^(-1)}, yw] + 
     2*G[{0}, yw]*G[{1, yv^(-1), yv^(-1)}, yw] + 4*G[{1}, yu^(-1)]*
      G[{1, yv^(-1), yv^(-1)}, yw] + 4*G[{1/(yu*yv)}, yw]*
      G[{1, yv^(-1), yv^(-1)}, yw] - G[{0}, yu^(-1)]*
      G[{1, yv^(-1), 1/(yu*yv)}, yw] - G[{0}, yv^(-1)]*
      G[{1, yv^(-1), 1/(yu*yv)}, yw] + G[{0}, yw]*G[{1, yv^(-1), 1/(yu*yv)}, 
       yw] + 2*G[{1}, yu^(-1)]*G[{1, yv^(-1), 1/(yu*yv)}, yw] - 
     G[{1/(yu*yv)}, yw]*G[{1, yv^(-1), 1/(yu*yv)}, yw] - 
     2*G[{1/(yu*yv)}, yw]*G[{1, 1/(yu*yv), yu^(-1)}, yw] - 
     2*G[{1/(yu*yv)}, yw]*G[{1, 1/(yu*yv), yv^(-1)}, yw] + 
     2*G[{0}, yu^(-1)]*G[{1, 1/(yu*yv), 1/(yu*yv)}, yw] + 
     2*G[{0}, yv^(-1)]*G[{1, 1/(yu*yv), 1/(yu*yv)}, yw] - 
     2*G[{0}, yw]*G[{1, 1/(yu*yv), 1/(yu*yv)}, yw] - 
     4*G[{1}, yu^(-1)]*G[{1, 1/(yu*yv), 1/(yu*yv)}, yw] - 
     4*G[{1}, yv^(-1)]*G[{1, 1/(yu*yv), 1/(yu*yv)}, yw] - 
     4*G[{1}, yw]*G[{1, 1/(yu*yv), 1/(yu*yv)}, yw] + 
     4*G[{yu}, yv^(-1)]*G[{1, 1/(yu*yv), 1/(yu*yv)}, yw] + 
     2*G[{1/(yu*yv)}, yw]*G[{1, 1/(yu*yv), 1/(yu*yv)}, yw] + 
     2*G[{0}, yu^(-1)]*G[{yu^(-1), yu^(-1), 1/(yu*yv)}, yw] + 
     2*G[{0}, yv^(-1)]*G[{yu^(-1), yu^(-1), 1/(yu*yv)}, yw] - 
     2*G[{0}, yw]*G[{yu^(-1), yu^(-1), 1/(yu*yv)}, yw] - 
     4*G[{1}, yv^(-1)]*G[{yu^(-1), yu^(-1), 1/(yu*yv)}, yw] + 
     4*G[{yu^(-1)}, yw]*G[{yu^(-1), yu^(-1), 1/(yu*yv)}, yw] - 
     2*G[{1/(yu*yv)}, yw]*G[{yu^(-1), 1/(yu*yv), yv^(-1)}, yw] + 
     G[{0}, yu^(-1)]*G[{yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] + 
     G[{0}, yv^(-1)]*G[{yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] - 
     G[{0}, yw]*G[{yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] - 
     2*G[{1}, yu^(-1)]*G[{yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] - 
     G[{1/(yu*yv)}, yw]*G[{yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] + 
     2*G[{0}, yu^(-1)]*G[{yv^(-1), yv^(-1), 1/(yu*yv)}, yw] + 
     2*G[{0}, yv^(-1)]*G[{yv^(-1), yv^(-1), 1/(yu*yv)}, yw] - 
     2*G[{0}, yw]*G[{yv^(-1), yv^(-1), 1/(yu*yv)}, yw] - 
     4*G[{1}, yu^(-1)]*G[{yv^(-1), yv^(-1), 1/(yu*yv)}, yw] + 
     4*G[{yv^(-1)}, yw]*G[{yv^(-1), yv^(-1), 1/(yu*yv)}, yw] + 
     G[{0}, yu^(-1)]*G[{yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] + 
     G[{0}, yv^(-1)]*G[{yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] - 
     G[{0}, yw]*G[{yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] - 
     2*G[{1}, yv^(-1)]*G[{yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] + 
     2*G[{yu^(-1)}, yw]*G[{yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] - 
     G[{1/(yu*yv)}, yw]*G[{yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] + 
     G[{0, 0, 0, 1}, yu^(-1)] + G[{0, 0, 0, 1}, yv^(-1)] - 
     G[{0, 0, 0, yu}, yv^(-1)] + G[{0, 0, 1, 1}, yu^(-1)] + 
     G[{0, 0, 1, 1}, yv^(-1)] + 2*G[{0, 0, 1, 1}, yw] - 
     2*G[{0, 0, 1, yu^(-1)}, yw] + 2*G[{0, 0, 1, yu}, yv^(-1)] - 
     2*G[{0, 0, 1, yv^(-1)}, yw] + 2*G[{0, 0, 1, 1/(yu*yv)}, yw] - 
     2*G[{0, 0, yu^(-1), 1}, yw] + G[{0, 0, yu, 1}, yv^(-1)] - 
     2*G[{0, 0, yu, yu}, yv^(-1)] - 2*G[{0, 0, yv^(-1), 1}, yw] + 
     2*G[{0, 0, 1/(yu*yv), 1}, yw] - 2*G[{0, 0, 1/(yu*yv), 1/(yu*yv)}, yw] - 
     G[{0, 1, 0, yu^(-1)}, yw] + G[{0, 1, 0, yu}, yv^(-1)] - 
     G[{0, 1, 0, yv^(-1)}, yw] + 2*G[{0, 1, 0, 1/(yu*yv)}, yw] + 
     2*G[{0, 1, 1, 1}, yw] + G[{0, 1, 1, yu^(-1)}, yw] + 
     G[{0, 1, 1, yv^(-1)}, yw] + 2*G[{0, 1, yu^(-1), 1}, yw] - 
     2*G[{0, 1, yu^(-1), yu^(-1)}, yw] - 2*G[{0, 1, yu^(-1), 1/(yu*yv)}, 
       yw] + 2*G[{0, 1, yv^(-1), 1}, yw] - 
     2*G[{0, 1, yv^(-1), yv^(-1)}, yw] - 2*G[{0, 1, yv^(-1), 1/(yu*yv)}, 
       yw] - 2*G[{0, 1, 1/(yu*yv), 1}, yw] + G[{0, 1, 1/(yu*yv), yu^(-1)}, 
      yw] + G[{0, 1, 1/(yu*yv), yv^(-1)}, yw] - G[{0, yu^(-1), 0, 1/(yu*yv)}, 
      yw] - G[{0, yu^(-1), 1, yu^(-1)}, yw] - G[{0, yu^(-1), 1, yv^(-1)}, 
      yw] - 2*G[{0, yu^(-1), yu^(-1), 1}, yw] + 
     2*G[{0, yu^(-1), yu^(-1), 1/(yu*yv)}, yw] - 
     2*G[{0, yu^(-1), yv^(-1), 1}, yw] + 
     2*G[{0, yu^(-1), yv^(-1), 1/(yu*yv)}, yw] + 
     G[{0, yu^(-1), 1/(yu*yv), yu^(-1)}, yw] + 
     G[{0, yu^(-1), 1/(yu*yv), yv^(-1)}, yw] - G[{0, yv^(-1), 0, 1/(yu*yv)}, 
      yw] - G[{0, yv^(-1), 1, yu^(-1)}, yw] - G[{0, yv^(-1), 1, yv^(-1)}, 
      yw] - 2*G[{0, yv^(-1), yu^(-1), 1}, yw] + 
     2*G[{0, yv^(-1), yu^(-1), 1/(yu*yv)}, yw] - 
     2*G[{0, yv^(-1), yv^(-1), 1}, yw] + 
     2*G[{0, yv^(-1), yv^(-1), 1/(yu*yv)}, yw] + 
     G[{0, yv^(-1), 1/(yu*yv), yu^(-1)}, yw] + 
     G[{0, yv^(-1), 1/(yu*yv), yv^(-1)}, yw] - 
     2*G[{0, 1/(yu*yv), 1, 1}, yw] + G[{0, 1/(yu*yv), 1, yu^(-1)}, yw] + 
     G[{0, 1/(yu*yv), 1, yv^(-1)}, yw] + 2*G[{0, 1/(yu*yv), yu^(-1), 1}, 
       yw] + 2*G[{0, 1/(yu*yv), yu^(-1), yu^(-1)}, yw] - 
     2*G[{0, 1/(yu*yv), yu^(-1), 1/(yu*yv)}, yw] + 
     2*G[{0, 1/(yu*yv), yv^(-1), 1}, yw] + 
     2*G[{0, 1/(yu*yv), yv^(-1), yv^(-1)}, yw] - 
     2*G[{0, 1/(yu*yv), yv^(-1), 1/(yu*yv)}, yw] + 
     2*G[{0, 1/(yu*yv), 1/(yu*yv), 1}, yw] - 
     3*G[{0, 1/(yu*yv), 1/(yu*yv), yu^(-1)}, yw] - 
     3*G[{0, 1/(yu*yv), 1/(yu*yv), yv^(-1)}, yw] - G[{1, 1, 1, yu^(-1)}, 
      yw] - G[{1, 1, 1, yv^(-1)}, yw] + 6*G[{1, 1, 1, 1/(yu*yv)}, yw] - 
     4*G[{1, 1, yu^(-1), yu^(-1)}, yw] - 2*G[{1, 1, yu^(-1), yv^(-1)}, yw] + 
     3*G[{1, 1, yu^(-1), 1/(yu*yv)}, yw] - 
     2*G[{1, 1, yv^(-1), yu^(-1)}, yw] - 4*G[{1, 1, yv^(-1), yv^(-1)}, yw] + 
     3*G[{1, 1, yv^(-1), 1/(yu*yv)}, yw] + 
     4*G[{1, 1, 1/(yu*yv), yu^(-1)}, yw] + 
     4*G[{1, 1, 1/(yu*yv), yv^(-1)}, yw] + 
     2*G[{1, 1, 1/(yu*yv), 1/(yu*yv)}, yw] + 
     2*G[{1, yu^(-1), 1, 1/(yu*yv)}, yw] - 
     4*G[{1, yu^(-1), yu^(-1), yu^(-1)}, yw] - 
     4*G[{1, yu^(-1), yu^(-1), 1/(yu*yv)}, yw] - 
     2*G[{1, yu^(-1), yv^(-1), 1/(yu*yv)}, yw] - 
     2*G[{1, yu^(-1), 1/(yu*yv), yu^(-1)}, yw] + 
     G[{1, yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] + 
     2*G[{1, yv^(-1), 1, 1/(yu*yv)}, yw] - 
     2*G[{1, yv^(-1), yu^(-1), 1/(yu*yv)}, yw] - 
     4*G[{1, yv^(-1), yv^(-1), yv^(-1)}, yw] - 
     4*G[{1, yv^(-1), yv^(-1), 1/(yu*yv)}, yw] - 
     2*G[{1, yv^(-1), 1/(yu*yv), yv^(-1)}, yw] + 
     G[{1, yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] + 
     2*G[{1, 1/(yu*yv), yu^(-1), 1/(yu*yv)}, yw] + 
     2*G[{1, 1/(yu*yv), yv^(-1), 1/(yu*yv)}, yw] + 
     4*G[{1, 1/(yu*yv), 1/(yu*yv), yu^(-1)}, yw] + 
     4*G[{1, 1/(yu*yv), 1/(yu*yv), yv^(-1)}, yw] - 
     2*G[{1, 1/(yu*yv), 1/(yu*yv), 1/(yu*yv)}, yw] - 
     4*G[{yu^(-1), yu^(-1), yu^(-1), 1/(yu*yv)}, yw] + 
     2*G[{yu^(-1), 1/(yu*yv), yv^(-1), 1/(yu*yv)}, yw] + 
     2*G[{yu^(-1), 1/(yu*yv), 1/(yu*yv), yv^(-1)}, yw] + 
     G[{yu^(-1), 1/(yu*yv), 1/(yu*yv), 1/(yu*yv)}, yw] - 
     4*G[{yv^(-1), yv^(-1), yv^(-1), 1/(yu*yv)}, yw] + 
     G[{yv^(-1), 1/(yu*yv), 1/(yu*yv), 1/(yu*yv)}, yw] - 
     2*G[{1}, yw]*Zeta[3] + 2*G[{1/(yu*yv)}, yw]*Zeta[3]
 
Omega2vwuRegII = -Pi^4/30 + (Pi^2*G[{1}, yu^(-1)]^2)/12 + 
     (G[{0}, yu^(-1)]^2*G[{1}, yu^(-1)]^2)/4 + 
     (G[{0}, yu^(-1)]*G[{0}, yv^(-1)]*G[{1}, yu^(-1)]^2)/2 + 
     (G[{0}, yv^(-1)]^2*G[{1}, yu^(-1)]^2)/4 - 
     (G[{0}, yu^(-1)]*G[{0}, yw]*G[{1}, yu^(-1)]^2)/2 - 
     (G[{0}, yv^(-1)]*G[{0}, yw]*G[{1}, yu^(-1)]^2)/2 + 
     (G[{0}, yw]^2*G[{1}, yu^(-1)]^2)/4 - (G[{0}, yu^(-1)]*G[{1}, yu^(-1)]^3)/
      2 - (G[{0}, yv^(-1)]*G[{1}, yu^(-1)]^3)/2 + 
     (G[{0}, yw]*G[{1}, yu^(-1)]^3)/2 + G[{1}, yu^(-1)]^4/4 - 
     (Pi^2*G[{0}, yu^(-1)]*G[{1}, yv^(-1)])/6 - 
     (Pi^2*G[{0}, yv^(-1)]*G[{1}, yv^(-1)])/6 + 
     (Pi^2*G[{0}, yw]*G[{1}, yv^(-1)])/6 - 
     (Pi^2*G[{1}, yu^(-1)]*G[{1}, yv^(-1)])/6 - 
     (G[{0}, yu^(-1)]^2*G[{1}, yu^(-1)]*G[{1}, yv^(-1)])/2 - 
     G[{0}, yu^(-1)]*G[{0}, yv^(-1)]*G[{1}, yu^(-1)]*G[{1}, yv^(-1)] - 
     (G[{0}, yv^(-1)]^2*G[{1}, yu^(-1)]*G[{1}, yv^(-1)])/2 + 
     G[{0}, yu^(-1)]*G[{0}, yw]*G[{1}, yu^(-1)]*G[{1}, yv^(-1)] + 
     G[{0}, yv^(-1)]*G[{0}, yw]*G[{1}, yu^(-1)]*G[{1}, yv^(-1)] - 
     (G[{0}, yw]^2*G[{1}, yu^(-1)]*G[{1}, yv^(-1)])/2 + 
     (G[{0}, yu^(-1)]*G[{1}, yu^(-1)]^2*G[{1}, yv^(-1)])/2 + 
     (G[{0}, yv^(-1)]*G[{1}, yu^(-1)]^2*G[{1}, yv^(-1)])/2 - 
     (G[{0}, yw]*G[{1}, yu^(-1)]^2*G[{1}, yv^(-1)])/2 + 
     (Pi^2*G[{1}, yv^(-1)]^2)/12 + (G[{0}, yu^(-1)]*G[{1}, yu^(-1)]*
       G[{1}, yv^(-1)]^2)/2 + (G[{0}, yv^(-1)]*G[{1}, yu^(-1)]*
       G[{1}, yv^(-1)]^2)/2 - (G[{0}, yw]*G[{1}, yu^(-1)]*G[{1}, yv^(-1)]^2)/
      2 - (G[{1}, yu^(-1)]^2*G[{1}, yv^(-1)]^2)/2 + 
     (Pi^2*G[{0}, yu^(-1)]*G[{1}, yw])/6 + (Pi^2*G[{0}, yv^(-1)]*G[{1}, yw])/
      6 - (Pi^2*G[{0}, yw]*G[{1}, yw])/6 + (Pi^2*G[{1}, yu^(-1)]*G[{1}, yw])/
      6 + (G[{0}, yu^(-1)]^2*G[{1}, yu^(-1)]*G[{1}, yw])/2 + 
     G[{0}, yu^(-1)]*G[{0}, yv^(-1)]*G[{1}, yu^(-1)]*G[{1}, yw] + 
     (G[{0}, yv^(-1)]^2*G[{1}, yu^(-1)]*G[{1}, yw])/2 - 
     G[{0}, yu^(-1)]*G[{0}, yw]*G[{1}, yu^(-1)]*G[{1}, yw] - 
     G[{0}, yv^(-1)]*G[{0}, yw]*G[{1}, yu^(-1)]*G[{1}, yw] + 
     (G[{0}, yw]^2*G[{1}, yu^(-1)]*G[{1}, yw])/2 - 
     (G[{0}, yu^(-1)]*G[{1}, yu^(-1)]^2*G[{1}, yw])/2 - 
     (G[{0}, yv^(-1)]*G[{1}, yu^(-1)]^2*G[{1}, yw])/2 + 
     (G[{0}, yw]*G[{1}, yu^(-1)]^2*G[{1}, yw])/2 - 
     (Pi^2*G[{1}, yv^(-1)]*G[{1}, yw])/6 - G[{0}, yu^(-1)]*G[{1}, yu^(-1)]*
      G[{1}, yv^(-1)]*G[{1}, yw] - G[{0}, yv^(-1)]*G[{1}, yu^(-1)]*
      G[{1}, yv^(-1)]*G[{1}, yw] + G[{0}, yw]*G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*
      G[{1}, yw] + G[{1}, yu^(-1)]^2*G[{1}, yv^(-1)]*G[{1}, yw] + 
     (Pi^2*G[{1}, yw]^2)/12 + (G[{0}, yu^(-1)]*G[{1}, yu^(-1)]*G[{1}, yw]^2)/
      2 + (G[{0}, yv^(-1)]*G[{1}, yu^(-1)]*G[{1}, yw]^2)/2 - 
     (G[{0}, yw]*G[{1}, yu^(-1)]*G[{1}, yw]^2)/2 - 
     (G[{1}, yu^(-1)]^2*G[{1}, yw]^2)/2 - (Pi^2*G[{1}, yw]*G[{yu}, yv^(-1)])/
      3 - (G[{0}, yu^(-1)]^2*G[{1}, yw]*G[{yu}, yv^(-1)])/2 - 
     G[{0}, yu^(-1)]*G[{0}, yv^(-1)]*G[{1}, yw]*G[{yu}, yv^(-1)] - 
     (G[{0}, yv^(-1)]^2*G[{1}, yw]*G[{yu}, yv^(-1)])/2 + 
     G[{0}, yu^(-1)]*G[{0}, yw]*G[{1}, yw]*G[{yu}, yv^(-1)] + 
     G[{0}, yv^(-1)]*G[{0}, yw]*G[{1}, yw]*G[{yu}, yv^(-1)] - 
     (G[{0}, yw]^2*G[{1}, yw]*G[{yu}, yv^(-1)])/2 + 
     (G[{1}, yv^(-1)]^2*G[{1}, yw]*G[{yu}, yv^(-1)])/2 - 
     (G[{0}, yu^(-1)]*G[{1}, yw]^2*G[{yu}, yv^(-1)])/2 - 
     (G[{0}, yv^(-1)]*G[{1}, yw]^2*G[{yu}, yv^(-1)])/2 + 
     (G[{0}, yw]*G[{1}, yw]^2*G[{yu}, yv^(-1)])/2 + 
     G[{0}, yu^(-1)]*G[{1}, yw]*G[{yu}, yv^(-1)]^2 + 
     G[{0}, yv^(-1)]*G[{1}, yw]*G[{yu}, yv^(-1)]^2 - 
     G[{0}, yw]*G[{1}, yw]*G[{yu}, yv^(-1)]^2 + 
     (G[{1}, yw]^2*G[{yu}, yv^(-1)]^2)/2 - (2*G[{1}, yw]*G[{yu}, yv^(-1)]^3)/
      3 - (Pi^2*G[{1}, yu^(-1)]*G[{1/(yu*yv)}, yw])/6 - 
     (G[{0}, yu^(-1)]^2*G[{1}, yu^(-1)]*G[{1/(yu*yv)}, yw])/2 - 
     G[{0}, yu^(-1)]*G[{0}, yv^(-1)]*G[{1}, yu^(-1)]*G[{1/(yu*yv)}, yw] - 
     (G[{0}, yv^(-1)]^2*G[{1}, yu^(-1)]*G[{1/(yu*yv)}, yw])/2 + 
     G[{0}, yu^(-1)]*G[{0}, yw]*G[{1}, yu^(-1)]*G[{1/(yu*yv)}, yw] + 
     G[{0}, yv^(-1)]*G[{0}, yw]*G[{1}, yu^(-1)]*G[{1/(yu*yv)}, yw] - 
     (G[{0}, yw]^2*G[{1}, yu^(-1)]*G[{1/(yu*yv)}, yw])/2 + 
     (3*G[{0}, yu^(-1)]*G[{1}, yu^(-1)]^2*G[{1/(yu*yv)}, yw])/2 + 
     (3*G[{0}, yv^(-1)]*G[{1}, yu^(-1)]^2*G[{1/(yu*yv)}, yw])/2 - 
     (3*G[{0}, yw]*G[{1}, yu^(-1)]^2*G[{1/(yu*yv)}, yw])/2 - 
     G[{1}, yu^(-1)]^3*G[{1/(yu*yv)}, yw] - 
     (Pi^2*G[{1}, yv^(-1)]*G[{1/(yu*yv)}, yw])/6 - 
     G[{0}, yu^(-1)]*G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*G[{1/(yu*yv)}, yw] - 
     G[{0}, yv^(-1)]*G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*G[{1/(yu*yv)}, yw] + 
     G[{0}, yw]*G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*G[{1/(yu*yv)}, yw] + 
     G[{1}, yu^(-1)]*G[{1}, yv^(-1)]^2*G[{1/(yu*yv)}, yw] - 
     (Pi^2*G[{1}, yw]*G[{1/(yu*yv)}, yw])/2 - G[{0}, yu^(-1)]^2*G[{1}, yw]*
      G[{1/(yu*yv)}, yw] - 2*G[{0}, yu^(-1)]*G[{0}, yv^(-1)]*G[{1}, yw]*
      G[{1/(yu*yv)}, yw] - G[{0}, yv^(-1)]^2*G[{1}, yw]*G[{1/(yu*yv)}, yw] + 
     2*G[{0}, yu^(-1)]*G[{0}, yw]*G[{1}, yw]*G[{1/(yu*yv)}, yw] + 
     2*G[{0}, yv^(-1)]*G[{0}, yw]*G[{1}, yw]*G[{1/(yu*yv)}, yw] - 
     G[{0}, yw]^2*G[{1}, yw]*G[{1/(yu*yv)}, yw] + 
     G[{0}, yu^(-1)]*G[{1}, yu^(-1)]*G[{1}, yw]*G[{1/(yu*yv)}, yw] + 
     G[{0}, yv^(-1)]*G[{1}, yu^(-1)]*G[{1}, yw]*G[{1/(yu*yv)}, yw] - 
     G[{0}, yw]*G[{1}, yu^(-1)]*G[{1}, yw]*G[{1/(yu*yv)}, yw] + 
     2*G[{0}, yu^(-1)]*G[{1}, yv^(-1)]*G[{1}, yw]*G[{1/(yu*yv)}, yw] + 
     2*G[{0}, yv^(-1)]*G[{1}, yv^(-1)]*G[{1}, yw]*G[{1/(yu*yv)}, yw] - 
     2*G[{0}, yw]*G[{1}, yv^(-1)]*G[{1}, yw]*G[{1/(yu*yv)}, yw] - 
     2*G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*G[{1}, yw]*G[{1/(yu*yv)}, yw] - 
     G[{1}, yv^(-1)]^2*G[{1}, yw]*G[{1/(yu*yv)}, yw] - 
     G[{0}, yu^(-1)]*G[{1}, yw]^2*G[{1/(yu*yv)}, yw] - 
     G[{0}, yv^(-1)]*G[{1}, yw]^2*G[{1/(yu*yv)}, yw] + 
     G[{0}, yw]*G[{1}, yw]^2*G[{1/(yu*yv)}, yw] + 
     G[{1}, yu^(-1)]*G[{1}, yw]^2*G[{1/(yu*yv)}, yw] + 
     G[{1}, yv^(-1)]*G[{1}, yw]^2*G[{1/(yu*yv)}, yw] + 
     (Pi^2*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw])/3 + 
     (G[{0}, yu^(-1)]^2*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw])/2 + 
     G[{0}, yu^(-1)]*G[{0}, yv^(-1)]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw] + 
     (G[{0}, yv^(-1)]^2*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw])/2 - 
     G[{0}, yu^(-1)]*G[{0}, yw]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw] - 
     G[{0}, yv^(-1)]*G[{0}, yw]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw] + 
     (G[{0}, yw]^2*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw])/2 - 
     2*G[{0}, yu^(-1)]*G[{1}, yv^(-1)]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw] - 
     2*G[{0}, yv^(-1)]*G[{1}, yv^(-1)]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw] + 
     2*G[{0}, yw]*G[{1}, yv^(-1)]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw] + 
     (3*G[{1}, yv^(-1)]^2*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw])/2 - 
     G[{1}, yv^(-1)]*G[{1}, yw]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw] - 
     (G[{1}, yw]^2*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw])/2 + 
     G[{0}, yu^(-1)]*G[{yu^(-1)}, yw]^2*G[{1/(yu*yv)}, yw] + 
     G[{0}, yv^(-1)]*G[{yu^(-1)}, yw]^2*G[{1/(yu*yv)}, yw] - 
     G[{0}, yw]*G[{yu^(-1)}, yw]^2*G[{1/(yu*yv)}, yw] - 
     2*G[{1}, yv^(-1)]*G[{yu^(-1)}, yw]^2*G[{1/(yu*yv)}, yw] + 
     (2*G[{yu^(-1)}, yw]^3*G[{1/(yu*yv)}, yw])/3 + 
     (Pi^2*G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw])/3 + 
     (G[{0}, yu^(-1)]^2*G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw])/2 + 
     G[{0}, yu^(-1)]*G[{0}, yv^(-1)]*G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw] + 
     (G[{0}, yv^(-1)]^2*G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw])/2 - 
     G[{0}, yu^(-1)]*G[{0}, yw]*G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw] - 
     G[{0}, yv^(-1)]*G[{0}, yw]*G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw] + 
     (G[{0}, yw]^2*G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw])/2 - 
     (G[{1}, yv^(-1)]^2*G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw])/2 + 
     G[{0}, yu^(-1)]*G[{1}, yw]*G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw] + 
     G[{0}, yv^(-1)]*G[{1}, yw]*G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw] - 
     G[{0}, yw]*G[{1}, yw]*G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw] + 
     G[{1}, yw]*G[{yu^(-1)}, yw]*G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw] - 
     G[{0}, yu^(-1)]*G[{yu}, yv^(-1)]^2*G[{1/(yu*yv)}, yw] - 
     G[{0}, yv^(-1)]*G[{yu}, yv^(-1)]^2*G[{1/(yu*yv)}, yw] + 
     G[{0}, yw]*G[{yu}, yv^(-1)]^2*G[{1/(yu*yv)}, yw] - 
     G[{1}, yw]*G[{yu}, yv^(-1)]^2*G[{1/(yu*yv)}, yw] + 
     (2*G[{yu}, yv^(-1)]^3*G[{1/(yu*yv)}, yw])/3 + 
     (Pi^2*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw])/3 + 
     G[{0}, yu^(-1)]^2*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw] + 
     2*G[{0}, yu^(-1)]*G[{0}, yv^(-1)]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw] + 
     G[{0}, yv^(-1)]^2*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw] - 
     2*G[{0}, yu^(-1)]*G[{0}, yw]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw] - 
     2*G[{0}, yv^(-1)]*G[{0}, yw]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw] + 
     G[{0}, yw]^2*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw] - 
     2*G[{0}, yu^(-1)]*G[{1}, yu^(-1)]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw] - 
     2*G[{0}, yv^(-1)]*G[{1}, yu^(-1)]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw] + 
     2*G[{0}, yw]*G[{1}, yu^(-1)]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw] + 
     2*G[{1}, yu^(-1)]^2*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw] - 
     2*G[{0}, yu^(-1)]*G[{1}, yv^(-1)]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw] - 
     2*G[{0}, yv^(-1)]*G[{1}, yv^(-1)]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw] + 
     2*G[{0}, yw]*G[{1}, yv^(-1)]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw] + 
     G[{1}, yv^(-1)]^2*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw] + 
     2*G[{0}, yu^(-1)]*G[{1}, yw]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw] + 
     2*G[{0}, yv^(-1)]*G[{1}, yw]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw] - 
     2*G[{0}, yw]*G[{1}, yw]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw] - 
     2*G[{1}, yv^(-1)]*G[{1}, yw]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw] + 
     G[{1}, yw]^2*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw] - 
     2*G[{1}, yw]*G[{yu}, yv^(-1)]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw] - 
     (Pi^2*G[{1/(yu*yv)}, yw]^2)/12 - 
     (G[{0}, yu^(-1)]^2*G[{1/(yu*yv)}, yw]^2)/4 - 
     (G[{0}, yu^(-1)]*G[{0}, yv^(-1)]*G[{1/(yu*yv)}, yw]^2)/2 - 
     (G[{0}, yv^(-1)]^2*G[{1/(yu*yv)}, yw]^2)/4 + 
     (G[{0}, yu^(-1)]*G[{0}, yw]*G[{1/(yu*yv)}, yw]^2)/2 + 
     (G[{0}, yv^(-1)]*G[{0}, yw]*G[{1/(yu*yv)}, yw]^2)/2 - 
     (G[{0}, yw]^2*G[{1/(yu*yv)}, yw]^2)/4 - 
     (G[{0}, yu^(-1)]*G[{1}, yu^(-1)]*G[{1/(yu*yv)}, yw]^2)/2 - 
     (G[{0}, yv^(-1)]*G[{1}, yu^(-1)]*G[{1/(yu*yv)}, yw]^2)/2 + 
     (G[{0}, yw]*G[{1}, yu^(-1)]*G[{1/(yu*yv)}, yw]^2)/2 + 
     (G[{1}, yu^(-1)]^2*G[{1/(yu*yv)}, yw]^2)/2 + 
     G[{0}, yu^(-1)]*G[{1}, yv^(-1)]*G[{1/(yu*yv)}, yw]^2 + 
     G[{0}, yv^(-1)]*G[{1}, yv^(-1)]*G[{1/(yu*yv)}, yw]^2 - 
     G[{0}, yw]*G[{1}, yv^(-1)]*G[{1/(yu*yv)}, yw]^2 - 
     (3*G[{1}, yv^(-1)]^2*G[{1/(yu*yv)}, yw]^2)/4 - 
     G[{0}, yu^(-1)]*G[{1}, yw]*G[{1/(yu*yv)}, yw]^2 - 
     G[{0}, yv^(-1)]*G[{1}, yw]*G[{1/(yu*yv)}, yw]^2 + 
     G[{0}, yw]*G[{1}, yw]*G[{1/(yu*yv)}, yw]^2 + 
     (G[{1}, yv^(-1)]*G[{1}, yw]*G[{1/(yu*yv)}, yw]^2)/2 - 
     (3*G[{1}, yw]^2*G[{1/(yu*yv)}, yw]^2)/4 - 
     (G[{0}, yu^(-1)]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2)/2 - 
     (G[{0}, yv^(-1)]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2)/2 + 
     (G[{0}, yw]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2)/2 + 
     G[{1}, yv^(-1)]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2 - 
     (G[{yu^(-1)}, yw]^2*G[{1/(yu*yv)}, yw]^2)/2 + 
     (G[{0}, yu^(-1)]*G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw]^2)/2 + 
     (G[{0}, yv^(-1)]*G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw]^2)/2 - 
     (G[{0}, yw]*G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw]^2)/2 + 
     (3*G[{1}, yw]*G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw]^2)/2 - 
     (G[{yu}, yv^(-1)]^2*G[{1/(yu*yv)}, yw]^2)/2 + 
     G[{0}, yu^(-1)]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2 + 
     G[{0}, yv^(-1)]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2 - 
     G[{0}, yw]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2 - 
     2*G[{1}, yu^(-1)]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2 + 
     G[{yv^(-1)}, yw]^2*G[{1/(yu*yv)}, yw]^2 - 
     (G[{0}, yu^(-1)]*G[{1/(yu*yv)}, yw]^3)/6 - 
     (G[{0}, yv^(-1)]*G[{1/(yu*yv)}, yw]^3)/6 + 
     (G[{0}, yw]*G[{1/(yu*yv)}, yw]^3)/6 + 
     (G[{1}, yu^(-1)]*G[{1/(yu*yv)}, yw]^3)/3 + 
     (G[{1}, yv^(-1)]*G[{1/(yu*yv)}, yw]^3)/6 + 
     (G[{1}, yw]*G[{1/(yu*yv)}, yw]^3)/6 - 
     (G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]^3)/6 - 
     (G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw]^3)/6 - 
     (G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]^3)/3 - (Pi^2*G[{0, 1}, yu^(-1)])/
      6 - (G[{0}, yu^(-1)]^2*G[{0, 1}, yu^(-1)])/2 - 
     G[{0}, yu^(-1)]*G[{0}, yv^(-1)]*G[{0, 1}, yu^(-1)] - 
     (G[{0}, yv^(-1)]^2*G[{0, 1}, yu^(-1)])/2 + G[{0}, yu^(-1)]*G[{0}, yw]*
      G[{0, 1}, yu^(-1)] + G[{0}, yv^(-1)]*G[{0}, yw]*G[{0, 1}, yu^(-1)] - 
     (G[{0}, yw]^2*G[{0, 1}, yu^(-1)])/2 + G[{0}, yu^(-1)]*G[{1}, yu^(-1)]*
      G[{0, 1}, yu^(-1)] + G[{0}, yv^(-1)]*G[{1}, yu^(-1)]*
      G[{0, 1}, yu^(-1)] - G[{0}, yw]*G[{1}, yu^(-1)]*G[{0, 1}, yu^(-1)] - 
     (G[{1}, yu^(-1)]^2*G[{0, 1}, yu^(-1)])/2 - G[{1}, yu^(-1)]*
      G[{1}, yv^(-1)]*G[{0, 1}, yu^(-1)] + 
     (G[{1}, yv^(-1)]^2*G[{0, 1}, yu^(-1)])/2 + G[{1}, yu^(-1)]*G[{1}, yw]*
      G[{0, 1}, yu^(-1)] - G[{1}, yv^(-1)]*G[{1}, yw]*G[{0, 1}, yu^(-1)] + 
     (G[{1}, yw]^2*G[{0, 1}, yu^(-1)])/2 - G[{0}, yu^(-1)]*G[{1/(yu*yv)}, yw]*
      G[{0, 1}, yu^(-1)] - G[{0}, yv^(-1)]*G[{1/(yu*yv)}, yw]*
      G[{0, 1}, yu^(-1)] + G[{0}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1}, yu^(-1)] + 
     G[{1}, yu^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, 1}, yu^(-1)] + 
     G[{1}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, 1}, yu^(-1)] - 
     G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1}, yu^(-1)] - 
     2*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1}, yu^(-1)] + 
     (G[{1/(yu*yv)}, yw]^2*G[{0, 1}, yu^(-1)])/2 + G[{0, 1}, yu^(-1)]^2/2 - 
     G[{0}, yu^(-1)]*G[{1}, yv^(-1)]*G[{0, 1}, yv^(-1)] - 
     G[{0}, yv^(-1)]*G[{1}, yv^(-1)]*G[{0, 1}, yv^(-1)] + 
     G[{0}, yw]*G[{1}, yv^(-1)]*G[{0, 1}, yv^(-1)] + 
     (G[{1}, yv^(-1)]^2*G[{0, 1}, yv^(-1)])/2 + G[{0}, yu^(-1)]*G[{1}, yw]*
      G[{0, 1}, yv^(-1)] + G[{0}, yv^(-1)]*G[{1}, yw]*G[{0, 1}, yv^(-1)] - 
     G[{0}, yw]*G[{1}, yw]*G[{0, 1}, yv^(-1)] - G[{1}, yv^(-1)]*G[{1}, yw]*
      G[{0, 1}, yv^(-1)] + (G[{1}, yw]^2*G[{0, 1}, yv^(-1)])/2 - 
     G[{1}, yw]*G[{yu}, yv^(-1)]*G[{0, 1}, yv^(-1)] - 
     G[{1}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, 1}, yv^(-1)] - 
     G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1}, yv^(-1)] + 
     G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1}, yv^(-1)] + 
     G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, 1}, yv^(-1)] + 
     (Pi^2*G[{0, 1}, yw])/3 + (G[{0}, yu^(-1)]^2*G[{0, 1}, yw])/2 + 
     G[{0}, yu^(-1)]*G[{0}, yv^(-1)]*G[{0, 1}, yw] + 
     (G[{0}, yv^(-1)]^2*G[{0, 1}, yw])/2 - G[{0}, yu^(-1)]*G[{0}, yw]*
      G[{0, 1}, yw] - G[{0}, yv^(-1)]*G[{0}, yw]*G[{0, 1}, yw] + 
     (G[{0}, yw]^2*G[{0, 1}, yw])/2 - G[{0}, yu^(-1)]*G[{1}, yv^(-1)]*
      G[{0, 1}, yw] - G[{0}, yv^(-1)]*G[{1}, yv^(-1)]*G[{0, 1}, yw] + 
     G[{0}, yw]*G[{1}, yv^(-1)]*G[{0, 1}, yw] + 
     (G[{1}, yv^(-1)]^2*G[{0, 1}, yw])/2 - (G[{1}, yw]^2*G[{0, 1}, yw])/2 - 
     G[{0}, yu^(-1)]*G[{yu}, yv^(-1)]*G[{0, 1}, yw] - 
     G[{0}, yv^(-1)]*G[{yu}, yv^(-1)]*G[{0, 1}, yw] + 
     G[{0}, yw]*G[{yu}, yv^(-1)]*G[{0, 1}, yw] + G[{yu}, yv^(-1)]^2*
      G[{0, 1}, yw] - G[{0}, yu^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, 1}, yw] - 
     G[{0}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, 1}, yw] + 
     G[{0}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1}, yw] + 
     2*G[{1}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, 1}, yw] - 
     G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1}, yw] + 
     2*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1}, yw] - 
     (G[{1/(yu*yv)}, yw]^2*G[{0, 1}, yw])/2 + G[{0, 1}, yv^(-1)]*
      G[{0, 1}, yw] - (Pi^2*G[{0, yu^(-1)}, yw])/3 - 
     (G[{0}, yu^(-1)]^2*G[{0, yu^(-1)}, yw])/2 - 
     G[{0}, yu^(-1)]*G[{0}, yv^(-1)]*G[{0, yu^(-1)}, yw] - 
     (G[{0}, yv^(-1)]^2*G[{0, yu^(-1)}, yw])/2 + G[{0}, yu^(-1)]*G[{0}, yw]*
      G[{0, yu^(-1)}, yw] + G[{0}, yv^(-1)]*G[{0}, yw]*G[{0, yu^(-1)}, yw] - 
     (G[{0}, yw]^2*G[{0, yu^(-1)}, yw])/2 + 2*G[{0}, yu^(-1)]*G[{1}, yv^(-1)]*
      G[{0, yu^(-1)}, yw] + 2*G[{0}, yv^(-1)]*G[{1}, yv^(-1)]*
      G[{0, yu^(-1)}, yw] - 2*G[{0}, yw]*G[{1}, yv^(-1)]*
      G[{0, yu^(-1)}, yw] - (3*G[{1}, yv^(-1)]^2*G[{0, yu^(-1)}, yw])/2 + 
     (G[{1}, yw]^2*G[{0, yu^(-1)}, yw])/2 + G[{0}, yu^(-1)]*
      G[{1/(yu*yv)}, yw]*G[{0, yu^(-1)}, yw] + G[{0}, yv^(-1)]*
      G[{1/(yu*yv)}, yw]*G[{0, yu^(-1)}, yw] - G[{0}, yw]*G[{1/(yu*yv)}, yw]*
      G[{0, yu^(-1)}, yw] - 2*G[{1}, yv^(-1)]*G[{1/(yu*yv)}, yw]*
      G[{0, yu^(-1)}, yw] + G[{1}, yw]*G[{1/(yu*yv)}, yw]*
      G[{0, yu^(-1)}, yw] - 2*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*
      G[{0, yu^(-1)}, yw] + (G[{1/(yu*yv)}, yw]^2*G[{0, yu^(-1)}, yw])/2 - 
     G[{0, 1}, yv^(-1)]*G[{0, yu^(-1)}, yw] + G[{0}, yu^(-1)]*G[{1}, yv^(-1)]*
      G[{0, yu}, yv^(-1)] + G[{0}, yv^(-1)]*G[{1}, yv^(-1)]*
      G[{0, yu}, yv^(-1)] - G[{0}, yw]*G[{1}, yv^(-1)]*G[{0, yu}, yv^(-1)] - 
     (G[{1}, yv^(-1)]^2*G[{0, yu}, yv^(-1)])/2 - G[{0}, yu^(-1)]*G[{1}, yw]*
      G[{0, yu}, yv^(-1)] - G[{0}, yv^(-1)]*G[{1}, yw]*G[{0, yu}, yv^(-1)] + 
     G[{0}, yw]*G[{1}, yw]*G[{0, yu}, yv^(-1)] + G[{1}, yv^(-1)]*G[{1}, yw]*
      G[{0, yu}, yv^(-1)] - (G[{1}, yw]^2*G[{0, yu}, yv^(-1)])/2 + 
     G[{1}, yw]*G[{yu}, yv^(-1)]*G[{0, yu}, yv^(-1)] + 
     G[{1}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, yu}, yv^(-1)] + 
     G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{0, yu}, yv^(-1)] - 
     G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{0, yu}, yv^(-1)] - 
     G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, yu}, yv^(-1)] - 
     G[{0, 1}, yw]*G[{0, yu}, yv^(-1)] + G[{0, yu^(-1)}, yw]*
      G[{0, yu}, yv^(-1)] - (Pi^2*G[{0, yv^(-1)}, yw])/6 - 
     (G[{0}, yu^(-1)]^2*G[{0, yv^(-1)}, yw])/2 - 
     G[{0}, yu^(-1)]*G[{0}, yv^(-1)]*G[{0, yv^(-1)}, yw] - 
     (G[{0}, yv^(-1)]^2*G[{0, yv^(-1)}, yw])/2 + G[{0}, yu^(-1)]*G[{0}, yw]*
      G[{0, yv^(-1)}, yw] + G[{0}, yv^(-1)]*G[{0}, yw]*G[{0, yv^(-1)}, yw] - 
     (G[{0}, yw]^2*G[{0, yv^(-1)}, yw])/2 + G[{0}, yu^(-1)]*G[{1}, yu^(-1)]*
      G[{0, yv^(-1)}, yw] + G[{0}, yv^(-1)]*G[{1}, yu^(-1)]*
      G[{0, yv^(-1)}, yw] - G[{0}, yw]*G[{1}, yu^(-1)]*G[{0, yv^(-1)}, yw] - 
     G[{1}, yu^(-1)]^2*G[{0, yv^(-1)}, yw] + G[{0}, yu^(-1)]*G[{1}, yv^(-1)]*
      G[{0, yv^(-1)}, yw] + G[{0}, yv^(-1)]*G[{1}, yv^(-1)]*
      G[{0, yv^(-1)}, yw] - G[{0}, yw]*G[{1}, yv^(-1)]*G[{0, yv^(-1)}, yw] - 
     (G[{1}, yv^(-1)]^2*G[{0, yv^(-1)}, yw])/2 + 
     (G[{1}, yw]^2*G[{0, yv^(-1)}, yw])/2 + G[{0}, yu^(-1)]*
      G[{1/(yu*yv)}, yw]*G[{0, yv^(-1)}, yw] + G[{0}, yv^(-1)]*
      G[{1/(yu*yv)}, yw]*G[{0, yv^(-1)}, yw] - G[{0}, yw]*G[{1/(yu*yv)}, yw]*
      G[{0, yv^(-1)}, yw] - 2*G[{1}, yv^(-1)]*G[{1/(yu*yv)}, yw]*
      G[{0, yv^(-1)}, yw] + G[{1}, yw]*G[{1/(yu*yv)}, yw]*
      G[{0, yv^(-1)}, yw] - 2*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*
      G[{0, yv^(-1)}, yw] + (G[{1/(yu*yv)}, yw]^2*G[{0, yv^(-1)}, yw])/2 + 
     G[{0, 1}, yu^(-1)]*G[{0, yv^(-1)}, yw] - G[{0, 1}, yw]*
      G[{0, yv^(-1)}, yw] + G[{0, yu^(-1)}, yw]*G[{0, yv^(-1)}, yw] + 
     G[{0, yv^(-1)}, yw]^2/2 + (Pi^2*G[{0, 1/(yu*yv)}, yw])/6 + 
     (G[{0}, yu^(-1)]^2*G[{0, 1/(yu*yv)}, yw])/2 + 
     G[{0}, yu^(-1)]*G[{0}, yv^(-1)]*G[{0, 1/(yu*yv)}, yw] + 
     (G[{0}, yv^(-1)]^2*G[{0, 1/(yu*yv)}, yw])/2 - G[{0}, yu^(-1)]*G[{0}, yw]*
      G[{0, 1/(yu*yv)}, yw] - G[{0}, yv^(-1)]*G[{0}, yw]*
      G[{0, 1/(yu*yv)}, yw] + (G[{0}, yw]^2*G[{0, 1/(yu*yv)}, yw])/2 - 
     G[{0}, yu^(-1)]*G[{1}, yu^(-1)]*G[{0, 1/(yu*yv)}, yw] - 
     G[{0}, yv^(-1)]*G[{1}, yu^(-1)]*G[{0, 1/(yu*yv)}, yw] + 
     G[{0}, yw]*G[{1}, yu^(-1)]*G[{0, 1/(yu*yv)}, yw] + 
     G[{1}, yu^(-1)]^2*G[{0, 1/(yu*yv)}, yw] - 2*G[{0}, yu^(-1)]*
      G[{1}, yv^(-1)]*G[{0, 1/(yu*yv)}, yw] - 2*G[{0}, yv^(-1)]*
      G[{1}, yv^(-1)]*G[{0, 1/(yu*yv)}, yw] + 2*G[{0}, yw]*G[{1}, yv^(-1)]*
      G[{0, 1/(yu*yv)}, yw] + (3*G[{1}, yv^(-1)]^2*G[{0, 1/(yu*yv)}, yw])/2 - 
     (G[{1}, yw]^2*G[{0, 1/(yu*yv)}, yw])/2 + G[{0}, yu^(-1)]*
      G[{yu}, yv^(-1)]*G[{0, 1/(yu*yv)}, yw] + G[{0}, yv^(-1)]*
      G[{yu}, yv^(-1)]*G[{0, 1/(yu*yv)}, yw] - G[{0}, yw]*G[{yu}, yv^(-1)]*
      G[{0, 1/(yu*yv)}, yw] - G[{yu}, yv^(-1)]^2*G[{0, 1/(yu*yv)}, yw] - 
     G[{0}, yu^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv)}, yw] - 
     G[{0}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv)}, yw] + 
     G[{0}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv)}, yw] + 
     2*G[{1}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv)}, yw] - 
     G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv)}, yw] + 
     2*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv)}, yw] - 
     (G[{1/(yu*yv)}, yw]^2*G[{0, 1/(yu*yv)}, yw])/2 - 
     G[{0, 1}, yu^(-1)]*G[{0, 1/(yu*yv)}, yw] + 
     G[{0, 1}, yw]*G[{0, 1/(yu*yv)}, yw] - G[{0, yu^(-1)}, yw]*
      G[{0, 1/(yu*yv)}, yw] - G[{0, yv^(-1)}, yw]*G[{0, 1/(yu*yv)}, yw] + 
     G[{0, 1/(yu*yv)}, yw]^2/2 + (Pi^2*G[{1, yu^(-1)}, yw])/3 + 
     (G[{0}, yu^(-1)]^2*G[{1, yu^(-1)}, yw])/2 + 
     G[{0}, yu^(-1)]*G[{0}, yv^(-1)]*G[{1, yu^(-1)}, yw] + 
     (G[{0}, yv^(-1)]^2*G[{1, yu^(-1)}, yw])/2 - G[{0}, yu^(-1)]*G[{0}, yw]*
      G[{1, yu^(-1)}, yw] - G[{0}, yv^(-1)]*G[{0}, yw]*G[{1, yu^(-1)}, yw] + 
     (G[{0}, yw]^2*G[{1, yu^(-1)}, yw])/2 - 2*G[{0}, yu^(-1)]*G[{1}, yv^(-1)]*
      G[{1, yu^(-1)}, yw] - 2*G[{0}, yv^(-1)]*G[{1}, yv^(-1)]*
      G[{1, yu^(-1)}, yw] + 2*G[{0}, yw]*G[{1}, yv^(-1)]*
      G[{1, yu^(-1)}, yw] + (3*G[{1}, yv^(-1)]^2*G[{1, yu^(-1)}, yw])/2 - 
     G[{1}, yv^(-1)]*G[{1}, yw]*G[{1, yu^(-1)}, yw] - 
     (G[{1}, yw]^2*G[{1, yu^(-1)}, yw])/2 + G[{1}, yw]*G[{yu}, yv^(-1)]*
      G[{1, yu^(-1)}, yw] - G[{0}, yu^(-1)]*G[{1/(yu*yv)}, yw]*
      G[{1, yu^(-1)}, yw] - G[{0}, yv^(-1)]*G[{1/(yu*yv)}, yw]*
      G[{1, yu^(-1)}, yw] + G[{0}, yw]*G[{1/(yu*yv)}, yw]*
      G[{1, yu^(-1)}, yw] + 3*G[{1}, yv^(-1)]*G[{1/(yu*yv)}, yw]*
      G[{1, yu^(-1)}, yw] + G[{1}, yw]*G[{1/(yu*yv)}, yw]*
      G[{1, yu^(-1)}, yw] + G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*
      G[{1, yu^(-1)}, yw] - G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw]*
      G[{1, yu^(-1)}, yw] + 2*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*
      G[{1, yu^(-1)}, yw] - (G[{1/(yu*yv)}, yw]^2*G[{1, yu^(-1)}, yw])/2 + 
     G[{0, 1}, yv^(-1)]*G[{1, yu^(-1)}, yw] - G[{0, yu}, yv^(-1)]*
      G[{1, yu^(-1)}, yw] + G[{1, yu^(-1)}, yw]^2/2 + 
     (Pi^2*G[{1, yu}, yv^(-1)])/3 + (G[{0}, yu^(-1)]^2*G[{1, yu}, yv^(-1)])/
      2 + G[{0}, yu^(-1)]*G[{0}, yv^(-1)]*G[{1, yu}, yv^(-1)] + 
     (G[{0}, yv^(-1)]^2*G[{1, yu}, yv^(-1)])/2 - G[{0}, yu^(-1)]*G[{0}, yw]*
      G[{1, yu}, yv^(-1)] - G[{0}, yv^(-1)]*G[{0}, yw]*G[{1, yu}, yv^(-1)] + 
     (G[{0}, yw]^2*G[{1, yu}, yv^(-1)])/2 - 
     (G[{1}, yv^(-1)]^2*G[{1, yu}, yv^(-1)])/2 + G[{0}, yu^(-1)]*G[{1}, yw]*
      G[{1, yu}, yv^(-1)] + G[{0}, yv^(-1)]*G[{1}, yw]*G[{1, yu}, yv^(-1)] - 
     G[{0}, yw]*G[{1}, yw]*G[{1, yu}, yv^(-1)] - G[{1}, yv^(-1)]*G[{1}, yw]*
      G[{1, yu}, yv^(-1)] - G[{1}, yw]*G[{yu}, yv^(-1)]*G[{1, yu}, yv^(-1)] + 
     G[{0}, yu^(-1)]*G[{1/(yu*yv)}, yw]*G[{1, yu}, yv^(-1)] + 
     G[{0}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{1, yu}, yv^(-1)] - 
     G[{0}, yw]*G[{1/(yu*yv)}, yw]*G[{1, yu}, yv^(-1)] + 
     G[{1}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{1, yu}, yv^(-1)] + 
     G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{1, yu}, yv^(-1)] + 
     G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{1, yu}, yv^(-1)] + 
     2*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{1, yu}, yv^(-1)] - 
     (G[{1/(yu*yv)}, yw]^2*G[{1, yu}, yv^(-1)])/2 + 
     G[{0, 1}, yv^(-1)]*G[{1, yu}, yv^(-1)] + G[{0, 1}, yw]*
      G[{1, yu}, yv^(-1)] - G[{0, yu^(-1)}, yw]*G[{1, yu}, yv^(-1)] - 
     G[{0, yu}, yv^(-1)]*G[{1, yu}, yv^(-1)] - G[{0, yv^(-1)}, yw]*
      G[{1, yu}, yv^(-1)] + G[{0, 1/(yu*yv)}, yw]*G[{1, yu}, yv^(-1)] + 
     G[{1, yu^(-1)}, yw]*G[{1, yu}, yv^(-1)] + G[{1, yu}, yv^(-1)]^2/2 - 
     2*G[{0}, yu^(-1)]*G[{1/(yu*yv)}, yw]*G[{1, yv^(-1)}, yw] - 
     2*G[{0}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{1, yv^(-1)}, yw] + 
     2*G[{0}, yw]*G[{1/(yu*yv)}, yw]*G[{1, yv^(-1)}, yw] + 
     2*G[{1}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{1, yv^(-1)}, yw] - 
     2*G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{1, yv^(-1)}, yw] + 
     2*G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{1, yv^(-1)}, yw] + 
     (Pi^2*G[{1, 1/(yu*yv)}, yw])/3 + 
     (G[{0}, yu^(-1)]^2*G[{1, 1/(yu*yv)}, yw])/2 + 
     G[{0}, yu^(-1)]*G[{0}, yv^(-1)]*G[{1, 1/(yu*yv)}, yw] + 
     (G[{0}, yv^(-1)]^2*G[{1, 1/(yu*yv)}, yw])/2 - G[{0}, yu^(-1)]*G[{0}, yw]*
      G[{1, 1/(yu*yv)}, yw] - G[{0}, yv^(-1)]*G[{0}, yw]*
      G[{1, 1/(yu*yv)}, yw] + (G[{0}, yw]^2*G[{1, 1/(yu*yv)}, yw])/2 - 
     (G[{1}, yv^(-1)]^2*G[{1, 1/(yu*yv)}, yw])/2 + 
     2*G[{0}, yu^(-1)]*G[{1}, yw]*G[{1, 1/(yu*yv)}, yw] + 
     2*G[{0}, yv^(-1)]*G[{1}, yw]*G[{1, 1/(yu*yv)}, yw] - 
     2*G[{0}, yw]*G[{1}, yw]*G[{1, 1/(yu*yv)}, yw] - 
     G[{1}, yv^(-1)]*G[{1}, yw]*G[{1, 1/(yu*yv)}, yw] + 
     (3*G[{1}, yw]^2*G[{1, 1/(yu*yv)}, yw])/2 - 2*G[{0}, yu^(-1)]*
      G[{yu}, yv^(-1)]*G[{1, 1/(yu*yv)}, yw] - 2*G[{0}, yv^(-1)]*
      G[{yu}, yv^(-1)]*G[{1, 1/(yu*yv)}, yw] + 2*G[{0}, yw]*G[{yu}, yv^(-1)]*
      G[{1, 1/(yu*yv)}, yw] - 3*G[{1}, yw]*G[{yu}, yv^(-1)]*
      G[{1, 1/(yu*yv)}, yw] + 2*G[{yu}, yv^(-1)]^2*G[{1, 1/(yu*yv)}, yw] + 
     G[{0}, yu^(-1)]*G[{1/(yu*yv)}, yw]*G[{1, 1/(yu*yv)}, yw] + 
     G[{0}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{1, 1/(yu*yv)}, yw] - 
     G[{0}, yw]*G[{1/(yu*yv)}, yw]*G[{1, 1/(yu*yv)}, yw] - 
     G[{1}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{1, 1/(yu*yv)}, yw] + 
     G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{1, 1/(yu*yv)}, yw] - 
     G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{1, 1/(yu*yv)}, yw] - 
     G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{1, 1/(yu*yv)}, yw] + 
     2*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{1, 1/(yu*yv)}, yw] - 
     (G[{1/(yu*yv)}, yw]^2*G[{1, 1/(yu*yv)}, yw])/2 + 
     G[{0, 1}, yv^(-1)]*G[{1, 1/(yu*yv)}, yw] - G[{0, yu}, yv^(-1)]*
      G[{1, 1/(yu*yv)}, yw] + G[{1, yu^(-1)}, yw]*G[{1, 1/(yu*yv)}, yw] + 
     G[{1, yu}, yv^(-1)]*G[{1, 1/(yu*yv)}, yw] - G[{1, 1/(yu*yv)}, yw]^2/2 - 
     (Pi^2*G[{yu^(-1), 1/(yu*yv)}, yw])/3 - 
     (G[{0}, yu^(-1)]^2*G[{yu^(-1), 1/(yu*yv)}, yw])/2 - 
     G[{0}, yu^(-1)]*G[{0}, yv^(-1)]*G[{yu^(-1), 1/(yu*yv)}, yw] - 
     (G[{0}, yv^(-1)]^2*G[{yu^(-1), 1/(yu*yv)}, yw])/2 + 
     G[{0}, yu^(-1)]*G[{0}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw] + 
     G[{0}, yv^(-1)]*G[{0}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw] - 
     (G[{0}, yw]^2*G[{yu^(-1), 1/(yu*yv)}, yw])/2 + 
     2*G[{0}, yu^(-1)]*G[{1}, yv^(-1)]*G[{yu^(-1), 1/(yu*yv)}, yw] + 
     2*G[{0}, yv^(-1)]*G[{1}, yv^(-1)]*G[{yu^(-1), 1/(yu*yv)}, yw] - 
     2*G[{0}, yw]*G[{1}, yv^(-1)]*G[{yu^(-1), 1/(yu*yv)}, yw] - 
     (3*G[{1}, yv^(-1)]^2*G[{yu^(-1), 1/(yu*yv)}, yw])/2 + 
     G[{1}, yv^(-1)]*G[{1}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw] + 
     (G[{1}, yw]^2*G[{yu^(-1), 1/(yu*yv)}, yw])/2 - 
     2*G[{0}, yu^(-1)]*G[{yu^(-1)}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw] - 
     2*G[{0}, yv^(-1)]*G[{yu^(-1)}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw] + 
     2*G[{0}, yw]*G[{yu^(-1)}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw] + 
     4*G[{1}, yv^(-1)]*G[{yu^(-1)}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw] - 
     2*G[{yu^(-1)}, yw]^2*G[{yu^(-1), 1/(yu*yv)}, yw] - 
     G[{1}, yw]*G[{yu}, yv^(-1)]*G[{yu^(-1), 1/(yu*yv)}, yw] + 
     G[{0}, yu^(-1)]*G[{1/(yu*yv)}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw] + 
     G[{0}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw] - 
     G[{0}, yw]*G[{1/(yu*yv)}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw] - 
     G[{1}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw] + 
     G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw] + 
     G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw] - 
     G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw] - 
     2*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw] + 
     (G[{1/(yu*yv)}, yw]^2*G[{yu^(-1), 1/(yu*yv)}, yw])/2 - 
     G[{0, 1}, yv^(-1)]*G[{yu^(-1), 1/(yu*yv)}, yw] + 
     G[{0, yu}, yv^(-1)]*G[{yu^(-1), 1/(yu*yv)}, yw] - 
     G[{1, yu^(-1)}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw] - 
     G[{1, yu}, yv^(-1)]*G[{yu^(-1), 1/(yu*yv)}, yw] + 
     G[{1, 1/(yu*yv)}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw] - 
     G[{yu^(-1), 1/(yu*yv)}, yw]^2/2 - (Pi^2*G[{yv^(-1), 1/(yu*yv)}, yw])/3 - 
     G[{0}, yu^(-1)]^2*G[{yv^(-1), 1/(yu*yv)}, yw] - 
     2*G[{0}, yu^(-1)]*G[{0}, yv^(-1)]*G[{yv^(-1), 1/(yu*yv)}, yw] - 
     G[{0}, yv^(-1)]^2*G[{yv^(-1), 1/(yu*yv)}, yw] + 
     2*G[{0}, yu^(-1)]*G[{0}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw] + 
     2*G[{0}, yv^(-1)]*G[{0}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw] - 
     G[{0}, yw]^2*G[{yv^(-1), 1/(yu*yv)}, yw] + 2*G[{0}, yu^(-1)]*
      G[{1}, yu^(-1)]*G[{yv^(-1), 1/(yu*yv)}, yw] + 
     2*G[{0}, yv^(-1)]*G[{1}, yu^(-1)]*G[{yv^(-1), 1/(yu*yv)}, yw] - 
     2*G[{0}, yw]*G[{1}, yu^(-1)]*G[{yv^(-1), 1/(yu*yv)}, yw] - 
     2*G[{1}, yu^(-1)]^2*G[{yv^(-1), 1/(yu*yv)}, yw] + 
     2*G[{0}, yu^(-1)]*G[{1}, yv^(-1)]*G[{yv^(-1), 1/(yu*yv)}, yw] + 
     2*G[{0}, yv^(-1)]*G[{1}, yv^(-1)]*G[{yv^(-1), 1/(yu*yv)}, yw] - 
     2*G[{0}, yw]*G[{1}, yv^(-1)]*G[{yv^(-1), 1/(yu*yv)}, yw] - 
     G[{1}, yv^(-1)]^2*G[{yv^(-1), 1/(yu*yv)}, yw] - 
     2*G[{0}, yu^(-1)]*G[{1}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw] - 
     2*G[{0}, yv^(-1)]*G[{1}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw] + 
     2*G[{0}, yw]*G[{1}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw] + 
     2*G[{1}, yv^(-1)]*G[{1}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw] - 
     G[{1}, yw]^2*G[{yv^(-1), 1/(yu*yv)}, yw] + 2*G[{1}, yw]*G[{yu}, yv^(-1)]*
      G[{yv^(-1), 1/(yu*yv)}, yw] - 2*G[{1}, yv^(-1)]*G[{1/(yu*yv)}, yw]*
      G[{yv^(-1), 1/(yu*yv)}, yw] - 2*G[{1}, yw]*G[{1/(yu*yv)}, yw]*
      G[{yv^(-1), 1/(yu*yv)}, yw] + 2*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*
      G[{yv^(-1), 1/(yu*yv)}, yw] + 2*G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw]*
      G[{yv^(-1), 1/(yu*yv)}, yw] + G[{1/(yu*yv)}, yw]^2*
      G[{yv^(-1), 1/(yu*yv)}, yw] + 2*G[{0, 1}, yu^(-1)]*
      G[{yv^(-1), 1/(yu*yv)}, yw] - 2*G[{0, 1}, yw]*G[{yv^(-1), 1/(yu*yv)}, 
       yw] + 2*G[{0, yu^(-1)}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw] + 
     2*G[{0, yv^(-1)}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw] - 
     2*G[{0, 1/(yu*yv)}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw] - 
     2*G[{1, yu^(-1)}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw] - 
     2*G[{1, yu}, yv^(-1)]*G[{yv^(-1), 1/(yu*yv)}, yw] - 
     2*G[{1, 1/(yu*yv)}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw] + 
     2*G[{yu^(-1), 1/(yu*yv)}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw] + 
     2*G[{yv^(-1), 1/(yu*yv)}, yw]^2 - G[{1}, yu^(-1)]*
      G[{0, 0, 1}, yu^(-1)] + G[{1}, yv^(-1)]*G[{0, 0, 1}, yu^(-1)] - 
     G[{1}, yw]*G[{0, 0, 1}, yu^(-1)] + G[{1/(yu*yv)}, yw]*
      G[{0, 0, 1}, yu^(-1)] + 2*G[{0}, yu^(-1)]*G[{0, 0, 1}, yw] + 
     2*G[{0}, yv^(-1)]*G[{0, 0, 1}, yw] - 2*G[{0}, yw]*G[{0, 0, 1}, yw] - 
     2*G[{1}, yv^(-1)]*G[{0, 0, 1}, yw] + G[{1}, yw]*G[{0, 0, 1}, yw] - 
     2*G[{yu}, yv^(-1)]*G[{0, 0, 1}, yw] - G[{1/(yu*yv)}, yw]*
      G[{0, 0, 1}, yw] - 2*G[{0}, yu^(-1)]*G[{0, 0, yu^(-1)}, yw] - 
     2*G[{0}, yv^(-1)]*G[{0, 0, yu^(-1)}, yw] + 
     2*G[{0}, yw]*G[{0, 0, yu^(-1)}, yw] + 4*G[{1}, yv^(-1)]*
      G[{0, 0, yu^(-1)}, yw] - G[{1}, yw]*G[{0, 0, yu^(-1)}, yw] + 
     G[{1/(yu*yv)}, yw]*G[{0, 0, yu^(-1)}, yw] - 2*G[{0}, yu^(-1)]*
      G[{0, 0, yv^(-1)}, yw] - 2*G[{0}, yv^(-1)]*G[{0, 0, yv^(-1)}, yw] + 
     2*G[{0}, yw]*G[{0, 0, yv^(-1)}, yw] + 2*G[{1}, yu^(-1)]*
      G[{0, 0, yv^(-1)}, yw] + 2*G[{1}, yv^(-1)]*G[{0, 0, yv^(-1)}, yw] - 
     G[{1}, yw]*G[{0, 0, yv^(-1)}, yw] + G[{1/(yu*yv)}, yw]*
      G[{0, 0, yv^(-1)}, yw] + 2*G[{0}, yu^(-1)]*G[{0, 0, 1/(yu*yv)}, yw] + 
     2*G[{0}, yv^(-1)]*G[{0, 0, 1/(yu*yv)}, yw] - 
     2*G[{0}, yw]*G[{0, 0, 1/(yu*yv)}, yw] - 2*G[{1}, yu^(-1)]*
      G[{0, 0, 1/(yu*yv)}, yw] - 4*G[{1}, yv^(-1)]*G[{0, 0, 1/(yu*yv)}, yw] + 
     G[{1}, yw]*G[{0, 0, 1/(yu*yv)}, yw] + 2*G[{yu}, yv^(-1)]*
      G[{0, 0, 1/(yu*yv)}, yw] - G[{1/(yu*yv)}, yw]*G[{0, 0, 1/(yu*yv)}, 
       yw] + G[{1}, yu^(-1)]*G[{0, 1, 1}, yu^(-1)] + 
     G[{1}, yv^(-1)]*G[{0, 1, 1}, yu^(-1)] - 
     G[{1}, yw]*G[{0, 1, 1}, yu^(-1)] - G[{1/(yu*yv)}, yw]*
      G[{0, 1, 1}, yu^(-1)] + 2*G[{0}, yu^(-1)]*G[{0, 1, 1}, yv^(-1)] + 
     2*G[{0}, yv^(-1)]*G[{0, 1, 1}, yv^(-1)] - 
     2*G[{0}, yw]*G[{0, 1, 1}, yv^(-1)] + 2*G[{1/(yu*yv)}, yw]*
      G[{0, 1, 1}, yv^(-1)] + G[{0}, yu^(-1)]*G[{0, 1, 1}, yw] + 
     G[{0}, yv^(-1)]*G[{0, 1, 1}, yw] - G[{0}, yw]*G[{0, 1, 1}, yw] - 
     G[{1}, yv^(-1)]*G[{0, 1, 1}, yw] + G[{1}, yw]*G[{0, 1, 1}, yw] - 
     G[{yu}, yv^(-1)]*G[{0, 1, 1}, yw] + G[{1/(yu*yv)}, yw]*
      G[{0, 1, 1}, yw] + G[{0}, yu^(-1)]*G[{0, 1, yu^(-1)}, yw] + 
     G[{0}, yv^(-1)]*G[{0, 1, yu^(-1)}, yw] - 
     G[{0}, yw]*G[{0, 1, yu^(-1)}, yw] - 2*G[{1}, yv^(-1)]*
      G[{0, 1, yu^(-1)}, yw] - 2*G[{1/(yu*yv)}, yw]*G[{0, 1, yu^(-1)}, yw] - 
     G[{0}, yu^(-1)]*G[{0, 1, yu}, yv^(-1)] - G[{0}, yv^(-1)]*
      G[{0, 1, yu}, yv^(-1)] + G[{0}, yw]*G[{0, 1, yu}, yv^(-1)] - 
     2*G[{1/(yu*yv)}, yw]*G[{0, 1, yu}, yv^(-1)] - 2*G[{1/(yu*yv)}, yw]*
      G[{0, 1, yv^(-1)}, yw] + G[{0}, yu^(-1)]*G[{0, 1, 1/(yu*yv)}, yw] + 
     G[{0}, yv^(-1)]*G[{0, 1, 1/(yu*yv)}, yw] - 
     G[{0}, yw]*G[{0, 1, 1/(yu*yv)}, yw] - G[{1}, yv^(-1)]*
      G[{0, 1, 1/(yu*yv)}, yw] + G[{1}, yw]*G[{0, 1, 1/(yu*yv)}, yw] - 
     G[{yu}, yv^(-1)]*G[{0, 1, 1/(yu*yv)}, yw] + G[{1/(yu*yv)}, yw]*
      G[{0, 1, 1/(yu*yv)}, yw] + G[{1}, yv^(-1)]*G[{0, yu^(-1), 1}, yw] - 
     G[{1}, yw]*G[{0, yu^(-1), 1}, yw] - G[{yu}, yv^(-1)]*
      G[{0, yu^(-1), 1}, yw] - G[{1/(yu*yv)}, yw]*G[{0, yu^(-1), 1}, yw] - 
     2*G[{0}, yu^(-1)]*G[{0, yu^(-1), yu^(-1)}, yw] - 
     2*G[{0}, yv^(-1)]*G[{0, yu^(-1), yu^(-1)}, yw] + 
     2*G[{0}, yw]*G[{0, yu^(-1), yu^(-1)}, yw] + 4*G[{1}, yv^(-1)]*
      G[{0, yu^(-1), yu^(-1)}, yw] + 2*G[{1/(yu*yv)}, yw]*
      G[{0, yu^(-1), yu^(-1)}, yw] + 2*G[{1/(yu*yv)}, yw]*
      G[{0, yu^(-1), yv^(-1)}, yw] - G[{0}, yu^(-1)]*
      G[{0, yu^(-1), 1/(yu*yv)}, yw] - G[{0}, yv^(-1)]*
      G[{0, yu^(-1), 1/(yu*yv)}, yw] + G[{0}, yw]*G[{0, yu^(-1), 1/(yu*yv)}, 
       yw] + G[{1}, yv^(-1)]*G[{0, yu^(-1), 1/(yu*yv)}, yw] - 
     G[{1}, yw]*G[{0, yu^(-1), 1/(yu*yv)}, yw] + G[{yu}, yv^(-1)]*
      G[{0, yu^(-1), 1/(yu*yv)}, yw] - G[{1/(yu*yv)}, yw]*
      G[{0, yu^(-1), 1/(yu*yv)}, yw] - G[{0}, yu^(-1)]*
      G[{0, yu, 1}, yv^(-1)] - G[{0}, yv^(-1)]*G[{0, yu, 1}, yv^(-1)] + 
     G[{0}, yw]*G[{0, yu, 1}, yv^(-1)] - 2*G[{1/(yu*yv)}, yw]*
      G[{0, yu, 1}, yv^(-1)] + 2*G[{1/(yu*yv)}, yw]*G[{0, yu, yu}, yv^(-1)] - 
     G[{0}, yu^(-1)]*G[{0, yv^(-1), 1}, yw] - G[{0}, yv^(-1)]*
      G[{0, yv^(-1), 1}, yw] + G[{0}, yw]*G[{0, yv^(-1), 1}, yw] + 
     G[{1}, yv^(-1)]*G[{0, yv^(-1), 1}, yw] - 
     G[{1}, yw]*G[{0, yv^(-1), 1}, yw] + G[{yu}, yv^(-1)]*
      G[{0, yv^(-1), 1}, yw] - G[{1/(yu*yv)}, yw]*G[{0, yv^(-1), 1}, yw] + 
     2*G[{1/(yu*yv)}, yw]*G[{0, yv^(-1), yu^(-1)}, yw] + 
     2*G[{1/(yu*yv)}, yw]*G[{0, yv^(-1), yv^(-1)}, yw] - 
     2*G[{0}, yu^(-1)]*G[{0, yv^(-1), 1/(yu*yv)}, yw] - 
     2*G[{0}, yv^(-1)]*G[{0, yv^(-1), 1/(yu*yv)}, yw] + 
     2*G[{0}, yw]*G[{0, yv^(-1), 1/(yu*yv)}, yw] + 
     2*G[{1}, yu^(-1)]*G[{0, yv^(-1), 1/(yu*yv)}, yw] + 
     3*G[{1}, yv^(-1)]*G[{0, yv^(-1), 1/(yu*yv)}, yw] - 
     G[{1}, yw]*G[{0, yv^(-1), 1/(yu*yv)}, yw] - G[{yu}, yv^(-1)]*
      G[{0, yv^(-1), 1/(yu*yv)}, yw] - G[{1/(yu*yv)}, yw]*
      G[{0, yv^(-1), 1/(yu*yv)}, yw] - G[{1}, yv^(-1)]*
      G[{0, 1/(yu*yv), 1}, yw] + G[{1}, yw]*G[{0, 1/(yu*yv), 1}, yw] + 
     G[{yu}, yv^(-1)]*G[{0, 1/(yu*yv), 1}, yw] + G[{1/(yu*yv)}, yw]*
      G[{0, 1/(yu*yv), 1}, yw] + G[{0}, yu^(-1)]*G[{0, 1/(yu*yv), yu^(-1)}, 
       yw] + G[{0}, yv^(-1)]*G[{0, 1/(yu*yv), yu^(-1)}, yw] - 
     G[{0}, yw]*G[{0, 1/(yu*yv), yu^(-1)}, yw] - 2*G[{1}, yv^(-1)]*
      G[{0, 1/(yu*yv), yu^(-1)}, yw] - 2*G[{1/(yu*yv)}, yw]*
      G[{0, 1/(yu*yv), yu^(-1)}, yw] - 2*G[{1/(yu*yv)}, yw]*
      G[{0, 1/(yu*yv), yv^(-1)}, yw] + 2*G[{0}, yu^(-1)]*
      G[{0, 1/(yu*yv), 1/(yu*yv)}, yw] + 2*G[{0}, yv^(-1)]*
      G[{0, 1/(yu*yv), 1/(yu*yv)}, yw] - 2*G[{0}, yw]*
      G[{0, 1/(yu*yv), 1/(yu*yv)}, yw] - 2*G[{1}, yu^(-1)]*
      G[{0, 1/(yu*yv), 1/(yu*yv)}, yw] - 3*G[{1}, yv^(-1)]*
      G[{0, 1/(yu*yv), 1/(yu*yv)}, yw] + G[{1}, yw]*
      G[{0, 1/(yu*yv), 1/(yu*yv)}, yw] + G[{yu}, yv^(-1)]*
      G[{0, 1/(yu*yv), 1/(yu*yv)}, yw] + G[{1/(yu*yv)}, yw]*
      G[{0, 1/(yu*yv), 1/(yu*yv)}, yw] + G[{0}, yu^(-1)]*
      G[{1, 1, yu^(-1)}, yw] + G[{0}, yv^(-1)]*G[{1, 1, yu^(-1)}, yw] - 
     G[{0}, yw]*G[{1, 1, yu^(-1)}, yw] + 2*G[{1}, yw]*
      G[{1, 1, yu^(-1)}, yw] - 2*G[{yu}, yv^(-1)]*G[{1, 1, yu^(-1)}, yw] - 
     3*G[{1/(yu*yv)}, yw]*G[{1, 1, yu^(-1)}, yw] - 
     G[{0}, yu^(-1)]*G[{1, 1, yu}, yv^(-1)] - G[{0}, yv^(-1)]*
      G[{1, 1, yu}, yv^(-1)] + G[{0}, yw]*G[{1, 1, yu}, yv^(-1)] + 
     2*G[{1}, yv^(-1)]*G[{1, 1, yu}, yv^(-1)] + 
     G[{1}, yw]*G[{1, 1, yu}, yv^(-1)] - 3*G[{1/(yu*yv)}, yw]*
      G[{1, 1, yu}, yv^(-1)] - 3*G[{0}, yu^(-1)]*G[{1, 1, 1/(yu*yv)}, yw] - 
     3*G[{0}, yv^(-1)]*G[{1, 1, 1/(yu*yv)}, yw] + 
     3*G[{0}, yw]*G[{1, 1, 1/(yu*yv)}, yw] + 2*G[{1}, yv^(-1)]*
      G[{1, 1, 1/(yu*yv)}, yw] - 4*G[{1}, yw]*G[{1, 1, 1/(yu*yv)}, yw] + 
     4*G[{yu}, yv^(-1)]*G[{1, 1, 1/(yu*yv)}, yw] + 
     G[{1/(yu*yv)}, yw]*G[{1, 1, 1/(yu*yv)}, yw] + 
     2*G[{0}, yu^(-1)]*G[{1, yu^(-1), yu^(-1)}, yw] + 
     2*G[{0}, yv^(-1)]*G[{1, yu^(-1), yu^(-1)}, yw] - 
     2*G[{0}, yw]*G[{1, yu^(-1), yu^(-1)}, yw] - 4*G[{1}, yv^(-1)]*
      G[{1, yu^(-1), yu^(-1)}, yw] - 4*G[{1/(yu*yv)}, yw]*
      G[{1, yu^(-1), yu^(-1)}, yw] - 2*G[{1/(yu*yv)}, yw]*
      G[{1, yu^(-1), yv^(-1)}, yw] + G[{0}, yu^(-1)]*
      G[{1, yu^(-1), 1/(yu*yv)}, yw] + G[{0}, yv^(-1)]*
      G[{1, yu^(-1), 1/(yu*yv)}, yw] - G[{0}, yw]*G[{1, yu^(-1), 1/(yu*yv)}, 
       yw] - 2*G[{1}, yv^(-1)]*G[{1, yu^(-1), 1/(yu*yv)}, yw] + 
     G[{1/(yu*yv)}, yw]*G[{1, yu^(-1), 1/(yu*yv)}, yw] - 
     2*G[{0}, yu^(-1)]*G[{1, yu, yu}, yv^(-1)] - 2*G[{0}, yv^(-1)]*
      G[{1, yu, yu}, yv^(-1)] + 2*G[{0}, yw]*G[{1, yu, yu}, yv^(-1)] - 
     4*G[{1/(yu*yv)}, yw]*G[{1, yu, yu}, yv^(-1)] - 
     2*G[{1/(yu*yv)}, yw]*G[{1, yv^(-1), yu^(-1)}, yw] + 
     2*G[{0}, yu^(-1)]*G[{1, yv^(-1), 1/(yu*yv)}, yw] + 
     2*G[{0}, yv^(-1)]*G[{1, yv^(-1), 1/(yu*yv)}, yw] - 
     2*G[{0}, yw]*G[{1, yv^(-1), 1/(yu*yv)}, yw] - 
     2*G[{1}, yv^(-1)]*G[{1, yv^(-1), 1/(yu*yv)}, yw] + 
     2*G[{1}, yw]*G[{1, yv^(-1), 1/(yu*yv)}, yw] - 
     2*G[{yu}, yv^(-1)]*G[{1, yv^(-1), 1/(yu*yv)}, yw] + 
     2*G[{1/(yu*yv)}, yw]*G[{1, 1/(yu*yv), yu^(-1)}, yw] - 
     2*G[{1/(yu*yv)}, yw]*G[{1, 1/(yu*yv), yv^(-1)}, yw] - 
     G[{0}, yu^(-1)]*G[{1, 1/(yu*yv), 1/(yu*yv)}, yw] - 
     G[{0}, yv^(-1)]*G[{1, 1/(yu*yv), 1/(yu*yv)}, yw] + 
     G[{0}, yw]*G[{1, 1/(yu*yv), 1/(yu*yv)}, yw] + 
     2*G[{1}, yv^(-1)]*G[{1, 1/(yu*yv), 1/(yu*yv)}, yw] + 
     G[{1/(yu*yv)}, yw]*G[{1, 1/(yu*yv), 1/(yu*yv)}, yw] + 
     2*G[{0}, yu^(-1)]*G[{yu^(-1), yu^(-1), 1/(yu*yv)}, yw] + 
     2*G[{0}, yv^(-1)]*G[{yu^(-1), yu^(-1), 1/(yu*yv)}, yw] - 
     2*G[{0}, yw]*G[{yu^(-1), yu^(-1), 1/(yu*yv)}, yw] - 
     4*G[{1}, yv^(-1)]*G[{yu^(-1), yu^(-1), 1/(yu*yv)}, yw] + 
     4*G[{yu^(-1)}, yw]*G[{yu^(-1), yu^(-1), 1/(yu*yv)}, yw] + 
     2*G[{1/(yu*yv)}, yw]*G[{yu^(-1), 1/(yu*yv), yv^(-1)}, yw] - 
     G[{0}, yu^(-1)]*G[{yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] - 
     G[{0}, yv^(-1)]*G[{yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] + 
     G[{0}, yw]*G[{yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] - 
     2*G[{1}, yw]*G[{yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] + 
     2*G[{yu}, yv^(-1)]*G[{yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] - 
     G[{1/(yu*yv)}, yw]*G[{yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] - 
     4*G[{1/(yu*yv)}, yw]*G[{yv^(-1), yv^(-1), 1/(yu*yv)}, yw] - 
     2*G[{0}, yu^(-1)]*G[{yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] - 
     2*G[{0}, yv^(-1)]*G[{yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] + 
     2*G[{0}, yw]*G[{yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] + 
     4*G[{1}, yu^(-1)]*G[{yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] + 
     4*G[{1}, yv^(-1)]*G[{yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] + 
     4*G[{1}, yw]*G[{yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] - 
     4*G[{yu^(-1)}, yw]*G[{yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] - 
     4*G[{yu}, yv^(-1)]*G[{yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] - 
     4*G[{yv^(-1)}, yw]*G[{yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] - 
     2*G[{1/(yu*yv)}, yw]*G[{yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] + 
     G[{0, 0, 0, 1}, yu^(-1)] + 3*G[{0, 0, 0, 1}, yw] - 
     3*G[{0, 0, 0, yu^(-1)}, yw] - 3*G[{0, 0, 0, yv^(-1)}, yw] + 
     3*G[{0, 0, 0, 1/(yu*yv)}, yw] - G[{0, 0, 1, 1}, yu^(-1)] + 
     G[{0, 0, 1, 1}, yw] + 2*G[{0, 0, 1, yu^(-1)}, yw] + 
     2*G[{0, 0, 1, yv^(-1)}, yw] - G[{0, 0, 1, 1/(yu*yv)}, yw] + 
     G[{0, 0, yu^(-1), 1}, yw] - 4*G[{0, 0, yu^(-1), yu^(-1)}, yw] - 
     2*G[{0, 0, yu^(-1), yv^(-1)}, yw] + G[{0, 0, yu^(-1), 1/(yu*yv)}, yw] + 
     G[{0, 0, yv^(-1), 1}, yw] - 2*G[{0, 0, yv^(-1), yu^(-1)}, yw] - 
     2*G[{0, 0, yv^(-1), yv^(-1)}, yw] - G[{0, 0, yv^(-1), 1/(yu*yv)}, yw] - 
     3*G[{0, 0, 1/(yu*yv), 1}, yw] + 4*G[{0, 0, 1/(yu*yv), yu^(-1)}, yw] + 
     2*G[{0, 0, 1/(yu*yv), yv^(-1)}, yw] + G[{0, 0, 1/(yu*yv), 1/(yu*yv)}, 
      yw] + G[{0, 1, 0, yv^(-1)}, yw] - G[{0, 1, 0, 1/(yu*yv)}, yw] - 
     3*G[{0, 1, 1, 1}, yu^(-1)] - 3*G[{0, 1, 1, 1}, yv^(-1)] + 
     G[{0, 1, 1, yu^(-1)}, yw] - G[{0, 1, 1, yu}, yv^(-1)] - 
     G[{0, 1, 1, 1/(yu*yv)}, yw] + 2*G[{0, 1, yu^(-1), yu^(-1)}, yw] + 
     2*G[{0, 1, yu^(-1), 1/(yu*yv)}, yw] + 2*G[{0, 1, yu, yu}, yv^(-1)] + 
     2*G[{0, 1, yv^(-1), 1/(yu*yv)}, yw] + G[{0, 1, 1/(yu*yv), yu^(-1)}, 
      yw] - G[{0, 1, 1/(yu*yv), 1/(yu*yv)}, yw] - G[{0, yu^(-1), 0, yv^(-1)}, 
      yw] + G[{0, yu^(-1), 0, 1/(yu*yv)}, yw] + 2*G[{0, yu^(-1), 1, 1}, yw] - 
     G[{0, yu^(-1), 1, yu^(-1)}, yw] + G[{0, yu^(-1), 1, 1/(yu*yv)}, yw] - 
     4*G[{0, yu^(-1), yu^(-1), yu^(-1)}, yw] - 
     2*G[{0, yu^(-1), yu^(-1), 1/(yu*yv)}, yw] - 
     2*G[{0, yu^(-1), yv^(-1), 1/(yu*yv)}, yw] - 
     G[{0, yu^(-1), 1/(yu*yv), yu^(-1)}, yw] + 
     G[{0, yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] + G[{0, yu, 1, 1}, yv^(-1)] + 
     G[{0, yu, 1, yu}, yv^(-1)] - G[{0, yv^(-1), 1, yu^(-1)}, yw] + 
     G[{0, yv^(-1), 1, 1/(yu*yv)}, yw] - 
     2*G[{0, yv^(-1), yu^(-1), 1/(yu*yv)}, yw] - 
     2*G[{0, yv^(-1), yv^(-1), 1/(yu*yv)}, yw] + 
     2*G[{0, yv^(-1), 1/(yu*yv), 1}, yw] - 
     3*G[{0, yv^(-1), 1/(yu*yv), yu^(-1)}, yw] - 
     2*G[{0, yv^(-1), 1/(yu*yv), yv^(-1)}, yw] + 
     G[{0, yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] - 
     2*G[{0, 1/(yu*yv), 1, 1}, yw] + G[{0, 1/(yu*yv), 1, yu^(-1)}, yw] - 
     G[{0, 1/(yu*yv), 1, 1/(yu*yv)}, yw] + 
     2*G[{0, 1/(yu*yv), yu^(-1), yu^(-1)}, yw] + 
     2*G[{0, 1/(yu*yv), yu^(-1), 1/(yu*yv)}, yw] + 
     2*G[{0, 1/(yu*yv), yv^(-1), 1/(yu*yv)}, yw] - 
     2*G[{0, 1/(yu*yv), 1/(yu*yv), 1}, yw] + 
     3*G[{0, 1/(yu*yv), 1/(yu*yv), yu^(-1)}, yw] + 
     2*G[{0, 1/(yu*yv), 1/(yu*yv), yv^(-1)}, yw] - 
     G[{0, 1/(yu*yv), 1/(yu*yv), 1/(yu*yv)}, yw] - 
     3*G[{1, 1, 1, yu^(-1)}, yw] - 3*G[{1, 1, 1, yu}, yv^(-1)] + 
     3*G[{1, 1, 1, 1/(yu*yv)}, yw] - G[{1, 1, yu^(-1), 1/(yu*yv)}, yw] - 
     2*G[{1, 1, 1/(yu*yv), yu^(-1)}, yw] - G[{1, 1, 1/(yu*yv), 1/(yu*yv)}, 
      yw] - 2*G[{1, yu^(-1), 1, 1/(yu*yv)}, yw] + 
     4*G[{1, yu^(-1), yu^(-1), yu^(-1)}, yw] + 
     4*G[{1, yu^(-1), yu^(-1), 1/(yu*yv)}, yw] + 
     2*G[{1, yu^(-1), yv^(-1), 1/(yu*yv)}, yw] + 
     2*G[{1, yu^(-1), 1/(yu*yv), yu^(-1)}, yw] - 
     G[{1, yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] + 
     4*G[{1, yu, yu, yu}, yv^(-1)] + 2*G[{1, yv^(-1), yu^(-1), 1/(yu*yv)}, 
       yw] + 2*G[{1, yv^(-1), 1/(yu*yv), yu^(-1)}, yw] - 
     2*G[{1, 1/(yu*yv), yu^(-1), 1/(yu*yv)}, yw] + 
     2*G[{1, 1/(yu*yv), yv^(-1), 1/(yu*yv)}, yw] - 
     2*G[{1, 1/(yu*yv), 1/(yu*yv), yu^(-1)}, yw] - 
     G[{1, 1/(yu*yv), 1/(yu*yv), 1/(yu*yv)}, yw] - 
     4*G[{yu^(-1), yu^(-1), yu^(-1), 1/(yu*yv)}, yw] - 
     2*G[{yu^(-1), 1/(yu*yv), yv^(-1), 1/(yu*yv)}, yw] + 
     G[{yu^(-1), 1/(yu*yv), 1/(yu*yv), 1/(yu*yv)}, yw] + 
     4*G[{yv^(-1), yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] + 
     2*G[{yv^(-1), 1/(yu*yv), 1/(yu*yv), 1/(yu*yv)}, yw] - 
     2*G[{0}, yu^(-1)]*Zeta[3] - 2*G[{0}, yv^(-1)]*Zeta[3] + 
     2*G[{0}, yw]*Zeta[3] + 2*G[{1}, yu^(-1)]*Zeta[3] - 
     2*G[{1/(yu*yv)}, yw]*Zeta[3]
 
Omega2wuvRegII = -Pi^4/30 - (Pi^2*G[{0}, yu^(-1)]*G[{1}, yu^(-1)])/6 - 
     (Pi^2*G[{0}, yv^(-1)]*G[{1}, yu^(-1)])/6 + 
     (Pi^2*G[{0}, yw]*G[{1}, yu^(-1)])/6 + (Pi^2*G[{1}, yu^(-1)]^2)/12 + 
     (Pi^2*G[{1}, yu^(-1)]*G[{1}, yv^(-1)])/6 + (Pi^2*G[{1}, yv^(-1)]^2)/12 + 
     (G[{0}, yu^(-1)]^2*G[{1}, yv^(-1)]^2)/4 + 
     (G[{0}, yu^(-1)]*G[{0}, yv^(-1)]*G[{1}, yv^(-1)]^2)/2 + 
     (G[{0}, yv^(-1)]^2*G[{1}, yv^(-1)]^2)/4 - 
     (G[{0}, yu^(-1)]*G[{0}, yw]*G[{1}, yv^(-1)]^2)/2 - 
     (G[{0}, yv^(-1)]*G[{0}, yw]*G[{1}, yv^(-1)]^2)/2 + 
     (G[{0}, yw]^2*G[{1}, yv^(-1)]^2)/4 - 
     (G[{1}, yu^(-1)]^2*G[{1}, yv^(-1)]^2)/4 - 
     (G[{0}, yu^(-1)]*G[{1}, yv^(-1)]^3)/2 - 
     (G[{0}, yv^(-1)]*G[{1}, yv^(-1)]^3)/2 + (G[{0}, yw]*G[{1}, yv^(-1)]^3)/
      2 + (G[{1}, yu^(-1)]*G[{1}, yv^(-1)]^3)/6 + G[{1}, yv^(-1)]^4/4 + 
     (Pi^2*G[{0}, yu^(-1)]*G[{1}, yw])/6 + (Pi^2*G[{0}, yv^(-1)]*G[{1}, yw])/
      6 - (Pi^2*G[{0}, yw]*G[{1}, yw])/6 - (Pi^2*G[{1}, yu^(-1)]*G[{1}, yw])/
      6 + (Pi^2*G[{1}, yv^(-1)]*G[{1}, yw])/6 + 
     (G[{0}, yu^(-1)]^2*G[{1}, yv^(-1)]*G[{1}, yw])/2 + 
     G[{0}, yu^(-1)]*G[{0}, yv^(-1)]*G[{1}, yv^(-1)]*G[{1}, yw] + 
     (G[{0}, yv^(-1)]^2*G[{1}, yv^(-1)]*G[{1}, yw])/2 - 
     G[{0}, yu^(-1)]*G[{0}, yw]*G[{1}, yv^(-1)]*G[{1}, yw] - 
     G[{0}, yv^(-1)]*G[{0}, yw]*G[{1}, yv^(-1)]*G[{1}, yw] + 
     (G[{0}, yw]^2*G[{1}, yv^(-1)]*G[{1}, yw])/2 - 
     (G[{1}, yu^(-1)]^2*G[{1}, yv^(-1)]*G[{1}, yw])/2 - 
     (G[{0}, yu^(-1)]*G[{1}, yv^(-1)]^2*G[{1}, yw])/2 - 
     (G[{0}, yv^(-1)]*G[{1}, yv^(-1)]^2*G[{1}, yw])/2 + 
     (G[{0}, yw]*G[{1}, yv^(-1)]^2*G[{1}, yw])/2 + 
     (G[{1}, yu^(-1)]*G[{1}, yv^(-1)]^2*G[{1}, yw])/2 + 
     (Pi^2*G[{1}, yw]^2)/12 + (G[{0}, yu^(-1)]*G[{1}, yv^(-1)]*G[{1}, yw]^2)/
      2 + (G[{0}, yv^(-1)]*G[{1}, yv^(-1)]*G[{1}, yw]^2)/2 - 
     (G[{0}, yw]*G[{1}, yv^(-1)]*G[{1}, yw]^2)/2 - 
     (G[{1}, yv^(-1)]^2*G[{1}, yw]^2)/2 - (Pi^2*G[{1}, yw]*G[{yu}, yv^(-1)])/
      3 - (G[{0}, yu^(-1)]^2*G[{1}, yw]*G[{yu}, yv^(-1)])/2 - 
     G[{0}, yu^(-1)]*G[{0}, yv^(-1)]*G[{1}, yw]*G[{yu}, yv^(-1)] - 
     (G[{0}, yv^(-1)]^2*G[{1}, yw]*G[{yu}, yv^(-1)])/2 + 
     G[{0}, yu^(-1)]*G[{0}, yw]*G[{1}, yw]*G[{yu}, yv^(-1)] + 
     G[{0}, yv^(-1)]*G[{0}, yw]*G[{1}, yw]*G[{yu}, yv^(-1)] - 
     (G[{0}, yw]^2*G[{1}, yw]*G[{yu}, yv^(-1)])/2 + 
     (G[{1}, yu^(-1)]^2*G[{1}, yw]*G[{yu}, yv^(-1)])/2 - 
     G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*G[{1}, yw]*G[{yu}, yv^(-1)] - 
     (G[{0}, yu^(-1)]*G[{1}, yw]^2*G[{yu}, yv^(-1)])/2 - 
     (G[{0}, yv^(-1)]*G[{1}, yw]^2*G[{yu}, yv^(-1)])/2 + 
     (G[{0}, yw]*G[{1}, yw]^2*G[{yu}, yv^(-1)])/2 + 
     G[{0}, yu^(-1)]*G[{1}, yw]*G[{yu}, yv^(-1)]^2 + 
     G[{0}, yv^(-1)]*G[{1}, yw]*G[{yu}, yv^(-1)]^2 - 
     G[{0}, yw]*G[{1}, yw]*G[{yu}, yv^(-1)]^2 + 
     (G[{1}, yw]^2*G[{yu}, yv^(-1)]^2)/2 - (2*G[{1}, yw]*G[{yu}, yv^(-1)]^3)/
      3 - (Pi^2*G[{1}, yu^(-1)]*G[{1/(yu*yv)}, yw])/6 - 
     (Pi^2*G[{1}, yv^(-1)]*G[{1/(yu*yv)}, yw])/6 - 
     (G[{0}, yu^(-1)]^2*G[{1}, yv^(-1)]*G[{1/(yu*yv)}, yw])/2 - 
     G[{0}, yu^(-1)]*G[{0}, yv^(-1)]*G[{1}, yv^(-1)]*G[{1/(yu*yv)}, yw] - 
     (G[{0}, yv^(-1)]^2*G[{1}, yv^(-1)]*G[{1/(yu*yv)}, yw])/2 + 
     G[{0}, yu^(-1)]*G[{0}, yw]*G[{1}, yv^(-1)]*G[{1/(yu*yv)}, yw] + 
     G[{0}, yv^(-1)]*G[{0}, yw]*G[{1}, yv^(-1)]*G[{1/(yu*yv)}, yw] - 
     (G[{0}, yw]^2*G[{1}, yv^(-1)]*G[{1/(yu*yv)}, yw])/2 + 
     (G[{1}, yu^(-1)]^2*G[{1}, yv^(-1)]*G[{1/(yu*yv)}, yw])/2 + 
     (3*G[{0}, yu^(-1)]*G[{1}, yv^(-1)]^2*G[{1/(yu*yv)}, yw])/2 + 
     (3*G[{0}, yv^(-1)]*G[{1}, yv^(-1)]^2*G[{1/(yu*yv)}, yw])/2 - 
     (3*G[{0}, yw]*G[{1}, yv^(-1)]^2*G[{1/(yu*yv)}, yw])/2 - 
     (G[{1}, yu^(-1)]*G[{1}, yv^(-1)]^2*G[{1/(yu*yv)}, yw])/2 - 
     G[{1}, yv^(-1)]^3*G[{1/(yu*yv)}, yw] - 
     (Pi^2*G[{1}, yw]*G[{1/(yu*yv)}, yw])/2 - G[{0}, yu^(-1)]^2*G[{1}, yw]*
      G[{1/(yu*yv)}, yw] - 2*G[{0}, yu^(-1)]*G[{0}, yv^(-1)]*G[{1}, yw]*
      G[{1/(yu*yv)}, yw] - G[{0}, yv^(-1)]^2*G[{1}, yw]*G[{1/(yu*yv)}, yw] + 
     2*G[{0}, yu^(-1)]*G[{0}, yw]*G[{1}, yw]*G[{1/(yu*yv)}, yw] + 
     2*G[{0}, yv^(-1)]*G[{0}, yw]*G[{1}, yw]*G[{1/(yu*yv)}, yw] - 
     G[{0}, yw]^2*G[{1}, yw]*G[{1/(yu*yv)}, yw] + 
     2*G[{0}, yu^(-1)]*G[{1}, yu^(-1)]*G[{1}, yw]*G[{1/(yu*yv)}, yw] + 
     2*G[{0}, yv^(-1)]*G[{1}, yu^(-1)]*G[{1}, yw]*G[{1/(yu*yv)}, yw] - 
     2*G[{0}, yw]*G[{1}, yu^(-1)]*G[{1}, yw]*G[{1/(yu*yv)}, yw] - 
     G[{1}, yu^(-1)]^2*G[{1}, yw]*G[{1/(yu*yv)}, yw] + 
     G[{0}, yu^(-1)]*G[{1}, yv^(-1)]*G[{1}, yw]*G[{1/(yu*yv)}, yw] + 
     G[{0}, yv^(-1)]*G[{1}, yv^(-1)]*G[{1}, yw]*G[{1/(yu*yv)}, yw] - 
     G[{0}, yw]*G[{1}, yv^(-1)]*G[{1}, yw]*G[{1/(yu*yv)}, yw] - 
     2*G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*G[{1}, yw]*G[{1/(yu*yv)}, yw] - 
     G[{0}, yu^(-1)]*G[{1}, yw]^2*G[{1/(yu*yv)}, yw] - 
     G[{0}, yv^(-1)]*G[{1}, yw]^2*G[{1/(yu*yv)}, yw] + 
     G[{0}, yw]*G[{1}, yw]^2*G[{1/(yu*yv)}, yw] + 
     G[{1}, yu^(-1)]*G[{1}, yw]^2*G[{1/(yu*yv)}, yw] + 
     G[{1}, yv^(-1)]*G[{1}, yw]^2*G[{1/(yu*yv)}, yw] + 
     (Pi^2*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw])/3 + 
     G[{0}, yu^(-1)]^2*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw] + 
     2*G[{0}, yu^(-1)]*G[{0}, yv^(-1)]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw] + 
     G[{0}, yv^(-1)]^2*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw] - 
     2*G[{0}, yu^(-1)]*G[{0}, yw]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw] - 
     2*G[{0}, yv^(-1)]*G[{0}, yw]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw] + 
     G[{0}, yw]^2*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw] - 
     2*G[{0}, yu^(-1)]*G[{1}, yu^(-1)]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw] - 
     2*G[{0}, yv^(-1)]*G[{1}, yu^(-1)]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw] + 
     2*G[{0}, yw]*G[{1}, yu^(-1)]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw] + 
     G[{1}, yu^(-1)]^2*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw] - 
     2*G[{0}, yu^(-1)]*G[{1}, yv^(-1)]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw] - 
     2*G[{0}, yv^(-1)]*G[{1}, yv^(-1)]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw] + 
     2*G[{0}, yw]*G[{1}, yv^(-1)]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw] + 
     2*G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw] + 
     2*G[{1}, yv^(-1)]^2*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw] + 
     2*G[{0}, yu^(-1)]*G[{1}, yw]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw] + 
     2*G[{0}, yv^(-1)]*G[{1}, yw]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw] - 
     2*G[{0}, yw]*G[{1}, yw]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw] - 
     2*G[{1}, yu^(-1)]*G[{1}, yw]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw] + 
     G[{1}, yw]^2*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw] + 
     (Pi^2*G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw])/3 + 
     (G[{0}, yu^(-1)]^2*G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw])/2 + 
     G[{0}, yu^(-1)]*G[{0}, yv^(-1)]*G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw] + 
     (G[{0}, yv^(-1)]^2*G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw])/2 - 
     G[{0}, yu^(-1)]*G[{0}, yw]*G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw] - 
     G[{0}, yv^(-1)]*G[{0}, yw]*G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw] + 
     (G[{0}, yw]^2*G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw])/2 - 
     (G[{1}, yu^(-1)]^2*G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw])/2 + 
     G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw] + 
     G[{0}, yu^(-1)]*G[{1}, yw]*G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw] + 
     G[{0}, yv^(-1)]*G[{1}, yw]*G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw] - 
     G[{0}, yw]*G[{1}, yw]*G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw] - 
     2*G[{1}, yw]*G[{yu^(-1)}, yw]*G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw] - 
     G[{0}, yu^(-1)]*G[{yu}, yv^(-1)]^2*G[{1/(yu*yv)}, yw] - 
     G[{0}, yv^(-1)]*G[{yu}, yv^(-1)]^2*G[{1/(yu*yv)}, yw] + 
     G[{0}, yw]*G[{yu}, yv^(-1)]^2*G[{1/(yu*yv)}, yw] - 
     G[{1}, yw]*G[{yu}, yv^(-1)]^2*G[{1/(yu*yv)}, yw] + 
     (2*G[{yu}, yv^(-1)]^3*G[{1/(yu*yv)}, yw])/3 + 
     (Pi^2*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw])/3 + 
     (G[{0}, yu^(-1)]^2*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw])/2 + 
     G[{0}, yu^(-1)]*G[{0}, yv^(-1)]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw] + 
     (G[{0}, yv^(-1)]^2*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw])/2 - 
     G[{0}, yu^(-1)]*G[{0}, yw]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw] - 
     G[{0}, yv^(-1)]*G[{0}, yw]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw] + 
     (G[{0}, yw]^2*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw])/2 - 
     2*G[{0}, yu^(-1)]*G[{1}, yu^(-1)]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw] - 
     2*G[{0}, yv^(-1)]*G[{1}, yu^(-1)]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw] + 
     2*G[{0}, yw]*G[{1}, yu^(-1)]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw] + 
     (3*G[{1}, yu^(-1)]^2*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw])/2 + 
     G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw] - 
     G[{1}, yu^(-1)]*G[{1}, yw]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw] - 
     (G[{1}, yw]^2*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw])/2 + 
     G[{1}, yw]*G[{yu}, yv^(-1)]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw] + 
     G[{0}, yu^(-1)]*G[{yv^(-1)}, yw]^2*G[{1/(yu*yv)}, yw] + 
     G[{0}, yv^(-1)]*G[{yv^(-1)}, yw]^2*G[{1/(yu*yv)}, yw] - 
     G[{0}, yw]*G[{yv^(-1)}, yw]^2*G[{1/(yu*yv)}, yw] - 
     2*G[{1}, yu^(-1)]*G[{yv^(-1)}, yw]^2*G[{1/(yu*yv)}, yw] + 
     (2*G[{yv^(-1)}, yw]^3*G[{1/(yu*yv)}, yw])/3 - 
     (Pi^2*G[{1/(yu*yv)}, yw]^2)/12 - 
     (G[{0}, yu^(-1)]^2*G[{1/(yu*yv)}, yw]^2)/4 - 
     (G[{0}, yu^(-1)]*G[{0}, yv^(-1)]*G[{1/(yu*yv)}, yw]^2)/2 - 
     (G[{0}, yv^(-1)]^2*G[{1/(yu*yv)}, yw]^2)/4 + 
     (G[{0}, yu^(-1)]*G[{0}, yw]*G[{1/(yu*yv)}, yw]^2)/2 + 
     (G[{0}, yv^(-1)]*G[{0}, yw]*G[{1/(yu*yv)}, yw]^2)/2 - 
     (G[{0}, yw]^2*G[{1/(yu*yv)}, yw]^2)/4 + G[{0}, yu^(-1)]*G[{1}, yu^(-1)]*
      G[{1/(yu*yv)}, yw]^2 + G[{0}, yv^(-1)]*G[{1}, yu^(-1)]*
      G[{1/(yu*yv)}, yw]^2 - G[{0}, yw]*G[{1}, yu^(-1)]*
      G[{1/(yu*yv)}, yw]^2 - (3*G[{1}, yu^(-1)]^2*G[{1/(yu*yv)}, yw]^2)/4 - 
     (G[{0}, yu^(-1)]*G[{1}, yv^(-1)]*G[{1/(yu*yv)}, yw]^2)/2 - 
     (G[{0}, yv^(-1)]*G[{1}, yv^(-1)]*G[{1/(yu*yv)}, yw]^2)/2 + 
     (G[{0}, yw]*G[{1}, yv^(-1)]*G[{1/(yu*yv)}, yw]^2)/2 - 
     (G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*G[{1/(yu*yv)}, yw]^2)/2 + 
     (G[{1}, yv^(-1)]^2*G[{1/(yu*yv)}, yw]^2)/2 - G[{0}, yu^(-1)]*G[{1}, yw]*
      G[{1/(yu*yv)}, yw]^2 - G[{0}, yv^(-1)]*G[{1}, yw]*
      G[{1/(yu*yv)}, yw]^2 + G[{0}, yw]*G[{1}, yw]*G[{1/(yu*yv)}, yw]^2 + 
     (G[{1}, yu^(-1)]*G[{1}, yw]*G[{1/(yu*yv)}, yw]^2)/2 - 
     (3*G[{1}, yw]^2*G[{1/(yu*yv)}, yw]^2)/4 + G[{0}, yu^(-1)]*
      G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2 + G[{0}, yv^(-1)]*
      G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2 - G[{0}, yw]*G[{yu^(-1)}, yw]*
      G[{1/(yu*yv)}, yw]^2 - 2*G[{1}, yv^(-1)]*G[{yu^(-1)}, yw]*
      G[{1/(yu*yv)}, yw]^2 + G[{yu^(-1)}, yw]^2*G[{1/(yu*yv)}, yw]^2 + 
     (G[{0}, yu^(-1)]*G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw]^2)/2 + 
     (G[{0}, yv^(-1)]*G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw]^2)/2 - 
     (G[{0}, yw]*G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw]^2)/2 + 
     (3*G[{1}, yw]*G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw]^2)/2 - 
     (G[{yu}, yv^(-1)]^2*G[{1/(yu*yv)}, yw]^2)/2 - 
     (G[{0}, yu^(-1)]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2)/2 - 
     (G[{0}, yv^(-1)]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2)/2 + 
     (G[{0}, yw]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2)/2 + 
     G[{1}, yu^(-1)]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2 - 
     (G[{yv^(-1)}, yw]^2*G[{1/(yu*yv)}, yw]^2)/2 - 
     (G[{0}, yu^(-1)]*G[{1/(yu*yv)}, yw]^3)/6 - 
     (G[{0}, yv^(-1)]*G[{1/(yu*yv)}, yw]^3)/6 + 
     (G[{0}, yw]*G[{1/(yu*yv)}, yw]^3)/6 + 
     (G[{1}, yu^(-1)]*G[{1/(yu*yv)}, yw]^3)/6 + 
     (G[{1}, yv^(-1)]*G[{1/(yu*yv)}, yw]^3)/3 + 
     (G[{1}, yw]*G[{1/(yu*yv)}, yw]^3)/6 - 
     (G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]^3)/3 - 
     (G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw]^3)/6 - 
     (G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]^3)/6 - 
     G[{0}, yu^(-1)]*G[{1}, yu^(-1)]*G[{0, 1}, yu^(-1)] - 
     G[{0}, yv^(-1)]*G[{1}, yu^(-1)]*G[{0, 1}, yu^(-1)] + 
     G[{0}, yw]*G[{1}, yu^(-1)]*G[{0, 1}, yu^(-1)] + 
     (G[{1}, yu^(-1)]^2*G[{0, 1}, yu^(-1)])/2 + G[{1}, yu^(-1)]*
      G[{1}, yv^(-1)]*G[{0, 1}, yu^(-1)] + G[{0}, yu^(-1)]*G[{1}, yw]*
      G[{0, 1}, yu^(-1)] + G[{0}, yv^(-1)]*G[{1}, yw]*G[{0, 1}, yu^(-1)] - 
     G[{0}, yw]*G[{1}, yw]*G[{0, 1}, yu^(-1)] - G[{1}, yu^(-1)]*G[{1}, yw]*
      G[{0, 1}, yu^(-1)] + (G[{1}, yw]^2*G[{0, 1}, yu^(-1)])/2 - 
     G[{1}, yw]*G[{yu}, yv^(-1)]*G[{0, 1}, yu^(-1)] - 
     G[{1}, yu^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, 1}, yu^(-1)] - 
     G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1}, yu^(-1)] + 
     G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, 1}, yu^(-1)] + 
     G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1}, yu^(-1)] - 
     (Pi^2*G[{0, 1}, yv^(-1)])/6 - (G[{0}, yu^(-1)]^2*G[{0, 1}, yv^(-1)])/2 - 
     G[{0}, yu^(-1)]*G[{0}, yv^(-1)]*G[{0, 1}, yv^(-1)] - 
     (G[{0}, yv^(-1)]^2*G[{0, 1}, yv^(-1)])/2 + G[{0}, yu^(-1)]*G[{0}, yw]*
      G[{0, 1}, yv^(-1)] + G[{0}, yv^(-1)]*G[{0}, yw]*G[{0, 1}, yv^(-1)] - 
     (G[{0}, yw]^2*G[{0, 1}, yv^(-1)])/2 + 
     (G[{1}, yu^(-1)]^2*G[{0, 1}, yv^(-1)])/2 + G[{0}, yu^(-1)]*
      G[{1}, yv^(-1)]*G[{0, 1}, yv^(-1)] + G[{0}, yv^(-1)]*G[{1}, yv^(-1)]*
      G[{0, 1}, yv^(-1)] - G[{0}, yw]*G[{1}, yv^(-1)]*G[{0, 1}, yv^(-1)] - 
     (G[{1}, yv^(-1)]^2*G[{0, 1}, yv^(-1)])/2 + G[{1}, yv^(-1)]*G[{1}, yw]*
      G[{0, 1}, yv^(-1)] + (G[{1}, yw]^2*G[{0, 1}, yv^(-1)])/2 - 
     G[{0}, yu^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, 1}, yv^(-1)] - 
     G[{0}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, 1}, yv^(-1)] + 
     G[{0}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1}, yv^(-1)] + 
     G[{1}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, 1}, yv^(-1)] - 
     G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1}, yv^(-1)] - 
     2*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1}, yv^(-1)] + 
     (G[{1/(yu*yv)}, yw]^2*G[{0, 1}, yv^(-1)])/2 + G[{0, 1}, yv^(-1)]^2/2 + 
     (Pi^2*G[{0, 1}, yw])/3 + (G[{0}, yu^(-1)]^2*G[{0, 1}, yw])/2 + 
     G[{0}, yu^(-1)]*G[{0}, yv^(-1)]*G[{0, 1}, yw] + 
     (G[{0}, yv^(-1)]^2*G[{0, 1}, yw])/2 - G[{0}, yu^(-1)]*G[{0}, yw]*
      G[{0, 1}, yw] - G[{0}, yv^(-1)]*G[{0}, yw]*G[{0, 1}, yw] + 
     (G[{0}, yw]^2*G[{0, 1}, yw])/2 - G[{0}, yu^(-1)]*G[{1}, yu^(-1)]*
      G[{0, 1}, yw] - G[{0}, yv^(-1)]*G[{1}, yu^(-1)]*G[{0, 1}, yw] + 
     G[{0}, yw]*G[{1}, yu^(-1)]*G[{0, 1}, yw] + 
     (G[{1}, yu^(-1)]^2*G[{0, 1}, yw])/2 + G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*
      G[{0, 1}, yw] - (G[{1}, yw]^2*G[{0, 1}, yw])/2 - 
     G[{0}, yu^(-1)]*G[{yu}, yv^(-1)]*G[{0, 1}, yw] - 
     G[{0}, yv^(-1)]*G[{yu}, yv^(-1)]*G[{0, 1}, yw] + 
     G[{0}, yw]*G[{yu}, yv^(-1)]*G[{0, 1}, yw] + G[{yu}, yv^(-1)]^2*
      G[{0, 1}, yw] - G[{0}, yu^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, 1}, yw] - 
     G[{0}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, 1}, yw] + 
     G[{0}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1}, yw] + 
     2*G[{1}, yu^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, 1}, yw] - 
     G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1}, yw] + 
     2*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1}, yw] - 
     (G[{1/(yu*yv)}, yw]^2*G[{0, 1}, yw])/2 + G[{0, 1}, yu^(-1)]*
      G[{0, 1}, yw] - (Pi^2*G[{0, yu^(-1)}, yw])/6 - 
     (G[{0}, yu^(-1)]^2*G[{0, yu^(-1)}, yw])/2 - 
     G[{0}, yu^(-1)]*G[{0}, yv^(-1)]*G[{0, yu^(-1)}, yw] - 
     (G[{0}, yv^(-1)]^2*G[{0, yu^(-1)}, yw])/2 + G[{0}, yu^(-1)]*G[{0}, yw]*
      G[{0, yu^(-1)}, yw] + G[{0}, yv^(-1)]*G[{0}, yw]*G[{0, yu^(-1)}, yw] - 
     (G[{0}, yw]^2*G[{0, yu^(-1)}, yw])/2 + G[{0}, yu^(-1)]*G[{1}, yu^(-1)]*
      G[{0, yu^(-1)}, yw] + G[{0}, yv^(-1)]*G[{1}, yu^(-1)]*
      G[{0, yu^(-1)}, yw] - G[{0}, yw]*G[{1}, yu^(-1)]*G[{0, yu^(-1)}, yw] - 
     (G[{1}, yu^(-1)]^2*G[{0, yu^(-1)}, yw])/2 + 
     G[{0}, yu^(-1)]*G[{1}, yv^(-1)]*G[{0, yu^(-1)}, yw] + 
     G[{0}, yv^(-1)]*G[{1}, yv^(-1)]*G[{0, yu^(-1)}, yw] - 
     G[{0}, yw]*G[{1}, yv^(-1)]*G[{0, yu^(-1)}, yw] - 
     G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*G[{0, yu^(-1)}, yw] - 
     G[{1}, yv^(-1)]^2*G[{0, yu^(-1)}, yw] + 
     (G[{1}, yw]^2*G[{0, yu^(-1)}, yw])/2 + G[{0}, yu^(-1)]*
      G[{1/(yu*yv)}, yw]*G[{0, yu^(-1)}, yw] + G[{0}, yv^(-1)]*
      G[{1/(yu*yv)}, yw]*G[{0, yu^(-1)}, yw] - G[{0}, yw]*G[{1/(yu*yv)}, yw]*
      G[{0, yu^(-1)}, yw] - 2*G[{1}, yu^(-1)]*G[{1/(yu*yv)}, yw]*
      G[{0, yu^(-1)}, yw] + G[{1}, yw]*G[{1/(yu*yv)}, yw]*
      G[{0, yu^(-1)}, yw] - 2*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*
      G[{0, yu^(-1)}, yw] + (G[{1/(yu*yv)}, yw]^2*G[{0, yu^(-1)}, yw])/2 + 
     G[{0, 1}, yv^(-1)]*G[{0, yu^(-1)}, yw] - G[{0, 1}, yw]*
      G[{0, yu^(-1)}, yw] + G[{0, yu^(-1)}, yw]^2/2 + 
     (Pi^2*G[{0, yu}, yv^(-1)])/3 + (G[{0}, yu^(-1)]^2*G[{0, yu}, yv^(-1)])/
      2 + G[{0}, yu^(-1)]*G[{0}, yv^(-1)]*G[{0, yu}, yv^(-1)] + 
     (G[{0}, yv^(-1)]^2*G[{0, yu}, yv^(-1)])/2 - G[{0}, yu^(-1)]*G[{0}, yw]*
      G[{0, yu}, yv^(-1)] - G[{0}, yv^(-1)]*G[{0}, yw]*G[{0, yu}, yv^(-1)] + 
     (G[{0}, yw]^2*G[{0, yu}, yv^(-1)])/2 - 
     (G[{1}, yu^(-1)]^2*G[{0, yu}, yv^(-1)])/2 - 
     G[{0}, yu^(-1)]*G[{1}, yv^(-1)]*G[{0, yu}, yv^(-1)] - 
     G[{0}, yv^(-1)]*G[{1}, yv^(-1)]*G[{0, yu}, yv^(-1)] + 
     G[{0}, yw]*G[{1}, yv^(-1)]*G[{0, yu}, yv^(-1)] + 
     (G[{1}, yv^(-1)]^2*G[{0, yu}, yv^(-1)])/2 - G[{1}, yv^(-1)]*G[{1}, yw]*
      G[{0, yu}, yv^(-1)] - (G[{1}, yw]^2*G[{0, yu}, yv^(-1)])/2 + 
     G[{0}, yu^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, yu}, yv^(-1)] + 
     G[{0}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, yu}, yv^(-1)] - 
     G[{0}, yw]*G[{1/(yu*yv)}, yw]*G[{0, yu}, yv^(-1)] - 
     G[{1}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, yu}, yv^(-1)] + 
     G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{0, yu}, yv^(-1)] + 
     2*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{0, yu}, yv^(-1)] - 
     (G[{1/(yu*yv)}, yw]^2*G[{0, yu}, yv^(-1)])/2 + 
     G[{0, 1}, yu^(-1)]*G[{0, yu}, yv^(-1)] - G[{0, yu^(-1)}, yw]*
      G[{0, yu}, yv^(-1)] - (Pi^2*G[{0, yv^(-1)}, yw])/3 - 
     (G[{0}, yu^(-1)]^2*G[{0, yv^(-1)}, yw])/2 - 
     G[{0}, yu^(-1)]*G[{0}, yv^(-1)]*G[{0, yv^(-1)}, yw] - 
     (G[{0}, yv^(-1)]^2*G[{0, yv^(-1)}, yw])/2 + G[{0}, yu^(-1)]*G[{0}, yw]*
      G[{0, yv^(-1)}, yw] + G[{0}, yv^(-1)]*G[{0}, yw]*G[{0, yv^(-1)}, yw] - 
     (G[{0}, yw]^2*G[{0, yv^(-1)}, yw])/2 + 2*G[{0}, yu^(-1)]*G[{1}, yu^(-1)]*
      G[{0, yv^(-1)}, yw] + 2*G[{0}, yv^(-1)]*G[{1}, yu^(-1)]*
      G[{0, yv^(-1)}, yw] - 2*G[{0}, yw]*G[{1}, yu^(-1)]*
      G[{0, yv^(-1)}, yw] - (3*G[{1}, yu^(-1)]^2*G[{0, yv^(-1)}, yw])/2 - 
     G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*G[{0, yv^(-1)}, yw] + 
     (G[{1}, yw]^2*G[{0, yv^(-1)}, yw])/2 + G[{0}, yu^(-1)]*
      G[{1/(yu*yv)}, yw]*G[{0, yv^(-1)}, yw] + G[{0}, yv^(-1)]*
      G[{1/(yu*yv)}, yw]*G[{0, yv^(-1)}, yw] - G[{0}, yw]*G[{1/(yu*yv)}, yw]*
      G[{0, yv^(-1)}, yw] - 2*G[{1}, yu^(-1)]*G[{1/(yu*yv)}, yw]*
      G[{0, yv^(-1)}, yw] + G[{1}, yw]*G[{1/(yu*yv)}, yw]*
      G[{0, yv^(-1)}, yw] - 2*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*
      G[{0, yv^(-1)}, yw] + (G[{1/(yu*yv)}, yw]^2*G[{0, yv^(-1)}, yw])/2 - 
     G[{0, 1}, yu^(-1)]*G[{0, yv^(-1)}, yw] + (Pi^2*G[{0, 1/(yu*yv)}, yw])/
      6 + (G[{0}, yu^(-1)]^2*G[{0, 1/(yu*yv)}, yw])/2 + 
     G[{0}, yu^(-1)]*G[{0}, yv^(-1)]*G[{0, 1/(yu*yv)}, yw] + 
     (G[{0}, yv^(-1)]^2*G[{0, 1/(yu*yv)}, yw])/2 - G[{0}, yu^(-1)]*G[{0}, yw]*
      G[{0, 1/(yu*yv)}, yw] - G[{0}, yv^(-1)]*G[{0}, yw]*
      G[{0, 1/(yu*yv)}, yw] + (G[{0}, yw]^2*G[{0, 1/(yu*yv)}, yw])/2 - 
     2*G[{0}, yu^(-1)]*G[{1}, yu^(-1)]*G[{0, 1/(yu*yv)}, yw] - 
     2*G[{0}, yv^(-1)]*G[{1}, yu^(-1)]*G[{0, 1/(yu*yv)}, yw] + 
     2*G[{0}, yw]*G[{1}, yu^(-1)]*G[{0, 1/(yu*yv)}, yw] + 
     (3*G[{1}, yu^(-1)]^2*G[{0, 1/(yu*yv)}, yw])/2 - 
     G[{0}, yu^(-1)]*G[{1}, yv^(-1)]*G[{0, 1/(yu*yv)}, yw] - 
     G[{0}, yv^(-1)]*G[{1}, yv^(-1)]*G[{0, 1/(yu*yv)}, yw] + 
     G[{0}, yw]*G[{1}, yv^(-1)]*G[{0, 1/(yu*yv)}, yw] + 
     G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*G[{0, 1/(yu*yv)}, yw] + 
     G[{1}, yv^(-1)]^2*G[{0, 1/(yu*yv)}, yw] - 
     (G[{1}, yw]^2*G[{0, 1/(yu*yv)}, yw])/2 + G[{0}, yu^(-1)]*
      G[{yu}, yv^(-1)]*G[{0, 1/(yu*yv)}, yw] + G[{0}, yv^(-1)]*
      G[{yu}, yv^(-1)]*G[{0, 1/(yu*yv)}, yw] - G[{0}, yw]*G[{yu}, yv^(-1)]*
      G[{0, 1/(yu*yv)}, yw] - G[{yu}, yv^(-1)]^2*G[{0, 1/(yu*yv)}, yw] - 
     G[{0}, yu^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv)}, yw] - 
     G[{0}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv)}, yw] + 
     G[{0}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv)}, yw] + 
     2*G[{1}, yu^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv)}, yw] - 
     G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv)}, yw] + 
     2*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv)}, yw] - 
     (G[{1/(yu*yv)}, yw]^2*G[{0, 1/(yu*yv)}, yw])/2 - 
     G[{0, 1}, yv^(-1)]*G[{0, 1/(yu*yv)}, yw] + 
     G[{0, 1}, yw]*G[{0, 1/(yu*yv)}, yw] - G[{0, yu^(-1)}, yw]*
      G[{0, 1/(yu*yv)}, yw] + G[{0, yu}, yv^(-1)]*G[{0, 1/(yu*yv)}, yw] - 
     G[{0, yv^(-1)}, yw]*G[{0, 1/(yu*yv)}, yw] + G[{0, 1/(yu*yv)}, yw]^2/2 - 
     2*G[{0}, yu^(-1)]*G[{1/(yu*yv)}, yw]*G[{1, yu^(-1)}, yw] - 
     2*G[{0}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{1, yu^(-1)}, yw] + 
     2*G[{0}, yw]*G[{1/(yu*yv)}, yw]*G[{1, yu^(-1)}, yw] + 
     2*G[{1}, yu^(-1)]*G[{1/(yu*yv)}, yw]*G[{1, yu^(-1)}, yw] - 
     2*G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{1, yu^(-1)}, yw] + 
     2*G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{1, yu^(-1)}, yw] - 
     (Pi^2*G[{1, yu}, yv^(-1)])/3 - (G[{0}, yu^(-1)]^2*G[{1, yu}, yv^(-1)])/
      2 - G[{0}, yu^(-1)]*G[{0}, yv^(-1)]*G[{1, yu}, yv^(-1)] - 
     (G[{0}, yv^(-1)]^2*G[{1, yu}, yv^(-1)])/2 + G[{0}, yu^(-1)]*G[{0}, yw]*
      G[{1, yu}, yv^(-1)] + G[{0}, yv^(-1)]*G[{0}, yw]*G[{1, yu}, yv^(-1)] - 
     (G[{0}, yw]^2*G[{1, yu}, yv^(-1)])/2 + 
     (G[{1}, yu^(-1)]^2*G[{1, yu}, yv^(-1)])/2 - 
     G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*G[{1, yu}, yv^(-1)] - 
     G[{0}, yu^(-1)]*G[{1}, yw]*G[{1, yu}, yv^(-1)] - 
     G[{0}, yv^(-1)]*G[{1}, yw]*G[{1, yu}, yv^(-1)] + 
     G[{0}, yw]*G[{1}, yw]*G[{1, yu}, yv^(-1)] + G[{1}, yu^(-1)]*G[{1}, yw]*
      G[{1, yu}, yv^(-1)] + G[{1}, yw]*G[{yu}, yv^(-1)]*G[{1, yu}, yv^(-1)] - 
     G[{0}, yu^(-1)]*G[{1/(yu*yv)}, yw]*G[{1, yu}, yv^(-1)] - 
     G[{0}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{1, yu}, yv^(-1)] + 
     G[{0}, yw]*G[{1/(yu*yv)}, yw]*G[{1, yu}, yv^(-1)] - 
     G[{1}, yu^(-1)]*G[{1/(yu*yv)}, yw]*G[{1, yu}, yv^(-1)] - 
     2*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{1, yu}, yv^(-1)] - 
     G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{1, yu}, yv^(-1)] - 
     G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{1, yu}, yv^(-1)] + 
     (G[{1/(yu*yv)}, yw]^2*G[{1, yu}, yv^(-1)])/2 - 
     G[{0, 1}, yu^(-1)]*G[{1, yu}, yv^(-1)] - G[{0, 1}, yw]*
      G[{1, yu}, yv^(-1)] + G[{0, yu^(-1)}, yw]*G[{1, yu}, yv^(-1)] + 
     G[{0, yv^(-1)}, yw]*G[{1, yu}, yv^(-1)] - G[{0, 1/(yu*yv)}, yw]*
      G[{1, yu}, yv^(-1)] + G[{1, yu}, yv^(-1)]^2/2 + 
     (Pi^2*G[{1, yv^(-1)}, yw])/3 + (G[{0}, yu^(-1)]^2*G[{1, yv^(-1)}, yw])/
      2 + G[{0}, yu^(-1)]*G[{0}, yv^(-1)]*G[{1, yv^(-1)}, yw] + 
     (G[{0}, yv^(-1)]^2*G[{1, yv^(-1)}, yw])/2 - G[{0}, yu^(-1)]*G[{0}, yw]*
      G[{1, yv^(-1)}, yw] - G[{0}, yv^(-1)]*G[{0}, yw]*G[{1, yv^(-1)}, yw] + 
     (G[{0}, yw]^2*G[{1, yv^(-1)}, yw])/2 - 2*G[{0}, yu^(-1)]*G[{1}, yu^(-1)]*
      G[{1, yv^(-1)}, yw] - 2*G[{0}, yv^(-1)]*G[{1}, yu^(-1)]*
      G[{1, yv^(-1)}, yw] + 2*G[{0}, yw]*G[{1}, yu^(-1)]*
      G[{1, yv^(-1)}, yw] + (3*G[{1}, yu^(-1)]^2*G[{1, yv^(-1)}, yw])/2 + 
     G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*G[{1, yv^(-1)}, yw] - 
     G[{1}, yu^(-1)]*G[{1}, yw]*G[{1, yv^(-1)}, yw] - 
     (G[{1}, yw]^2*G[{1, yv^(-1)}, yw])/2 + G[{1}, yw]*G[{yu}, yv^(-1)]*
      G[{1, yv^(-1)}, yw] - G[{0}, yu^(-1)]*G[{1/(yu*yv)}, yw]*
      G[{1, yv^(-1)}, yw] - G[{0}, yv^(-1)]*G[{1/(yu*yv)}, yw]*
      G[{1, yv^(-1)}, yw] + G[{0}, yw]*G[{1/(yu*yv)}, yw]*
      G[{1, yv^(-1)}, yw] + 3*G[{1}, yu^(-1)]*G[{1/(yu*yv)}, yw]*
      G[{1, yv^(-1)}, yw] + G[{1}, yw]*G[{1/(yu*yv)}, yw]*
      G[{1, yv^(-1)}, yw] + 2*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*
      G[{1, yv^(-1)}, yw] - G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw]*
      G[{1, yv^(-1)}, yw] + G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*
      G[{1, yv^(-1)}, yw] - (G[{1/(yu*yv)}, yw]^2*G[{1, yv^(-1)}, yw])/2 + 
     G[{0, 1}, yu^(-1)]*G[{1, yv^(-1)}, yw] - G[{1, yu}, yv^(-1)]*
      G[{1, yv^(-1)}, yw] + G[{1, yv^(-1)}, yw]^2/2 + 
     (Pi^2*G[{1, 1/(yu*yv)}, yw])/3 + 
     (G[{0}, yu^(-1)]^2*G[{1, 1/(yu*yv)}, yw])/2 + 
     G[{0}, yu^(-1)]*G[{0}, yv^(-1)]*G[{1, 1/(yu*yv)}, yw] + 
     (G[{0}, yv^(-1)]^2*G[{1, 1/(yu*yv)}, yw])/2 - G[{0}, yu^(-1)]*G[{0}, yw]*
      G[{1, 1/(yu*yv)}, yw] - G[{0}, yv^(-1)]*G[{0}, yw]*
      G[{1, 1/(yu*yv)}, yw] + (G[{0}, yw]^2*G[{1, 1/(yu*yv)}, yw])/2 - 
     (G[{1}, yu^(-1)]^2*G[{1, 1/(yu*yv)}, yw])/2 + 
     G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*G[{1, 1/(yu*yv)}, yw] + 
     2*G[{0}, yu^(-1)]*G[{1}, yw]*G[{1, 1/(yu*yv)}, yw] + 
     2*G[{0}, yv^(-1)]*G[{1}, yw]*G[{1, 1/(yu*yv)}, yw] - 
     2*G[{0}, yw]*G[{1}, yw]*G[{1, 1/(yu*yv)}, yw] - 
     G[{1}, yu^(-1)]*G[{1}, yw]*G[{1, 1/(yu*yv)}, yw] + 
     (3*G[{1}, yw]^2*G[{1, 1/(yu*yv)}, yw])/2 - 2*G[{0}, yu^(-1)]*
      G[{yu}, yv^(-1)]*G[{1, 1/(yu*yv)}, yw] - 2*G[{0}, yv^(-1)]*
      G[{yu}, yv^(-1)]*G[{1, 1/(yu*yv)}, yw] + 2*G[{0}, yw]*G[{yu}, yv^(-1)]*
      G[{1, 1/(yu*yv)}, yw] - 3*G[{1}, yw]*G[{yu}, yv^(-1)]*
      G[{1, 1/(yu*yv)}, yw] + 2*G[{yu}, yv^(-1)]^2*G[{1, 1/(yu*yv)}, yw] + 
     G[{0}, yu^(-1)]*G[{1/(yu*yv)}, yw]*G[{1, 1/(yu*yv)}, yw] + 
     G[{0}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{1, 1/(yu*yv)}, yw] - 
     G[{0}, yw]*G[{1/(yu*yv)}, yw]*G[{1, 1/(yu*yv)}, yw] - 
     G[{1}, yu^(-1)]*G[{1/(yu*yv)}, yw]*G[{1, 1/(yu*yv)}, yw] + 
     G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{1, 1/(yu*yv)}, yw] + 
     2*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{1, 1/(yu*yv)}, yw] - 
     G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{1, 1/(yu*yv)}, yw] - 
     G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{1, 1/(yu*yv)}, yw] - 
     (G[{1/(yu*yv)}, yw]^2*G[{1, 1/(yu*yv)}, yw])/2 + 
     G[{0, 1}, yu^(-1)]*G[{1, 1/(yu*yv)}, yw] - G[{1, yu}, yv^(-1)]*
      G[{1, 1/(yu*yv)}, yw] + G[{1, yv^(-1)}, yw]*G[{1, 1/(yu*yv)}, yw] - 
     G[{1, 1/(yu*yv)}, yw]^2/2 - (Pi^2*G[{yu^(-1), 1/(yu*yv)}, yw])/3 - 
     G[{0}, yu^(-1)]^2*G[{yu^(-1), 1/(yu*yv)}, yw] - 
     2*G[{0}, yu^(-1)]*G[{0}, yv^(-1)]*G[{yu^(-1), 1/(yu*yv)}, yw] - 
     G[{0}, yv^(-1)]^2*G[{yu^(-1), 1/(yu*yv)}, yw] + 
     2*G[{0}, yu^(-1)]*G[{0}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw] + 
     2*G[{0}, yv^(-1)]*G[{0}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw] - 
     G[{0}, yw]^2*G[{yu^(-1), 1/(yu*yv)}, yw] + 2*G[{0}, yu^(-1)]*
      G[{1}, yu^(-1)]*G[{yu^(-1), 1/(yu*yv)}, yw] + 
     2*G[{0}, yv^(-1)]*G[{1}, yu^(-1)]*G[{yu^(-1), 1/(yu*yv)}, yw] - 
     2*G[{0}, yw]*G[{1}, yu^(-1)]*G[{yu^(-1), 1/(yu*yv)}, yw] - 
     G[{1}, yu^(-1)]^2*G[{yu^(-1), 1/(yu*yv)}, yw] + 
     2*G[{0}, yu^(-1)]*G[{1}, yv^(-1)]*G[{yu^(-1), 1/(yu*yv)}, yw] + 
     2*G[{0}, yv^(-1)]*G[{1}, yv^(-1)]*G[{yu^(-1), 1/(yu*yv)}, yw] - 
     2*G[{0}, yw]*G[{1}, yv^(-1)]*G[{yu^(-1), 1/(yu*yv)}, yw] - 
     2*G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*G[{yu^(-1), 1/(yu*yv)}, yw] - 
     2*G[{1}, yv^(-1)]^2*G[{yu^(-1), 1/(yu*yv)}, yw] - 
     2*G[{0}, yu^(-1)]*G[{1}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw] - 
     2*G[{0}, yv^(-1)]*G[{1}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw] + 
     2*G[{0}, yw]*G[{1}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw] + 
     2*G[{1}, yu^(-1)]*G[{1}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw] - 
     G[{1}, yw]^2*G[{yu^(-1), 1/(yu*yv)}, yw] + 2*G[{1}, yw]*G[{yu}, yv^(-1)]*
      G[{yu^(-1), 1/(yu*yv)}, yw] - 2*G[{1}, yu^(-1)]*G[{1/(yu*yv)}, yw]*
      G[{yu^(-1), 1/(yu*yv)}, yw] - 2*G[{1}, yw]*G[{1/(yu*yv)}, yw]*
      G[{yu^(-1), 1/(yu*yv)}, yw] + 2*G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw]*
      G[{yu^(-1), 1/(yu*yv)}, yw] + G[{1/(yu*yv)}, yw]^2*
      G[{yu^(-1), 1/(yu*yv)}, yw] + 2*G[{0, 1}, yv^(-1)]*
      G[{yu^(-1), 1/(yu*yv)}, yw] - 2*G[{0, 1}, yw]*G[{yu^(-1), 1/(yu*yv)}, 
       yw] + 2*G[{0, yu^(-1)}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw] - 
     2*G[{0, yu}, yv^(-1)]*G[{yu^(-1), 1/(yu*yv)}, yw] + 
     2*G[{0, yv^(-1)}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw] - 
     2*G[{0, 1/(yu*yv)}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw] + 
     2*G[{1, yu}, yv^(-1)]*G[{yu^(-1), 1/(yu*yv)}, yw] - 
     2*G[{1, yv^(-1)}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw] - 
     2*G[{1, 1/(yu*yv)}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw] + 
     2*G[{yu^(-1), 1/(yu*yv)}, yw]^2 - (Pi^2*G[{yv^(-1), 1/(yu*yv)}, yw])/3 - 
     (G[{0}, yu^(-1)]^2*G[{yv^(-1), 1/(yu*yv)}, yw])/2 - 
     G[{0}, yu^(-1)]*G[{0}, yv^(-1)]*G[{yv^(-1), 1/(yu*yv)}, yw] - 
     (G[{0}, yv^(-1)]^2*G[{yv^(-1), 1/(yu*yv)}, yw])/2 + 
     G[{0}, yu^(-1)]*G[{0}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw] + 
     G[{0}, yv^(-1)]*G[{0}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw] - 
     (G[{0}, yw]^2*G[{yv^(-1), 1/(yu*yv)}, yw])/2 + 
     2*G[{0}, yu^(-1)]*G[{1}, yu^(-1)]*G[{yv^(-1), 1/(yu*yv)}, yw] + 
     2*G[{0}, yv^(-1)]*G[{1}, yu^(-1)]*G[{yv^(-1), 1/(yu*yv)}, yw] - 
     2*G[{0}, yw]*G[{1}, yu^(-1)]*G[{yv^(-1), 1/(yu*yv)}, yw] - 
     (3*G[{1}, yu^(-1)]^2*G[{yv^(-1), 1/(yu*yv)}, yw])/2 - 
     G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*G[{yv^(-1), 1/(yu*yv)}, yw] + 
     G[{1}, yu^(-1)]*G[{1}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw] + 
     (G[{1}, yw]^2*G[{yv^(-1), 1/(yu*yv)}, yw])/2 - 
     G[{1}, yw]*G[{yu}, yv^(-1)]*G[{yv^(-1), 1/(yu*yv)}, yw] - 
     2*G[{0}, yu^(-1)]*G[{yv^(-1)}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw] - 
     2*G[{0}, yv^(-1)]*G[{yv^(-1)}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw] + 
     2*G[{0}, yw]*G[{yv^(-1)}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw] + 
     4*G[{1}, yu^(-1)]*G[{yv^(-1)}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw] - 
     2*G[{yv^(-1)}, yw]^2*G[{yv^(-1), 1/(yu*yv)}, yw] + 
     G[{0}, yu^(-1)]*G[{1/(yu*yv)}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw] + 
     G[{0}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw] - 
     G[{0}, yw]*G[{1/(yu*yv)}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw] - 
     G[{1}, yu^(-1)]*G[{1/(yu*yv)}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw] + 
     G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw] - 
     G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw] + 
     G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw] + 
     (G[{1/(yu*yv)}, yw]^2*G[{yv^(-1), 1/(yu*yv)}, yw])/2 - 
     G[{0, 1}, yu^(-1)]*G[{yv^(-1), 1/(yu*yv)}, yw] + 
     G[{1, yu}, yv^(-1)]*G[{yv^(-1), 1/(yu*yv)}, yw] - 
     G[{1, yv^(-1)}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw] + 
     G[{1, 1/(yu*yv)}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw] - 
     G[{yv^(-1), 1/(yu*yv)}, yw]^2/2 - G[{1}, yv^(-1)]*
      G[{0, 0, 1}, yv^(-1)] - G[{1}, yw]*G[{0, 0, 1}, yv^(-1)] + 
     G[{1/(yu*yv)}, yw]*G[{0, 0, 1}, yv^(-1)] + 2*G[{0}, yu^(-1)]*
      G[{0, 0, 1}, yw] + 2*G[{0}, yv^(-1)]*G[{0, 0, 1}, yw] - 
     2*G[{0}, yw]*G[{0, 0, 1}, yw] - 2*G[{1}, yu^(-1)]*G[{0, 0, 1}, yw] + 
     G[{1}, yw]*G[{0, 0, 1}, yw] - 2*G[{yu}, yv^(-1)]*G[{0, 0, 1}, yw] - 
     G[{1/(yu*yv)}, yw]*G[{0, 0, 1}, yw] - 2*G[{0}, yu^(-1)]*
      G[{0, 0, yu^(-1)}, yw] - 2*G[{0}, yv^(-1)]*G[{0, 0, yu^(-1)}, yw] + 
     2*G[{0}, yw]*G[{0, 0, yu^(-1)}, yw] + 2*G[{1}, yu^(-1)]*
      G[{0, 0, yu^(-1)}, yw] + 2*G[{1}, yv^(-1)]*G[{0, 0, yu^(-1)}, yw] - 
     G[{1}, yw]*G[{0, 0, yu^(-1)}, yw] + G[{1/(yu*yv)}, yw]*
      G[{0, 0, yu^(-1)}, yw] + G[{1}, yv^(-1)]*G[{0, 0, yu}, yv^(-1)] + 
     G[{1}, yw]*G[{0, 0, yu}, yv^(-1)] - G[{1/(yu*yv)}, yw]*
      G[{0, 0, yu}, yv^(-1)] - 2*G[{0}, yu^(-1)]*G[{0, 0, yv^(-1)}, yw] - 
     2*G[{0}, yv^(-1)]*G[{0, 0, yv^(-1)}, yw] + 
     2*G[{0}, yw]*G[{0, 0, yv^(-1)}, yw] + 4*G[{1}, yu^(-1)]*
      G[{0, 0, yv^(-1)}, yw] - G[{1}, yw]*G[{0, 0, yv^(-1)}, yw] + 
     G[{1/(yu*yv)}, yw]*G[{0, 0, yv^(-1)}, yw] + 2*G[{0}, yu^(-1)]*
      G[{0, 0, 1/(yu*yv)}, yw] + 2*G[{0}, yv^(-1)]*G[{0, 0, 1/(yu*yv)}, yw] - 
     2*G[{0}, yw]*G[{0, 0, 1/(yu*yv)}, yw] - 4*G[{1}, yu^(-1)]*
      G[{0, 0, 1/(yu*yv)}, yw] - 2*G[{1}, yv^(-1)]*G[{0, 0, 1/(yu*yv)}, yw] + 
     G[{1}, yw]*G[{0, 0, 1/(yu*yv)}, yw] + 2*G[{yu}, yv^(-1)]*
      G[{0, 0, 1/(yu*yv)}, yw] - G[{1/(yu*yv)}, yw]*G[{0, 0, 1/(yu*yv)}, 
       yw] + 2*G[{0}, yu^(-1)]*G[{0, 1, 1}, yu^(-1)] + 
     2*G[{0}, yv^(-1)]*G[{0, 1, 1}, yu^(-1)] - 
     2*G[{0}, yw]*G[{0, 1, 1}, yu^(-1)] - 2*G[{1}, yv^(-1)]*
      G[{0, 1, 1}, yu^(-1)] + 2*G[{1/(yu*yv)}, yw]*G[{0, 1, 1}, yu^(-1)] - 
     G[{1}, yu^(-1)]*G[{0, 1, 1}, yv^(-1)] + G[{1}, yv^(-1)]*
      G[{0, 1, 1}, yv^(-1)] - G[{1}, yw]*G[{0, 1, 1}, yv^(-1)] - 
     G[{1/(yu*yv)}, yw]*G[{0, 1, 1}, yv^(-1)] + G[{0}, yu^(-1)]*
      G[{0, 1, 1}, yw] + G[{0}, yv^(-1)]*G[{0, 1, 1}, yw] - 
     G[{0}, yw]*G[{0, 1, 1}, yw] - G[{1}, yu^(-1)]*G[{0, 1, 1}, yw] + 
     G[{1}, yw]*G[{0, 1, 1}, yw] - G[{yu}, yv^(-1)]*G[{0, 1, 1}, yw] + 
     G[{1/(yu*yv)}, yw]*G[{0, 1, 1}, yw] - 2*G[{1/(yu*yv)}, yw]*
      G[{0, 1, yu^(-1)}, yw] + G[{0}, yu^(-1)]*G[{0, 1, yu}, yv^(-1)] + 
     G[{0}, yv^(-1)]*G[{0, 1, yu}, yv^(-1)] - 
     G[{0}, yw]*G[{0, 1, yu}, yv^(-1)] - 2*G[{1}, yv^(-1)]*
      G[{0, 1, yu}, yv^(-1)] + 2*G[{1/(yu*yv)}, yw]*G[{0, 1, yu}, yv^(-1)] + 
     G[{0}, yu^(-1)]*G[{0, 1, yv^(-1)}, yw] + G[{0}, yv^(-1)]*
      G[{0, 1, yv^(-1)}, yw] - G[{0}, yw]*G[{0, 1, yv^(-1)}, yw] - 
     2*G[{1}, yu^(-1)]*G[{0, 1, yv^(-1)}, yw] - 2*G[{1/(yu*yv)}, yw]*
      G[{0, 1, yv^(-1)}, yw] + G[{0}, yu^(-1)]*G[{0, 1, 1/(yu*yv)}, yw] + 
     G[{0}, yv^(-1)]*G[{0, 1, 1/(yu*yv)}, yw] - 
     G[{0}, yw]*G[{0, 1, 1/(yu*yv)}, yw] - G[{1}, yu^(-1)]*
      G[{0, 1, 1/(yu*yv)}, yw] + G[{1}, yw]*G[{0, 1, 1/(yu*yv)}, yw] - 
     G[{yu}, yv^(-1)]*G[{0, 1, 1/(yu*yv)}, yw] + G[{1/(yu*yv)}, yw]*
      G[{0, 1, 1/(yu*yv)}, yw] - G[{0}, yu^(-1)]*G[{0, yu^(-1), 1}, yw] - 
     G[{0}, yv^(-1)]*G[{0, yu^(-1), 1}, yw] + 
     G[{0}, yw]*G[{0, yu^(-1), 1}, yw] + G[{1}, yu^(-1)]*
      G[{0, yu^(-1), 1}, yw] - G[{1}, yw]*G[{0, yu^(-1), 1}, yw] + 
     G[{yu}, yv^(-1)]*G[{0, yu^(-1), 1}, yw] - G[{1/(yu*yv)}, yw]*
      G[{0, yu^(-1), 1}, yw] + 2*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1), yu^(-1)}, 
       yw] + 2*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1), yv^(-1)}, yw] - 
     2*G[{0}, yu^(-1)]*G[{0, yu^(-1), 1/(yu*yv)}, yw] - 
     2*G[{0}, yv^(-1)]*G[{0, yu^(-1), 1/(yu*yv)}, yw] + 
     2*G[{0}, yw]*G[{0, yu^(-1), 1/(yu*yv)}, yw] + 
     3*G[{1}, yu^(-1)]*G[{0, yu^(-1), 1/(yu*yv)}, yw] + 
     2*G[{1}, yv^(-1)]*G[{0, yu^(-1), 1/(yu*yv)}, yw] - 
     G[{1}, yw]*G[{0, yu^(-1), 1/(yu*yv)}, yw] - G[{yu}, yv^(-1)]*
      G[{0, yu^(-1), 1/(yu*yv)}, yw] - G[{1/(yu*yv)}, yw]*
      G[{0, yu^(-1), 1/(yu*yv)}, yw] + G[{0}, yu^(-1)]*
      G[{0, yu, 1}, yv^(-1)] + G[{0}, yv^(-1)]*G[{0, yu, 1}, yv^(-1)] - 
     G[{0}, yw]*G[{0, yu, 1}, yv^(-1)] + G[{1}, yu^(-1)]*
      G[{0, yu, 1}, yv^(-1)] - G[{1}, yv^(-1)]*G[{0, yu, 1}, yv^(-1)] + 
     G[{1}, yw]*G[{0, yu, 1}, yv^(-1)] + G[{1/(yu*yv)}, yw]*
      G[{0, yu, 1}, yv^(-1)] - 2*G[{0}, yu^(-1)]*G[{0, yu, yu}, yv^(-1)] - 
     2*G[{0}, yv^(-1)]*G[{0, yu, yu}, yv^(-1)] + 
     2*G[{0}, yw]*G[{0, yu, yu}, yv^(-1)] + 2*G[{1}, yv^(-1)]*
      G[{0, yu, yu}, yv^(-1)] - 2*G[{1/(yu*yv)}, yw]*
      G[{0, yu, yu}, yv^(-1)] + G[{1}, yu^(-1)]*G[{0, yv^(-1), 1}, yw] - 
     G[{1}, yw]*G[{0, yv^(-1), 1}, yw] - G[{yu}, yv^(-1)]*
      G[{0, yv^(-1), 1}, yw] - G[{1/(yu*yv)}, yw]*G[{0, yv^(-1), 1}, yw] + 
     2*G[{1/(yu*yv)}, yw]*G[{0, yv^(-1), yu^(-1)}, yw] - 
     2*G[{0}, yu^(-1)]*G[{0, yv^(-1), yv^(-1)}, yw] - 
     2*G[{0}, yv^(-1)]*G[{0, yv^(-1), yv^(-1)}, yw] + 
     2*G[{0}, yw]*G[{0, yv^(-1), yv^(-1)}, yw] + 4*G[{1}, yu^(-1)]*
      G[{0, yv^(-1), yv^(-1)}, yw] + 2*G[{1/(yu*yv)}, yw]*
      G[{0, yv^(-1), yv^(-1)}, yw] - G[{0}, yu^(-1)]*
      G[{0, yv^(-1), 1/(yu*yv)}, yw] - G[{0}, yv^(-1)]*
      G[{0, yv^(-1), 1/(yu*yv)}, yw] + G[{0}, yw]*G[{0, yv^(-1), 1/(yu*yv)}, 
       yw] + G[{1}, yu^(-1)]*G[{0, yv^(-1), 1/(yu*yv)}, yw] - 
     G[{1}, yw]*G[{0, yv^(-1), 1/(yu*yv)}, yw] + G[{yu}, yv^(-1)]*
      G[{0, yv^(-1), 1/(yu*yv)}, yw] - G[{1/(yu*yv)}, yw]*
      G[{0, yv^(-1), 1/(yu*yv)}, yw] - G[{1}, yu^(-1)]*
      G[{0, 1/(yu*yv), 1}, yw] + G[{1}, yw]*G[{0, 1/(yu*yv), 1}, yw] + 
     G[{yu}, yv^(-1)]*G[{0, 1/(yu*yv), 1}, yw] + G[{1/(yu*yv)}, yw]*
      G[{0, 1/(yu*yv), 1}, yw] - 2*G[{1/(yu*yv)}, yw]*
      G[{0, 1/(yu*yv), yu^(-1)}, yw] + G[{0}, yu^(-1)]*
      G[{0, 1/(yu*yv), yv^(-1)}, yw] + G[{0}, yv^(-1)]*
      G[{0, 1/(yu*yv), yv^(-1)}, yw] - G[{0}, yw]*G[{0, 1/(yu*yv), yv^(-1)}, 
       yw] - 2*G[{1}, yu^(-1)]*G[{0, 1/(yu*yv), yv^(-1)}, yw] - 
     2*G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv), yv^(-1)}, yw] + 
     2*G[{0}, yu^(-1)]*G[{0, 1/(yu*yv), 1/(yu*yv)}, yw] + 
     2*G[{0}, yv^(-1)]*G[{0, 1/(yu*yv), 1/(yu*yv)}, yw] - 
     2*G[{0}, yw]*G[{0, 1/(yu*yv), 1/(yu*yv)}, yw] - 
     3*G[{1}, yu^(-1)]*G[{0, 1/(yu*yv), 1/(yu*yv)}, yw] - 
     2*G[{1}, yv^(-1)]*G[{0, 1/(yu*yv), 1/(yu*yv)}, yw] + 
     G[{1}, yw]*G[{0, 1/(yu*yv), 1/(yu*yv)}, yw] + 
     G[{yu}, yv^(-1)]*G[{0, 1/(yu*yv), 1/(yu*yv)}, yw] + 
     G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv), 1/(yu*yv)}, yw] + 
     G[{0}, yu^(-1)]*G[{1, 1, yu}, yv^(-1)] + G[{0}, yv^(-1)]*
      G[{1, 1, yu}, yv^(-1)] - G[{0}, yw]*G[{1, 1, yu}, yv^(-1)] + 
     2*G[{1}, yu^(-1)]*G[{1, 1, yu}, yv^(-1)] + 
     G[{1}, yw]*G[{1, 1, yu}, yv^(-1)] + G[{1/(yu*yv)}, yw]*
      G[{1, 1, yu}, yv^(-1)] + G[{0}, yu^(-1)]*G[{1, 1, yv^(-1)}, yw] + 
     G[{0}, yv^(-1)]*G[{1, 1, yv^(-1)}, yw] - 
     G[{0}, yw]*G[{1, 1, yv^(-1)}, yw] + 2*G[{1}, yw]*
      G[{1, 1, yv^(-1)}, yw] - 2*G[{yu}, yv^(-1)]*G[{1, 1, yv^(-1)}, yw] - 
     3*G[{1/(yu*yv)}, yw]*G[{1, 1, yv^(-1)}, yw] - 
     3*G[{0}, yu^(-1)]*G[{1, 1, 1/(yu*yv)}, yw] - 
     3*G[{0}, yv^(-1)]*G[{1, 1, 1/(yu*yv)}, yw] + 
     3*G[{0}, yw]*G[{1, 1, 1/(yu*yv)}, yw] + 2*G[{1}, yu^(-1)]*
      G[{1, 1, 1/(yu*yv)}, yw] - 4*G[{1}, yw]*G[{1, 1, 1/(yu*yv)}, yw] + 
     4*G[{yu}, yv^(-1)]*G[{1, 1, 1/(yu*yv)}, yw] + 
     G[{1/(yu*yv)}, yw]*G[{1, 1, 1/(yu*yv)}, yw] - 2*G[{1/(yu*yv)}, yw]*
      G[{1, yu^(-1), yv^(-1)}, yw] + 2*G[{0}, yu^(-1)]*
      G[{1, yu^(-1), 1/(yu*yv)}, yw] + 2*G[{0}, yv^(-1)]*
      G[{1, yu^(-1), 1/(yu*yv)}, yw] - 2*G[{0}, yw]*
      G[{1, yu^(-1), 1/(yu*yv)}, yw] - 2*G[{1}, yu^(-1)]*
      G[{1, yu^(-1), 1/(yu*yv)}, yw] + 2*G[{1}, yw]*
      G[{1, yu^(-1), 1/(yu*yv)}, yw] - 2*G[{yu}, yv^(-1)]*
      G[{1, yu^(-1), 1/(yu*yv)}, yw] + 2*G[{0}, yu^(-1)]*
      G[{1, yu, yu}, yv^(-1)] + 2*G[{0}, yv^(-1)]*G[{1, yu, yu}, yv^(-1)] - 
     2*G[{0}, yw]*G[{1, yu, yu}, yv^(-1)] + 4*G[{1/(yu*yv)}, yw]*
      G[{1, yu, yu}, yv^(-1)] - 2*G[{1/(yu*yv)}, yw]*G[{1, yv^(-1), yu^(-1)}, 
       yw] + 2*G[{0}, yu^(-1)]*G[{1, yv^(-1), yv^(-1)}, yw] + 
     2*G[{0}, yv^(-1)]*G[{1, yv^(-1), yv^(-1)}, yw] - 
     2*G[{0}, yw]*G[{1, yv^(-1), yv^(-1)}, yw] - 4*G[{1}, yu^(-1)]*
      G[{1, yv^(-1), yv^(-1)}, yw] - 4*G[{1/(yu*yv)}, yw]*
      G[{1, yv^(-1), yv^(-1)}, yw] + G[{0}, yu^(-1)]*
      G[{1, yv^(-1), 1/(yu*yv)}, yw] + G[{0}, yv^(-1)]*
      G[{1, yv^(-1), 1/(yu*yv)}, yw] - G[{0}, yw]*G[{1, yv^(-1), 1/(yu*yv)}, 
       yw] - 2*G[{1}, yu^(-1)]*G[{1, yv^(-1), 1/(yu*yv)}, yw] + 
     G[{1/(yu*yv)}, yw]*G[{1, yv^(-1), 1/(yu*yv)}, yw] - 
     2*G[{1/(yu*yv)}, yw]*G[{1, 1/(yu*yv), yu^(-1)}, yw] + 
     2*G[{1/(yu*yv)}, yw]*G[{1, 1/(yu*yv), yv^(-1)}, yw] - 
     G[{0}, yu^(-1)]*G[{1, 1/(yu*yv), 1/(yu*yv)}, yw] - 
     G[{0}, yv^(-1)]*G[{1, 1/(yu*yv), 1/(yu*yv)}, yw] + 
     G[{0}, yw]*G[{1, 1/(yu*yv), 1/(yu*yv)}, yw] + 
     2*G[{1}, yu^(-1)]*G[{1, 1/(yu*yv), 1/(yu*yv)}, yw] + 
     G[{1/(yu*yv)}, yw]*G[{1, 1/(yu*yv), 1/(yu*yv)}, yw] - 
     4*G[{1/(yu*yv)}, yw]*G[{yu^(-1), yu^(-1), 1/(yu*yv)}, yw] + 
     2*G[{1/(yu*yv)}, yw]*G[{yu^(-1), 1/(yu*yv), yv^(-1)}, yw] - 
     2*G[{0}, yu^(-1)]*G[{yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] - 
     2*G[{0}, yv^(-1)]*G[{yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] + 
     2*G[{0}, yw]*G[{yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] + 
     4*G[{1}, yu^(-1)]*G[{yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] + 
     4*G[{1}, yv^(-1)]*G[{yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] + 
     4*G[{1}, yw]*G[{yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] - 
     4*G[{yu^(-1)}, yw]*G[{yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] - 
     4*G[{yu}, yv^(-1)]*G[{yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] - 
     2*G[{1/(yu*yv)}, yw]*G[{yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] + 
     2*G[{0}, yu^(-1)]*G[{yv^(-1), yv^(-1), 1/(yu*yv)}, yw] + 
     2*G[{0}, yv^(-1)]*G[{yv^(-1), yv^(-1), 1/(yu*yv)}, yw] - 
     2*G[{0}, yw]*G[{yv^(-1), yv^(-1), 1/(yu*yv)}, yw] - 
     4*G[{1}, yu^(-1)]*G[{yv^(-1), yv^(-1), 1/(yu*yv)}, yw] + 
     4*G[{yv^(-1)}, yw]*G[{yv^(-1), yv^(-1), 1/(yu*yv)}, yw] - 
     G[{0}, yu^(-1)]*G[{yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] - 
     G[{0}, yv^(-1)]*G[{yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] + 
     G[{0}, yw]*G[{yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] - 
     2*G[{1}, yw]*G[{yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] + 
     2*G[{yu}, yv^(-1)]*G[{yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] - 
     G[{1/(yu*yv)}, yw]*G[{yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] + 
     G[{0, 0, 0, 1}, yv^(-1)] + 3*G[{0, 0, 0, 1}, yw] - 
     3*G[{0, 0, 0, yu^(-1)}, yw] - G[{0, 0, 0, yu}, yv^(-1)] - 
     3*G[{0, 0, 0, yv^(-1)}, yw] + 3*G[{0, 0, 0, 1/(yu*yv)}, yw] - 
     G[{0, 0, 1, 1}, yv^(-1)] + G[{0, 0, 1, 1}, yw] + 
     2*G[{0, 0, 1, yu^(-1)}, yw] + 2*G[{0, 0, 1, yv^(-1)}, yw] - 
     G[{0, 0, 1, 1/(yu*yv)}, yw] + G[{0, 0, yu^(-1), 1}, yw] - 
     2*G[{0, 0, yu^(-1), yu^(-1)}, yw] - G[{0, 0, yu^(-1), 1/(yu*yv)}, yw] - 
     G[{0, 0, yu, 1}, yv^(-1)] + G[{0, 0, yv^(-1), 1}, yw] - 
     4*G[{0, 0, yv^(-1), yv^(-1)}, yw] + G[{0, 0, yv^(-1), 1/(yu*yv)}, yw] - 
     3*G[{0, 0, 1/(yu*yv), 1}, yw] + 2*G[{0, 0, 1/(yu*yv), yu^(-1)}, yw] + 
     4*G[{0, 0, 1/(yu*yv), yv^(-1)}, yw] + G[{0, 0, 1/(yu*yv), 1/(yu*yv)}, 
      yw] + G[{0, 1, 0, yu^(-1)}, yw] - G[{0, 1, 0, yu}, yv^(-1)] - 
     G[{0, 1, 0, 1/(yu*yv)}, yw] - 3*G[{0, 1, 1, 1}, yu^(-1)] - 
     3*G[{0, 1, 1, 1}, yv^(-1)] + 3*G[{0, 1, 1, yu}, yv^(-1)] + 
     G[{0, 1, 1, yv^(-1)}, yw] - G[{0, 1, 1, 1/(yu*yv)}, yw] + 
     2*G[{0, 1, yu^(-1), 1/(yu*yv)}, yw] + 2*G[{0, 1, yu, 1}, yv^(-1)] - 
     2*G[{0, 1, yu, yu}, yv^(-1)] + 2*G[{0, 1, yv^(-1), yv^(-1)}, yw] + 
     2*G[{0, 1, yv^(-1), 1/(yu*yv)}, yw] + G[{0, 1, 1/(yu*yv), yv^(-1)}, 
      yw] - G[{0, 1, 1/(yu*yv), 1/(yu*yv)}, yw] + G[{0, yu^(-1), 0, yv^(-1)}, 
      yw] - G[{0, yu^(-1), 1, yv^(-1)}, yw] + G[{0, yu^(-1), 1, 1/(yu*yv)}, 
      yw] - 2*G[{0, yu^(-1), yu^(-1), 1/(yu*yv)}, yw] - 
     2*G[{0, yu^(-1), yv^(-1), 1/(yu*yv)}, yw] + 
     2*G[{0, yu^(-1), 1/(yu*yv), 1}, yw] - 
     2*G[{0, yu^(-1), 1/(yu*yv), yu^(-1)}, yw] - 
     3*G[{0, yu^(-1), 1/(yu*yv), yv^(-1)}, yw] + 
     G[{0, yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] + G[{0, yu, 1, 1}, yv^(-1)] - 
     3*G[{0, yu, 1, yu}, yv^(-1)] - 2*G[{0, yu, yu, 1}, yv^(-1)] + 
     4*G[{0, yu, yu, yu}, yv^(-1)] + G[{0, yv^(-1), 0, 1/(yu*yv)}, yw] + 
     2*G[{0, yv^(-1), 1, 1}, yw] - G[{0, yv^(-1), 1, yv^(-1)}, yw] + 
     G[{0, yv^(-1), 1, 1/(yu*yv)}, yw] - 
     2*G[{0, yv^(-1), yu^(-1), 1/(yu*yv)}, yw] - 
     4*G[{0, yv^(-1), yv^(-1), yv^(-1)}, yw] - 
     2*G[{0, yv^(-1), yv^(-1), 1/(yu*yv)}, yw] - 
     G[{0, yv^(-1), 1/(yu*yv), yv^(-1)}, yw] + 
     G[{0, yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] - 
     2*G[{0, 1/(yu*yv), 1, 1}, yw] + G[{0, 1/(yu*yv), 1, yv^(-1)}, yw] - 
     G[{0, 1/(yu*yv), 1, 1/(yu*yv)}, yw] + 
     2*G[{0, 1/(yu*yv), yu^(-1), 1/(yu*yv)}, yw] + 
     2*G[{0, 1/(yu*yv), yv^(-1), yv^(-1)}, yw] + 
     2*G[{0, 1/(yu*yv), yv^(-1), 1/(yu*yv)}, yw] - 
     2*G[{0, 1/(yu*yv), 1/(yu*yv), 1}, yw] + 
     2*G[{0, 1/(yu*yv), 1/(yu*yv), yu^(-1)}, yw] + 
     3*G[{0, 1/(yu*yv), 1/(yu*yv), yv^(-1)}, yw] - 
     G[{0, 1/(yu*yv), 1/(yu*yv), 1/(yu*yv)}, yw] - 
     G[{1, 1, 1, yu}, yv^(-1)] - 3*G[{1, 1, 1, yv^(-1)}, yw] + 
     3*G[{1, 1, 1, 1/(yu*yv)}, yw] - 4*G[{1, 1, yu, yu}, yv^(-1)] - 
     G[{1, 1, yv^(-1), 1/(yu*yv)}, yw] - 2*G[{1, 1, 1/(yu*yv), yv^(-1)}, 
       yw] - G[{1, 1, 1/(yu*yv), 1/(yu*yv)}, yw] + 
     2*G[{1, yu^(-1), yv^(-1), 1/(yu*yv)}, yw] + 
     2*G[{1, yu^(-1), 1/(yu*yv), yv^(-1)}, yw] - 
     4*G[{1, yu, yu, yu}, yv^(-1)] - 2*G[{1, yv^(-1), 1, 1/(yu*yv)}, yw] + 
     2*G[{1, yv^(-1), yu^(-1), 1/(yu*yv)}, yw] + 
     4*G[{1, yv^(-1), yv^(-1), yv^(-1)}, yw] + 
     4*G[{1, yv^(-1), yv^(-1), 1/(yu*yv)}, yw] + 
     2*G[{1, yv^(-1), 1/(yu*yv), yv^(-1)}, yw] - 
     G[{1, yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] + 
     2*G[{1, 1/(yu*yv), yu^(-1), 1/(yu*yv)}, yw] - 
     2*G[{1, 1/(yu*yv), yv^(-1), 1/(yu*yv)}, yw] - 
     2*G[{1, 1/(yu*yv), 1/(yu*yv), yv^(-1)}, yw] - 
     G[{1, 1/(yu*yv), 1/(yu*yv), 1/(yu*yv)}, yw] + 
     4*G[{yu^(-1), yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] - 
     2*G[{yu^(-1), 1/(yu*yv), yv^(-1), 1/(yu*yv)}, yw] - 
     4*G[{yu^(-1), 1/(yu*yv), 1/(yu*yv), yv^(-1)}, yw] + 
     2*G[{yu^(-1), 1/(yu*yv), 1/(yu*yv), 1/(yu*yv)}, yw] - 
     4*G[{yv^(-1), yv^(-1), yv^(-1), 1/(yu*yv)}, yw] + 
     G[{yv^(-1), 1/(yu*yv), 1/(yu*yv), 1/(yu*yv)}, yw] - 
     2*G[{0}, yu^(-1)]*Zeta[3] - 2*G[{0}, yv^(-1)]*Zeta[3] + 
     2*G[{0}, yw]*Zeta[3] + 2*G[{1}, yv^(-1)]*Zeta[3] - 
     2*G[{1/(yu*yv)}, yw]*Zeta[3]
 
F1uvwRegII = (-17*Pi^4)/360 - (Pi^2*G[{0}, yu^(-1)]*G[{1}, yu^(-1)])/6 - 
     (Pi^2*G[{0}, yv^(-1)]*G[{1}, yu^(-1)])/6 + 
     (Pi^2*G[{0}, yw]*G[{1}, yu^(-1)])/6 + 
     (Pi^2*G[{0}, yu^(-1)]*G[{yu^(-1)}, yw])/6 + 
     (Pi^2*G[{0}, yv^(-1)]*G[{yu^(-1)}, yw])/6 - 
     (Pi^2*G[{0}, yw]*G[{yu^(-1)}, yw])/6 + 
     (Pi^2*G[{0}, yu^(-1)]*G[{yu}, yv^(-1)])/6 + 
     (Pi^2*G[{0}, yv^(-1)]*G[{yu}, yv^(-1)])/6 - 
     (Pi^2*G[{0}, yw]*G[{yu}, yv^(-1)])/6 - 
     (Pi^2*G[{0}, yu^(-1)]*G[{1/(yu*yv)}, yw])/6 - 
     (Pi^2*G[{0}, yv^(-1)]*G[{1/(yu*yv)}, yw])/6 + 
     (Pi^2*G[{0}, yw]*G[{1/(yu*yv)}, yw])/6 + (Pi^2*G[{0, 1}, yu^(-1)])/6 - 
     G[{0}, yu^(-1)]*G[{1}, yu^(-1)]*G[{0, 1}, yu^(-1)] - 
     G[{0}, yv^(-1)]*G[{1}, yu^(-1)]*G[{0, 1}, yu^(-1)] + 
     G[{0}, yw]*G[{1}, yu^(-1)]*G[{0, 1}, yu^(-1)] + 
     G[{0}, yu^(-1)]*G[{yu^(-1)}, yw]*G[{0, 1}, yu^(-1)] + 
     G[{0}, yv^(-1)]*G[{yu^(-1)}, yw]*G[{0, 1}, yu^(-1)] - 
     G[{0}, yw]*G[{yu^(-1)}, yw]*G[{0, 1}, yu^(-1)] + 
     G[{0}, yu^(-1)]*G[{yu}, yv^(-1)]*G[{0, 1}, yu^(-1)] + 
     G[{0}, yv^(-1)]*G[{yu}, yv^(-1)]*G[{0, 1}, yu^(-1)] - 
     G[{0}, yw]*G[{yu}, yv^(-1)]*G[{0, 1}, yu^(-1)] - 
     G[{0}, yu^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, 1}, yu^(-1)] - 
     G[{0}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, 1}, yu^(-1)] + 
     G[{0}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1}, yu^(-1)] + 
     G[{0, 1}, yu^(-1)]^2/2 - (Pi^2*G[{0, 1}, yv^(-1)])/6 + 
     G[{0}, yu^(-1)]*G[{1}, yu^(-1)]*G[{0, 1}, yv^(-1)] + 
     G[{0}, yv^(-1)]*G[{1}, yu^(-1)]*G[{0, 1}, yv^(-1)] - 
     G[{0}, yw]*G[{1}, yu^(-1)]*G[{0, 1}, yv^(-1)] - 
     G[{1}, yu^(-1)]^2*G[{0, 1}, yv^(-1)] + G[{0}, yu^(-1)]*G[{yu^(-1)}, yw]*
      G[{0, 1}, yv^(-1)] + G[{0}, yv^(-1)]*G[{yu^(-1)}, yw]*
      G[{0, 1}, yv^(-1)] - G[{0}, yw]*G[{yu^(-1)}, yw]*G[{0, 1}, yv^(-1)] + 
     G[{0}, yu^(-1)]*G[{yu}, yv^(-1)]*G[{0, 1}, yv^(-1)] + 
     G[{0}, yv^(-1)]*G[{yu}, yv^(-1)]*G[{0, 1}, yv^(-1)] - 
     G[{0}, yw]*G[{yu}, yv^(-1)]*G[{0, 1}, yv^(-1)] - 
     G[{0}, yu^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, 1}, yv^(-1)] - 
     G[{0}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, 1}, yv^(-1)] + 
     G[{0}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1}, yv^(-1)] - 
     G[{0, 1}, yu^(-1)]*G[{0, 1}, yv^(-1)] + G[{0, 1}, yv^(-1)]^2/2 + 
     (Pi^2*G[{0, 1}, yw])/6 - G[{0}, yu^(-1)]*G[{1}, yu^(-1)]*G[{0, 1}, yw] - 
     G[{0}, yv^(-1)]*G[{1}, yu^(-1)]*G[{0, 1}, yw] + 
     G[{0}, yw]*G[{1}, yu^(-1)]*G[{0, 1}, yw] + G[{1}, yu^(-1)]^2*
      G[{0, 1}, yw] + 2*G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*G[{0, 1}, yw] + 
     G[{0}, yu^(-1)]*G[{yu^(-1)}, yw]*G[{0, 1}, yw] + 
     G[{0}, yv^(-1)]*G[{yu^(-1)}, yw]*G[{0, 1}, yw] - 
     G[{0}, yw]*G[{yu^(-1)}, yw]*G[{0, 1}, yw] + 
     G[{0}, yu^(-1)]*G[{yu}, yv^(-1)]*G[{0, 1}, yw] + 
     G[{0}, yv^(-1)]*G[{yu}, yv^(-1)]*G[{0, 1}, yw] - 
     G[{0}, yw]*G[{yu}, yv^(-1)]*G[{0, 1}, yw] - 2*G[{1}, yu^(-1)]*
      G[{yu}, yv^(-1)]*G[{0, 1}, yw] - 2*G[{yu^(-1)}, yw]*G[{yu}, yv^(-1)]*
      G[{0, 1}, yw] - G[{0}, yu^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, 1}, yw] - 
     G[{0}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, 1}, yw] + 
     G[{0}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1}, yw] + 
     2*G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, 1}, yw] + 
     G[{0, 1}, yu^(-1)]*G[{0, 1}, yw] - G[{0, 1}, yv^(-1)]*G[{0, 1}, yw] - 
     G[{0, 1}, yw]^2/2 + (Pi^2*G[{0, yu^(-1)}, yw])/6 + 
     G[{0}, yu^(-1)]*G[{1}, yu^(-1)]*G[{0, yu^(-1)}, yw] + 
     G[{0}, yv^(-1)]*G[{1}, yu^(-1)]*G[{0, yu^(-1)}, yw] - 
     G[{0}, yw]*G[{1}, yu^(-1)]*G[{0, yu^(-1)}, yw] - 
     G[{1}, yu^(-1)]^2*G[{0, yu^(-1)}, yw] - G[{0}, yu^(-1)]*G[{yu^(-1)}, yw]*
      G[{0, yu^(-1)}, yw] - G[{0}, yv^(-1)]*G[{yu^(-1)}, yw]*
      G[{0, yu^(-1)}, yw] + G[{0}, yw]*G[{yu^(-1)}, yw]*G[{0, yu^(-1)}, yw] + 
     2*G[{1}, yv^(-1)]*G[{yu^(-1)}, yw]*G[{0, yu^(-1)}, yw] - 
     G[{0}, yu^(-1)]*G[{yu}, yv^(-1)]*G[{0, yu^(-1)}, yw] - 
     G[{0}, yv^(-1)]*G[{yu}, yv^(-1)]*G[{0, yu^(-1)}, yw] + 
     G[{0}, yw]*G[{yu}, yv^(-1)]*G[{0, yu^(-1)}, yw] + 
     2*G[{1}, yv^(-1)]*G[{yu}, yv^(-1)]*G[{0, yu^(-1)}, yw] + 
     G[{0}, yu^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1)}, yw] + 
     G[{0}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1)}, yw] - 
     G[{0}, yw]*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1)}, yw] - 
     2*G[{1}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1)}, yw] + 
     G[{0, 1}, yu^(-1)]*G[{0, yu^(-1)}, yw] - G[{0, 1}, yv^(-1)]*
      G[{0, yu^(-1)}, yw] - G[{0, 1}, yw]*G[{0, yu^(-1)}, yw] + 
     G[{0, yu^(-1)}, yw]^2/2 - (Pi^2*G[{0, yu}, yv^(-1)])/6 - 
     G[{0}, yu^(-1)]*G[{1}, yu^(-1)]*G[{0, yu}, yv^(-1)] - 
     G[{0}, yv^(-1)]*G[{1}, yu^(-1)]*G[{0, yu}, yv^(-1)] + 
     G[{0}, yw]*G[{1}, yu^(-1)]*G[{0, yu}, yv^(-1)] + 
     G[{1}, yu^(-1)]^2*G[{0, yu}, yv^(-1)] - G[{0}, yu^(-1)]*G[{yu^(-1)}, yw]*
      G[{0, yu}, yv^(-1)] - G[{0}, yv^(-1)]*G[{yu^(-1)}, yw]*
      G[{0, yu}, yv^(-1)] + G[{0}, yw]*G[{yu^(-1)}, yw]*G[{0, yu}, yv^(-1)] - 
     G[{0}, yu^(-1)]*G[{yu}, yv^(-1)]*G[{0, yu}, yv^(-1)] - 
     G[{0}, yv^(-1)]*G[{yu}, yv^(-1)]*G[{0, yu}, yv^(-1)] + 
     G[{0}, yw]*G[{yu}, yv^(-1)]*G[{0, yu}, yv^(-1)] + 
     G[{0}, yu^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, yu}, yv^(-1)] + 
     G[{0}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, yu}, yv^(-1)] - 
     G[{0}, yw]*G[{1/(yu*yv)}, yw]*G[{0, yu}, yv^(-1)] - 
     G[{0, 1}, yu^(-1)]*G[{0, yu}, yv^(-1)] + G[{0, 1}, yv^(-1)]*
      G[{0, yu}, yv^(-1)] + G[{0, 1}, yw]*G[{0, yu}, yv^(-1)] + 
     G[{0, yu^(-1)}, yw]*G[{0, yu}, yv^(-1)] - G[{0, yu}, yv^(-1)]^2/2 - 
     (Pi^2*G[{0, yv^(-1)}, yw])/6 + G[{0}, yu^(-1)]*G[{1}, yu^(-1)]*
      G[{0, yv^(-1)}, yw] + G[{0}, yv^(-1)]*G[{1}, yu^(-1)]*
      G[{0, yv^(-1)}, yw] - G[{0}, yw]*G[{1}, yu^(-1)]*G[{0, yv^(-1)}, yw] - 
     G[{1}, yu^(-1)]^2*G[{0, yv^(-1)}, yw] - 2*G[{1}, yu^(-1)]*
      G[{1}, yv^(-1)]*G[{0, yv^(-1)}, yw] - G[{0}, yu^(-1)]*G[{yu^(-1)}, yw]*
      G[{0, yv^(-1)}, yw] - G[{0}, yv^(-1)]*G[{yu^(-1)}, yw]*
      G[{0, yv^(-1)}, yw] + G[{0}, yw]*G[{yu^(-1)}, yw]*G[{0, yv^(-1)}, yw] + 
     2*G[{1}, yu^(-1)]*G[{yu^(-1)}, yw]*G[{0, yv^(-1)}, yw] - 
     G[{0}, yu^(-1)]*G[{yu}, yv^(-1)]*G[{0, yv^(-1)}, yw] - 
     G[{0}, yv^(-1)]*G[{yu}, yv^(-1)]*G[{0, yv^(-1)}, yw] + 
     G[{0}, yw]*G[{yu}, yv^(-1)]*G[{0, yv^(-1)}, yw] + 
     2*G[{1}, yu^(-1)]*G[{yu}, yv^(-1)]*G[{0, yv^(-1)}, yw] + 
     G[{0}, yu^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, yv^(-1)}, yw] + 
     G[{0}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, yv^(-1)}, yw] - 
     G[{0}, yw]*G[{1/(yu*yv)}, yw]*G[{0, yv^(-1)}, yw] - 
     2*G[{1}, yu^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, yv^(-1)}, yw] - 
     G[{0, 1}, yu^(-1)]*G[{0, yv^(-1)}, yw] + G[{0, 1}, yv^(-1)]*
      G[{0, yv^(-1)}, yw] + G[{0, 1}, yw]*G[{0, yv^(-1)}, yw] - 
     G[{0, yu^(-1)}, yw]*G[{0, yv^(-1)}, yw] - G[{0, yu}, yv^(-1)]*
      G[{0, yv^(-1)}, yw] - G[{0, yv^(-1)}, yw]^2/2 - 
     (Pi^2*G[{0, 1/(yu*yv)}, yw])/6 - G[{0}, yu^(-1)]*G[{1}, yu^(-1)]*
      G[{0, 1/(yu*yv)}, yw] - G[{0}, yv^(-1)]*G[{1}, yu^(-1)]*
      G[{0, 1/(yu*yv)}, yw] + G[{0}, yw]*G[{1}, yu^(-1)]*
      G[{0, 1/(yu*yv)}, yw] + G[{1}, yu^(-1)]^2*G[{0, 1/(yu*yv)}, yw] + 
     G[{0}, yu^(-1)]*G[{yu^(-1)}, yw]*G[{0, 1/(yu*yv)}, yw] + 
     G[{0}, yv^(-1)]*G[{yu^(-1)}, yw]*G[{0, 1/(yu*yv)}, yw] - 
     G[{0}, yw]*G[{yu^(-1)}, yw]*G[{0, 1/(yu*yv)}, yw] - 
     2*G[{1}, yu^(-1)]*G[{yu^(-1)}, yw]*G[{0, 1/(yu*yv)}, yw] - 
     2*G[{1}, yv^(-1)]*G[{yu^(-1)}, yw]*G[{0, 1/(yu*yv)}, yw] + 
     G[{0}, yu^(-1)]*G[{yu}, yv^(-1)]*G[{0, 1/(yu*yv)}, yw] + 
     G[{0}, yv^(-1)]*G[{yu}, yv^(-1)]*G[{0, 1/(yu*yv)}, yw] - 
     G[{0}, yw]*G[{yu}, yv^(-1)]*G[{0, 1/(yu*yv)}, yw] - 
     2*G[{1}, yv^(-1)]*G[{yu}, yv^(-1)]*G[{0, 1/(yu*yv)}, yw] + 
     2*G[{yu^(-1)}, yw]*G[{yu}, yv^(-1)]*G[{0, 1/(yu*yv)}, yw] - 
     G[{0}, yu^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv)}, yw] - 
     G[{0}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv)}, yw] + 
     G[{0}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv)}, yw] + 
     2*G[{1}, yu^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv)}, yw] + 
     2*G[{1}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv)}, yw] - 
     2*G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv)}, yw] - 
     G[{0, 1}, yu^(-1)]*G[{0, 1/(yu*yv)}, yw] + G[{0, 1}, yv^(-1)]*
      G[{0, 1/(yu*yv)}, yw] + G[{0, 1}, yw]*G[{0, 1/(yu*yv)}, yw] - 
     G[{0, yu^(-1)}, yw]*G[{0, 1/(yu*yv)}, yw] - G[{0, yu}, yv^(-1)]*
      G[{0, 1/(yu*yv)}, yw] - G[{0, yv^(-1)}, yw]*G[{0, 1/(yu*yv)}, yw] + 
     G[{0, 1/(yu*yv)}, yw]^2/2 - 2*G[{0, 1}, yw]*G[{1, yu}, yv^(-1)] - 
     2*G[{0, yu^(-1)}, yw]*G[{1, yu}, yv^(-1)] + 2*G[{0, yv^(-1)}, yw]*
      G[{1, yu}, yv^(-1)] + 2*G[{0, 1/(yu*yv)}, yw]*G[{1, yu}, yv^(-1)] - 
     2*G[{0}, yu^(-1)]*G[{0, 0, 1}, yv^(-1)] - 2*G[{0}, yv^(-1)]*
      G[{0, 0, 1}, yv^(-1)] + 2*G[{0}, yw]*G[{0, 0, 1}, yv^(-1)] - 
     2*G[{1}, yu^(-1)]*G[{0, 0, 1}, yw] + 2*G[{yu^(-1)}, yw]*
      G[{0, 0, 1}, yw] + 2*G[{yu}, yv^(-1)]*G[{0, 0, 1}, yw] - 
     2*G[{1/(yu*yv)}, yw]*G[{0, 0, 1}, yw] + 2*G[{1}, yu^(-1)]*
      G[{0, 0, yu^(-1)}, yw] - 2*G[{yu^(-1)}, yw]*G[{0, 0, yu^(-1)}, yw] - 
     2*G[{yu}, yv^(-1)]*G[{0, 0, yu^(-1)}, yw] + 2*G[{1/(yu*yv)}, yw]*
      G[{0, 0, yu^(-1)}, yw] + 2*G[{0}, yu^(-1)]*G[{0, 0, yu}, yv^(-1)] + 
     2*G[{0}, yv^(-1)]*G[{0, 0, yu}, yv^(-1)] - 
     2*G[{0}, yw]*G[{0, 0, yu}, yv^(-1)] + 2*G[{1}, yu^(-1)]*
      G[{0, 0, yv^(-1)}, yw] - 2*G[{yu^(-1)}, yw]*G[{0, 0, yv^(-1)}, yw] - 
     2*G[{yu}, yv^(-1)]*G[{0, 0, yv^(-1)}, yw] + 2*G[{1/(yu*yv)}, yw]*
      G[{0, 0, yv^(-1)}, yw] - 2*G[{1}, yu^(-1)]*G[{0, 0, 1/(yu*yv)}, yw] + 
     2*G[{yu^(-1)}, yw]*G[{0, 0, 1/(yu*yv)}, yw] + 
     2*G[{yu}, yv^(-1)]*G[{0, 0, 1/(yu*yv)}, yw] - 2*G[{1/(yu*yv)}, yw]*
      G[{0, 0, 1/(yu*yv)}, yw] + 2*G[{0}, yu^(-1)]*G[{0, 1, 1}, yu^(-1)] + 
     2*G[{0}, yv^(-1)]*G[{0, 1, 1}, yu^(-1)] - 
     2*G[{0}, yw]*G[{0, 1, 1}, yu^(-1)] + 2*G[{1}, yu^(-1)]*
      G[{0, 1, 1}, yu^(-1)] - 2*G[{yu^(-1)}, yw]*G[{0, 1, 1}, yu^(-1)] - 
     2*G[{yu}, yv^(-1)]*G[{0, 1, 1}, yu^(-1)] + 2*G[{1/(yu*yv)}, yw]*
      G[{0, 1, 1}, yu^(-1)] - 2*G[{1}, yu^(-1)]*G[{0, 1, 1}, yv^(-1)] - 
     2*G[{yu^(-1)}, yw]*G[{0, 1, 1}, yv^(-1)] - 2*G[{yu}, yv^(-1)]*
      G[{0, 1, 1}, yv^(-1)] + 2*G[{1/(yu*yv)}, yw]*G[{0, 1, 1}, yv^(-1)] - 
     2*G[{0}, yu^(-1)]*G[{0, 1, 1}, yw] - 2*G[{0}, yv^(-1)]*
      G[{0, 1, 1}, yw] + 2*G[{0}, yw]*G[{0, 1, 1}, yw] + 
     2*G[{1}, yu^(-1)]*G[{0, 1, 1}, yw] + 2*G[{1}, yv^(-1)]*
      G[{0, 1, 1}, yw] + 2*G[{yu^(-1)}, yw]*G[{0, 1, 1}, yw] - 
     2*G[{1/(yu*yv)}, yw]*G[{0, 1, 1}, yw] - 2*G[{1}, yu^(-1)]*
      G[{0, 1, yu^(-1)}, yw] + 2*G[{yu}, yv^(-1)]*G[{0, 1, yu^(-1)}, yw] - 
     2*G[{0}, yu^(-1)]*G[{0, 1, yu}, yv^(-1)] - 2*G[{0}, yv^(-1)]*
      G[{0, 1, yu}, yv^(-1)] + 2*G[{0}, yw]*G[{0, 1, yu}, yv^(-1)] + 
     2*G[{1}, yu^(-1)]*G[{0, 1, yu}, yv^(-1)] + 2*G[{0}, yu^(-1)]*
      G[{0, 1, yv^(-1)}, yw] + 2*G[{0}, yv^(-1)]*G[{0, 1, yv^(-1)}, yw] - 
     2*G[{0}, yw]*G[{0, 1, yv^(-1)}, yw] - 4*G[{1}, yu^(-1)]*
      G[{0, 1, yv^(-1)}, yw] - 2*G[{1}, yv^(-1)]*G[{0, 1, yv^(-1)}, yw] + 
     2*G[{yu}, yv^(-1)]*G[{0, 1, yv^(-1)}, yw] + 2*G[{1}, yu^(-1)]*
      G[{0, 1, 1/(yu*yv)}, yw] - 2*G[{yu}, yv^(-1)]*G[{0, 1, 1/(yu*yv)}, 
       yw] + 2*G[{0}, yu^(-1)]*G[{0, yu^(-1), yu^(-1)}, yw] + 
     2*G[{0}, yv^(-1)]*G[{0, yu^(-1), yu^(-1)}, yw] - 
     2*G[{0}, yw]*G[{0, yu^(-1), yu^(-1)}, yw] - 2*G[{1}, yv^(-1)]*
      G[{0, yu^(-1), yu^(-1)}, yw] - 2*G[{yu^(-1)}, yw]*
      G[{0, yu^(-1), yu^(-1)}, yw] - 2*G[{yu}, yv^(-1)]*
      G[{0, yu^(-1), yu^(-1)}, yw] + 2*G[{1/(yu*yv)}, yw]*
      G[{0, yu^(-1), yu^(-1)}, yw] - 2*G[{0}, yu^(-1)]*
      G[{0, yu^(-1), 1/(yu*yv)}, yw] - 2*G[{0}, yv^(-1)]*
      G[{0, yu^(-1), 1/(yu*yv)}, yw] + 2*G[{0}, yw]*
      G[{0, yu^(-1), 1/(yu*yv)}, yw] + 2*G[{1}, yu^(-1)]*
      G[{0, yu^(-1), 1/(yu*yv)}, yw] + 2*G[{1}, yv^(-1)]*
      G[{0, yu^(-1), 1/(yu*yv)}, yw] + 2*G[{0}, yu^(-1)]*
      G[{0, yu, yu}, yv^(-1)] + 2*G[{0}, yv^(-1)]*G[{0, yu, yu}, yv^(-1)] - 
     2*G[{0}, yw]*G[{0, yu, yu}, yv^(-1)] + 2*G[{yu^(-1)}, yw]*
      G[{0, yu, yu}, yv^(-1)] + 2*G[{yu}, yv^(-1)]*G[{0, yu, yu}, yv^(-1)] - 
     2*G[{1/(yu*yv)}, yw]*G[{0, yu, yu}, yv^(-1)] + 
     2*G[{0}, yu^(-1)]*G[{0, yv^(-1), 1}, yw] + 2*G[{0}, yv^(-1)]*
      G[{0, yv^(-1), 1}, yw] - 2*G[{0}, yw]*G[{0, yv^(-1), 1}, yw] - 
     2*G[{1}, yu^(-1)]*G[{0, yv^(-1), 1}, yw] - 2*G[{1}, yv^(-1)]*
      G[{0, yv^(-1), 1}, yw] - 2*G[{0}, yu^(-1)]*G[{0, yv^(-1), yv^(-1)}, 
       yw] - 2*G[{0}, yv^(-1)]*G[{0, yv^(-1), yv^(-1)}, yw] + 
     2*G[{0}, yw]*G[{0, yv^(-1), yv^(-1)}, yw] + 4*G[{1}, yu^(-1)]*
      G[{0, yv^(-1), yv^(-1)}, yw] + 2*G[{1}, yv^(-1)]*
      G[{0, yv^(-1), yv^(-1)}, yw] - 2*G[{yu^(-1)}, yw]*
      G[{0, yv^(-1), yv^(-1)}, yw] - 2*G[{yu}, yv^(-1)]*
      G[{0, yv^(-1), yv^(-1)}, yw] + 2*G[{1/(yu*yv)}, yw]*
      G[{0, yv^(-1), yv^(-1)}, yw] - 2*G[{yu^(-1)}, yw]*
      G[{0, 1/(yu*yv), 1}, yw] + 2*G[{1/(yu*yv)}, yw]*
      G[{0, 1/(yu*yv), 1}, yw] - 2*G[{0}, yu^(-1)]*G[{0, 1/(yu*yv), yu^(-1)}, 
       yw] - 2*G[{0}, yv^(-1)]*G[{0, 1/(yu*yv), yu^(-1)}, yw] + 
     2*G[{0}, yw]*G[{0, 1/(yu*yv), yu^(-1)}, yw] + 
     2*G[{1}, yu^(-1)]*G[{0, 1/(yu*yv), yu^(-1)}, yw] + 
     2*G[{1}, yv^(-1)]*G[{0, 1/(yu*yv), yu^(-1)}, yw] + 
     2*G[{yu^(-1)}, yw]*G[{0, 1/(yu*yv), yu^(-1)}, yw] - 
     2*G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv), yu^(-1)}, yw] + 
     2*G[{yu^(-1)}, yw]*G[{0, 1/(yu*yv), yv^(-1)}, yw] - 
     2*G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv), yv^(-1)}, yw] + 
     2*G[{0}, yu^(-1)]*G[{0, 1/(yu*yv), 1/(yu*yv)}, yw] + 
     2*G[{0}, yv^(-1)]*G[{0, 1/(yu*yv), 1/(yu*yv)}, yw] - 
     2*G[{0}, yw]*G[{0, 1/(yu*yv), 1/(yu*yv)}, yw] - 
     4*G[{1}, yu^(-1)]*G[{0, 1/(yu*yv), 1/(yu*yv)}, yw] - 
     2*G[{1}, yv^(-1)]*G[{0, 1/(yu*yv), 1/(yu*yv)}, yw] + 
     2*G[{yu}, yv^(-1)]*G[{0, 1/(yu*yv), 1/(yu*yv)}, yw] - 
     2*G[{0, 0, 1, 1}, yu^(-1)] + 2*G[{0, 0, 1, 1}, yv^(-1)] - 
     2*G[{0, 0, 1, 1}, yw] + 2*G[{0, 0, 1, yu^(-1)}, yw] - 
     2*G[{0, 0, 1, yu}, yv^(-1)] + 2*G[{0, 0, 1, yv^(-1)}, yw] - 
     2*G[{0, 0, 1, 1/(yu*yv)}, yw] + 2*G[{0, 0, yu^(-1), 1}, yw] + 
     2*G[{0, 0, yu^(-1), yu^(-1)}, yw] + 2*G[{0, 0, yu^(-1), yv^(-1)}, yw] - 
     2*G[{0, 0, yu^(-1), 1/(yu*yv)}, yw] - 2*G[{0, 0, yu, 1}, yv^(-1)] - 
     2*G[{0, 0, yu, yu}, yv^(-1)] + 2*G[{0, 0, yv^(-1), 1}, yw] + 
     2*G[{0, 0, yv^(-1), yu^(-1)}, yw] - 2*G[{0, 0, yv^(-1), yv^(-1)}, yw] + 
     2*G[{0, 0, yv^(-1), 1/(yu*yv)}, yw] - 2*G[{0, 0, 1/(yu*yv), 1}, yw] - 
     2*G[{0, 0, 1/(yu*yv), yu^(-1)}, yw] + 
     2*G[{0, 0, 1/(yu*yv), yv^(-1)}, yw] + 
     2*G[{0, 0, 1/(yu*yv), 1/(yu*yv)}, yw] + 2*G[{0, 1, 0, yu^(-1)}, yw] - 
     2*G[{0, 1, 0, yu}, yv^(-1)] - 2*G[{0, 1, 0, 1/(yu*yv)}, yw] - 
     6*G[{0, 1, 1, 1}, yu^(-1)] - 4*G[{0, 1, 1, yu^(-1)}, yw] + 
     4*G[{0, 1, 1, yu}, yv^(-1)] - 2*G[{0, 1, 1, yv^(-1)}, yw] + 
     2*G[{0, 1, 1, 1/(yu*yv)}, yw] - 2*G[{0, 1, yu^(-1), 1}, yw] + 
     2*G[{0, 1, yu^(-1), yv^(-1)}, yw] + 2*G[{0, 1, yu, 1}, yv^(-1)] - 
     2*G[{0, 1, yv^(-1), 1}, yw] + 2*G[{0, 1, yv^(-1), yu^(-1)}, yw] + 
     4*G[{0, 1, yv^(-1), yv^(-1)}, yw] + 2*G[{0, 1, 1/(yu*yv), 1}, yw] - 
     2*G[{0, 1, 1/(yu*yv), yv^(-1)}, yw] + 
     2*G[{0, yu^(-1), 0, yv^(-1)}, yw] + 2*G[{0, yu^(-1), yu^(-1), 1}, yw] + 
     4*G[{0, yu^(-1), yu^(-1), yu^(-1)}, yw] - 
     2*G[{0, yu^(-1), yu^(-1), 1/(yu*yv)}, yw] - 
     2*G[{0, yu^(-1), 1/(yu*yv), yu^(-1)}, yw] - 
     2*G[{0, yu^(-1), 1/(yu*yv), yv^(-1)}, yw] - 
     2*G[{0, yu, yu, 1}, yv^(-1)] - 4*G[{0, yu, yu, yu}, yv^(-1)] + 
     2*G[{0, yv^(-1), 0, 1/(yu*yv)}, yw] + 
     2*G[{0, yv^(-1), 1, yu^(-1)}, yw] + 2*G[{0, yv^(-1), 1, yv^(-1)}, yw] + 
     2*G[{0, yv^(-1), yv^(-1), 1}, yw] - 4*G[{0, yv^(-1), yv^(-1), yv^(-1)}, 
       yw] - 2*G[{0, yv^(-1), yv^(-1), 1/(yu*yv)}, yw] + 
     2*G[{0, 1/(yu*yv), 1, yu^(-1)}, yw] - 
     2*G[{0, 1/(yu*yv), 1, 1/(yu*yv)}, yw] - 
     4*G[{0, 1/(yu*yv), yu^(-1), yu^(-1)}, yw] - 
     2*G[{0, 1/(yu*yv), yu^(-1), yv^(-1)}, yw] + 
     2*G[{0, 1/(yu*yv), yu^(-1), 1/(yu*yv)}, yw] - 
     2*G[{0, 1/(yu*yv), yv^(-1), yu^(-1)}, yw] + 
     2*G[{0, 1/(yu*yv), yv^(-1), 1/(yu*yv)}, yw] - 
     2*G[{0, 1/(yu*yv), 1/(yu*yv), 1}, yw] + 
     2*G[{0, 1/(yu*yv), 1/(yu*yv), yu^(-1)}, yw] + 
     4*G[{0, 1/(yu*yv), 1/(yu*yv), yv^(-1)}, yw] - 
     2*G[{0}, yu^(-1)]*Zeta[3] - 2*G[{0}, yv^(-1)]*Zeta[3] + 
     2*G[{0}, yw]*Zeta[3] - 2*G[{1}, yu^(-1)]*Zeta[3] + 
     2*G[{yu^(-1)}, yw]*Zeta[3] + 2*G[{yu}, yv^(-1)]*Zeta[3] - 
     2*G[{1/(yu*yv)}, yw]*Zeta[3]
 
F1vwuRegII = (-17*Pi^4)/360 - (Pi^2*G[{0}, yu^(-1)]*G[{1}, yv^(-1)])/6 - 
     (Pi^2*G[{0}, yv^(-1)]*G[{1}, yv^(-1)])/6 + 
     (Pi^2*G[{0}, yw]*G[{1}, yv^(-1)])/6 + 
     (Pi^2*G[{0}, yu^(-1)]*G[{yu}, yv^(-1)])/6 + 
     (Pi^2*G[{0}, yv^(-1)]*G[{yu}, yv^(-1)])/6 - 
     (Pi^2*G[{0}, yw]*G[{yu}, yv^(-1)])/6 + 
     (Pi^2*G[{0}, yu^(-1)]*G[{yv^(-1)}, yw])/6 + 
     (Pi^2*G[{0}, yv^(-1)]*G[{yv^(-1)}, yw])/6 - 
     (Pi^2*G[{0}, yw]*G[{yv^(-1)}, yw])/6 - 
     (Pi^2*G[{0}, yu^(-1)]*G[{1/(yu*yv)}, yw])/6 - 
     (Pi^2*G[{0}, yv^(-1)]*G[{1/(yu*yv)}, yw])/6 + 
     (Pi^2*G[{0}, yw]*G[{1/(yu*yv)}, yw])/6 - (Pi^2*G[{0, 1}, yu^(-1)])/6 - 
     G[{0}, yu^(-1)]*G[{1}, yv^(-1)]*G[{0, 1}, yu^(-1)] - 
     G[{0}, yv^(-1)]*G[{1}, yv^(-1)]*G[{0, 1}, yu^(-1)] + 
     G[{0}, yw]*G[{1}, yv^(-1)]*G[{0, 1}, yu^(-1)] + 
     G[{0}, yu^(-1)]*G[{yu}, yv^(-1)]*G[{0, 1}, yu^(-1)] + 
     G[{0}, yv^(-1)]*G[{yu}, yv^(-1)]*G[{0, 1}, yu^(-1)] - 
     G[{0}, yw]*G[{yu}, yv^(-1)]*G[{0, 1}, yu^(-1)] + 
     G[{0}, yu^(-1)]*G[{yv^(-1)}, yw]*G[{0, 1}, yu^(-1)] + 
     G[{0}, yv^(-1)]*G[{yv^(-1)}, yw]*G[{0, 1}, yu^(-1)] - 
     G[{0}, yw]*G[{yv^(-1)}, yw]*G[{0, 1}, yu^(-1)] - 
     G[{0}, yu^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, 1}, yu^(-1)] - 
     G[{0}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, 1}, yu^(-1)] + 
     G[{0}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1}, yu^(-1)] + 
     G[{0, 1}, yu^(-1)]^2/2 + (Pi^2*G[{0, 1}, yv^(-1)])/6 - 
     G[{0}, yu^(-1)]*G[{1}, yv^(-1)]*G[{0, 1}, yv^(-1)] - 
     G[{0}, yv^(-1)]*G[{1}, yv^(-1)]*G[{0, 1}, yv^(-1)] + 
     G[{0}, yw]*G[{1}, yv^(-1)]*G[{0, 1}, yv^(-1)] + 
     G[{0}, yu^(-1)]*G[{yu}, yv^(-1)]*G[{0, 1}, yv^(-1)] + 
     G[{0}, yv^(-1)]*G[{yu}, yv^(-1)]*G[{0, 1}, yv^(-1)] - 
     G[{0}, yw]*G[{yu}, yv^(-1)]*G[{0, 1}, yv^(-1)] + 
     G[{0}, yu^(-1)]*G[{yv^(-1)}, yw]*G[{0, 1}, yv^(-1)] + 
     G[{0}, yv^(-1)]*G[{yv^(-1)}, yw]*G[{0, 1}, yv^(-1)] - 
     G[{0}, yw]*G[{yv^(-1)}, yw]*G[{0, 1}, yv^(-1)] - 
     G[{0}, yu^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, 1}, yv^(-1)] - 
     G[{0}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, 1}, yv^(-1)] + 
     G[{0}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1}, yv^(-1)] - 
     G[{0, 1}, yu^(-1)]*G[{0, 1}, yv^(-1)] + G[{0, 1}, yv^(-1)]^2/2 + 
     (Pi^2*G[{0, 1}, yw])/6 - G[{0}, yu^(-1)]*G[{1}, yv^(-1)]*G[{0, 1}, yw] - 
     G[{0}, yv^(-1)]*G[{1}, yv^(-1)]*G[{0, 1}, yw] + 
     G[{0}, yw]*G[{1}, yv^(-1)]*G[{0, 1}, yw] + G[{1}, yv^(-1)]^2*
      G[{0, 1}, yw] + G[{0}, yu^(-1)]*G[{yu}, yv^(-1)]*G[{0, 1}, yw] + 
     G[{0}, yv^(-1)]*G[{yu}, yv^(-1)]*G[{0, 1}, yw] - 
     G[{0}, yw]*G[{yu}, yv^(-1)]*G[{0, 1}, yw] - 2*G[{1}, yv^(-1)]*
      G[{yu}, yv^(-1)]*G[{0, 1}, yw] + G[{0}, yu^(-1)]*G[{yv^(-1)}, yw]*
      G[{0, 1}, yw] + G[{0}, yv^(-1)]*G[{yv^(-1)}, yw]*G[{0, 1}, yw] - 
     G[{0}, yw]*G[{yv^(-1)}, yw]*G[{0, 1}, yw] - 2*G[{yu}, yv^(-1)]*
      G[{yv^(-1)}, yw]*G[{0, 1}, yw] - G[{0}, yu^(-1)]*G[{1/(yu*yv)}, yw]*
      G[{0, 1}, yw] - G[{0}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, 1}, yw] + 
     G[{0}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1}, yw] + 
     2*G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, 1}, yw] - 
     G[{0, 1}, yu^(-1)]*G[{0, 1}, yw] + G[{0, 1}, yv^(-1)]*G[{0, 1}, yw] - 
     G[{0, 1}, yw]^2/2 - (Pi^2*G[{0, yu^(-1)}, yw])/6 + 
     G[{0}, yu^(-1)]*G[{1}, yv^(-1)]*G[{0, yu^(-1)}, yw] + 
     G[{0}, yv^(-1)]*G[{1}, yv^(-1)]*G[{0, yu^(-1)}, yw] - 
     G[{0}, yw]*G[{1}, yv^(-1)]*G[{0, yu^(-1)}, yw] - 
     G[{1}, yv^(-1)]^2*G[{0, yu^(-1)}, yw] - G[{0}, yu^(-1)]*G[{yu}, yv^(-1)]*
      G[{0, yu^(-1)}, yw] - G[{0}, yv^(-1)]*G[{yu}, yv^(-1)]*
      G[{0, yu^(-1)}, yw] + G[{0}, yw]*G[{yu}, yv^(-1)]*G[{0, yu^(-1)}, yw] + 
     2*G[{1}, yv^(-1)]*G[{yu}, yv^(-1)]*G[{0, yu^(-1)}, yw] - 
     G[{0}, yu^(-1)]*G[{yv^(-1)}, yw]*G[{0, yu^(-1)}, yw] - 
     G[{0}, yv^(-1)]*G[{yv^(-1)}, yw]*G[{0, yu^(-1)}, yw] + 
     G[{0}, yw]*G[{yv^(-1)}, yw]*G[{0, yu^(-1)}, yw] + 
     2*G[{1}, yv^(-1)]*G[{yv^(-1)}, yw]*G[{0, yu^(-1)}, yw] + 
     G[{0}, yu^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1)}, yw] + 
     G[{0}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1)}, yw] - 
     G[{0}, yw]*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1)}, yw] - 
     2*G[{1}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1)}, yw] + 
     G[{0, 1}, yu^(-1)]*G[{0, yu^(-1)}, yw] - G[{0, 1}, yv^(-1)]*
      G[{0, yu^(-1)}, yw] + G[{0, 1}, yw]*G[{0, yu^(-1)}, yw] - 
     G[{0, yu^(-1)}, yw]^2/2 - (Pi^2*G[{0, yu}, yv^(-1)])/6 + 
     G[{0}, yu^(-1)]*G[{1}, yv^(-1)]*G[{0, yu}, yv^(-1)] + 
     G[{0}, yv^(-1)]*G[{1}, yv^(-1)]*G[{0, yu}, yv^(-1)] - 
     G[{0}, yw]*G[{1}, yv^(-1)]*G[{0, yu}, yv^(-1)] - 
     G[{0}, yu^(-1)]*G[{yu}, yv^(-1)]*G[{0, yu}, yv^(-1)] - 
     G[{0}, yv^(-1)]*G[{yu}, yv^(-1)]*G[{0, yu}, yv^(-1)] + 
     G[{0}, yw]*G[{yu}, yv^(-1)]*G[{0, yu}, yv^(-1)] - 
     G[{0}, yu^(-1)]*G[{yv^(-1)}, yw]*G[{0, yu}, yv^(-1)] - 
     G[{0}, yv^(-1)]*G[{yv^(-1)}, yw]*G[{0, yu}, yv^(-1)] + 
     G[{0}, yw]*G[{yv^(-1)}, yw]*G[{0, yu}, yv^(-1)] + 
     G[{0}, yu^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, yu}, yv^(-1)] + 
     G[{0}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, yu}, yv^(-1)] - 
     G[{0}, yw]*G[{1/(yu*yv)}, yw]*G[{0, yu}, yv^(-1)] + 
     G[{0, 1}, yu^(-1)]*G[{0, yu}, yv^(-1)] - G[{0, 1}, yv^(-1)]*
      G[{0, yu}, yv^(-1)] - G[{0, 1}, yw]*G[{0, yu}, yv^(-1)] + 
     G[{0, yu^(-1)}, yw]*G[{0, yu}, yv^(-1)] + G[{0, yu}, yv^(-1)]^2/2 + 
     (Pi^2*G[{0, yv^(-1)}, yw])/6 + G[{0}, yu^(-1)]*G[{1}, yv^(-1)]*
      G[{0, yv^(-1)}, yw] + G[{0}, yv^(-1)]*G[{1}, yv^(-1)]*
      G[{0, yv^(-1)}, yw] - G[{0}, yw]*G[{1}, yv^(-1)]*G[{0, yv^(-1)}, yw] - 
     2*G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*G[{0, yv^(-1)}, yw] - 
     G[{1}, yv^(-1)]^2*G[{0, yv^(-1)}, yw] - G[{0}, yu^(-1)]*G[{yu}, yv^(-1)]*
      G[{0, yv^(-1)}, yw] - G[{0}, yv^(-1)]*G[{yu}, yv^(-1)]*
      G[{0, yv^(-1)}, yw] + G[{0}, yw]*G[{yu}, yv^(-1)]*G[{0, yv^(-1)}, yw] + 
     2*G[{1}, yu^(-1)]*G[{yu}, yv^(-1)]*G[{0, yv^(-1)}, yw] - 
     G[{0}, yu^(-1)]*G[{yv^(-1)}, yw]*G[{0, yv^(-1)}, yw] - 
     G[{0}, yv^(-1)]*G[{yv^(-1)}, yw]*G[{0, yv^(-1)}, yw] + 
     G[{0}, yw]*G[{yv^(-1)}, yw]*G[{0, yv^(-1)}, yw] + 
     2*G[{1}, yu^(-1)]*G[{yv^(-1)}, yw]*G[{0, yv^(-1)}, yw] + 
     G[{0}, yu^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, yv^(-1)}, yw] + 
     G[{0}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, yv^(-1)}, yw] - 
     G[{0}, yw]*G[{1/(yu*yv)}, yw]*G[{0, yv^(-1)}, yw] - 
     2*G[{1}, yu^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, yv^(-1)}, yw] - 
     G[{0, 1}, yu^(-1)]*G[{0, yv^(-1)}, yw] + G[{0, 1}, yv^(-1)]*
      G[{0, yv^(-1)}, yw] - G[{0, 1}, yw]*G[{0, yv^(-1)}, yw] + 
     G[{0, yu^(-1)}, yw]*G[{0, yv^(-1)}, yw] - G[{0, yu}, yv^(-1)]*
      G[{0, yv^(-1)}, yw] + G[{0, yv^(-1)}, yw]^2/2 - 
     (Pi^2*G[{0, 1/(yu*yv)}, yw])/6 - G[{0}, yu^(-1)]*G[{1}, yv^(-1)]*
      G[{0, 1/(yu*yv)}, yw] - G[{0}, yv^(-1)]*G[{1}, yv^(-1)]*
      G[{0, 1/(yu*yv)}, yw] + G[{0}, yw]*G[{1}, yv^(-1)]*
      G[{0, 1/(yu*yv)}, yw] + 2*G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*
      G[{0, 1/(yu*yv)}, yw] + G[{1}, yv^(-1)]^2*G[{0, 1/(yu*yv)}, yw] + 
     G[{0}, yu^(-1)]*G[{yu}, yv^(-1)]*G[{0, 1/(yu*yv)}, yw] + 
     G[{0}, yv^(-1)]*G[{yu}, yv^(-1)]*G[{0, 1/(yu*yv)}, yw] - 
     G[{0}, yw]*G[{yu}, yv^(-1)]*G[{0, 1/(yu*yv)}, yw] - 
     2*G[{1}, yu^(-1)]*G[{yu}, yv^(-1)]*G[{0, 1/(yu*yv)}, yw] + 
     G[{0}, yu^(-1)]*G[{yv^(-1)}, yw]*G[{0, 1/(yu*yv)}, yw] + 
     G[{0}, yv^(-1)]*G[{yv^(-1)}, yw]*G[{0, 1/(yu*yv)}, yw] - 
     G[{0}, yw]*G[{yv^(-1)}, yw]*G[{0, 1/(yu*yv)}, yw] - 
     2*G[{1}, yu^(-1)]*G[{yv^(-1)}, yw]*G[{0, 1/(yu*yv)}, yw] - 
     2*G[{1}, yv^(-1)]*G[{yv^(-1)}, yw]*G[{0, 1/(yu*yv)}, yw] + 
     2*G[{yu}, yv^(-1)]*G[{yv^(-1)}, yw]*G[{0, 1/(yu*yv)}, yw] - 
     G[{0}, yu^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv)}, yw] - 
     G[{0}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv)}, yw] + 
     G[{0}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv)}, yw] + 
     2*G[{1}, yu^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv)}, yw] + 
     2*G[{1}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv)}, yw] - 
     2*G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv)}, yw] + 
     G[{0, 1}, yu^(-1)]*G[{0, 1/(yu*yv)}, yw] - G[{0, 1}, yv^(-1)]*
      G[{0, 1/(yu*yv)}, yw] + G[{0, 1}, yw]*G[{0, 1/(yu*yv)}, yw] - 
     G[{0, yu^(-1)}, yw]*G[{0, 1/(yu*yv)}, yw] + G[{0, yu}, yv^(-1)]*
      G[{0, 1/(yu*yv)}, yw] - G[{0, yv^(-1)}, yw]*G[{0, 1/(yu*yv)}, yw] + 
     G[{0, 1/(yu*yv)}, yw]^2/2 + 2*G[{0, 1}, yw]*G[{1, yu}, yv^(-1)] - 
     2*G[{0, yu^(-1)}, yw]*G[{1, yu}, yv^(-1)] + 2*G[{0, yv^(-1)}, yw]*
      G[{1, yu}, yv^(-1)] - 2*G[{0, 1/(yu*yv)}, yw]*G[{1, yu}, yv^(-1)] - 
     2*G[{0}, yu^(-1)]*G[{0, 0, 1}, yu^(-1)] - 2*G[{0}, yv^(-1)]*
      G[{0, 0, 1}, yu^(-1)] + 2*G[{0}, yw]*G[{0, 0, 1}, yu^(-1)] - 
     2*G[{1}, yv^(-1)]*G[{0, 0, 1}, yw] + 2*G[{yu}, yv^(-1)]*
      G[{0, 0, 1}, yw] + 2*G[{yv^(-1)}, yw]*G[{0, 0, 1}, yw] - 
     2*G[{1/(yu*yv)}, yw]*G[{0, 0, 1}, yw] + 2*G[{1}, yv^(-1)]*
      G[{0, 0, yu^(-1)}, yw] - 2*G[{yu}, yv^(-1)]*G[{0, 0, yu^(-1)}, yw] - 
     2*G[{yv^(-1)}, yw]*G[{0, 0, yu^(-1)}, yw] + 2*G[{1/(yu*yv)}, yw]*
      G[{0, 0, yu^(-1)}, yw] + 2*G[{1}, yv^(-1)]*G[{0, 0, yv^(-1)}, yw] - 
     2*G[{yu}, yv^(-1)]*G[{0, 0, yv^(-1)}, yw] - 2*G[{yv^(-1)}, yw]*
      G[{0, 0, yv^(-1)}, yw] + 2*G[{1/(yu*yv)}, yw]*G[{0, 0, yv^(-1)}, yw] - 
     2*G[{1}, yv^(-1)]*G[{0, 0, 1/(yu*yv)}, yw] + 2*G[{yu}, yv^(-1)]*
      G[{0, 0, 1/(yu*yv)}, yw] + 2*G[{yv^(-1)}, yw]*G[{0, 0, 1/(yu*yv)}, 
       yw] - 2*G[{1/(yu*yv)}, yw]*G[{0, 0, 1/(yu*yv)}, yw] + 
     2*G[{1}, yv^(-1)]*G[{0, 1, 1}, yu^(-1)] - 2*G[{yu}, yv^(-1)]*
      G[{0, 1, 1}, yu^(-1)] - 2*G[{yv^(-1)}, yw]*G[{0, 1, 1}, yu^(-1)] + 
     2*G[{1/(yu*yv)}, yw]*G[{0, 1, 1}, yu^(-1)] + 
     2*G[{0}, yu^(-1)]*G[{0, 1, 1}, yv^(-1)] + 2*G[{0}, yv^(-1)]*
      G[{0, 1, 1}, yv^(-1)] - 2*G[{0}, yw]*G[{0, 1, 1}, yv^(-1)] - 
     2*G[{1}, yu^(-1)]*G[{0, 1, 1}, yv^(-1)] + 2*G[{1}, yv^(-1)]*
      G[{0, 1, 1}, yv^(-1)] - 2*G[{yu}, yv^(-1)]*G[{0, 1, 1}, yv^(-1)] - 
     2*G[{yv^(-1)}, yw]*G[{0, 1, 1}, yv^(-1)] + 2*G[{1/(yu*yv)}, yw]*
      G[{0, 1, 1}, yv^(-1)] - 2*G[{0}, yu^(-1)]*G[{0, 1, 1}, yw] - 
     2*G[{0}, yv^(-1)]*G[{0, 1, 1}, yw] + 2*G[{0}, yw]*G[{0, 1, 1}, yw] + 
     2*G[{1}, yu^(-1)]*G[{0, 1, 1}, yw] + 2*G[{1}, yv^(-1)]*
      G[{0, 1, 1}, yw] + 2*G[{yv^(-1)}, yw]*G[{0, 1, 1}, yw] - 
     2*G[{1/(yu*yv)}, yw]*G[{0, 1, 1}, yw] + 2*G[{0}, yu^(-1)]*
      G[{0, 1, yu^(-1)}, yw] + 2*G[{0}, yv^(-1)]*G[{0, 1, yu^(-1)}, yw] - 
     2*G[{0}, yw]*G[{0, 1, yu^(-1)}, yw] - 2*G[{1}, yu^(-1)]*
      G[{0, 1, yu^(-1)}, yw] - 4*G[{1}, yv^(-1)]*G[{0, 1, yu^(-1)}, yw] + 
     2*G[{yu}, yv^(-1)]*G[{0, 1, yu^(-1)}, yw] - 2*G[{0}, yu^(-1)]*
      G[{0, 1, yu}, yv^(-1)] - 2*G[{0}, yv^(-1)]*G[{0, 1, yu}, yv^(-1)] + 
     2*G[{0}, yw]*G[{0, 1, yu}, yv^(-1)] + 2*G[{1}, yu^(-1)]*
      G[{0, 1, yu}, yv^(-1)] - 2*G[{1}, yv^(-1)]*G[{0, 1, yv^(-1)}, yw] + 
     2*G[{yu}, yv^(-1)]*G[{0, 1, yv^(-1)}, yw] + 2*G[{1}, yv^(-1)]*
      G[{0, 1, 1/(yu*yv)}, yw] - 2*G[{yu}, yv^(-1)]*G[{0, 1, 1/(yu*yv)}, 
       yw] + 2*G[{0}, yu^(-1)]*G[{0, yu^(-1), 1}, yw] + 
     2*G[{0}, yv^(-1)]*G[{0, yu^(-1), 1}, yw] - 
     2*G[{0}, yw]*G[{0, yu^(-1), 1}, yw] - 2*G[{1}, yu^(-1)]*
      G[{0, yu^(-1), 1}, yw] - 2*G[{1}, yv^(-1)]*G[{0, yu^(-1), 1}, yw] - 
     2*G[{0}, yu^(-1)]*G[{0, yu^(-1), yu^(-1)}, yw] - 
     2*G[{0}, yv^(-1)]*G[{0, yu^(-1), yu^(-1)}, yw] + 
     2*G[{0}, yw]*G[{0, yu^(-1), yu^(-1)}, yw] + 2*G[{1}, yu^(-1)]*
      G[{0, yu^(-1), yu^(-1)}, yw] + 4*G[{1}, yv^(-1)]*
      G[{0, yu^(-1), yu^(-1)}, yw] - 2*G[{yu}, yv^(-1)]*
      G[{0, yu^(-1), yu^(-1)}, yw] - 2*G[{yv^(-1)}, yw]*
      G[{0, yu^(-1), yu^(-1)}, yw] + 2*G[{1/(yu*yv)}, yw]*
      G[{0, yu^(-1), yu^(-1)}, yw] - 2*G[{0}, yu^(-1)]*
      G[{0, yu, 1}, yv^(-1)] - 2*G[{0}, yv^(-1)]*G[{0, yu, 1}, yv^(-1)] + 
     2*G[{0}, yw]*G[{0, yu, 1}, yv^(-1)] + 2*G[{1}, yu^(-1)]*
      G[{0, yu, 1}, yv^(-1)] + 2*G[{0}, yu^(-1)]*G[{0, yu, yu}, yv^(-1)] + 
     2*G[{0}, yv^(-1)]*G[{0, yu, yu}, yv^(-1)] - 
     2*G[{0}, yw]*G[{0, yu, yu}, yv^(-1)] - 2*G[{1}, yu^(-1)]*
      G[{0, yu, yu}, yv^(-1)] - 2*G[{1}, yv^(-1)]*G[{0, yu, yu}, yv^(-1)] + 
     2*G[{yu}, yv^(-1)]*G[{0, yu, yu}, yv^(-1)] + 2*G[{yv^(-1)}, yw]*
      G[{0, yu, yu}, yv^(-1)] - 2*G[{1/(yu*yv)}, yw]*
      G[{0, yu, yu}, yv^(-1)] + 2*G[{0}, yu^(-1)]*G[{0, yv^(-1), yv^(-1)}, 
       yw] + 2*G[{0}, yv^(-1)]*G[{0, yv^(-1), yv^(-1)}, yw] - 
     2*G[{0}, yw]*G[{0, yv^(-1), yv^(-1)}, yw] - 2*G[{1}, yu^(-1)]*
      G[{0, yv^(-1), yv^(-1)}, yw] - 2*G[{yu}, yv^(-1)]*
      G[{0, yv^(-1), yv^(-1)}, yw] - 2*G[{yv^(-1)}, yw]*
      G[{0, yv^(-1), yv^(-1)}, yw] + 2*G[{1/(yu*yv)}, yw]*
      G[{0, yv^(-1), yv^(-1)}, yw] - 2*G[{0}, yu^(-1)]*
      G[{0, yv^(-1), 1/(yu*yv)}, yw] - 2*G[{0}, yv^(-1)]*
      G[{0, yv^(-1), 1/(yu*yv)}, yw] + 2*G[{0}, yw]*
      G[{0, yv^(-1), 1/(yu*yv)}, yw] + 2*G[{1}, yu^(-1)]*
      G[{0, yv^(-1), 1/(yu*yv)}, yw] + 2*G[{1}, yv^(-1)]*
      G[{0, yv^(-1), 1/(yu*yv)}, yw] - 2*G[{yv^(-1)}, yw]*
      G[{0, 1/(yu*yv), 1}, yw] + 2*G[{1/(yu*yv)}, yw]*
      G[{0, 1/(yu*yv), 1}, yw] + 2*G[{yv^(-1)}, yw]*
      G[{0, 1/(yu*yv), yu^(-1)}, yw] - 2*G[{1/(yu*yv)}, yw]*
      G[{0, 1/(yu*yv), yu^(-1)}, yw] - 2*G[{0}, yu^(-1)]*
      G[{0, 1/(yu*yv), yv^(-1)}, yw] - 2*G[{0}, yv^(-1)]*
      G[{0, 1/(yu*yv), yv^(-1)}, yw] + 2*G[{0}, yw]*
      G[{0, 1/(yu*yv), yv^(-1)}, yw] + 2*G[{1}, yu^(-1)]*
      G[{0, 1/(yu*yv), yv^(-1)}, yw] + 2*G[{1}, yv^(-1)]*
      G[{0, 1/(yu*yv), yv^(-1)}, yw] + 2*G[{yv^(-1)}, yw]*
      G[{0, 1/(yu*yv), yv^(-1)}, yw] - 2*G[{1/(yu*yv)}, yw]*
      G[{0, 1/(yu*yv), yv^(-1)}, yw] + 2*G[{0}, yu^(-1)]*
      G[{0, 1/(yu*yv), 1/(yu*yv)}, yw] + 2*G[{0}, yv^(-1)]*
      G[{0, 1/(yu*yv), 1/(yu*yv)}, yw] - 2*G[{0}, yw]*
      G[{0, 1/(yu*yv), 1/(yu*yv)}, yw] - 2*G[{1}, yu^(-1)]*
      G[{0, 1/(yu*yv), 1/(yu*yv)}, yw] - 4*G[{1}, yv^(-1)]*
      G[{0, 1/(yu*yv), 1/(yu*yv)}, yw] + 2*G[{yu}, yv^(-1)]*
      G[{0, 1/(yu*yv), 1/(yu*yv)}, yw] + 2*G[{0, 0, 1, 1}, yu^(-1)] - 
     2*G[{0, 0, 1, 1}, yv^(-1)] - 2*G[{0, 0, 1, 1}, yw] + 
     2*G[{0, 0, 1, yu^(-1)}, yw] + 2*G[{0, 0, 1, yu}, yv^(-1)] + 
     2*G[{0, 0, 1, yv^(-1)}, yw] - 2*G[{0, 0, 1, 1/(yu*yv)}, yw] + 
     2*G[{0, 0, yu^(-1), 1}, yw] - 2*G[{0, 0, yu^(-1), yu^(-1)}, yw] - 
     2*G[{0, 0, yu^(-1), yv^(-1)}, yw] + 2*G[{0, 0, yu^(-1), 1/(yu*yv)}, 
       yw] + 2*G[{0, 0, yu, 1}, yv^(-1)] - 2*G[{0, 0, yu, yu}, yv^(-1)] + 
     2*G[{0, 0, yv^(-1), 1}, yw] - 2*G[{0, 0, yv^(-1), yu^(-1)}, yw] + 
     2*G[{0, 0, yv^(-1), yv^(-1)}, yw] - 2*G[{0, 0, yv^(-1), 1/(yu*yv)}, 
       yw] - 2*G[{0, 0, 1/(yu*yv), 1}, yw] + 
     2*G[{0, 0, 1/(yu*yv), yu^(-1)}, yw] - 
     2*G[{0, 0, 1/(yu*yv), yv^(-1)}, yw] + 
     2*G[{0, 0, 1/(yu*yv), 1/(yu*yv)}, yw] + 2*G[{0, 1, 0, yv^(-1)}, yw] - 
     2*G[{0, 1, 0, 1/(yu*yv)}, yw] - 6*G[{0, 1, 1, 1}, yv^(-1)] - 
     2*G[{0, 1, 1, yu^(-1)}, yw] + 4*G[{0, 1, 1, yu}, yv^(-1)] - 
     4*G[{0, 1, 1, yv^(-1)}, yw] + 2*G[{0, 1, 1, 1/(yu*yv)}, yw] - 
     2*G[{0, 1, yu^(-1), 1}, yw] + 4*G[{0, 1, yu^(-1), yu^(-1)}, yw] + 
     2*G[{0, 1, yu^(-1), yv^(-1)}, yw] + 2*G[{0, 1, yu, 1}, yv^(-1)] - 
     2*G[{0, 1, yv^(-1), 1}, yw] + 2*G[{0, 1, yv^(-1), yu^(-1)}, yw] + 
     2*G[{0, 1, 1/(yu*yv), 1}, yw] - 2*G[{0, 1, 1/(yu*yv), yu^(-1)}, yw] - 
     2*G[{0, yu^(-1), 0, yv^(-1)}, yw] + 2*G[{0, yu^(-1), 0, 1/(yu*yv)}, 
       yw] + 2*G[{0, yu^(-1), 1, yu^(-1)}, yw] + 
     2*G[{0, yu^(-1), 1, yv^(-1)}, yw] + 2*G[{0, yu^(-1), yu^(-1), 1}, yw] - 
     4*G[{0, yu^(-1), yu^(-1), yu^(-1)}, yw] - 
     2*G[{0, yu^(-1), yu^(-1), 1/(yu*yv)}, yw] + 
     2*G[{0, yu, 1, 1}, yv^(-1)] + 2*G[{0, yu, yu, 1}, yv^(-1)] - 
     4*G[{0, yu, yu, yu}, yv^(-1)] + 2*G[{0, yv^(-1), yv^(-1), 1}, yw] + 
     4*G[{0, yv^(-1), yv^(-1), yv^(-1)}, yw] - 
     2*G[{0, yv^(-1), yv^(-1), 1/(yu*yv)}, yw] - 
     2*G[{0, yv^(-1), 1/(yu*yv), yu^(-1)}, yw] - 
     2*G[{0, yv^(-1), 1/(yu*yv), yv^(-1)}, yw] + 
     2*G[{0, 1/(yu*yv), 1, yv^(-1)}, yw] - 
     2*G[{0, 1/(yu*yv), 1, 1/(yu*yv)}, yw] - 
     2*G[{0, 1/(yu*yv), yu^(-1), yv^(-1)}, yw] + 
     2*G[{0, 1/(yu*yv), yu^(-1), 1/(yu*yv)}, yw] - 
     2*G[{0, 1/(yu*yv), yv^(-1), yu^(-1)}, yw] - 
     4*G[{0, 1/(yu*yv), yv^(-1), yv^(-1)}, yw] + 
     2*G[{0, 1/(yu*yv), yv^(-1), 1/(yu*yv)}, yw] - 
     2*G[{0, 1/(yu*yv), 1/(yu*yv), 1}, yw] + 
     4*G[{0, 1/(yu*yv), 1/(yu*yv), yu^(-1)}, yw] + 
     2*G[{0, 1/(yu*yv), 1/(yu*yv), yv^(-1)}, yw] - 
     2*G[{0}, yu^(-1)]*Zeta[3] - 2*G[{0}, yv^(-1)]*Zeta[3] + 
     2*G[{0}, yw]*Zeta[3] - 2*G[{1}, yv^(-1)]*Zeta[3] + 
     2*G[{yu}, yv^(-1)]*Zeta[3] + 2*G[{yv^(-1)}, yw]*Zeta[3] - 
     2*G[{1/(yu*yv)}, yw]*Zeta[3]
 
F1wuvRegII = (-3*Pi^4)/40 - (Pi^2*G[{0}, yu^(-1)]*G[{1}, yw])/6 - 
     (Pi^2*G[{0}, yv^(-1)]*G[{1}, yw])/6 + (Pi^2*G[{0}, yw]*G[{1}, yw])/6 + 
     (Pi^2*G[{0}, yu^(-1)]*G[{yu^(-1)}, yw])/6 + 
     (Pi^2*G[{0}, yv^(-1)]*G[{yu^(-1)}, yw])/6 - 
     (Pi^2*G[{0}, yw]*G[{yu^(-1)}, yw])/6 + 
     (Pi^2*G[{0}, yu^(-1)]*G[{yv^(-1)}, yw])/6 + 
     (Pi^2*G[{0}, yv^(-1)]*G[{yv^(-1)}, yw])/6 - 
     (Pi^2*G[{0}, yw]*G[{yv^(-1)}, yw])/6 - 
     (Pi^2*G[{0}, yu^(-1)]*G[{1/(yu*yv)}, yw])/6 - 
     (Pi^2*G[{0}, yv^(-1)]*G[{1/(yu*yv)}, yw])/6 + 
     (Pi^2*G[{0}, yw]*G[{1/(yu*yv)}, yw])/6 - (Pi^2*G[{0, 1}, yu^(-1)])/2 - 
     G[{0}, yu^(-1)]*G[{1}, yw]*G[{0, 1}, yu^(-1)] - 
     G[{0}, yv^(-1)]*G[{1}, yw]*G[{0, 1}, yu^(-1)] + 
     G[{0}, yw]*G[{1}, yw]*G[{0, 1}, yu^(-1)] + G[{0}, yu^(-1)]*
      G[{yu^(-1)}, yw]*G[{0, 1}, yu^(-1)] + G[{0}, yv^(-1)]*G[{yu^(-1)}, yw]*
      G[{0, 1}, yu^(-1)] - G[{0}, yw]*G[{yu^(-1)}, yw]*G[{0, 1}, yu^(-1)] + 
     G[{0}, yu^(-1)]*G[{yv^(-1)}, yw]*G[{0, 1}, yu^(-1)] + 
     G[{0}, yv^(-1)]*G[{yv^(-1)}, yw]*G[{0, 1}, yu^(-1)] - 
     G[{0}, yw]*G[{yv^(-1)}, yw]*G[{0, 1}, yu^(-1)] - 
     G[{0}, yu^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, 1}, yu^(-1)] - 
     G[{0}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, 1}, yu^(-1)] + 
     G[{0}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1}, yu^(-1)] - 
     G[{0, 1}, yu^(-1)]^2/2 - (Pi^2*G[{0, 1}, yv^(-1)])/2 - 
     G[{0}, yu^(-1)]*G[{1}, yw]*G[{0, 1}, yv^(-1)] - 
     G[{0}, yv^(-1)]*G[{1}, yw]*G[{0, 1}, yv^(-1)] + 
     G[{0}, yw]*G[{1}, yw]*G[{0, 1}, yv^(-1)] + G[{0}, yu^(-1)]*
      G[{yu^(-1)}, yw]*G[{0, 1}, yv^(-1)] + G[{0}, yv^(-1)]*G[{yu^(-1)}, yw]*
      G[{0, 1}, yv^(-1)] - G[{0}, yw]*G[{yu^(-1)}, yw]*G[{0, 1}, yv^(-1)] + 
     G[{0}, yu^(-1)]*G[{yv^(-1)}, yw]*G[{0, 1}, yv^(-1)] + 
     G[{0}, yv^(-1)]*G[{yv^(-1)}, yw]*G[{0, 1}, yv^(-1)] - 
     G[{0}, yw]*G[{yv^(-1)}, yw]*G[{0, 1}, yv^(-1)] - 
     G[{0}, yu^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, 1}, yv^(-1)] - 
     G[{0}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, 1}, yv^(-1)] + 
     G[{0}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1}, yv^(-1)] - 
     G[{0, 1}, yu^(-1)]*G[{0, 1}, yv^(-1)] - G[{0, 1}, yv^(-1)]^2/2 - 
     (Pi^2*G[{0, 1}, yw])/2 - G[{0}, yu^(-1)]*G[{1}, yw]*G[{0, 1}, yw] - 
     G[{0}, yv^(-1)]*G[{1}, yw]*G[{0, 1}, yw] + G[{0}, yw]*G[{1}, yw]*
      G[{0, 1}, yw] + G[{0}, yu^(-1)]*G[{yu^(-1)}, yw]*G[{0, 1}, yw] + 
     G[{0}, yv^(-1)]*G[{yu^(-1)}, yw]*G[{0, 1}, yw] - 
     G[{0}, yw]*G[{yu^(-1)}, yw]*G[{0, 1}, yw] + 
     2*G[{1}, yw]*G[{yu}, yv^(-1)]*G[{0, 1}, yw] - 
     2*G[{yu^(-1)}, yw]*G[{yu}, yv^(-1)]*G[{0, 1}, yw] + 
     G[{0}, yu^(-1)]*G[{yv^(-1)}, yw]*G[{0, 1}, yw] + 
     G[{0}, yv^(-1)]*G[{yv^(-1)}, yw]*G[{0, 1}, yw] - 
     G[{0}, yw]*G[{yv^(-1)}, yw]*G[{0, 1}, yw] - 2*G[{yu}, yv^(-1)]*
      G[{yv^(-1)}, yw]*G[{0, 1}, yw] - G[{0}, yu^(-1)]*G[{1/(yu*yv)}, yw]*
      G[{0, 1}, yw] - G[{0}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, 1}, yw] + 
     G[{0}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1}, yw] + 
     2*G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, 1}, yw] - 
     G[{0, 1}, yu^(-1)]*G[{0, 1}, yw] - G[{0, 1}, yv^(-1)]*G[{0, 1}, yw] - 
     G[{0, 1}, yw]^2/2 + (Pi^2*G[{0, yu^(-1)}, yw])/2 + 
     G[{0}, yu^(-1)]*G[{1}, yw]*G[{0, yu^(-1)}, yw] + 
     G[{0}, yv^(-1)]*G[{1}, yw]*G[{0, yu^(-1)}, yw] - 
     G[{0}, yw]*G[{1}, yw]*G[{0, yu^(-1)}, yw] - 2*G[{1}, yv^(-1)]*G[{1}, yw]*
      G[{0, yu^(-1)}, yw] - G[{0}, yu^(-1)]*G[{yu^(-1)}, yw]*
      G[{0, yu^(-1)}, yw] - G[{0}, yv^(-1)]*G[{yu^(-1)}, yw]*
      G[{0, yu^(-1)}, yw] + G[{0}, yw]*G[{yu^(-1)}, yw]*G[{0, yu^(-1)}, yw] + 
     2*G[{1}, yv^(-1)]*G[{yu^(-1)}, yw]*G[{0, yu^(-1)}, yw] - 
     G[{0}, yu^(-1)]*G[{yv^(-1)}, yw]*G[{0, yu^(-1)}, yw] - 
     G[{0}, yv^(-1)]*G[{yv^(-1)}, yw]*G[{0, yu^(-1)}, yw] + 
     G[{0}, yw]*G[{yv^(-1)}, yw]*G[{0, yu^(-1)}, yw] + 
     2*G[{1}, yv^(-1)]*G[{yv^(-1)}, yw]*G[{0, yu^(-1)}, yw] + 
     G[{0}, yu^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1)}, yw] + 
     G[{0}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1)}, yw] - 
     G[{0}, yw]*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1)}, yw] - 
     2*G[{1}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1)}, yw] + 
     G[{0, 1}, yu^(-1)]*G[{0, yu^(-1)}, yw] + G[{0, 1}, yv^(-1)]*
      G[{0, yu^(-1)}, yw] + G[{0, 1}, yw]*G[{0, yu^(-1)}, yw] - 
     G[{0, yu^(-1)}, yw]^2/2 + (Pi^2*G[{0, yu}, yv^(-1)])/2 + 
     G[{0}, yu^(-1)]*G[{1}, yw]*G[{0, yu}, yv^(-1)] + 
     G[{0}, yv^(-1)]*G[{1}, yw]*G[{0, yu}, yv^(-1)] - 
     G[{0}, yw]*G[{1}, yw]*G[{0, yu}, yv^(-1)] - 
     G[{0}, yu^(-1)]*G[{yu^(-1)}, yw]*G[{0, yu}, yv^(-1)] - 
     G[{0}, yv^(-1)]*G[{yu^(-1)}, yw]*G[{0, yu}, yv^(-1)] + 
     G[{0}, yw]*G[{yu^(-1)}, yw]*G[{0, yu}, yv^(-1)] - 
     G[{0}, yu^(-1)]*G[{yv^(-1)}, yw]*G[{0, yu}, yv^(-1)] - 
     G[{0}, yv^(-1)]*G[{yv^(-1)}, yw]*G[{0, yu}, yv^(-1)] + 
     G[{0}, yw]*G[{yv^(-1)}, yw]*G[{0, yu}, yv^(-1)] + 
     G[{0}, yu^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, yu}, yv^(-1)] + 
     G[{0}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, yu}, yv^(-1)] - 
     G[{0}, yw]*G[{1/(yu*yv)}, yw]*G[{0, yu}, yv^(-1)] + 
     G[{0, 1}, yu^(-1)]*G[{0, yu}, yv^(-1)] + G[{0, 1}, yv^(-1)]*
      G[{0, yu}, yv^(-1)] + G[{0, 1}, yw]*G[{0, yu}, yv^(-1)] - 
     G[{0, yu^(-1)}, yw]*G[{0, yu}, yv^(-1)] - G[{0, yu}, yv^(-1)]^2/2 + 
     (Pi^2*G[{0, yv^(-1)}, yw])/2 + G[{0}, yu^(-1)]*G[{1}, yw]*
      G[{0, yv^(-1)}, yw] + G[{0}, yv^(-1)]*G[{1}, yw]*G[{0, yv^(-1)}, yw] - 
     G[{0}, yw]*G[{1}, yw]*G[{0, yv^(-1)}, yw] - 2*G[{1}, yu^(-1)]*G[{1}, yw]*
      G[{0, yv^(-1)}, yw] - G[{0}, yu^(-1)]*G[{yu^(-1)}, yw]*
      G[{0, yv^(-1)}, yw] - G[{0}, yv^(-1)]*G[{yu^(-1)}, yw]*
      G[{0, yv^(-1)}, yw] + G[{0}, yw]*G[{yu^(-1)}, yw]*G[{0, yv^(-1)}, yw] + 
     2*G[{1}, yu^(-1)]*G[{yu^(-1)}, yw]*G[{0, yv^(-1)}, yw] - 
     G[{0}, yu^(-1)]*G[{yv^(-1)}, yw]*G[{0, yv^(-1)}, yw] - 
     G[{0}, yv^(-1)]*G[{yv^(-1)}, yw]*G[{0, yv^(-1)}, yw] + 
     G[{0}, yw]*G[{yv^(-1)}, yw]*G[{0, yv^(-1)}, yw] + 
     2*G[{1}, yu^(-1)]*G[{yv^(-1)}, yw]*G[{0, yv^(-1)}, yw] + 
     G[{0}, yu^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, yv^(-1)}, yw] + 
     G[{0}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, yv^(-1)}, yw] - 
     G[{0}, yw]*G[{1/(yu*yv)}, yw]*G[{0, yv^(-1)}, yw] - 
     2*G[{1}, yu^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, yv^(-1)}, yw] + 
     G[{0, 1}, yu^(-1)]*G[{0, yv^(-1)}, yw] + G[{0, 1}, yv^(-1)]*
      G[{0, yv^(-1)}, yw] + G[{0, 1}, yw]*G[{0, yv^(-1)}, yw] - 
     G[{0, yu^(-1)}, yw]*G[{0, yv^(-1)}, yw] - G[{0, yu}, yv^(-1)]*
      G[{0, yv^(-1)}, yw] - G[{0, yv^(-1)}, yw]^2/2 - 
     (Pi^2*G[{0, 1/(yu*yv)}, yw])/2 - G[{0}, yu^(-1)]*G[{1}, yw]*
      G[{0, 1/(yu*yv)}, yw] - G[{0}, yv^(-1)]*G[{1}, yw]*
      G[{0, 1/(yu*yv)}, yw] + G[{0}, yw]*G[{1}, yw]*G[{0, 1/(yu*yv)}, yw] + 
     2*G[{1}, yu^(-1)]*G[{1}, yw]*G[{0, 1/(yu*yv)}, yw] + 
     2*G[{1}, yv^(-1)]*G[{1}, yw]*G[{0, 1/(yu*yv)}, yw] + 
     G[{0}, yu^(-1)]*G[{yu^(-1)}, yw]*G[{0, 1/(yu*yv)}, yw] + 
     G[{0}, yv^(-1)]*G[{yu^(-1)}, yw]*G[{0, 1/(yu*yv)}, yw] - 
     G[{0}, yw]*G[{yu^(-1)}, yw]*G[{0, 1/(yu*yv)}, yw] - 
     2*G[{1}, yu^(-1)]*G[{yu^(-1)}, yw]*G[{0, 1/(yu*yv)}, yw] - 
     2*G[{1}, yv^(-1)]*G[{yu^(-1)}, yw]*G[{0, 1/(yu*yv)}, yw] - 
     2*G[{1}, yw]*G[{yu}, yv^(-1)]*G[{0, 1/(yu*yv)}, yw] + 
     2*G[{yu^(-1)}, yw]*G[{yu}, yv^(-1)]*G[{0, 1/(yu*yv)}, yw] + 
     G[{0}, yu^(-1)]*G[{yv^(-1)}, yw]*G[{0, 1/(yu*yv)}, yw] + 
     G[{0}, yv^(-1)]*G[{yv^(-1)}, yw]*G[{0, 1/(yu*yv)}, yw] - 
     G[{0}, yw]*G[{yv^(-1)}, yw]*G[{0, 1/(yu*yv)}, yw] - 
     2*G[{1}, yu^(-1)]*G[{yv^(-1)}, yw]*G[{0, 1/(yu*yv)}, yw] - 
     2*G[{1}, yv^(-1)]*G[{yv^(-1)}, yw]*G[{0, 1/(yu*yv)}, yw] + 
     2*G[{yu}, yv^(-1)]*G[{yv^(-1)}, yw]*G[{0, 1/(yu*yv)}, yw] - 
     G[{0}, yu^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv)}, yw] - 
     G[{0}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv)}, yw] + 
     G[{0}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv)}, yw] + 
     2*G[{1}, yu^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv)}, yw] + 
     2*G[{1}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv)}, yw] - 
     2*G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv)}, yw] - 
     G[{0, 1}, yu^(-1)]*G[{0, 1/(yu*yv)}, yw] - G[{0, 1}, yv^(-1)]*
      G[{0, 1/(yu*yv)}, yw] - G[{0, 1}, yw]*G[{0, 1/(yu*yv)}, yw] + 
     G[{0, yu^(-1)}, yw]*G[{0, 1/(yu*yv)}, yw] + G[{0, yu}, yv^(-1)]*
      G[{0, 1/(yu*yv)}, yw] + G[{0, yv^(-1)}, yw]*G[{0, 1/(yu*yv)}, yw] - 
     G[{0, 1/(yu*yv)}, yw]^2/2 - 2*G[{1}, yw]*G[{0, 0, 1}, yw] + 
     2*G[{yu^(-1)}, yw]*G[{0, 0, 1}, yw] + 2*G[{yv^(-1)}, yw]*
      G[{0, 0, 1}, yw] - 2*G[{1/(yu*yv)}, yw]*G[{0, 0, 1}, yw] + 
     2*G[{1}, yw]*G[{0, 0, yu^(-1)}, yw] - 2*G[{yu^(-1)}, yw]*
      G[{0, 0, yu^(-1)}, yw] - 2*G[{yv^(-1)}, yw]*G[{0, 0, yu^(-1)}, yw] + 
     2*G[{1/(yu*yv)}, yw]*G[{0, 0, yu^(-1)}, yw] + 
     2*G[{1}, yw]*G[{0, 0, yv^(-1)}, yw] - 2*G[{yu^(-1)}, yw]*
      G[{0, 0, yv^(-1)}, yw] - 2*G[{yv^(-1)}, yw]*G[{0, 0, yv^(-1)}, yw] + 
     2*G[{1/(yu*yv)}, yw]*G[{0, 0, yv^(-1)}, yw] - 
     2*G[{1}, yw]*G[{0, 0, 1/(yu*yv)}, yw] + 2*G[{yu^(-1)}, yw]*
      G[{0, 0, 1/(yu*yv)}, yw] + 2*G[{yv^(-1)}, yw]*G[{0, 0, 1/(yu*yv)}, 
       yw] - 2*G[{1/(yu*yv)}, yw]*G[{0, 0, 1/(yu*yv)}, yw] + 
     2*G[{1}, yw]*G[{0, 1, 1}, yu^(-1)] - 2*G[{yu^(-1)}, yw]*
      G[{0, 1, 1}, yu^(-1)] - 2*G[{yv^(-1)}, yw]*G[{0, 1, 1}, yu^(-1)] + 
     2*G[{1/(yu*yv)}, yw]*G[{0, 1, 1}, yu^(-1)] - 
     2*G[{1}, yu^(-1)]*G[{0, 1, 1}, yv^(-1)] + 
     2*G[{1}, yw]*G[{0, 1, 1}, yv^(-1)] - 2*G[{yu^(-1)}, yw]*
      G[{0, 1, 1}, yv^(-1)] - 2*G[{yv^(-1)}, yw]*G[{0, 1, 1}, yv^(-1)] + 
     2*G[{1/(yu*yv)}, yw]*G[{0, 1, 1}, yv^(-1)] + 
     2*G[{1}, yu^(-1)]*G[{0, 1, 1}, yw] + 2*G[{1}, yv^(-1)]*
      G[{0, 1, 1}, yw] - 2*G[{1}, yw]*G[{0, 1, 1}, yw] + 
     2*G[{yu^(-1)}, yw]*G[{0, 1, 1}, yw] - 4*G[{yu}, yv^(-1)]*
      G[{0, 1, 1}, yw] + 2*G[{yv^(-1)}, yw]*G[{0, 1, 1}, yw] - 
     2*G[{1/(yu*yv)}, yw]*G[{0, 1, 1}, yw] - 2*G[{1}, yu^(-1)]*
      G[{0, 1, yu^(-1)}, yw] + 2*G[{yu}, yv^(-1)]*G[{0, 1, yu^(-1)}, yw] + 
     2*G[{1}, yu^(-1)]*G[{0, 1, yu}, yv^(-1)] - 2*G[{1}, yv^(-1)]*
      G[{0, 1, yv^(-1)}, yw] + 2*G[{yu}, yv^(-1)]*G[{0, 1, yv^(-1)}, yw] - 
     2*G[{1}, yu^(-1)]*G[{0, yu^(-1), 1}, yw] + 2*G[{yu}, yv^(-1)]*
      G[{0, yu^(-1), 1}, yw] + 2*G[{1}, yu^(-1)]*G[{0, yu^(-1), yu^(-1)}, 
       yw] - 2*G[{1}, yv^(-1)]*G[{0, yu^(-1), yu^(-1)}, yw] + 
     2*G[{1}, yw]*G[{0, yu^(-1), yu^(-1)}, yw] - 2*G[{yu^(-1)}, yw]*
      G[{0, yu^(-1), yu^(-1)}, yw] - 2*G[{yv^(-1)}, yw]*
      G[{0, yu^(-1), yu^(-1)}, yw] + 2*G[{1/(yu*yv)}, yw]*
      G[{0, yu^(-1), yu^(-1)}, yw] + 2*G[{1}, yv^(-1)]*
      G[{0, yu^(-1), 1/(yu*yv)}, yw] - 2*G[{yu}, yv^(-1)]*
      G[{0, yu^(-1), 1/(yu*yv)}, yw] + 2*G[{1}, yu^(-1)]*
      G[{0, yu, 1}, yv^(-1)] - 2*G[{1}, yu^(-1)]*G[{0, yu, yu}, yv^(-1)] - 
     2*G[{1}, yw]*G[{0, yu, yu}, yv^(-1)] + 2*G[{yu^(-1)}, yw]*
      G[{0, yu, yu}, yv^(-1)] + 2*G[{yv^(-1)}, yw]*G[{0, yu, yu}, yv^(-1)] - 
     2*G[{1/(yu*yv)}, yw]*G[{0, yu, yu}, yv^(-1)] - 
     2*G[{1}, yv^(-1)]*G[{0, yv^(-1), 1}, yw] + 2*G[{yu}, yv^(-1)]*
      G[{0, yv^(-1), 1}, yw] - 2*G[{1}, yu^(-1)]*G[{0, yv^(-1), yv^(-1)}, 
       yw] + 2*G[{1}, yv^(-1)]*G[{0, yv^(-1), yv^(-1)}, yw] + 
     2*G[{1}, yw]*G[{0, yv^(-1), yv^(-1)}, yw] - 2*G[{yu^(-1)}, yw]*
      G[{0, yv^(-1), yv^(-1)}, yw] - 2*G[{yv^(-1)}, yw]*
      G[{0, yv^(-1), yv^(-1)}, yw] + 2*G[{1/(yu*yv)}, yw]*
      G[{0, yv^(-1), yv^(-1)}, yw] + 2*G[{1}, yu^(-1)]*
      G[{0, yv^(-1), 1/(yu*yv)}, yw] - 2*G[{yu}, yv^(-1)]*
      G[{0, yv^(-1), 1/(yu*yv)}, yw] + 2*G[{1}, yw]*G[{0, 1/(yu*yv), 1}, 
       yw] - 2*G[{yu^(-1)}, yw]*G[{0, 1/(yu*yv), 1}, yw] - 
     2*G[{yv^(-1)}, yw]*G[{0, 1/(yu*yv), 1}, yw] + 2*G[{1/(yu*yv)}, yw]*
      G[{0, 1/(yu*yv), 1}, yw] + 2*G[{1}, yv^(-1)]*G[{0, 1/(yu*yv), yu^(-1)}, 
       yw] - 2*G[{1}, yw]*G[{0, 1/(yu*yv), yu^(-1)}, yw] + 
     2*G[{yu^(-1)}, yw]*G[{0, 1/(yu*yv), yu^(-1)}, yw] - 
     2*G[{yu}, yv^(-1)]*G[{0, 1/(yu*yv), yu^(-1)}, yw] + 
     2*G[{yv^(-1)}, yw]*G[{0, 1/(yu*yv), yu^(-1)}, yw] - 
     2*G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv), yu^(-1)}, yw] + 
     2*G[{1}, yu^(-1)]*G[{0, 1/(yu*yv), yv^(-1)}, yw] - 
     2*G[{1}, yw]*G[{0, 1/(yu*yv), yv^(-1)}, yw] + 
     2*G[{yu^(-1)}, yw]*G[{0, 1/(yu*yv), yv^(-1)}, yw] - 
     2*G[{yu}, yv^(-1)]*G[{0, 1/(yu*yv), yv^(-1)}, yw] + 
     2*G[{yv^(-1)}, yw]*G[{0, 1/(yu*yv), yv^(-1)}, yw] - 
     2*G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv), yv^(-1)}, yw] - 
     2*G[{1}, yu^(-1)]*G[{0, 1/(yu*yv), 1/(yu*yv)}, yw] - 
     2*G[{1}, yv^(-1)]*G[{0, 1/(yu*yv), 1/(yu*yv)}, yw] + 
     4*G[{yu}, yv^(-1)]*G[{0, 1/(yu*yv), 1/(yu*yv)}, yw] + 
     2*G[{0, 0, 1, 1}, yu^(-1)] + 2*G[{0, 0, 1, 1}, yv^(-1)] + 
     2*G[{0, 0, 1, 1}, yw] - 2*G[{0, 0, 1, yu^(-1)}, yw] - 
     2*G[{0, 0, 1, yu}, yv^(-1)] - 2*G[{0, 0, 1, yv^(-1)}, yw] + 
     2*G[{0, 0, 1, 1/(yu*yv)}, yw] - 2*G[{0, 0, yu^(-1), 1}, yw] + 
     2*G[{0, 0, yu^(-1), yu^(-1)}, yw] + 2*G[{0, 0, yu^(-1), yv^(-1)}, yw] - 
     2*G[{0, 0, yu^(-1), 1/(yu*yv)}, yw] - 2*G[{0, 0, yu, 1}, yv^(-1)] + 
     2*G[{0, 0, yu, yu}, yv^(-1)] - 2*G[{0, 0, yv^(-1), 1}, yw] + 
     2*G[{0, 0, yv^(-1), yu^(-1)}, yw] + 2*G[{0, 0, yv^(-1), yv^(-1)}, yw] - 
     2*G[{0, 0, yv^(-1), 1/(yu*yv)}, yw] + 2*G[{0, 0, 1/(yu*yv), 1}, yw] - 
     2*G[{0, 0, 1/(yu*yv), yu^(-1)}, yw] - 
     2*G[{0, 0, 1/(yu*yv), yv^(-1)}, yw] + 
     2*G[{0, 0, 1/(yu*yv), 1/(yu*yv)}, yw] + 6*G[{0, 1, 1, 1}, yw] - 
     4*G[{0, 1, 1, yu^(-1)}, yw] + 2*G[{0, 1, 1, yu}, yv^(-1)] - 
     4*G[{0, 1, 1, yv^(-1)}, yw] + 2*G[{0, 1, 1, 1/(yu*yv)}, yw] - 
     2*G[{0, 1, yu^(-1), 1}, yw] + 2*G[{0, 1, yu^(-1), yv^(-1)}, yw] + 
     2*G[{0, 1, yu, 1}, yv^(-1)] - 4*G[{0, 1, yu, yu}, yv^(-1)] - 
     2*G[{0, 1, yv^(-1), 1}, yw] + 2*G[{0, 1, yv^(-1), yu^(-1)}, yw] - 
     2*G[{0, yu^(-1), 1, 1}, yw] + 2*G[{0, yu^(-1), 1, yv^(-1)}, yw] - 
     2*G[{0, yu^(-1), yu^(-1), 1}, yw] + 4*G[{0, yu^(-1), yu^(-1), yu^(-1)}, 
       yw] - 2*G[{0, yu^(-1), yu^(-1), 1/(yu*yv)}, yw] + 
     2*G[{0, yu^(-1), 1/(yu*yv), 1}, yw] - 
     2*G[{0, yu^(-1), 1/(yu*yv), yu^(-1)}, yw] - 
     2*G[{0, yu, 1, yu}, yv^(-1)] - 2*G[{0, yu, yu, 1}, yv^(-1)] + 
     4*G[{0, yu, yu, yu}, yv^(-1)] - 2*G[{0, yv^(-1), 1, 1}, yw] + 
     2*G[{0, yv^(-1), 1, yu^(-1)}, yw] - 2*G[{0, yv^(-1), yv^(-1), 1}, yw] + 
     4*G[{0, yv^(-1), yv^(-1), yv^(-1)}, yw] - 
     2*G[{0, yv^(-1), yv^(-1), 1/(yu*yv)}, yw] + 
     2*G[{0, yv^(-1), 1/(yu*yv), 1}, yw] - 
     2*G[{0, yv^(-1), 1/(yu*yv), yv^(-1)}, yw] - 
     2*G[{0, 1/(yu*yv), 1, 1}, yw] + 2*G[{0, 1/(yu*yv), 1, yu^(-1)}, yw] + 
     2*G[{0, 1/(yu*yv), 1, yv^(-1)}, yw] - 
     2*G[{0, 1/(yu*yv), 1, 1/(yu*yv)}, yw] + 
     4*G[{0, 1/(yu*yv), yu^(-1), 1}, yw] - 
     4*G[{0, 1/(yu*yv), yu^(-1), yu^(-1)}, yw] - 
     2*G[{0, 1/(yu*yv), yu^(-1), yv^(-1)}, yw] + 
     2*G[{0, 1/(yu*yv), yu^(-1), 1/(yu*yv)}, yw] + 
     4*G[{0, 1/(yu*yv), yv^(-1), 1}, yw] - 
     2*G[{0, 1/(yu*yv), yv^(-1), yu^(-1)}, yw] - 
     4*G[{0, 1/(yu*yv), yv^(-1), yv^(-1)}, yw] + 
     2*G[{0, 1/(yu*yv), yv^(-1), 1/(yu*yv)}, yw] - 
     4*G[{0, 1/(yu*yv), 1/(yu*yv), 1}, yw] + 
     2*G[{0, 1/(yu*yv), 1/(yu*yv), yu^(-1)}, yw] + 
     2*G[{0, 1/(yu*yv), 1/(yu*yv), yv^(-1)}, yw] - 2*G[{1}, yw]*Zeta[3] + 
     2*G[{yu^(-1)}, yw]*Zeta[3] + 2*G[{yv^(-1)}, yw]*Zeta[3] - 
     2*G[{1/(yu*yv)}, yw]*Zeta[3]
 
QepuvwRegII = (Pi^4*G[{0}, yu^(-1)])/1152 + (Pi^4*G[{0}, yv^(-1)])/1152 - 
     (Pi^4*G[{0}, yw])/1152 - (Pi^4*G[{1}, yu^(-1)])/1152 + 
     (Pi^2*G[{0}, yu^(-1)]*G[{1}, yu^(-1)]^2)/96 + 
     (Pi^2*G[{0}, yv^(-1)]*G[{1}, yu^(-1)]^2)/96 - 
     (Pi^2*G[{0}, yw]*G[{1}, yu^(-1)]^2)/96 - (5*Pi^2*G[{1}, yu^(-1)]^3)/
      576 + (3*G[{0}, yu^(-1)]^2*G[{1}, yu^(-1)]^3)/256 + 
     (3*G[{0}, yu^(-1)]*G[{0}, yv^(-1)]*G[{1}, yu^(-1)]^3)/128 + 
     (3*G[{0}, yv^(-1)]^2*G[{1}, yu^(-1)]^3)/256 - 
     (3*G[{0}, yu^(-1)]*G[{0}, yw]*G[{1}, yu^(-1)]^3)/128 - 
     (3*G[{0}, yv^(-1)]*G[{0}, yw]*G[{1}, yu^(-1)]^3)/128 + 
     (3*G[{0}, yw]^2*G[{1}, yu^(-1)]^3)/256 - 
     (3*G[{0}, yu^(-1)]*G[{1}, yu^(-1)]^4)/128 - 
     (3*G[{0}, yv^(-1)]*G[{1}, yu^(-1)]^4)/128 + 
     (3*G[{0}, yw]*G[{1}, yu^(-1)]^4)/128 + (3*G[{1}, yu^(-1)]^5)/256 - 
     (Pi^4*G[{1}, yv^(-1)])/384 - (Pi^2*G[{0}, yu^(-1)]*G[{1}, yu^(-1)]*
       G[{1}, yv^(-1)])/32 - (Pi^2*G[{0}, yv^(-1)]*G[{1}, yu^(-1)]*
       G[{1}, yv^(-1)])/32 + (Pi^2*G[{0}, yw]*G[{1}, yu^(-1)]*
       G[{1}, yv^(-1)])/32 + (Pi^2*G[{1}, yu^(-1)]^2*G[{1}, yv^(-1)])/192 - 
     (9*G[{0}, yu^(-1)]^2*G[{1}, yu^(-1)]^2*G[{1}, yv^(-1)])/256 - 
     (9*G[{0}, yu^(-1)]*G[{0}, yv^(-1)]*G[{1}, yu^(-1)]^2*G[{1}, yv^(-1)])/
      128 - (9*G[{0}, yv^(-1)]^2*G[{1}, yu^(-1)]^2*G[{1}, yv^(-1)])/256 + 
     (9*G[{0}, yu^(-1)]*G[{0}, yw]*G[{1}, yu^(-1)]^2*G[{1}, yv^(-1)])/128 + 
     (9*G[{0}, yv^(-1)]*G[{0}, yw]*G[{1}, yu^(-1)]^2*G[{1}, yv^(-1)])/128 - 
     (9*G[{0}, yw]^2*G[{1}, yu^(-1)]^2*G[{1}, yv^(-1)])/256 + 
     (3*G[{0}, yu^(-1)]*G[{1}, yu^(-1)]^3*G[{1}, yv^(-1)])/64 + 
     (3*G[{0}, yv^(-1)]*G[{1}, yu^(-1)]^3*G[{1}, yv^(-1)])/64 - 
     (3*G[{0}, yw]*G[{1}, yu^(-1)]^3*G[{1}, yv^(-1)])/64 - 
     (3*G[{1}, yu^(-1)]^4*G[{1}, yv^(-1)])/256 + 
     (Pi^2*G[{0}, yu^(-1)]*G[{1}, yv^(-1)]^2)/192 + 
     (Pi^2*G[{0}, yv^(-1)]*G[{1}, yv^(-1)]^2)/192 - 
     (Pi^2*G[{0}, yw]*G[{1}, yv^(-1)]^2)/192 + 
     (9*Pi^2*G[{1}, yu^(-1)]*G[{1}, yv^(-1)]^2)/512 + 
     (3*G[{0}, yu^(-1)]^2*G[{1}, yu^(-1)]*G[{1}, yv^(-1)]^2)/256 + 
     (3*G[{0}, yu^(-1)]*G[{0}, yv^(-1)]*G[{1}, yu^(-1)]*G[{1}, yv^(-1)]^2)/
      128 + (3*G[{0}, yv^(-1)]^2*G[{1}, yu^(-1)]*G[{1}, yv^(-1)]^2)/256 - 
     (3*G[{0}, yu^(-1)]*G[{0}, yw]*G[{1}, yu^(-1)]*G[{1}, yv^(-1)]^2)/128 - 
     (3*G[{0}, yv^(-1)]*G[{0}, yw]*G[{1}, yu^(-1)]*G[{1}, yv^(-1)]^2)/128 + 
     (3*G[{0}, yw]^2*G[{1}, yu^(-1)]*G[{1}, yv^(-1)]^2)/256 - 
     (Pi^2*G[{1}, yv^(-1)]^3)/576 - (G[{0}, yu^(-1)]*G[{1}, yu^(-1)]*
       G[{1}, yv^(-1)]^3)/384 - (G[{0}, yv^(-1)]*G[{1}, yu^(-1)]*
       G[{1}, yv^(-1)]^3)/384 + (G[{0}, yw]*G[{1}, yu^(-1)]*
       G[{1}, yv^(-1)]^3)/384 - (G[{1}, yu^(-1)]^2*G[{1}, yv^(-1)]^3)/768 - 
     (G[{1}, yu^(-1)]*G[{1}, yv^(-1)]^4)/768 + (Pi^4*G[{1}, yw])/384 + 
     (Pi^2*G[{0}, yu^(-1)]*G[{1}, yu^(-1)]*G[{1}, yw])/32 + 
     (Pi^2*G[{0}, yv^(-1)]*G[{1}, yu^(-1)]*G[{1}, yw])/32 - 
     (Pi^2*G[{0}, yw]*G[{1}, yu^(-1)]*G[{1}, yw])/32 - 
     (Pi^2*G[{1}, yu^(-1)]^2*G[{1}, yw])/192 + 
     (9*G[{0}, yu^(-1)]^2*G[{1}, yu^(-1)]^2*G[{1}, yw])/256 + 
     (9*G[{0}, yu^(-1)]*G[{0}, yv^(-1)]*G[{1}, yu^(-1)]^2*G[{1}, yw])/128 + 
     (9*G[{0}, yv^(-1)]^2*G[{1}, yu^(-1)]^2*G[{1}, yw])/256 - 
     (9*G[{0}, yu^(-1)]*G[{0}, yw]*G[{1}, yu^(-1)]^2*G[{1}, yw])/128 - 
     (9*G[{0}, yv^(-1)]*G[{0}, yw]*G[{1}, yu^(-1)]^2*G[{1}, yw])/128 + 
     (9*G[{0}, yw]^2*G[{1}, yu^(-1)]^2*G[{1}, yw])/256 - 
     (3*G[{0}, yu^(-1)]*G[{1}, yu^(-1)]^3*G[{1}, yw])/64 - 
     (3*G[{0}, yv^(-1)]*G[{1}, yu^(-1)]^3*G[{1}, yw])/64 + 
     (3*G[{0}, yw]*G[{1}, yu^(-1)]^3*G[{1}, yw])/64 + 
     (3*G[{1}, yu^(-1)]^4*G[{1}, yw])/256 - 
     (Pi^2*G[{0}, yu^(-1)]*G[{1}, yv^(-1)]*G[{1}, yw])/96 - 
     (Pi^2*G[{0}, yv^(-1)]*G[{1}, yv^(-1)]*G[{1}, yw])/96 + 
     (Pi^2*G[{0}, yw]*G[{1}, yv^(-1)]*G[{1}, yw])/96 - 
     (9*Pi^2*G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*G[{1}, yw])/256 - 
     (3*G[{0}, yu^(-1)]^2*G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*G[{1}, yw])/128 - 
     (3*G[{0}, yu^(-1)]*G[{0}, yv^(-1)]*G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*
       G[{1}, yw])/64 - (3*G[{0}, yv^(-1)]^2*G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*
       G[{1}, yw])/128 + (3*G[{0}, yu^(-1)]*G[{0}, yw]*G[{1}, yu^(-1)]*
       G[{1}, yv^(-1)]*G[{1}, yw])/64 + (3*G[{0}, yv^(-1)]*G[{0}, yw]*
       G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*G[{1}, yw])/64 - 
     (3*G[{0}, yw]^2*G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*G[{1}, yw])/128 + 
     (Pi^2*G[{1}, yv^(-1)]^2*G[{1}, yw])/192 + 
     (G[{0}, yu^(-1)]*G[{1}, yu^(-1)]*G[{1}, yv^(-1)]^2*G[{1}, yw])/128 + 
     (G[{0}, yv^(-1)]*G[{1}, yu^(-1)]*G[{1}, yv^(-1)]^2*G[{1}, yw])/128 - 
     (G[{0}, yw]*G[{1}, yu^(-1)]*G[{1}, yv^(-1)]^2*G[{1}, yw])/128 + 
     (G[{1}, yu^(-1)]^2*G[{1}, yv^(-1)]^2*G[{1}, yw])/256 + 
     (G[{1}, yu^(-1)]*G[{1}, yv^(-1)]^3*G[{1}, yw])/192 + 
     (Pi^2*G[{0}, yu^(-1)]*G[{1}, yw]^2)/48 + 
     (Pi^2*G[{0}, yv^(-1)]*G[{1}, yw]^2)/48 - (Pi^2*G[{0}, yw]*G[{1}, yw]^2)/
      48 + (Pi^2*G[{1}, yu^(-1)]*G[{1}, yw]^2)/192 + 
     (9*G[{0}, yu^(-1)]^2*G[{1}, yu^(-1)]*G[{1}, yw]^2)/256 + 
     (9*G[{0}, yu^(-1)]*G[{0}, yv^(-1)]*G[{1}, yu^(-1)]*G[{1}, yw]^2)/128 + 
     (9*G[{0}, yv^(-1)]^2*G[{1}, yu^(-1)]*G[{1}, yw]^2)/256 - 
     (9*G[{0}, yu^(-1)]*G[{0}, yw]*G[{1}, yu^(-1)]*G[{1}, yw]^2)/128 - 
     (9*G[{0}, yv^(-1)]*G[{0}, yw]*G[{1}, yu^(-1)]*G[{1}, yw]^2)/128 + 
     (9*G[{0}, yw]^2*G[{1}, yu^(-1)]*G[{1}, yw]^2)/256 - 
     (G[{0}, yu^(-1)]*G[{1}, yu^(-1)]^2*G[{1}, yw]^2)/32 - 
     (G[{0}, yv^(-1)]*G[{1}, yu^(-1)]^2*G[{1}, yw]^2)/32 + 
     (G[{0}, yw]*G[{1}, yu^(-1)]^2*G[{1}, yw]^2)/32 - 
     (G[{1}, yu^(-1)]^3*G[{1}, yw]^2)/256 - 
     (Pi^2*G[{1}, yv^(-1)]*G[{1}, yw]^2)/48 - 
     (3*G[{0}, yu^(-1)]*G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*G[{1}, yw]^2)/128 - 
     (3*G[{0}, yv^(-1)]*G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*G[{1}, yw]^2)/128 + 
     (3*G[{0}, yw]*G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*G[{1}, yw]^2)/128 + 
     (G[{1}, yu^(-1)]^2*G[{1}, yv^(-1)]*G[{1}, yw]^2)/128 - 
     (5*G[{1}, yu^(-1)]*G[{1}, yv^(-1)]^2*G[{1}, yw]^2)/256 + 
     (Pi^2*G[{1}, yw]^3)/144 + (3*G[{0}, yu^(-1)]^2*G[{1}, yw]^3)/256 + 
     (3*G[{0}, yu^(-1)]*G[{0}, yv^(-1)]*G[{1}, yw]^3)/128 + 
     (3*G[{0}, yv^(-1)]^2*G[{1}, yw]^3)/256 - 
     (3*G[{0}, yu^(-1)]*G[{0}, yw]*G[{1}, yw]^3)/128 - 
     (3*G[{0}, yv^(-1)]*G[{0}, yw]*G[{1}, yw]^3)/128 + 
     (3*G[{0}, yw]^2*G[{1}, yw]^3)/256 - (5*G[{0}, yu^(-1)]*G[{1}, yu^(-1)]*
       G[{1}, yw]^3)/192 - (5*G[{0}, yv^(-1)]*G[{1}, yu^(-1)]*G[{1}, yw]^3)/
      192 + (5*G[{0}, yw]*G[{1}, yu^(-1)]*G[{1}, yw]^3)/192 + 
     (11*G[{1}, yu^(-1)]^2*G[{1}, yw]^3)/768 - 
     (3*G[{0}, yu^(-1)]*G[{1}, yv^(-1)]*G[{1}, yw]^3)/128 - 
     (3*G[{0}, yv^(-1)]*G[{1}, yv^(-1)]*G[{1}, yw]^3)/128 + 
     (3*G[{0}, yw]*G[{1}, yv^(-1)]*G[{1}, yw]^3)/128 + 
     (7*G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*G[{1}, yw]^3)/128 + 
     (3*G[{1}, yv^(-1)]^2*G[{1}, yw]^3)/256 - (G[{0}, yu^(-1)]*G[{1}, yw]^4)/
      96 - (G[{0}, yv^(-1)]*G[{1}, yw]^4)/96 + (G[{0}, yw]*G[{1}, yw]^4)/96 + 
     (G[{1}, yu^(-1)]*G[{1}, yw]^4)/96 + (G[{1}, yv^(-1)]*G[{1}, yw]^4)/96 - 
     (Pi^2*G[{0}, yu^(-1)]*G[{1}, yw]*G[{yu}, yv^(-1)])/32 - 
     (Pi^2*G[{0}, yv^(-1)]*G[{1}, yw]*G[{yu}, yv^(-1)])/32 + 
     (Pi^2*G[{0}, yw]*G[{1}, yw]*G[{yu}, yv^(-1)])/32 - 
     (13*Pi^2*G[{1}, yu^(-1)]*G[{1}, yw]*G[{yu}, yv^(-1)])/768 - 
     (3*G[{0}, yu^(-1)]^2*G[{1}, yu^(-1)]*G[{1}, yw]*G[{yu}, yv^(-1)])/64 - 
     (3*G[{0}, yu^(-1)]*G[{0}, yv^(-1)]*G[{1}, yu^(-1)]*G[{1}, yw]*
       G[{yu}, yv^(-1)])/32 - (3*G[{0}, yv^(-1)]^2*G[{1}, yu^(-1)]*G[{1}, yw]*
       G[{yu}, yv^(-1)])/64 + (3*G[{0}, yu^(-1)]*G[{0}, yw]*G[{1}, yu^(-1)]*
       G[{1}, yw]*G[{yu}, yv^(-1)])/32 + (3*G[{0}, yv^(-1)]*G[{0}, yw]*
       G[{1}, yu^(-1)]*G[{1}, yw]*G[{yu}, yv^(-1)])/32 - 
     (3*G[{0}, yw]^2*G[{1}, yu^(-1)]*G[{1}, yw]*G[{yu}, yv^(-1)])/64 + 
     (3*G[{1}, yu^(-1)]^3*G[{1}, yw]*G[{yu}, yv^(-1)])/64 - 
     (Pi^2*G[{1}, yv^(-1)]*G[{1}, yw]*G[{yu}, yv^(-1)])/96 - 
     (3*G[{0}, yu^(-1)]*G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*G[{1}, yw]*
       G[{yu}, yv^(-1)])/32 - (3*G[{0}, yv^(-1)]*G[{1}, yu^(-1)]*
       G[{1}, yv^(-1)]*G[{1}, yw]*G[{yu}, yv^(-1)])/32 + 
     (3*G[{0}, yw]*G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*G[{1}, yw]*
       G[{yu}, yv^(-1)])/32 + (3*G[{1}, yu^(-1)]^2*G[{1}, yv^(-1)]*G[{1}, yw]*
       G[{yu}, yv^(-1)])/64 + (G[{0}, yu^(-1)]*G[{1}, yv^(-1)]^2*G[{1}, yw]*
       G[{yu}, yv^(-1)])/32 + (G[{0}, yv^(-1)]*G[{1}, yv^(-1)]^2*G[{1}, yw]*
       G[{yu}, yv^(-1)])/32 - (G[{0}, yw]*G[{1}, yv^(-1)]^2*G[{1}, yw]*
       G[{yu}, yv^(-1)])/32 + (3*G[{1}, yu^(-1)]*G[{1}, yv^(-1)]^2*G[{1}, yw]*
       G[{yu}, yv^(-1)])/32 - (G[{1}, yv^(-1)]^3*G[{1}, yw]*G[{yu}, yv^(-1)])/
      32 - (5*Pi^2*G[{1}, yw]^2*G[{yu}, yv^(-1)])/192 - 
     (9*G[{0}, yu^(-1)]^2*G[{1}, yw]^2*G[{yu}, yv^(-1)])/256 - 
     (9*G[{0}, yu^(-1)]*G[{0}, yv^(-1)]*G[{1}, yw]^2*G[{yu}, yv^(-1)])/128 - 
     (9*G[{0}, yv^(-1)]^2*G[{1}, yw]^2*G[{yu}, yv^(-1)])/256 + 
     (9*G[{0}, yu^(-1)]*G[{0}, yw]*G[{1}, yw]^2*G[{yu}, yv^(-1)])/128 + 
     (9*G[{0}, yv^(-1)]*G[{0}, yw]*G[{1}, yw]^2*G[{yu}, yv^(-1)])/128 - 
     (9*G[{0}, yw]^2*G[{1}, yw]^2*G[{yu}, yv^(-1)])/256 - 
     (7*G[{0}, yu^(-1)]*G[{1}, yu^(-1)]*G[{1}, yw]^2*G[{yu}, yv^(-1)])/128 - 
     (7*G[{0}, yv^(-1)]*G[{1}, yu^(-1)]*G[{1}, yw]^2*G[{yu}, yv^(-1)])/128 + 
     (7*G[{0}, yw]*G[{1}, yu^(-1)]*G[{1}, yw]^2*G[{yu}, yv^(-1)])/128 + 
     (17*G[{1}, yu^(-1)]^2*G[{1}, yw]^2*G[{yu}, yv^(-1)])/256 - 
     (3*G[{0}, yu^(-1)]*G[{1}, yv^(-1)]*G[{1}, yw]^2*G[{yu}, yv^(-1)])/128 - 
     (3*G[{0}, yv^(-1)]*G[{1}, yv^(-1)]*G[{1}, yw]^2*G[{yu}, yv^(-1)])/128 + 
     (3*G[{0}, yw]*G[{1}, yv^(-1)]*G[{1}, yw]^2*G[{yu}, yv^(-1)])/128 - 
     (5*G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*G[{1}, yw]^2*G[{yu}, yv^(-1)])/64 + 
     (19*G[{1}, yv^(-1)]^2*G[{1}, yw]^2*G[{yu}, yv^(-1)])/256 + 
     (G[{0}, yu^(-1)]*G[{1}, yw]^3*G[{yu}, yv^(-1)])/384 + 
     (G[{0}, yv^(-1)]*G[{1}, yw]^3*G[{yu}, yv^(-1)])/384 - 
     (G[{0}, yw]*G[{1}, yw]^3*G[{yu}, yv^(-1)])/384 - 
     (G[{1}, yu^(-1)]*G[{1}, yw]^3*G[{yu}, yv^(-1)])/32 - 
     (7*G[{1}, yv^(-1)]*G[{1}, yw]^3*G[{yu}, yv^(-1)])/128 + 
     (23*Pi^2*G[{1}, yw]*G[{yu}, yv^(-1)]^2)/512 + 
     (3*G[{0}, yu^(-1)]^2*G[{1}, yw]*G[{yu}, yv^(-1)]^2)/128 + 
     (3*G[{0}, yu^(-1)]*G[{0}, yv^(-1)]*G[{1}, yw]*G[{yu}, yv^(-1)]^2)/64 + 
     (3*G[{0}, yv^(-1)]^2*G[{1}, yw]*G[{yu}, yv^(-1)]^2)/128 - 
     (3*G[{0}, yu^(-1)]*G[{0}, yw]*G[{1}, yw]*G[{yu}, yv^(-1)]^2)/64 - 
     (3*G[{0}, yv^(-1)]*G[{0}, yw]*G[{1}, yw]*G[{yu}, yv^(-1)]^2)/64 + 
     (3*G[{0}, yw]^2*G[{1}, yw]*G[{yu}, yv^(-1)]^2)/128 + 
     (9*G[{0}, yu^(-1)]*G[{1}, yu^(-1)]*G[{1}, yw]*G[{yu}, yv^(-1)]^2)/64 + 
     (9*G[{0}, yv^(-1)]*G[{1}, yu^(-1)]*G[{1}, yw]*G[{yu}, yv^(-1)]^2)/64 - 
     (9*G[{0}, yw]*G[{1}, yu^(-1)]*G[{1}, yw]*G[{yu}, yv^(-1)]^2)/64 - 
     (3*G[{1}, yu^(-1)]^2*G[{1}, yw]*G[{yu}, yv^(-1)]^2)/32 + 
     (G[{0}, yu^(-1)]*G[{1}, yv^(-1)]*G[{1}, yw]*G[{yu}, yv^(-1)]^2)/64 + 
     (G[{0}, yv^(-1)]*G[{1}, yv^(-1)]*G[{1}, yw]*G[{yu}, yv^(-1)]^2)/64 - 
     (G[{0}, yw]*G[{1}, yv^(-1)]*G[{1}, yw]*G[{yu}, yv^(-1)]^2)/64 + 
     (3*G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*G[{1}, yw]*G[{yu}, yv^(-1)]^2)/64 - 
     (9*G[{1}, yv^(-1)]^2*G[{1}, yw]*G[{yu}, yv^(-1)]^2)/128 + 
     (7*G[{0}, yu^(-1)]*G[{1}, yw]^2*G[{yu}, yv^(-1)]^2)/64 + 
     (7*G[{0}, yv^(-1)]*G[{1}, yw]^2*G[{yu}, yv^(-1)]^2)/64 - 
     (7*G[{0}, yw]*G[{1}, yw]^2*G[{yu}, yv^(-1)]^2)/64 + 
     (7*G[{1}, yu^(-1)]*G[{1}, yw]^2*G[{yu}, yv^(-1)]^2)/256 + 
     (G[{1}, yv^(-1)]*G[{1}, yw]^2*G[{yu}, yv^(-1)]^2)/64 + 
     (31*G[{1}, yw]^3*G[{yu}, yv^(-1)]^2)/768 - 
     (G[{0}, yu^(-1)]*G[{1}, yw]*G[{yu}, yv^(-1)]^3)/12 - 
     (G[{0}, yv^(-1)]*G[{1}, yw]*G[{yu}, yv^(-1)]^3)/12 + 
     (G[{0}, yw]*G[{1}, yw]*G[{yu}, yv^(-1)]^3)/12 - 
     (3*G[{1}, yu^(-1)]*G[{1}, yw]*G[{yu}, yv^(-1)]^3)/64 - 
     (67*G[{1}, yw]^2*G[{yu}, yv^(-1)]^3)/768 + 
     (41*G[{1}, yw]*G[{yu}, yv^(-1)]^4)/768 + (Pi^4*G[{1/(yu*yv)}, yw])/
      1152 - (Pi^2*G[{0}, yu^(-1)]*G[{1}, yu^(-1)]*G[{1/(yu*yv)}, yw])/48 - 
     (Pi^2*G[{0}, yv^(-1)]*G[{1}, yu^(-1)]*G[{1/(yu*yv)}, yw])/48 + 
     (Pi^2*G[{0}, yw]*G[{1}, yu^(-1)]*G[{1/(yu*yv)}, yw])/48 + 
     (5*Pi^2*G[{1}, yu^(-1)]^2*G[{1/(yu*yv)}, yw])/192 - 
     (9*G[{0}, yu^(-1)]^2*G[{1}, yu^(-1)]^2*G[{1/(yu*yv)}, yw])/256 - 
     (9*G[{0}, yu^(-1)]*G[{0}, yv^(-1)]*G[{1}, yu^(-1)]^2*G[{1/(yu*yv)}, yw])/
      128 - (9*G[{0}, yv^(-1)]^2*G[{1}, yu^(-1)]^2*G[{1/(yu*yv)}, yw])/256 + 
     (9*G[{0}, yu^(-1)]*G[{0}, yw]*G[{1}, yu^(-1)]^2*G[{1/(yu*yv)}, yw])/
      128 + (9*G[{0}, yv^(-1)]*G[{0}, yw]*G[{1}, yu^(-1)]^2*
       G[{1/(yu*yv)}, yw])/128 - (9*G[{0}, yw]^2*G[{1}, yu^(-1)]^2*
       G[{1/(yu*yv)}, yw])/256 + (3*G[{0}, yu^(-1)]*G[{1}, yu^(-1)]^3*
       G[{1/(yu*yv)}, yw])/32 + (3*G[{0}, yv^(-1)]*G[{1}, yu^(-1)]^3*
       G[{1/(yu*yv)}, yw])/32 - (3*G[{0}, yw]*G[{1}, yu^(-1)]^3*
       G[{1/(yu*yv)}, yw])/32 - (15*G[{1}, yu^(-1)]^4*G[{1/(yu*yv)}, yw])/
      256 - (7*Pi^2*G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*G[{1/(yu*yv)}, yw])/256 + 
     (3*G[{0}, yu^(-1)]^2*G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*G[{1/(yu*yv)}, yw])/
      128 + (3*G[{0}, yu^(-1)]*G[{0}, yv^(-1)]*G[{1}, yu^(-1)]*
       G[{1}, yv^(-1)]*G[{1/(yu*yv)}, yw])/64 + 
     (3*G[{0}, yv^(-1)]^2*G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*G[{1/(yu*yv)}, yw])/
      128 - (3*G[{0}, yu^(-1)]*G[{0}, yw]*G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*
       G[{1/(yu*yv)}, yw])/64 - (3*G[{0}, yv^(-1)]*G[{0}, yw]*G[{1}, yu^(-1)]*
       G[{1}, yv^(-1)]*G[{1/(yu*yv)}, yw])/64 + 
     (3*G[{0}, yw]^2*G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*G[{1/(yu*yv)}, yw])/
      128 - (9*G[{0}, yu^(-1)]*G[{1}, yu^(-1)]^2*G[{1}, yv^(-1)]*
       G[{1/(yu*yv)}, yw])/64 - (9*G[{0}, yv^(-1)]*G[{1}, yu^(-1)]^2*
       G[{1}, yv^(-1)]*G[{1/(yu*yv)}, yw])/64 + 
     (9*G[{0}, yw]*G[{1}, yu^(-1)]^2*G[{1}, yv^(-1)]*G[{1/(yu*yv)}, yw])/64 + 
     (3*G[{1}, yu^(-1)]^3*G[{1}, yv^(-1)]*G[{1/(yu*yv)}, yw])/32 + 
     (Pi^2*G[{1}, yv^(-1)]^2*G[{1/(yu*yv)}, yw])/192 + 
     (5*G[{0}, yu^(-1)]*G[{1}, yu^(-1)]*G[{1}, yv^(-1)]^2*G[{1/(yu*yv)}, yw])/
      128 + (5*G[{0}, yv^(-1)]*G[{1}, yu^(-1)]*G[{1}, yv^(-1)]^2*
       G[{1/(yu*yv)}, yw])/128 - (5*G[{0}, yw]*G[{1}, yu^(-1)]*
       G[{1}, yv^(-1)]^2*G[{1/(yu*yv)}, yw])/128 - 
     (G[{1}, yu^(-1)]^2*G[{1}, yv^(-1)]^2*G[{1/(yu*yv)}, yw])/256 - 
     (G[{1}, yu^(-1)]*G[{1}, yv^(-1)]^3*G[{1/(yu*yv)}, yw])/96 - 
     (Pi^2*G[{0}, yu^(-1)]*G[{1}, yw]*G[{1/(yu*yv)}, yw])/48 - 
     (Pi^2*G[{0}, yv^(-1)]*G[{1}, yw]*G[{1/(yu*yv)}, yw])/48 + 
     (Pi^2*G[{0}, yw]*G[{1}, yw]*G[{1/(yu*yv)}, yw])/48 - 
     (Pi^2*G[{1}, yu^(-1)]*G[{1}, yw]*G[{1/(yu*yv)}, yw])/32 - 
     (9*G[{0}, yu^(-1)]^2*G[{1}, yu^(-1)]*G[{1}, yw]*G[{1/(yu*yv)}, yw])/
      128 - (9*G[{0}, yu^(-1)]*G[{0}, yv^(-1)]*G[{1}, yu^(-1)]*G[{1}, yw]*
       G[{1/(yu*yv)}, yw])/64 - (9*G[{0}, yv^(-1)]^2*G[{1}, yu^(-1)]*
       G[{1}, yw]*G[{1/(yu*yv)}, yw])/128 + 
     (9*G[{0}, yu^(-1)]*G[{0}, yw]*G[{1}, yu^(-1)]*G[{1}, yw]*
       G[{1/(yu*yv)}, yw])/64 + (9*G[{0}, yv^(-1)]*G[{0}, yw]*G[{1}, yu^(-1)]*
       G[{1}, yw]*G[{1/(yu*yv)}, yw])/64 - 
     (9*G[{0}, yw]^2*G[{1}, yu^(-1)]*G[{1}, yw]*G[{1/(yu*yv)}, yw])/128 + 
     (5*G[{0}, yu^(-1)]*G[{1}, yu^(-1)]^2*G[{1}, yw]*G[{1/(yu*yv)}, yw])/64 + 
     (5*G[{0}, yv^(-1)]*G[{1}, yu^(-1)]^2*G[{1}, yw]*G[{1/(yu*yv)}, yw])/64 - 
     (5*G[{0}, yw]*G[{1}, yu^(-1)]^2*G[{1}, yw]*G[{1/(yu*yv)}, yw])/64 - 
     (G[{1}, yu^(-1)]^3*G[{1}, yw]*G[{1/(yu*yv)}, yw])/128 - 
     (3*G[{0}, yu^(-1)]*G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*G[{1}, yw]*
       G[{1/(yu*yv)}, yw])/64 - (3*G[{0}, yv^(-1)]*G[{1}, yu^(-1)]*
       G[{1}, yv^(-1)]*G[{1}, yw]*G[{1/(yu*yv)}, yw])/64 + 
     (3*G[{0}, yw]*G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*G[{1}, yw]*
       G[{1/(yu*yv)}, yw])/64 + (G[{1}, yu^(-1)]^2*G[{1}, yv^(-1)]*G[{1}, yw]*
       G[{1/(yu*yv)}, yw])/16 + (G[{1}, yu^(-1)]*G[{1}, yv^(-1)]^2*G[{1}, yw]*
       G[{1/(yu*yv)}, yw])/128 - (Pi^2*G[{1}, yw]^2*G[{1/(yu*yv)}, yw])/32 - 
     (9*G[{0}, yu^(-1)]^2*G[{1}, yw]^2*G[{1/(yu*yv)}, yw])/256 - 
     (9*G[{0}, yu^(-1)]*G[{0}, yv^(-1)]*G[{1}, yw]^2*G[{1/(yu*yv)}, yw])/
      128 - (9*G[{0}, yv^(-1)]^2*G[{1}, yw]^2*G[{1/(yu*yv)}, yw])/256 + 
     (9*G[{0}, yu^(-1)]*G[{0}, yw]*G[{1}, yw]^2*G[{1/(yu*yv)}, yw])/128 + 
     (9*G[{0}, yv^(-1)]*G[{0}, yw]*G[{1}, yw]^2*G[{1/(yu*yv)}, yw])/128 - 
     (9*G[{0}, yw]^2*G[{1}, yw]^2*G[{1/(yu*yv)}, yw])/256 - 
     (3*G[{0}, yu^(-1)]*G[{1}, yu^(-1)]*G[{1}, yw]^2*G[{1/(yu*yv)}, yw])/32 - 
     (3*G[{0}, yv^(-1)]*G[{1}, yu^(-1)]*G[{1}, yw]^2*G[{1/(yu*yv)}, yw])/32 + 
     (3*G[{0}, yw]*G[{1}, yu^(-1)]*G[{1}, yw]^2*G[{1/(yu*yv)}, yw])/32 + 
     (33*G[{1}, yu^(-1)]^2*G[{1}, yw]^2*G[{1/(yu*yv)}, yw])/256 + 
     (9*G[{0}, yu^(-1)]*G[{1}, yv^(-1)]*G[{1}, yw]^2*G[{1/(yu*yv)}, yw])/
      128 + (9*G[{0}, yv^(-1)]*G[{1}, yv^(-1)]*G[{1}, yw]^2*
       G[{1/(yu*yv)}, yw])/128 - (9*G[{0}, yw]*G[{1}, yv^(-1)]*G[{1}, yw]^2*
       G[{1/(yu*yv)}, yw])/128 + (G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*
       G[{1}, yw]^2*G[{1/(yu*yv)}, yw])/128 - 
     (9*G[{1}, yv^(-1)]^2*G[{1}, yw]^2*G[{1/(yu*yv)}, yw])/256 - 
     (7*G[{0}, yu^(-1)]*G[{1}, yw]^3*G[{1/(yu*yv)}, yw])/192 - 
     (7*G[{0}, yv^(-1)]*G[{1}, yw]^3*G[{1/(yu*yv)}, yw])/192 + 
     (7*G[{0}, yw]*G[{1}, yw]^3*G[{1/(yu*yv)}, yw])/192 + 
     (7*G[{1}, yu^(-1)]*G[{1}, yw]^3*G[{1/(yu*yv)}, yw])/192 + 
     (7*G[{1}, yv^(-1)]*G[{1}, yw]^3*G[{1/(yu*yv)}, yw])/192 - 
     (Pi^2*G[{0}, yu^(-1)]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw])/96 - 
     (Pi^2*G[{0}, yv^(-1)]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw])/96 + 
     (Pi^2*G[{0}, yw]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw])/96 + 
     (Pi^2*G[{1}, yu^(-1)]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw])/24 + 
     (G[{0}, yu^(-1)]*G[{1}, yu^(-1)]^2*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw])/
      16 + (G[{0}, yv^(-1)]*G[{1}, yu^(-1)]^2*G[{yu^(-1)}, yw]*
       G[{1/(yu*yv)}, yw])/16 - (G[{0}, yw]*G[{1}, yu^(-1)]^2*
       G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw])/16 - 
     (5*G[{1}, yu^(-1)]^3*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw])/128 - 
     (Pi^2*G[{1}, yv^(-1)]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw])/48 - 
     (G[{0}, yu^(-1)]*G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*G[{yu^(-1)}, yw]*
       G[{1/(yu*yv)}, yw])/8 - (G[{0}, yv^(-1)]*G[{1}, yu^(-1)]*
       G[{1}, yv^(-1)]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw])/8 + 
     (G[{0}, yw]*G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*G[{yu^(-1)}, yw]*
       G[{1/(yu*yv)}, yw])/8 - (G[{1}, yu^(-1)]^2*G[{1}, yv^(-1)]*
       G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw])/128 + 
     (G[{0}, yu^(-1)]*G[{1}, yv^(-1)]^2*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw])/
      32 + (G[{0}, yv^(-1)]*G[{1}, yv^(-1)]^2*G[{yu^(-1)}, yw]*
       G[{1/(yu*yv)}, yw])/32 - (G[{0}, yw]*G[{1}, yv^(-1)]^2*
       G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw])/32 + 
     (15*G[{1}, yu^(-1)]*G[{1}, yv^(-1)]^2*G[{yu^(-1)}, yw]*
       G[{1/(yu*yv)}, yw])/128 - (G[{1}, yv^(-1)]^3*G[{yu^(-1)}, yw]*
       G[{1/(yu*yv)}, yw])/32 - (Pi^2*G[{1}, yw]*G[{yu^(-1)}, yw]*
       G[{1/(yu*yv)}, yw])/96 + (G[{0}, yu^(-1)]*G[{1}, yu^(-1)]*G[{1}, yw]*
       G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw])/8 + 
     (G[{0}, yv^(-1)]*G[{1}, yu^(-1)]*G[{1}, yw]*G[{yu^(-1)}, yw]*
       G[{1/(yu*yv)}, yw])/8 - (G[{0}, yw]*G[{1}, yu^(-1)]*G[{1}, yw]*
       G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw])/8 - 
     (19*G[{1}, yu^(-1)]^2*G[{1}, yw]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw])/
      128 - (G[{0}, yu^(-1)]*G[{1}, yv^(-1)]*G[{1}, yw]*G[{yu^(-1)}, yw]*
       G[{1/(yu*yv)}, yw])/16 - (G[{0}, yv^(-1)]*G[{1}, yv^(-1)]*G[{1}, yw]*
       G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw])/16 + 
     (G[{0}, yw]*G[{1}, yv^(-1)]*G[{1}, yw]*G[{yu^(-1)}, yw]*
       G[{1/(yu*yv)}, yw])/16 - (11*G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*
       G[{1}, yw]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw])/64 + 
     (3*G[{1}, yv^(-1)]^2*G[{1}, yw]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw])/
      32 - (11*G[{1}, yu^(-1)]*G[{1}, yw]^2*G[{yu^(-1)}, yw]*
       G[{1/(yu*yv)}, yw])/128 - (G[{1}, yv^(-1)]*G[{1}, yw]^2*
       G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw])/32 - 
     (5*G[{1}, yw]^3*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw])/128 + 
     (Pi^2*G[{yu^(-1)}, yw]^2*G[{1/(yu*yv)}, yw])/64 + 
     (5*G[{1}, yu^(-1)]^2*G[{yu^(-1)}, yw]^2*G[{1/(yu*yv)}, yw])/64 - 
     (5*G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*G[{yu^(-1)}, yw]^2*
       G[{1/(yu*yv)}, yw])/32 + (G[{1}, yv^(-1)]^2*G[{yu^(-1)}, yw]^2*
       G[{1/(yu*yv)}, yw])/32 + (G[{0}, yu^(-1)]*G[{1}, yw]*
       G[{yu^(-1)}, yw]^2*G[{1/(yu*yv)}, yw])/16 + 
     (G[{0}, yv^(-1)]*G[{1}, yw]*G[{yu^(-1)}, yw]^2*G[{1/(yu*yv)}, yw])/16 - 
     (G[{0}, yw]*G[{1}, yw]*G[{yu^(-1)}, yw]^2*G[{1/(yu*yv)}, yw])/16 - 
     (G[{1}, yu^(-1)]*G[{1}, yw]*G[{yu^(-1)}, yw]^2*G[{1/(yu*yv)}, yw])/32 - 
     (G[{1}, yv^(-1)]*G[{1}, yw]*G[{yu^(-1)}, yw]^2*G[{1/(yu*yv)}, yw])/8 - 
     (G[{1}, yw]^2*G[{yu^(-1)}, yw]^2*G[{1/(yu*yv)}, yw])/64 - 
     (G[{0}, yu^(-1)]*G[{yu^(-1)}, yw]^3*G[{1/(yu*yv)}, yw])/48 - 
     (G[{0}, yv^(-1)]*G[{yu^(-1)}, yw]^3*G[{1/(yu*yv)}, yw])/48 + 
     (G[{0}, yw]*G[{yu^(-1)}, yw]^3*G[{1/(yu*yv)}, yw])/48 + 
     (G[{1}, yu^(-1)]*G[{yu^(-1)}, yw]^3*G[{1/(yu*yv)}, yw])/16 - 
     (G[{1}, yv^(-1)]*G[{yu^(-1)}, yw]^3*G[{1/(yu*yv)}, yw])/48 + 
     (G[{yu^(-1)}, yw]^4*G[{1/(yu*yv)}, yw])/192 + 
     (Pi^2*G[{0}, yu^(-1)]*G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw])/32 + 
     (Pi^2*G[{0}, yv^(-1)]*G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw])/32 - 
     (Pi^2*G[{0}, yw]*G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw])/32 + 
     (13*Pi^2*G[{1}, yu^(-1)]*G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw])/768 + 
     (3*G[{0}, yu^(-1)]^2*G[{1}, yu^(-1)]*G[{yu}, yv^(-1)]*
       G[{1/(yu*yv)}, yw])/64 + (3*G[{0}, yu^(-1)]*G[{0}, yv^(-1)]*
       G[{1}, yu^(-1)]*G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw])/32 + 
     (3*G[{0}, yv^(-1)]^2*G[{1}, yu^(-1)]*G[{yu}, yv^(-1)]*
       G[{1/(yu*yv)}, yw])/64 - (3*G[{0}, yu^(-1)]*G[{0}, yw]*G[{1}, yu^(-1)]*
       G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw])/32 - 
     (3*G[{0}, yv^(-1)]*G[{0}, yw]*G[{1}, yu^(-1)]*G[{yu}, yv^(-1)]*
       G[{1/(yu*yv)}, yw])/32 + (3*G[{0}, yw]^2*G[{1}, yu^(-1)]*
       G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw])/64 - 
     (3*G[{1}, yu^(-1)]^3*G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw])/64 + 
     (Pi^2*G[{1}, yv^(-1)]*G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw])/96 + 
     (3*G[{0}, yu^(-1)]*G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*G[{yu}, yv^(-1)]*
       G[{1/(yu*yv)}, yw])/32 + (3*G[{0}, yv^(-1)]*G[{1}, yu^(-1)]*
       G[{1}, yv^(-1)]*G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw])/32 - 
     (3*G[{0}, yw]*G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*G[{yu}, yv^(-1)]*
       G[{1/(yu*yv)}, yw])/32 - (3*G[{1}, yu^(-1)]^2*G[{1}, yv^(-1)]*
       G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw])/64 - 
     (G[{0}, yu^(-1)]*G[{1}, yv^(-1)]^2*G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw])/
      32 - (G[{0}, yv^(-1)]*G[{1}, yv^(-1)]^2*G[{yu}, yv^(-1)]*
       G[{1/(yu*yv)}, yw])/32 + (G[{0}, yw]*G[{1}, yv^(-1)]^2*
       G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw])/32 - 
     (3*G[{1}, yu^(-1)]*G[{1}, yv^(-1)]^2*G[{yu}, yv^(-1)]*
       G[{1/(yu*yv)}, yw])/32 + (G[{1}, yv^(-1)]^3*G[{yu}, yv^(-1)]*
       G[{1/(yu*yv)}, yw])/32 + (7*Pi^2*G[{1}, yw]*G[{yu}, yv^(-1)]*
       G[{1/(yu*yv)}, yw])/96 + (9*G[{0}, yu^(-1)]^2*G[{1}, yw]*
       G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw])/128 + 
     (9*G[{0}, yu^(-1)]*G[{0}, yv^(-1)]*G[{1}, yw]*G[{yu}, yv^(-1)]*
       G[{1/(yu*yv)}, yw])/64 + (9*G[{0}, yv^(-1)]^2*G[{1}, yw]*
       G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw])/128 - 
     (9*G[{0}, yu^(-1)]*G[{0}, yw]*G[{1}, yw]*G[{yu}, yv^(-1)]*
       G[{1/(yu*yv)}, yw])/64 - (9*G[{0}, yv^(-1)]*G[{0}, yw]*G[{1}, yw]*
       G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw])/64 + 
     (9*G[{0}, yw]^2*G[{1}, yw]*G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw])/128 + 
     (11*G[{0}, yu^(-1)]*G[{1}, yu^(-1)]*G[{1}, yw]*G[{yu}, yv^(-1)]*
       G[{1/(yu*yv)}, yw])/64 + (11*G[{0}, yv^(-1)]*G[{1}, yu^(-1)]*
       G[{1}, yw]*G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw])/64 - 
     (11*G[{0}, yw]*G[{1}, yu^(-1)]*G[{1}, yw]*G[{yu}, yv^(-1)]*
       G[{1/(yu*yv)}, yw])/64 - (25*G[{1}, yu^(-1)]^2*G[{1}, yw]*
       G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw])/128 + 
     (3*G[{0}, yu^(-1)]*G[{1}, yv^(-1)]*G[{1}, yw]*G[{yu}, yv^(-1)]*
       G[{1/(yu*yv)}, yw])/64 + (3*G[{0}, yv^(-1)]*G[{1}, yv^(-1)]*G[{1}, yw]*
       G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw])/64 - 
     (3*G[{0}, yw]*G[{1}, yv^(-1)]*G[{1}, yw]*G[{yu}, yv^(-1)]*
       G[{1/(yu*yv)}, yw])/64 + (3*G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*G[{1}, yw]*
       G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw])/32 - 
     (19*G[{1}, yv^(-1)]^2*G[{1}, yw]*G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw])/
      128 + (21*G[{0}, yu^(-1)]*G[{1}, yw]^2*G[{yu}, yv^(-1)]*
       G[{1/(yu*yv)}, yw])/128 + (21*G[{0}, yv^(-1)]*G[{1}, yw]^2*
       G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw])/128 - 
     (21*G[{0}, yw]*G[{1}, yw]^2*G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw])/128 - 
     (5*G[{1}, yu^(-1)]*G[{1}, yw]^2*G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw])/
      64 - (G[{1}, yv^(-1)]*G[{1}, yw]^2*G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw])/
      128 - (G[{0}, yu^(-1)]*G[{1}, yw]*G[{yu^(-1)}, yw]*G[{yu}, yv^(-1)]*
       G[{1/(yu*yv)}, yw])/16 - (G[{0}, yv^(-1)]*G[{1}, yw]*G[{yu^(-1)}, yw]*
       G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw])/16 + 
     (G[{0}, yw]*G[{1}, yw]*G[{yu^(-1)}, yw]*G[{yu}, yv^(-1)]*
       G[{1/(yu*yv)}, yw])/16 + (7*G[{1}, yu^(-1)]*G[{1}, yw]*
       G[{yu^(-1)}, yw]*G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw])/32 + 
     (G[{1}, yv^(-1)]*G[{1}, yw]*G[{yu^(-1)}, yw]*G[{yu}, yv^(-1)]*
       G[{1/(yu*yv)}, yw])/16 + (15*G[{1}, yw]^2*G[{yu^(-1)}, yw]*
       G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw])/128 + 
     (G[{1}, yw]*G[{yu^(-1)}, yw]^2*G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw])/32 - 
     (23*Pi^2*G[{yu}, yv^(-1)]^2*G[{1/(yu*yv)}, yw])/512 - 
     (3*G[{0}, yu^(-1)]^2*G[{yu}, yv^(-1)]^2*G[{1/(yu*yv)}, yw])/128 - 
     (3*G[{0}, yu^(-1)]*G[{0}, yv^(-1)]*G[{yu}, yv^(-1)]^2*
       G[{1/(yu*yv)}, yw])/64 - (3*G[{0}, yv^(-1)]^2*G[{yu}, yv^(-1)]^2*
       G[{1/(yu*yv)}, yw])/128 + (3*G[{0}, yu^(-1)]*G[{0}, yw]*
       G[{yu}, yv^(-1)]^2*G[{1/(yu*yv)}, yw])/64 + 
     (3*G[{0}, yv^(-1)]*G[{0}, yw]*G[{yu}, yv^(-1)]^2*G[{1/(yu*yv)}, yw])/
      64 - (3*G[{0}, yw]^2*G[{yu}, yv^(-1)]^2*G[{1/(yu*yv)}, yw])/128 - 
     (9*G[{0}, yu^(-1)]*G[{1}, yu^(-1)]*G[{yu}, yv^(-1)]^2*
       G[{1/(yu*yv)}, yw])/64 - (9*G[{0}, yv^(-1)]*G[{1}, yu^(-1)]*
       G[{yu}, yv^(-1)]^2*G[{1/(yu*yv)}, yw])/64 + 
     (9*G[{0}, yw]*G[{1}, yu^(-1)]*G[{yu}, yv^(-1)]^2*G[{1/(yu*yv)}, yw])/
      64 + (3*G[{1}, yu^(-1)]^2*G[{yu}, yv^(-1)]^2*G[{1/(yu*yv)}, yw])/32 - 
     (G[{0}, yu^(-1)]*G[{1}, yv^(-1)]*G[{yu}, yv^(-1)]^2*G[{1/(yu*yv)}, yw])/
      64 - (G[{0}, yv^(-1)]*G[{1}, yv^(-1)]*G[{yu}, yv^(-1)]^2*
       G[{1/(yu*yv)}, yw])/64 + (G[{0}, yw]*G[{1}, yv^(-1)]*
       G[{yu}, yv^(-1)]^2*G[{1/(yu*yv)}, yw])/64 - 
     (3*G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*G[{yu}, yv^(-1)]^2*
       G[{1/(yu*yv)}, yw])/64 + (9*G[{1}, yv^(-1)]^2*G[{yu}, yv^(-1)]^2*
       G[{1/(yu*yv)}, yw])/128 - (G[{0}, yu^(-1)]*G[{1}, yw]*
       G[{yu}, yv^(-1)]^2*G[{1/(yu*yv)}, yw])/4 - 
     (G[{0}, yv^(-1)]*G[{1}, yw]*G[{yu}, yv^(-1)]^2*G[{1/(yu*yv)}, yw])/4 + 
     (G[{0}, yw]*G[{1}, yw]*G[{yu}, yv^(-1)]^2*G[{1/(yu*yv)}, yw])/4 - 
     (3*G[{1}, yu^(-1)]*G[{1}, yw]*G[{yu}, yv^(-1)]^2*G[{1/(yu*yv)}, yw])/
      128 - (31*G[{1}, yw]^2*G[{yu}, yv^(-1)]^2*G[{1/(yu*yv)}, yw])/256 - 
     (5*G[{1}, yw]*G[{yu^(-1)}, yw]*G[{yu}, yv^(-1)]^2*G[{1/(yu*yv)}, yw])/
      64 + (G[{0}, yu^(-1)]*G[{yu}, yv^(-1)]^3*G[{1/(yu*yv)}, yw])/12 + 
     (G[{0}, yv^(-1)]*G[{yu}, yv^(-1)]^3*G[{1/(yu*yv)}, yw])/12 - 
     (G[{0}, yw]*G[{yu}, yv^(-1)]^3*G[{1/(yu*yv)}, yw])/12 + 
     (3*G[{1}, yu^(-1)]*G[{yu}, yv^(-1)]^3*G[{1/(yu*yv)}, yw])/64 + 
     (67*G[{1}, yw]*G[{yu}, yv^(-1)]^3*G[{1/(yu*yv)}, yw])/384 - 
     (41*G[{yu}, yv^(-1)]^4*G[{1/(yu*yv)}, yw])/768 + 
     (Pi^2*G[{0}, yu^(-1)]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw])/96 + 
     (Pi^2*G[{0}, yv^(-1)]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw])/96 - 
     (Pi^2*G[{0}, yw]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw])/96 - 
     (19*Pi^2*G[{1}, yu^(-1)]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw])/768 + 
     (3*G[{0}, yu^(-1)]^2*G[{1}, yu^(-1)]*G[{yv^(-1)}, yw]*
       G[{1/(yu*yv)}, yw])/64 + (3*G[{0}, yu^(-1)]*G[{0}, yv^(-1)]*
       G[{1}, yu^(-1)]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw])/32 + 
     (3*G[{0}, yv^(-1)]^2*G[{1}, yu^(-1)]*G[{yv^(-1)}, yw]*
       G[{1/(yu*yv)}, yw])/64 - (3*G[{0}, yu^(-1)]*G[{0}, yw]*G[{1}, yu^(-1)]*
       G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw])/32 - 
     (3*G[{0}, yv^(-1)]*G[{0}, yw]*G[{1}, yu^(-1)]*G[{yv^(-1)}, yw]*
       G[{1/(yu*yv)}, yw])/32 + (3*G[{0}, yw]^2*G[{1}, yu^(-1)]*
       G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw])/64 - 
     (G[{0}, yu^(-1)]*G[{1}, yu^(-1)]^2*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw])/
      8 - (G[{0}, yv^(-1)]*G[{1}, yu^(-1)]^2*G[{yv^(-1)}, yw]*
       G[{1/(yu*yv)}, yw])/8 + (G[{0}, yw]*G[{1}, yu^(-1)]^2*G[{yv^(-1)}, yw]*
       G[{1/(yu*yv)}, yw])/8 + (13*G[{1}, yu^(-1)]^3*G[{yv^(-1)}, yw]*
       G[{1/(yu*yv)}, yw])/128 + (Pi^2*G[{1}, yv^(-1)]*G[{yv^(-1)}, yw]*
       G[{1/(yu*yv)}, yw])/96 + (3*G[{0}, yu^(-1)]*G[{1}, yu^(-1)]*
       G[{1}, yv^(-1)]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw])/32 + 
     (3*G[{0}, yv^(-1)]*G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*G[{yv^(-1)}, yw]*
       G[{1/(yu*yv)}, yw])/32 - (3*G[{0}, yw]*G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*
       G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw])/32 - 
     (23*G[{1}, yu^(-1)]^2*G[{1}, yv^(-1)]*G[{yv^(-1)}, yw]*
       G[{1/(yu*yv)}, yw])/128 + (3*G[{1}, yu^(-1)]*G[{1}, yv^(-1)]^2*
       G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw])/128 + 
     (7*Pi^2*G[{1}, yw]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw])/256 + 
     (3*G[{0}, yu^(-1)]^2*G[{1}, yw]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw])/
      64 + (3*G[{0}, yu^(-1)]*G[{0}, yv^(-1)]*G[{1}, yw]*G[{yv^(-1)}, yw]*
       G[{1/(yu*yv)}, yw])/32 + (3*G[{0}, yv^(-1)]^2*G[{1}, yw]*
       G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw])/64 - 
     (3*G[{0}, yu^(-1)]*G[{0}, yw]*G[{1}, yw]*G[{yv^(-1)}, yw]*
       G[{1/(yu*yv)}, yw])/32 - (3*G[{0}, yv^(-1)]*G[{0}, yw]*G[{1}, yw]*
       G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw])/32 + 
     (3*G[{0}, yw]^2*G[{1}, yw]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw])/64 + 
     (G[{0}, yu^(-1)]*G[{1}, yu^(-1)]*G[{1}, yw]*G[{yv^(-1)}, yw]*
       G[{1/(yu*yv)}, yw])/16 + (G[{0}, yv^(-1)]*G[{1}, yu^(-1)]*G[{1}, yw]*
       G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw])/16 - 
     (G[{0}, yw]*G[{1}, yu^(-1)]*G[{1}, yw]*G[{yv^(-1)}, yw]*
       G[{1/(yu*yv)}, yw])/16 - (5*G[{1}, yu^(-1)]^2*G[{1}, yw]*
       G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw])/128 - 
     (3*G[{0}, yu^(-1)]*G[{1}, yv^(-1)]*G[{1}, yw]*G[{yv^(-1)}, yw]*
       G[{1/(yu*yv)}, yw])/32 - (3*G[{0}, yv^(-1)]*G[{1}, yv^(-1)]*G[{1}, yw]*
       G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw])/32 + 
     (3*G[{0}, yw]*G[{1}, yv^(-1)]*G[{1}, yw]*G[{yv^(-1)}, yw]*
       G[{1/(yu*yv)}, yw])/32 - (9*G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*G[{1}, yw]*
       G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw])/64 + 
     (3*G[{1}, yv^(-1)]^2*G[{1}, yw]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw])/
      64 + (G[{0}, yu^(-1)]*G[{1}, yw]^2*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw])/
      8 + (G[{0}, yv^(-1)]*G[{1}, yw]^2*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw])/
      8 - (G[{0}, yw]*G[{1}, yw]^2*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw])/8 - 
     (7*G[{1}, yu^(-1)]*G[{1}, yw]^2*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw])/
      128 - (G[{1}, yv^(-1)]*G[{1}, yw]^2*G[{yv^(-1)}, yw]*
       G[{1/(yu*yv)}, yw])/8 + (3*G[{1}, yw]^3*G[{yv^(-1)}, yw]*
       G[{1/(yu*yv)}, yw])/128 - (Pi^2*G[{yu^(-1)}, yw]*G[{yv^(-1)}, yw]*
       G[{1/(yu*yv)}, yw])/32 - (G[{0}, yu^(-1)]*G[{1}, yu^(-1)]*
       G[{yu^(-1)}, yw]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw])/8 - 
     (G[{0}, yv^(-1)]*G[{1}, yu^(-1)]*G[{yu^(-1)}, yw]*G[{yv^(-1)}, yw]*
       G[{1/(yu*yv)}, yw])/8 + (G[{0}, yw]*G[{1}, yu^(-1)]*G[{yu^(-1)}, yw]*
       G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw])/8 + 
     (3*G[{1}, yu^(-1)]^2*G[{yu^(-1)}, yw]*G[{yv^(-1)}, yw]*
       G[{1/(yu*yv)}, yw])/32 + (G[{0}, yu^(-1)]*G[{1}, yv^(-1)]*
       G[{yu^(-1)}, yw]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw])/8 + 
     (G[{0}, yv^(-1)]*G[{1}, yv^(-1)]*G[{yu^(-1)}, yw]*G[{yv^(-1)}, yw]*
       G[{1/(yu*yv)}, yw])/8 - (G[{0}, yw]*G[{1}, yv^(-1)]*G[{yu^(-1)}, yw]*
       G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw])/8 + 
     (G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*G[{yu^(-1)}, yw]*G[{yv^(-1)}, yw]*
       G[{1/(yu*yv)}, yw])/16 - (G[{1}, yv^(-1)]^2*G[{yu^(-1)}, yw]*
       G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw])/8 + 
     (G[{1}, yu^(-1)]*G[{1}, yw]*G[{yu^(-1)}, yw]*G[{yv^(-1)}, yw]*
       G[{1/(yu*yv)}, yw])/16 + (G[{1}, yv^(-1)]*G[{1}, yw]*G[{yu^(-1)}, yw]*
       G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw])/8 + 
     (3*G[{1}, yw]^2*G[{yu^(-1)}, yw]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw])/
      32 - (G[{0}, yu^(-1)]*G[{yu^(-1)}, yw]^2*G[{yv^(-1)}, yw]*
       G[{1/(yu*yv)}, yw])/16 - (G[{0}, yv^(-1)]*G[{yu^(-1)}, yw]^2*
       G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw])/16 + 
     (G[{0}, yw]*G[{yu^(-1)}, yw]^2*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw])/16 - 
     (G[{1}, yu^(-1)]*G[{yu^(-1)}, yw]^2*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw])/
      16 + (3*G[{1}, yv^(-1)]*G[{yu^(-1)}, yw]^2*G[{yv^(-1)}, yw]*
       G[{1/(yu*yv)}, yw])/16 - (G[{yu^(-1)}, yw]^3*G[{yv^(-1)}, yw]*
       G[{1/(yu*yv)}, yw])/16 - (5*Pi^2*G[{yu}, yv^(-1)]*G[{yv^(-1)}, yw]*
       G[{1/(yu*yv)}, yw])/768 - (3*G[{0}, yu^(-1)]^2*G[{yu}, yv^(-1)]*
       G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw])/64 - 
     (3*G[{0}, yu^(-1)]*G[{0}, yv^(-1)]*G[{yu}, yv^(-1)]*G[{yv^(-1)}, yw]*
       G[{1/(yu*yv)}, yw])/32 - (3*G[{0}, yv^(-1)]^2*G[{yu}, yv^(-1)]*
       G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw])/64 + 
     (3*G[{0}, yu^(-1)]*G[{0}, yw]*G[{yu}, yv^(-1)]*G[{yv^(-1)}, yw]*
       G[{1/(yu*yv)}, yw])/32 + (3*G[{0}, yv^(-1)]*G[{0}, yw]*
       G[{yu}, yv^(-1)]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw])/32 - 
     (3*G[{0}, yw]^2*G[{yu}, yv^(-1)]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw])/
      64 - (G[{0}, yu^(-1)]*G[{1}, yu^(-1)]*G[{yu}, yv^(-1)]*G[{yv^(-1)}, yw]*
       G[{1/(yu*yv)}, yw])/32 - (G[{0}, yv^(-1)]*G[{1}, yu^(-1)]*
       G[{yu}, yv^(-1)]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw])/32 + 
     (G[{0}, yw]*G[{1}, yu^(-1)]*G[{yu}, yv^(-1)]*G[{yv^(-1)}, yw]*
       G[{1/(yu*yv)}, yw])/32 + (G[{1}, yu^(-1)]^2*G[{yu}, yv^(-1)]*
       G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw])/8 - 
     (G[{0}, yu^(-1)]*G[{1}, yv^(-1)]*G[{yu}, yv^(-1)]*G[{yv^(-1)}, yw]*
       G[{1/(yu*yv)}, yw])/32 - (G[{0}, yv^(-1)]*G[{1}, yv^(-1)]*
       G[{yu}, yv^(-1)]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw])/32 + 
     (G[{0}, yw]*G[{1}, yv^(-1)]*G[{yu}, yv^(-1)]*G[{yv^(-1)}, yw]*
       G[{1/(yu*yv)}, yw])/32 + (G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*
       G[{yu}, yv^(-1)]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw])/32 + 
     (5*G[{1}, yv^(-1)]^2*G[{yu}, yv^(-1)]*G[{yv^(-1)}, yw]*
       G[{1/(yu*yv)}, yw])/64 - (5*G[{0}, yu^(-1)]*G[{1}, yw]*
       G[{yu}, yv^(-1)]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw])/32 - 
     (5*G[{0}, yv^(-1)]*G[{1}, yw]*G[{yu}, yv^(-1)]*G[{yv^(-1)}, yw]*
       G[{1/(yu*yv)}, yw])/32 + (5*G[{0}, yw]*G[{1}, yw]*G[{yu}, yv^(-1)]*
       G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw])/32 + 
     (3*G[{1}, yu^(-1)]*G[{1}, yw]*G[{yu}, yv^(-1)]*G[{yv^(-1)}, yw]*
       G[{1/(yu*yv)}, yw])/32 + (G[{1}, yv^(-1)]*G[{1}, yw]*G[{yu}, yv^(-1)]*
       G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw])/32 - 
     (9*G[{1}, yw]^2*G[{yu}, yv^(-1)]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw])/
      128 - (3*G[{1}, yw]*G[{yu^(-1)}, yw]*G[{yu}, yv^(-1)]*G[{yv^(-1)}, yw]*
       G[{1/(yu*yv)}, yw])/16 + (G[{0}, yu^(-1)]*G[{yu}, yv^(-1)]^2*
       G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw])/8 + 
     (G[{0}, yv^(-1)]*G[{yu}, yv^(-1)]^2*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw])/
      8 - (G[{0}, yw]*G[{yu}, yv^(-1)]^2*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw])/
      8 - (7*G[{1}, yu^(-1)]*G[{yu}, yv^(-1)]^2*G[{yv^(-1)}, yw]*
       G[{1/(yu*yv)}, yw])/64 + (3*G[{1}, yw]*G[{yu}, yv^(-1)]^2*
       G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw])/32 - 
     (3*G[{yu}, yv^(-1)]^3*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw])/64 + 
     (Pi^2*G[{yv^(-1)}, yw]^2*G[{1/(yu*yv)}, yw])/512 - 
     (3*G[{0}, yu^(-1)]^2*G[{yv^(-1)}, yw]^2*G[{1/(yu*yv)}, yw])/128 - 
     (3*G[{0}, yu^(-1)]*G[{0}, yv^(-1)]*G[{yv^(-1)}, yw]^2*
       G[{1/(yu*yv)}, yw])/64 - (3*G[{0}, yv^(-1)]^2*G[{yv^(-1)}, yw]^2*
       G[{1/(yu*yv)}, yw])/128 + (3*G[{0}, yu^(-1)]*G[{0}, yw]*
       G[{yv^(-1)}, yw]^2*G[{1/(yu*yv)}, yw])/64 + 
     (3*G[{0}, yv^(-1)]*G[{0}, yw]*G[{yv^(-1)}, yw]^2*G[{1/(yu*yv)}, yw])/
      64 - (3*G[{0}, yw]^2*G[{yv^(-1)}, yw]^2*G[{1/(yu*yv)}, yw])/128 + 
     (3*G[{0}, yu^(-1)]*G[{1}, yu^(-1)]*G[{yv^(-1)}, yw]^2*
       G[{1/(yu*yv)}, yw])/64 + (3*G[{0}, yv^(-1)]*G[{1}, yu^(-1)]*
       G[{yv^(-1)}, yw]^2*G[{1/(yu*yv)}, yw])/64 - 
     (3*G[{0}, yw]*G[{1}, yu^(-1)]*G[{yv^(-1)}, yw]^2*G[{1/(yu*yv)}, yw])/
      64 - (G[{1}, yu^(-1)]^2*G[{yv^(-1)}, yw]^2*G[{1/(yu*yv)}, yw])/64 + 
     (3*G[{0}, yu^(-1)]*G[{1}, yv^(-1)]*G[{yv^(-1)}, yw]^2*
       G[{1/(yu*yv)}, yw])/64 + (3*G[{0}, yv^(-1)]*G[{1}, yv^(-1)]*
       G[{yv^(-1)}, yw]^2*G[{1/(yu*yv)}, yw])/64 - 
     (3*G[{0}, yw]*G[{1}, yv^(-1)]*G[{yv^(-1)}, yw]^2*G[{1/(yu*yv)}, yw])/
      64 + (3*G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*G[{yv^(-1)}, yw]^2*
       G[{1/(yu*yv)}, yw])/64 - (3*G[{1}, yv^(-1)]^2*G[{yv^(-1)}, yw]^2*
       G[{1/(yu*yv)}, yw])/128 - (7*G[{0}, yu^(-1)]*G[{1}, yw]*
       G[{yv^(-1)}, yw]^2*G[{1/(yu*yv)}, yw])/64 - 
     (7*G[{0}, yv^(-1)]*G[{1}, yw]*G[{yv^(-1)}, yw]^2*G[{1/(yu*yv)}, yw])/
      64 + (7*G[{0}, yw]*G[{1}, yw]*G[{yv^(-1)}, yw]^2*G[{1/(yu*yv)}, yw])/
      64 + (G[{1}, yu^(-1)]*G[{1}, yw]*G[{yv^(-1)}, yw]^2*G[{1/(yu*yv)}, yw])/
      8 + (7*G[{1}, yv^(-1)]*G[{1}, yw]*G[{yv^(-1)}, yw]^2*
       G[{1/(yu*yv)}, yw])/64 + (G[{1}, yw]^2*G[{yv^(-1)}, yw]^2*
       G[{1/(yu*yv)}, yw])/128 + (G[{0}, yu^(-1)]*G[{yu^(-1)}, yw]*
       G[{yv^(-1)}, yw]^2*G[{1/(yu*yv)}, yw])/16 + 
     (G[{0}, yv^(-1)]*G[{yu^(-1)}, yw]*G[{yv^(-1)}, yw]^2*G[{1/(yu*yv)}, yw])/
      16 - (G[{0}, yw]*G[{yu^(-1)}, yw]*G[{yv^(-1)}, yw]^2*
       G[{1/(yu*yv)}, yw])/16 - (G[{1}, yu^(-1)]*G[{yu^(-1)}, yw]*
       G[{yv^(-1)}, yw]^2*G[{1/(yu*yv)}, yw])/16 - 
     (G[{1}, yv^(-1)]*G[{yu^(-1)}, yw]*G[{yv^(-1)}, yw]^2*G[{1/(yu*yv)}, yw])/
      16 + (G[{yu^(-1)}, yw]^2*G[{yv^(-1)}, yw]^2*G[{1/(yu*yv)}, yw])/32 - 
     (7*G[{1}, yu^(-1)]*G[{yu}, yv^(-1)]*G[{yv^(-1)}, yw]^2*
       G[{1/(yu*yv)}, yw])/64 - (G[{1}, yw]*G[{yu}, yv^(-1)]*
       G[{yv^(-1)}, yw]^2*G[{1/(yu*yv)}, yw])/64 + 
     (7*G[{yu}, yv^(-1)]^2*G[{yv^(-1)}, yw]^2*G[{1/(yu*yv)}, yw])/128 + 
     (G[{0}, yu^(-1)]*G[{yv^(-1)}, yw]^3*G[{1/(yu*yv)}, yw])/48 + 
     (G[{0}, yv^(-1)]*G[{yv^(-1)}, yw]^3*G[{1/(yu*yv)}, yw])/48 - 
     (G[{0}, yw]*G[{yv^(-1)}, yw]^3*G[{1/(yu*yv)}, yw])/48 - 
     (11*G[{1}, yu^(-1)]*G[{yv^(-1)}, yw]^3*G[{1/(yu*yv)}, yw])/192 - 
     (G[{1}, yv^(-1)]*G[{yv^(-1)}, yw]^3*G[{1/(yu*yv)}, yw])/48 - 
     (7*G[{1}, yw]*G[{yv^(-1)}, yw]^3*G[{1/(yu*yv)}, yw])/192 + 
     (G[{yu^(-1)}, yw]*G[{yv^(-1)}, yw]^3*G[{1/(yu*yv)}, yw])/48 + 
     (7*G[{yu}, yv^(-1)]*G[{yv^(-1)}, yw]^3*G[{1/(yu*yv)}, yw])/192 + 
     (11*G[{yv^(-1)}, yw]^4*G[{1/(yu*yv)}, yw])/768 + 
     (Pi^2*G[{0}, yu^(-1)]*G[{1/(yu*yv)}, yw]^2)/192 + 
     (Pi^2*G[{0}, yv^(-1)]*G[{1/(yu*yv)}, yw]^2)/192 - 
     (Pi^2*G[{0}, yw]*G[{1/(yu*yv)}, yw]^2)/192 - 
     (7*Pi^2*G[{1}, yu^(-1)]*G[{1/(yu*yv)}, yw]^2)/512 + 
     (3*G[{0}, yu^(-1)]^2*G[{1}, yu^(-1)]*G[{1/(yu*yv)}, yw]^2)/256 + 
     (3*G[{0}, yu^(-1)]*G[{0}, yv^(-1)]*G[{1}, yu^(-1)]*G[{1/(yu*yv)}, yw]^2)/
      128 + (3*G[{0}, yv^(-1)]^2*G[{1}, yu^(-1)]*G[{1/(yu*yv)}, yw]^2)/256 - 
     (3*G[{0}, yu^(-1)]*G[{0}, yw]*G[{1}, yu^(-1)]*G[{1/(yu*yv)}, yw]^2)/
      128 - (3*G[{0}, yv^(-1)]*G[{0}, yw]*G[{1}, yu^(-1)]*
       G[{1/(yu*yv)}, yw]^2)/128 + (3*G[{0}, yw]^2*G[{1}, yu^(-1)]*
       G[{1/(yu*yv)}, yw]^2)/256 - (5*G[{0}, yu^(-1)]*G[{1}, yu^(-1)]^2*
       G[{1/(yu*yv)}, yw]^2)/64 - (5*G[{0}, yv^(-1)]*G[{1}, yu^(-1)]^2*
       G[{1/(yu*yv)}, yw]^2)/64 + (5*G[{0}, yw]*G[{1}, yu^(-1)]^2*
       G[{1/(yu*yv)}, yw]^2)/64 + (17*G[{1}, yu^(-1)]^3*G[{1/(yu*yv)}, yw]^2)/
      256 + (Pi^2*G[{1}, yv^(-1)]*G[{1/(yu*yv)}, yw]^2)/192 + 
     (11*G[{0}, yu^(-1)]*G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*
       G[{1/(yu*yv)}, yw]^2)/128 + (11*G[{0}, yv^(-1)]*G[{1}, yu^(-1)]*
       G[{1}, yv^(-1)]*G[{1/(yu*yv)}, yw]^2)/128 - 
     (11*G[{0}, yw]*G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*G[{1/(yu*yv)}, yw]^2)/
      128 - (5*G[{1}, yu^(-1)]^2*G[{1}, yv^(-1)]*G[{1/(yu*yv)}, yw]^2)/64 - 
     (G[{0}, yu^(-1)]*G[{1}, yv^(-1)]^2*G[{1/(yu*yv)}, yw]^2)/64 - 
     (G[{0}, yv^(-1)]*G[{1}, yv^(-1)]^2*G[{1/(yu*yv)}, yw]^2)/64 + 
     (G[{0}, yw]*G[{1}, yv^(-1)]^2*G[{1/(yu*yv)}, yw]^2)/64 - 
     (9*G[{1}, yu^(-1)]*G[{1}, yv^(-1)]^2*G[{1/(yu*yv)}, yw]^2)/256 + 
     (G[{1}, yv^(-1)]^3*G[{1/(yu*yv)}, yw]^2)/64 + 
     (Pi^2*G[{1}, yw]*G[{1/(yu*yv)}, yw]^2)/512 + 
     (3*G[{0}, yu^(-1)]^2*G[{1}, yw]*G[{1/(yu*yv)}, yw]^2)/256 + 
     (3*G[{0}, yu^(-1)]*G[{0}, yv^(-1)]*G[{1}, yw]*G[{1/(yu*yv)}, yw]^2)/
      128 + (3*G[{0}, yv^(-1)]^2*G[{1}, yw]*G[{1/(yu*yv)}, yw]^2)/256 - 
     (3*G[{0}, yu^(-1)]*G[{0}, yw]*G[{1}, yw]*G[{1/(yu*yv)}, yw]^2)/128 - 
     (3*G[{0}, yv^(-1)]*G[{0}, yw]*G[{1}, yw]*G[{1/(yu*yv)}, yw]^2)/128 + 
     (3*G[{0}, yw]^2*G[{1}, yw]*G[{1/(yu*yv)}, yw]^2)/256 - 
     (5*G[{0}, yu^(-1)]*G[{1}, yu^(-1)]*G[{1}, yw]*G[{1/(yu*yv)}, yw]^2)/64 - 
     (5*G[{0}, yv^(-1)]*G[{1}, yu^(-1)]*G[{1}, yw]*G[{1/(yu*yv)}, yw]^2)/64 + 
     (5*G[{0}, yw]*G[{1}, yu^(-1)]*G[{1}, yw]*G[{1/(yu*yv)}, yw]^2)/64 + 
     (5*G[{1}, yu^(-1)]^2*G[{1}, yw]*G[{1/(yu*yv)}, yw]^2)/256 + 
     (9*G[{0}, yu^(-1)]*G[{1}, yv^(-1)]*G[{1}, yw]*G[{1/(yu*yv)}, yw]^2)/
      128 + (9*G[{0}, yv^(-1)]*G[{1}, yv^(-1)]*G[{1}, yw]*
       G[{1/(yu*yv)}, yw]^2)/128 - (9*G[{0}, yw]*G[{1}, yv^(-1)]*G[{1}, yw]*
       G[{1/(yu*yv)}, yw]^2)/128 - (9*G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*
       G[{1}, yw]*G[{1/(yu*yv)}, yw]^2)/128 - 
     (17*G[{1}, yv^(-1)]^2*G[{1}, yw]*G[{1/(yu*yv)}, yw]^2)/256 + 
     (3*G[{0}, yu^(-1)]*G[{1}, yw]^2*G[{1/(yu*yv)}, yw]^2)/64 + 
     (3*G[{0}, yv^(-1)]*G[{1}, yw]^2*G[{1/(yu*yv)}, yw]^2)/64 - 
     (3*G[{0}, yw]*G[{1}, yw]^2*G[{1/(yu*yv)}, yw]^2)/64 - 
     (G[{1}, yu^(-1)]*G[{1}, yw]^2*G[{1/(yu*yv)}, yw]^2)/8 - 
     (G[{1}, yv^(-1)]*G[{1}, yw]^2*G[{1/(yu*yv)}, yw]^2)/16 - 
     (G[{1}, yw]^3*G[{1/(yu*yv)}, yw]^2)/32 - 
     (Pi^2*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2)/192 - 
     (G[{0}, yu^(-1)]*G[{1}, yu^(-1)]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2)/
      32 - (G[{0}, yv^(-1)]*G[{1}, yu^(-1)]*G[{yu^(-1)}, yw]*
       G[{1/(yu*yv)}, yw]^2)/32 + (G[{0}, yw]*G[{1}, yu^(-1)]*
       G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2)/32 + 
     (3*G[{1}, yu^(-1)]^2*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2)/128 - 
     (G[{0}, yu^(-1)]*G[{1}, yv^(-1)]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2)/
      32 - (G[{0}, yv^(-1)]*G[{1}, yv^(-1)]*G[{yu^(-1)}, yw]*
       G[{1/(yu*yv)}, yw]^2)/32 + (G[{0}, yw]*G[{1}, yv^(-1)]*
       G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2)/32 + 
     (7*G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*G[{yu^(-1)}, yw]*
       G[{1/(yu*yv)}, yw]^2)/64 + (G[{1}, yv^(-1)]^2*G[{yu^(-1)}, yw]*
       G[{1/(yu*yv)}, yw]^2)/64 - (G[{0}, yu^(-1)]*G[{1}, yw]*
       G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2)/8 - 
     (G[{0}, yv^(-1)]*G[{1}, yw]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2)/8 + 
     (G[{0}, yw]*G[{1}, yw]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2)/8 + 
     (9*G[{1}, yu^(-1)]*G[{1}, yw]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2)/
      64 + (G[{1}, yv^(-1)]*G[{1}, yw]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2)/
      8 + (G[{1}, yw]^2*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2)/128 + 
     (3*G[{0}, yu^(-1)]*G[{yu^(-1)}, yw]^2*G[{1/(yu*yv)}, yw]^2)/64 + 
     (3*G[{0}, yv^(-1)]*G[{yu^(-1)}, yw]^2*G[{1/(yu*yv)}, yw]^2)/64 - 
     (3*G[{0}, yw]*G[{yu^(-1)}, yw]^2*G[{1/(yu*yv)}, yw]^2)/64 - 
     (5*G[{1}, yu^(-1)]*G[{yu^(-1)}, yw]^2*G[{1/(yu*yv)}, yw]^2)/64 - 
     (3*G[{1}, yv^(-1)]*G[{yu^(-1)}, yw]^2*G[{1/(yu*yv)}, yw]^2)/64 - 
     (G[{1}, yw]*G[{yu^(-1)}, yw]^2*G[{1/(yu*yv)}, yw]^2)/32 + 
     (G[{yu^(-1)}, yw]^3*G[{1/(yu*yv)}, yw]^2)/64 - 
     (Pi^2*G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw]^2)/512 - 
     (3*G[{0}, yu^(-1)]^2*G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw]^2)/256 - 
     (3*G[{0}, yu^(-1)]*G[{0}, yv^(-1)]*G[{yu}, yv^(-1)]*
       G[{1/(yu*yv)}, yw]^2)/128 - (3*G[{0}, yv^(-1)]^2*G[{yu}, yv^(-1)]*
       G[{1/(yu*yv)}, yw]^2)/256 + (3*G[{0}, yu^(-1)]*G[{0}, yw]*
       G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw]^2)/128 + 
     (3*G[{0}, yv^(-1)]*G[{0}, yw]*G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw]^2)/
      128 - (3*G[{0}, yw]^2*G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw]^2)/256 + 
     (3*G[{0}, yu^(-1)]*G[{1}, yu^(-1)]*G[{yu}, yv^(-1)]*
       G[{1/(yu*yv)}, yw]^2)/128 + (3*G[{0}, yv^(-1)]*G[{1}, yu^(-1)]*
       G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw]^2)/128 - 
     (3*G[{0}, yw]*G[{1}, yu^(-1)]*G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw]^2)/
      128 + (9*G[{1}, yu^(-1)]^2*G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw]^2)/256 - 
     (G[{0}, yu^(-1)]*G[{1}, yv^(-1)]*G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw]^2)/
      128 - (G[{0}, yv^(-1)]*G[{1}, yv^(-1)]*G[{yu}, yv^(-1)]*
       G[{1/(yu*yv)}, yw]^2)/128 + (G[{0}, yw]*G[{1}, yv^(-1)]*
       G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw]^2)/128 + 
     (G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw]^2)/
      32 + (G[{1}, yv^(-1)]^2*G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw]^2)/256 - 
     (5*G[{0}, yu^(-1)]*G[{1}, yw]*G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw]^2)/
      128 - (5*G[{0}, yv^(-1)]*G[{1}, yw]*G[{yu}, yv^(-1)]*
       G[{1/(yu*yv)}, yw]^2)/128 + (5*G[{0}, yw]*G[{1}, yw]*G[{yu}, yv^(-1)]*
       G[{1/(yu*yv)}, yw]^2)/128 + (3*G[{1}, yu^(-1)]*G[{1}, yw]*
       G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw]^2)/16 + 
     (9*G[{1}, yv^(-1)]*G[{1}, yw]*G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw]^2)/
      128 + (3*G[{1}, yw]^2*G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw]^2)/32 + 
     (G[{0}, yu^(-1)]*G[{yu^(-1)}, yw]*G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw]^2)/
      16 + (G[{0}, yv^(-1)]*G[{yu^(-1)}, yw]*G[{yu}, yv^(-1)]*
       G[{1/(yu*yv)}, yw]^2)/16 - (G[{0}, yw]*G[{yu^(-1)}, yw]*
       G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw]^2)/16 - 
     (3*G[{1}, yu^(-1)]*G[{yu^(-1)}, yw]*G[{yu}, yv^(-1)]*
       G[{1/(yu*yv)}, yw]^2)/32 - (G[{1}, yv^(-1)]*G[{yu^(-1)}, yw]*
       G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw]^2)/16 - 
     (G[{1}, yw]*G[{yu^(-1)}, yw]*G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw]^2)/64 + 
     (G[{yu^(-1)}, yw]^2*G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw]^2)/32 + 
     (G[{0}, yu^(-1)]*G[{yu}, yv^(-1)]^2*G[{1/(yu*yv)}, yw]^2)/64 + 
     (G[{0}, yv^(-1)]*G[{yu}, yv^(-1)]^2*G[{1/(yu*yv)}, yw]^2)/64 - 
     (G[{0}, yw]*G[{yu}, yv^(-1)]^2*G[{1/(yu*yv)}, yw]^2)/64 - 
     (19*G[{1}, yu^(-1)]*G[{yu}, yv^(-1)]^2*G[{1/(yu*yv)}, yw]^2)/256 - 
     (G[{1}, yv^(-1)]*G[{yu}, yv^(-1)]^2*G[{1/(yu*yv)}, yw]^2)/64 - 
     (23*G[{1}, yw]*G[{yu}, yv^(-1)]^2*G[{1/(yu*yv)}, yw]^2)/256 + 
     (G[{yu^(-1)}, yw]*G[{yu}, yv^(-1)]^2*G[{1/(yu*yv)}, yw]^2)/64 + 
     (5*G[{yu}, yv^(-1)]^3*G[{1/(yu*yv)}, yw]^2)/256 + 
     (7*Pi^2*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2)/512 - 
     (3*G[{0}, yu^(-1)]^2*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2)/256 - 
     (3*G[{0}, yu^(-1)]*G[{0}, yv^(-1)]*G[{yv^(-1)}, yw]*
       G[{1/(yu*yv)}, yw]^2)/128 - (3*G[{0}, yv^(-1)]^2*G[{yv^(-1)}, yw]*
       G[{1/(yu*yv)}, yw]^2)/256 + (3*G[{0}, yu^(-1)]*G[{0}, yw]*
       G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2)/128 + 
     (3*G[{0}, yv^(-1)]*G[{0}, yw]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2)/
      128 - (3*G[{0}, yw]^2*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2)/256 + 
     (15*G[{0}, yu^(-1)]*G[{1}, yu^(-1)]*G[{yv^(-1)}, yw]*
       G[{1/(yu*yv)}, yw]^2)/128 + (15*G[{0}, yv^(-1)]*G[{1}, yu^(-1)]*
       G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2)/128 - 
     (15*G[{0}, yw]*G[{1}, yu^(-1)]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2)/
      128 - (41*G[{1}, yu^(-1)]^2*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2)/
      256 - (13*G[{0}, yu^(-1)]*G[{1}, yv^(-1)]*G[{yv^(-1)}, yw]*
       G[{1/(yu*yv)}, yw]^2)/128 - (13*G[{0}, yv^(-1)]*G[{1}, yv^(-1)]*
       G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2)/128 + 
     (13*G[{0}, yw]*G[{1}, yv^(-1)]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2)/
      128 + (13*G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*G[{yv^(-1)}, yw]*
       G[{1/(yu*yv)}, yw]^2)/64 + (21*G[{1}, yv^(-1)]^2*G[{yv^(-1)}, yw]*
       G[{1/(yu*yv)}, yw]^2)/256 - (3*G[{0}, yu^(-1)]*G[{1}, yw]*
       G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2)/128 - 
     (3*G[{0}, yv^(-1)]*G[{1}, yw]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2)/
      128 + (3*G[{0}, yw]*G[{1}, yw]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2)/
      128 + (5*G[{1}, yu^(-1)]*G[{1}, yw]*G[{yv^(-1)}, yw]*
       G[{1/(yu*yv)}, yw]^2)/128 + (11*G[{1}, yv^(-1)]*G[{1}, yw]*
       G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2)/128 + 
     (5*G[{1}, yw]^2*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2)/128 + 
     (3*G[{0}, yu^(-1)]*G[{yu^(-1)}, yw]*G[{yv^(-1)}, yw]*
       G[{1/(yu*yv)}, yw]^2)/32 + (3*G[{0}, yv^(-1)]*G[{yu^(-1)}, yw]*
       G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2)/32 - 
     (3*G[{0}, yw]*G[{yu^(-1)}, yw]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2)/
      32 - (G[{1}, yu^(-1)]*G[{yu^(-1)}, yw]*G[{yv^(-1)}, yw]*
       G[{1/(yu*yv)}, yw]^2)/8 - (5*G[{1}, yv^(-1)]*G[{yu^(-1)}, yw]*
       G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2)/32 - 
     (3*G[{1}, yw]*G[{yu^(-1)}, yw]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2)/
      32 + (5*G[{yu^(-1)}, yw]^2*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2)/64 + 
     (G[{0}, yu^(-1)]*G[{yu}, yv^(-1)]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2)/
      32 + (G[{0}, yv^(-1)]*G[{yu}, yv^(-1)]*G[{yv^(-1)}, yw]*
       G[{1/(yu*yv)}, yw]^2)/32 - (G[{0}, yw]*G[{yu}, yv^(-1)]*
       G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2)/32 - 
     (15*G[{1}, yu^(-1)]*G[{yu}, yv^(-1)]*G[{yv^(-1)}, yw]*
       G[{1/(yu*yv)}, yw]^2)/128 - (3*G[{1}, yv^(-1)]*G[{yu}, yv^(-1)]*
       G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2)/32 - 
     (5*G[{1}, yw]*G[{yu}, yv^(-1)]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2)/
      64 + (3*G[{yu^(-1)}, yw]*G[{yu}, yv^(-1)]*G[{yv^(-1)}, yw]*
       G[{1/(yu*yv)}, yw]^2)/32 + (19*G[{yu}, yv^(-1)]^2*G[{yv^(-1)}, yw]*
       G[{1/(yu*yv)}, yw]^2)/256 - (G[{0}, yu^(-1)]*G[{yv^(-1)}, yw]^2*
       G[{1/(yu*yv)}, yw]^2)/16 - (G[{0}, yv^(-1)]*G[{yv^(-1)}, yw]^2*
       G[{1/(yu*yv)}, yw]^2)/16 + (G[{0}, yw]*G[{yv^(-1)}, yw]^2*
       G[{1/(yu*yv)}, yw]^2)/16 + (33*G[{1}, yu^(-1)]*G[{yv^(-1)}, yw]^2*
       G[{1/(yu*yv)}, yw]^2)/256 - (G[{1}, yv^(-1)]*G[{yv^(-1)}, yw]^2*
       G[{1/(yu*yv)}, yw]^2)/16 - (15*G[{1}, yw]*G[{yv^(-1)}, yw]^2*
       G[{1/(yu*yv)}, yw]^2)/256 + (G[{yu^(-1)}, yw]*G[{yv^(-1)}, yw]^2*
       G[{1/(yu*yv)}, yw]^2)/16 + (15*G[{yu}, yv^(-1)]*G[{yv^(-1)}, yw]^2*
       G[{1/(yu*yv)}, yw]^2)/256 - (11*G[{yv^(-1)}, yw]^3*
       G[{1/(yu*yv)}, yw]^2)/256 + (5*G[{0}, yu^(-1)]*G[{1}, yu^(-1)]*
       G[{1/(yu*yv)}, yw]^3)/384 + (5*G[{0}, yv^(-1)]*G[{1}, yu^(-1)]*
       G[{1/(yu*yv)}, yw]^3)/384 - (5*G[{0}, yw]*G[{1}, yu^(-1)]*
       G[{1/(yu*yv)}, yw]^3)/384 - (5*G[{1}, yu^(-1)]^2*G[{1/(yu*yv)}, yw]^3)/
      384 + (G[{0}, yu^(-1)]*G[{1}, yv^(-1)]*G[{1/(yu*yv)}, yw]^3)/48 + 
     (G[{0}, yv^(-1)]*G[{1}, yv^(-1)]*G[{1/(yu*yv)}, yw]^3)/48 - 
     (G[{0}, yw]*G[{1}, yv^(-1)]*G[{1/(yu*yv)}, yw]^3)/48 - 
     (3*G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*G[{1/(yu*yv)}, yw]^3)/128 - 
     (G[{1}, yv^(-1)]^2*G[{1/(yu*yv)}, yw]^3)/48 + 
     (13*G[{0}, yu^(-1)]*G[{1}, yw]*G[{1/(yu*yv)}, yw]^3)/384 + 
     (13*G[{0}, yv^(-1)]*G[{1}, yw]*G[{1/(yu*yv)}, yw]^3)/384 - 
     (13*G[{0}, yw]*G[{1}, yw]*G[{1/(yu*yv)}, yw]^3)/384 - 
     (3*G[{1}, yu^(-1)]*G[{1}, yw]*G[{1/(yu*yv)}, yw]^3)/128 - 
     (3*G[{1}, yv^(-1)]*G[{1}, yw]*G[{1/(yu*yv)}, yw]^3)/128 + 
     (G[{1}, yw]^2*G[{1/(yu*yv)}, yw]^3)/96 - 
     (G[{0}, yu^(-1)]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]^3)/48 - 
     (G[{0}, yv^(-1)]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]^3)/48 + 
     (G[{0}, yw]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]^3)/48 + 
     (3*G[{1}, yu^(-1)]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]^3)/128 + 
     (G[{1}, yv^(-1)]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]^3)/24 + 
     (3*G[{1}, yw]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]^3)/128 - 
     (G[{yu^(-1)}, yw]^2*G[{1/(yu*yv)}, yw]^3)/48 - 
     (13*G[{0}, yu^(-1)]*G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw]^3)/384 - 
     (13*G[{0}, yv^(-1)]*G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw]^3)/384 + 
     (13*G[{0}, yw]*G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw]^3)/384 + 
     (3*G[{1}, yu^(-1)]*G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw]^3)/128 + 
     (3*G[{1}, yv^(-1)]*G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw]^3)/128 - 
     (G[{1}, yw]*G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw]^3)/48 - 
     (3*G[{yu^(-1)}, yw]*G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw]^3)/128 + 
     (G[{yu}, yv^(-1)]^2*G[{1/(yu*yv)}, yw]^3)/96 - 
     (5*G[{0}, yu^(-1)]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]^3)/384 - 
     (5*G[{0}, yv^(-1)]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]^3)/384 + 
     (5*G[{0}, yw]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]^3)/384 + 
     (5*G[{1}, yu^(-1)]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]^3)/192 + 
     (3*G[{1}, yv^(-1)]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]^3)/128 + 
     (3*G[{1}, yw]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]^3)/128 - 
     (3*G[{yu^(-1)}, yw]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]^3)/128 - 
     (3*G[{yu}, yv^(-1)]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]^3)/128 - 
     (5*G[{yv^(-1)}, yw]^2*G[{1/(yu*yv)}, yw]^3)/384 - 
     (Pi^2*G[{0}, yu^(-1)]*G[{0, 1}, yu^(-1)])/48 - 
     (Pi^2*G[{0}, yv^(-1)]*G[{0, 1}, yu^(-1)])/48 + 
     (Pi^2*G[{0}, yw]*G[{0, 1}, yu^(-1)])/48 + 
     (5*Pi^2*G[{1}, yu^(-1)]*G[{0, 1}, yu^(-1)])/768 - 
     (3*G[{0}, yu^(-1)]^2*G[{1}, yu^(-1)]*G[{0, 1}, yu^(-1)])/128 - 
     (3*G[{0}, yu^(-1)]*G[{0}, yv^(-1)]*G[{1}, yu^(-1)]*G[{0, 1}, yu^(-1)])/
      64 - (3*G[{0}, yv^(-1)]^2*G[{1}, yu^(-1)]*G[{0, 1}, yu^(-1)])/128 + 
     (3*G[{0}, yu^(-1)]*G[{0}, yw]*G[{1}, yu^(-1)]*G[{0, 1}, yu^(-1)])/64 + 
     (3*G[{0}, yv^(-1)]*G[{0}, yw]*G[{1}, yu^(-1)]*G[{0, 1}, yu^(-1)])/64 - 
     (3*G[{0}, yw]^2*G[{1}, yu^(-1)]*G[{0, 1}, yu^(-1)])/128 + 
     (5*G[{0}, yu^(-1)]*G[{1}, yu^(-1)]^2*G[{0, 1}, yu^(-1)])/64 + 
     (5*G[{0}, yv^(-1)]*G[{1}, yu^(-1)]^2*G[{0, 1}, yu^(-1)])/64 - 
     (5*G[{0}, yw]*G[{1}, yu^(-1)]^2*G[{0, 1}, yu^(-1)])/64 - 
     (13*G[{1}, yu^(-1)]^3*G[{0, 1}, yu^(-1)])/192 + 
     (Pi^2*G[{1}, yv^(-1)]*G[{0, 1}, yu^(-1)])/256 + 
     (3*G[{0}, yu^(-1)]^2*G[{1}, yv^(-1)]*G[{0, 1}, yu^(-1)])/128 + 
     (3*G[{0}, yu^(-1)]*G[{0}, yv^(-1)]*G[{1}, yv^(-1)]*G[{0, 1}, yu^(-1)])/
      64 + (3*G[{0}, yv^(-1)]^2*G[{1}, yv^(-1)]*G[{0, 1}, yu^(-1)])/128 - 
     (3*G[{0}, yu^(-1)]*G[{0}, yw]*G[{1}, yv^(-1)]*G[{0, 1}, yu^(-1)])/64 - 
     (3*G[{0}, yv^(-1)]*G[{0}, yw]*G[{1}, yv^(-1)]*G[{0, 1}, yu^(-1)])/64 + 
     (3*G[{0}, yw]^2*G[{1}, yv^(-1)]*G[{0, 1}, yu^(-1)])/128 - 
     (G[{0}, yu^(-1)]*G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*G[{0, 1}, yu^(-1)])/8 - 
     (G[{0}, yv^(-1)]*G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*G[{0, 1}, yu^(-1)])/8 + 
     (G[{0}, yw]*G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*G[{0, 1}, yu^(-1)])/8 + 
     (3*G[{1}, yu^(-1)]^2*G[{1}, yv^(-1)]*G[{0, 1}, yu^(-1)])/64 + 
     (G[{0}, yu^(-1)]*G[{1}, yv^(-1)]^2*G[{0, 1}, yu^(-1)])/64 + 
     (G[{0}, yv^(-1)]*G[{1}, yv^(-1)]^2*G[{0, 1}, yu^(-1)])/64 - 
     (G[{0}, yw]*G[{1}, yv^(-1)]^2*G[{0, 1}, yu^(-1)])/64 + 
     (G[{1}, yu^(-1)]*G[{1}, yv^(-1)]^2*G[{0, 1}, yu^(-1)])/16 - 
     (G[{1}, yv^(-1)]^3*G[{0, 1}, yu^(-1)])/128 - 
     (Pi^2*G[{1}, yw]*G[{0, 1}, yu^(-1)])/256 - 
     (3*G[{0}, yu^(-1)]^2*G[{1}, yw]*G[{0, 1}, yu^(-1)])/128 - 
     (3*G[{0}, yu^(-1)]*G[{0}, yv^(-1)]*G[{1}, yw]*G[{0, 1}, yu^(-1)])/64 - 
     (3*G[{0}, yv^(-1)]^2*G[{1}, yw]*G[{0, 1}, yu^(-1)])/128 + 
     (3*G[{0}, yu^(-1)]*G[{0}, yw]*G[{1}, yw]*G[{0, 1}, yu^(-1)])/64 + 
     (3*G[{0}, yv^(-1)]*G[{0}, yw]*G[{1}, yw]*G[{0, 1}, yu^(-1)])/64 - 
     (3*G[{0}, yw]^2*G[{1}, yw]*G[{0, 1}, yu^(-1)])/128 + 
     (G[{0}, yu^(-1)]*G[{1}, yu^(-1)]*G[{1}, yw]*G[{0, 1}, yu^(-1)])/8 + 
     (G[{0}, yv^(-1)]*G[{1}, yu^(-1)]*G[{1}, yw]*G[{0, 1}, yu^(-1)])/8 - 
     (G[{0}, yw]*G[{1}, yu^(-1)]*G[{1}, yw]*G[{0, 1}, yu^(-1)])/8 - 
     (3*G[{1}, yu^(-1)]^2*G[{1}, yw]*G[{0, 1}, yu^(-1)])/64 - 
     (G[{0}, yu^(-1)]*G[{1}, yv^(-1)]*G[{1}, yw]*G[{0, 1}, yu^(-1)])/32 - 
     (G[{0}, yv^(-1)]*G[{1}, yv^(-1)]*G[{1}, yw]*G[{0, 1}, yu^(-1)])/32 + 
     (G[{0}, yw]*G[{1}, yv^(-1)]*G[{1}, yw]*G[{0, 1}, yu^(-1)])/32 - 
     (G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*G[{1}, yw]*G[{0, 1}, yu^(-1)])/8 + 
     (3*G[{1}, yv^(-1)]^2*G[{1}, yw]*G[{0, 1}, yu^(-1)])/128 + 
     (3*G[{0}, yu^(-1)]*G[{1}, yw]^2*G[{0, 1}, yu^(-1)])/64 + 
     (3*G[{0}, yv^(-1)]*G[{1}, yw]^2*G[{0, 1}, yu^(-1)])/64 - 
     (3*G[{0}, yw]*G[{1}, yw]^2*G[{0, 1}, yu^(-1)])/64 + 
     (5*G[{1}, yu^(-1)]*G[{1}, yw]^2*G[{0, 1}, yu^(-1)])/128 - 
     (G[{1}, yv^(-1)]*G[{1}, yw]^2*G[{0, 1}, yu^(-1)])/16 + 
     (11*G[{1}, yw]^3*G[{0, 1}, yu^(-1)])/384 - 
     (G[{0}, yu^(-1)]*G[{1}, yw]*G[{yu}, yv^(-1)]*G[{0, 1}, yu^(-1)])/16 - 
     (G[{0}, yv^(-1)]*G[{1}, yw]*G[{yu}, yv^(-1)]*G[{0, 1}, yu^(-1)])/16 + 
     (G[{0}, yw]*G[{1}, yw]*G[{yu}, yv^(-1)]*G[{0, 1}, yu^(-1)])/16 - 
     (G[{1}, yu^(-1)]*G[{1}, yw]*G[{yu}, yv^(-1)]*G[{0, 1}, yu^(-1)])/32 + 
     (G[{1}, yv^(-1)]*G[{1}, yw]*G[{yu}, yv^(-1)]*G[{0, 1}, yu^(-1)])/32 - 
     (9*G[{1}, yw]^2*G[{yu}, yv^(-1)]*G[{0, 1}, yu^(-1)])/128 + 
     (G[{1}, yw]*G[{yu}, yv^(-1)]^2*G[{0, 1}, yu^(-1)])/16 - 
     (5*Pi^2*G[{1/(yu*yv)}, yw]*G[{0, 1}, yu^(-1)])/768 + 
     (3*G[{0}, yu^(-1)]^2*G[{1/(yu*yv)}, yw]*G[{0, 1}, yu^(-1)])/128 + 
     (3*G[{0}, yu^(-1)]*G[{0}, yv^(-1)]*G[{1/(yu*yv)}, yw]*
       G[{0, 1}, yu^(-1)])/64 + (3*G[{0}, yv^(-1)]^2*G[{1/(yu*yv)}, yw]*
       G[{0, 1}, yu^(-1)])/128 - (3*G[{0}, yu^(-1)]*G[{0}, yw]*
       G[{1/(yu*yv)}, yw]*G[{0, 1}, yu^(-1)])/64 - 
     (3*G[{0}, yv^(-1)]*G[{0}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1}, yu^(-1)])/
      64 + (3*G[{0}, yw]^2*G[{1/(yu*yv)}, yw]*G[{0, 1}, yu^(-1)])/128 - 
     (5*G[{0}, yu^(-1)]*G[{1}, yu^(-1)]*G[{1/(yu*yv)}, yw]*
       G[{0, 1}, yu^(-1)])/32 - (5*G[{0}, yv^(-1)]*G[{1}, yu^(-1)]*
       G[{1/(yu*yv)}, yw]*G[{0, 1}, yu^(-1)])/32 + 
     (5*G[{0}, yw]*G[{1}, yu^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, 1}, yu^(-1)])/
      32 + (13*G[{1}, yu^(-1)]^2*G[{1/(yu*yv)}, yw]*G[{0, 1}, yu^(-1)])/64 + 
     (G[{0}, yu^(-1)]*G[{1}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, 1}, yu^(-1)])/
      16 + (G[{0}, yv^(-1)]*G[{1}, yv^(-1)]*G[{1/(yu*yv)}, yw]*
       G[{0, 1}, yu^(-1)])/16 - (G[{0}, yw]*G[{1}, yv^(-1)]*
       G[{1/(yu*yv)}, yw]*G[{0, 1}, yu^(-1)])/16 - 
     (G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, 1}, yu^(-1)])/
      8 + (G[{1}, yv^(-1)]^2*G[{1/(yu*yv)}, yw]*G[{0, 1}, yu^(-1)])/128 - 
     (G[{0}, yu^(-1)]*G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1}, yu^(-1)])/16 - 
     (G[{0}, yv^(-1)]*G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1}, yu^(-1)])/16 + 
     (G[{0}, yw]*G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1}, yu^(-1)])/16 + 
     (G[{1}, yu^(-1)]*G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1}, yu^(-1)])/64 - 
     (G[{1}, yv^(-1)]*G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1}, yu^(-1)])/32 - 
     (11*G[{1}, yw]^2*G[{1/(yu*yv)}, yw]*G[{0, 1}, yu^(-1)])/128 - 
     (G[{0}, yu^(-1)]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1}, yu^(-1)])/
      16 - (G[{0}, yv^(-1)]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*
       G[{0, 1}, yu^(-1)])/16 + (G[{0}, yw]*G[{yu^(-1)}, yw]*
       G[{1/(yu*yv)}, yw]*G[{0, 1}, yu^(-1)])/16 + 
     (5*G[{1}, yu^(-1)]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*
       G[{0, 1}, yu^(-1)])/64 + (3*G[{1}, yv^(-1)]*G[{yu^(-1)}, yw]*
       G[{1/(yu*yv)}, yw]*G[{0, 1}, yu^(-1)])/64 + 
     (G[{1}, yw]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1}, yu^(-1)])/64 - 
     (G[{yu^(-1)}, yw]^2*G[{1/(yu*yv)}, yw]*G[{0, 1}, yu^(-1)])/32 + 
     (G[{0}, yu^(-1)]*G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, 1}, yu^(-1)])/
      16 + (G[{0}, yv^(-1)]*G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw]*
       G[{0, 1}, yu^(-1)])/16 - (G[{0}, yw]*G[{yu}, yv^(-1)]*
       G[{1/(yu*yv)}, yw]*G[{0, 1}, yu^(-1)])/16 + 
     (G[{1}, yu^(-1)]*G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, 1}, yu^(-1)])/
      32 - (G[{1}, yv^(-1)]*G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw]*
       G[{0, 1}, yu^(-1)])/32 + (9*G[{1}, yw]*G[{yu}, yv^(-1)]*
       G[{1/(yu*yv)}, yw]*G[{0, 1}, yu^(-1)])/64 - 
     (G[{yu}, yv^(-1)]^2*G[{1/(yu*yv)}, yw]*G[{0, 1}, yu^(-1)])/16 + 
     (G[{0}, yu^(-1)]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1}, yu^(-1)])/
      16 + (G[{0}, yv^(-1)]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*
       G[{0, 1}, yu^(-1)])/16 - (G[{0}, yw]*G[{yv^(-1)}, yw]*
       G[{1/(yu*yv)}, yw]*G[{0, 1}, yu^(-1)])/16 - 
     (17*G[{1}, yu^(-1)]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*
       G[{0, 1}, yu^(-1)])/64 + (9*G[{1}, yv^(-1)]*G[{yv^(-1)}, yw]*
       G[{1/(yu*yv)}, yw]*G[{0, 1}, yu^(-1)])/64 - 
     (5*G[{1}, yw]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1}, yu^(-1)])/
      64 - (G[{yu^(-1)}, yw]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*
       G[{0, 1}, yu^(-1)])/16 + (3*G[{yv^(-1)}, yw]^2*G[{1/(yu*yv)}, yw]*
       G[{0, 1}, yu^(-1)])/32 + (3*G[{0}, yu^(-1)]*G[{1/(yu*yv)}, yw]^2*
       G[{0, 1}, yu^(-1)])/64 + (3*G[{0}, yv^(-1)]*G[{1/(yu*yv)}, yw]^2*
       G[{0, 1}, yu^(-1)])/64 - (3*G[{0}, yw]*G[{1/(yu*yv)}, yw]^2*
       G[{0, 1}, yu^(-1)])/64 - (9*G[{1}, yu^(-1)]*G[{1/(yu*yv)}, yw]^2*
       G[{0, 1}, yu^(-1)])/128 - (G[{1}, yv^(-1)]*G[{1/(yu*yv)}, yw]^2*
       G[{0, 1}, yu^(-1)])/64 + (G[{1}, yw]*G[{1/(yu*yv)}, yw]^2*
       G[{0, 1}, yu^(-1)])/128 + (G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2*
       G[{0, 1}, yu^(-1)])/64 - (G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw]^2*
       G[{0, 1}, yu^(-1)])/128 + (9*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2*
       G[{0, 1}, yu^(-1)])/128 - (G[{0}, yu^(-1)]*G[{0, 1}, yu^(-1)]^2)/32 - 
     (G[{0}, yv^(-1)]*G[{0, 1}, yu^(-1)]^2)/32 + 
     (G[{0}, yw]*G[{0, 1}, yu^(-1)]^2)/32 + 
     (G[{1}, yu^(-1)]*G[{0, 1}, yu^(-1)]^2)/128 - 
     (G[{1}, yv^(-1)]*G[{0, 1}, yu^(-1)]^2)/128 + 
     (G[{1}, yw]*G[{0, 1}, yu^(-1)]^2)/128 - 
     (G[{1/(yu*yv)}, yw]*G[{0, 1}, yu^(-1)]^2)/128 - 
     (Pi^2*G[{1}, yv^(-1)]*G[{0, 1}, yv^(-1)])/32 - 
     (G[{0}, yu^(-1)]*G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*G[{0, 1}, yv^(-1)])/8 - 
     (G[{0}, yv^(-1)]*G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*G[{0, 1}, yv^(-1)])/8 + 
     (G[{0}, yw]*G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*G[{0, 1}, yv^(-1)])/8 + 
     (G[{1}, yu^(-1)]^2*G[{1}, yv^(-1)]*G[{0, 1}, yv^(-1)])/32 + 
     (G[{0}, yu^(-1)]*G[{1}, yv^(-1)]^2*G[{0, 1}, yv^(-1)])/32 + 
     (G[{0}, yv^(-1)]*G[{1}, yv^(-1)]^2*G[{0, 1}, yv^(-1)])/32 - 
     (G[{0}, yw]*G[{1}, yv^(-1)]^2*G[{0, 1}, yv^(-1)])/32 + 
     (G[{1}, yu^(-1)]*G[{1}, yv^(-1)]^2*G[{0, 1}, yv^(-1)])/16 - 
     (G[{1}, yv^(-1)]^3*G[{0, 1}, yv^(-1)])/96 + 
     (Pi^2*G[{1}, yw]*G[{0, 1}, yv^(-1)])/32 + 
     (G[{0}, yu^(-1)]*G[{1}, yu^(-1)]*G[{1}, yw]*G[{0, 1}, yv^(-1)])/8 + 
     (G[{0}, yv^(-1)]*G[{1}, yu^(-1)]*G[{1}, yw]*G[{0, 1}, yv^(-1)])/8 - 
     (G[{0}, yw]*G[{1}, yu^(-1)]*G[{1}, yw]*G[{0, 1}, yv^(-1)])/8 - 
     (G[{1}, yu^(-1)]^2*G[{1}, yw]*G[{0, 1}, yv^(-1)])/32 - 
     (G[{0}, yu^(-1)]*G[{1}, yv^(-1)]*G[{1}, yw]*G[{0, 1}, yv^(-1)])/16 - 
     (G[{0}, yv^(-1)]*G[{1}, yv^(-1)]*G[{1}, yw]*G[{0, 1}, yv^(-1)])/16 + 
     (G[{0}, yw]*G[{1}, yv^(-1)]*G[{1}, yw]*G[{0, 1}, yv^(-1)])/16 - 
     (G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*G[{1}, yw]*G[{0, 1}, yv^(-1)])/8 + 
     (G[{1}, yv^(-1)]^2*G[{1}, yw]*G[{0, 1}, yv^(-1)])/32 + 
     (3*G[{0}, yu^(-1)]*G[{1}, yw]^2*G[{0, 1}, yv^(-1)])/32 + 
     (3*G[{0}, yv^(-1)]*G[{1}, yw]^2*G[{0, 1}, yv^(-1)])/32 - 
     (3*G[{0}, yw]*G[{1}, yw]^2*G[{0, 1}, yv^(-1)])/32 + 
     (G[{1}, yu^(-1)]*G[{1}, yw]^2*G[{0, 1}, yv^(-1)])/16 - 
     (3*G[{1}, yv^(-1)]*G[{1}, yw]^2*G[{0, 1}, yv^(-1)])/32 + 
     (5*G[{1}, yw]^3*G[{0, 1}, yv^(-1)])/96 - 
     (G[{0}, yu^(-1)]*G[{1}, yw]*G[{yu}, yv^(-1)]*G[{0, 1}, yv^(-1)])/16 - 
     (G[{0}, yv^(-1)]*G[{1}, yw]*G[{yu}, yv^(-1)]*G[{0, 1}, yv^(-1)])/16 + 
     (G[{0}, yw]*G[{1}, yw]*G[{yu}, yv^(-1)]*G[{0, 1}, yv^(-1)])/16 - 
     (G[{1}, yu^(-1)]*G[{1}, yw]*G[{yu}, yv^(-1)]*G[{0, 1}, yv^(-1)])/8 - 
     (G[{1}, yv^(-1)]*G[{1}, yw]*G[{yu}, yv^(-1)]*G[{0, 1}, yv^(-1)])/16 - 
     (G[{1}, yw]^2*G[{yu}, yv^(-1)]*G[{0, 1}, yv^(-1)])/8 + 
     (G[{1}, yw]*G[{yu}, yv^(-1)]^2*G[{0, 1}, yv^(-1)])/8 - 
     (G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, 1}, yv^(-1)])/
      8 + (G[{1}, yv^(-1)]^2*G[{1/(yu*yv)}, yw]*G[{0, 1}, yv^(-1)])/32 - 
     (G[{0}, yu^(-1)]*G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1}, yv^(-1)])/16 - 
     (G[{0}, yv^(-1)]*G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1}, yv^(-1)])/16 + 
     (G[{0}, yw]*G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1}, yv^(-1)])/16 - 
     (G[{1}, yu^(-1)]*G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1}, yv^(-1)])/8 - 
     (G[{1}, yv^(-1)]*G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1}, yv^(-1)])/16 - 
     (5*G[{1}, yw]^2*G[{1/(yu*yv)}, yw]*G[{0, 1}, yv^(-1)])/32 + 
     (G[{1}, yu^(-1)]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1}, yv^(-1)])/
      8 - (G[{1}, yv^(-1)]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*
       G[{0, 1}, yv^(-1)])/16 + (G[{1}, yw]*G[{yu^(-1)}, yw]*
       G[{1/(yu*yv)}, yw]*G[{0, 1}, yv^(-1)])/16 + 
     (G[{yu^(-1)}, yw]^2*G[{1/(yu*yv)}, yw]*G[{0, 1}, yv^(-1)])/16 + 
     (G[{0}, yu^(-1)]*G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, 1}, yv^(-1)])/
      16 + (G[{0}, yv^(-1)]*G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw]*
       G[{0, 1}, yv^(-1)])/16 - (G[{0}, yw]*G[{yu}, yv^(-1)]*
       G[{1/(yu*yv)}, yw]*G[{0, 1}, yv^(-1)])/16 + 
     (G[{1}, yu^(-1)]*G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, 1}, yv^(-1)])/
      8 + (G[{1}, yv^(-1)]*G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw]*
       G[{0, 1}, yv^(-1)])/16 + (G[{1}, yw]*G[{yu}, yv^(-1)]*
       G[{1/(yu*yv)}, yw]*G[{0, 1}, yv^(-1)])/4 - 
     (G[{yu}, yv^(-1)]^2*G[{1/(yu*yv)}, yw]*G[{0, 1}, yv^(-1)])/8 + 
     (G[{1}, yv^(-1)]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1}, yv^(-1)])/
      8 + (G[{1}, yw]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1}, yv^(-1)])/
      8 - (G[{yu^(-1)}, yw]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*
       G[{0, 1}, yv^(-1)])/8 - (G[{yu}, yv^(-1)]*G[{yv^(-1)}, yw]*
       G[{1/(yu*yv)}, yw]*G[{0, 1}, yv^(-1)])/8 - 
     (G[{0}, yu^(-1)]*G[{0, 1}, yv^(-1)]^2)/32 - 
     (G[{0}, yv^(-1)]*G[{0, 1}, yv^(-1)]^2)/32 + 
     (G[{0}, yw]*G[{0, 1}, yv^(-1)]^2)/32 - 
     (G[{1}, yv^(-1)]*G[{0, 1}, yv^(-1)]^2)/32 + 
     (G[{1}, yw]*G[{0, 1}, yv^(-1)]^2)/32 - 
     (G[{1/(yu*yv)}, yw]*G[{0, 1}, yv^(-1)]^2)/32 + 
     (Pi^2*G[{1}, yu^(-1)]*G[{0, 1}, yw])/24 + 
     (G[{0}, yu^(-1)]*G[{1}, yu^(-1)]^2*G[{0, 1}, yw])/16 + 
     (G[{0}, yv^(-1)]*G[{1}, yu^(-1)]^2*G[{0, 1}, yw])/16 - 
     (G[{0}, yw]*G[{1}, yu^(-1)]^2*G[{0, 1}, yw])/16 - 
     (5*G[{1}, yu^(-1)]^3*G[{0, 1}, yw])/128 + 
     (Pi^2*G[{1}, yv^(-1)]*G[{0, 1}, yw])/96 - 
     (5*G[{1}, yu^(-1)]^2*G[{1}, yv^(-1)]*G[{0, 1}, yw])/128 + 
     (3*G[{1}, yu^(-1)]*G[{1}, yv^(-1)]^2*G[{0, 1}, yw])/128 + 
     (Pi^2*G[{1}, yw]*G[{0, 1}, yw])/48 + 
     (G[{0}, yu^(-1)]*G[{1}, yu^(-1)]*G[{1}, yw]*G[{0, 1}, yw])/8 + 
     (G[{0}, yv^(-1)]*G[{1}, yu^(-1)]*G[{1}, yw]*G[{0, 1}, yw])/8 - 
     (G[{0}, yw]*G[{1}, yu^(-1)]*G[{1}, yw]*G[{0, 1}, yw])/8 - 
     (15*G[{1}, yu^(-1)]^2*G[{1}, yw]*G[{0, 1}, yw])/128 - 
     (7*G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*G[{1}, yw]*G[{0, 1}, yw])/64 + 
     (G[{0}, yu^(-1)]*G[{1}, yw]^2*G[{0, 1}, yw])/32 + 
     (G[{0}, yv^(-1)]*G[{1}, yw]^2*G[{0, 1}, yw])/32 - 
     (G[{0}, yw]*G[{1}, yw]^2*G[{0, 1}, yw])/32 - 
     (15*G[{1}, yu^(-1)]*G[{1}, yw]^2*G[{0, 1}, yw])/128 - 
     (G[{1}, yv^(-1)]*G[{1}, yw]^2*G[{0, 1}, yw])/32 - 
     (5*G[{1}, yw]^3*G[{0, 1}, yw])/128 - 
     (Pi^2*G[{yu}, yv^(-1)]*G[{0, 1}, yw])/24 - 
     (G[{0}, yu^(-1)]*G[{1}, yu^(-1)]*G[{yu}, yv^(-1)]*G[{0, 1}, yw])/8 - 
     (G[{0}, yv^(-1)]*G[{1}, yu^(-1)]*G[{yu}, yv^(-1)]*G[{0, 1}, yw])/8 + 
     (G[{0}, yw]*G[{1}, yu^(-1)]*G[{yu}, yv^(-1)]*G[{0, 1}, yw])/8 + 
     (G[{1}, yu^(-1)]^2*G[{yu}, yv^(-1)]*G[{0, 1}, yw])/32 - 
     (G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*G[{yu}, yv^(-1)]*G[{0, 1}, yw])/16 + 
     (G[{1}, yv^(-1)]^2*G[{yu}, yv^(-1)]*G[{0, 1}, yw])/32 - 
     (G[{0}, yu^(-1)]*G[{1}, yw]*G[{yu}, yv^(-1)]*G[{0, 1}, yw])/8 - 
     (G[{0}, yv^(-1)]*G[{1}, yw]*G[{yu}, yv^(-1)]*G[{0, 1}, yw])/8 + 
     (G[{0}, yw]*G[{1}, yw]*G[{yu}, yv^(-1)]*G[{0, 1}, yw])/8 + 
     (3*G[{1}, yu^(-1)]*G[{1}, yw]*G[{yu}, yv^(-1)]*G[{0, 1}, yw])/32 + 
     (G[{1}, yv^(-1)]*G[{1}, yw]*G[{yu}, yv^(-1)]*G[{0, 1}, yw])/16 + 
     (11*G[{1}, yw]^2*G[{yu}, yv^(-1)]*G[{0, 1}, yw])/128 + 
     (G[{0}, yu^(-1)]*G[{yu}, yv^(-1)]^2*G[{0, 1}, yw])/16 + 
     (G[{0}, yv^(-1)]*G[{yu}, yv^(-1)]^2*G[{0, 1}, yw])/16 - 
     (G[{0}, yw]*G[{yu}, yv^(-1)]^2*G[{0, 1}, yw])/16 + 
     (G[{1}, yu^(-1)]*G[{yu}, yv^(-1)]^2*G[{0, 1}, yw])/8 + 
     (3*G[{1}, yw]*G[{yu}, yv^(-1)]^2*G[{0, 1}, yw])/64 - 
     (G[{yu}, yv^(-1)]^3*G[{0, 1}, yw])/12 - 
     (G[{0}, yu^(-1)]*G[{1}, yu^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, 1}, yw])/16 - 
     (G[{0}, yv^(-1)]*G[{1}, yu^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, 1}, yw])/16 + 
     (G[{0}, yw]*G[{1}, yu^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, 1}, yw])/16 + 
     (3*G[{1}, yu^(-1)]^2*G[{1/(yu*yv)}, yw]*G[{0, 1}, yw])/128 - 
     (G[{0}, yu^(-1)]*G[{1}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, 1}, yw])/16 - 
     (G[{0}, yv^(-1)]*G[{1}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, 1}, yw])/16 + 
     (G[{0}, yw]*G[{1}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, 1}, yw])/16 + 
     (11*G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, 1}, yw])/
      64 + (G[{1}, yv^(-1)]^2*G[{1/(yu*yv)}, yw]*G[{0, 1}, yw])/32 - 
     (G[{0}, yu^(-1)]*G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1}, yw])/16 - 
     (G[{0}, yv^(-1)]*G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1}, yw])/16 + 
     (G[{0}, yw]*G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1}, yw])/16 - 
     (G[{1}, yu^(-1)]*G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1}, yw])/64 + 
     (3*G[{1}, yv^(-1)]*G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1}, yw])/16 + 
     (7*G[{1}, yw]^2*G[{1/(yu*yv)}, yw]*G[{0, 1}, yw])/128 + 
     (G[{1}, yu^(-1)]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1}, yw])/16 - 
     (G[{1}, yv^(-1)]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1}, yw])/16 - 
     (G[{1}, yw]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1}, yw])/16 + 
     (G[{yu^(-1)}, yw]^2*G[{1/(yu*yv)}, yw]*G[{0, 1}, yw])/16 + 
     (G[{0}, yu^(-1)]*G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, 1}, yw])/8 + 
     (G[{0}, yv^(-1)]*G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, 1}, yw])/8 - 
     (G[{0}, yw]*G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, 1}, yw])/8 - 
     (3*G[{1}, yu^(-1)]*G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, 1}, yw])/
      32 - (G[{1}, yv^(-1)]*G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw]*
       G[{0, 1}, yw])/16 - (3*G[{1}, yw]*G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw]*
       G[{0, 1}, yw])/64 - (3*G[{yu}, yv^(-1)]^2*G[{1/(yu*yv)}, yw]*
       G[{0, 1}, yw])/64 + (3*G[{1}, yu^(-1)]*G[{yv^(-1)}, yw]*
       G[{1/(yu*yv)}, yw]*G[{0, 1}, yw])/32 - 
     (G[{1}, yv^(-1)]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1}, yw])/8 + 
     (3*G[{1}, yw]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1}, yw])/32 + 
     (G[{yu}, yv^(-1)]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1}, yw])/
      32 - (7*G[{yv^(-1)}, yw]^2*G[{1/(yu*yv)}, yw]*G[{0, 1}, yw])/64 - 
     (G[{1}, yu^(-1)]*G[{1/(yu*yv)}, yw]^2*G[{0, 1}, yw])/128 + 
     (G[{1}, yv^(-1)]*G[{1/(yu*yv)}, yw]^2*G[{0, 1}, yw])/16 + 
     (7*G[{1}, yw]*G[{1/(yu*yv)}, yw]^2*G[{0, 1}, yw])/128 - 
     (G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2*G[{0, 1}, yw])/16 - 
     (7*G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw]^2*G[{0, 1}, yw])/128 + 
     (G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2*G[{0, 1}, yw])/128 + 
     (5*G[{1}, yu^(-1)]*G[{0, 1}, yu^(-1)]*G[{0, 1}, yw])/64 + 
     (3*G[{1}, yv^(-1)]*G[{0, 1}, yu^(-1)]*G[{0, 1}, yw])/64 + 
     (G[{1}, yw]*G[{0, 1}, yu^(-1)]*G[{0, 1}, yw])/64 - 
     (G[{yu}, yv^(-1)]*G[{0, 1}, yu^(-1)]*G[{0, 1}, yw])/16 + 
     (3*G[{1/(yu*yv)}, yw]*G[{0, 1}, yu^(-1)]*G[{0, 1}, yw])/64 + 
     (G[{1}, yu^(-1)]*G[{0, 1}, yv^(-1)]*G[{0, 1}, yw])/8 + 
     (G[{1}, yv^(-1)]*G[{0, 1}, yv^(-1)]*G[{0, 1}, yw])/16 + 
     (G[{1}, yw]*G[{0, 1}, yv^(-1)]*G[{0, 1}, yw])/16 - 
     (G[{yu}, yv^(-1)]*G[{0, 1}, yv^(-1)]*G[{0, 1}, yw])/16 + 
     (G[{0}, yu^(-1)]*G[{0, 1}, yw]^2)/32 + (G[{0}, yv^(-1)]*G[{0, 1}, yw]^2)/
      32 - (G[{0}, yw]*G[{0, 1}, yw]^2)/32 - 
     (G[{1}, yv^(-1)]*G[{0, 1}, yw]^2)/32 + (G[{1}, yw]*G[{0, 1}, yw]^2)/32 - 
     (G[{yu}, yv^(-1)]*G[{0, 1}, yw]^2)/32 - 
     (G[{1/(yu*yv)}, yw]*G[{0, 1}, yw]^2)/32 + 
     (Pi^2*G[{0}, yu^(-1)]*G[{0, yu^(-1)}, yw])/96 + 
     (Pi^2*G[{0}, yv^(-1)]*G[{0, yu^(-1)}, yw])/96 - 
     (Pi^2*G[{0}, yw]*G[{0, yu^(-1)}, yw])/96 - 
     (Pi^2*G[{1}, yu^(-1)]*G[{0, yu^(-1)}, yw])/24 - 
     (G[{0}, yu^(-1)]*G[{1}, yu^(-1)]^2*G[{0, yu^(-1)}, yw])/16 - 
     (G[{0}, yv^(-1)]*G[{1}, yu^(-1)]^2*G[{0, yu^(-1)}, yw])/16 + 
     (G[{0}, yw]*G[{1}, yu^(-1)]^2*G[{0, yu^(-1)}, yw])/16 + 
     (5*G[{1}, yu^(-1)]^3*G[{0, yu^(-1)}, yw])/128 + 
     (Pi^2*G[{1}, yv^(-1)]*G[{0, yu^(-1)}, yw])/48 + 
     (G[{0}, yu^(-1)]*G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*G[{0, yu^(-1)}, yw])/
      8 + (G[{0}, yv^(-1)]*G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*
       G[{0, yu^(-1)}, yw])/8 - (G[{0}, yw]*G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*
       G[{0, yu^(-1)}, yw])/8 + (G[{1}, yu^(-1)]^2*G[{1}, yv^(-1)]*
       G[{0, yu^(-1)}, yw])/128 - (G[{0}, yu^(-1)]*G[{1}, yv^(-1)]^2*
       G[{0, yu^(-1)}, yw])/32 - (G[{0}, yv^(-1)]*G[{1}, yv^(-1)]^2*
       G[{0, yu^(-1)}, yw])/32 + (G[{0}, yw]*G[{1}, yv^(-1)]^2*
       G[{0, yu^(-1)}, yw])/32 - (15*G[{1}, yu^(-1)]*G[{1}, yv^(-1)]^2*
       G[{0, yu^(-1)}, yw])/128 + (G[{1}, yv^(-1)]^3*G[{0, yu^(-1)}, yw])/
      32 - (Pi^2*G[{1}, yw]*G[{0, yu^(-1)}, yw])/32 - 
     (G[{0}, yu^(-1)]*G[{1}, yu^(-1)]*G[{1}, yw]*G[{0, yu^(-1)}, yw])/8 - 
     (G[{0}, yv^(-1)]*G[{1}, yu^(-1)]*G[{1}, yw]*G[{0, yu^(-1)}, yw])/8 + 
     (G[{0}, yw]*G[{1}, yu^(-1)]*G[{1}, yw]*G[{0, yu^(-1)}, yw])/8 + 
     (15*G[{1}, yu^(-1)]^2*G[{1}, yw]*G[{0, yu^(-1)}, yw])/128 + 
     (G[{0}, yu^(-1)]*G[{1}, yv^(-1)]*G[{1}, yw]*G[{0, yu^(-1)}, yw])/16 + 
     (G[{0}, yv^(-1)]*G[{1}, yv^(-1)]*G[{1}, yw]*G[{0, yu^(-1)}, yw])/16 - 
     (G[{0}, yw]*G[{1}, yv^(-1)]*G[{1}, yw]*G[{0, yu^(-1)}, yw])/16 + 
     (7*G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*G[{1}, yw]*G[{0, yu^(-1)}, yw])/64 - 
     (G[{1}, yv^(-1)]^2*G[{1}, yw]*G[{0, yu^(-1)}, yw])/16 - 
     (G[{0}, yu^(-1)]*G[{1}, yw]^2*G[{0, yu^(-1)}, yw])/32 - 
     (G[{0}, yv^(-1)]*G[{1}, yw]^2*G[{0, yu^(-1)}, yw])/32 + 
     (G[{0}, yw]*G[{1}, yw]^2*G[{0, yu^(-1)}, yw])/32 + 
     (15*G[{1}, yu^(-1)]*G[{1}, yw]^2*G[{0, yu^(-1)}, yw])/128 + 
     (G[{1}, yv^(-1)]*G[{1}, yw]^2*G[{0, yu^(-1)}, yw])/32 + 
     (5*G[{1}, yw]^3*G[{0, yu^(-1)}, yw])/128 + 
     (G[{0}, yu^(-1)]*G[{1}, yw]*G[{yu}, yv^(-1)]*G[{0, yu^(-1)}, yw])/16 + 
     (G[{0}, yv^(-1)]*G[{1}, yw]*G[{yu}, yv^(-1)]*G[{0, yu^(-1)}, yw])/16 - 
     (G[{0}, yw]*G[{1}, yw]*G[{yu}, yv^(-1)]*G[{0, yu^(-1)}, yw])/16 - 
     (3*G[{1}, yu^(-1)]*G[{1}, yw]*G[{yu}, yv^(-1)]*G[{0, yu^(-1)}, yw])/32 - 
     (G[{1}, yv^(-1)]*G[{1}, yw]*G[{yu}, yv^(-1)]*G[{0, yu^(-1)}, yw])/16 - 
     (11*G[{1}, yw]^2*G[{yu}, yv^(-1)]*G[{0, yu^(-1)}, yw])/128 + 
     (G[{1}, yw]*G[{yu}, yv^(-1)]^2*G[{0, yu^(-1)}, yw])/64 + 
     (G[{0}, yu^(-1)]*G[{1}, yu^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1)}, yw])/
      16 + (G[{0}, yv^(-1)]*G[{1}, yu^(-1)]*G[{1/(yu*yv)}, yw]*
       G[{0, yu^(-1)}, yw])/16 - (G[{0}, yw]*G[{1}, yu^(-1)]*
       G[{1/(yu*yv)}, yw]*G[{0, yu^(-1)}, yw])/16 - 
     (3*G[{1}, yu^(-1)]^2*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1)}, yw])/128 - 
     (11*G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*G[{1/(yu*yv)}, yw]*
       G[{0, yu^(-1)}, yw])/64 + (G[{1}, yv^(-1)]^2*G[{1/(yu*yv)}, yw]*
       G[{0, yu^(-1)}, yw])/32 + (G[{0}, yu^(-1)]*G[{1}, yw]*
       G[{1/(yu*yv)}, yw]*G[{0, yu^(-1)}, yw])/16 + 
     (G[{0}, yv^(-1)]*G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1)}, yw])/16 - 
     (G[{0}, yw]*G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1)}, yw])/16 + 
     (G[{1}, yu^(-1)]*G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1)}, yw])/64 - 
     (3*G[{1}, yv^(-1)]*G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1)}, yw])/
      16 - (7*G[{1}, yw]^2*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1)}, yw])/128 - 
     (G[{1}, yu^(-1)]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*
       G[{0, yu^(-1)}, yw])/16 + (G[{1}, yv^(-1)]*G[{yu^(-1)}, yw]*
       G[{1/(yu*yv)}, yw]*G[{0, yu^(-1)}, yw])/16 + 
     (G[{1}, yw]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1)}, yw])/
      16 - (G[{yu^(-1)}, yw]^2*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1)}, yw])/16 - 
     (G[{0}, yu^(-1)]*G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw]*
       G[{0, yu^(-1)}, yw])/16 - (G[{0}, yv^(-1)]*G[{yu}, yv^(-1)]*
       G[{1/(yu*yv)}, yw]*G[{0, yu^(-1)}, yw])/16 + 
     (G[{0}, yw]*G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1)}, yw])/
      16 + (3*G[{1}, yu^(-1)]*G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw]*
       G[{0, yu^(-1)}, yw])/32 + (G[{1}, yv^(-1)]*G[{yu}, yv^(-1)]*
       G[{1/(yu*yv)}, yw]*G[{0, yu^(-1)}, yw])/16 + 
     (3*G[{1}, yw]*G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1)}, yw])/
      64 - (G[{yu}, yv^(-1)]^2*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1)}, yw])/64 - 
     (3*G[{1}, yu^(-1)]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*
       G[{0, yu^(-1)}, yw])/32 + (G[{1}, yv^(-1)]*G[{yv^(-1)}, yw]*
       G[{1/(yu*yv)}, yw]*G[{0, yu^(-1)}, yw])/8 - 
     (3*G[{1}, yw]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1)}, yw])/
      32 - (G[{yu}, yv^(-1)]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*
       G[{0, yu^(-1)}, yw])/32 + (7*G[{yv^(-1)}, yw]^2*G[{1/(yu*yv)}, yw]*
       G[{0, yu^(-1)}, yw])/64 + (G[{1}, yu^(-1)]*G[{1/(yu*yv)}, yw]^2*
       G[{0, yu^(-1)}, yw])/128 - (G[{1}, yv^(-1)]*G[{1/(yu*yv)}, yw]^2*
       G[{0, yu^(-1)}, yw])/16 - (7*G[{1}, yw]*G[{1/(yu*yv)}, yw]^2*
       G[{0, yu^(-1)}, yw])/128 + (G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2*
       G[{0, yu^(-1)}, yw])/16 + (7*G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw]^2*
       G[{0, yu^(-1)}, yw])/128 - (G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2*
       G[{0, yu^(-1)}, yw])/128 + (G[{0}, yu^(-1)]*G[{0, 1}, yu^(-1)]*
       G[{0, yu^(-1)}, yw])/16 + (G[{0}, yv^(-1)]*G[{0, 1}, yu^(-1)]*
       G[{0, yu^(-1)}, yw])/16 - (G[{0}, yw]*G[{0, 1}, yu^(-1)]*
       G[{0, yu^(-1)}, yw])/16 - (5*G[{1}, yu^(-1)]*G[{0, 1}, yu^(-1)]*
       G[{0, yu^(-1)}, yw])/64 - (3*G[{1}, yv^(-1)]*G[{0, 1}, yu^(-1)]*
       G[{0, yu^(-1)}, yw])/64 - (5*G[{1}, yw]*G[{0, 1}, yu^(-1)]*
       G[{0, yu^(-1)}, yw])/64 - (3*G[{1/(yu*yv)}, yw]*G[{0, 1}, yu^(-1)]*
       G[{0, yu^(-1)}, yw])/64 - (G[{1}, yu^(-1)]*G[{0, 1}, yv^(-1)]*
       G[{0, yu^(-1)}, yw])/8 + (G[{1}, yv^(-1)]*G[{0, 1}, yv^(-1)]*
       G[{0, yu^(-1)}, yw])/16 - (G[{1}, yw]*G[{0, 1}, yv^(-1)]*
       G[{0, yu^(-1)}, yw])/8 - (G[{1}, yu^(-1)]*G[{0, 1}, yw]*
       G[{0, yu^(-1)}, yw])/16 + (G[{1}, yv^(-1)]*G[{0, 1}, yw]*
       G[{0, yu^(-1)}, yw])/16 + (G[{1/(yu*yv)}, yw]*G[{0, 1}, yw]*
       G[{0, yu^(-1)}, yw])/16 + (G[{1}, yu^(-1)]*G[{0, yu^(-1)}, yw]^2)/32 - 
     (G[{1}, yv^(-1)]*G[{0, yu^(-1)}, yw]^2)/32 - 
     (G[{1/(yu*yv)}, yw]*G[{0, yu^(-1)}, yw]^2)/32 + 
     (Pi^2*G[{1}, yv^(-1)]*G[{0, yu}, yv^(-1)])/24 + 
     (G[{0}, yu^(-1)]*G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*G[{0, yu}, yv^(-1)])/
      8 + (G[{0}, yv^(-1)]*G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*
       G[{0, yu}, yv^(-1)])/8 - (G[{0}, yw]*G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*
       G[{0, yu}, yv^(-1)])/8 - (G[{1}, yu^(-1)]^2*G[{1}, yv^(-1)]*
       G[{0, yu}, yv^(-1)])/32 - (G[{0}, yu^(-1)]*G[{1}, yv^(-1)]^2*
       G[{0, yu}, yv^(-1)])/32 - (G[{0}, yv^(-1)]*G[{1}, yv^(-1)]^2*
       G[{0, yu}, yv^(-1)])/32 + (G[{0}, yw]*G[{1}, yv^(-1)]^2*
       G[{0, yu}, yv^(-1)])/32 - (G[{1}, yu^(-1)]*G[{1}, yv^(-1)]^2*
       G[{0, yu}, yv^(-1)])/16 + (G[{1}, yv^(-1)]^3*G[{0, yu}, yv^(-1)])/96 - 
     (Pi^2*G[{1}, yw]*G[{0, yu}, yv^(-1)])/24 - 
     (G[{0}, yu^(-1)]*G[{1}, yu^(-1)]*G[{1}, yw]*G[{0, yu}, yv^(-1)])/8 - 
     (G[{0}, yv^(-1)]*G[{1}, yu^(-1)]*G[{1}, yw]*G[{0, yu}, yv^(-1)])/8 + 
     (G[{0}, yw]*G[{1}, yu^(-1)]*G[{1}, yw]*G[{0, yu}, yv^(-1)])/8 + 
     (G[{1}, yu^(-1)]^2*G[{1}, yw]*G[{0, yu}, yv^(-1)])/32 + 
     (G[{0}, yu^(-1)]*G[{1}, yv^(-1)]*G[{1}, yw]*G[{0, yu}, yv^(-1)])/16 + 
     (G[{0}, yv^(-1)]*G[{1}, yv^(-1)]*G[{1}, yw]*G[{0, yu}, yv^(-1)])/16 - 
     (G[{0}, yw]*G[{1}, yv^(-1)]*G[{1}, yw]*G[{0, yu}, yv^(-1)])/16 + 
     (G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*G[{1}, yw]*G[{0, yu}, yv^(-1)])/8 - 
     (G[{1}, yv^(-1)]^2*G[{1}, yw]*G[{0, yu}, yv^(-1)])/32 - 
     (3*G[{0}, yu^(-1)]*G[{1}, yw]^2*G[{0, yu}, yv^(-1)])/32 - 
     (3*G[{0}, yv^(-1)]*G[{1}, yw]^2*G[{0, yu}, yv^(-1)])/32 + 
     (3*G[{0}, yw]*G[{1}, yw]^2*G[{0, yu}, yv^(-1)])/32 - 
     (G[{1}, yu^(-1)]*G[{1}, yw]^2*G[{0, yu}, yv^(-1)])/16 + 
     (3*G[{1}, yv^(-1)]*G[{1}, yw]^2*G[{0, yu}, yv^(-1)])/32 - 
     (5*G[{1}, yw]^3*G[{0, yu}, yv^(-1)])/96 + 
     (G[{0}, yu^(-1)]*G[{1}, yw]*G[{yu}, yv^(-1)]*G[{0, yu}, yv^(-1)])/16 + 
     (G[{0}, yv^(-1)]*G[{1}, yw]*G[{yu}, yv^(-1)]*G[{0, yu}, yv^(-1)])/16 - 
     (G[{0}, yw]*G[{1}, yw]*G[{yu}, yv^(-1)]*G[{0, yu}, yv^(-1)])/16 + 
     (G[{1}, yu^(-1)]*G[{1}, yw]*G[{yu}, yv^(-1)]*G[{0, yu}, yv^(-1)])/8 + 
     (G[{1}, yv^(-1)]*G[{1}, yw]*G[{yu}, yv^(-1)]*G[{0, yu}, yv^(-1)])/16 + 
     (G[{1}, yw]^2*G[{yu}, yv^(-1)]*G[{0, yu}, yv^(-1)])/8 - 
     (G[{1}, yw]*G[{yu}, yv^(-1)]^2*G[{0, yu}, yv^(-1)])/8 + 
     (G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, yu}, yv^(-1)])/
      8 - (G[{1}, yv^(-1)]^2*G[{1/(yu*yv)}, yw]*G[{0, yu}, yv^(-1)])/32 + 
     (G[{0}, yu^(-1)]*G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{0, yu}, yv^(-1)])/16 + 
     (G[{0}, yv^(-1)]*G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{0, yu}, yv^(-1)])/16 - 
     (G[{0}, yw]*G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{0, yu}, yv^(-1)])/16 + 
     (G[{1}, yu^(-1)]*G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{0, yu}, yv^(-1)])/8 + 
     (G[{1}, yv^(-1)]*G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{0, yu}, yv^(-1)])/16 + 
     (5*G[{1}, yw]^2*G[{1/(yu*yv)}, yw]*G[{0, yu}, yv^(-1)])/32 - 
     (G[{1}, yu^(-1)]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*
       G[{0, yu}, yv^(-1)])/8 + (G[{1}, yv^(-1)]*G[{yu^(-1)}, yw]*
       G[{1/(yu*yv)}, yw]*G[{0, yu}, yv^(-1)])/16 - 
     (G[{1}, yw]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{0, yu}, yv^(-1)])/
      16 - (G[{yu^(-1)}, yw]^2*G[{1/(yu*yv)}, yw]*G[{0, yu}, yv^(-1)])/16 - 
     (G[{0}, yu^(-1)]*G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw]*
       G[{0, yu}, yv^(-1)])/16 - (G[{0}, yv^(-1)]*G[{yu}, yv^(-1)]*
       G[{1/(yu*yv)}, yw]*G[{0, yu}, yv^(-1)])/16 + 
     (G[{0}, yw]*G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, yu}, yv^(-1)])/
      16 - (G[{1}, yu^(-1)]*G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw]*
       G[{0, yu}, yv^(-1)])/8 - (G[{1}, yv^(-1)]*G[{yu}, yv^(-1)]*
       G[{1/(yu*yv)}, yw]*G[{0, yu}, yv^(-1)])/16 - 
     (G[{1}, yw]*G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, yu}, yv^(-1)])/4 + 
     (G[{yu}, yv^(-1)]^2*G[{1/(yu*yv)}, yw]*G[{0, yu}, yv^(-1)])/8 - 
     (G[{1}, yv^(-1)]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*
       G[{0, yu}, yv^(-1)])/8 - (G[{1}, yw]*G[{yv^(-1)}, yw]*
       G[{1/(yu*yv)}, yw]*G[{0, yu}, yv^(-1)])/8 + 
     (G[{yu^(-1)}, yw]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*
       G[{0, yu}, yv^(-1)])/8 + (G[{yu}, yv^(-1)]*G[{yv^(-1)}, yw]*
       G[{1/(yu*yv)}, yw]*G[{0, yu}, yv^(-1)])/8 + 
     (G[{1}, yv^(-1)]*G[{0, 1}, yu^(-1)]*G[{0, yu}, yv^(-1)])/16 - 
     (G[{1}, yw]*G[{0, 1}, yu^(-1)]*G[{0, yu}, yv^(-1)])/16 + 
     (G[{1}, yv^(-1)]*G[{0, 1}, yv^(-1)]*G[{0, yu}, yv^(-1)])/8 - 
     (G[{1}, yw]*G[{0, 1}, yv^(-1)]*G[{0, yu}, yv^(-1)])/8 + 
     (G[{1/(yu*yv)}, yw]*G[{0, 1}, yv^(-1)]*G[{0, yu}, yv^(-1)])/16 - 
     (G[{1}, yu^(-1)]*G[{0, 1}, yw]*G[{0, yu}, yv^(-1)])/8 - 
     (G[{1}, yv^(-1)]*G[{0, 1}, yw]*G[{0, yu}, yv^(-1)])/16 - 
     (G[{1}, yw]*G[{0, 1}, yw]*G[{0, yu}, yv^(-1)])/16 + 
     (G[{yu}, yv^(-1)]*G[{0, 1}, yw]*G[{0, yu}, yv^(-1)])/16 + 
     (G[{1}, yu^(-1)]*G[{0, yu^(-1)}, yw]*G[{0, yu}, yv^(-1)])/8 - 
     (G[{1}, yv^(-1)]*G[{0, yu^(-1)}, yw]*G[{0, yu}, yv^(-1)])/16 + 
     (G[{1}, yw]*G[{0, yu^(-1)}, yw]*G[{0, yu}, yv^(-1)])/8 - 
     (G[{1}, yv^(-1)]*G[{0, yu}, yv^(-1)]^2)/16 + 
     (G[{1}, yw]*G[{0, yu}, yv^(-1)]^2)/16 - 
     (G[{1/(yu*yv)}, yw]*G[{0, yu}, yv^(-1)]^2)/32 + 
     (G[{0}, yu^(-1)]*G[{1}, yu^(-1)]^2*G[{0, yv^(-1)}, yw])/32 + 
     (G[{0}, yv^(-1)]*G[{1}, yu^(-1)]^2*G[{0, yv^(-1)}, yw])/32 - 
     (G[{0}, yw]*G[{1}, yu^(-1)]^2*G[{0, yv^(-1)}, yw])/32 - 
     (7*G[{1}, yu^(-1)]^3*G[{0, yv^(-1)}, yw])/128 - 
     (Pi^2*G[{1}, yv^(-1)]*G[{0, yv^(-1)}, yw])/48 - 
     (G[{0}, yu^(-1)]*G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*G[{0, yv^(-1)}, yw])/
      16 - (G[{0}, yv^(-1)]*G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*
       G[{0, yv^(-1)}, yw])/16 + (G[{0}, yw]*G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*
       G[{0, yv^(-1)}, yw])/16 + (13*G[{1}, yu^(-1)]^2*G[{1}, yv^(-1)]*
       G[{0, yv^(-1)}, yw])/128 - (3*G[{1}, yu^(-1)]*G[{1}, yv^(-1)]^2*
       G[{0, yv^(-1)}, yw])/128 - (Pi^2*G[{1}, yw]*G[{0, yv^(-1)}, yw])/96 - 
     (G[{0}, yu^(-1)]*G[{1}, yu^(-1)]*G[{1}, yw]*G[{0, yv^(-1)}, yw])/16 - 
     (G[{0}, yv^(-1)]*G[{1}, yu^(-1)]*G[{1}, yw]*G[{0, yv^(-1)}, yw])/16 + 
     (G[{0}, yw]*G[{1}, yu^(-1)]*G[{1}, yw]*G[{0, yv^(-1)}, yw])/16 + 
     (7*G[{1}, yu^(-1)]^2*G[{1}, yw]*G[{0, yv^(-1)}, yw])/128 + 
     (7*G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*G[{1}, yw]*G[{0, yv^(-1)}, yw])/64 - 
     (G[{0}, yu^(-1)]*G[{1}, yw]^2*G[{0, yv^(-1)}, yw])/32 - 
     (G[{0}, yv^(-1)]*G[{1}, yw]^2*G[{0, yv^(-1)}, yw])/32 + 
     (G[{0}, yw]*G[{1}, yw]^2*G[{0, yv^(-1)}, yw])/32 + 
     (15*G[{1}, yu^(-1)]*G[{1}, yw]^2*G[{0, yv^(-1)}, yw])/128 + 
     (G[{1}, yv^(-1)]*G[{1}, yw]^2*G[{0, yv^(-1)}, yw])/32 + 
     (5*G[{1}, yw]^3*G[{0, yv^(-1)}, yw])/128 + 
     (G[{0}, yu^(-1)]*G[{1}, yw]*G[{yu}, yv^(-1)]*G[{0, yv^(-1)}, yw])/16 + 
     (G[{0}, yv^(-1)]*G[{1}, yw]*G[{yu}, yv^(-1)]*G[{0, yv^(-1)}, yw])/16 - 
     (G[{0}, yw]*G[{1}, yw]*G[{yu}, yv^(-1)]*G[{0, yv^(-1)}, yw])/16 - 
     (3*G[{1}, yu^(-1)]*G[{1}, yw]*G[{yu}, yv^(-1)]*G[{0, yv^(-1)}, yw])/32 - 
     (G[{1}, yv^(-1)]*G[{1}, yw]*G[{yu}, yv^(-1)]*G[{0, yv^(-1)}, yw])/16 - 
     (11*G[{1}, yw]^2*G[{yu}, yv^(-1)]*G[{0, yv^(-1)}, yw])/128 + 
     (G[{1}, yw]*G[{yu}, yv^(-1)]^2*G[{0, yv^(-1)}, yw])/64 + 
     (5*G[{1}, yu^(-1)]^2*G[{1/(yu*yv)}, yw]*G[{0, yv^(-1)}, yw])/128 + 
     (G[{0}, yu^(-1)]*G[{1}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, yv^(-1)}, yw])/
      16 + (G[{0}, yv^(-1)]*G[{1}, yv^(-1)]*G[{1/(yu*yv)}, yw]*
       G[{0, yv^(-1)}, yw])/16 - (G[{0}, yw]*G[{1}, yv^(-1)]*
       G[{1/(yu*yv)}, yw]*G[{0, yv^(-1)}, yw])/16 - 
     (11*G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*G[{1/(yu*yv)}, yw]*
       G[{0, yv^(-1)}, yw])/64 - (G[{1}, yv^(-1)]^2*G[{1/(yu*yv)}, yw]*
       G[{0, yv^(-1)}, yw])/32 + (G[{0}, yu^(-1)]*G[{1}, yw]*
       G[{1/(yu*yv)}, yw]*G[{0, yv^(-1)}, yw])/16 + 
     (G[{0}, yv^(-1)]*G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{0, yv^(-1)}, yw])/16 - 
     (G[{0}, yw]*G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{0, yv^(-1)}, yw])/16 + 
     (G[{1}, yu^(-1)]*G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{0, yv^(-1)}, yw])/64 - 
     (3*G[{1}, yv^(-1)]*G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{0, yv^(-1)}, yw])/
      16 - (7*G[{1}, yw]^2*G[{1/(yu*yv)}, yw]*G[{0, yv^(-1)}, yw])/128 - 
     (G[{1}, yu^(-1)]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*
       G[{0, yv^(-1)}, yw])/16 + (G[{1}, yv^(-1)]*G[{yu^(-1)}, yw]*
       G[{1/(yu*yv)}, yw]*G[{0, yv^(-1)}, yw])/16 + 
     (G[{1}, yw]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{0, yv^(-1)}, yw])/
      16 - (G[{yu^(-1)}, yw]^2*G[{1/(yu*yv)}, yw]*G[{0, yv^(-1)}, yw])/16 - 
     (G[{0}, yu^(-1)]*G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw]*
       G[{0, yv^(-1)}, yw])/16 - (G[{0}, yv^(-1)]*G[{yu}, yv^(-1)]*
       G[{1/(yu*yv)}, yw]*G[{0, yv^(-1)}, yw])/16 + 
     (G[{0}, yw]*G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, yv^(-1)}, yw])/
      16 + (3*G[{1}, yu^(-1)]*G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw]*
       G[{0, yv^(-1)}, yw])/32 + (G[{1}, yv^(-1)]*G[{yu}, yv^(-1)]*
       G[{1/(yu*yv)}, yw]*G[{0, yv^(-1)}, yw])/16 + 
     (3*G[{1}, yw]*G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, yv^(-1)}, yw])/
      64 - (G[{yu}, yv^(-1)]^2*G[{1/(yu*yv)}, yw]*G[{0, yv^(-1)}, yw])/64 - 
     (3*G[{1}, yu^(-1)]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*
       G[{0, yv^(-1)}, yw])/32 + (G[{1}, yv^(-1)]*G[{yv^(-1)}, yw]*
       G[{1/(yu*yv)}, yw]*G[{0, yv^(-1)}, yw])/8 - 
     (3*G[{1}, yw]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{0, yv^(-1)}, yw])/
      32 - (G[{yu}, yv^(-1)]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*
       G[{0, yv^(-1)}, yw])/32 + (7*G[{yv^(-1)}, yw]^2*G[{1/(yu*yv)}, yw]*
       G[{0, yv^(-1)}, yw])/64 + (G[{1}, yu^(-1)]*G[{1/(yu*yv)}, yw]^2*
       G[{0, yv^(-1)}, yw])/128 - (G[{1}, yv^(-1)]*G[{1/(yu*yv)}, yw]^2*
       G[{0, yv^(-1)}, yw])/16 - (7*G[{1}, yw]*G[{1/(yu*yv)}, yw]^2*
       G[{0, yv^(-1)}, yw])/128 + (G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2*
       G[{0, yv^(-1)}, yw])/16 + (7*G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw]^2*
       G[{0, yv^(-1)}, yw])/128 - (G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2*
       G[{0, yv^(-1)}, yw])/128 - (G[{0}, yu^(-1)]*G[{0, 1}, yu^(-1)]*
       G[{0, yv^(-1)}, yw])/16 - (G[{0}, yv^(-1)]*G[{0, 1}, yu^(-1)]*
       G[{0, yv^(-1)}, yw])/16 + (G[{0}, yw]*G[{0, 1}, yu^(-1)]*
       G[{0, yv^(-1)}, yw])/16 + (7*G[{1}, yu^(-1)]*G[{0, 1}, yu^(-1)]*
       G[{0, yv^(-1)}, yw])/64 - (7*G[{1}, yv^(-1)]*G[{0, 1}, yu^(-1)]*
       G[{0, yv^(-1)}, yw])/64 + (3*G[{1}, yw]*G[{0, 1}, yu^(-1)]*
       G[{0, yv^(-1)}, yw])/64 - (3*G[{1/(yu*yv)}, yw]*G[{0, 1}, yu^(-1)]*
       G[{0, yv^(-1)}, yw])/64 - (G[{1}, yv^(-1)]*G[{0, 1}, yv^(-1)]*
       G[{0, yv^(-1)}, yw])/8 - (G[{0}, yu^(-1)]*G[{0, 1}, yw]*
       G[{0, yv^(-1)}, yw])/16 - (G[{0}, yv^(-1)]*G[{0, 1}, yw]*
       G[{0, yv^(-1)}, yw])/16 + (G[{0}, yw]*G[{0, 1}, yw]*
       G[{0, yv^(-1)}, yw])/16 - (G[{1}, yu^(-1)]*G[{0, 1}, yw]*
       G[{0, yv^(-1)}, yw])/16 + (G[{1}, yv^(-1)]*G[{0, 1}, yw]*
       G[{0, yv^(-1)}, yw])/16 - (G[{1}, yw]*G[{0, 1}, yw]*
       G[{0, yv^(-1)}, yw])/8 + (G[{yu}, yv^(-1)]*G[{0, 1}, yw]*
       G[{0, yv^(-1)}, yw])/8 + (G[{1/(yu*yv)}, yw]*G[{0, 1}, yw]*
       G[{0, yv^(-1)}, yw])/16 + (G[{0}, yu^(-1)]*G[{0, yu^(-1)}, yw]*
       G[{0, yv^(-1)}, yw])/16 + (G[{0}, yv^(-1)]*G[{0, yu^(-1)}, yw]*
       G[{0, yv^(-1)}, yw])/16 - (G[{0}, yw]*G[{0, yu^(-1)}, yw]*
       G[{0, yv^(-1)}, yw])/16 + (G[{1}, yu^(-1)]*G[{0, yu^(-1)}, yw]*
       G[{0, yv^(-1)}, yw])/16 - (3*G[{1}, yv^(-1)]*G[{0, yu^(-1)}, yw]*
       G[{0, yv^(-1)}, yw])/16 + (G[{1}, yw]*G[{0, yu^(-1)}, yw]*
       G[{0, yv^(-1)}, yw])/8 - (G[{1/(yu*yv)}, yw]*G[{0, yu^(-1)}, yw]*
       G[{0, yv^(-1)}, yw])/16 + (G[{1}, yv^(-1)]*G[{0, yu}, yv^(-1)]*
       G[{0, yv^(-1)}, yw])/8 + (G[{0}, yu^(-1)]*G[{0, yv^(-1)}, yw]^2)/32 + 
     (G[{0}, yv^(-1)]*G[{0, yv^(-1)}, yw]^2)/32 - 
     (G[{0}, yw]*G[{0, yv^(-1)}, yw]^2)/32 - 
     (G[{1}, yu^(-1)]*G[{0, yv^(-1)}, yw]^2)/32 - 
     (G[{1}, yv^(-1)]*G[{0, yv^(-1)}, yw]^2)/32 + 
     (G[{1}, yw]*G[{0, yv^(-1)}, yw]^2)/16 - 
     (G[{1/(yu*yv)}, yw]*G[{0, yv^(-1)}, yw]^2)/32 - 
     (Pi^2*G[{0}, yu^(-1)]*G[{0, 1/(yu*yv)}, yw])/96 - 
     (Pi^2*G[{0}, yv^(-1)]*G[{0, 1/(yu*yv)}, yw])/96 + 
     (Pi^2*G[{0}, yw]*G[{0, 1/(yu*yv)}, yw])/96 - 
     (G[{0}, yu^(-1)]*G[{1}, yu^(-1)]^2*G[{0, 1/(yu*yv)}, yw])/32 - 
     (G[{0}, yv^(-1)]*G[{1}, yu^(-1)]^2*G[{0, 1/(yu*yv)}, yw])/32 + 
     (G[{0}, yw]*G[{1}, yu^(-1)]^2*G[{0, 1/(yu*yv)}, yw])/32 + 
     (7*G[{1}, yu^(-1)]^3*G[{0, 1/(yu*yv)}, yw])/128 - 
     (Pi^2*G[{1}, yv^(-1)]*G[{0, 1/(yu*yv)}, yw])/96 - 
     (G[{0}, yu^(-1)]*G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*G[{0, 1/(yu*yv)}, yw])/
      16 - (G[{0}, yv^(-1)]*G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*
       G[{0, 1/(yu*yv)}, yw])/16 + (G[{0}, yw]*G[{1}, yu^(-1)]*
       G[{1}, yv^(-1)]*G[{0, 1/(yu*yv)}, yw])/16 - 
     (9*G[{1}, yu^(-1)]^2*G[{1}, yv^(-1)]*G[{0, 1/(yu*yv)}, yw])/128 + 
     (G[{0}, yu^(-1)]*G[{1}, yv^(-1)]^2*G[{0, 1/(yu*yv)}, yw])/32 + 
     (G[{0}, yv^(-1)]*G[{1}, yv^(-1)]^2*G[{0, 1/(yu*yv)}, yw])/32 - 
     (G[{0}, yw]*G[{1}, yv^(-1)]^2*G[{0, 1/(yu*yv)}, yw])/32 + 
     (15*G[{1}, yu^(-1)]*G[{1}, yv^(-1)]^2*G[{0, 1/(yu*yv)}, yw])/128 - 
     (G[{1}, yv^(-1)]^3*G[{0, 1/(yu*yv)}, yw])/32 + 
     (Pi^2*G[{1}, yw]*G[{0, 1/(yu*yv)}, yw])/48 + 
     (G[{0}, yu^(-1)]*G[{1}, yu^(-1)]*G[{1}, yw]*G[{0, 1/(yu*yv)}, yw])/16 + 
     (G[{0}, yv^(-1)]*G[{1}, yu^(-1)]*G[{1}, yw]*G[{0, 1/(yu*yv)}, yw])/16 - 
     (G[{0}, yw]*G[{1}, yu^(-1)]*G[{1}, yw]*G[{0, 1/(yu*yv)}, yw])/16 - 
     (7*G[{1}, yu^(-1)]^2*G[{1}, yw]*G[{0, 1/(yu*yv)}, yw])/128 - 
     (G[{0}, yu^(-1)]*G[{1}, yv^(-1)]*G[{1}, yw]*G[{0, 1/(yu*yv)}, yw])/16 - 
     (G[{0}, yv^(-1)]*G[{1}, yv^(-1)]*G[{1}, yw]*G[{0, 1/(yu*yv)}, yw])/16 + 
     (G[{0}, yw]*G[{1}, yv^(-1)]*G[{1}, yw]*G[{0, 1/(yu*yv)}, yw])/16 - 
     (7*G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*G[{1}, yw]*G[{0, 1/(yu*yv)}, yw])/
      64 + (G[{1}, yv^(-1)]^2*G[{1}, yw]*G[{0, 1/(yu*yv)}, yw])/16 + 
     (G[{0}, yu^(-1)]*G[{1}, yw]^2*G[{0, 1/(yu*yv)}, yw])/32 + 
     (G[{0}, yv^(-1)]*G[{1}, yw]^2*G[{0, 1/(yu*yv)}, yw])/32 - 
     (G[{0}, yw]*G[{1}, yw]^2*G[{0, 1/(yu*yv)}, yw])/32 - 
     (15*G[{1}, yu^(-1)]*G[{1}, yw]^2*G[{0, 1/(yu*yv)}, yw])/128 - 
     (G[{1}, yv^(-1)]*G[{1}, yw]^2*G[{0, 1/(yu*yv)}, yw])/32 - 
     (5*G[{1}, yw]^3*G[{0, 1/(yu*yv)}, yw])/128 + 
     (Pi^2*G[{yu}, yv^(-1)]*G[{0, 1/(yu*yv)}, yw])/24 + 
     (G[{0}, yu^(-1)]*G[{1}, yu^(-1)]*G[{yu}, yv^(-1)]*G[{0, 1/(yu*yv)}, yw])/
      8 + (G[{0}, yv^(-1)]*G[{1}, yu^(-1)]*G[{yu}, yv^(-1)]*
       G[{0, 1/(yu*yv)}, yw])/8 - (G[{0}, yw]*G[{1}, yu^(-1)]*
       G[{yu}, yv^(-1)]*G[{0, 1/(yu*yv)}, yw])/8 - 
     (G[{1}, yu^(-1)]^2*G[{yu}, yv^(-1)]*G[{0, 1/(yu*yv)}, yw])/32 + 
     (G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*G[{yu}, yv^(-1)]*G[{0, 1/(yu*yv)}, yw])/
      16 - (G[{1}, yv^(-1)]^2*G[{yu}, yv^(-1)]*G[{0, 1/(yu*yv)}, yw])/32 + 
     (3*G[{1}, yu^(-1)]*G[{1}, yw]*G[{yu}, yv^(-1)]*G[{0, 1/(yu*yv)}, yw])/
      32 + (G[{1}, yv^(-1)]*G[{1}, yw]*G[{yu}, yv^(-1)]*
       G[{0, 1/(yu*yv)}, yw])/16 + (11*G[{1}, yw]^2*G[{yu}, yv^(-1)]*
       G[{0, 1/(yu*yv)}, yw])/128 - (G[{0}, yu^(-1)]*G[{yu}, yv^(-1)]^2*
       G[{0, 1/(yu*yv)}, yw])/16 - (G[{0}, yv^(-1)]*G[{yu}, yv^(-1)]^2*
       G[{0, 1/(yu*yv)}, yw])/16 + (G[{0}, yw]*G[{yu}, yv^(-1)]^2*
       G[{0, 1/(yu*yv)}, yw])/16 - (G[{1}, yu^(-1)]*G[{yu}, yv^(-1)]^2*
       G[{0, 1/(yu*yv)}, yw])/8 - (5*G[{1}, yw]*G[{yu}, yv^(-1)]^2*
       G[{0, 1/(yu*yv)}, yw])/64 + (G[{yu}, yv^(-1)]^3*G[{0, 1/(yu*yv)}, yw])/
      12 - (5*G[{1}, yu^(-1)]^2*G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv)}, yw])/
      128 + (11*G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*G[{1/(yu*yv)}, yw]*
       G[{0, 1/(yu*yv)}, yw])/64 - (G[{1}, yv^(-1)]^2*G[{1/(yu*yv)}, yw]*
       G[{0, 1/(yu*yv)}, yw])/32 - (G[{0}, yu^(-1)]*G[{1}, yw]*
       G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv)}, yw])/16 - 
     (G[{0}, yv^(-1)]*G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv)}, yw])/
      16 + (G[{0}, yw]*G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv)}, yw])/
      16 - (G[{1}, yu^(-1)]*G[{1}, yw]*G[{1/(yu*yv)}, yw]*
       G[{0, 1/(yu*yv)}, yw])/64 + (3*G[{1}, yv^(-1)]*G[{1}, yw]*
       G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv)}, yw])/16 + 
     (7*G[{1}, yw]^2*G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv)}, yw])/128 + 
     (G[{1}, yu^(-1)]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*
       G[{0, 1/(yu*yv)}, yw])/16 - (G[{1}, yv^(-1)]*G[{yu^(-1)}, yw]*
       G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv)}, yw])/16 - 
     (G[{1}, yw]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv)}, yw])/
      16 + (G[{yu^(-1)}, yw]^2*G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv)}, yw])/16 - 
     (3*G[{1}, yu^(-1)]*G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw]*
       G[{0, 1/(yu*yv)}, yw])/32 - (G[{1}, yv^(-1)]*G[{yu}, yv^(-1)]*
       G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv)}, yw])/16 - 
     (3*G[{1}, yw]*G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv)}, yw])/
      64 + (5*G[{yu}, yv^(-1)]^2*G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv)}, yw])/
      64 + (3*G[{1}, yu^(-1)]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*
       G[{0, 1/(yu*yv)}, yw])/32 - (G[{1}, yv^(-1)]*G[{yv^(-1)}, yw]*
       G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv)}, yw])/8 + 
     (3*G[{1}, yw]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv)}, yw])/
      32 + (G[{yu}, yv^(-1)]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*
       G[{0, 1/(yu*yv)}, yw])/32 - (7*G[{yv^(-1)}, yw]^2*G[{1/(yu*yv)}, yw]*
       G[{0, 1/(yu*yv)}, yw])/64 - (G[{1}, yu^(-1)]*G[{1/(yu*yv)}, yw]^2*
       G[{0, 1/(yu*yv)}, yw])/128 + (G[{1}, yv^(-1)]*G[{1/(yu*yv)}, yw]^2*
       G[{0, 1/(yu*yv)}, yw])/16 + (7*G[{1}, yw]*G[{1/(yu*yv)}, yw]^2*
       G[{0, 1/(yu*yv)}, yw])/128 - (G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2*
       G[{0, 1/(yu*yv)}, yw])/16 - (7*G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw]^2*
       G[{0, 1/(yu*yv)}, yw])/128 + (G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2*
       G[{0, 1/(yu*yv)}, yw])/128 - (7*G[{1}, yu^(-1)]*G[{0, 1}, yu^(-1)]*
       G[{0, 1/(yu*yv)}, yw])/64 + (7*G[{1}, yv^(-1)]*G[{0, 1}, yu^(-1)]*
       G[{0, 1/(yu*yv)}, yw])/64 + (G[{1}, yw]*G[{0, 1}, yu^(-1)]*
       G[{0, 1/(yu*yv)}, yw])/64 + (G[{yu}, yv^(-1)]*G[{0, 1}, yu^(-1)]*
       G[{0, 1/(yu*yv)}, yw])/16 + (3*G[{1/(yu*yv)}, yw]*G[{0, 1}, yu^(-1)]*
       G[{0, 1/(yu*yv)}, yw])/64 + (G[{1}, yw]*G[{0, 1}, yv^(-1)]*
       G[{0, 1/(yu*yv)}, yw])/16 + (G[{yu}, yv^(-1)]*G[{0, 1}, yv^(-1)]*
       G[{0, 1/(yu*yv)}, yw])/16 + (G[{1}, yu^(-1)]*G[{0, 1}, yw]*
       G[{0, 1/(yu*yv)}, yw])/8 - (G[{1}, yv^(-1)]*G[{0, 1}, yw]*
       G[{0, 1/(yu*yv)}, yw])/16 + (G[{1}, yw]*G[{0, 1}, yw]*
       G[{0, 1/(yu*yv)}, yw])/16 - (G[{yu}, yv^(-1)]*G[{0, 1}, yw]*
       G[{0, 1/(yu*yv)}, yw])/16 - (G[{1/(yu*yv)}, yw]*G[{0, 1}, yw]*
       G[{0, 1/(yu*yv)}, yw])/16 - (G[{1}, yu^(-1)]*G[{0, yu^(-1)}, yw]*
       G[{0, 1/(yu*yv)}, yw])/8 + (G[{1}, yv^(-1)]*G[{0, yu^(-1)}, yw]*
       G[{0, 1/(yu*yv)}, yw])/8 - (G[{1}, yw]*G[{0, yu^(-1)}, yw]*
       G[{0, 1/(yu*yv)}, yw])/16 + (G[{1/(yu*yv)}, yw]*G[{0, yu^(-1)}, yw]*
       G[{0, 1/(yu*yv)}, yw])/16 - (G[{1}, yw]*G[{0, yu}, yv^(-1)]*
       G[{0, 1/(yu*yv)}, yw])/16 - (G[{yu}, yv^(-1)]*G[{0, yu}, yv^(-1)]*
       G[{0, 1/(yu*yv)}, yw])/16 - (G[{1}, yu^(-1)]*G[{0, yv^(-1)}, yw]*
       G[{0, 1/(yu*yv)}, yw])/16 + (G[{1}, yv^(-1)]*G[{0, yv^(-1)}, yw]*
       G[{0, 1/(yu*yv)}, yw])/16 - (G[{1}, yw]*G[{0, yv^(-1)}, yw]*
       G[{0, 1/(yu*yv)}, yw])/16 + (G[{1/(yu*yv)}, yw]*G[{0, yv^(-1)}, yw]*
       G[{0, 1/(yu*yv)}, yw])/16 + (G[{1}, yu^(-1)]*G[{0, 1/(yu*yv)}, yw]^2)/
      32 - (G[{1}, yv^(-1)]*G[{0, 1/(yu*yv)}, yw]^2)/16 + 
     (G[{1}, yw]*G[{0, 1/(yu*yv)}, yw]^2)/32 + 
     (G[{yu}, yv^(-1)]*G[{0, 1/(yu*yv)}, yw]^2)/32 - 
     (G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv)}, yw]^2)/32 - 
     (Pi^2*G[{0}, yu^(-1)]*G[{1, yu^(-1)}, yw])/96 - 
     (Pi^2*G[{0}, yv^(-1)]*G[{1, yu^(-1)}, yw])/96 + 
     (Pi^2*G[{0}, yw]*G[{1, yu^(-1)}, yw])/96 + 
     (Pi^2*G[{1}, yu^(-1)]*G[{1, yu^(-1)}, yw])/24 + 
     (G[{0}, yu^(-1)]*G[{1}, yu^(-1)]^2*G[{1, yu^(-1)}, yw])/16 + 
     (G[{0}, yv^(-1)]*G[{1}, yu^(-1)]^2*G[{1, yu^(-1)}, yw])/16 - 
     (G[{0}, yw]*G[{1}, yu^(-1)]^2*G[{1, yu^(-1)}, yw])/16 - 
     (5*G[{1}, yu^(-1)]^3*G[{1, yu^(-1)}, yw])/128 - 
     (Pi^2*G[{1}, yv^(-1)]*G[{1, yu^(-1)}, yw])/48 - 
     (G[{0}, yu^(-1)]*G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*G[{1, yu^(-1)}, yw])/
      8 - (G[{0}, yv^(-1)]*G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*
       G[{1, yu^(-1)}, yw])/8 + (G[{0}, yw]*G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*
       G[{1, yu^(-1)}, yw])/8 - (G[{1}, yu^(-1)]^2*G[{1}, yv^(-1)]*
       G[{1, yu^(-1)}, yw])/128 + (G[{0}, yu^(-1)]*G[{1}, yv^(-1)]^2*
       G[{1, yu^(-1)}, yw])/32 + (G[{0}, yv^(-1)]*G[{1}, yv^(-1)]^2*
       G[{1, yu^(-1)}, yw])/32 - (G[{0}, yw]*G[{1}, yv^(-1)]^2*
       G[{1, yu^(-1)}, yw])/32 + (15*G[{1}, yu^(-1)]*G[{1}, yv^(-1)]^2*
       G[{1, yu^(-1)}, yw])/128 - (G[{1}, yv^(-1)]^3*G[{1, yu^(-1)}, yw])/
      32 - (Pi^2*G[{1}, yw]*G[{1, yu^(-1)}, yw])/96 + 
     (G[{0}, yu^(-1)]*G[{1}, yu^(-1)]*G[{1}, yw]*G[{1, yu^(-1)}, yw])/8 + 
     (G[{0}, yv^(-1)]*G[{1}, yu^(-1)]*G[{1}, yw]*G[{1, yu^(-1)}, yw])/8 - 
     (G[{0}, yw]*G[{1}, yu^(-1)]*G[{1}, yw]*G[{1, yu^(-1)}, yw])/8 - 
     (19*G[{1}, yu^(-1)]^2*G[{1}, yw]*G[{1, yu^(-1)}, yw])/128 - 
     (G[{0}, yu^(-1)]*G[{1}, yv^(-1)]*G[{1}, yw]*G[{1, yu^(-1)}, yw])/16 - 
     (G[{0}, yv^(-1)]*G[{1}, yv^(-1)]*G[{1}, yw]*G[{1, yu^(-1)}, yw])/16 + 
     (G[{0}, yw]*G[{1}, yv^(-1)]*G[{1}, yw]*G[{1, yu^(-1)}, yw])/16 - 
     (11*G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*G[{1}, yw]*G[{1, yu^(-1)}, yw])/64 + 
     (3*G[{1}, yv^(-1)]^2*G[{1}, yw]*G[{1, yu^(-1)}, yw])/32 - 
     (11*G[{1}, yu^(-1)]*G[{1}, yw]^2*G[{1, yu^(-1)}, yw])/128 - 
     (G[{1}, yv^(-1)]*G[{1}, yw]^2*G[{1, yu^(-1)}, yw])/32 - 
     (5*G[{1}, yw]^3*G[{1, yu^(-1)}, yw])/128 - 
     (G[{0}, yu^(-1)]*G[{1}, yw]*G[{yu}, yv^(-1)]*G[{1, yu^(-1)}, yw])/16 - 
     (G[{0}, yv^(-1)]*G[{1}, yw]*G[{yu}, yv^(-1)]*G[{1, yu^(-1)}, yw])/16 + 
     (G[{0}, yw]*G[{1}, yw]*G[{yu}, yv^(-1)]*G[{1, yu^(-1)}, yw])/16 + 
     (7*G[{1}, yu^(-1)]*G[{1}, yw]*G[{yu}, yv^(-1)]*G[{1, yu^(-1)}, yw])/32 + 
     (G[{1}, yv^(-1)]*G[{1}, yw]*G[{yu}, yv^(-1)]*G[{1, yu^(-1)}, yw])/16 + 
     (15*G[{1}, yw]^2*G[{yu}, yv^(-1)]*G[{1, yu^(-1)}, yw])/128 - 
     (5*G[{1}, yw]*G[{yu}, yv^(-1)]^2*G[{1, yu^(-1)}, yw])/64 - 
     (G[{0}, yu^(-1)]*G[{1}, yu^(-1)]*G[{1/(yu*yv)}, yw]*G[{1, yu^(-1)}, yw])/
      16 - (G[{0}, yv^(-1)]*G[{1}, yu^(-1)]*G[{1/(yu*yv)}, yw]*
       G[{1, yu^(-1)}, yw])/16 + (G[{0}, yw]*G[{1}, yu^(-1)]*
       G[{1/(yu*yv)}, yw]*G[{1, yu^(-1)}, yw])/16 + 
     (3*G[{1}, yu^(-1)]^2*G[{1/(yu*yv)}, yw]*G[{1, yu^(-1)}, yw])/128 + 
     (19*G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*G[{1/(yu*yv)}, yw]*
       G[{1, yu^(-1)}, yw])/64 - (G[{1}, yv^(-1)]^2*G[{1/(yu*yv)}, yw]*
       G[{1, yu^(-1)}, yw])/16 - (G[{0}, yu^(-1)]*G[{1}, yw]*
       G[{1/(yu*yv)}, yw]*G[{1, yu^(-1)}, yw])/8 - 
     (G[{0}, yv^(-1)]*G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{1, yu^(-1)}, yw])/8 + 
     (G[{0}, yw]*G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{1, yu^(-1)}, yw])/8 + 
     (15*G[{1}, yu^(-1)]*G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{1, yu^(-1)}, yw])/
      64 + (3*G[{1}, yv^(-1)]*G[{1}, yw]*G[{1/(yu*yv)}, yw]*
       G[{1, yu^(-1)}, yw])/16 + (11*G[{1}, yw]^2*G[{1/(yu*yv)}, yw]*
       G[{1, yu^(-1)}, yw])/128 + (3*G[{1}, yu^(-1)]*G[{yu^(-1)}, yw]*
       G[{1/(yu*yv)}, yw]*G[{1, yu^(-1)}, yw])/16 - 
     (G[{1}, yv^(-1)]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*
       G[{1, yu^(-1)}, yw])/16 + (G[{1}, yw]*G[{yu^(-1)}, yw]*
       G[{1/(yu*yv)}, yw]*G[{1, yu^(-1)}, yw])/8 + 
     (G[{yu^(-1)}, yw]^2*G[{1/(yu*yv)}, yw]*G[{1, yu^(-1)}, yw])/8 + 
     (G[{0}, yu^(-1)]*G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw]*
       G[{1, yu^(-1)}, yw])/16 + (G[{0}, yv^(-1)]*G[{yu}, yv^(-1)]*
       G[{1/(yu*yv)}, yw]*G[{1, yu^(-1)}, yw])/16 - 
     (G[{0}, yw]*G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{1, yu^(-1)}, yw])/
      16 - (7*G[{1}, yu^(-1)]*G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw]*
       G[{1, yu^(-1)}, yw])/32 - (G[{1}, yv^(-1)]*G[{yu}, yv^(-1)]*
       G[{1/(yu*yv)}, yw]*G[{1, yu^(-1)}, yw])/16 - 
     (11*G[{1}, yw]*G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{1, yu^(-1)}, yw])/
      64 - (G[{yu^(-1)}, yw]*G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw]*
       G[{1, yu^(-1)}, yw])/8 + (5*G[{yu}, yv^(-1)]^2*G[{1/(yu*yv)}, yw]*
       G[{1, yu^(-1)}, yw])/64 + (3*G[{1}, yu^(-1)]*G[{yv^(-1)}, yw]*
       G[{1/(yu*yv)}, yw]*G[{1, yu^(-1)}, yw])/32 - 
     (G[{1}, yv^(-1)]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*
       G[{1, yu^(-1)}, yw])/4 - (5*G[{1}, yw]*G[{yv^(-1)}, yw]*
       G[{1/(yu*yv)}, yw]*G[{1, yu^(-1)}, yw])/32 - 
     (G[{yu^(-1)}, yw]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*
       G[{1, yu^(-1)}, yw])/8 + (5*G[{yu}, yv^(-1)]*G[{yv^(-1)}, yw]*
       G[{1/(yu*yv)}, yw]*G[{1, yu^(-1)}, yw])/32 - 
     (7*G[{yv^(-1)}, yw]^2*G[{1/(yu*yv)}, yw]*G[{1, yu^(-1)}, yw])/64 - 
     (G[{1}, yu^(-1)]*G[{1/(yu*yv)}, yw]^2*G[{1, yu^(-1)}, yw])/128 + 
     (G[{1}, yv^(-1)]*G[{1/(yu*yv)}, yw]^2*G[{1, yu^(-1)}, yw])/16 + 
     (7*G[{1}, yw]*G[{1/(yu*yv)}, yw]^2*G[{1, yu^(-1)}, yw])/128 - 
     (G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2*G[{1, yu^(-1)}, yw])/16 - 
     (7*G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw]^2*G[{1, yu^(-1)}, yw])/128 + 
     (G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2*G[{1, yu^(-1)}, yw])/128 - 
     (G[{0}, yu^(-1)]*G[{0, 1}, yu^(-1)]*G[{1, yu^(-1)}, yw])/16 - 
     (G[{0}, yv^(-1)]*G[{0, 1}, yu^(-1)]*G[{1, yu^(-1)}, yw])/16 + 
     (G[{0}, yw]*G[{0, 1}, yu^(-1)]*G[{1, yu^(-1)}, yw])/16 + 
     (5*G[{1}, yu^(-1)]*G[{0, 1}, yu^(-1)]*G[{1, yu^(-1)}, yw])/64 + 
     (3*G[{1}, yv^(-1)]*G[{0, 1}, yu^(-1)]*G[{1, yu^(-1)}, yw])/64 + 
     (G[{1}, yw]*G[{0, 1}, yu^(-1)]*G[{1, yu^(-1)}, yw])/64 + 
     (3*G[{1/(yu*yv)}, yw]*G[{0, 1}, yu^(-1)]*G[{1, yu^(-1)}, yw])/64 + 
     (G[{1}, yu^(-1)]*G[{0, 1}, yv^(-1)]*G[{1, yu^(-1)}, yw])/8 - 
     (G[{1}, yv^(-1)]*G[{0, 1}, yv^(-1)]*G[{1, yu^(-1)}, yw])/16 + 
     (G[{1}, yw]*G[{0, 1}, yv^(-1)]*G[{1, yu^(-1)}, yw])/16 - 
     (G[{1/(yu*yv)}, yw]*G[{0, 1}, yv^(-1)]*G[{1, yu^(-1)}, yw])/16 + 
     (G[{1}, yu^(-1)]*G[{0, 1}, yw]*G[{1, yu^(-1)}, yw])/16 - 
     (G[{1}, yv^(-1)]*G[{0, 1}, yw]*G[{1, yu^(-1)}, yw])/16 - 
     (G[{1}, yw]*G[{0, 1}, yw]*G[{1, yu^(-1)}, yw])/16 - 
     (G[{1/(yu*yv)}, yw]*G[{0, 1}, yw]*G[{1, yu^(-1)}, yw])/16 - 
     (G[{1}, yu^(-1)]*G[{0, yu^(-1)}, yw]*G[{1, yu^(-1)}, yw])/16 + 
     (G[{1}, yv^(-1)]*G[{0, yu^(-1)}, yw]*G[{1, yu^(-1)}, yw])/16 + 
     (G[{1}, yw]*G[{0, yu^(-1)}, yw]*G[{1, yu^(-1)}, yw])/16 + 
     (G[{1/(yu*yv)}, yw]*G[{0, yu^(-1)}, yw]*G[{1, yu^(-1)}, yw])/16 - 
     (G[{1}, yu^(-1)]*G[{0, yu}, yv^(-1)]*G[{1, yu^(-1)}, yw])/8 + 
     (G[{1}, yv^(-1)]*G[{0, yu}, yv^(-1)]*G[{1, yu^(-1)}, yw])/16 - 
     (G[{1}, yw]*G[{0, yu}, yv^(-1)]*G[{1, yu^(-1)}, yw])/16 + 
     (G[{1/(yu*yv)}, yw]*G[{0, yu}, yv^(-1)]*G[{1, yu^(-1)}, yw])/16 - 
     (G[{1}, yu^(-1)]*G[{0, yv^(-1)}, yw]*G[{1, yu^(-1)}, yw])/16 + 
     (G[{1}, yv^(-1)]*G[{0, yv^(-1)}, yw]*G[{1, yu^(-1)}, yw])/16 + 
     (G[{1}, yw]*G[{0, yv^(-1)}, yw]*G[{1, yu^(-1)}, yw])/16 + 
     (G[{1/(yu*yv)}, yw]*G[{0, yv^(-1)}, yw]*G[{1, yu^(-1)}, yw])/16 + 
     (G[{1}, yu^(-1)]*G[{0, 1/(yu*yv)}, yw]*G[{1, yu^(-1)}, yw])/16 - 
     (G[{1}, yv^(-1)]*G[{0, 1/(yu*yv)}, yw]*G[{1, yu^(-1)}, yw])/16 - 
     (G[{1}, yw]*G[{0, 1/(yu*yv)}, yw]*G[{1, yu^(-1)}, yw])/16 - 
     (G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv)}, yw]*G[{1, yu^(-1)}, yw])/16 + 
     (3*G[{1}, yu^(-1)]*G[{1, yu^(-1)}, yw]^2)/32 - 
     (G[{1}, yv^(-1)]*G[{1, yu^(-1)}, yw]^2)/32 + 
     (G[{1}, yw]*G[{1, yu^(-1)}, yw]^2)/16 - 
     (G[{yu}, yv^(-1)]*G[{1, yu^(-1)}, yw]^2)/16 - 
     (G[{1/(yu*yv)}, yw]*G[{1, yu^(-1)}, yw]^2)/16 + 
     (Pi^2*G[{0}, yu^(-1)]*G[{1, yu}, yv^(-1)])/32 + 
     (Pi^2*G[{0}, yv^(-1)]*G[{1, yu}, yv^(-1)])/32 - 
     (Pi^2*G[{0}, yw]*G[{1, yu}, yv^(-1)])/32 + 
     (13*Pi^2*G[{1}, yu^(-1)]*G[{1, yu}, yv^(-1)])/768 + 
     (3*G[{0}, yu^(-1)]^2*G[{1}, yu^(-1)]*G[{1, yu}, yv^(-1)])/64 + 
     (3*G[{0}, yu^(-1)]*G[{0}, yv^(-1)]*G[{1}, yu^(-1)]*G[{1, yu}, yv^(-1)])/
      32 + (3*G[{0}, yv^(-1)]^2*G[{1}, yu^(-1)]*G[{1, yu}, yv^(-1)])/64 - 
     (3*G[{0}, yu^(-1)]*G[{0}, yw]*G[{1}, yu^(-1)]*G[{1, yu}, yv^(-1)])/32 - 
     (3*G[{0}, yv^(-1)]*G[{0}, yw]*G[{1}, yu^(-1)]*G[{1, yu}, yv^(-1)])/32 + 
     (3*G[{0}, yw]^2*G[{1}, yu^(-1)]*G[{1, yu}, yv^(-1)])/64 - 
     (3*G[{1}, yu^(-1)]^3*G[{1, yu}, yv^(-1)])/64 + 
     (Pi^2*G[{1}, yv^(-1)]*G[{1, yu}, yv^(-1)])/96 + 
     (3*G[{0}, yu^(-1)]*G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*G[{1, yu}, yv^(-1)])/
      32 + (3*G[{0}, yv^(-1)]*G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*
       G[{1, yu}, yv^(-1)])/32 - (3*G[{0}, yw]*G[{1}, yu^(-1)]*
       G[{1}, yv^(-1)]*G[{1, yu}, yv^(-1)])/32 - 
     (3*G[{1}, yu^(-1)]^2*G[{1}, yv^(-1)]*G[{1, yu}, yv^(-1)])/64 - 
     (G[{0}, yu^(-1)]*G[{1}, yv^(-1)]^2*G[{1, yu}, yv^(-1)])/32 - 
     (G[{0}, yv^(-1)]*G[{1}, yv^(-1)]^2*G[{1, yu}, yv^(-1)])/32 + 
     (G[{0}, yw]*G[{1}, yv^(-1)]^2*G[{1, yu}, yv^(-1)])/32 - 
     (3*G[{1}, yu^(-1)]*G[{1}, yv^(-1)]^2*G[{1, yu}, yv^(-1)])/32 + 
     (G[{1}, yv^(-1)]^3*G[{1, yu}, yv^(-1)])/32 + 
     (43*Pi^2*G[{1}, yw]*G[{1, yu}, yv^(-1)])/768 + 
     (3*G[{0}, yu^(-1)]^2*G[{1}, yw]*G[{1, yu}, yv^(-1)])/128 + 
     (3*G[{0}, yu^(-1)]*G[{0}, yv^(-1)]*G[{1}, yw]*G[{1, yu}, yv^(-1)])/64 + 
     (3*G[{0}, yv^(-1)]^2*G[{1}, yw]*G[{1, yu}, yv^(-1)])/128 - 
     (3*G[{0}, yu^(-1)]*G[{0}, yw]*G[{1}, yw]*G[{1, yu}, yv^(-1)])/64 - 
     (3*G[{0}, yv^(-1)]*G[{0}, yw]*G[{1}, yw]*G[{1, yu}, yv^(-1)])/64 + 
     (3*G[{0}, yw]^2*G[{1}, yw]*G[{1, yu}, yv^(-1)])/128 + 
     (11*G[{0}, yu^(-1)]*G[{1}, yu^(-1)]*G[{1}, yw]*G[{1, yu}, yv^(-1)])/64 + 
     (11*G[{0}, yv^(-1)]*G[{1}, yu^(-1)]*G[{1}, yw]*G[{1, yu}, yv^(-1)])/64 - 
     (11*G[{0}, yw]*G[{1}, yu^(-1)]*G[{1}, yw]*G[{1, yu}, yv^(-1)])/64 - 
     (7*G[{1}, yu^(-1)]^2*G[{1}, yw]*G[{1, yu}, yv^(-1)])/128 - 
     (3*G[{0}, yu^(-1)]*G[{1}, yv^(-1)]*G[{1}, yw]*G[{1, yu}, yv^(-1)])/64 - 
     (3*G[{0}, yv^(-1)]*G[{1}, yv^(-1)]*G[{1}, yw]*G[{1, yu}, yv^(-1)])/64 + 
     (3*G[{0}, yw]*G[{1}, yv^(-1)]*G[{1}, yw]*G[{1, yu}, yv^(-1)])/64 + 
     (3*G[{1}, yv^(-1)]^2*G[{1}, yw]*G[{1, yu}, yv^(-1)])/128 + 
     (3*G[{0}, yu^(-1)]*G[{1}, yw]^2*G[{1, yu}, yv^(-1)])/64 + 
     (3*G[{0}, yv^(-1)]*G[{1}, yw]^2*G[{1, yu}, yv^(-1)])/64 - 
     (3*G[{0}, yw]*G[{1}, yw]^2*G[{1, yu}, yv^(-1)])/64 + 
     (19*G[{1}, yu^(-1)]*G[{1}, yw]^2*G[{1, yu}, yv^(-1)])/128 - 
     (5*G[{1}, yv^(-1)]*G[{1}, yw]^2*G[{1, yu}, yv^(-1)])/64 + 
     (3*G[{1}, yw]^3*G[{1, yu}, yv^(-1)])/128 - 
     (3*G[{1}, yu^(-1)]*G[{1}, yw]*G[{yu}, yv^(-1)]*G[{1, yu}, yv^(-1)])/16 + 
     (G[{1}, yv^(-1)]*G[{1}, yw]*G[{yu}, yv^(-1)]*G[{1, yu}, yv^(-1)])/4 - 
     (7*G[{1}, yw]^2*G[{yu}, yv^(-1)]*G[{1, yu}, yv^(-1)])/128 + 
     (G[{1}, yw]*G[{yu}, yv^(-1)]^2*G[{1, yu}, yv^(-1)])/16 + 
     (5*Pi^2*G[{1/(yu*yv)}, yw]*G[{1, yu}, yv^(-1)])/768 - 
     (3*G[{0}, yu^(-1)]^2*G[{1/(yu*yv)}, yw]*G[{1, yu}, yv^(-1)])/128 - 
     (3*G[{0}, yu^(-1)]*G[{0}, yv^(-1)]*G[{1/(yu*yv)}, yw]*
       G[{1, yu}, yv^(-1)])/64 - (3*G[{0}, yv^(-1)]^2*G[{1/(yu*yv)}, yw]*
       G[{1, yu}, yv^(-1)])/128 + (3*G[{0}, yu^(-1)]*G[{0}, yw]*
       G[{1/(yu*yv)}, yw]*G[{1, yu}, yv^(-1)])/64 + 
     (3*G[{0}, yv^(-1)]*G[{0}, yw]*G[{1/(yu*yv)}, yw]*G[{1, yu}, yv^(-1)])/
      64 - (3*G[{0}, yw]^2*G[{1/(yu*yv)}, yw]*G[{1, yu}, yv^(-1)])/128 + 
     (G[{0}, yu^(-1)]*G[{1}, yu^(-1)]*G[{1/(yu*yv)}, yw]*G[{1, yu}, yv^(-1)])/
      64 + (G[{0}, yv^(-1)]*G[{1}, yu^(-1)]*G[{1/(yu*yv)}, yw]*
       G[{1, yu}, yv^(-1)])/64 - (G[{0}, yw]*G[{1}, yu^(-1)]*
       G[{1/(yu*yv)}, yw]*G[{1, yu}, yv^(-1)])/64 + 
     (7*G[{1}, yu^(-1)]^2*G[{1/(yu*yv)}, yw]*G[{1, yu}, yv^(-1)])/128 + 
     (3*G[{0}, yu^(-1)]*G[{1}, yv^(-1)]*G[{1/(yu*yv)}, yw]*
       G[{1, yu}, yv^(-1)])/64 + (3*G[{0}, yv^(-1)]*G[{1}, yv^(-1)]*
       G[{1/(yu*yv)}, yw]*G[{1, yu}, yv^(-1)])/64 - 
     (3*G[{0}, yw]*G[{1}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{1, yu}, yv^(-1)])/
      64 + (3*G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*G[{1/(yu*yv)}, yw]*
       G[{1, yu}, yv^(-1)])/16 - (11*G[{1}, yv^(-1)]^2*G[{1/(yu*yv)}, yw]*
       G[{1, yu}, yv^(-1)])/128 - (9*G[{1}, yu^(-1)]*G[{1}, yw]*
       G[{1/(yu*yv)}, yw]*G[{1, yu}, yv^(-1)])/64 + 
     (5*G[{1}, yv^(-1)]*G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{1, yu}, yv^(-1)])/
      16 - (9*G[{1}, yw]^2*G[{1/(yu*yv)}, yw]*G[{1, yu}, yv^(-1)])/128 + 
     (G[{0}, yu^(-1)]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*
       G[{1, yu}, yv^(-1)])/16 + (G[{0}, yv^(-1)]*G[{yu^(-1)}, yw]*
       G[{1/(yu*yv)}, yw]*G[{1, yu}, yv^(-1)])/16 - 
     (G[{0}, yw]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{1, yu}, yv^(-1)])/
      16 + (G[{1}, yu^(-1)]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*
       G[{1, yu}, yv^(-1)])/32 - (G[{1}, yv^(-1)]*G[{yu^(-1)}, yw]*
       G[{1/(yu*yv)}, yw]*G[{1, yu}, yv^(-1)])/16 + 
     (3*G[{1}, yw]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{1, yu}, yv^(-1)])/
      64 + (3*G[{yu^(-1)}, yw]^2*G[{1/(yu*yv)}, yw]*G[{1, yu}, yv^(-1)])/32 + 
     (3*G[{1}, yu^(-1)]*G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw]*
       G[{1, yu}, yv^(-1)])/16 - (G[{1}, yv^(-1)]*G[{yu}, yv^(-1)]*
       G[{1/(yu*yv)}, yw]*G[{1, yu}, yv^(-1)])/4 + 
     (7*G[{1}, yw]*G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{1, yu}, yv^(-1)])/
      64 - (G[{yu}, yv^(-1)]^2*G[{1/(yu*yv)}, yw]*G[{1, yu}, yv^(-1)])/16 - 
     (G[{0}, yu^(-1)]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*
       G[{1, yu}, yv^(-1)])/16 - (G[{0}, yv^(-1)]*G[{yv^(-1)}, yw]*
       G[{1/(yu*yv)}, yw]*G[{1, yu}, yv^(-1)])/16 + 
     (G[{0}, yw]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{1, yu}, yv^(-1)])/
      16 + (3*G[{1}, yu^(-1)]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*
       G[{1, yu}, yv^(-1)])/32 - (3*G[{1}, yv^(-1)]*G[{yv^(-1)}, yw]*
       G[{1/(yu*yv)}, yw]*G[{1, yu}, yv^(-1)])/16 + 
     (13*G[{1}, yw]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{1, yu}, yv^(-1)])/
      64 - (G[{yu^(-1)}, yw]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*
       G[{1, yu}, yv^(-1)])/16 - (G[{yu}, yv^(-1)]*G[{yv^(-1)}, yw]*
       G[{1/(yu*yv)}, yw]*G[{1, yu}, yv^(-1)])/8 - 
     (3*G[{yv^(-1)}, yw]^2*G[{1/(yu*yv)}, yw]*G[{1, yu}, yv^(-1)])/32 - 
     (3*G[{0}, yu^(-1)]*G[{1/(yu*yv)}, yw]^2*G[{1, yu}, yv^(-1)])/64 - 
     (3*G[{0}, yv^(-1)]*G[{1/(yu*yv)}, yw]^2*G[{1, yu}, yv^(-1)])/64 + 
     (3*G[{0}, yw]*G[{1/(yu*yv)}, yw]^2*G[{1, yu}, yv^(-1)])/64 + 
     (3*G[{1}, yu^(-1)]*G[{1/(yu*yv)}, yw]^2*G[{1, yu}, yv^(-1)])/128 + 
     (G[{1}, yv^(-1)]*G[{1/(yu*yv)}, yw]^2*G[{1, yu}, yv^(-1)])/64 - 
     (G[{1}, yw]*G[{1/(yu*yv)}, yw]^2*G[{1, yu}, yv^(-1)])/128 - 
     (G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2*G[{1, yu}, yv^(-1)])/64 + 
     (G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw]^2*G[{1, yu}, yv^(-1)])/128 - 
     (9*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2*G[{1, yu}, yv^(-1)])/128 + 
     (G[{0}, yu^(-1)]*G[{0, 1}, yu^(-1)]*G[{1, yu}, yv^(-1)])/16 + 
     (G[{0}, yv^(-1)]*G[{0, 1}, yu^(-1)]*G[{1, yu}, yv^(-1)])/16 - 
     (G[{0}, yw]*G[{0, 1}, yu^(-1)]*G[{1, yu}, yv^(-1)])/16 + 
     (G[{1}, yu^(-1)]*G[{0, 1}, yu^(-1)]*G[{1, yu}, yv^(-1)])/32 - 
     (G[{1}, yv^(-1)]*G[{0, 1}, yu^(-1)]*G[{1, yu}, yv^(-1)])/32 + 
     (7*G[{1}, yw]*G[{0, 1}, yu^(-1)]*G[{1, yu}, yv^(-1)])/64 + 
     (G[{1/(yu*yv)}, yw]*G[{0, 1}, yu^(-1)]*G[{1, yu}, yv^(-1)])/64 + 
     (G[{0}, yu^(-1)]*G[{0, 1}, yv^(-1)]*G[{1, yu}, yv^(-1)])/16 + 
     (G[{0}, yv^(-1)]*G[{0, 1}, yv^(-1)]*G[{1, yu}, yv^(-1)])/16 - 
     (G[{0}, yw]*G[{0, 1}, yv^(-1)]*G[{1, yu}, yv^(-1)])/16 + 
     (G[{1}, yu^(-1)]*G[{0, 1}, yv^(-1)]*G[{1, yu}, yv^(-1)])/8 + 
     (G[{1}, yv^(-1)]*G[{0, 1}, yv^(-1)]*G[{1, yu}, yv^(-1)])/16 + 
     (3*G[{1}, yw]*G[{0, 1}, yv^(-1)]*G[{1, yu}, yv^(-1)])/16 - 
     (G[{1/(yu*yv)}, yw]*G[{0, 1}, yv^(-1)]*G[{1, yu}, yv^(-1)])/16 + 
     (3*G[{1}, yu^(-1)]*G[{0, 1}, yw]*G[{1, yu}, yv^(-1)])/32 - 
     (G[{1}, yv^(-1)]*G[{0, 1}, yw]*G[{1, yu}, yv^(-1)])/8 + 
     (3*G[{1}, yw]*G[{0, 1}, yw]*G[{1, yu}, yv^(-1)])/64 - 
     (3*G[{1/(yu*yv)}, yw]*G[{0, 1}, yw]*G[{1, yu}, yv^(-1)])/64 - 
     (G[{0}, yu^(-1)]*G[{0, yu^(-1)}, yw]*G[{1, yu}, yv^(-1)])/16 - 
     (G[{0}, yv^(-1)]*G[{0, yu^(-1)}, yw]*G[{1, yu}, yv^(-1)])/16 + 
     (G[{0}, yw]*G[{0, yu^(-1)}, yw]*G[{1, yu}, yv^(-1)])/16 - 
     (G[{1}, yu^(-1)]*G[{0, yu^(-1)}, yw]*G[{1, yu}, yv^(-1)])/32 + 
     (G[{1}, yv^(-1)]*G[{0, yu^(-1)}, yw]*G[{1, yu}, yv^(-1)])/16 - 
     (3*G[{1}, yw]*G[{0, yu^(-1)}, yw]*G[{1, yu}, yv^(-1)])/64 + 
     (3*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1)}, yw]*G[{1, yu}, yv^(-1)])/64 - 
     (G[{0}, yu^(-1)]*G[{0, yu}, yv^(-1)]*G[{1, yu}, yv^(-1)])/16 - 
     (G[{0}, yv^(-1)]*G[{0, yu}, yv^(-1)]*G[{1, yu}, yv^(-1)])/16 + 
     (G[{0}, yw]*G[{0, yu}, yv^(-1)]*G[{1, yu}, yv^(-1)])/16 - 
     (G[{1}, yu^(-1)]*G[{0, yu}, yv^(-1)]*G[{1, yu}, yv^(-1)])/8 - 
     (G[{1}, yv^(-1)]*G[{0, yu}, yv^(-1)]*G[{1, yu}, yv^(-1)])/16 - 
     (3*G[{1}, yw]*G[{0, yu}, yv^(-1)]*G[{1, yu}, yv^(-1)])/16 + 
     (G[{1/(yu*yv)}, yw]*G[{0, yu}, yv^(-1)]*G[{1, yu}, yv^(-1)])/16 + 
     (G[{0}, yu^(-1)]*G[{0, yv^(-1)}, yw]*G[{1, yu}, yv^(-1)])/16 + 
     (G[{0}, yv^(-1)]*G[{0, yv^(-1)}, yw]*G[{1, yu}, yv^(-1)])/16 - 
     (G[{0}, yw]*G[{0, yv^(-1)}, yw]*G[{1, yu}, yv^(-1)])/16 - 
     (G[{1}, yu^(-1)]*G[{0, yv^(-1)}, yw]*G[{1, yu}, yv^(-1)])/32 + 
     (G[{1}, yv^(-1)]*G[{0, yv^(-1)}, yw]*G[{1, yu}, yv^(-1)])/16 - 
     (3*G[{1}, yw]*G[{0, yv^(-1)}, yw]*G[{1, yu}, yv^(-1)])/64 + 
     (3*G[{1/(yu*yv)}, yw]*G[{0, yv^(-1)}, yw]*G[{1, yu}, yv^(-1)])/64 - 
     (G[{1}, yu^(-1)]*G[{0, 1/(yu*yv)}, yw]*G[{1, yu}, yv^(-1)])/32 + 
     (3*G[{1}, yw]*G[{0, 1/(yu*yv)}, yw]*G[{1, yu}, yv^(-1)])/64 - 
     (3*G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv)}, yw]*G[{1, yu}, yv^(-1)])/64 + 
     (G[{0}, yu^(-1)]*G[{1, yu^(-1)}, yw]*G[{1, yu}, yv^(-1)])/16 + 
     (G[{0}, yv^(-1)]*G[{1, yu^(-1)}, yw]*G[{1, yu}, yv^(-1)])/16 - 
     (G[{0}, yw]*G[{1, yu^(-1)}, yw]*G[{1, yu}, yv^(-1)])/16 + 
     (G[{1}, yu^(-1)]*G[{1, yu^(-1)}, yw]*G[{1, yu}, yv^(-1)])/32 - 
     (G[{1}, yv^(-1)]*G[{1, yu^(-1)}, yw]*G[{1, yu}, yv^(-1)])/16 + 
     (3*G[{1}, yw]*G[{1, yu^(-1)}, yw]*G[{1, yu}, yv^(-1)])/64 - 
     (7*G[{1/(yu*yv)}, yw]*G[{1, yu^(-1)}, yw]*G[{1, yu}, yv^(-1)])/64 + 
     (3*G[{1}, yu^(-1)]*G[{1, yu}, yv^(-1)]^2)/32 - 
     (G[{1}, yv^(-1)]*G[{1, yu}, yv^(-1)]^2)/8 + 
     (5*G[{1}, yw]*G[{1, yu}, yv^(-1)]^2)/128 - 
     (5*G[{1/(yu*yv)}, yw]*G[{1, yu}, yv^(-1)]^2)/128 - 
     (Pi^2*G[{0}, yu^(-1)]*G[{1, yv^(-1)}, yw])/32 - 
     (Pi^2*G[{0}, yv^(-1)]*G[{1, yv^(-1)}, yw])/32 + 
     (Pi^2*G[{0}, yw]*G[{1, yv^(-1)}, yw])/32 + 
     (19*Pi^2*G[{1}, yu^(-1)]*G[{1, yv^(-1)}, yw])/768 - 
     (3*G[{0}, yu^(-1)]^2*G[{1}, yu^(-1)]*G[{1, yv^(-1)}, yw])/64 - 
     (3*G[{0}, yu^(-1)]*G[{0}, yv^(-1)]*G[{1}, yu^(-1)]*G[{1, yv^(-1)}, yw])/
      32 - (3*G[{0}, yv^(-1)]^2*G[{1}, yu^(-1)]*G[{1, yv^(-1)}, yw])/64 + 
     (3*G[{0}, yu^(-1)]*G[{0}, yw]*G[{1}, yu^(-1)]*G[{1, yv^(-1)}, yw])/32 + 
     (3*G[{0}, yv^(-1)]*G[{0}, yw]*G[{1}, yu^(-1)]*G[{1, yv^(-1)}, yw])/32 - 
     (3*G[{0}, yw]^2*G[{1}, yu^(-1)]*G[{1, yv^(-1)}, yw])/64 + 
     (G[{0}, yu^(-1)]*G[{1}, yu^(-1)]^2*G[{1, yv^(-1)}, yw])/16 + 
     (G[{0}, yv^(-1)]*G[{1}, yu^(-1)]^2*G[{1, yv^(-1)}, yw])/16 - 
     (G[{0}, yw]*G[{1}, yu^(-1)]^2*G[{1, yv^(-1)}, yw])/16 + 
     (G[{1}, yu^(-1)]^3*G[{1, yv^(-1)}, yw])/128 + 
     (Pi^2*G[{1}, yv^(-1)]*G[{1, yv^(-1)}, yw])/32 + 
     (G[{0}, yu^(-1)]*G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*G[{1, yv^(-1)}, yw])/
      32 + (G[{0}, yv^(-1)]*G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*
       G[{1, yv^(-1)}, yw])/32 - (G[{0}, yw]*G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*
       G[{1, yv^(-1)}, yw])/32 - (3*G[{1}, yu^(-1)]^2*G[{1}, yv^(-1)]*
       G[{1, yv^(-1)}, yw])/128 + (3*G[{1}, yu^(-1)]*G[{1}, yv^(-1)]^2*
       G[{1, yv^(-1)}, yw])/128 - (5*Pi^2*G[{1}, yw]*G[{1, yv^(-1)}, yw])/
      768 - (3*G[{0}, yu^(-1)]^2*G[{1}, yw]*G[{1, yv^(-1)}, yw])/64 - 
     (3*G[{0}, yu^(-1)]*G[{0}, yv^(-1)]*G[{1}, yw]*G[{1, yv^(-1)}, yw])/32 - 
     (3*G[{0}, yv^(-1)]^2*G[{1}, yw]*G[{1, yv^(-1)}, yw])/64 + 
     (3*G[{0}, yu^(-1)]*G[{0}, yw]*G[{1}, yw]*G[{1, yv^(-1)}, yw])/32 + 
     (3*G[{0}, yv^(-1)]*G[{0}, yw]*G[{1}, yw]*G[{1, yv^(-1)}, yw])/32 - 
     (3*G[{0}, yw]^2*G[{1}, yw]*G[{1, yv^(-1)}, yw])/64 + 
     (G[{0}, yu^(-1)]*G[{1}, yu^(-1)]*G[{1}, yw]*G[{1, yv^(-1)}, yw])/16 + 
     (G[{0}, yv^(-1)]*G[{1}, yu^(-1)]*G[{1}, yw]*G[{1, yv^(-1)}, yw])/16 - 
     (G[{0}, yw]*G[{1}, yu^(-1)]*G[{1}, yw]*G[{1, yv^(-1)}, yw])/16 + 
     (7*G[{1}, yu^(-1)]^2*G[{1}, yw]*G[{1, yv^(-1)}, yw])/128 + 
     (3*G[{0}, yu^(-1)]*G[{1}, yv^(-1)]*G[{1}, yw]*G[{1, yv^(-1)}, yw])/32 + 
     (3*G[{0}, yv^(-1)]*G[{1}, yv^(-1)]*G[{1}, yw]*G[{1, yv^(-1)}, yw])/32 - 
     (3*G[{0}, yw]*G[{1}, yv^(-1)]*G[{1}, yw]*G[{1, yv^(-1)}, yw])/32 - 
     (5*G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*G[{1}, yw]*G[{1, yv^(-1)}, yw])/64 - 
     (3*G[{1}, yv^(-1)]^2*G[{1}, yw]*G[{1, yv^(-1)}, yw])/64 + 
     (9*G[{1}, yu^(-1)]*G[{1}, yw]^2*G[{1, yv^(-1)}, yw])/128 + 
     (3*G[{1}, yw]^3*G[{1, yv^(-1)}, yw])/128 + 
     (5*Pi^2*G[{yu}, yv^(-1)]*G[{1, yv^(-1)}, yw])/768 + 
     (3*G[{0}, yu^(-1)]^2*G[{yu}, yv^(-1)]*G[{1, yv^(-1)}, yw])/64 + 
     (3*G[{0}, yu^(-1)]*G[{0}, yv^(-1)]*G[{yu}, yv^(-1)]*G[{1, yv^(-1)}, yw])/
      32 + (3*G[{0}, yv^(-1)]^2*G[{yu}, yv^(-1)]*G[{1, yv^(-1)}, yw])/64 - 
     (3*G[{0}, yu^(-1)]*G[{0}, yw]*G[{yu}, yv^(-1)]*G[{1, yv^(-1)}, yw])/32 - 
     (3*G[{0}, yv^(-1)]*G[{0}, yw]*G[{yu}, yv^(-1)]*G[{1, yv^(-1)}, yw])/32 + 
     (3*G[{0}, yw]^2*G[{yu}, yv^(-1)]*G[{1, yv^(-1)}, yw])/64 + 
     (G[{0}, yu^(-1)]*G[{1}, yu^(-1)]*G[{yu}, yv^(-1)]*G[{1, yv^(-1)}, yw])/
      32 + (G[{0}, yv^(-1)]*G[{1}, yu^(-1)]*G[{yu}, yv^(-1)]*
       G[{1, yv^(-1)}, yw])/32 - (G[{0}, yw]*G[{1}, yu^(-1)]*G[{yu}, yv^(-1)]*
       G[{1, yv^(-1)}, yw])/32 - (G[{1}, yu^(-1)]^2*G[{yu}, yv^(-1)]*
       G[{1, yv^(-1)}, yw])/8 + (G[{0}, yu^(-1)]*G[{1}, yv^(-1)]*
       G[{yu}, yv^(-1)]*G[{1, yv^(-1)}, yw])/32 + 
     (G[{0}, yv^(-1)]*G[{1}, yv^(-1)]*G[{yu}, yv^(-1)]*G[{1, yv^(-1)}, yw])/
      32 - (G[{0}, yw]*G[{1}, yv^(-1)]*G[{yu}, yv^(-1)]*G[{1, yv^(-1)}, yw])/
      32 - (G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*G[{yu}, yv^(-1)]*
       G[{1, yv^(-1)}, yw])/32 - (5*G[{1}, yv^(-1)]^2*G[{yu}, yv^(-1)]*
       G[{1, yv^(-1)}, yw])/64 + (G[{0}, yu^(-1)]*G[{1}, yw]*G[{yu}, yv^(-1)]*
       G[{1, yv^(-1)}, yw])/32 + (G[{0}, yv^(-1)]*G[{1}, yw]*G[{yu}, yv^(-1)]*
       G[{1, yv^(-1)}, yw])/32 - (G[{0}, yw]*G[{1}, yw]*G[{yu}, yv^(-1)]*
       G[{1, yv^(-1)}, yw])/32 - (5*G[{1}, yu^(-1)]*G[{1}, yw]*
       G[{yu}, yv^(-1)]*G[{1, yv^(-1)}, yw])/32 + 
     (3*G[{1}, yv^(-1)]*G[{1}, yw]*G[{yu}, yv^(-1)]*G[{1, yv^(-1)}, yw])/32 - 
     (9*G[{1}, yw]^2*G[{yu}, yv^(-1)]*G[{1, yv^(-1)}, yw])/128 - 
     (G[{0}, yu^(-1)]*G[{yu}, yv^(-1)]^2*G[{1, yv^(-1)}, yw])/8 - 
     (G[{0}, yv^(-1)]*G[{yu}, yv^(-1)]^2*G[{1, yv^(-1)}, yw])/8 + 
     (G[{0}, yw]*G[{yu}, yv^(-1)]^2*G[{1, yv^(-1)}, yw])/8 + 
     (7*G[{1}, yu^(-1)]*G[{yu}, yv^(-1)]^2*G[{1, yv^(-1)}, yw])/64 + 
     (3*G[{yu}, yv^(-1)]^3*G[{1, yv^(-1)}, yw])/64 - 
     (5*Pi^2*G[{1/(yu*yv)}, yw]*G[{1, yv^(-1)}, yw])/768 + 
     (3*G[{0}, yu^(-1)]^2*G[{1/(yu*yv)}, yw]*G[{1, yv^(-1)}, yw])/128 + 
     (3*G[{0}, yu^(-1)]*G[{0}, yv^(-1)]*G[{1/(yu*yv)}, yw]*
       G[{1, yv^(-1)}, yw])/64 + (3*G[{0}, yv^(-1)]^2*G[{1/(yu*yv)}, yw]*
       G[{1, yv^(-1)}, yw])/128 - (3*G[{0}, yu^(-1)]*G[{0}, yw]*
       G[{1/(yu*yv)}, yw]*G[{1, yv^(-1)}, yw])/64 - 
     (3*G[{0}, yv^(-1)]*G[{0}, yw]*G[{1/(yu*yv)}, yw]*G[{1, yv^(-1)}, yw])/
      64 + (3*G[{0}, yw]^2*G[{1/(yu*yv)}, yw]*G[{1, yv^(-1)}, yw])/128 - 
     (5*G[{0}, yu^(-1)]*G[{1}, yu^(-1)]*G[{1/(yu*yv)}, yw]*
       G[{1, yv^(-1)}, yw])/64 - (5*G[{0}, yv^(-1)]*G[{1}, yu^(-1)]*
       G[{1/(yu*yv)}, yw]*G[{1, yv^(-1)}, yw])/64 + 
     (5*G[{0}, yw]*G[{1}, yu^(-1)]*G[{1/(yu*yv)}, yw]*G[{1, yv^(-1)}, yw])/
      64 - (G[{1}, yu^(-1)]^2*G[{1/(yu*yv)}, yw]*G[{1, yv^(-1)}, yw])/32 - 
     (3*G[{0}, yu^(-1)]*G[{1}, yv^(-1)]*G[{1/(yu*yv)}, yw]*
       G[{1, yv^(-1)}, yw])/64 - (3*G[{0}, yv^(-1)]*G[{1}, yv^(-1)]*
       G[{1/(yu*yv)}, yw]*G[{1, yv^(-1)}, yw])/64 + 
     (3*G[{0}, yw]*G[{1}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{1, yv^(-1)}, yw])/
      64 + (7*G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*G[{1/(yu*yv)}, yw]*
       G[{1, yv^(-1)}, yw])/64 + (3*G[{1}, yv^(-1)]^2*G[{1/(yu*yv)}, yw]*
       G[{1, yv^(-1)}, yw])/128 - (3*G[{0}, yu^(-1)]*G[{1}, yw]*
       G[{1/(yu*yv)}, yw]*G[{1, yv^(-1)}, yw])/64 - 
     (3*G[{0}, yv^(-1)]*G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{1, yv^(-1)}, yw])/
      64 + (3*G[{0}, yw]*G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{1, yv^(-1)}, yw])/
      64 - (G[{1}, yu^(-1)]*G[{1}, yw]*G[{1/(yu*yv)}, yw]*
       G[{1, yv^(-1)}, yw])/8 + (3*G[{1}, yv^(-1)]*G[{1}, yw]*
       G[{1/(yu*yv)}, yw]*G[{1, yv^(-1)}, yw])/64 - 
     (11*G[{1}, yw]^2*G[{1/(yu*yv)}, yw]*G[{1, yv^(-1)}, yw])/128 - 
     (G[{0}, yu^(-1)]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*
       G[{1, yv^(-1)}, yw])/16 - (G[{0}, yv^(-1)]*G[{yu^(-1)}, yw]*
       G[{1/(yu*yv)}, yw]*G[{1, yv^(-1)}, yw])/16 + 
     (G[{0}, yw]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{1, yv^(-1)}, yw])/
      16 + (5*G[{1}, yu^(-1)]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*
       G[{1, yv^(-1)}, yw])/32 + (G[{1}, yw]*G[{yu^(-1)}, yw]*
       G[{1/(yu*yv)}, yw]*G[{1, yv^(-1)}, yw])/32 + 
     (G[{yu^(-1)}, yw]^2*G[{1/(yu*yv)}, yw]*G[{1, yv^(-1)}, yw])/32 + 
     (G[{0}, yu^(-1)]*G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw]*
       G[{1, yv^(-1)}, yw])/32 + (G[{0}, yv^(-1)]*G[{yu}, yv^(-1)]*
       G[{1/(yu*yv)}, yw]*G[{1, yv^(-1)}, yw])/32 - 
     (G[{0}, yw]*G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{1, yv^(-1)}, yw])/
      32 + (7*G[{1}, yu^(-1)]*G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw]*
       G[{1, yv^(-1)}, yw])/64 - (G[{1}, yv^(-1)]*G[{yu}, yv^(-1)]*
       G[{1/(yu*yv)}, yw]*G[{1, yv^(-1)}, yw])/32 + 
     (11*G[{1}, yw]*G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{1, yv^(-1)}, yw])/
      64 - (G[{yu^(-1)}, yw]*G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw]*
       G[{1, yv^(-1)}, yw])/32 - (9*G[{yu}, yv^(-1)]^2*G[{1/(yu*yv)}, yw]*
       G[{1, yv^(-1)}, yw])/128 + (G[{0}, yu^(-1)]*G[{yv^(-1)}, yw]*
       G[{1/(yu*yv)}, yw]*G[{1, yv^(-1)}, yw])/16 + 
     (G[{0}, yv^(-1)]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*
       G[{1, yv^(-1)}, yw])/16 - (G[{0}, yw]*G[{yv^(-1)}, yw]*
       G[{1/(yu*yv)}, yw]*G[{1, yv^(-1)}, yw])/16 - 
     (G[{1}, yv^(-1)]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*
       G[{1, yv^(-1)}, yw])/16 + (G[{1}, yw]*G[{yv^(-1)}, yw]*
       G[{1/(yu*yv)}, yw]*G[{1, yv^(-1)}, yw])/16 - 
     (G[{yu^(-1)}, yw]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*
       G[{1, yv^(-1)}, yw])/16 - (G[{yu}, yv^(-1)]*G[{yv^(-1)}, yw]*
       G[{1/(yu*yv)}, yw]*G[{1, yv^(-1)}, yw])/16 - 
     (G[{yv^(-1)}, yw]^2*G[{1/(yu*yv)}, yw]*G[{1, yv^(-1)}, yw])/64 + 
     (3*G[{0}, yu^(-1)]*G[{1/(yu*yv)}, yw]^2*G[{1, yv^(-1)}, yw])/64 + 
     (3*G[{0}, yv^(-1)]*G[{1/(yu*yv)}, yw]^2*G[{1, yv^(-1)}, yw])/64 - 
     (3*G[{0}, yw]*G[{1/(yu*yv)}, yw]^2*G[{1, yv^(-1)}, yw])/64 - 
     (G[{1}, yu^(-1)]*G[{1/(yu*yv)}, yw]^2*G[{1, yv^(-1)}, yw])/32 + 
     (3*G[{1}, yv^(-1)]*G[{1/(yu*yv)}, yw]^2*G[{1, yv^(-1)}, yw])/64 + 
     (7*G[{1}, yw]*G[{1/(yu*yv)}, yw]^2*G[{1, yv^(-1)}, yw])/64 - 
     (3*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2*G[{1, yv^(-1)}, yw])/64 - 
     (7*G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw]^2*G[{1, yv^(-1)}, yw])/64 + 
     (5*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2*G[{1, yv^(-1)}, yw])/64 - 
     (G[{0}, yu^(-1)]*G[{0, 1}, yu^(-1)]*G[{1, yv^(-1)}, yw])/16 - 
     (G[{0}, yv^(-1)]*G[{0, 1}, yu^(-1)]*G[{1, yv^(-1)}, yw])/16 + 
     (G[{0}, yw]*G[{0, 1}, yu^(-1)]*G[{1, yv^(-1)}, yw])/16 + 
     (3*G[{1}, yu^(-1)]*G[{0, 1}, yu^(-1)]*G[{1, yv^(-1)}, yw])/64 + 
     (5*G[{1}, yv^(-1)]*G[{0, 1}, yu^(-1)]*G[{1, yv^(-1)}, yw])/64 - 
     (G[{1}, yw]*G[{0, 1}, yu^(-1)]*G[{1, yv^(-1)}, yw])/64 + 
     (G[{1/(yu*yv)}, yw]*G[{0, 1}, yu^(-1)]*G[{1, yv^(-1)}, yw])/32 - 
     (G[{0}, yu^(-1)]*G[{0, 1}, yv^(-1)]*G[{1, yv^(-1)}, yw])/8 - 
     (G[{0}, yv^(-1)]*G[{0, 1}, yv^(-1)]*G[{1, yv^(-1)}, yw])/8 + 
     (G[{0}, yw]*G[{0, 1}, yv^(-1)]*G[{1, yv^(-1)}, yw])/8 + 
     (G[{1}, yv^(-1)]*G[{0, 1}, yv^(-1)]*G[{1, yv^(-1)}, yw])/8 - 
     (G[{1}, yw]*G[{0, 1}, yv^(-1)]*G[{1, yv^(-1)}, yw])/8 + 
     (G[{yu}, yv^(-1)]*G[{0, 1}, yv^(-1)]*G[{1, yv^(-1)}, yw])/8 + 
     (G[{1}, yu^(-1)]*G[{0, 1}, yw]*G[{1, yv^(-1)}, yw])/32 + 
     (G[{1}, yw]*G[{0, 1}, yw]*G[{1, yv^(-1)}, yw])/32 - 
     (G[{yu}, yv^(-1)]*G[{0, 1}, yw]*G[{1, yv^(-1)}, yw])/32 - 
     (G[{1/(yu*yv)}, yw]*G[{0, 1}, yw]*G[{1, yv^(-1)}, yw])/64 - 
     (G[{1}, yu^(-1)]*G[{0, yu^(-1)}, yw]*G[{1, yv^(-1)}, yw])/32 - 
     (G[{1}, yw]*G[{0, yu^(-1)}, yw]*G[{1, yv^(-1)}, yw])/32 + 
     (G[{yu}, yv^(-1)]*G[{0, yu^(-1)}, yw]*G[{1, yv^(-1)}, yw])/32 + 
     (G[{1/(yu*yv)}, yw]*G[{0, yu^(-1)}, yw]*G[{1, yv^(-1)}, yw])/64 + 
     (G[{0}, yu^(-1)]*G[{0, yu}, yv^(-1)]*G[{1, yv^(-1)}, yw])/8 + 
     (G[{0}, yv^(-1)]*G[{0, yu}, yv^(-1)]*G[{1, yv^(-1)}, yw])/8 - 
     (G[{0}, yw]*G[{0, yu}, yv^(-1)]*G[{1, yv^(-1)}, yw])/8 - 
     (G[{1}, yv^(-1)]*G[{0, yu}, yv^(-1)]*G[{1, yv^(-1)}, yw])/8 + 
     (G[{1}, yw]*G[{0, yu}, yv^(-1)]*G[{1, yv^(-1)}, yw])/8 - 
     (G[{yu}, yv^(-1)]*G[{0, yu}, yv^(-1)]*G[{1, yv^(-1)}, yw])/8 - 
     (G[{1}, yu^(-1)]*G[{0, yv^(-1)}, yw]*G[{1, yv^(-1)}, yw])/32 - 
     (G[{1}, yw]*G[{0, yv^(-1)}, yw]*G[{1, yv^(-1)}, yw])/32 + 
     (G[{yu}, yv^(-1)]*G[{0, yv^(-1)}, yw]*G[{1, yv^(-1)}, yw])/32 + 
     (G[{1/(yu*yv)}, yw]*G[{0, yv^(-1)}, yw]*G[{1, yv^(-1)}, yw])/64 + 
     (G[{1}, yu^(-1)]*G[{0, 1/(yu*yv)}, yw]*G[{1, yv^(-1)}, yw])/32 + 
     (G[{1}, yw]*G[{0, 1/(yu*yv)}, yw]*G[{1, yv^(-1)}, yw])/32 - 
     (G[{yu}, yv^(-1)]*G[{0, 1/(yu*yv)}, yw]*G[{1, yv^(-1)}, yw])/32 - 
     (G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv)}, yw]*G[{1, yv^(-1)}, yw])/64 - 
     (G[{0}, yu^(-1)]*G[{1, yu^(-1)}, yw]*G[{1, yv^(-1)}, yw])/8 - 
     (G[{0}, yv^(-1)]*G[{1, yu^(-1)}, yw]*G[{1, yv^(-1)}, yw])/8 + 
     (G[{0}, yw]*G[{1, yu^(-1)}, yw]*G[{1, yv^(-1)}, yw])/8 + 
     (G[{1}, yu^(-1)]*G[{1, yu^(-1)}, yw]*G[{1, yv^(-1)}, yw])/32 + 
     (G[{1}, yv^(-1)]*G[{1, yu^(-1)}, yw]*G[{1, yv^(-1)}, yw])/8 - 
     (3*G[{1}, yw]*G[{1, yu^(-1)}, yw]*G[{1, yv^(-1)}, yw])/32 + 
     (3*G[{yu}, yv^(-1)]*G[{1, yu^(-1)}, yw]*G[{1, yv^(-1)}, yw])/32 - 
     (G[{1/(yu*yv)}, yw]*G[{1, yu^(-1)}, yw]*G[{1, yv^(-1)}, yw])/64 - 
     (G[{0}, yu^(-1)]*G[{1, yu}, yv^(-1)]*G[{1, yv^(-1)}, yw])/16 - 
     (G[{0}, yv^(-1)]*G[{1, yu}, yv^(-1)]*G[{1, yv^(-1)}, yw])/16 + 
     (G[{0}, yw]*G[{1, yu}, yv^(-1)]*G[{1, yv^(-1)}, yw])/16 - 
     (G[{1}, yu^(-1)]*G[{1, yu}, yv^(-1)]*G[{1, yv^(-1)}, yw])/32 + 
     (G[{1}, yv^(-1)]*G[{1, yu}, yv^(-1)]*G[{1, yv^(-1)}, yw])/16 - 
     (7*G[{1}, yw]*G[{1, yu}, yv^(-1)]*G[{1, yv^(-1)}, yw])/64 + 
     (G[{yu}, yv^(-1)]*G[{1, yu}, yv^(-1)]*G[{1, yv^(-1)}, yw])/8 - 
     (G[{1/(yu*yv)}, yw]*G[{1, yu}, yv^(-1)]*G[{1, yv^(-1)}, yw])/32 - 
     (G[{0}, yu^(-1)]*G[{1, yv^(-1)}, yw]^2)/32 - 
     (G[{0}, yv^(-1)]*G[{1, yv^(-1)}, yw]^2)/32 + 
     (G[{0}, yw]*G[{1, yv^(-1)}, yw]^2)/32 + 
     (G[{1}, yu^(-1)]*G[{1, yv^(-1)}, yw]^2)/32 + 
     (G[{1}, yv^(-1)]*G[{1, yv^(-1)}, yw]^2)/32 + 
     (G[{1/(yu*yv)}, yw]*G[{1, yv^(-1)}, yw]^2)/128 + 
     (Pi^2*G[{0}, yu^(-1)]*G[{1, 1/(yu*yv)}, yw])/32 + 
     (Pi^2*G[{0}, yv^(-1)]*G[{1, 1/(yu*yv)}, yw])/32 - 
     (Pi^2*G[{0}, yw]*G[{1, 1/(yu*yv)}, yw])/32 + 
     (13*Pi^2*G[{1}, yu^(-1)]*G[{1, 1/(yu*yv)}, yw])/768 + 
     (3*G[{0}, yu^(-1)]^2*G[{1}, yu^(-1)]*G[{1, 1/(yu*yv)}, yw])/64 + 
     (3*G[{0}, yu^(-1)]*G[{0}, yv^(-1)]*G[{1}, yu^(-1)]*
       G[{1, 1/(yu*yv)}, yw])/32 + (3*G[{0}, yv^(-1)]^2*G[{1}, yu^(-1)]*
       G[{1, 1/(yu*yv)}, yw])/64 - (3*G[{0}, yu^(-1)]*G[{0}, yw]*
       G[{1}, yu^(-1)]*G[{1, 1/(yu*yv)}, yw])/32 - 
     (3*G[{0}, yv^(-1)]*G[{0}, yw]*G[{1}, yu^(-1)]*G[{1, 1/(yu*yv)}, yw])/
      32 + (3*G[{0}, yw]^2*G[{1}, yu^(-1)]*G[{1, 1/(yu*yv)}, yw])/64 - 
     (3*G[{1}, yu^(-1)]^3*G[{1, 1/(yu*yv)}, yw])/64 + 
     (Pi^2*G[{1}, yv^(-1)]*G[{1, 1/(yu*yv)}, yw])/96 + 
     (3*G[{0}, yu^(-1)]*G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*
       G[{1, 1/(yu*yv)}, yw])/32 + (3*G[{0}, yv^(-1)]*G[{1}, yu^(-1)]*
       G[{1}, yv^(-1)]*G[{1, 1/(yu*yv)}, yw])/32 - 
     (3*G[{0}, yw]*G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*G[{1, 1/(yu*yv)}, yw])/
      32 - (3*G[{1}, yu^(-1)]^2*G[{1}, yv^(-1)]*G[{1, 1/(yu*yv)}, yw])/64 - 
     (G[{0}, yu^(-1)]*G[{1}, yv^(-1)]^2*G[{1, 1/(yu*yv)}, yw])/32 - 
     (G[{0}, yv^(-1)]*G[{1}, yv^(-1)]^2*G[{1, 1/(yu*yv)}, yw])/32 + 
     (G[{0}, yw]*G[{1}, yv^(-1)]^2*G[{1, 1/(yu*yv)}, yw])/32 - 
     (3*G[{1}, yu^(-1)]*G[{1}, yv^(-1)]^2*G[{1, 1/(yu*yv)}, yw])/32 + 
     (G[{1}, yv^(-1)]^3*G[{1, 1/(yu*yv)}, yw])/32 + 
     (61*Pi^2*G[{1}, yw]*G[{1, 1/(yu*yv)}, yw])/768 + 
     (3*G[{0}, yu^(-1)]^2*G[{1}, yw]*G[{1, 1/(yu*yv)}, yw])/64 + 
     (3*G[{0}, yu^(-1)]*G[{0}, yv^(-1)]*G[{1}, yw]*G[{1, 1/(yu*yv)}, yw])/
      32 + (3*G[{0}, yv^(-1)]^2*G[{1}, yw]*G[{1, 1/(yu*yv)}, yw])/64 - 
     (3*G[{0}, yu^(-1)]*G[{0}, yw]*G[{1}, yw]*G[{1, 1/(yu*yv)}, yw])/32 - 
     (3*G[{0}, yv^(-1)]*G[{0}, yw]*G[{1}, yw]*G[{1, 1/(yu*yv)}, yw])/32 + 
     (3*G[{0}, yw]^2*G[{1}, yw]*G[{1, 1/(yu*yv)}, yw])/64 + 
     (3*G[{0}, yu^(-1)]*G[{1}, yu^(-1)]*G[{1}, yw]*G[{1, 1/(yu*yv)}, yw])/
      16 + (3*G[{0}, yv^(-1)]*G[{1}, yu^(-1)]*G[{1}, yw]*
       G[{1, 1/(yu*yv)}, yw])/16 - (3*G[{0}, yw]*G[{1}, yu^(-1)]*G[{1}, yw]*
       G[{1, 1/(yu*yv)}, yw])/16 - (9*G[{1}, yu^(-1)]^2*G[{1}, yw]*
       G[{1, 1/(yu*yv)}, yw])/64 - (G[{0}, yu^(-1)]*G[{1}, yv^(-1)]*
       G[{1}, yw]*G[{1, 1/(yu*yv)}, yw])/32 - 
     (G[{0}, yv^(-1)]*G[{1}, yv^(-1)]*G[{1}, yw]*G[{1, 1/(yu*yv)}, yw])/32 + 
     (G[{0}, yw]*G[{1}, yv^(-1)]*G[{1}, yw]*G[{1, 1/(yu*yv)}, yw])/32 + 
     (G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*G[{1}, yw]*G[{1, 1/(yu*yv)}, yw])/32 - 
     (3*G[{1}, yv^(-1)]^2*G[{1}, yw]*G[{1, 1/(yu*yv)}, yw])/64 + 
     (G[{0}, yu^(-1)]*G[{1}, yw]^2*G[{1, 1/(yu*yv)}, yw])/8 + 
     (G[{0}, yv^(-1)]*G[{1}, yw]^2*G[{1, 1/(yu*yv)}, yw])/8 - 
     (G[{0}, yw]*G[{1}, yw]^2*G[{1, 1/(yu*yv)}, yw])/8 + 
     (G[{1}, yu^(-1)]*G[{1}, yw]^2*G[{1, 1/(yu*yv)}, yw])/32 - 
     (3*G[{1}, yv^(-1)]*G[{1}, yw]^2*G[{1, 1/(yu*yv)}, yw])/32 + 
     (G[{1}, yw]^3*G[{1, 1/(yu*yv)}, yw])/16 - 
     (23*Pi^2*G[{yu}, yv^(-1)]*G[{1, 1/(yu*yv)}, yw])/256 - 
     (3*G[{0}, yu^(-1)]^2*G[{yu}, yv^(-1)]*G[{1, 1/(yu*yv)}, yw])/64 - 
     (3*G[{0}, yu^(-1)]*G[{0}, yv^(-1)]*G[{yu}, yv^(-1)]*
       G[{1, 1/(yu*yv)}, yw])/32 - (3*G[{0}, yv^(-1)]^2*G[{yu}, yv^(-1)]*
       G[{1, 1/(yu*yv)}, yw])/64 + (3*G[{0}, yu^(-1)]*G[{0}, yw]*
       G[{yu}, yv^(-1)]*G[{1, 1/(yu*yv)}, yw])/32 + 
     (3*G[{0}, yv^(-1)]*G[{0}, yw]*G[{yu}, yv^(-1)]*G[{1, 1/(yu*yv)}, yw])/
      32 - (3*G[{0}, yw]^2*G[{yu}, yv^(-1)]*G[{1, 1/(yu*yv)}, yw])/64 - 
     (9*G[{0}, yu^(-1)]*G[{1}, yu^(-1)]*G[{yu}, yv^(-1)]*
       G[{1, 1/(yu*yv)}, yw])/32 - (9*G[{0}, yv^(-1)]*G[{1}, yu^(-1)]*
       G[{yu}, yv^(-1)]*G[{1, 1/(yu*yv)}, yw])/32 + 
     (9*G[{0}, yw]*G[{1}, yu^(-1)]*G[{yu}, yv^(-1)]*G[{1, 1/(yu*yv)}, yw])/
      32 + (3*G[{1}, yu^(-1)]^2*G[{yu}, yv^(-1)]*G[{1, 1/(yu*yv)}, yw])/16 - 
     (G[{0}, yu^(-1)]*G[{1}, yv^(-1)]*G[{yu}, yv^(-1)]*G[{1, 1/(yu*yv)}, yw])/
      32 - (G[{0}, yv^(-1)]*G[{1}, yv^(-1)]*G[{yu}, yv^(-1)]*
       G[{1, 1/(yu*yv)}, yw])/32 + (G[{0}, yw]*G[{1}, yv^(-1)]*
       G[{yu}, yv^(-1)]*G[{1, 1/(yu*yv)}, yw])/32 - 
     (3*G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*G[{yu}, yv^(-1)]*
       G[{1, 1/(yu*yv)}, yw])/32 + (9*G[{1}, yv^(-1)]^2*G[{yu}, yv^(-1)]*
       G[{1, 1/(yu*yv)}, yw])/64 - (11*G[{0}, yu^(-1)]*G[{1}, yw]*
       G[{yu}, yv^(-1)]*G[{1, 1/(yu*yv)}, yw])/32 - 
     (11*G[{0}, yv^(-1)]*G[{1}, yw]*G[{yu}, yv^(-1)]*G[{1, 1/(yu*yv)}, yw])/
      32 + (11*G[{0}, yw]*G[{1}, yw]*G[{yu}, yv^(-1)]*G[{1, 1/(yu*yv)}, yw])/
      32 - (G[{1}, yu^(-1)]*G[{1}, yw]*G[{yu}, yv^(-1)]*
       G[{1, 1/(yu*yv)}, yw])/8 - (G[{1}, yv^(-1)]*G[{1}, yw]*
       G[{yu}, yv^(-1)]*G[{1, 1/(yu*yv)}, yw])/32 - 
     (3*G[{1}, yw]^2*G[{yu}, yv^(-1)]*G[{1, 1/(yu*yv)}, yw])/16 + 
     (G[{0}, yu^(-1)]*G[{yu}, yv^(-1)]^2*G[{1, 1/(yu*yv)}, yw])/4 + 
     (G[{0}, yv^(-1)]*G[{yu}, yv^(-1)]^2*G[{1, 1/(yu*yv)}, yw])/4 - 
     (G[{0}, yw]*G[{yu}, yv^(-1)]^2*G[{1, 1/(yu*yv)}, yw])/4 + 
     (9*G[{1}, yu^(-1)]*G[{yu}, yv^(-1)]^2*G[{1, 1/(yu*yv)}, yw])/64 + 
     (27*G[{1}, yw]*G[{yu}, yv^(-1)]^2*G[{1, 1/(yu*yv)}, yw])/64 - 
     (41*G[{yu}, yv^(-1)]^3*G[{1, 1/(yu*yv)}, yw])/192 + 
     (5*Pi^2*G[{1/(yu*yv)}, yw]*G[{1, 1/(yu*yv)}, yw])/768 - 
     (3*G[{0}, yu^(-1)]^2*G[{1/(yu*yv)}, yw]*G[{1, 1/(yu*yv)}, yw])/128 - 
     (3*G[{0}, yu^(-1)]*G[{0}, yv^(-1)]*G[{1/(yu*yv)}, yw]*
       G[{1, 1/(yu*yv)}, yw])/64 - (3*G[{0}, yv^(-1)]^2*G[{1/(yu*yv)}, yw]*
       G[{1, 1/(yu*yv)}, yw])/128 + (3*G[{0}, yu^(-1)]*G[{0}, yw]*
       G[{1/(yu*yv)}, yw]*G[{1, 1/(yu*yv)}, yw])/64 + 
     (3*G[{0}, yv^(-1)]*G[{0}, yw]*G[{1/(yu*yv)}, yw]*G[{1, 1/(yu*yv)}, yw])/
      64 - (3*G[{0}, yw]^2*G[{1/(yu*yv)}, yw]*G[{1, 1/(yu*yv)}, yw])/128 + 
     (G[{0}, yu^(-1)]*G[{1}, yu^(-1)]*G[{1/(yu*yv)}, yw]*
       G[{1, 1/(yu*yv)}, yw])/64 + (G[{0}, yv^(-1)]*G[{1}, yu^(-1)]*
       G[{1/(yu*yv)}, yw]*G[{1, 1/(yu*yv)}, yw])/64 - 
     (G[{0}, yw]*G[{1}, yu^(-1)]*G[{1/(yu*yv)}, yw]*G[{1, 1/(yu*yv)}, yw])/
      64 + (7*G[{1}, yu^(-1)]^2*G[{1/(yu*yv)}, yw]*G[{1, 1/(yu*yv)}, yw])/
      128 - (5*G[{0}, yu^(-1)]*G[{1}, yv^(-1)]*G[{1/(yu*yv)}, yw]*
       G[{1, 1/(yu*yv)}, yw])/64 - (5*G[{0}, yv^(-1)]*G[{1}, yv^(-1)]*
       G[{1/(yu*yv)}, yw]*G[{1, 1/(yu*yv)}, yw])/64 + 
     (5*G[{0}, yw]*G[{1}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{1, 1/(yu*yv)}, yw])/
      64 - (G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*G[{1/(yu*yv)}, yw]*
       G[{1, 1/(yu*yv)}, yw])/16 + (13*G[{1}, yv^(-1)]^2*G[{1/(yu*yv)}, yw]*
       G[{1, 1/(yu*yv)}, yw])/128 - (13*G[{0}, yu^(-1)]*G[{1}, yw]*
       G[{1/(yu*yv)}, yw]*G[{1, 1/(yu*yv)}, yw])/64 - 
     (13*G[{0}, yv^(-1)]*G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{1, 1/(yu*yv)}, yw])/
      64 + (13*G[{0}, yw]*G[{1}, yw]*G[{1/(yu*yv)}, yw]*
       G[{1, 1/(yu*yv)}, yw])/64 + (7*G[{1}, yu^(-1)]*G[{1}, yw]*
       G[{1/(yu*yv)}, yw]*G[{1, 1/(yu*yv)}, yw])/64 + 
     (G[{1}, yv^(-1)]*G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{1, 1/(yu*yv)}, yw])/
      64 - (9*G[{1}, yw]^2*G[{1/(yu*yv)}, yw]*G[{1, 1/(yu*yv)}, yw])/64 + 
     (G[{0}, yu^(-1)]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*
       G[{1, 1/(yu*yv)}, yw])/16 + (G[{0}, yv^(-1)]*G[{yu^(-1)}, yw]*
       G[{1/(yu*yv)}, yw]*G[{1, 1/(yu*yv)}, yw])/16 - 
     (G[{0}, yw]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{1, 1/(yu*yv)}, yw])/
      16 - (7*G[{1}, yu^(-1)]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*
       G[{1, 1/(yu*yv)}, yw])/32 - (G[{1}, yv^(-1)]*G[{yu^(-1)}, yw]*
       G[{1/(yu*yv)}, yw]*G[{1, 1/(yu*yv)}, yw])/16 - 
     (5*G[{1}, yw]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{1, 1/(yu*yv)}, yw])/
      32 - (G[{yu^(-1)}, yw]^2*G[{1/(yu*yv)}, yw]*G[{1, 1/(yu*yv)}, yw])/32 + 
     (5*G[{0}, yu^(-1)]*G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw]*
       G[{1, 1/(yu*yv)}, yw])/32 + (5*G[{0}, yv^(-1)]*G[{yu}, yv^(-1)]*
       G[{1/(yu*yv)}, yw]*G[{1, 1/(yu*yv)}, yw])/32 - 
     (5*G[{0}, yw]*G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{1, 1/(yu*yv)}, yw])/
      32 - (5*G[{1}, yu^(-1)]*G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw]*
       G[{1, 1/(yu*yv)}, yw])/64 - (G[{1}, yv^(-1)]*G[{yu}, yv^(-1)]*
       G[{1/(yu*yv)}, yw]*G[{1, 1/(yu*yv)}, yw])/32 + 
     (9*G[{1}, yw]*G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{1, 1/(yu*yv)}, yw])/
      32 + (5*G[{yu^(-1)}, yw]*G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw]*
       G[{1, 1/(yu*yv)}, yw])/32 - (13*G[{yu}, yv^(-1)]^2*G[{1/(yu*yv)}, yw]*
       G[{1, 1/(yu*yv)}, yw])/128 - (G[{0}, yu^(-1)]*G[{yv^(-1)}, yw]*
       G[{1/(yu*yv)}, yw]*G[{1, 1/(yu*yv)}, yw])/16 - 
     (G[{0}, yv^(-1)]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*
       G[{1, 1/(yu*yv)}, yw])/16 + (G[{0}, yw]*G[{yv^(-1)}, yw]*
       G[{1/(yu*yv)}, yw]*G[{1, 1/(yu*yv)}, yw])/16 + 
     (3*G[{1}, yu^(-1)]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*
       G[{1, 1/(yu*yv)}, yw])/32 + (G[{1}, yv^(-1)]*G[{yv^(-1)}, yw]*
       G[{1/(yu*yv)}, yw]*G[{1, 1/(yu*yv)}, yw])/16 + 
     (G[{1}, yw]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{1, 1/(yu*yv)}, yw])/
      32 + (3*G[{yu^(-1)}, yw]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*
       G[{1, 1/(yu*yv)}, yw])/16 - (G[{yu}, yv^(-1)]*G[{yv^(-1)}, yw]*
       G[{1/(yu*yv)}, yw]*G[{1, 1/(yu*yv)}, yw])/32 - 
     (3*G[{yv^(-1)}, yw]^2*G[{1/(yu*yv)}, yw]*G[{1, 1/(yu*yv)}, yw])/32 - 
     (3*G[{0}, yu^(-1)]*G[{1/(yu*yv)}, yw]^2*G[{1, 1/(yu*yv)}, yw])/64 - 
     (3*G[{0}, yv^(-1)]*G[{1/(yu*yv)}, yw]^2*G[{1, 1/(yu*yv)}, yw])/64 + 
     (3*G[{0}, yw]*G[{1/(yu*yv)}, yw]^2*G[{1, 1/(yu*yv)}, yw])/64 + 
     (3*G[{1}, yu^(-1)]*G[{1/(yu*yv)}, yw]^2*G[{1, 1/(yu*yv)}, yw])/128 + 
     (G[{1}, yv^(-1)]*G[{1/(yu*yv)}, yw]^2*G[{1, 1/(yu*yv)}, yw])/64 - 
     (7*G[{1}, yw]*G[{1/(yu*yv)}, yw]^2*G[{1, 1/(yu*yv)}, yw])/128 - 
     (G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2*G[{1, 1/(yu*yv)}, yw])/64 + 
     (7*G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw]^2*G[{1, 1/(yu*yv)}, yw])/128 - 
     (9*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2*G[{1, 1/(yu*yv)}, yw])/128 + 
     (G[{0}, yu^(-1)]*G[{0, 1}, yu^(-1)]*G[{1, 1/(yu*yv)}, yw])/16 + 
     (G[{0}, yv^(-1)]*G[{0, 1}, yu^(-1)]*G[{1, 1/(yu*yv)}, yw])/16 - 
     (G[{0}, yw]*G[{0, 1}, yu^(-1)]*G[{1, 1/(yu*yv)}, yw])/16 + 
     (G[{1}, yu^(-1)]*G[{0, 1}, yu^(-1)]*G[{1, 1/(yu*yv)}, yw])/32 - 
     (G[{1}, yv^(-1)]*G[{0, 1}, yu^(-1)]*G[{1, 1/(yu*yv)}, yw])/32 + 
     (5*G[{1}, yw]*G[{0, 1}, yu^(-1)]*G[{1, 1/(yu*yv)}, yw])/32 - 
     (G[{yu}, yv^(-1)]*G[{0, 1}, yu^(-1)]*G[{1, 1/(yu*yv)}, yw])/8 + 
     (G[{1/(yu*yv)}, yw]*G[{0, 1}, yu^(-1)]*G[{1, 1/(yu*yv)}, yw])/64 + 
     (G[{0}, yu^(-1)]*G[{0, 1}, yv^(-1)]*G[{1, 1/(yu*yv)}, yw])/16 + 
     (G[{0}, yv^(-1)]*G[{0, 1}, yv^(-1)]*G[{1, 1/(yu*yv)}, yw])/16 - 
     (G[{0}, yw]*G[{0, 1}, yv^(-1)]*G[{1, 1/(yu*yv)}, yw])/16 + 
     (G[{1}, yu^(-1)]*G[{0, 1}, yv^(-1)]*G[{1, 1/(yu*yv)}, yw])/8 + 
     (G[{1}, yv^(-1)]*G[{0, 1}, yv^(-1)]*G[{1, 1/(yu*yv)}, yw])/16 + 
     (5*G[{1}, yw]*G[{0, 1}, yv^(-1)]*G[{1, 1/(yu*yv)}, yw])/16 - 
     (G[{yu}, yv^(-1)]*G[{0, 1}, yv^(-1)]*G[{1, 1/(yu*yv)}, yw])/4 + 
     (G[{1/(yu*yv)}, yw]*G[{0, 1}, yv^(-1)]*G[{1, 1/(yu*yv)}, yw])/16 + 
     (G[{0}, yu^(-1)]*G[{0, 1}, yw]*G[{1, 1/(yu*yv)}, yw])/16 + 
     (G[{0}, yv^(-1)]*G[{0, 1}, yw]*G[{1, 1/(yu*yv)}, yw])/16 - 
     (G[{0}, yw]*G[{0, 1}, yw]*G[{1, 1/(yu*yv)}, yw])/16 - 
     (3*G[{1}, yu^(-1)]*G[{0, 1}, yw]*G[{1, 1/(yu*yv)}, yw])/32 - 
     (G[{1}, yv^(-1)]*G[{0, 1}, yw]*G[{1, 1/(yu*yv)}, yw])/16 - 
     (3*G[{1}, yw]*G[{0, 1}, yw]*G[{1, 1/(yu*yv)}, yw])/32 + 
     (G[{yu}, yv^(-1)]*G[{0, 1}, yw]*G[{1, 1/(yu*yv)}, yw])/32 - 
     (3*G[{1/(yu*yv)}, yw]*G[{0, 1}, yw]*G[{1, 1/(yu*yv)}, yw])/64 - 
     (G[{0}, yu^(-1)]*G[{0, yu^(-1)}, yw]*G[{1, 1/(yu*yv)}, yw])/16 - 
     (G[{0}, yv^(-1)]*G[{0, yu^(-1)}, yw]*G[{1, 1/(yu*yv)}, yw])/16 + 
     (G[{0}, yw]*G[{0, yu^(-1)}, yw]*G[{1, 1/(yu*yv)}, yw])/16 + 
     (3*G[{1}, yu^(-1)]*G[{0, yu^(-1)}, yw]*G[{1, 1/(yu*yv)}, yw])/32 + 
     (G[{1}, yv^(-1)]*G[{0, yu^(-1)}, yw]*G[{1, 1/(yu*yv)}, yw])/16 + 
     (3*G[{1}, yw]*G[{0, yu^(-1)}, yw]*G[{1, 1/(yu*yv)}, yw])/32 - 
     (G[{yu}, yv^(-1)]*G[{0, yu^(-1)}, yw]*G[{1, 1/(yu*yv)}, yw])/32 + 
     (3*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1)}, yw]*G[{1, 1/(yu*yv)}, yw])/64 - 
     (G[{0}, yu^(-1)]*G[{0, yu}, yv^(-1)]*G[{1, 1/(yu*yv)}, yw])/16 - 
     (G[{0}, yv^(-1)]*G[{0, yu}, yv^(-1)]*G[{1, 1/(yu*yv)}, yw])/16 + 
     (G[{0}, yw]*G[{0, yu}, yv^(-1)]*G[{1, 1/(yu*yv)}, yw])/16 - 
     (G[{1}, yu^(-1)]*G[{0, yu}, yv^(-1)]*G[{1, 1/(yu*yv)}, yw])/8 - 
     (G[{1}, yv^(-1)]*G[{0, yu}, yv^(-1)]*G[{1, 1/(yu*yv)}, yw])/16 - 
     (5*G[{1}, yw]*G[{0, yu}, yv^(-1)]*G[{1, 1/(yu*yv)}, yw])/16 + 
     (G[{yu}, yv^(-1)]*G[{0, yu}, yv^(-1)]*G[{1, 1/(yu*yv)}, yw])/4 - 
     (G[{1/(yu*yv)}, yw]*G[{0, yu}, yv^(-1)]*G[{1, 1/(yu*yv)}, yw])/16 - 
     (G[{0}, yu^(-1)]*G[{0, yv^(-1)}, yw]*G[{1, 1/(yu*yv)}, yw])/16 - 
     (G[{0}, yv^(-1)]*G[{0, yv^(-1)}, yw]*G[{1, 1/(yu*yv)}, yw])/16 + 
     (G[{0}, yw]*G[{0, yv^(-1)}, yw]*G[{1, 1/(yu*yv)}, yw])/16 + 
     (3*G[{1}, yu^(-1)]*G[{0, yv^(-1)}, yw]*G[{1, 1/(yu*yv)}, yw])/32 + 
     (G[{1}, yv^(-1)]*G[{0, yv^(-1)}, yw]*G[{1, 1/(yu*yv)}, yw])/16 + 
     (3*G[{1}, yw]*G[{0, yv^(-1)}, yw]*G[{1, 1/(yu*yv)}, yw])/32 - 
     (G[{yu}, yv^(-1)]*G[{0, yv^(-1)}, yw]*G[{1, 1/(yu*yv)}, yw])/32 + 
     (3*G[{1/(yu*yv)}, yw]*G[{0, yv^(-1)}, yw]*G[{1, 1/(yu*yv)}, yw])/64 + 
     (G[{0}, yu^(-1)]*G[{0, 1/(yu*yv)}, yw]*G[{1, 1/(yu*yv)}, yw])/16 + 
     (G[{0}, yv^(-1)]*G[{0, 1/(yu*yv)}, yw]*G[{1, 1/(yu*yv)}, yw])/16 - 
     (G[{0}, yw]*G[{0, 1/(yu*yv)}, yw]*G[{1, 1/(yu*yv)}, yw])/16 - 
     (3*G[{1}, yu^(-1)]*G[{0, 1/(yu*yv)}, yw]*G[{1, 1/(yu*yv)}, yw])/32 - 
     (G[{1}, yv^(-1)]*G[{0, 1/(yu*yv)}, yw]*G[{1, 1/(yu*yv)}, yw])/16 - 
     (3*G[{1}, yw]*G[{0, 1/(yu*yv)}, yw]*G[{1, 1/(yu*yv)}, yw])/32 + 
     (G[{yu}, yv^(-1)]*G[{0, 1/(yu*yv)}, yw]*G[{1, 1/(yu*yv)}, yw])/32 - 
     (3*G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv)}, yw]*G[{1, 1/(yu*yv)}, yw])/64 + 
     (G[{0}, yu^(-1)]*G[{1, yu^(-1)}, yw]*G[{1, 1/(yu*yv)}, yw])/8 + 
     (G[{0}, yv^(-1)]*G[{1, yu^(-1)}, yw]*G[{1, 1/(yu*yv)}, yw])/8 - 
     (G[{0}, yw]*G[{1, yu^(-1)}, yw]*G[{1, 1/(yu*yv)}, yw])/8 + 
     (G[{1}, yu^(-1)]*G[{1, yu^(-1)}, yw]*G[{1, 1/(yu*yv)}, yw])/32 - 
     (5*G[{1}, yv^(-1)]*G[{1, yu^(-1)}, yw]*G[{1, 1/(yu*yv)}, yw])/16 - 
     (G[{1}, yw]*G[{1, yu^(-1)}, yw]*G[{1, 1/(yu*yv)}, yw])/32 + 
     (G[{yu}, yv^(-1)]*G[{1, yu^(-1)}, yw]*G[{1, 1/(yu*yv)}, yw])/32 + 
     (G[{1/(yu*yv)}, yw]*G[{1, yu^(-1)}, yw]*G[{1, 1/(yu*yv)}, yw])/64 + 
     (3*G[{1}, yu^(-1)]*G[{1, yu}, yv^(-1)]*G[{1, 1/(yu*yv)}, yw])/16 - 
     (G[{1}, yv^(-1)]*G[{1, yu}, yv^(-1)]*G[{1, 1/(yu*yv)}, yw])/4 + 
     (5*G[{1}, yw]*G[{1, yu}, yv^(-1)]*G[{1, 1/(yu*yv)}, yw])/32 - 
     (G[{yu}, yv^(-1)]*G[{1, yu}, yv^(-1)]*G[{1, 1/(yu*yv)}, yw])/8 + 
     (3*G[{1/(yu*yv)}, yw]*G[{1, yu}, yv^(-1)]*G[{1, 1/(yu*yv)}, yw])/64 + 
     (G[{0}, yu^(-1)]*G[{1, yv^(-1)}, yw]*G[{1, 1/(yu*yv)}, yw])/8 + 
     (G[{0}, yv^(-1)]*G[{1, yv^(-1)}, yw]*G[{1, 1/(yu*yv)}, yw])/8 - 
     (G[{0}, yw]*G[{1, yv^(-1)}, yw]*G[{1, 1/(yu*yv)}, yw])/8 - 
     (5*G[{1}, yu^(-1)]*G[{1, yv^(-1)}, yw]*G[{1, 1/(yu*yv)}, yw])/32 - 
     (G[{1}, yv^(-1)]*G[{1, yv^(-1)}, yw]*G[{1, 1/(yu*yv)}, yw])/16 + 
     (G[{1}, yw]*G[{1, yv^(-1)}, yw]*G[{1, 1/(yu*yv)}, yw])/32 - 
     (G[{yu}, yv^(-1)]*G[{1, yv^(-1)}, yw]*G[{1, 1/(yu*yv)}, yw])/32 - 
     (G[{1/(yu*yv)}, yw]*G[{1, yv^(-1)}, yw]*G[{1, 1/(yu*yv)}, yw])/32 - 
     (G[{0}, yu^(-1)]*G[{1, 1/(yu*yv)}, yw]^2)/16 - 
     (G[{0}, yv^(-1)]*G[{1, 1/(yu*yv)}, yw]^2)/16 + 
     (G[{0}, yw]*G[{1, 1/(yu*yv)}, yw]^2)/16 - 
     (G[{1}, yu^(-1)]*G[{1, 1/(yu*yv)}, yw]^2)/32 + 
     (G[{1}, yv^(-1)]*G[{1, 1/(yu*yv)}, yw]^2)/8 - 
     (G[{1}, yw]*G[{1, 1/(yu*yv)}, yw]^2)/32 + 
     (G[{yu}, yv^(-1)]*G[{1, 1/(yu*yv)}, yw]^2)/32 - 
     (5*G[{1/(yu*yv)}, yw]*G[{1, 1/(yu*yv)}, yw]^2)/128 + 
     (Pi^2*G[{0}, yu^(-1)]*G[{yu^(-1), 1/(yu*yv)}, yw])/96 + 
     (Pi^2*G[{0}, yv^(-1)]*G[{yu^(-1), 1/(yu*yv)}, yw])/96 - 
     (Pi^2*G[{0}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw])/96 - 
     (Pi^2*G[{1}, yu^(-1)]*G[{yu^(-1), 1/(yu*yv)}, yw])/24 - 
     (G[{0}, yu^(-1)]*G[{1}, yu^(-1)]^2*G[{yu^(-1), 1/(yu*yv)}, yw])/16 - 
     (G[{0}, yv^(-1)]*G[{1}, yu^(-1)]^2*G[{yu^(-1), 1/(yu*yv)}, yw])/16 + 
     (G[{0}, yw]*G[{1}, yu^(-1)]^2*G[{yu^(-1), 1/(yu*yv)}, yw])/16 + 
     (5*G[{1}, yu^(-1)]^3*G[{yu^(-1), 1/(yu*yv)}, yw])/128 + 
     (Pi^2*G[{1}, yv^(-1)]*G[{yu^(-1), 1/(yu*yv)}, yw])/48 + 
     (G[{0}, yu^(-1)]*G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*G[{yu^(-1), 1/(yu*yv)}, 
        yw])/8 + (G[{0}, yv^(-1)]*G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*
       G[{yu^(-1), 1/(yu*yv)}, yw])/8 - (G[{0}, yw]*G[{1}, yu^(-1)]*
       G[{1}, yv^(-1)]*G[{yu^(-1), 1/(yu*yv)}, yw])/8 + 
     (G[{1}, yu^(-1)]^2*G[{1}, yv^(-1)]*G[{yu^(-1), 1/(yu*yv)}, yw])/128 - 
     (G[{0}, yu^(-1)]*G[{1}, yv^(-1)]^2*G[{yu^(-1), 1/(yu*yv)}, yw])/32 - 
     (G[{0}, yv^(-1)]*G[{1}, yv^(-1)]^2*G[{yu^(-1), 1/(yu*yv)}, yw])/32 + 
     (G[{0}, yw]*G[{1}, yv^(-1)]^2*G[{yu^(-1), 1/(yu*yv)}, yw])/32 - 
     (15*G[{1}, yu^(-1)]*G[{1}, yv^(-1)]^2*G[{yu^(-1), 1/(yu*yv)}, yw])/128 + 
     (G[{1}, yv^(-1)]^3*G[{yu^(-1), 1/(yu*yv)}, yw])/32 + 
     (Pi^2*G[{1}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw])/96 - 
     (G[{0}, yu^(-1)]*G[{1}, yu^(-1)]*G[{1}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw])/
      8 - (G[{0}, yv^(-1)]*G[{1}, yu^(-1)]*G[{1}, yw]*G[{yu^(-1), 1/(yu*yv)}, 
        yw])/8 + (G[{0}, yw]*G[{1}, yu^(-1)]*G[{1}, yw]*
       G[{yu^(-1), 1/(yu*yv)}, yw])/8 + (19*G[{1}, yu^(-1)]^2*G[{1}, yw]*
       G[{yu^(-1), 1/(yu*yv)}, yw])/128 + 
     (G[{0}, yu^(-1)]*G[{1}, yv^(-1)]*G[{1}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw])/
      16 + (G[{0}, yv^(-1)]*G[{1}, yv^(-1)]*G[{1}, yw]*
       G[{yu^(-1), 1/(yu*yv)}, yw])/16 - 
     (G[{0}, yw]*G[{1}, yv^(-1)]*G[{1}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw])/16 + 
     (11*G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*G[{1}, yw]*G[{yu^(-1), 1/(yu*yv)}, 
        yw])/64 - (3*G[{1}, yv^(-1)]^2*G[{1}, yw]*G[{yu^(-1), 1/(yu*yv)}, 
        yw])/32 + (11*G[{1}, yu^(-1)]*G[{1}, yw]^2*G[{yu^(-1), 1/(yu*yv)}, 
        yw])/128 + (G[{1}, yv^(-1)]*G[{1}, yw]^2*G[{yu^(-1), 1/(yu*yv)}, yw])/
      32 + (5*G[{1}, yw]^3*G[{yu^(-1), 1/(yu*yv)}, yw])/128 - 
     (Pi^2*G[{yu^(-1)}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw])/32 - 
     (5*G[{1}, yu^(-1)]^2*G[{yu^(-1)}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw])/32 + 
     (5*G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*G[{yu^(-1)}, yw]*
       G[{yu^(-1), 1/(yu*yv)}, yw])/16 - (G[{1}, yv^(-1)]^2*G[{yu^(-1)}, yw]*
       G[{yu^(-1), 1/(yu*yv)}, yw])/16 - 
     (G[{0}, yu^(-1)]*G[{1}, yw]*G[{yu^(-1)}, yw]*G[{yu^(-1), 1/(yu*yv)}, 
        yw])/8 - (G[{0}, yv^(-1)]*G[{1}, yw]*G[{yu^(-1)}, yw]*
       G[{yu^(-1), 1/(yu*yv)}, yw])/8 + 
     (G[{0}, yw]*G[{1}, yw]*G[{yu^(-1)}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw])/8 + 
     (G[{1}, yu^(-1)]*G[{1}, yw]*G[{yu^(-1)}, yw]*G[{yu^(-1), 1/(yu*yv)}, 
        yw])/16 + (G[{1}, yv^(-1)]*G[{1}, yw]*G[{yu^(-1)}, yw]*
       G[{yu^(-1), 1/(yu*yv)}, yw])/4 + (G[{1}, yw]^2*G[{yu^(-1)}, yw]*
       G[{yu^(-1), 1/(yu*yv)}, yw])/32 + (G[{0}, yu^(-1)]*G[{yu^(-1)}, yw]^2*
       G[{yu^(-1), 1/(yu*yv)}, yw])/16 + (G[{0}, yv^(-1)]*G[{yu^(-1)}, yw]^2*
       G[{yu^(-1), 1/(yu*yv)}, yw])/16 - (G[{0}, yw]*G[{yu^(-1)}, yw]^2*
       G[{yu^(-1), 1/(yu*yv)}, yw])/16 - 
     (3*G[{1}, yu^(-1)]*G[{yu^(-1)}, yw]^2*G[{yu^(-1), 1/(yu*yv)}, yw])/16 + 
     (G[{1}, yv^(-1)]*G[{yu^(-1)}, yw]^2*G[{yu^(-1), 1/(yu*yv)}, yw])/16 - 
     (G[{yu^(-1)}, yw]^3*G[{yu^(-1), 1/(yu*yv)}, yw])/48 + 
     (G[{0}, yu^(-1)]*G[{1}, yw]*G[{yu}, yv^(-1)]*G[{yu^(-1), 1/(yu*yv)}, 
        yw])/16 + (G[{0}, yv^(-1)]*G[{1}, yw]*G[{yu}, yv^(-1)]*
       G[{yu^(-1), 1/(yu*yv)}, yw])/16 - 
     (G[{0}, yw]*G[{1}, yw]*G[{yu}, yv^(-1)]*G[{yu^(-1), 1/(yu*yv)}, yw])/
      16 - (7*G[{1}, yu^(-1)]*G[{1}, yw]*G[{yu}, yv^(-1)]*
       G[{yu^(-1), 1/(yu*yv)}, yw])/32 - 
     (G[{1}, yv^(-1)]*G[{1}, yw]*G[{yu}, yv^(-1)]*G[{yu^(-1), 1/(yu*yv)}, 
        yw])/16 - (15*G[{1}, yw]^2*G[{yu}, yv^(-1)]*G[{yu^(-1), 1/(yu*yv)}, 
        yw])/128 - (G[{1}, yw]*G[{yu^(-1)}, yw]*G[{yu}, yv^(-1)]*
       G[{yu^(-1), 1/(yu*yv)}, yw])/16 + (5*G[{1}, yw]*G[{yu}, yv^(-1)]^2*
       G[{yu^(-1), 1/(yu*yv)}, yw])/64 + (G[{0}, yu^(-1)]*G[{1}, yu^(-1)]*
       G[{1/(yu*yv)}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw])/16 + 
     (G[{0}, yv^(-1)]*G[{1}, yu^(-1)]*G[{1/(yu*yv)}, yw]*
       G[{yu^(-1), 1/(yu*yv)}, yw])/16 - 
     (G[{0}, yw]*G[{1}, yu^(-1)]*G[{1/(yu*yv)}, yw]*G[{yu^(-1), 1/(yu*yv)}, 
        yw])/16 - (3*G[{1}, yu^(-1)]^2*G[{1/(yu*yv)}, yw]*
       G[{yu^(-1), 1/(yu*yv)}, yw])/128 - 
     (3*G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*G[{1/(yu*yv)}, yw]*
       G[{yu^(-1), 1/(yu*yv)}, yw])/64 + 
     (G[{0}, yu^(-1)]*G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{yu^(-1), 1/(yu*yv)}, 
        yw])/8 + (G[{0}, yv^(-1)]*G[{1}, yw]*G[{1/(yu*yv)}, yw]*
       G[{yu^(-1), 1/(yu*yv)}, yw])/8 - 
     (G[{0}, yw]*G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw])/
      8 + (G[{1}, yu^(-1)]*G[{1}, yw]*G[{1/(yu*yv)}, yw]*
       G[{yu^(-1), 1/(yu*yv)}, yw])/64 - 
     (G[{1}, yv^(-1)]*G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{yu^(-1), 1/(yu*yv)}, 
        yw])/16 + (13*G[{1}, yw]^2*G[{1/(yu*yv)}, yw]*G[{yu^(-1), 1/(yu*yv)}, 
        yw])/128 - (G[{0}, yu^(-1)]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*
       G[{yu^(-1), 1/(yu*yv)}, yw])/16 - (G[{0}, yv^(-1)]*G[{yu^(-1)}, yw]*
       G[{1/(yu*yv)}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw])/16 + 
     (G[{0}, yw]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{yu^(-1), 1/(yu*yv)}, 
        yw])/16 + (G[{1}, yu^(-1)]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*
       G[{yu^(-1), 1/(yu*yv)}, yw])/16 + (G[{1}, yv^(-1)]*G[{yu^(-1)}, yw]*
       G[{1/(yu*yv)}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw])/8 + 
     (G[{1}, yw]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{yu^(-1), 1/(yu*yv)}, 
        yw])/16 - (G[{yu^(-1)}, yw]^2*G[{1/(yu*yv)}, yw]*
       G[{yu^(-1), 1/(yu*yv)}, yw])/16 - (G[{0}, yu^(-1)]*G[{yu}, yv^(-1)]*
       G[{1/(yu*yv)}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw])/16 - 
     (G[{0}, yv^(-1)]*G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw]*
       G[{yu^(-1), 1/(yu*yv)}, yw])/16 + 
     (G[{0}, yw]*G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{yu^(-1), 1/(yu*yv)}, 
        yw])/16 - (G[{1}, yu^(-1)]*G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw]*
       G[{yu^(-1), 1/(yu*yv)}, yw])/32 + (G[{1}, yv^(-1)]*G[{yu}, yv^(-1)]*
       G[{1/(yu*yv)}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw])/16 - 
     (13*G[{1}, yw]*G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw]*
       G[{yu^(-1), 1/(yu*yv)}, yw])/64 - (G[{yu^(-1)}, yw]*G[{yu}, yv^(-1)]*
       G[{1/(yu*yv)}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw])/16 + 
     (3*G[{yu}, yv^(-1)]^2*G[{1/(yu*yv)}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw])/
      64 - (3*G[{1}, yu^(-1)]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*
       G[{yu^(-1), 1/(yu*yv)}, yw])/32 - (3*G[{1}, yw]*G[{yv^(-1)}, yw]*
       G[{1/(yu*yv)}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw])/32 + 
     (3*G[{yu}, yv^(-1)]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*
       G[{yu^(-1), 1/(yu*yv)}, yw])/32 + 
     (7*G[{yv^(-1)}, yw]^2*G[{1/(yu*yv)}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw])/
      64 + (G[{1}, yu^(-1)]*G[{1/(yu*yv)}, yw]^2*G[{yu^(-1), 1/(yu*yv)}, yw])/
      128 - (G[{1}, yv^(-1)]*G[{1/(yu*yv)}, yw]^2*G[{yu^(-1), 1/(yu*yv)}, 
        yw])/16 - (7*G[{1}, yw]*G[{1/(yu*yv)}, yw]^2*G[{yu^(-1), 1/(yu*yv)}, 
        yw])/128 + (G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2*
       G[{yu^(-1), 1/(yu*yv)}, yw])/16 + 
     (7*G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw]^2*G[{yu^(-1), 1/(yu*yv)}, yw])/
      128 - (G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2*G[{yu^(-1), 1/(yu*yv)}, 
        yw])/128 + (G[{0}, yu^(-1)]*G[{0, 1}, yu^(-1)]*
       G[{yu^(-1), 1/(yu*yv)}, yw])/16 + (G[{0}, yv^(-1)]*G[{0, 1}, yu^(-1)]*
       G[{yu^(-1), 1/(yu*yv)}, yw])/16 - (G[{0}, yw]*G[{0, 1}, yu^(-1)]*
       G[{yu^(-1), 1/(yu*yv)}, yw])/16 - 
     (5*G[{1}, yu^(-1)]*G[{0, 1}, yu^(-1)]*G[{yu^(-1), 1/(yu*yv)}, yw])/64 - 
     (3*G[{1}, yv^(-1)]*G[{0, 1}, yu^(-1)]*G[{yu^(-1), 1/(yu*yv)}, yw])/64 - 
     (G[{1}, yw]*G[{0, 1}, yu^(-1)]*G[{yu^(-1), 1/(yu*yv)}, yw])/64 + 
     (G[{yu^(-1)}, yw]*G[{0, 1}, yu^(-1)]*G[{yu^(-1), 1/(yu*yv)}, yw])/16 - 
     (3*G[{1/(yu*yv)}, yw]*G[{0, 1}, yu^(-1)]*G[{yu^(-1), 1/(yu*yv)}, yw])/
      64 - (G[{1}, yu^(-1)]*G[{0, 1}, yv^(-1)]*G[{yu^(-1), 1/(yu*yv)}, yw])/
      8 + (G[{1}, yv^(-1)]*G[{0, 1}, yv^(-1)]*G[{yu^(-1), 1/(yu*yv)}, yw])/
      16 - (G[{1}, yw]*G[{0, 1}, yv^(-1)]*G[{yu^(-1), 1/(yu*yv)}, yw])/16 - 
     (G[{yu^(-1)}, yw]*G[{0, 1}, yv^(-1)]*G[{yu^(-1), 1/(yu*yv)}, yw])/8 - 
     (G[{1/(yu*yv)}, yw]*G[{0, 1}, yv^(-1)]*G[{yu^(-1), 1/(yu*yv)}, yw])/16 - 
     (G[{1}, yu^(-1)]*G[{0, 1}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw])/16 + 
     (G[{1}, yv^(-1)]*G[{0, 1}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw])/16 + 
     (G[{1}, yw]*G[{0, 1}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw])/16 - 
     (G[{yu^(-1)}, yw]*G[{0, 1}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw])/8 + 
     (G[{1/(yu*yv)}, yw]*G[{0, 1}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw])/16 + 
     (G[{1}, yu^(-1)]*G[{0, yu^(-1)}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw])/16 - 
     (G[{1}, yv^(-1)]*G[{0, yu^(-1)}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw])/16 - 
     (G[{1}, yw]*G[{0, yu^(-1)}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw])/16 + 
     (G[{yu^(-1)}, yw]*G[{0, yu^(-1)}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw])/8 - 
     (G[{1/(yu*yv)}, yw]*G[{0, yu^(-1)}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw])/
      16 + (G[{1}, yu^(-1)]*G[{0, yu}, yv^(-1)]*G[{yu^(-1), 1/(yu*yv)}, yw])/
      8 - (G[{1}, yv^(-1)]*G[{0, yu}, yv^(-1)]*G[{yu^(-1), 1/(yu*yv)}, yw])/
      16 + (G[{1}, yw]*G[{0, yu}, yv^(-1)]*G[{yu^(-1), 1/(yu*yv)}, yw])/16 + 
     (G[{yu^(-1)}, yw]*G[{0, yu}, yv^(-1)]*G[{yu^(-1), 1/(yu*yv)}, yw])/8 + 
     (G[{1/(yu*yv)}, yw]*G[{0, yu}, yv^(-1)]*G[{yu^(-1), 1/(yu*yv)}, yw])/
      16 + (G[{1}, yu^(-1)]*G[{0, yv^(-1)}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw])/
      16 - (G[{1}, yv^(-1)]*G[{0, yv^(-1)}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw])/
      16 - (G[{1}, yw]*G[{0, yv^(-1)}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw])/16 + 
     (G[{yu^(-1)}, yw]*G[{0, yv^(-1)}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw])/8 - 
     (G[{1/(yu*yv)}, yw]*G[{0, yv^(-1)}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw])/
      16 - (G[{1}, yu^(-1)]*G[{0, 1/(yu*yv)}, yw]*G[{yu^(-1), 1/(yu*yv)}, 
        yw])/16 + (G[{1}, yv^(-1)]*G[{0, 1/(yu*yv)}, yw]*
       G[{yu^(-1), 1/(yu*yv)}, yw])/16 + (G[{1}, yw]*G[{0, 1/(yu*yv)}, yw]*
       G[{yu^(-1), 1/(yu*yv)}, yw])/16 - 
     (G[{yu^(-1)}, yw]*G[{0, 1/(yu*yv)}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw])/8 + 
     (G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv)}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw])/
      16 - (3*G[{1}, yu^(-1)]*G[{1, yu^(-1)}, yw]*G[{yu^(-1), 1/(yu*yv)}, 
        yw])/16 + (G[{1}, yv^(-1)]*G[{1, yu^(-1)}, yw]*
       G[{yu^(-1), 1/(yu*yv)}, yw])/16 - (G[{1}, yw]*G[{1, yu^(-1)}, yw]*
       G[{yu^(-1), 1/(yu*yv)}, yw])/8 - (G[{yu^(-1)}, yw]*G[{1, yu^(-1)}, yw]*
       G[{yu^(-1), 1/(yu*yv)}, yw])/4 + (G[{yu}, yv^(-1)]*G[{1, yu^(-1)}, yw]*
       G[{yu^(-1), 1/(yu*yv)}, yw])/8 - (G[{0}, yu^(-1)]*G[{1, yu}, yv^(-1)]*
       G[{yu^(-1), 1/(yu*yv)}, yw])/16 - (G[{0}, yv^(-1)]*G[{1, yu}, yv^(-1)]*
       G[{yu^(-1), 1/(yu*yv)}, yw])/16 + (G[{0}, yw]*G[{1, yu}, yv^(-1)]*
       G[{yu^(-1), 1/(yu*yv)}, yw])/16 - (G[{1}, yu^(-1)]*G[{1, yu}, yv^(-1)]*
       G[{yu^(-1), 1/(yu*yv)}, yw])/32 + (G[{1}, yv^(-1)]*G[{1, yu}, yv^(-1)]*
       G[{yu^(-1), 1/(yu*yv)}, yw])/16 - (3*G[{1}, yw]*G[{1, yu}, yv^(-1)]*
       G[{yu^(-1), 1/(yu*yv)}, yw])/64 - 
     (3*G[{yu^(-1)}, yw]*G[{1, yu}, yv^(-1)]*G[{yu^(-1), 1/(yu*yv)}, yw])/
      16 - (G[{1/(yu*yv)}, yw]*G[{1, yu}, yv^(-1)]*G[{yu^(-1), 1/(yu*yv)}, 
        yw])/64 + (G[{0}, yu^(-1)]*G[{1, yv^(-1)}, yw]*
       G[{yu^(-1), 1/(yu*yv)}, yw])/16 + (G[{0}, yv^(-1)]*G[{1, yv^(-1)}, yw]*
       G[{yu^(-1), 1/(yu*yv)}, yw])/16 - (G[{0}, yw]*G[{1, yv^(-1)}, yw]*
       G[{yu^(-1), 1/(yu*yv)}, yw])/16 - 
     (5*G[{1}, yu^(-1)]*G[{1, yv^(-1)}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw])/32 - 
     (G[{1}, yw]*G[{1, yv^(-1)}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw])/32 - 
     (G[{yu^(-1)}, yw]*G[{1, yv^(-1)}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw])/16 + 
     (G[{yu}, yv^(-1)]*G[{1, yv^(-1)}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw])/32 + 
     (G[{1/(yu*yv)}, yw]*G[{1, yv^(-1)}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw])/
      64 - (G[{0}, yu^(-1)]*G[{1, 1/(yu*yv)}, yw]*G[{yu^(-1), 1/(yu*yv)}, 
        yw])/16 - (G[{0}, yv^(-1)]*G[{1, 1/(yu*yv)}, yw]*
       G[{yu^(-1), 1/(yu*yv)}, yw])/16 + (G[{0}, yw]*G[{1, 1/(yu*yv)}, yw]*
       G[{yu^(-1), 1/(yu*yv)}, yw])/16 + 
     (7*G[{1}, yu^(-1)]*G[{1, 1/(yu*yv)}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw])/
      32 + (G[{1}, yv^(-1)]*G[{1, 1/(yu*yv)}, yw]*G[{yu^(-1), 1/(yu*yv)}, 
        yw])/16 + (5*G[{1}, yw]*G[{1, 1/(yu*yv)}, yw]*G[{yu^(-1), 1/(yu*yv)}, 
        yw])/32 + (G[{yu^(-1)}, yw]*G[{1, 1/(yu*yv)}, yw]*
       G[{yu^(-1), 1/(yu*yv)}, yw])/16 - 
     (5*G[{yu}, yv^(-1)]*G[{1, 1/(yu*yv)}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw])/
      32 + (7*G[{1/(yu*yv)}, yw]*G[{1, 1/(yu*yv)}, yw]*
       G[{yu^(-1), 1/(yu*yv)}, yw])/64 - 
     (G[{1}, yu^(-1)]*G[{yu^(-1), 1/(yu*yv)}, yw]^2)/32 - 
     (G[{1}, yv^(-1)]*G[{yu^(-1), 1/(yu*yv)}, yw]^2)/32 - 
     (G[{1}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw]^2)/16 + 
     (G[{yu^(-1)}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw]^2)/32 + 
     (G[{yu}, yv^(-1)]*G[{yu^(-1), 1/(yu*yv)}, yw]^2)/16 - 
     (G[{1/(yu*yv)}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw]^2)/16 - 
     (Pi^2*G[{0}, yu^(-1)]*G[{yv^(-1), 1/(yu*yv)}, yw])/96 - 
     (Pi^2*G[{0}, yv^(-1)]*G[{yv^(-1), 1/(yu*yv)}, yw])/96 + 
     (Pi^2*G[{0}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw])/96 + 
     (19*Pi^2*G[{1}, yu^(-1)]*G[{yv^(-1), 1/(yu*yv)}, yw])/768 - 
     (3*G[{0}, yu^(-1)]^2*G[{1}, yu^(-1)]*G[{yv^(-1), 1/(yu*yv)}, yw])/64 - 
     (3*G[{0}, yu^(-1)]*G[{0}, yv^(-1)]*G[{1}, yu^(-1)]*
       G[{yv^(-1), 1/(yu*yv)}, yw])/32 - (3*G[{0}, yv^(-1)]^2*G[{1}, yu^(-1)]*
       G[{yv^(-1), 1/(yu*yv)}, yw])/64 + (3*G[{0}, yu^(-1)]*G[{0}, yw]*
       G[{1}, yu^(-1)]*G[{yv^(-1), 1/(yu*yv)}, yw])/32 + 
     (3*G[{0}, yv^(-1)]*G[{0}, yw]*G[{1}, yu^(-1)]*G[{yv^(-1), 1/(yu*yv)}, 
        yw])/32 - (3*G[{0}, yw]^2*G[{1}, yu^(-1)]*G[{yv^(-1), 1/(yu*yv)}, 
        yw])/64 + (G[{0}, yu^(-1)]*G[{1}, yu^(-1)]^2*G[{yv^(-1), 1/(yu*yv)}, 
        yw])/8 + (G[{0}, yv^(-1)]*G[{1}, yu^(-1)]^2*G[{yv^(-1), 1/(yu*yv)}, 
        yw])/8 - (G[{0}, yw]*G[{1}, yu^(-1)]^2*G[{yv^(-1), 1/(yu*yv)}, yw])/
      8 - (13*G[{1}, yu^(-1)]^3*G[{yv^(-1), 1/(yu*yv)}, yw])/128 - 
     (Pi^2*G[{1}, yv^(-1)]*G[{yv^(-1), 1/(yu*yv)}, yw])/96 - 
     (3*G[{0}, yu^(-1)]*G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*
       G[{yv^(-1), 1/(yu*yv)}, yw])/32 - (3*G[{0}, yv^(-1)]*G[{1}, yu^(-1)]*
       G[{1}, yv^(-1)]*G[{yv^(-1), 1/(yu*yv)}, yw])/32 + 
     (3*G[{0}, yw]*G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*G[{yv^(-1), 1/(yu*yv)}, 
        yw])/32 + (23*G[{1}, yu^(-1)]^2*G[{1}, yv^(-1)]*
       G[{yv^(-1), 1/(yu*yv)}, yw])/128 - 
     (3*G[{1}, yu^(-1)]*G[{1}, yv^(-1)]^2*G[{yv^(-1), 1/(yu*yv)}, yw])/128 - 
     (7*Pi^2*G[{1}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw])/256 - 
     (3*G[{0}, yu^(-1)]^2*G[{1}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw])/64 - 
     (3*G[{0}, yu^(-1)]*G[{0}, yv^(-1)]*G[{1}, yw]*G[{yv^(-1), 1/(yu*yv)}, 
        yw])/32 - (3*G[{0}, yv^(-1)]^2*G[{1}, yw]*G[{yv^(-1), 1/(yu*yv)}, 
        yw])/64 + (3*G[{0}, yu^(-1)]*G[{0}, yw]*G[{1}, yw]*
       G[{yv^(-1), 1/(yu*yv)}, yw])/32 + (3*G[{0}, yv^(-1)]*G[{0}, yw]*
       G[{1}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw])/32 - 
     (3*G[{0}, yw]^2*G[{1}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw])/64 - 
     (G[{0}, yu^(-1)]*G[{1}, yu^(-1)]*G[{1}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw])/
      16 - (G[{0}, yv^(-1)]*G[{1}, yu^(-1)]*G[{1}, yw]*
       G[{yv^(-1), 1/(yu*yv)}, yw])/16 + 
     (G[{0}, yw]*G[{1}, yu^(-1)]*G[{1}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw])/16 + 
     (5*G[{1}, yu^(-1)]^2*G[{1}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw])/128 + 
     (3*G[{0}, yu^(-1)]*G[{1}, yv^(-1)]*G[{1}, yw]*G[{yv^(-1), 1/(yu*yv)}, 
        yw])/32 + (3*G[{0}, yv^(-1)]*G[{1}, yv^(-1)]*G[{1}, yw]*
       G[{yv^(-1), 1/(yu*yv)}, yw])/32 - (3*G[{0}, yw]*G[{1}, yv^(-1)]*
       G[{1}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw])/32 + 
     (9*G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*G[{1}, yw]*G[{yv^(-1), 1/(yu*yv)}, 
        yw])/64 - (3*G[{1}, yv^(-1)]^2*G[{1}, yw]*G[{yv^(-1), 1/(yu*yv)}, 
        yw])/64 - (G[{0}, yu^(-1)]*G[{1}, yw]^2*G[{yv^(-1), 1/(yu*yv)}, yw])/
      8 - (G[{0}, yv^(-1)]*G[{1}, yw]^2*G[{yv^(-1), 1/(yu*yv)}, yw])/8 + 
     (G[{0}, yw]*G[{1}, yw]^2*G[{yv^(-1), 1/(yu*yv)}, yw])/8 + 
     (7*G[{1}, yu^(-1)]*G[{1}, yw]^2*G[{yv^(-1), 1/(yu*yv)}, yw])/128 + 
     (G[{1}, yv^(-1)]*G[{1}, yw]^2*G[{yv^(-1), 1/(yu*yv)}, yw])/8 - 
     (3*G[{1}, yw]^3*G[{yv^(-1), 1/(yu*yv)}, yw])/128 + 
     (Pi^2*G[{yu^(-1)}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw])/32 + 
     (G[{0}, yu^(-1)]*G[{1}, yu^(-1)]*G[{yu^(-1)}, yw]*
       G[{yv^(-1), 1/(yu*yv)}, yw])/8 + (G[{0}, yv^(-1)]*G[{1}, yu^(-1)]*
       G[{yu^(-1)}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw])/8 - 
     (G[{0}, yw]*G[{1}, yu^(-1)]*G[{yu^(-1)}, yw]*G[{yv^(-1), 1/(yu*yv)}, 
        yw])/8 - (3*G[{1}, yu^(-1)]^2*G[{yu^(-1)}, yw]*
       G[{yv^(-1), 1/(yu*yv)}, yw])/32 - (G[{0}, yu^(-1)]*G[{1}, yv^(-1)]*
       G[{yu^(-1)}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw])/8 - 
     (G[{0}, yv^(-1)]*G[{1}, yv^(-1)]*G[{yu^(-1)}, yw]*
       G[{yv^(-1), 1/(yu*yv)}, yw])/8 + (G[{0}, yw]*G[{1}, yv^(-1)]*
       G[{yu^(-1)}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw])/8 - 
     (G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*G[{yu^(-1)}, yw]*
       G[{yv^(-1), 1/(yu*yv)}, yw])/16 + (G[{1}, yv^(-1)]^2*G[{yu^(-1)}, yw]*
       G[{yv^(-1), 1/(yu*yv)}, yw])/8 - (G[{1}, yu^(-1)]*G[{1}, yw]*
       G[{yu^(-1)}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw])/16 - 
     (G[{1}, yv^(-1)]*G[{1}, yw]*G[{yu^(-1)}, yw]*G[{yv^(-1), 1/(yu*yv)}, 
        yw])/8 - (3*G[{1}, yw]^2*G[{yu^(-1)}, yw]*G[{yv^(-1), 1/(yu*yv)}, 
        yw])/32 + (G[{0}, yu^(-1)]*G[{yu^(-1)}, yw]^2*G[{yv^(-1), 1/(yu*yv)}, 
        yw])/16 + (G[{0}, yv^(-1)]*G[{yu^(-1)}, yw]^2*G[{yv^(-1), 1/(yu*yv)}, 
        yw])/16 - (G[{0}, yw]*G[{yu^(-1)}, yw]^2*G[{yv^(-1), 1/(yu*yv)}, yw])/
      16 + (G[{1}, yu^(-1)]*G[{yu^(-1)}, yw]^2*G[{yv^(-1), 1/(yu*yv)}, yw])/
      16 - (3*G[{1}, yv^(-1)]*G[{yu^(-1)}, yw]^2*G[{yv^(-1), 1/(yu*yv)}, yw])/
      16 + (G[{yu^(-1)}, yw]^3*G[{yv^(-1), 1/(yu*yv)}, yw])/16 + 
     (5*Pi^2*G[{yu}, yv^(-1)]*G[{yv^(-1), 1/(yu*yv)}, yw])/768 + 
     (3*G[{0}, yu^(-1)]^2*G[{yu}, yv^(-1)]*G[{yv^(-1), 1/(yu*yv)}, yw])/64 + 
     (3*G[{0}, yu^(-1)]*G[{0}, yv^(-1)]*G[{yu}, yv^(-1)]*
       G[{yv^(-1), 1/(yu*yv)}, yw])/32 + 
     (3*G[{0}, yv^(-1)]^2*G[{yu}, yv^(-1)]*G[{yv^(-1), 1/(yu*yv)}, yw])/64 - 
     (3*G[{0}, yu^(-1)]*G[{0}, yw]*G[{yu}, yv^(-1)]*G[{yv^(-1), 1/(yu*yv)}, 
        yw])/32 - (3*G[{0}, yv^(-1)]*G[{0}, yw]*G[{yu}, yv^(-1)]*
       G[{yv^(-1), 1/(yu*yv)}, yw])/32 + (3*G[{0}, yw]^2*G[{yu}, yv^(-1)]*
       G[{yv^(-1), 1/(yu*yv)}, yw])/64 + (G[{0}, yu^(-1)]*G[{1}, yu^(-1)]*
       G[{yu}, yv^(-1)]*G[{yv^(-1), 1/(yu*yv)}, yw])/32 + 
     (G[{0}, yv^(-1)]*G[{1}, yu^(-1)]*G[{yu}, yv^(-1)]*
       G[{yv^(-1), 1/(yu*yv)}, yw])/32 - 
     (G[{0}, yw]*G[{1}, yu^(-1)]*G[{yu}, yv^(-1)]*G[{yv^(-1), 1/(yu*yv)}, 
        yw])/32 - (G[{1}, yu^(-1)]^2*G[{yu}, yv^(-1)]*G[{yv^(-1), 1/(yu*yv)}, 
        yw])/8 + (G[{0}, yu^(-1)]*G[{1}, yv^(-1)]*G[{yu}, yv^(-1)]*
       G[{yv^(-1), 1/(yu*yv)}, yw])/32 + (G[{0}, yv^(-1)]*G[{1}, yv^(-1)]*
       G[{yu}, yv^(-1)]*G[{yv^(-1), 1/(yu*yv)}, yw])/32 - 
     (G[{0}, yw]*G[{1}, yv^(-1)]*G[{yu}, yv^(-1)]*G[{yv^(-1), 1/(yu*yv)}, 
        yw])/32 - (G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*G[{yu}, yv^(-1)]*
       G[{yv^(-1), 1/(yu*yv)}, yw])/32 - 
     (5*G[{1}, yv^(-1)]^2*G[{yu}, yv^(-1)]*G[{yv^(-1), 1/(yu*yv)}, yw])/64 + 
     (5*G[{0}, yu^(-1)]*G[{1}, yw]*G[{yu}, yv^(-1)]*G[{yv^(-1), 1/(yu*yv)}, 
        yw])/32 + (5*G[{0}, yv^(-1)]*G[{1}, yw]*G[{yu}, yv^(-1)]*
       G[{yv^(-1), 1/(yu*yv)}, yw])/32 - 
     (5*G[{0}, yw]*G[{1}, yw]*G[{yu}, yv^(-1)]*G[{yv^(-1), 1/(yu*yv)}, yw])/
      32 - (3*G[{1}, yu^(-1)]*G[{1}, yw]*G[{yu}, yv^(-1)]*
       G[{yv^(-1), 1/(yu*yv)}, yw])/32 - 
     (G[{1}, yv^(-1)]*G[{1}, yw]*G[{yu}, yv^(-1)]*G[{yv^(-1), 1/(yu*yv)}, 
        yw])/32 + (9*G[{1}, yw]^2*G[{yu}, yv^(-1)]*G[{yv^(-1), 1/(yu*yv)}, 
        yw])/128 + (3*G[{1}, yw]*G[{yu^(-1)}, yw]*G[{yu}, yv^(-1)]*
       G[{yv^(-1), 1/(yu*yv)}, yw])/16 - (G[{0}, yu^(-1)]*G[{yu}, yv^(-1)]^2*
       G[{yv^(-1), 1/(yu*yv)}, yw])/8 - (G[{0}, yv^(-1)]*G[{yu}, yv^(-1)]^2*
       G[{yv^(-1), 1/(yu*yv)}, yw])/8 + (G[{0}, yw]*G[{yu}, yv^(-1)]^2*
       G[{yv^(-1), 1/(yu*yv)}, yw])/8 + (7*G[{1}, yu^(-1)]*G[{yu}, yv^(-1)]^2*
       G[{yv^(-1), 1/(yu*yv)}, yw])/64 - (3*G[{1}, yw]*G[{yu}, yv^(-1)]^2*
       G[{yv^(-1), 1/(yu*yv)}, yw])/32 + 
     (3*G[{yu}, yv^(-1)]^3*G[{yv^(-1), 1/(yu*yv)}, yw])/64 - 
     (Pi^2*G[{yv^(-1)}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw])/256 + 
     (3*G[{0}, yu^(-1)]^2*G[{yv^(-1)}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw])/64 + 
     (3*G[{0}, yu^(-1)]*G[{0}, yv^(-1)]*G[{yv^(-1)}, yw]*
       G[{yv^(-1), 1/(yu*yv)}, yw])/32 + 
     (3*G[{0}, yv^(-1)]^2*G[{yv^(-1)}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw])/64 - 
     (3*G[{0}, yu^(-1)]*G[{0}, yw]*G[{yv^(-1)}, yw]*G[{yv^(-1), 1/(yu*yv)}, 
        yw])/32 - (3*G[{0}, yv^(-1)]*G[{0}, yw]*G[{yv^(-1)}, yw]*
       G[{yv^(-1), 1/(yu*yv)}, yw])/32 + (3*G[{0}, yw]^2*G[{yv^(-1)}, yw]*
       G[{yv^(-1), 1/(yu*yv)}, yw])/64 - (3*G[{0}, yu^(-1)]*G[{1}, yu^(-1)]*
       G[{yv^(-1)}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw])/32 - 
     (3*G[{0}, yv^(-1)]*G[{1}, yu^(-1)]*G[{yv^(-1)}, yw]*
       G[{yv^(-1), 1/(yu*yv)}, yw])/32 + (3*G[{0}, yw]*G[{1}, yu^(-1)]*
       G[{yv^(-1)}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw])/32 + 
     (G[{1}, yu^(-1)]^2*G[{yv^(-1)}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw])/32 - 
     (3*G[{0}, yu^(-1)]*G[{1}, yv^(-1)]*G[{yv^(-1)}, yw]*
       G[{yv^(-1), 1/(yu*yv)}, yw])/32 - (3*G[{0}, yv^(-1)]*G[{1}, yv^(-1)]*
       G[{yv^(-1)}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw])/32 + 
     (3*G[{0}, yw]*G[{1}, yv^(-1)]*G[{yv^(-1)}, yw]*G[{yv^(-1), 1/(yu*yv)}, 
        yw])/32 - (3*G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*G[{yv^(-1)}, yw]*
       G[{yv^(-1), 1/(yu*yv)}, yw])/32 + 
     (3*G[{1}, yv^(-1)]^2*G[{yv^(-1)}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw])/64 + 
     (7*G[{0}, yu^(-1)]*G[{1}, yw]*G[{yv^(-1)}, yw]*G[{yv^(-1), 1/(yu*yv)}, 
        yw])/32 + (7*G[{0}, yv^(-1)]*G[{1}, yw]*G[{yv^(-1)}, yw]*
       G[{yv^(-1), 1/(yu*yv)}, yw])/32 - 
     (7*G[{0}, yw]*G[{1}, yw]*G[{yv^(-1)}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw])/
      32 - (G[{1}, yu^(-1)]*G[{1}, yw]*G[{yv^(-1)}, yw]*
       G[{yv^(-1), 1/(yu*yv)}, yw])/4 - (7*G[{1}, yv^(-1)]*G[{1}, yw]*
       G[{yv^(-1)}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw])/32 - 
     (G[{1}, yw]^2*G[{yv^(-1)}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw])/64 - 
     (G[{0}, yu^(-1)]*G[{yu^(-1)}, yw]*G[{yv^(-1)}, yw]*
       G[{yv^(-1), 1/(yu*yv)}, yw])/8 - (G[{0}, yv^(-1)]*G[{yu^(-1)}, yw]*
       G[{yv^(-1)}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw])/8 + 
     (G[{0}, yw]*G[{yu^(-1)}, yw]*G[{yv^(-1)}, yw]*G[{yv^(-1), 1/(yu*yv)}, 
        yw])/8 + (G[{1}, yu^(-1)]*G[{yu^(-1)}, yw]*G[{yv^(-1)}, yw]*
       G[{yv^(-1), 1/(yu*yv)}, yw])/8 + (G[{1}, yv^(-1)]*G[{yu^(-1)}, yw]*
       G[{yv^(-1)}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw])/8 - 
     (G[{yu^(-1)}, yw]^2*G[{yv^(-1)}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw])/16 + 
     (7*G[{1}, yu^(-1)]*G[{yu}, yv^(-1)]*G[{yv^(-1)}, yw]*
       G[{yv^(-1), 1/(yu*yv)}, yw])/32 + 
     (G[{1}, yw]*G[{yu}, yv^(-1)]*G[{yv^(-1)}, yw]*G[{yv^(-1), 1/(yu*yv)}, 
        yw])/32 - (7*G[{yu}, yv^(-1)]^2*G[{yv^(-1)}, yw]*
       G[{yv^(-1), 1/(yu*yv)}, yw])/64 - (G[{0}, yu^(-1)]*G[{yv^(-1)}, yw]^2*
       G[{yv^(-1), 1/(yu*yv)}, yw])/16 - (G[{0}, yv^(-1)]*G[{yv^(-1)}, yw]^2*
       G[{yv^(-1), 1/(yu*yv)}, yw])/16 + (G[{0}, yw]*G[{yv^(-1)}, yw]^2*
       G[{yv^(-1), 1/(yu*yv)}, yw])/16 + 
     (11*G[{1}, yu^(-1)]*G[{yv^(-1)}, yw]^2*G[{yv^(-1), 1/(yu*yv)}, yw])/64 + 
     (G[{1}, yv^(-1)]*G[{yv^(-1)}, yw]^2*G[{yv^(-1), 1/(yu*yv)}, yw])/16 + 
     (7*G[{1}, yw]*G[{yv^(-1)}, yw]^2*G[{yv^(-1), 1/(yu*yv)}, yw])/64 - 
     (G[{yu^(-1)}, yw]*G[{yv^(-1)}, yw]^2*G[{yv^(-1), 1/(yu*yv)}, yw])/16 - 
     (7*G[{yu}, yv^(-1)]*G[{yv^(-1)}, yw]^2*G[{yv^(-1), 1/(yu*yv)}, yw])/64 - 
     (11*G[{yv^(-1)}, yw]^3*G[{yv^(-1), 1/(yu*yv)}, yw])/192 - 
     (5*Pi^2*G[{1/(yu*yv)}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw])/768 + 
     (3*G[{0}, yu^(-1)]^2*G[{1/(yu*yv)}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw])/
      128 + (3*G[{0}, yu^(-1)]*G[{0}, yv^(-1)]*G[{1/(yu*yv)}, yw]*
       G[{yv^(-1), 1/(yu*yv)}, yw])/64 + 
     (3*G[{0}, yv^(-1)]^2*G[{1/(yu*yv)}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw])/
      128 - (3*G[{0}, yu^(-1)]*G[{0}, yw]*G[{1/(yu*yv)}, yw]*
       G[{yv^(-1), 1/(yu*yv)}, yw])/64 - (3*G[{0}, yv^(-1)]*G[{0}, yw]*
       G[{1/(yu*yv)}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw])/64 + 
     (3*G[{0}, yw]^2*G[{1/(yu*yv)}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw])/128 - 
     (5*G[{0}, yu^(-1)]*G[{1}, yu^(-1)]*G[{1/(yu*yv)}, yw]*
       G[{yv^(-1), 1/(yu*yv)}, yw])/64 - (5*G[{0}, yv^(-1)]*G[{1}, yu^(-1)]*
       G[{1/(yu*yv)}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw])/64 + 
     (5*G[{0}, yw]*G[{1}, yu^(-1)]*G[{1/(yu*yv)}, yw]*G[{yv^(-1), 1/(yu*yv)}, 
        yw])/64 + (3*G[{1}, yu^(-1)]^2*G[{1/(yu*yv)}, yw]*
       G[{yv^(-1), 1/(yu*yv)}, yw])/64 + (5*G[{0}, yu^(-1)]*G[{1}, yv^(-1)]*
       G[{1/(yu*yv)}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw])/64 + 
     (5*G[{0}, yv^(-1)]*G[{1}, yv^(-1)]*G[{1/(yu*yv)}, yw]*
       G[{yv^(-1), 1/(yu*yv)}, yw])/64 - (5*G[{0}, yw]*G[{1}, yv^(-1)]*
       G[{1/(yu*yv)}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw])/64 - 
     (15*G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*G[{1/(yu*yv)}, yw]*
       G[{yv^(-1), 1/(yu*yv)}, yw])/64 - 
     (5*G[{1}, yv^(-1)]^2*G[{1/(yu*yv)}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw])/
      128 + (13*G[{0}, yu^(-1)]*G[{1}, yw]*G[{1/(yu*yv)}, yw]*
       G[{yv^(-1), 1/(yu*yv)}, yw])/64 + (13*G[{0}, yv^(-1)]*G[{1}, yw]*
       G[{1/(yu*yv)}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw])/64 - 
     (13*G[{0}, yw]*G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{yv^(-1), 1/(yu*yv)}, 
        yw])/64 - (11*G[{1}, yu^(-1)]*G[{1}, yw]*G[{1/(yu*yv)}, yw]*
       G[{yv^(-1), 1/(yu*yv)}, yw])/32 - (13*G[{1}, yv^(-1)]*G[{1}, yw]*
       G[{1/(yu*yv)}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw])/64 - 
     (9*G[{1}, yw]^2*G[{1/(yu*yv)}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw])/128 - 
     (3*G[{0}, yu^(-1)]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*
       G[{yv^(-1), 1/(yu*yv)}, yw])/16 - (3*G[{0}, yv^(-1)]*G[{yu^(-1)}, yw]*
       G[{1/(yu*yv)}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw])/16 + 
     (3*G[{0}, yw]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*
       G[{yv^(-1), 1/(yu*yv)}, yw])/16 + (9*G[{1}, yu^(-1)]*G[{yu^(-1)}, yw]*
       G[{1/(yu*yv)}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw])/32 + 
     (3*G[{1}, yv^(-1)]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*
       G[{yv^(-1), 1/(yu*yv)}, yw])/16 + (3*G[{1}, yw]*G[{yu^(-1)}, yw]*
       G[{1/(yu*yv)}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw])/32 - 
     (3*G[{yu^(-1)}, yw]^2*G[{1/(yu*yv)}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw])/
      32 - (3*G[{0}, yu^(-1)]*G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw]*
       G[{yv^(-1), 1/(yu*yv)}, yw])/32 - (3*G[{0}, yv^(-1)]*G[{yu}, yv^(-1)]*
       G[{1/(yu*yv)}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw])/32 + 
     (3*G[{0}, yw]*G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw]*
       G[{yv^(-1), 1/(yu*yv)}, yw])/32 + (19*G[{1}, yu^(-1)]*G[{yu}, yv^(-1)]*
       G[{1/(yu*yv)}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw])/64 + 
     (3*G[{1}, yv^(-1)]*G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw]*
       G[{yv^(-1), 1/(yu*yv)}, yw])/32 + (9*G[{1}, yw]*G[{yu}, yv^(-1)]*
       G[{1/(yu*yv)}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw])/64 - 
     (3*G[{yu^(-1)}, yw]*G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw]*
       G[{yv^(-1), 1/(yu*yv)}, yw])/32 - 
     (13*G[{yu}, yv^(-1)]^2*G[{1/(yu*yv)}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw])/
      128 - (G[{0}, yu^(-1)]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*
       G[{yv^(-1), 1/(yu*yv)}, yw])/32 - (G[{0}, yv^(-1)]*G[{yv^(-1)}, yw]*
       G[{1/(yu*yv)}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw])/32 + 
     (G[{0}, yw]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{yv^(-1), 1/(yu*yv)}, 
        yw])/32 + (5*G[{1}, yu^(-1)]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*
       G[{yv^(-1), 1/(yu*yv)}, yw])/64 + (9*G[{1}, yv^(-1)]*G[{yv^(-1)}, yw]*
       G[{1/(yu*yv)}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw])/32 + 
     (19*G[{1}, yw]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*
       G[{yv^(-1), 1/(yu*yv)}, yw])/64 - (9*G[{yu^(-1)}, yw]*G[{yv^(-1)}, yw]*
       G[{1/(yu*yv)}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw])/32 - 
     (19*G[{yu}, yv^(-1)]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*
       G[{yv^(-1), 1/(yu*yv)}, yw])/64 - 
     (5*G[{yv^(-1)}, yw]^2*G[{1/(yu*yv)}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw])/
      128 + (3*G[{0}, yu^(-1)]*G[{1/(yu*yv)}, yw]^2*G[{yv^(-1), 1/(yu*yv)}, 
        yw])/64 + (3*G[{0}, yv^(-1)]*G[{1/(yu*yv)}, yw]^2*
       G[{yv^(-1), 1/(yu*yv)}, yw])/64 - (3*G[{0}, yw]*G[{1/(yu*yv)}, yw]^2*
       G[{yv^(-1), 1/(yu*yv)}, yw])/64 - 
     (G[{1}, yu^(-1)]*G[{1/(yu*yv)}, yw]^2*G[{yv^(-1), 1/(yu*yv)}, yw])/64 - 
     (5*G[{1}, yv^(-1)]*G[{1/(yu*yv)}, yw]^2*G[{yv^(-1), 1/(yu*yv)}, yw])/
      64 + (5*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2*G[{yv^(-1), 1/(yu*yv)}, 
        yw])/64 + (G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2*
       G[{yv^(-1), 1/(yu*yv)}, yw])/64 - (G[{0}, yu^(-1)]*G[{0, 1}, yu^(-1)]*
       G[{yv^(-1), 1/(yu*yv)}, yw])/16 - (G[{0}, yv^(-1)]*G[{0, 1}, yu^(-1)]*
       G[{yv^(-1), 1/(yu*yv)}, yw])/16 + (G[{0}, yw]*G[{0, 1}, yu^(-1)]*
       G[{yv^(-1), 1/(yu*yv)}, yw])/16 + 
     (17*G[{1}, yu^(-1)]*G[{0, 1}, yu^(-1)]*G[{yv^(-1), 1/(yu*yv)}, yw])/64 - 
     (9*G[{1}, yv^(-1)]*G[{0, 1}, yu^(-1)]*G[{yv^(-1), 1/(yu*yv)}, yw])/64 + 
     (5*G[{1}, yw]*G[{0, 1}, yu^(-1)]*G[{yv^(-1), 1/(yu*yv)}, yw])/64 + 
     (G[{yu^(-1)}, yw]*G[{0, 1}, yu^(-1)]*G[{yv^(-1), 1/(yu*yv)}, yw])/16 - 
     (3*G[{yv^(-1)}, yw]*G[{0, 1}, yu^(-1)]*G[{yv^(-1), 1/(yu*yv)}, yw])/16 - 
     (G[{1/(yu*yv)}, yw]*G[{0, 1}, yu^(-1)]*G[{yv^(-1), 1/(yu*yv)}, yw])/16 - 
     (G[{1}, yv^(-1)]*G[{0, 1}, yv^(-1)]*G[{yv^(-1), 1/(yu*yv)}, yw])/8 - 
     (G[{1}, yw]*G[{0, 1}, yv^(-1)]*G[{yv^(-1), 1/(yu*yv)}, yw])/8 + 
     (G[{yu^(-1)}, yw]*G[{0, 1}, yv^(-1)]*G[{yv^(-1), 1/(yu*yv)}, yw])/8 + 
     (G[{yu}, yv^(-1)]*G[{0, 1}, yv^(-1)]*G[{yv^(-1), 1/(yu*yv)}, yw])/8 - 
     (3*G[{1}, yu^(-1)]*G[{0, 1}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw])/32 + 
     (G[{1}, yv^(-1)]*G[{0, 1}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw])/8 - 
     (3*G[{1}, yw]*G[{0, 1}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw])/32 - 
     (G[{yu}, yv^(-1)]*G[{0, 1}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw])/32 + 
     (7*G[{yv^(-1)}, yw]*G[{0, 1}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw])/32 + 
     (7*G[{1/(yu*yv)}, yw]*G[{0, 1}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw])/64 + 
     (3*G[{1}, yu^(-1)]*G[{0, yu^(-1)}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw])/32 - 
     (G[{1}, yv^(-1)]*G[{0, yu^(-1)}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw])/8 + 
     (3*G[{1}, yw]*G[{0, yu^(-1)}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw])/32 + 
     (G[{yu}, yv^(-1)]*G[{0, yu^(-1)}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw])/32 - 
     (7*G[{yv^(-1)}, yw]*G[{0, yu^(-1)}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw])/
      32 - (7*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1)}, yw]*G[{yv^(-1), 1/(yu*yv)}, 
        yw])/64 + (G[{1}, yv^(-1)]*G[{0, yu}, yv^(-1)]*
       G[{yv^(-1), 1/(yu*yv)}, yw])/8 + (G[{1}, yw]*G[{0, yu}, yv^(-1)]*
       G[{yv^(-1), 1/(yu*yv)}, yw])/8 - (G[{yu^(-1)}, yw]*G[{0, yu}, yv^(-1)]*
       G[{yv^(-1), 1/(yu*yv)}, yw])/8 - (G[{yu}, yv^(-1)]*G[{0, yu}, yv^(-1)]*
       G[{yv^(-1), 1/(yu*yv)}, yw])/8 + 
     (3*G[{1}, yu^(-1)]*G[{0, yv^(-1)}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw])/32 - 
     (G[{1}, yv^(-1)]*G[{0, yv^(-1)}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw])/8 + 
     (3*G[{1}, yw]*G[{0, yv^(-1)}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw])/32 + 
     (G[{yu}, yv^(-1)]*G[{0, yv^(-1)}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw])/32 - 
     (7*G[{yv^(-1)}, yw]*G[{0, yv^(-1)}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw])/
      32 - (7*G[{1/(yu*yv)}, yw]*G[{0, yv^(-1)}, yw]*G[{yv^(-1), 1/(yu*yv)}, 
        yw])/64 - (3*G[{1}, yu^(-1)]*G[{0, 1/(yu*yv)}, yw]*
       G[{yv^(-1), 1/(yu*yv)}, yw])/32 + 
     (G[{1}, yv^(-1)]*G[{0, 1/(yu*yv)}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw])/8 - 
     (3*G[{1}, yw]*G[{0, 1/(yu*yv)}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw])/32 - 
     (G[{yu}, yv^(-1)]*G[{0, 1/(yu*yv)}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw])/
      32 + (7*G[{yv^(-1)}, yw]*G[{0, 1/(yu*yv)}, yw]*G[{yv^(-1), 1/(yu*yv)}, 
        yw])/32 + (7*G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv)}, yw]*
       G[{yv^(-1), 1/(yu*yv)}, yw])/64 - 
     (3*G[{1}, yu^(-1)]*G[{1, yu^(-1)}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw])/32 + 
     (G[{1}, yv^(-1)]*G[{1, yu^(-1)}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw])/4 + 
     (5*G[{1}, yw]*G[{1, yu^(-1)}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw])/32 + 
     (G[{yu^(-1)}, yw]*G[{1, yu^(-1)}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw])/8 - 
     (5*G[{yu}, yv^(-1)]*G[{1, yu^(-1)}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw])/
      32 + (7*G[{yv^(-1)}, yw]*G[{1, yu^(-1)}, yw]*G[{yv^(-1), 1/(yu*yv)}, 
        yw])/32 + (7*G[{1/(yu*yv)}, yw]*G[{1, yu^(-1)}, yw]*
       G[{yv^(-1), 1/(yu*yv)}, yw])/64 + (G[{0}, yu^(-1)]*G[{1, yu}, yv^(-1)]*
       G[{yv^(-1), 1/(yu*yv)}, yw])/16 + (G[{0}, yv^(-1)]*G[{1, yu}, yv^(-1)]*
       G[{yv^(-1), 1/(yu*yv)}, yw])/16 - (G[{0}, yw]*G[{1, yu}, yv^(-1)]*
       G[{yv^(-1), 1/(yu*yv)}, yw])/16 - 
     (3*G[{1}, yu^(-1)]*G[{1, yu}, yv^(-1)]*G[{yv^(-1), 1/(yu*yv)}, yw])/32 + 
     (3*G[{1}, yv^(-1)]*G[{1, yu}, yv^(-1)]*G[{yv^(-1), 1/(yu*yv)}, yw])/16 - 
     (13*G[{1}, yw]*G[{1, yu}, yv^(-1)]*G[{yv^(-1), 1/(yu*yv)}, yw])/64 + 
     (G[{yu^(-1)}, yw]*G[{1, yu}, yv^(-1)]*G[{yv^(-1), 1/(yu*yv)}, yw])/16 + 
     (G[{yu}, yv^(-1)]*G[{1, yu}, yv^(-1)]*G[{yv^(-1), 1/(yu*yv)}, yw])/8 + 
     (3*G[{yv^(-1)}, yw]*G[{1, yu}, yv^(-1)]*G[{yv^(-1), 1/(yu*yv)}, yw])/
      16 + (G[{1/(yu*yv)}, yw]*G[{1, yu}, yv^(-1)]*G[{yv^(-1), 1/(yu*yv)}, 
        yw])/16 - (G[{0}, yu^(-1)]*G[{1, yv^(-1)}, yw]*
       G[{yv^(-1), 1/(yu*yv)}, yw])/16 - (G[{0}, yv^(-1)]*G[{1, yv^(-1)}, yw]*
       G[{yv^(-1), 1/(yu*yv)}, yw])/16 + (G[{0}, yw]*G[{1, yv^(-1)}, yw]*
       G[{yv^(-1), 1/(yu*yv)}, yw])/16 + (G[{1}, yv^(-1)]*G[{1, yv^(-1)}, yw]*
       G[{yv^(-1), 1/(yu*yv)}, yw])/16 - (G[{1}, yw]*G[{1, yv^(-1)}, yw]*
       G[{yv^(-1), 1/(yu*yv)}, yw])/16 + 
     (G[{yu^(-1)}, yw]*G[{1, yv^(-1)}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw])/16 + 
     (G[{yu}, yv^(-1)]*G[{1, yv^(-1)}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw])/16 + 
     (G[{yv^(-1)}, yw]*G[{1, yv^(-1)}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw])/32 + 
     (3*G[{1/(yu*yv)}, yw]*G[{1, yv^(-1)}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw])/
      64 + (G[{0}, yu^(-1)]*G[{1, 1/(yu*yv)}, yw]*G[{yv^(-1), 1/(yu*yv)}, 
        yw])/16 + (G[{0}, yv^(-1)]*G[{1, 1/(yu*yv)}, yw]*
       G[{yv^(-1), 1/(yu*yv)}, yw])/16 - (G[{0}, yw]*G[{1, 1/(yu*yv)}, yw]*
       G[{yv^(-1), 1/(yu*yv)}, yw])/16 - 
     (3*G[{1}, yu^(-1)]*G[{1, 1/(yu*yv)}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw])/
      32 - (G[{1}, yv^(-1)]*G[{1, 1/(yu*yv)}, yw]*G[{yv^(-1), 1/(yu*yv)}, 
        yw])/16 - (G[{1}, yw]*G[{1, 1/(yu*yv)}, yw]*G[{yv^(-1), 1/(yu*yv)}, 
        yw])/32 - (3*G[{yu^(-1)}, yw]*G[{1, 1/(yu*yv)}, yw]*
       G[{yv^(-1), 1/(yu*yv)}, yw])/16 + 
     (G[{yu}, yv^(-1)]*G[{1, 1/(yu*yv)}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw])/
      32 + (3*G[{yv^(-1)}, yw]*G[{1, 1/(yu*yv)}, yw]*G[{yv^(-1), 1/(yu*yv)}, 
        yw])/16 + (G[{1/(yu*yv)}, yw]*G[{1, 1/(yu*yv)}, yw]*
       G[{yv^(-1), 1/(yu*yv)}, yw])/16 + 
     (3*G[{1}, yu^(-1)]*G[{yu^(-1), 1/(yu*yv)}, yw]*G[{yv^(-1), 1/(yu*yv)}, 
        yw])/32 + (3*G[{1}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw]*
       G[{yv^(-1), 1/(yu*yv)}, yw])/32 - 
     (3*G[{yu}, yv^(-1)]*G[{yu^(-1), 1/(yu*yv)}, yw]*G[{yv^(-1), 1/(yu*yv)}, 
        yw])/32 - (7*G[{yv^(-1)}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw]*
       G[{yv^(-1), 1/(yu*yv)}, yw])/32 - 
     (7*G[{1/(yu*yv)}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw]*
       G[{yv^(-1), 1/(yu*yv)}, yw])/64 - 
     (G[{0}, yu^(-1)]*G[{yv^(-1), 1/(yu*yv)}, yw]^2)/32 - 
     (G[{0}, yv^(-1)]*G[{yv^(-1), 1/(yu*yv)}, yw]^2)/32 + 
     (G[{0}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw]^2)/32 + 
     (3*G[{1}, yu^(-1)]*G[{yv^(-1), 1/(yu*yv)}, yw]^2)/32 - 
     (3*G[{1}, yv^(-1)]*G[{yv^(-1), 1/(yu*yv)}, yw]^2)/32 - 
     (G[{1}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw]^2)/16 + 
     (3*G[{yu^(-1)}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw]^2)/32 + 
     (G[{yu}, yv^(-1)]*G[{yv^(-1), 1/(yu*yv)}, yw]^2)/16 - 
     (3*G[{yv^(-1)}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw]^2)/32 - 
     (11*G[{1/(yu*yv)}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw]^2)/128 + 
     (11*Pi^2*G[{0, 0, 1}, yu^(-1)])/768 + 
     (3*G[{0}, yu^(-1)]^2*G[{0, 0, 1}, yu^(-1)])/128 + 
     (3*G[{0}, yu^(-1)]*G[{0}, yv^(-1)]*G[{0, 0, 1}, yu^(-1)])/64 + 
     (3*G[{0}, yv^(-1)]^2*G[{0, 0, 1}, yu^(-1)])/128 - 
     (3*G[{0}, yu^(-1)]*G[{0}, yw]*G[{0, 0, 1}, yu^(-1)])/64 - 
     (3*G[{0}, yv^(-1)]*G[{0}, yw]*G[{0, 0, 1}, yu^(-1)])/64 + 
     (3*G[{0}, yw]^2*G[{0, 0, 1}, yu^(-1)])/128 - 
     (3*G[{0}, yu^(-1)]*G[{1}, yu^(-1)]*G[{0, 0, 1}, yu^(-1)])/64 - 
     (3*G[{0}, yv^(-1)]*G[{1}, yu^(-1)]*G[{0, 0, 1}, yu^(-1)])/64 + 
     (3*G[{0}, yw]*G[{1}, yu^(-1)]*G[{0, 0, 1}, yu^(-1)])/64 + 
     (5*G[{1}, yu^(-1)]^2*G[{0, 0, 1}, yu^(-1)])/128 + 
     (G[{0}, yu^(-1)]*G[{1}, yv^(-1)]*G[{0, 0, 1}, yu^(-1)])/64 + 
     (G[{0}, yv^(-1)]*G[{1}, yv^(-1)]*G[{0, 0, 1}, yu^(-1)])/64 - 
     (G[{0}, yw]*G[{1}, yv^(-1)]*G[{0, 0, 1}, yu^(-1)])/64 + 
     (G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*G[{0, 0, 1}, yu^(-1)])/64 - 
     (G[{1}, yv^(-1)]^2*G[{0, 0, 1}, yu^(-1)])/128 - 
     (G[{0}, yu^(-1)]*G[{1}, yw]*G[{0, 0, 1}, yu^(-1)])/64 - 
     (G[{0}, yv^(-1)]*G[{1}, yw]*G[{0, 0, 1}, yu^(-1)])/64 + 
     (G[{0}, yw]*G[{1}, yw]*G[{0, 0, 1}, yu^(-1)])/64 - 
     (G[{1}, yu^(-1)]*G[{1}, yw]*G[{0, 0, 1}, yu^(-1)])/64 + 
     (G[{1}, yv^(-1)]*G[{1}, yw]*G[{0, 0, 1}, yu^(-1)])/64 - 
     (G[{1}, yw]^2*G[{0, 0, 1}, yu^(-1)])/64 + 
     (G[{1}, yw]*G[{yu}, yv^(-1)]*G[{0, 0, 1}, yu^(-1)])/32 + 
     (3*G[{0}, yu^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, 0, 1}, yu^(-1)])/64 + 
     (3*G[{0}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, 0, 1}, yu^(-1)])/64 - 
     (3*G[{0}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 0, 1}, yu^(-1)])/64 - 
     (5*G[{1}, yu^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, 0, 1}, yu^(-1)])/64 + 
     (G[{1}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, 0, 1}, yu^(-1)])/64 + 
     (G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 0, 1}, yu^(-1)])/32 - 
     (G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 0, 1}, yu^(-1)])/64 - 
     (G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, 0, 1}, yu^(-1)])/32 + 
     (5*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 0, 1}, yu^(-1)])/64 - 
     (G[{0, 1}, yu^(-1)]*G[{0, 0, 1}, yu^(-1)])/32 - 
     (G[{0, 1}, yw]*G[{0, 0, 1}, yu^(-1)])/64 + 
     (G[{0, yu^(-1)}, yw]*G[{0, 0, 1}, yu^(-1)])/64 - 
     (3*G[{0, yv^(-1)}, yw]*G[{0, 0, 1}, yu^(-1)])/64 + 
     (3*G[{0, 1/(yu*yv)}, yw]*G[{0, 0, 1}, yu^(-1)])/64 - 
     (G[{1, yu^(-1)}, yw]*G[{0, 0, 1}, yu^(-1)])/64 - 
     (G[{1, yu}, yv^(-1)]*G[{0, 0, 1}, yu^(-1)])/32 + 
     (G[{1, yv^(-1)}, yw]*G[{0, 0, 1}, yu^(-1)])/64 - 
     (G[{1, 1/(yu*yv)}, yw]*G[{0, 0, 1}, yu^(-1)])/32 + 
     (G[{yu^(-1), 1/(yu*yv)}, yw]*G[{0, 0, 1}, yu^(-1)])/64 - 
     (5*G[{yv^(-1), 1/(yu*yv)}, yw]*G[{0, 0, 1}, yu^(-1)])/64 + 
     (G[{0}, yu^(-1)]*G[{1}, yv^(-1)]*G[{0, 0, 1}, yv^(-1)])/16 + 
     (G[{0}, yv^(-1)]*G[{1}, yv^(-1)]*G[{0, 0, 1}, yv^(-1)])/16 - 
     (G[{0}, yw]*G[{1}, yv^(-1)]*G[{0, 0, 1}, yv^(-1)])/16 - 
     (G[{1}, yv^(-1)]^2*G[{0, 0, 1}, yv^(-1)])/32 - 
     (G[{0}, yu^(-1)]*G[{1}, yw]*G[{0, 0, 1}, yv^(-1)])/16 - 
     (G[{0}, yv^(-1)]*G[{1}, yw]*G[{0, 0, 1}, yv^(-1)])/16 + 
     (G[{0}, yw]*G[{1}, yw]*G[{0, 0, 1}, yv^(-1)])/16 + 
     (G[{1}, yv^(-1)]*G[{1}, yw]*G[{0, 0, 1}, yv^(-1)])/16 - 
     (G[{1}, yw]^2*G[{0, 0, 1}, yv^(-1)])/32 + 
     (G[{1}, yw]*G[{yu}, yv^(-1)]*G[{0, 0, 1}, yv^(-1)])/16 + 
     (G[{1}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, 0, 1}, yv^(-1)])/16 + 
     (G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 0, 1}, yv^(-1)])/16 - 
     (G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 0, 1}, yv^(-1)])/16 - 
     (G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, 0, 1}, yv^(-1)])/16 - 
     (G[{0, 1}, yw]*G[{0, 0, 1}, yv^(-1)])/16 + 
     (G[{0, yu^(-1)}, yw]*G[{0, 0, 1}, yv^(-1)])/16 - 
     (G[{1, yu^(-1)}, yw]*G[{0, 0, 1}, yv^(-1)])/16 - 
     (G[{1, yu}, yv^(-1)]*G[{0, 0, 1}, yv^(-1)])/16 - 
     (G[{1, 1/(yu*yv)}, yw]*G[{0, 0, 1}, yv^(-1)])/16 + 
     (G[{yu^(-1), 1/(yu*yv)}, yw]*G[{0, 0, 1}, yv^(-1)])/16 + 
     (Pi^2*G[{0, 0, 1}, yw])/96 + (G[{1}, yu^(-1)]^2*G[{0, 0, 1}, yw])/8 + 
     (G[{1}, yu^(-1)]*G[{1}, yw]*G[{0, 0, 1}, yw])/4 + 
     (G[{1}, yw]^2*G[{0, 0, 1}, yw])/16 - 
     (G[{1}, yu^(-1)]*G[{yu}, yv^(-1)]*G[{0, 0, 1}, yw])/4 - 
     (G[{1}, yw]*G[{yu}, yv^(-1)]*G[{0, 0, 1}, yw])/4 + 
     (G[{yu}, yv^(-1)]^2*G[{0, 0, 1}, yw])/8 - 
     (G[{1}, yu^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, 0, 1}, yw])/8 - 
     (G[{1}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, 0, 1}, yw])/8 - 
     (G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 0, 1}, yw])/8 + 
     (G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, 0, 1}, yw])/4 + 
     (G[{0, 1}, yw]*G[{0, 0, 1}, yw])/8 - 
     (G[{0, yv^(-1)}, yw]*G[{0, 0, 1}, yw])/8 + 
     (G[{1, 1/(yu*yv)}, yw]*G[{0, 0, 1}, yw])/8 + 
     (Pi^2*G[{0, 0, yu^(-1)}, yw])/96 - 
     (G[{1}, yu^(-1)]^2*G[{0, 0, yu^(-1)}, yw])/8 + 
     (G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*G[{0, 0, yu^(-1)}, yw])/4 - 
     (G[{1}, yv^(-1)]^2*G[{0, 0, yu^(-1)}, yw])/16 - 
     (G[{1}, yu^(-1)]*G[{1}, yw]*G[{0, 0, yu^(-1)}, yw])/4 + 
     (G[{1}, yv^(-1)]*G[{1}, yw]*G[{0, 0, yu^(-1)}, yw])/8 - 
     (G[{1}, yw]^2*G[{0, 0, yu^(-1)}, yw])/16 + 
     (G[{1}, yw]*G[{yu}, yv^(-1)]*G[{0, 0, yu^(-1)}, yw])/8 + 
     (G[{1}, yu^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, 0, yu^(-1)}, yw])/8 + 
     (G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 0, yu^(-1)}, yw])/8 - 
     (G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, 0, yu^(-1)}, yw])/8 + 
     (G[{0, 1}, yu^(-1)]*G[{0, 0, yu^(-1)}, yw])/8 - 
     (G[{0, 1}, yw]*G[{0, 0, yu^(-1)}, yw])/8 + 
     (G[{0, yv^(-1)}, yw]*G[{0, 0, yu^(-1)}, yw])/8 - 
     (G[{1, yu}, yv^(-1)]*G[{0, 0, yu^(-1)}, yw])/8 - 
     (G[{1, 1/(yu*yv)}, yw]*G[{0, 0, yu^(-1)}, yw])/8 - 
     (G[{0}, yu^(-1)]*G[{1}, yv^(-1)]*G[{0, 0, yu}, yv^(-1)])/16 - 
     (G[{0}, yv^(-1)]*G[{1}, yv^(-1)]*G[{0, 0, yu}, yv^(-1)])/16 + 
     (G[{0}, yw]*G[{1}, yv^(-1)]*G[{0, 0, yu}, yv^(-1)])/16 + 
     (G[{1}, yv^(-1)]^2*G[{0, 0, yu}, yv^(-1)])/32 + 
     (G[{0}, yu^(-1)]*G[{1}, yw]*G[{0, 0, yu}, yv^(-1)])/16 + 
     (G[{0}, yv^(-1)]*G[{1}, yw]*G[{0, 0, yu}, yv^(-1)])/16 - 
     (G[{0}, yw]*G[{1}, yw]*G[{0, 0, yu}, yv^(-1)])/16 - 
     (G[{1}, yv^(-1)]*G[{1}, yw]*G[{0, 0, yu}, yv^(-1)])/16 + 
     (G[{1}, yw]^2*G[{0, 0, yu}, yv^(-1)])/32 - 
     (G[{1}, yw]*G[{yu}, yv^(-1)]*G[{0, 0, yu}, yv^(-1)])/16 - 
     (G[{1}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, 0, yu}, yv^(-1)])/16 - 
     (G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 0, yu}, yv^(-1)])/16 + 
     (G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 0, yu}, yv^(-1)])/16 + 
     (G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, 0, yu}, yv^(-1)])/16 + 
     (G[{0, 1}, yw]*G[{0, 0, yu}, yv^(-1)])/16 - 
     (G[{0, yu^(-1)}, yw]*G[{0, 0, yu}, yv^(-1)])/16 + 
     (G[{1, yu^(-1)}, yw]*G[{0, 0, yu}, yv^(-1)])/16 + 
     (G[{1, yu}, yv^(-1)]*G[{0, 0, yu}, yv^(-1)])/16 + 
     (G[{1, 1/(yu*yv)}, yw]*G[{0, 0, yu}, yv^(-1)])/16 - 
     (G[{yu^(-1), 1/(yu*yv)}, yw]*G[{0, 0, yu}, yv^(-1)])/16 - 
     (Pi^2*G[{0, 0, yv^(-1)}, yw])/96 + 
     (G[{1}, yu^(-1)]^2*G[{0, 0, yv^(-1)}, yw])/16 - 
     (G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*G[{0, 0, yv^(-1)}, yw])/8 - 
     (G[{1}, yu^(-1)]*G[{1}, yw]*G[{0, 0, yv^(-1)}, yw])/8 - 
     (G[{1}, yw]^2*G[{0, 0, yv^(-1)}, yw])/16 + 
     (G[{1}, yw]*G[{yu}, yv^(-1)]*G[{0, 0, yv^(-1)}, yw])/8 + 
     (G[{1}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, 0, yv^(-1)}, yw])/8 + 
     (G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 0, yv^(-1)}, yw])/8 - 
     (G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, 0, yv^(-1)}, yw])/8 - 
     (G[{0, 1}, yu^(-1)]*G[{0, 0, yv^(-1)}, yw])/8 - 
     (G[{0, 1}, yw]*G[{0, 0, yv^(-1)}, yw])/8 + 
     (G[{0, yv^(-1)}, yw]*G[{0, 0, yv^(-1)}, yw])/8 + 
     (G[{1, yu}, yv^(-1)]*G[{0, 0, yv^(-1)}, yw])/8 - 
     (G[{1, 1/(yu*yv)}, yw]*G[{0, 0, yv^(-1)}, yw])/8 - 
     (Pi^2*G[{0, 0, 1/(yu*yv)}, yw])/96 - 
     (G[{1}, yu^(-1)]^2*G[{0, 0, 1/(yu*yv)}, yw])/16 - 
     (G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*G[{0, 0, 1/(yu*yv)}, yw])/8 + 
     (G[{1}, yv^(-1)]^2*G[{0, 0, 1/(yu*yv)}, yw])/16 + 
     (G[{1}, yu^(-1)]*G[{1}, yw]*G[{0, 0, 1/(yu*yv)}, yw])/8 - 
     (G[{1}, yv^(-1)]*G[{1}, yw]*G[{0, 0, 1/(yu*yv)}, yw])/8 + 
     (G[{1}, yw]^2*G[{0, 0, 1/(yu*yv)}, yw])/16 + 
     (G[{1}, yu^(-1)]*G[{yu}, yv^(-1)]*G[{0, 0, 1/(yu*yv)}, yw])/4 - 
     (G[{yu}, yv^(-1)]^2*G[{0, 0, 1/(yu*yv)}, yw])/8 - 
     (G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 0, 1/(yu*yv)}, yw])/8 + 
     (G[{0, 1}, yw]*G[{0, 0, 1/(yu*yv)}, yw])/8 - 
     (G[{0, yv^(-1)}, yw]*G[{0, 0, 1/(yu*yv)}, yw])/8 + 
     (G[{1, 1/(yu*yv)}, yw]*G[{0, 0, 1/(yu*yv)}, yw])/8 + 
     (7*Pi^2*G[{0, 1, 1}, yu^(-1)])/384 - 
     (3*G[{0}, yu^(-1)]^2*G[{0, 1, 1}, yu^(-1)])/128 - 
     (3*G[{0}, yu^(-1)]*G[{0}, yv^(-1)]*G[{0, 1, 1}, yu^(-1)])/64 - 
     (3*G[{0}, yv^(-1)]^2*G[{0, 1, 1}, yu^(-1)])/128 + 
     (3*G[{0}, yu^(-1)]*G[{0}, yw]*G[{0, 1, 1}, yu^(-1)])/64 + 
     (3*G[{0}, yv^(-1)]*G[{0}, yw]*G[{0, 1, 1}, yu^(-1)])/64 - 
     (3*G[{0}, yw]^2*G[{0, 1, 1}, yu^(-1)])/128 - 
     (5*G[{0}, yu^(-1)]*G[{1}, yu^(-1)]*G[{0, 1, 1}, yu^(-1)])/64 - 
     (5*G[{0}, yv^(-1)]*G[{1}, yu^(-1)]*G[{0, 1, 1}, yu^(-1)])/64 + 
     (5*G[{0}, yw]*G[{1}, yu^(-1)]*G[{0, 1, 1}, yu^(-1)])/64 + 
     (17*G[{1}, yu^(-1)]^2*G[{0, 1, 1}, yu^(-1)])/128 + 
     (7*G[{0}, yu^(-1)]*G[{1}, yv^(-1)]*G[{0, 1, 1}, yu^(-1)])/64 + 
     (7*G[{0}, yv^(-1)]*G[{1}, yv^(-1)]*G[{0, 1, 1}, yu^(-1)])/64 - 
     (7*G[{0}, yw]*G[{1}, yv^(-1)]*G[{0, 1, 1}, yu^(-1)])/64 + 
     (G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*G[{0, 1, 1}, yu^(-1)])/64 - 
     (17*G[{1}, yv^(-1)]^2*G[{0, 1, 1}, yu^(-1)])/128 - 
     (7*G[{0}, yu^(-1)]*G[{1}, yw]*G[{0, 1, 1}, yu^(-1)])/64 - 
     (7*G[{0}, yv^(-1)]*G[{1}, yw]*G[{0, 1, 1}, yu^(-1)])/64 + 
     (7*G[{0}, yw]*G[{1}, yw]*G[{0, 1, 1}, yu^(-1)])/64 - 
     (G[{1}, yu^(-1)]*G[{1}, yw]*G[{0, 1, 1}, yu^(-1)])/64 + 
     (17*G[{1}, yv^(-1)]*G[{1}, yw]*G[{0, 1, 1}, yu^(-1)])/64 - 
     (G[{1}, yw]^2*G[{0, 1, 1}, yu^(-1)])/8 + 
     (3*G[{1}, yw]*G[{yu}, yv^(-1)]*G[{0, 1, 1}, yu^(-1)])/32 + 
     (5*G[{0}, yu^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, 1, 1}, yu^(-1)])/64 + 
     (5*G[{0}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, 1, 1}, yu^(-1)])/64 - 
     (5*G[{0}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1, 1}, yu^(-1)])/64 - 
     (17*G[{1}, yu^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, 1, 1}, yu^(-1)])/64 + 
     (5*G[{1}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, 1, 1}, yu^(-1)])/64 + 
     (G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1, 1}, yu^(-1)])/64 - 
     (3*G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, 1, 1}, yu^(-1)])/32 + 
     (11*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1, 1}, yu^(-1)])/64 + 
     (3*G[{1/(yu*yv)}, yw]^2*G[{0, 1, 1}, yu^(-1)])/64 + 
     (9*G[{0, 1}, yu^(-1)]*G[{0, 1, 1}, yu^(-1)])/64 - 
     (7*G[{0, 1}, yw]*G[{0, 1, 1}, yu^(-1)])/64 - 
     (G[{0, yu^(-1)}, yw]*G[{0, 1, 1}, yu^(-1)])/64 + 
     (3*G[{0, yv^(-1)}, yw]*G[{0, 1, 1}, yu^(-1)])/64 + 
     (5*G[{0, 1/(yu*yv)}, yw]*G[{0, 1, 1}, yu^(-1)])/64 + 
     (G[{1, yu^(-1)}, yw]*G[{0, 1, 1}, yu^(-1)])/64 - 
     (3*G[{1, yu}, yv^(-1)]*G[{0, 1, 1}, yu^(-1)])/32 - 
     (G[{1, yv^(-1)}, yw]*G[{0, 1, 1}, yu^(-1)])/64 - 
     (3*G[{1, 1/(yu*yv)}, yw]*G[{0, 1, 1}, yu^(-1)])/32 - 
     (G[{yu^(-1), 1/(yu*yv)}, yw]*G[{0, 1, 1}, yu^(-1)])/64 - 
     (11*G[{yv^(-1), 1/(yu*yv)}, yw]*G[{0, 1, 1}, yu^(-1)])/64 + 
     (Pi^2*G[{0, 1, 1}, yv^(-1)])/16 + (G[{0}, yu^(-1)]*G[{1}, yu^(-1)]*
       G[{0, 1, 1}, yv^(-1)])/4 + (G[{0}, yv^(-1)]*G[{1}, yu^(-1)]*
       G[{0, 1, 1}, yv^(-1)])/4 - (G[{0}, yw]*G[{1}, yu^(-1)]*
       G[{0, 1, 1}, yv^(-1)])/4 - (G[{1}, yu^(-1)]^2*G[{0, 1, 1}, yv^(-1)])/
      16 - (G[{0}, yu^(-1)]*G[{1}, yv^(-1)]*G[{0, 1, 1}, yv^(-1)])/16 - 
     (G[{0}, yv^(-1)]*G[{1}, yv^(-1)]*G[{0, 1, 1}, yv^(-1)])/16 + 
     (G[{0}, yw]*G[{1}, yv^(-1)]*G[{0, 1, 1}, yv^(-1)])/16 - 
     (G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*G[{0, 1, 1}, yv^(-1)])/16 - 
     (G[{1}, yv^(-1)]^2*G[{0, 1, 1}, yv^(-1)])/32 + 
     (G[{0}, yu^(-1)]*G[{1}, yw]*G[{0, 1, 1}, yv^(-1)])/16 + 
     (G[{0}, yv^(-1)]*G[{1}, yw]*G[{0, 1, 1}, yv^(-1)])/16 - 
     (G[{0}, yw]*G[{1}, yw]*G[{0, 1, 1}, yv^(-1)])/16 + 
     (G[{1}, yu^(-1)]*G[{1}, yw]*G[{0, 1, 1}, yv^(-1)])/16 + 
     (G[{1}, yv^(-1)]*G[{1}, yw]*G[{0, 1, 1}, yv^(-1)])/16 - 
     (G[{1}, yw]^2*G[{0, 1, 1}, yv^(-1)])/32 + 
     (5*G[{1}, yw]*G[{yu}, yv^(-1)]*G[{0, 1, 1}, yv^(-1)])/16 + 
     (G[{1}, yu^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, 1, 1}, yv^(-1)])/4 - 
     (G[{1}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, 1, 1}, yv^(-1)])/16 + 
     (5*G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1, 1}, yv^(-1)])/16 + 
     (G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1, 1}, yv^(-1)])/16 - 
     (5*G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, 1, 1}, yv^(-1)])/16 - 
     (G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1, 1}, yv^(-1)])/4 + 
     (3*G[{0, 1}, yv^(-1)]*G[{0, 1, 1}, yv^(-1)])/16 - 
     (3*G[{0, 1}, yw]*G[{0, 1, 1}, yv^(-1)])/16 - 
     (G[{0, yu^(-1)}, yw]*G[{0, 1, 1}, yv^(-1)])/16 + 
     (G[{0, yv^(-1)}, yw]*G[{0, 1, 1}, yv^(-1)])/4 + 
     (G[{1, yu^(-1)}, yw]*G[{0, 1, 1}, yv^(-1)])/16 - 
     (5*G[{1, yu}, yv^(-1)]*G[{0, 1, 1}, yv^(-1)])/16 - 
     (5*G[{1, 1/(yu*yv)}, yw]*G[{0, 1, 1}, yv^(-1)])/16 - 
     (G[{yu^(-1), 1/(yu*yv)}, yw]*G[{0, 1, 1}, yv^(-1)])/16 + 
     (G[{yv^(-1), 1/(yu*yv)}, yw]*G[{0, 1, 1}, yv^(-1)])/4 + 
     (Pi^2*G[{0, 1, 1}, yw])/96 + (G[{0}, yu^(-1)]*G[{1}, yu^(-1)]*
       G[{0, 1, 1}, yw])/16 + (G[{0}, yv^(-1)]*G[{1}, yu^(-1)]*
       G[{0, 1, 1}, yw])/16 - (G[{0}, yw]*G[{1}, yu^(-1)]*G[{0, 1, 1}, yw])/
      16 + (G[{0}, yu^(-1)]*G[{1}, yw]*G[{0, 1, 1}, yw])/8 + 
     (G[{0}, yv^(-1)]*G[{1}, yw]*G[{0, 1, 1}, yw])/8 - 
     (G[{0}, yw]*G[{1}, yw]*G[{0, 1, 1}, yw])/8 + 
     (G[{1}, yu^(-1)]*G[{1}, yw]*G[{0, 1, 1}, yw])/16 - 
     (G[{1}, yv^(-1)]*G[{1}, yw]*G[{0, 1, 1}, yw])/8 + 
     (G[{1}, yw]^2*G[{0, 1, 1}, yw])/32 - 
     (G[{0}, yu^(-1)]*G[{yu}, yv^(-1)]*G[{0, 1, 1}, yw])/16 - 
     (G[{0}, yv^(-1)]*G[{yu}, yv^(-1)]*G[{0, 1, 1}, yw])/16 + 
     (G[{0}, yw]*G[{yu}, yv^(-1)]*G[{0, 1, 1}, yw])/16 - 
     (G[{1}, yu^(-1)]*G[{yu}, yv^(-1)]*G[{0, 1, 1}, yw])/8 - 
     (3*G[{1}, yw]*G[{yu}, yv^(-1)]*G[{0, 1, 1}, yw])/16 + 
     (G[{yu}, yv^(-1)]^2*G[{0, 1, 1}, yw])/8 - 
     (G[{0}, yu^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, 1, 1}, yw])/8 - 
     (G[{0}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, 1, 1}, yw])/8 + 
     (G[{0}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1, 1}, yw])/8 + 
     (G[{1}, yu^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, 1, 1}, yw])/8 - 
     (G[{1}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, 1, 1}, yw])/16 - 
     (G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1, 1}, yw])/16 + 
     (G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1, 1}, yw])/16 + 
     (3*G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, 1, 1}, yw])/16 - 
     (G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1, 1}, yw])/8 + 
     (G[{0, 1}, yu^(-1)]*G[{0, 1, 1}, yw])/16 + 
     (G[{0, 1}, yv^(-1)]*G[{0, 1, 1}, yw])/16 - 
     (G[{0, 1}, yw]*G[{0, 1, 1}, yw])/8 - 
     (G[{0, yu^(-1)}, yw]*G[{0, 1, 1}, yw])/16 - 
     (G[{0, yu}, yv^(-1)]*G[{0, 1, 1}, yw])/16 - 
     (G[{0, yv^(-1)}, yw]*G[{0, 1, 1}, yw])/16 + 
     (G[{1, yu^(-1)}, yw]*G[{0, 1, 1}, yw])/16 + 
     (G[{1, 1/(yu*yv)}, yw]*G[{0, 1, 1}, yw])/16 - 
     (G[{yu^(-1), 1/(yu*yv)}, yw]*G[{0, 1, 1}, yw])/16 + 
     (G[{yv^(-1), 1/(yu*yv)}, yw]*G[{0, 1, 1}, yw])/8 - 
     (G[{0}, yu^(-1)]*G[{1}, yu^(-1)]*G[{0, 1, yu^(-1)}, yw])/16 - 
     (G[{0}, yv^(-1)]*G[{1}, yu^(-1)]*G[{0, 1, yu^(-1)}, yw])/16 + 
     (G[{0}, yw]*G[{1}, yu^(-1)]*G[{0, 1, yu^(-1)}, yw])/16 + 
     (G[{1}, yu^(-1)]^2*G[{0, 1, yu^(-1)}, yw])/8 + 
     (G[{0}, yu^(-1)]*G[{1}, yv^(-1)]*G[{0, 1, yu^(-1)}, yw])/16 + 
     (G[{0}, yv^(-1)]*G[{1}, yv^(-1)]*G[{0, 1, yu^(-1)}, yw])/16 - 
     (G[{0}, yw]*G[{1}, yv^(-1)]*G[{0, 1, yu^(-1)}, yw])/16 - 
     (G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*G[{0, 1, yu^(-1)}, yw])/8 - 
     (G[{1}, yv^(-1)]^2*G[{0, 1, yu^(-1)}, yw])/32 - 
     (G[{0}, yu^(-1)]*G[{1}, yw]*G[{0, 1, yu^(-1)}, yw])/16 - 
     (G[{0}, yv^(-1)]*G[{1}, yw]*G[{0, 1, yu^(-1)}, yw])/16 + 
     (G[{0}, yw]*G[{1}, yw]*G[{0, 1, yu^(-1)}, yw])/16 + 
     (G[{1}, yu^(-1)]*G[{1}, yw]*G[{0, 1, yu^(-1)}, yw])/8 + 
     (G[{1}, yv^(-1)]*G[{1}, yw]*G[{0, 1, yu^(-1)}, yw])/16 + 
     (G[{1}, yw]^2*G[{0, 1, yu^(-1)}, yw])/32 - 
     (G[{1}, yw]*G[{yu}, yv^(-1)]*G[{0, 1, yu^(-1)}, yw])/16 + 
     (G[{0}, yu^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, 1, yu^(-1)}, yw])/8 + 
     (G[{0}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, 1, yu^(-1)}, yw])/8 - 
     (G[{0}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1, yu^(-1)}, yw])/8 - 
     (G[{1}, yu^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, 1, yu^(-1)}, yw])/4 - 
     (G[{1}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, 1, yu^(-1)}, yw])/16 - 
     (G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1, yu^(-1)}, yw])/16 - 
     (G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1, yu^(-1)}, yw])/16 + 
     (G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, 1, yu^(-1)}, yw])/16 + 
     (G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1, yu^(-1)}, yw])/8 - 
     (G[{0, 1}, yu^(-1)]*G[{0, 1, yu^(-1)}, yw])/16 + 
     (G[{0, 1}, yw]*G[{0, 1, yu^(-1)}, yw])/16 + 
     (G[{0, yu^(-1)}, yw]*G[{0, 1, yu^(-1)}, yw])/16 - 
     (G[{0, yv^(-1)}, yw]*G[{0, 1, yu^(-1)}, yw])/16 - 
     (G[{1, yu^(-1)}, yw]*G[{0, 1, yu^(-1)}, yw])/16 + 
     (G[{1, yu}, yv^(-1)]*G[{0, 1, yu^(-1)}, yw])/16 + 
     (G[{1, 1/(yu*yv)}, yw]*G[{0, 1, yu^(-1)}, yw])/16 + 
     (G[{yu^(-1), 1/(yu*yv)}, yw]*G[{0, 1, yu^(-1)}, yw])/16 - 
     (G[{yv^(-1), 1/(yu*yv)}, yw]*G[{0, 1, yu^(-1)}, yw])/8 - 
     (Pi^2*G[{0, 1, yu}, yv^(-1)])/24 - (G[{0}, yu^(-1)]*G[{1}, yu^(-1)]*
       G[{0, 1, yu}, yv^(-1)])/8 - (G[{0}, yv^(-1)]*G[{1}, yu^(-1)]*
       G[{0, 1, yu}, yv^(-1)])/8 + (G[{0}, yw]*G[{1}, yu^(-1)]*
       G[{0, 1, yu}, yv^(-1)])/8 + (G[{1}, yu^(-1)]^2*G[{0, 1, yu}, yv^(-1)])/
      32 + (G[{0}, yu^(-1)]*G[{1}, yv^(-1)]*G[{0, 1, yu}, yv^(-1)])/16 + 
     (G[{0}, yv^(-1)]*G[{1}, yv^(-1)]*G[{0, 1, yu}, yv^(-1)])/16 - 
     (G[{0}, yw]*G[{1}, yv^(-1)]*G[{0, 1, yu}, yv^(-1)])/16 - 
     (G[{0}, yu^(-1)]*G[{1}, yw]*G[{0, 1, yu}, yv^(-1)])/16 - 
     (G[{0}, yv^(-1)]*G[{1}, yw]*G[{0, 1, yu}, yv^(-1)])/16 + 
     (G[{0}, yw]*G[{1}, yw]*G[{0, 1, yu}, yv^(-1)])/16 - 
     (G[{1}, yw]*G[{yu}, yv^(-1)]*G[{0, 1, yu}, yv^(-1)])/4 - 
     (G[{0}, yu^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, 1, yu}, yv^(-1)])/16 - 
     (G[{0}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, 1, yu}, yv^(-1)])/16 + 
     (G[{0}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1, yu}, yv^(-1)])/16 - 
     (G[{1}, yu^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, 1, yu}, yv^(-1)])/4 + 
     (G[{1}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, 1, yu}, yv^(-1)])/8 - 
     (G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1, yu}, yv^(-1)])/4 - 
     (G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1, yu}, yv^(-1)])/8 + 
     (G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, 1, yu}, yv^(-1)])/4 + 
     (G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1, yu}, yv^(-1)])/4 - 
     (G[{0, 1}, yu^(-1)]*G[{0, 1, yu}, yv^(-1)])/16 - 
     (G[{0, 1}, yv^(-1)]*G[{0, 1, yu}, yv^(-1)])/16 + 
     (G[{0, 1}, yw]*G[{0, 1, yu}, yv^(-1)])/16 + 
     (G[{0, yu^(-1)}, yw]*G[{0, 1, yu}, yv^(-1)])/8 - 
     (G[{0, yv^(-1)}, yw]*G[{0, 1, yu}, yv^(-1)])/8 - 
     (G[{0, 1/(yu*yv)}, yw]*G[{0, 1, yu}, yv^(-1)])/16 - 
     (G[{1, yu^(-1)}, yw]*G[{0, 1, yu}, yv^(-1)])/8 + 
     (G[{1, yu}, yv^(-1)]*G[{0, 1, yu}, yv^(-1)])/4 + 
     (G[{1, 1/(yu*yv)}, yw]*G[{0, 1, yu}, yv^(-1)])/4 + 
     (G[{yu^(-1), 1/(yu*yv)}, yw]*G[{0, 1, yu}, yv^(-1)])/8 - 
     (G[{yv^(-1), 1/(yu*yv)}, yw]*G[{0, 1, yu}, yv^(-1)])/4 - 
     (Pi^2*G[{0, 1, yv^(-1)}, yw])/32 - (G[{0}, yu^(-1)]*G[{1}, yu^(-1)]*
       G[{0, 1, yv^(-1)}, yw])/8 - (G[{0}, yv^(-1)]*G[{1}, yu^(-1)]*
       G[{0, 1, yv^(-1)}, yw])/8 + (G[{0}, yw]*G[{1}, yu^(-1)]*
       G[{0, 1, yv^(-1)}, yw])/8 + (3*G[{1}, yu^(-1)]^2*
       G[{0, 1, yv^(-1)}, yw])/32 + (G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*
       G[{0, 1, yv^(-1)}, yw])/16 - (3*G[{0}, yu^(-1)]*G[{1}, yw]*
       G[{0, 1, yv^(-1)}, yw])/16 - (3*G[{0}, yv^(-1)]*G[{1}, yw]*
       G[{0, 1, yv^(-1)}, yw])/16 + (3*G[{0}, yw]*G[{1}, yw]*
       G[{0, 1, yv^(-1)}, yw])/16 + (G[{1}, yu^(-1)]*G[{1}, yw]*
       G[{0, 1, yv^(-1)}, yw])/4 + (3*G[{1}, yv^(-1)]*G[{1}, yw]*
       G[{0, 1, yv^(-1)}, yw])/16 + (G[{1}, yw]^2*G[{0, 1, yv^(-1)}, yw])/
      32 + (G[{0}, yu^(-1)]*G[{yu}, yv^(-1)]*G[{0, 1, yv^(-1)}, yw])/8 + 
     (G[{0}, yv^(-1)]*G[{yu}, yv^(-1)]*G[{0, 1, yv^(-1)}, yw])/8 - 
     (G[{0}, yw]*G[{yu}, yv^(-1)]*G[{0, 1, yv^(-1)}, yw])/8 - 
     (G[{1}, yw]*G[{yu}, yv^(-1)]*G[{0, 1, yv^(-1)}, yw])/16 - 
     (G[{yu}, yv^(-1)]^2*G[{0, 1, yv^(-1)}, yw])/8 + 
     (G[{0}, yu^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, 1, yv^(-1)}, yw])/8 + 
     (G[{0}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, 1, yv^(-1)}, yw])/8 - 
     (G[{0}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1, yv^(-1)}, yw])/8 - 
     (G[{1}, yu^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, 1, yv^(-1)}, yw])/4 - 
     (G[{1}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, 1, yv^(-1)}, yw])/16 - 
     (G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1, yv^(-1)}, yw])/16 - 
     (G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1, yv^(-1)}, yw])/16 + 
     (G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, 1, yv^(-1)}, yw])/16 + 
     (G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1, yv^(-1)}, yw])/8 - 
     (G[{0, 1}, yu^(-1)]*G[{0, 1, yv^(-1)}, yw])/16 - 
     (G[{0, 1}, yv^(-1)]*G[{0, 1, yv^(-1)}, yw])/8 + 
     (G[{0, yu^(-1)}, yw]*G[{0, 1, yv^(-1)}, yw])/16 + 
     (G[{0, yu}, yv^(-1)]*G[{0, 1, yv^(-1)}, yw])/8 - 
     (G[{0, yv^(-1)}, yw]*G[{0, 1, yv^(-1)}, yw])/16 - 
     (G[{1, yu^(-1)}, yw]*G[{0, 1, yv^(-1)}, yw])/16 - 
     (G[{1, yu}, yv^(-1)]*G[{0, 1, yv^(-1)}, yw])/16 + 
     (G[{1, 1/(yu*yv)}, yw]*G[{0, 1, yv^(-1)}, yw])/16 + 
     (G[{yu^(-1), 1/(yu*yv)}, yw]*G[{0, 1, yv^(-1)}, yw])/16 - 
     (G[{yv^(-1), 1/(yu*yv)}, yw]*G[{0, 1, yv^(-1)}, yw])/8 - 
     (Pi^2*G[{0, 1, 1/(yu*yv)}, yw])/96 + 
     (G[{0}, yu^(-1)]*G[{1}, yu^(-1)]*G[{0, 1, 1/(yu*yv)}, yw])/16 + 
     (G[{0}, yv^(-1)]*G[{1}, yu^(-1)]*G[{0, 1, 1/(yu*yv)}, yw])/16 - 
     (G[{0}, yw]*G[{1}, yu^(-1)]*G[{0, 1, 1/(yu*yv)}, yw])/16 + 
     (G[{0}, yu^(-1)]*G[{1}, yw]*G[{0, 1, 1/(yu*yv)}, yw])/16 + 
     (G[{0}, yv^(-1)]*G[{1}, yw]*G[{0, 1, 1/(yu*yv)}, yw])/16 - 
     (G[{0}, yw]*G[{1}, yw]*G[{0, 1, 1/(yu*yv)}, yw])/16 + 
     (G[{1}, yu^(-1)]*G[{1}, yw]*G[{0, 1, 1/(yu*yv)}, yw])/16 - 
     (G[{1}, yv^(-1)]*G[{1}, yw]*G[{0, 1, 1/(yu*yv)}, yw])/8 + 
     (G[{1}, yw]^2*G[{0, 1, 1/(yu*yv)}, yw])/32 - 
     (G[{0}, yu^(-1)]*G[{yu}, yv^(-1)]*G[{0, 1, 1/(yu*yv)}, yw])/16 - 
     (G[{0}, yv^(-1)]*G[{yu}, yv^(-1)]*G[{0, 1, 1/(yu*yv)}, yw])/16 + 
     (G[{0}, yw]*G[{yu}, yv^(-1)]*G[{0, 1, 1/(yu*yv)}, yw])/16 - 
     (G[{1}, yu^(-1)]*G[{yu}, yv^(-1)]*G[{0, 1, 1/(yu*yv)}, yw])/8 - 
     (G[{1}, yw]*G[{yu}, yv^(-1)]*G[{0, 1, 1/(yu*yv)}, yw])/16 + 
     (G[{yu}, yv^(-1)]^2*G[{0, 1, 1/(yu*yv)}, yw])/8 - 
     (G[{0}, yu^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, 1, 1/(yu*yv)}, yw])/16 - 
     (G[{0}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, 1, 1/(yu*yv)}, yw])/16 + 
     (G[{0}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1, 1/(yu*yv)}, yw])/16 + 
     (G[{1}, yu^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, 1, 1/(yu*yv)}, yw])/8 - 
     (G[{1}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, 1, 1/(yu*yv)}, yw])/16 - 
     (G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1, 1/(yu*yv)}, yw])/16 + 
     (G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1, 1/(yu*yv)}, yw])/16 + 
     (G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, 1, 1/(yu*yv)}, yw])/16 - 
     (G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1, 1/(yu*yv)}, yw])/8 - 
     (G[{0, 1}, yu^(-1)]*G[{0, 1, 1/(yu*yv)}, yw])/16 - 
     (G[{0, 1}, yv^(-1)]*G[{0, 1, 1/(yu*yv)}, yw])/16 - 
     (G[{0, yu^(-1)}, yw]*G[{0, 1, 1/(yu*yv)}, yw])/16 + 
     (G[{0, yu}, yv^(-1)]*G[{0, 1, 1/(yu*yv)}, yw])/16 + 
     (G[{0, yv^(-1)}, yw]*G[{0, 1, 1/(yu*yv)}, yw])/16 - 
     (G[{0, 1/(yu*yv)}, yw]*G[{0, 1, 1/(yu*yv)}, yw])/16 + 
     (G[{1, yu^(-1)}, yw]*G[{0, 1, 1/(yu*yv)}, yw])/16 + 
     (G[{1, 1/(yu*yv)}, yw]*G[{0, 1, 1/(yu*yv)}, yw])/16 - 
     (G[{yu^(-1), 1/(yu*yv)}, yw]*G[{0, 1, 1/(yu*yv)}, yw])/16 + 
     (G[{yv^(-1), 1/(yu*yv)}, yw]*G[{0, 1, 1/(yu*yv)}, yw])/8 + 
     (Pi^2*G[{0, yu^(-1), 1}, yw])/24 + 
     (G[{1}, yu^(-1)]^2*G[{0, yu^(-1), 1}, yw])/32 + 
     (G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*G[{0, yu^(-1), 1}, yw])/16 - 
     (G[{1}, yv^(-1)]^2*G[{0, yu^(-1), 1}, yw])/32 - 
     (G[{1}, yu^(-1)]*G[{1}, yw]*G[{0, yu^(-1), 1}, yw])/16 + 
     (G[{1}, yv^(-1)]*G[{1}, yw]*G[{0, yu^(-1), 1}, yw])/8 - 
     (G[{1}, yw]^2*G[{0, yu^(-1), 1}, yw])/32 - 
     (G[{1}, yu^(-1)]*G[{yu}, yv^(-1)]*G[{0, yu^(-1), 1}, yw])/8 - 
     (G[{1}, yw]*G[{yu}, yv^(-1)]*G[{0, yu^(-1), 1}, yw])/16 + 
     (G[{yu}, yv^(-1)]^2*G[{0, yu^(-1), 1}, yw])/16 + 
     (G[{0}, yu^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1), 1}, yw])/16 + 
     (G[{0}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1), 1}, yw])/16 - 
     (G[{0}, yw]*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1), 1}, yw])/16 - 
     (G[{1}, yu^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1), 1}, yw])/8 + 
     (G[{1}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1), 1}, yw])/16 + 
     (G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1), 1}, yw])/16 - 
     (G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1), 1}, yw])/16 - 
     (G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1), 1}, yw])/16 + 
     (G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1), 1}, yw])/8 + 
     (G[{0, 1}, yu^(-1)]*G[{0, yu^(-1), 1}, yw])/16 + 
     (G[{0, 1}, yv^(-1)]*G[{0, yu^(-1), 1}, yw])/16 + 
     (G[{0, 1}, yw]*G[{0, yu^(-1), 1}, yw])/16 - 
     (G[{0, yu^(-1)}, yw]*G[{0, yu^(-1), 1}, yw])/16 - 
     (G[{0, yu}, yv^(-1)]*G[{0, yu^(-1), 1}, yw])/16 - 
     (G[{0, yv^(-1)}, yw]*G[{0, yu^(-1), 1}, yw])/16 + 
     (G[{0, 1/(yu*yv)}, yw]*G[{0, yu^(-1), 1}, yw])/16 - 
     (G[{1, yu^(-1)}, yw]*G[{0, yu^(-1), 1}, yw])/16 - 
     (G[{1, 1/(yu*yv)}, yw]*G[{0, yu^(-1), 1}, yw])/16 + 
     (G[{yu^(-1), 1/(yu*yv)}, yw]*G[{0, yu^(-1), 1}, yw])/16 - 
     (G[{yv^(-1), 1/(yu*yv)}, yw]*G[{0, yu^(-1), 1}, yw])/8 - 
     (Pi^2*G[{0, yu^(-1), yu^(-1)}, yw])/32 - 
     (5*G[{1}, yu^(-1)]^2*G[{0, yu^(-1), yu^(-1)}, yw])/32 + 
     (5*G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*G[{0, yu^(-1), yu^(-1)}, yw])/16 - 
     (G[{1}, yv^(-1)]^2*G[{0, yu^(-1), yu^(-1)}, yw])/16 - 
     (G[{0}, yu^(-1)]*G[{1}, yw]*G[{0, yu^(-1), yu^(-1)}, yw])/16 - 
     (G[{0}, yv^(-1)]*G[{1}, yw]*G[{0, yu^(-1), yu^(-1)}, yw])/16 + 
     (G[{0}, yw]*G[{1}, yw]*G[{0, yu^(-1), yu^(-1)}, yw])/16 - 
     (G[{1}, yu^(-1)]*G[{1}, yw]*G[{0, yu^(-1), yu^(-1)}, yw])/8 + 
     (3*G[{1}, yv^(-1)]*G[{1}, yw]*G[{0, yu^(-1), yu^(-1)}, yw])/16 - 
     (G[{1}, yw]^2*G[{0, yu^(-1), yu^(-1)}, yw])/32 + 
     (G[{1}, yw]*G[{yu}, yv^(-1)]*G[{0, yu^(-1), yu^(-1)}, yw])/16 - 
     (G[{0}, yu^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1), yu^(-1)}, yw])/16 - 
     (G[{0}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1), yu^(-1)}, yw])/16 + 
     (G[{0}, yw]*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1), yu^(-1)}, yw])/16 + 
     (G[{1}, yu^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1), yu^(-1)}, yw])/4 - 
     (G[{1}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1), yu^(-1)}, yw])/16 + 
     (G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1), yu^(-1)}, yw])/16 + 
     (G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1), yu^(-1)}, yw])/16 - 
     (G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1), yu^(-1)}, yw])/16 - 
     (G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1), yu^(-1)}, yw])/8 + 
     (G[{0, 1}, yu^(-1)]*G[{0, yu^(-1), yu^(-1)}, yw])/16 - 
     (G[{0, 1}, yv^(-1)]*G[{0, yu^(-1), yu^(-1)}, yw])/8 - 
     (G[{0, 1}, yw]*G[{0, yu^(-1), yu^(-1)}, yw])/8 + 
     (G[{0, yu^(-1)}, yw]*G[{0, yu^(-1), yu^(-1)}, yw])/8 + 
     (G[{0, yu}, yv^(-1)]*G[{0, yu^(-1), yu^(-1)}, yw])/8 + 
     (3*G[{0, yv^(-1)}, yw]*G[{0, yu^(-1), yu^(-1)}, yw])/16 - 
     (G[{0, 1/(yu*yv)}, yw]*G[{0, yu^(-1), yu^(-1)}, yw])/16 + 
     (G[{1, yu^(-1)}, yw]*G[{0, yu^(-1), yu^(-1)}, yw])/16 - 
     (3*G[{1, yu}, yv^(-1)]*G[{0, yu^(-1), yu^(-1)}, yw])/16 - 
     (G[{1, 1/(yu*yv)}, yw]*G[{0, yu^(-1), yu^(-1)}, yw])/16 - 
     (G[{yu^(-1), 1/(yu*yv)}, yw]*G[{0, yu^(-1), yu^(-1)}, yw])/16 + 
     (G[{yv^(-1), 1/(yu*yv)}, yw]*G[{0, yu^(-1), yu^(-1)}, yw])/8 + 
     (Pi^2*G[{0, yu^(-1), yv^(-1)}, yw])/32 + 
     (G[{0}, yu^(-1)]*G[{1}, yu^(-1)]*G[{0, yu^(-1), yv^(-1)}, yw])/8 + 
     (G[{0}, yv^(-1)]*G[{1}, yu^(-1)]*G[{0, yu^(-1), yv^(-1)}, yw])/8 - 
     (G[{0}, yw]*G[{1}, yu^(-1)]*G[{0, yu^(-1), yv^(-1)}, yw])/8 - 
     (3*G[{1}, yu^(-1)]^2*G[{0, yu^(-1), yv^(-1)}, yw])/32 - 
     (G[{0}, yu^(-1)]*G[{1}, yv^(-1)]*G[{0, yu^(-1), yv^(-1)}, yw])/8 - 
     (G[{0}, yv^(-1)]*G[{1}, yv^(-1)]*G[{0, yu^(-1), yv^(-1)}, yw])/8 + 
     (G[{0}, yw]*G[{1}, yv^(-1)]*G[{0, yu^(-1), yv^(-1)}, yw])/8 - 
     (G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*G[{0, yu^(-1), yv^(-1)}, yw])/16 + 
     (G[{1}, yv^(-1)]^2*G[{0, yu^(-1), yv^(-1)}, yw])/8 + 
     (G[{0}, yu^(-1)]*G[{1}, yw]*G[{0, yu^(-1), yv^(-1)}, yw])/8 + 
     (G[{0}, yv^(-1)]*G[{1}, yw]*G[{0, yu^(-1), yv^(-1)}, yw])/8 - 
     (G[{0}, yw]*G[{1}, yw]*G[{0, yu^(-1), yv^(-1)}, yw])/8 - 
     (G[{1}, yu^(-1)]*G[{1}, yw]*G[{0, yu^(-1), yv^(-1)}, yw])/8 - 
     (3*G[{1}, yv^(-1)]*G[{1}, yw]*G[{0, yu^(-1), yv^(-1)}, yw])/16 - 
     (G[{1}, yw]^2*G[{0, yu^(-1), yv^(-1)}, yw])/32 + 
     (G[{1}, yw]*G[{yu}, yv^(-1)]*G[{0, yu^(-1), yv^(-1)}, yw])/16 - 
     (G[{0}, yu^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1), yv^(-1)}, yw])/8 - 
     (G[{0}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1), yv^(-1)}, yw])/8 + 
     (G[{0}, yw]*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1), yv^(-1)}, yw])/8 + 
     (G[{1}, yu^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1), yv^(-1)}, yw])/4 + 
     (G[{1}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1), yv^(-1)}, yw])/16 + 
     (G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1), yv^(-1)}, yw])/16 + 
     (G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1), yv^(-1)}, yw])/16 - 
     (G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1), yv^(-1)}, yw])/16 - 
     (G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1), yv^(-1)}, yw])/8 + 
     (G[{0, 1}, yu^(-1)]*G[{0, yu^(-1), yv^(-1)}, yw])/16 + 
     (G[{0, 1}, yv^(-1)]*G[{0, yu^(-1), yv^(-1)}, yw])/8 - 
     (G[{0, yu}, yv^(-1)]*G[{0, yu^(-1), yv^(-1)}, yw])/8 + 
     (G[{0, yv^(-1)}, yw]*G[{0, yu^(-1), yv^(-1)}, yw])/16 + 
     (G[{1, yu^(-1)}, yw]*G[{0, yu^(-1), yv^(-1)}, yw])/16 + 
     (G[{1, yu}, yv^(-1)]*G[{0, yu^(-1), yv^(-1)}, yw])/16 - 
     (G[{1, 1/(yu*yv)}, yw]*G[{0, yu^(-1), yv^(-1)}, yw])/16 - 
     (G[{yu^(-1), 1/(yu*yv)}, yw]*G[{0, yu^(-1), yv^(-1)}, yw])/16 + 
     (G[{yv^(-1), 1/(yu*yv)}, yw]*G[{0, yu^(-1), yv^(-1)}, yw])/8 + 
     (Pi^2*G[{0, yu^(-1), 1/(yu*yv)}, yw])/96 - 
     (G[{0}, yu^(-1)]*G[{1}, yu^(-1)]*G[{0, yu^(-1), 1/(yu*yv)}, yw])/16 - 
     (G[{0}, yv^(-1)]*G[{1}, yu^(-1)]*G[{0, yu^(-1), 1/(yu*yv)}, yw])/16 + 
     (G[{0}, yw]*G[{1}, yu^(-1)]*G[{0, yu^(-1), 1/(yu*yv)}, yw])/16 + 
     (G[{0}, yu^(-1)]*G[{1}, yv^(-1)]*G[{0, yu^(-1), 1/(yu*yv)}, yw])/16 + 
     (G[{0}, yv^(-1)]*G[{1}, yv^(-1)]*G[{0, yu^(-1), 1/(yu*yv)}, yw])/16 - 
     (G[{0}, yw]*G[{1}, yv^(-1)]*G[{0, yu^(-1), 1/(yu*yv)}, yw])/16 - 
     (G[{1}, yv^(-1)]^2*G[{0, yu^(-1), 1/(yu*yv)}, yw])/16 - 
     (3*G[{1}, yu^(-1)]*G[{1}, yw]*G[{0, yu^(-1), 1/(yu*yv)}, yw])/16 - 
     (G[{1}, yw]^2*G[{0, yu^(-1), 1/(yu*yv)}, yw])/32 + 
     (G[{1}, yu^(-1)]*G[{yu}, yv^(-1)]*G[{0, yu^(-1), 1/(yu*yv)}, yw])/8 + 
     (3*G[{1}, yw]*G[{yu}, yv^(-1)]*G[{0, yu^(-1), 1/(yu*yv)}, yw])/16 - 
     (G[{yu}, yv^(-1)]^2*G[{0, yu^(-1), 1/(yu*yv)}, yw])/16 + 
     (G[{0}, yu^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1), 1/(yu*yv)}, yw])/16 + 
     (G[{0}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1), 1/(yu*yv)}, yw])/16 - 
     (G[{0}, yw]*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1), 1/(yu*yv)}, yw])/16 - 
     (G[{1}, yu^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1), 1/(yu*yv)}, yw])/8 + 
     (G[{1}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1), 1/(yu*yv)}, yw])/16 + 
     (G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1), 1/(yu*yv)}, yw])/16 - 
     (G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1), 1/(yu*yv)}, yw])/
      16 - (G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1), 1/(yu*yv)}, 
        yw])/16 + (G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*
       G[{0, yu^(-1), 1/(yu*yv)}, yw])/8 + 
     (G[{0, 1}, yu^(-1)]*G[{0, yu^(-1), 1/(yu*yv)}, yw])/16 + 
     (G[{0, 1}, yv^(-1)]*G[{0, yu^(-1), 1/(yu*yv)}, yw])/16 - 
     (G[{0, yu}, yv^(-1)]*G[{0, yu^(-1), 1/(yu*yv)}, yw])/16 - 
     (G[{0, yv^(-1)}, yw]*G[{0, yu^(-1), 1/(yu*yv)}, yw])/16 + 
     (G[{0, 1/(yu*yv)}, yw]*G[{0, yu^(-1), 1/(yu*yv)}, yw])/16 - 
     (G[{1, yu^(-1)}, yw]*G[{0, yu^(-1), 1/(yu*yv)}, yw])/16 - 
     (G[{1, 1/(yu*yv)}, yw]*G[{0, yu^(-1), 1/(yu*yv)}, yw])/16 + 
     (G[{yu^(-1), 1/(yu*yv)}, yw]*G[{0, yu^(-1), 1/(yu*yv)}, yw])/16 - 
     (G[{yv^(-1), 1/(yu*yv)}, yw]*G[{0, yu^(-1), 1/(yu*yv)}, yw])/8 - 
     (Pi^2*G[{0, yu, 1}, yv^(-1)])/24 - (G[{0}, yu^(-1)]*G[{1}, yu^(-1)]*
       G[{0, yu, 1}, yv^(-1)])/8 - (G[{0}, yv^(-1)]*G[{1}, yu^(-1)]*
       G[{0, yu, 1}, yv^(-1)])/8 + (G[{0}, yw]*G[{1}, yu^(-1)]*
       G[{0, yu, 1}, yv^(-1)])/8 + (G[{1}, yu^(-1)]^2*G[{0, yu, 1}, yv^(-1)])/
      32 + (G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*G[{0, yu, 1}, yv^(-1)])/16 + 
     (G[{1}, yv^(-1)]^2*G[{0, yu, 1}, yv^(-1)])/32 - 
     (G[{1}, yu^(-1)]*G[{1}, yw]*G[{0, yu, 1}, yv^(-1)])/16 - 
     (G[{1}, yv^(-1)]*G[{1}, yw]*G[{0, yu, 1}, yv^(-1)])/16 + 
     (G[{1}, yw]^2*G[{0, yu, 1}, yv^(-1)])/32 - 
     (5*G[{1}, yw]*G[{yu}, yv^(-1)]*G[{0, yu, 1}, yv^(-1)])/16 - 
     (G[{0}, yu^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, yu, 1}, yv^(-1)])/16 - 
     (G[{0}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, yu, 1}, yv^(-1)])/16 + 
     (G[{0}, yw]*G[{1/(yu*yv)}, yw]*G[{0, yu, 1}, yv^(-1)])/16 - 
     (G[{1}, yu^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, yu, 1}, yv^(-1)])/4 + 
     (G[{1}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, yu, 1}, yv^(-1)])/16 - 
     (5*G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{0, yu, 1}, yv^(-1)])/16 - 
     (G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{0, yu, 1}, yv^(-1)])/16 + 
     (5*G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, yu, 1}, yv^(-1)])/16 + 
     (G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{0, yu, 1}, yv^(-1)])/4 - 
     (G[{0, 1}, yu^(-1)]*G[{0, yu, 1}, yv^(-1)])/16 - 
     (G[{0, 1}, yv^(-1)]*G[{0, yu, 1}, yv^(-1)])/8 + 
     (G[{0, 1}, yw]*G[{0, yu, 1}, yv^(-1)])/8 + 
     (G[{0, yu^(-1)}, yw]*G[{0, yu, 1}, yv^(-1)])/16 + 
     (G[{0, yu}, yv^(-1)]*G[{0, yu, 1}, yv^(-1)])/8 - 
     (G[{0, yv^(-1)}, yw]*G[{0, yu, 1}, yv^(-1)])/8 - 
     (G[{0, 1/(yu*yv)}, yw]*G[{0, yu, 1}, yv^(-1)])/16 - 
     (G[{1, yu^(-1)}, yw]*G[{0, yu, 1}, yv^(-1)])/16 + 
     (5*G[{1, yu}, yv^(-1)]*G[{0, yu, 1}, yv^(-1)])/16 + 
     (5*G[{1, 1/(yu*yv)}, yw]*G[{0, yu, 1}, yv^(-1)])/16 + 
     (G[{yu^(-1), 1/(yu*yv)}, yw]*G[{0, yu, 1}, yv^(-1)])/16 - 
     (G[{yv^(-1), 1/(yu*yv)}, yw]*G[{0, yu, 1}, yv^(-1)])/4 + 
     (G[{1}, yw]*G[{yu}, yv^(-1)]*G[{0, yu, yu}, yv^(-1)])/4 + 
     (G[{0}, yu^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, yu, yu}, yv^(-1)])/8 + 
     (G[{0}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, yu, yu}, yv^(-1)])/8 - 
     (G[{0}, yw]*G[{1/(yu*yv)}, yw]*G[{0, yu, yu}, yv^(-1)])/8 + 
     (G[{1}, yu^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, yu, yu}, yv^(-1)])/4 - 
     (G[{1}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, yu, yu}, yv^(-1)])/8 + 
     (G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{0, yu, yu}, yv^(-1)])/4 + 
     (G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{0, yu, yu}, yv^(-1)])/8 - 
     (G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, yu, yu}, yv^(-1)])/4 - 
     (G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{0, yu, yu}, yv^(-1)])/4 - 
     (G[{0, yu^(-1)}, yw]*G[{0, yu, yu}, yv^(-1)])/8 + 
     (G[{0, 1/(yu*yv)}, yw]*G[{0, yu, yu}, yv^(-1)])/8 + 
     (G[{1, yu^(-1)}, yw]*G[{0, yu, yu}, yv^(-1)])/8 - 
     (G[{1, yu}, yv^(-1)]*G[{0, yu, yu}, yv^(-1)])/4 - 
     (G[{1, 1/(yu*yv)}, yw]*G[{0, yu, yu}, yv^(-1)])/4 - 
     (G[{yu^(-1), 1/(yu*yv)}, yw]*G[{0, yu, yu}, yv^(-1)])/8 + 
     (G[{yv^(-1), 1/(yu*yv)}, yw]*G[{0, yu, yu}, yv^(-1)])/4 - 
     (G[{1}, yu^(-1)]^2*G[{0, yv^(-1), 1}, yw])/16 - 
     (G[{0}, yu^(-1)]*G[{1}, yw]*G[{0, yv^(-1), 1}, yw])/8 - 
     (G[{0}, yv^(-1)]*G[{1}, yw]*G[{0, yv^(-1), 1}, yw])/8 + 
     (G[{0}, yw]*G[{1}, yw]*G[{0, yv^(-1), 1}, yw])/8 - 
     (G[{1}, yu^(-1)]*G[{1}, yw]*G[{0, yv^(-1), 1}, yw])/16 + 
     (G[{1}, yv^(-1)]*G[{1}, yw]*G[{0, yv^(-1), 1}, yw])/8 - 
     (G[{1}, yw]^2*G[{0, yv^(-1), 1}, yw])/32 + 
     (G[{1}, yu^(-1)]*G[{yu}, yv^(-1)]*G[{0, yv^(-1), 1}, yw])/8 + 
     (3*G[{1}, yw]*G[{yu}, yv^(-1)]*G[{0, yv^(-1), 1}, yw])/16 - 
     (G[{yu}, yv^(-1)]^2*G[{0, yv^(-1), 1}, yw])/16 + 
     (G[{0}, yu^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, yv^(-1), 1}, yw])/16 + 
     (G[{0}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, yv^(-1), 1}, yw])/16 - 
     (G[{0}, yw]*G[{1/(yu*yv)}, yw]*G[{0, yv^(-1), 1}, yw])/16 - 
     (G[{1}, yu^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, yv^(-1), 1}, yw])/8 + 
     (G[{1}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, yv^(-1), 1}, yw])/16 + 
     (G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{0, yv^(-1), 1}, yw])/16 - 
     (G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{0, yv^(-1), 1}, yw])/16 - 
     (G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, yv^(-1), 1}, yw])/16 + 
     (G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{0, yv^(-1), 1}, yw])/8 + 
     (G[{0, 1}, yw]*G[{0, yv^(-1), 1}, yw])/16 - 
     (G[{0, yu^(-1)}, yw]*G[{0, yv^(-1), 1}, yw])/16 - 
     (G[{0, yv^(-1)}, yw]*G[{0, yv^(-1), 1}, yw])/16 + 
     (G[{0, 1/(yu*yv)}, yw]*G[{0, yv^(-1), 1}, yw])/16 - 
     (G[{1, yu^(-1)}, yw]*G[{0, yv^(-1), 1}, yw])/16 - 
     (G[{1, 1/(yu*yv)}, yw]*G[{0, yv^(-1), 1}, yw])/16 + 
     (G[{yu^(-1), 1/(yu*yv)}, yw]*G[{0, yv^(-1), 1}, yw])/16 - 
     (G[{yv^(-1), 1/(yu*yv)}, yw]*G[{0, yv^(-1), 1}, yw])/8 + 
     (Pi^2*G[{0, yv^(-1), yu^(-1)}, yw])/32 + 
     (G[{0}, yu^(-1)]*G[{1}, yu^(-1)]*G[{0, yv^(-1), yu^(-1)}, yw])/8 + 
     (G[{0}, yv^(-1)]*G[{1}, yu^(-1)]*G[{0, yv^(-1), yu^(-1)}, yw])/8 - 
     (G[{0}, yw]*G[{1}, yu^(-1)]*G[{0, yv^(-1), yu^(-1)}, yw])/8 - 
     (3*G[{1}, yu^(-1)]^2*G[{0, yv^(-1), yu^(-1)}, yw])/32 - 
     (G[{0}, yu^(-1)]*G[{1}, yv^(-1)]*G[{0, yv^(-1), yu^(-1)}, yw])/8 - 
     (G[{0}, yv^(-1)]*G[{1}, yv^(-1)]*G[{0, yv^(-1), yu^(-1)}, yw])/8 + 
     (G[{0}, yw]*G[{1}, yv^(-1)]*G[{0, yv^(-1), yu^(-1)}, yw])/8 - 
     (G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*G[{0, yv^(-1), yu^(-1)}, yw])/16 + 
     (G[{1}, yv^(-1)]^2*G[{0, yv^(-1), yu^(-1)}, yw])/8 + 
     (G[{0}, yu^(-1)]*G[{1}, yw]*G[{0, yv^(-1), yu^(-1)}, yw])/8 + 
     (G[{0}, yv^(-1)]*G[{1}, yw]*G[{0, yv^(-1), yu^(-1)}, yw])/8 - 
     (G[{0}, yw]*G[{1}, yw]*G[{0, yv^(-1), yu^(-1)}, yw])/8 - 
     (G[{1}, yu^(-1)]*G[{1}, yw]*G[{0, yv^(-1), yu^(-1)}, yw])/8 - 
     (3*G[{1}, yv^(-1)]*G[{1}, yw]*G[{0, yv^(-1), yu^(-1)}, yw])/16 - 
     (G[{1}, yw]^2*G[{0, yv^(-1), yu^(-1)}, yw])/32 + 
     (G[{1}, yw]*G[{yu}, yv^(-1)]*G[{0, yv^(-1), yu^(-1)}, yw])/16 - 
     (G[{0}, yu^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, yv^(-1), yu^(-1)}, yw])/8 - 
     (G[{0}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, yv^(-1), yu^(-1)}, yw])/8 + 
     (G[{0}, yw]*G[{1/(yu*yv)}, yw]*G[{0, yv^(-1), yu^(-1)}, yw])/8 + 
     (G[{1}, yu^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, yv^(-1), yu^(-1)}, yw])/4 + 
     (G[{1}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, yv^(-1), yu^(-1)}, yw])/16 + 
     (G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{0, yv^(-1), yu^(-1)}, yw])/16 + 
     (G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{0, yv^(-1), yu^(-1)}, yw])/16 - 
     (G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, yv^(-1), yu^(-1)}, yw])/16 - 
     (G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{0, yv^(-1), yu^(-1)}, yw])/8 + 
     (G[{0, 1}, yu^(-1)]*G[{0, yv^(-1), yu^(-1)}, yw])/16 + 
     (G[{0, 1}, yv^(-1)]*G[{0, yv^(-1), yu^(-1)}, yw])/8 - 
     (G[{0, yu}, yv^(-1)]*G[{0, yv^(-1), yu^(-1)}, yw])/8 + 
     (G[{1, yu^(-1)}, yw]*G[{0, yv^(-1), yu^(-1)}, yw])/16 + 
     (G[{1, yu}, yv^(-1)]*G[{0, yv^(-1), yu^(-1)}, yw])/16 - 
     (G[{1, 1/(yu*yv)}, yw]*G[{0, yv^(-1), yu^(-1)}, yw])/16 - 
     (G[{yu^(-1), 1/(yu*yv)}, yw]*G[{0, yv^(-1), yu^(-1)}, yw])/16 + 
     (G[{yv^(-1), 1/(yu*yv)}, yw]*G[{0, yv^(-1), yu^(-1)}, yw])/8 + 
     (Pi^2*G[{0, yv^(-1), yv^(-1)}, yw])/96 + 
     (G[{1}, yu^(-1)]^2*G[{0, yv^(-1), yv^(-1)}, yw])/32 - 
     (G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*G[{0, yv^(-1), yv^(-1)}, yw])/16 + 
     (3*G[{0}, yu^(-1)]*G[{1}, yw]*G[{0, yv^(-1), yv^(-1)}, yw])/16 + 
     (3*G[{0}, yv^(-1)]*G[{1}, yw]*G[{0, yv^(-1), yv^(-1)}, yw])/16 - 
     (3*G[{0}, yw]*G[{1}, yw]*G[{0, yv^(-1), yv^(-1)}, yw])/16 - 
     (G[{1}, yu^(-1)]*G[{1}, yw]*G[{0, yv^(-1), yv^(-1)}, yw])/4 - 
     (3*G[{1}, yv^(-1)]*G[{1}, yw]*G[{0, yv^(-1), yv^(-1)}, yw])/16 - 
     (G[{1}, yw]^2*G[{0, yv^(-1), yv^(-1)}, yw])/32 + 
     (G[{1}, yw]*G[{yu}, yv^(-1)]*G[{0, yv^(-1), yv^(-1)}, yw])/16 - 
     (G[{0}, yu^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, yv^(-1), yv^(-1)}, yw])/16 - 
     (G[{0}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, yv^(-1), yv^(-1)}, yw])/16 + 
     (G[{0}, yw]*G[{1/(yu*yv)}, yw]*G[{0, yv^(-1), yv^(-1)}, yw])/16 + 
     (G[{1}, yu^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, yv^(-1), yv^(-1)}, yw])/8 + 
     (G[{1}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, yv^(-1), yv^(-1)}, yw])/16 + 
     (G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{0, yv^(-1), yv^(-1)}, yw])/16 + 
     (G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{0, yv^(-1), yv^(-1)}, yw])/16 - 
     (G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, yv^(-1), yv^(-1)}, yw])/16 - 
     (G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{0, yv^(-1), yv^(-1)}, yw])/8 - 
     (G[{0, 1}, yu^(-1)]*G[{0, yv^(-1), yv^(-1)}, yw])/16 + 
     (G[{0, 1}, yw]*G[{0, yv^(-1), yv^(-1)}, yw])/8 - 
     (G[{0, yu^(-1)}, yw]*G[{0, yv^(-1), yv^(-1)}, yw])/8 - 
     (G[{0, yv^(-1)}, yw]*G[{0, yv^(-1), yv^(-1)}, yw])/8 - 
     (G[{0, 1/(yu*yv)}, yw]*G[{0, yv^(-1), yv^(-1)}, yw])/16 + 
     (G[{1, yu^(-1)}, yw]*G[{0, yv^(-1), yv^(-1)}, yw])/16 + 
     (G[{1, yu}, yv^(-1)]*G[{0, yv^(-1), yv^(-1)}, yw])/16 - 
     (G[{1, 1/(yu*yv)}, yw]*G[{0, yv^(-1), yv^(-1)}, yw])/16 - 
     (G[{yu^(-1), 1/(yu*yv)}, yw]*G[{0, yv^(-1), yv^(-1)}, yw])/16 + 
     (G[{yv^(-1), 1/(yu*yv)}, yw]*G[{0, yv^(-1), yv^(-1)}, yw])/8 - 
     (Pi^2*G[{0, yv^(-1), 1/(yu*yv)}, yw])/96 - 
     (G[{0}, yu^(-1)]*G[{1}, yu^(-1)]*G[{0, yv^(-1), 1/(yu*yv)}, yw])/16 - 
     (G[{0}, yv^(-1)]*G[{1}, yu^(-1)]*G[{0, yv^(-1), 1/(yu*yv)}, yw])/16 + 
     (G[{0}, yw]*G[{1}, yu^(-1)]*G[{0, yv^(-1), 1/(yu*yv)}, yw])/16 + 
     (3*G[{1}, yu^(-1)]^2*G[{0, yv^(-1), 1/(yu*yv)}, yw])/32 + 
     (G[{0}, yu^(-1)]*G[{1}, yv^(-1)]*G[{0, yv^(-1), 1/(yu*yv)}, yw])/16 + 
     (G[{0}, yv^(-1)]*G[{1}, yv^(-1)]*G[{0, yv^(-1), 1/(yu*yv)}, yw])/16 - 
     (G[{0}, yw]*G[{1}, yv^(-1)]*G[{0, yv^(-1), 1/(yu*yv)}, yw])/16 + 
     (G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*G[{0, yv^(-1), 1/(yu*yv)}, yw])/16 - 
     (3*G[{1}, yv^(-1)]^2*G[{0, yv^(-1), 1/(yu*yv)}, yw])/32 - 
     (G[{0}, yu^(-1)]*G[{1}, yw]*G[{0, yv^(-1), 1/(yu*yv)}, yw])/8 - 
     (G[{0}, yv^(-1)]*G[{1}, yw]*G[{0, yv^(-1), 1/(yu*yv)}, yw])/8 + 
     (G[{0}, yw]*G[{1}, yw]*G[{0, yv^(-1), 1/(yu*yv)}, yw])/8 + 
     (G[{1}, yu^(-1)]*G[{1}, yw]*G[{0, yv^(-1), 1/(yu*yv)}, yw])/16 + 
     (G[{1}, yv^(-1)]*G[{1}, yw]*G[{0, yv^(-1), 1/(yu*yv)}, yw])/4 - 
     (G[{1}, yw]^2*G[{0, yv^(-1), 1/(yu*yv)}, yw])/32 - 
     (G[{1}, yu^(-1)]*G[{yu}, yv^(-1)]*G[{0, yv^(-1), 1/(yu*yv)}, yw])/8 - 
     (G[{1}, yw]*G[{yu}, yv^(-1)]*G[{0, yv^(-1), 1/(yu*yv)}, yw])/16 + 
     (G[{yu}, yv^(-1)]^2*G[{0, yv^(-1), 1/(yu*yv)}, yw])/16 + 
     (G[{0}, yu^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, yv^(-1), 1/(yu*yv)}, yw])/16 + 
     (G[{0}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, yv^(-1), 1/(yu*yv)}, yw])/16 - 
     (G[{0}, yw]*G[{1/(yu*yv)}, yw]*G[{0, yv^(-1), 1/(yu*yv)}, yw])/16 - 
     (G[{1}, yu^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, yv^(-1), 1/(yu*yv)}, yw])/8 + 
     (G[{1}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, yv^(-1), 1/(yu*yv)}, yw])/16 + 
     (G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{0, yv^(-1), 1/(yu*yv)}, yw])/16 - 
     (G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{0, yv^(-1), 1/(yu*yv)}, yw])/
      16 - (G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, yv^(-1), 1/(yu*yv)}, 
        yw])/16 + (G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*
       G[{0, yv^(-1), 1/(yu*yv)}, yw])/8 - 
     (G[{0, 1}, yw]*G[{0, yv^(-1), 1/(yu*yv)}, yw])/8 + 
     (G[{0, yu^(-1)}, yw]*G[{0, yv^(-1), 1/(yu*yv)}, yw])/8 + 
     (G[{0, yv^(-1)}, yw]*G[{0, yv^(-1), 1/(yu*yv)}, yw])/8 + 
     (G[{0, 1/(yu*yv)}, yw]*G[{0, yv^(-1), 1/(yu*yv)}, yw])/16 - 
     (G[{1, yu^(-1)}, yw]*G[{0, yv^(-1), 1/(yu*yv)}, yw])/16 - 
     (G[{1, 1/(yu*yv)}, yw]*G[{0, yv^(-1), 1/(yu*yv)}, yw])/16 + 
     (G[{yu^(-1), 1/(yu*yv)}, yw]*G[{0, yv^(-1), 1/(yu*yv)}, yw])/16 - 
     (G[{yv^(-1), 1/(yu*yv)}, yw]*G[{0, yv^(-1), 1/(yu*yv)}, yw])/8 - 
     (5*Pi^2*G[{0, 1/(yu*yv), 1}, yw])/96 - 
     (G[{0}, yu^(-1)]*G[{1}, yu^(-1)]*G[{0, 1/(yu*yv), 1}, yw])/16 - 
     (G[{0}, yv^(-1)]*G[{1}, yu^(-1)]*G[{0, 1/(yu*yv), 1}, yw])/16 + 
     (G[{0}, yw]*G[{1}, yu^(-1)]*G[{0, 1/(yu*yv), 1}, yw])/16 + 
     (G[{1}, yu^(-1)]^2*G[{0, 1/(yu*yv), 1}, yw])/32 - 
     (G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*G[{0, 1/(yu*yv), 1}, yw])/16 + 
     (G[{1}, yv^(-1)]^2*G[{0, 1/(yu*yv), 1}, yw])/32 + 
     (G[{1}, yu^(-1)]*G[{1}, yw]*G[{0, 1/(yu*yv), 1}, yw])/16 - 
     (G[{1}, yv^(-1)]*G[{1}, yw]*G[{0, 1/(yu*yv), 1}, yw])/8 + 
     (G[{1}, yw]^2*G[{0, 1/(yu*yv), 1}, yw])/32 + 
     (G[{0}, yu^(-1)]*G[{yu}, yv^(-1)]*G[{0, 1/(yu*yv), 1}, yw])/16 + 
     (G[{0}, yv^(-1)]*G[{yu}, yv^(-1)]*G[{0, 1/(yu*yv), 1}, yw])/16 - 
     (G[{0}, yw]*G[{yu}, yv^(-1)]*G[{0, 1/(yu*yv), 1}, yw])/16 + 
     (G[{1}, yu^(-1)]*G[{yu}, yv^(-1)]*G[{0, 1/(yu*yv), 1}, yw])/8 + 
     (G[{1}, yw]*G[{yu}, yv^(-1)]*G[{0, 1/(yu*yv), 1}, yw])/16 - 
     (G[{yu}, yv^(-1)]^2*G[{0, 1/(yu*yv), 1}, yw])/8 + 
     (G[{1}, yu^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv), 1}, yw])/8 - 
     (G[{1}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv), 1}, yw])/16 - 
     (G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv), 1}, yw])/16 + 
     (G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv), 1}, yw])/16 - 
     (G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv), 1}, yw])/16 - 
     (G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv), 1}, yw])/8 - 
     (G[{0, 1}, yu^(-1)]*G[{0, 1/(yu*yv), 1}, yw])/8 - 
     (G[{0, 1}, yv^(-1)]*G[{0, 1/(yu*yv), 1}, yw])/8 + 
     (G[{0, yu}, yv^(-1)]*G[{0, 1/(yu*yv), 1}, yw])/8 + 
     (G[{1, yu^(-1)}, yw]*G[{0, 1/(yu*yv), 1}, yw])/16 + 
     (G[{1, 1/(yu*yv)}, yw]*G[{0, 1/(yu*yv), 1}, yw])/16 - 
     (G[{yu^(-1), 1/(yu*yv)}, yw]*G[{0, 1/(yu*yv), 1}, yw])/16 + 
     (G[{yv^(-1), 1/(yu*yv)}, yw]*G[{0, 1/(yu*yv), 1}, yw])/8 - 
     (G[{0}, yu^(-1)]*G[{1}, yu^(-1)]*G[{0, 1/(yu*yv), yu^(-1)}, yw])/16 - 
     (G[{0}, yv^(-1)]*G[{1}, yu^(-1)]*G[{0, 1/(yu*yv), yu^(-1)}, yw])/16 + 
     (G[{0}, yw]*G[{1}, yu^(-1)]*G[{0, 1/(yu*yv), yu^(-1)}, yw])/16 + 
     (G[{1}, yu^(-1)]^2*G[{0, 1/(yu*yv), yu^(-1)}, yw])/8 + 
     (G[{0}, yu^(-1)]*G[{1}, yv^(-1)]*G[{0, 1/(yu*yv), yu^(-1)}, yw])/16 + 
     (G[{0}, yv^(-1)]*G[{1}, yv^(-1)]*G[{0, 1/(yu*yv), yu^(-1)}, yw])/16 - 
     (G[{0}, yw]*G[{1}, yv^(-1)]*G[{0, 1/(yu*yv), yu^(-1)}, yw])/16 - 
     (G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*G[{0, 1/(yu*yv), yu^(-1)}, yw])/8 - 
     (G[{1}, yv^(-1)]^2*G[{0, 1/(yu*yv), yu^(-1)}, yw])/32 + 
     (G[{1}, yu^(-1)]*G[{1}, yw]*G[{0, 1/(yu*yv), yu^(-1)}, yw])/8 - 
     (G[{1}, yv^(-1)]*G[{1}, yw]*G[{0, 1/(yu*yv), yu^(-1)}, yw])/16 + 
     (G[{1}, yw]^2*G[{0, 1/(yu*yv), yu^(-1)}, yw])/32 - 
     (G[{1}, yw]*G[{yu}, yv^(-1)]*G[{0, 1/(yu*yv), yu^(-1)}, yw])/16 + 
     (G[{0}, yu^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv), yu^(-1)}, yw])/16 + 
     (G[{0}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv), yu^(-1)}, yw])/16 - 
     (G[{0}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv), yu^(-1)}, yw])/16 - 
     (G[{1}, yu^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv), yu^(-1)}, yw])/4 + 
     (G[{1}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv), yu^(-1)}, yw])/16 - 
     (G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv), yu^(-1)}, yw])/16 - 
     (G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv), yu^(-1)}, yw])/
      16 + (G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv), yu^(-1)}, 
        yw])/16 + (G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*
       G[{0, 1/(yu*yv), yu^(-1)}, yw])/8 - 
     (G[{0, 1}, yu^(-1)]*G[{0, 1/(yu*yv), yu^(-1)}, yw])/16 + 
     (G[{0, 1}, yw]*G[{0, 1/(yu*yv), yu^(-1)}, yw])/16 - 
     (G[{0, yu^(-1)}, yw]*G[{0, 1/(yu*yv), yu^(-1)}, yw])/16 - 
     (G[{0, yv^(-1)}, yw]*G[{0, 1/(yu*yv), yu^(-1)}, yw])/16 + 
     (G[{0, 1/(yu*yv)}, yw]*G[{0, 1/(yu*yv), yu^(-1)}, yw])/16 - 
     (G[{1, yu^(-1)}, yw]*G[{0, 1/(yu*yv), yu^(-1)}, yw])/16 + 
     (G[{1, yu}, yv^(-1)]*G[{0, 1/(yu*yv), yu^(-1)}, yw])/16 + 
     (G[{1, 1/(yu*yv)}, yw]*G[{0, 1/(yu*yv), yu^(-1)}, yw])/16 + 
     (G[{yu^(-1), 1/(yu*yv)}, yw]*G[{0, 1/(yu*yv), yu^(-1)}, yw])/16 - 
     (G[{yv^(-1), 1/(yu*yv)}, yw]*G[{0, 1/(yu*yv), yu^(-1)}, yw])/8 - 
     (Pi^2*G[{0, 1/(yu*yv), yv^(-1)}, yw])/96 - 
     (G[{1}, yu^(-1)]^2*G[{0, 1/(yu*yv), yv^(-1)}, yw])/32 + 
     (G[{0}, yu^(-1)]*G[{1}, yv^(-1)]*G[{0, 1/(yu*yv), yv^(-1)}, yw])/8 + 
     (G[{0}, yv^(-1)]*G[{1}, yv^(-1)]*G[{0, 1/(yu*yv), yv^(-1)}, yw])/8 - 
     (G[{0}, yw]*G[{1}, yv^(-1)]*G[{0, 1/(yu*yv), yv^(-1)}, yw])/8 + 
     (G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*G[{0, 1/(yu*yv), yv^(-1)}, yw])/16 - 
     (G[{1}, yv^(-1)]^2*G[{0, 1/(yu*yv), yv^(-1)}, yw])/8 - 
     (G[{0}, yu^(-1)]*G[{1}, yw]*G[{0, 1/(yu*yv), yv^(-1)}, yw])/8 - 
     (G[{0}, yv^(-1)]*G[{1}, yw]*G[{0, 1/(yu*yv), yv^(-1)}, yw])/8 + 
     (G[{0}, yw]*G[{1}, yw]*G[{0, 1/(yu*yv), yv^(-1)}, yw])/8 + 
     (G[{1}, yu^(-1)]*G[{1}, yw]*G[{0, 1/(yu*yv), yv^(-1)}, yw])/8 + 
     (3*G[{1}, yv^(-1)]*G[{1}, yw]*G[{0, 1/(yu*yv), yv^(-1)}, yw])/16 + 
     (G[{1}, yw]^2*G[{0, 1/(yu*yv), yv^(-1)}, yw])/32 - 
     (G[{0}, yu^(-1)]*G[{yu}, yv^(-1)]*G[{0, 1/(yu*yv), yv^(-1)}, yw])/8 - 
     (G[{0}, yv^(-1)]*G[{yu}, yv^(-1)]*G[{0, 1/(yu*yv), yv^(-1)}, yw])/8 + 
     (G[{0}, yw]*G[{yu}, yv^(-1)]*G[{0, 1/(yu*yv), yv^(-1)}, yw])/8 - 
     (G[{1}, yw]*G[{yu}, yv^(-1)]*G[{0, 1/(yu*yv), yv^(-1)}, yw])/16 + 
     (G[{yu}, yv^(-1)]^2*G[{0, 1/(yu*yv), yv^(-1)}, yw])/8 + 
     (G[{0}, yu^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv), yv^(-1)}, yw])/16 + 
     (G[{0}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv), yv^(-1)}, yw])/16 - 
     (G[{0}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv), yv^(-1)}, yw])/16 - 
     (G[{1}, yu^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv), yv^(-1)}, yw])/8 - 
     (G[{1}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv), yv^(-1)}, yw])/16 - 
     (G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv), yv^(-1)}, yw])/16 - 
     (G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv), yv^(-1)}, yw])/
      16 + (G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv), yv^(-1)}, 
        yw])/16 + (G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*
       G[{0, 1/(yu*yv), yv^(-1)}, yw])/8 + 
     (G[{0, 1}, yu^(-1)]*G[{0, 1/(yu*yv), yv^(-1)}, yw])/16 - 
     (G[{0, 1}, yw]*G[{0, 1/(yu*yv), yv^(-1)}, yw])/8 + 
     (G[{0, yu^(-1)}, yw]*G[{0, 1/(yu*yv), yv^(-1)}, yw])/8 + 
     (G[{0, yv^(-1)}, yw]*G[{0, 1/(yu*yv), yv^(-1)}, yw])/8 - 
     (G[{0, 1/(yu*yv)}, yw]*G[{0, 1/(yu*yv), yv^(-1)}, yw])/8 - 
     (G[{1, yu^(-1)}, yw]*G[{0, 1/(yu*yv), yv^(-1)}, yw])/16 - 
     (G[{1, yu}, yv^(-1)]*G[{0, 1/(yu*yv), yv^(-1)}, yw])/16 + 
     (G[{1, 1/(yu*yv)}, yw]*G[{0, 1/(yu*yv), yv^(-1)}, yw])/16 + 
     (G[{yu^(-1), 1/(yu*yv)}, yw]*G[{0, 1/(yu*yv), yv^(-1)}, yw])/16 - 
     (G[{yv^(-1), 1/(yu*yv)}, yw]*G[{0, 1/(yu*yv), yv^(-1)}, yw])/8 + 
     (Pi^2*G[{0, 1/(yu*yv), 1/(yu*yv)}, yw])/96 + 
     (G[{0}, yu^(-1)]*G[{1}, yu^(-1)]*G[{0, 1/(yu*yv), 1/(yu*yv)}, yw])/16 + 
     (G[{0}, yv^(-1)]*G[{1}, yu^(-1)]*G[{0, 1/(yu*yv), 1/(yu*yv)}, yw])/16 - 
     (G[{0}, yw]*G[{1}, yu^(-1)]*G[{0, 1/(yu*yv), 1/(yu*yv)}, yw])/16 - 
     (3*G[{1}, yu^(-1)]^2*G[{0, 1/(yu*yv), 1/(yu*yv)}, yw])/32 - 
     (G[{0}, yu^(-1)]*G[{1}, yv^(-1)]*G[{0, 1/(yu*yv), 1/(yu*yv)}, yw])/8 - 
     (G[{0}, yv^(-1)]*G[{1}, yv^(-1)]*G[{0, 1/(yu*yv), 1/(yu*yv)}, yw])/8 + 
     (G[{0}, yw]*G[{1}, yv^(-1)]*G[{0, 1/(yu*yv), 1/(yu*yv)}, yw])/8 - 
     (G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*G[{0, 1/(yu*yv), 1/(yu*yv)}, yw])/16 + 
     (5*G[{1}, yv^(-1)]^2*G[{0, 1/(yu*yv), 1/(yu*yv)}, yw])/32 + 
     (G[{0}, yu^(-1)]*G[{1}, yw]*G[{0, 1/(yu*yv), 1/(yu*yv)}, yw])/16 + 
     (G[{0}, yv^(-1)]*G[{1}, yw]*G[{0, 1/(yu*yv), 1/(yu*yv)}, yw])/16 - 
     (G[{0}, yw]*G[{1}, yw]*G[{0, 1/(yu*yv), 1/(yu*yv)}, yw])/16 + 
     (G[{1}, yu^(-1)]*G[{1}, yw]*G[{0, 1/(yu*yv), 1/(yu*yv)}, yw])/16 - 
     (G[{1}, yv^(-1)]*G[{1}, yw]*G[{0, 1/(yu*yv), 1/(yu*yv)}, yw])/8 + 
     (G[{1}, yw]^2*G[{0, 1/(yu*yv), 1/(yu*yv)}, yw])/32 + 
     (G[{0}, yu^(-1)]*G[{yu}, yv^(-1)]*G[{0, 1/(yu*yv), 1/(yu*yv)}, yw])/16 + 
     (G[{0}, yv^(-1)]*G[{yu}, yv^(-1)]*G[{0, 1/(yu*yv), 1/(yu*yv)}, yw])/16 - 
     (G[{0}, yw]*G[{yu}, yv^(-1)]*G[{0, 1/(yu*yv), 1/(yu*yv)}, yw])/16 + 
     (G[{1}, yu^(-1)]*G[{yu}, yv^(-1)]*G[{0, 1/(yu*yv), 1/(yu*yv)}, yw])/8 - 
     (G[{1}, yw]*G[{yu}, yv^(-1)]*G[{0, 1/(yu*yv), 1/(yu*yv)}, yw])/16 - 
     (G[{yu}, yv^(-1)]^2*G[{0, 1/(yu*yv), 1/(yu*yv)}, yw])/8 - 
     (G[{0}, yu^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv), 1/(yu*yv)}, yw])/
      16 - (G[{0}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv), 1/(yu*yv)}, 
        yw])/16 + (G[{0}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv), 1/(yu*yv)}, 
        yw])/16 + (G[{1}, yu^(-1)]*G[{1/(yu*yv)}, yw]*
       G[{0, 1/(yu*yv), 1/(yu*yv)}, yw])/8 - 
     (G[{1}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv), 1/(yu*yv)}, yw])/
      16 - (G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv), 1/(yu*yv)}, yw])/
      16 + (G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv), 1/(yu*yv)}, 
        yw])/16 + (G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw]*
       G[{0, 1/(yu*yv), 1/(yu*yv)}, yw])/16 - 
     (G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv), 1/(yu*yv)}, yw])/
      8 + (G[{0, 1}, yw]*G[{0, 1/(yu*yv), 1/(yu*yv)}, yw])/8 - 
     (G[{0, yu^(-1)}, yw]*G[{0, 1/(yu*yv), 1/(yu*yv)}, yw])/8 - 
     (G[{0, yv^(-1)}, yw]*G[{0, 1/(yu*yv), 1/(yu*yv)}, yw])/8 + 
     (G[{0, 1/(yu*yv)}, yw]*G[{0, 1/(yu*yv), 1/(yu*yv)}, yw])/8 + 
     (G[{1, yu^(-1)}, yw]*G[{0, 1/(yu*yv), 1/(yu*yv)}, yw])/16 + 
     (G[{1, 1/(yu*yv)}, yw]*G[{0, 1/(yu*yv), 1/(yu*yv)}, yw])/16 - 
     (G[{yu^(-1), 1/(yu*yv)}, yw]*G[{0, 1/(yu*yv), 1/(yu*yv)}, yw])/16 + 
     (G[{yv^(-1), 1/(yu*yv)}, yw]*G[{0, 1/(yu*yv), 1/(yu*yv)}, yw])/8 + 
     (7*Pi^2*G[{1, 1, yu^(-1)}, yw])/96 + 
     (G[{0}, yu^(-1)]*G[{1}, yu^(-1)]*G[{1, 1, yu^(-1)}, yw])/16 + 
     (G[{0}, yv^(-1)]*G[{1}, yu^(-1)]*G[{1, 1, yu^(-1)}, yw])/16 - 
     (G[{0}, yw]*G[{1}, yu^(-1)]*G[{1, 1, yu^(-1)}, yw])/16 + 
     (G[{1}, yu^(-1)]^2*G[{1, 1, yu^(-1)}, yw])/16 - 
     (G[{0}, yu^(-1)]*G[{1}, yv^(-1)]*G[{1, 1, yu^(-1)}, yw])/16 - 
     (G[{0}, yv^(-1)]*G[{1}, yv^(-1)]*G[{1, 1, yu^(-1)}, yw])/16 + 
     (G[{0}, yw]*G[{1}, yv^(-1)]*G[{1, 1, yu^(-1)}, yw])/16 + 
     (G[{1}, yv^(-1)]^2*G[{1, 1, yu^(-1)}, yw])/32 + 
     (G[{0}, yu^(-1)]*G[{1}, yw]*G[{1, 1, yu^(-1)}, yw])/8 + 
     (G[{0}, yv^(-1)]*G[{1}, yw]*G[{1, 1, yu^(-1)}, yw])/8 - 
     (G[{0}, yw]*G[{1}, yw]*G[{1, 1, yu^(-1)}, yw])/8 + 
     (G[{1}, yu^(-1)]*G[{1}, yw]*G[{1, 1, yu^(-1)}, yw])/16 - 
     (G[{1}, yv^(-1)]*G[{1}, yw]*G[{1, 1, yu^(-1)}, yw])/4 + 
     (G[{1}, yw]^2*G[{1, 1, yu^(-1)}, yw])/32 - 
     (G[{1}, yu^(-1)]*G[{yu}, yv^(-1)]*G[{1, 1, yu^(-1)}, yw])/4 - 
     (G[{1}, yw]*G[{yu}, yv^(-1)]*G[{1, 1, yu^(-1)}, yw])/16 + 
     (G[{yu}, yv^(-1)]^2*G[{1, 1, yu^(-1)}, yw])/8 - 
     (3*G[{1}, yu^(-1)]*G[{1/(yu*yv)}, yw]*G[{1, 1, yu^(-1)}, yw])/8 + 
     (G[{1}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{1, 1, yu^(-1)}, yw])/4 - 
     (G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{1, 1, yu^(-1)}, yw])/8 - 
     (G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{1, 1, yu^(-1)}, yw])/8 + 
     (G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{1, 1, yu^(-1)}, yw])/8 + 
     (3*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{1, 1, yu^(-1)}, yw])/8 + 
     (G[{0, 1}, yu^(-1)]*G[{1, 1, yu^(-1)}, yw])/16 + 
     (G[{0, 1}, yv^(-1)]*G[{1, 1, yu^(-1)}, yw])/8 + 
     (G[{0, 1}, yw]*G[{1, 1, yu^(-1)}, yw])/8 - 
     (G[{0, yu^(-1)}, yw]*G[{1, 1, yu^(-1)}, yw])/8 - 
     (G[{0, yu}, yv^(-1)]*G[{1, 1, yu^(-1)}, yw])/8 - 
     (G[{0, yv^(-1)}, yw]*G[{1, 1, yu^(-1)}, yw])/8 + 
     (G[{0, 1/(yu*yv)}, yw]*G[{1, 1, yu^(-1)}, yw])/8 - 
     (G[{1, yu^(-1)}, yw]*G[{1, 1, yu^(-1)}, yw])/8 + 
     (G[{1, yu}, yv^(-1)]*G[{1, 1, yu^(-1)}, yw])/16 + 
     (G[{1, 1/(yu*yv)}, yw]*G[{1, 1, yu^(-1)}, yw])/4 + 
     (G[{yu^(-1), 1/(yu*yv)}, yw]*G[{1, 1, yu^(-1)}, yw])/8 - 
     (3*G[{yv^(-1), 1/(yu*yv)}, yw]*G[{1, 1, yu^(-1)}, yw])/8 - 
     (17*Pi^2*G[{1, 1, yu}, yv^(-1)])/256 - 
     (3*G[{0}, yu^(-1)]^2*G[{1, 1, yu}, yv^(-1)])/128 - 
     (3*G[{0}, yu^(-1)]*G[{0}, yv^(-1)]*G[{1, 1, yu}, yv^(-1)])/64 - 
     (3*G[{0}, yv^(-1)]^2*G[{1, 1, yu}, yv^(-1)])/128 + 
     (3*G[{0}, yu^(-1)]*G[{0}, yw]*G[{1, 1, yu}, yv^(-1)])/64 + 
     (3*G[{0}, yv^(-1)]*G[{0}, yw]*G[{1, 1, yu}, yv^(-1)])/64 - 
     (3*G[{0}, yw]^2*G[{1, 1, yu}, yv^(-1)])/128 - 
     (17*G[{0}, yu^(-1)]*G[{1}, yu^(-1)]*G[{1, 1, yu}, yv^(-1)])/64 - 
     (17*G[{0}, yv^(-1)]*G[{1}, yu^(-1)]*G[{1, 1, yu}, yv^(-1)])/64 + 
     (17*G[{0}, yw]*G[{1}, yu^(-1)]*G[{1, 1, yu}, yv^(-1)])/64 + 
     (13*G[{1}, yu^(-1)]^2*G[{1, 1, yu}, yv^(-1)])/128 + 
     (7*G[{0}, yu^(-1)]*G[{1}, yv^(-1)]*G[{1, 1, yu}, yv^(-1)])/64 + 
     (7*G[{0}, yv^(-1)]*G[{1}, yv^(-1)]*G[{1, 1, yu}, yv^(-1)])/64 - 
     (7*G[{0}, yw]*G[{1}, yv^(-1)]*G[{1, 1, yu}, yv^(-1)])/64 + 
     (3*G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*G[{1, 1, yu}, yv^(-1)])/16 - 
     (15*G[{1}, yv^(-1)]^2*G[{1, 1, yu}, yv^(-1)])/128 + 
     (G[{0}, yu^(-1)]*G[{1}, yw]*G[{1, 1, yu}, yv^(-1)])/64 + 
     (G[{0}, yv^(-1)]*G[{1}, yw]*G[{1, 1, yu}, yv^(-1)])/64 - 
     (G[{0}, yw]*G[{1}, yw]*G[{1, 1, yu}, yv^(-1)])/64 - 
     (17*G[{1}, yu^(-1)]*G[{1}, yw]*G[{1, 1, yu}, yv^(-1)])/64 + 
     (3*G[{1}, yv^(-1)]*G[{1}, yw]*G[{1, 1, yu}, yv^(-1)])/64 + 
     (3*G[{1}, yw]^2*G[{1, 1, yu}, yv^(-1)])/64 - 
     (11*G[{1}, yw]*G[{yu}, yv^(-1)]*G[{1, 1, yu}, yv^(-1)])/32 - 
     (7*G[{0}, yu^(-1)]*G[{1/(yu*yv)}, yw]*G[{1, 1, yu}, yv^(-1)])/64 - 
     (7*G[{0}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{1, 1, yu}, yv^(-1)])/64 + 
     (7*G[{0}, yw]*G[{1/(yu*yv)}, yw]*G[{1, 1, yu}, yv^(-1)])/64 - 
     (17*G[{1}, yu^(-1)]*G[{1/(yu*yv)}, yw]*G[{1, 1, yu}, yv^(-1)])/64 + 
     (11*G[{1}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{1, 1, yu}, yv^(-1)])/64 - 
     (11*G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{1, 1, yu}, yv^(-1)])/32 - 
     (3*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{1, 1, yu}, yv^(-1)])/64 + 
     (11*G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{1, 1, yu}, yv^(-1)])/32 + 
     (11*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{1, 1, yu}, yv^(-1)])/64 - 
     (5*G[{0, 1}, yu^(-1)]*G[{1, 1, yu}, yv^(-1)])/64 - 
     (G[{0, 1}, yv^(-1)]*G[{1, 1, yu}, yv^(-1)])/4 + 
     (9*G[{0, 1}, yw]*G[{1, 1, yu}, yv^(-1)])/64 + 
     (3*G[{0, yu^(-1)}, yw]*G[{1, 1, yu}, yv^(-1)])/64 + 
     (G[{0, yu}, yv^(-1)]*G[{1, 1, yu}, yv^(-1)])/4 - 
     (5*G[{0, yv^(-1)}, yw]*G[{1, 1, yu}, yv^(-1)])/64 - 
     (7*G[{0, 1/(yu*yv)}, yw]*G[{1, 1, yu}, yv^(-1)])/64 - 
     (3*G[{1, yu^(-1)}, yw]*G[{1, 1, yu}, yv^(-1)])/64 + 
     (11*G[{1, yu}, yv^(-1)]*G[{1, 1, yu}, yv^(-1)])/32 - 
     (G[{1, yv^(-1)}, yw]*G[{1, 1, yu}, yv^(-1)])/64 + 
     (11*G[{1, 1/(yu*yv)}, yw]*G[{1, 1, yu}, yv^(-1)])/32 + 
     (3*G[{yu^(-1), 1/(yu*yv)}, yw]*G[{1, 1, yu}, yv^(-1)])/64 - 
     (11*G[{yv^(-1), 1/(yu*yv)}, yw]*G[{1, 1, yu}, yv^(-1)])/64 + 
     (5*Pi^2*G[{1, 1, yv^(-1)}, yw])/384 + 
     (3*G[{0}, yu^(-1)]^2*G[{1, 1, yv^(-1)}, yw])/128 + 
     (3*G[{0}, yu^(-1)]*G[{0}, yv^(-1)]*G[{1, 1, yv^(-1)}, yw])/64 + 
     (3*G[{0}, yv^(-1)]^2*G[{1, 1, yv^(-1)}, yw])/128 - 
     (3*G[{0}, yu^(-1)]*G[{0}, yw]*G[{1, 1, yv^(-1)}, yw])/64 - 
     (3*G[{0}, yv^(-1)]*G[{0}, yw]*G[{1, 1, yv^(-1)}, yw])/64 + 
     (3*G[{0}, yw]^2*G[{1, 1, yv^(-1)}, yw])/128 + 
     (5*G[{0}, yu^(-1)]*G[{1}, yu^(-1)]*G[{1, 1, yv^(-1)}, yw])/64 + 
     (5*G[{0}, yv^(-1)]*G[{1}, yu^(-1)]*G[{1, 1, yv^(-1)}, yw])/64 - 
     (5*G[{0}, yw]*G[{1}, yu^(-1)]*G[{1, 1, yv^(-1)}, yw])/64 - 
     (27*G[{1}, yu^(-1)]^2*G[{1, 1, yv^(-1)}, yw])/128 - 
     (3*G[{0}, yu^(-1)]*G[{1}, yv^(-1)]*G[{1, 1, yv^(-1)}, yw])/64 - 
     (3*G[{0}, yv^(-1)]*G[{1}, yv^(-1)]*G[{1, 1, yv^(-1)}, yw])/64 + 
     (3*G[{0}, yw]*G[{1}, yv^(-1)]*G[{1, 1, yv^(-1)}, yw])/64 - 
     (3*G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*G[{1, 1, yv^(-1)}, yw])/32 + 
     (3*G[{1}, yv^(-1)]^2*G[{1, 1, yv^(-1)}, yw])/128 + 
     (15*G[{0}, yu^(-1)]*G[{1}, yw]*G[{1, 1, yv^(-1)}, yw])/64 + 
     (15*G[{0}, yv^(-1)]*G[{1}, yw]*G[{1, 1, yv^(-1)}, yw])/64 - 
     (15*G[{0}, yw]*G[{1}, yw]*G[{1, 1, yv^(-1)}, yw])/64 - 
     (29*G[{1}, yu^(-1)]*G[{1}, yw]*G[{1, 1, yv^(-1)}, yw])/64 - 
     (15*G[{1}, yv^(-1)]*G[{1}, yw]*G[{1, 1, yv^(-1)}, yw])/64 - 
     (7*G[{1}, yw]^2*G[{1, 1, yv^(-1)}, yw])/64 - 
     (G[{0}, yu^(-1)]*G[{yu}, yv^(-1)]*G[{1, 1, yv^(-1)}, yw])/8 - 
     (G[{0}, yv^(-1)]*G[{yu}, yv^(-1)]*G[{1, 1, yv^(-1)}, yw])/8 + 
     (G[{0}, yw]*G[{yu}, yv^(-1)]*G[{1, 1, yv^(-1)}, yw])/8 + 
     (23*G[{1}, yu^(-1)]*G[{yu}, yv^(-1)]*G[{1, 1, yv^(-1)}, yw])/64 + 
     (7*G[{1}, yw]*G[{yu}, yv^(-1)]*G[{1, 1, yv^(-1)}, yw])/32 - 
     (7*G[{yu}, yv^(-1)]^2*G[{1, 1, yv^(-1)}, yw])/128 - 
     (5*G[{0}, yu^(-1)]*G[{1/(yu*yv)}, yw]*G[{1, 1, yv^(-1)}, yw])/64 - 
     (5*G[{0}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{1, 1, yv^(-1)}, yw])/64 + 
     (5*G[{0}, yw]*G[{1/(yu*yv)}, yw]*G[{1, 1, yv^(-1)}, yw])/64 + 
     (G[{1}, yu^(-1)]*G[{1/(yu*yv)}, yw]*G[{1, 1, yv^(-1)}, yw])/8 + 
     (5*G[{1}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{1, 1, yv^(-1)}, yw])/64 + 
     (3*G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{1, 1, yv^(-1)}, yw])/64 - 
     (5*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{1, 1, yv^(-1)}, yw])/64 - 
     (3*G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{1, 1, yv^(-1)}, yw])/64 - 
     (3*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{1, 1, yv^(-1)}, yw])/64 - 
     (3*G[{1/(yu*yv)}, yw]^2*G[{1, 1, yv^(-1)}, yw])/64 - 
     (G[{0, 1}, yu^(-1)]*G[{1, 1, yv^(-1)}, yw])/64 + 
     (G[{0, 1}, yv^(-1)]*G[{1, 1, yv^(-1)}, yw])/8 + 
     (7*G[{0, 1}, yw]*G[{1, 1, yv^(-1)}, yw])/64 - 
     (7*G[{0, yu^(-1)}, yw]*G[{1, 1, yv^(-1)}, yw])/64 - 
     (G[{0, yu}, yv^(-1)]*G[{1, 1, yv^(-1)}, yw])/8 - 
     (7*G[{0, yv^(-1)}, yw]*G[{1, 1, yv^(-1)}, yw])/64 + 
     (7*G[{0, 1/(yu*yv)}, yw]*G[{1, 1, yv^(-1)}, yw])/64 - 
     (5*G[{1, yu^(-1)}, yw]*G[{1, 1, yv^(-1)}, yw])/64 + 
     (9*G[{1, yu}, yv^(-1)]*G[{1, 1, yv^(-1)}, yw])/64 + 
     (G[{1, yv^(-1)}, yw]*G[{1, 1, yv^(-1)}, yw])/64 + 
     (G[{1, 1/(yu*yv)}, yw]*G[{1, 1, yv^(-1)}, yw])/32 + 
     (5*G[{yu^(-1), 1/(yu*yv)}, yw]*G[{1, 1, yv^(-1)}, yw])/64 + 
     (3*G[{yv^(-1), 1/(yu*yv)}, yw]*G[{1, 1, yv^(-1)}, yw])/64 - 
     (41*Pi^2*G[{1, 1, 1/(yu*yv)}, yw])/384 - 
     (3*G[{0}, yu^(-1)]^2*G[{1, 1, 1/(yu*yv)}, yw])/128 - 
     (3*G[{0}, yu^(-1)]*G[{0}, yv^(-1)]*G[{1, 1, 1/(yu*yv)}, yw])/64 - 
     (3*G[{0}, yv^(-1)]^2*G[{1, 1, 1/(yu*yv)}, yw])/128 + 
     (3*G[{0}, yu^(-1)]*G[{0}, yw]*G[{1, 1, 1/(yu*yv)}, yw])/64 + 
     (3*G[{0}, yv^(-1)]*G[{0}, yw]*G[{1, 1, 1/(yu*yv)}, yw])/64 - 
     (3*G[{0}, yw]^2*G[{1, 1, 1/(yu*yv)}, yw])/128 - 
     (17*G[{0}, yu^(-1)]*G[{1}, yu^(-1)]*G[{1, 1, 1/(yu*yv)}, yw])/64 - 
     (17*G[{0}, yv^(-1)]*G[{1}, yu^(-1)]*G[{1, 1, 1/(yu*yv)}, yw])/64 + 
     (17*G[{0}, yw]*G[{1}, yu^(-1)]*G[{1, 1, 1/(yu*yv)}, yw])/64 + 
     (19*G[{1}, yu^(-1)]^2*G[{1, 1, 1/(yu*yv)}, yw])/128 + 
     (7*G[{0}, yu^(-1)]*G[{1}, yv^(-1)]*G[{1, 1, 1/(yu*yv)}, yw])/64 + 
     (7*G[{0}, yv^(-1)]*G[{1}, yv^(-1)]*G[{1, 1, 1/(yu*yv)}, yw])/64 - 
     (7*G[{0}, yw]*G[{1}, yv^(-1)]*G[{1, 1, 1/(yu*yv)}, yw])/64 + 
     (3*G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*G[{1, 1, 1/(yu*yv)}, yw])/32 - 
     (7*G[{1}, yv^(-1)]^2*G[{1, 1, 1/(yu*yv)}, yw])/128 - 
     (15*G[{0}, yu^(-1)]*G[{1}, yw]*G[{1, 1, 1/(yu*yv)}, yw])/64 - 
     (15*G[{0}, yv^(-1)]*G[{1}, yw]*G[{1, 1, 1/(yu*yv)}, yw])/64 + 
     (15*G[{0}, yw]*G[{1}, yw]*G[{1, 1, 1/(yu*yv)}, yw])/64 + 
     (G[{1}, yu^(-1)]*G[{1}, yw]*G[{1, 1, 1/(yu*yv)}, yw])/64 + 
     (23*G[{1}, yv^(-1)]*G[{1}, yw]*G[{1, 1, 1/(yu*yv)}, yw])/64 - 
     (3*G[{1}, yw]^2*G[{1, 1, 1/(yu*yv)}, yw])/64 + 
     (G[{0}, yu^(-1)]*G[{yu}, yv^(-1)]*G[{1, 1, 1/(yu*yv)}, yw])/4 + 
     (G[{0}, yv^(-1)]*G[{yu}, yv^(-1)]*G[{1, 1, 1/(yu*yv)}, yw])/4 - 
     (G[{0}, yw]*G[{yu}, yv^(-1)]*G[{1, 1, 1/(yu*yv)}, yw])/4 + 
     (9*G[{1}, yu^(-1)]*G[{yu}, yv^(-1)]*G[{1, 1, 1/(yu*yv)}, yw])/64 + 
     (3*G[{1}, yw]*G[{yu}, yv^(-1)]*G[{1, 1, 1/(yu*yv)}, yw])/32 - 
     (41*G[{yu}, yv^(-1)]^2*G[{1, 1, 1/(yu*yv)}, yw])/128 + 
     (21*G[{0}, yu^(-1)]*G[{1/(yu*yv)}, yw]*G[{1, 1, 1/(yu*yv)}, yw])/64 + 
     (21*G[{0}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{1, 1, 1/(yu*yv)}, yw])/64 - 
     (21*G[{0}, yw]*G[{1/(yu*yv)}, yw]*G[{1, 1, 1/(yu*yv)}, yw])/64 - 
     (13*G[{1}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{1, 1, 1/(yu*yv)}, yw])/64 + 
     (29*G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{1, 1, 1/(yu*yv)}, yw])/64 + 
     (5*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{1, 1, 1/(yu*yv)}, yw])/64 - 
     (29*G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{1, 1, 1/(yu*yv)}, yw])/64 - 
     (5*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{1, 1, 1/(yu*yv)}, yw])/64 + 
     (3*G[{1/(yu*yv)}, yw]^2*G[{1, 1, 1/(yu*yv)}, yw])/64 - 
     (11*G[{0, 1}, yu^(-1)]*G[{1, 1, 1/(yu*yv)}, yw])/64 - 
     (3*G[{0, 1}, yv^(-1)]*G[{1, 1, 1/(yu*yv)}, yw])/8 + 
     (G[{0, 1}, yw]*G[{1, 1, 1/(yu*yv)}, yw])/64 - 
     (G[{0, yu^(-1)}, yw]*G[{1, 1, 1/(yu*yv)}, yw])/64 + 
     (3*G[{0, yu}, yv^(-1)]*G[{1, 1, 1/(yu*yv)}, yw])/8 - 
     (G[{0, yv^(-1)}, yw]*G[{1, 1, 1/(yu*yv)}, yw])/64 + 
     (G[{0, 1/(yu*yv)}, yw]*G[{1, 1, 1/(yu*yv)}, yw])/64 + 
     (5*G[{1, yu^(-1)}, yw]*G[{1, 1, 1/(yu*yv)}, yw])/64 - 
     (13*G[{1, yu}, yv^(-1)]*G[{1, 1, 1/(yu*yv)}, yw])/64 - 
     (G[{1, yv^(-1)}, yw]*G[{1, 1, 1/(yu*yv)}, yw])/64 - 
     (13*G[{1, 1/(yu*yv)}, yw]*G[{1, 1, 1/(yu*yv)}, yw])/32 - 
     (5*G[{yu^(-1), 1/(yu*yv)}, yw]*G[{1, 1, 1/(yu*yv)}, yw])/64 + 
     (5*G[{yv^(-1), 1/(yu*yv)}, yw]*G[{1, 1, 1/(yu*yv)}, yw])/64 + 
     (Pi^2*G[{1, yu^(-1), yu^(-1)}, yw])/32 + 
     (5*G[{1}, yu^(-1)]^2*G[{1, yu^(-1), yu^(-1)}, yw])/32 - 
     (5*G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*G[{1, yu^(-1), yu^(-1)}, yw])/16 + 
     (G[{1}, yv^(-1)]^2*G[{1, yu^(-1), yu^(-1)}, yw])/16 + 
     (G[{0}, yu^(-1)]*G[{1}, yw]*G[{1, yu^(-1), yu^(-1)}, yw])/8 + 
     (G[{0}, yv^(-1)]*G[{1}, yw]*G[{1, yu^(-1), yu^(-1)}, yw])/8 - 
     (G[{0}, yw]*G[{1}, yw]*G[{1, yu^(-1), yu^(-1)}, yw])/8 - 
     (G[{1}, yu^(-1)]*G[{1}, yw]*G[{1, yu^(-1), yu^(-1)}, yw])/16 - 
     (G[{1}, yv^(-1)]*G[{1}, yw]*G[{1, yu^(-1), yu^(-1)}, yw])/4 - 
     (G[{1}, yw]^2*G[{1, yu^(-1), yu^(-1)}, yw])/32 + 
     (G[{1}, yw]*G[{yu}, yv^(-1)]*G[{1, yu^(-1), yu^(-1)}, yw])/16 + 
     (G[{0}, yu^(-1)]*G[{1/(yu*yv)}, yw]*G[{1, yu^(-1), yu^(-1)}, yw])/16 + 
     (G[{0}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{1, yu^(-1), yu^(-1)}, yw])/16 - 
     (G[{0}, yw]*G[{1/(yu*yv)}, yw]*G[{1, yu^(-1), yu^(-1)}, yw])/16 - 
     (G[{1}, yu^(-1)]*G[{1/(yu*yv)}, yw]*G[{1, yu^(-1), yu^(-1)}, yw])/2 + 
     (3*G[{1}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{1, yu^(-1), yu^(-1)}, yw])/16 - 
     (3*G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{1, yu^(-1), yu^(-1)}, yw])/16 - 
     (3*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{1, yu^(-1), yu^(-1)}, yw])/
      16 + (3*G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{1, yu^(-1), yu^(-1)}, 
        yw])/16 + (3*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*
       G[{1, yu^(-1), yu^(-1)}, yw])/8 - 
     (G[{0, 1}, yu^(-1)]*G[{1, yu^(-1), yu^(-1)}, yw])/16 + 
     (G[{0, 1}, yv^(-1)]*G[{1, yu^(-1), yu^(-1)}, yw])/8 + 
     (G[{0, 1}, yw]*G[{1, yu^(-1), yu^(-1)}, yw])/8 - 
     (G[{0, yu^(-1)}, yw]*G[{1, yu^(-1), yu^(-1)}, yw])/8 - 
     (G[{0, yu}, yv^(-1)]*G[{1, yu^(-1), yu^(-1)}, yw])/8 - 
     (G[{0, yv^(-1)}, yw]*G[{1, yu^(-1), yu^(-1)}, yw])/8 + 
     (G[{0, 1/(yu*yv)}, yw]*G[{1, yu^(-1), yu^(-1)}, yw])/8 + 
     (G[{1, yu^(-1)}, yw]*G[{1, yu^(-1), yu^(-1)}, yw])/4 + 
     (3*G[{1, yu}, yv^(-1)]*G[{1, yu^(-1), yu^(-1)}, yw])/16 + 
     (5*G[{1, 1/(yu*yv)}, yw]*G[{1, yu^(-1), yu^(-1)}, yw])/16 + 
     (3*G[{yu^(-1), 1/(yu*yv)}, yw]*G[{1, yu^(-1), yu^(-1)}, yw])/16 - 
     (3*G[{yv^(-1), 1/(yu*yv)}, yw]*G[{1, yu^(-1), yu^(-1)}, yw])/8 - 
     (Pi^2*G[{1, yu^(-1), yv^(-1)}, yw])/32 - 
     (G[{0}, yu^(-1)]*G[{1}, yu^(-1)]*G[{1, yu^(-1), yv^(-1)}, yw])/8 - 
     (G[{0}, yv^(-1)]*G[{1}, yu^(-1)]*G[{1, yu^(-1), yv^(-1)}, yw])/8 + 
     (G[{0}, yw]*G[{1}, yu^(-1)]*G[{1, yu^(-1), yv^(-1)}, yw])/8 + 
     (3*G[{1}, yu^(-1)]^2*G[{1, yu^(-1), yv^(-1)}, yw])/32 + 
     (G[{0}, yu^(-1)]*G[{1}, yv^(-1)]*G[{1, yu^(-1), yv^(-1)}, yw])/8 + 
     (G[{0}, yv^(-1)]*G[{1}, yv^(-1)]*G[{1, yu^(-1), yv^(-1)}, yw])/8 - 
     (G[{0}, yw]*G[{1}, yv^(-1)]*G[{1, yu^(-1), yv^(-1)}, yw])/8 + 
     (G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*G[{1, yu^(-1), yv^(-1)}, yw])/16 - 
     (G[{1}, yv^(-1)]^2*G[{1, yu^(-1), yv^(-1)}, yw])/8 + 
     (G[{1}, yu^(-1)]*G[{1}, yw]*G[{1, yu^(-1), yv^(-1)}, yw])/16 + 
     (G[{1}, yv^(-1)]*G[{1}, yw]*G[{1, yu^(-1), yv^(-1)}, yw])/8 + 
     (3*G[{1}, yw]^2*G[{1, yu^(-1), yv^(-1)}, yw])/32 - 
     (3*G[{1}, yw]*G[{yu}, yv^(-1)]*G[{1, yu^(-1), yv^(-1)}, yw])/16 + 
     (G[{0}, yu^(-1)]*G[{1/(yu*yv)}, yw]*G[{1, yu^(-1), yv^(-1)}, yw])/8 + 
     (G[{0}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{1, yu^(-1), yv^(-1)}, yw])/8 - 
     (G[{0}, yw]*G[{1/(yu*yv)}, yw]*G[{1, yu^(-1), yv^(-1)}, yw])/8 - 
     (G[{1}, yu^(-1)]*G[{1/(yu*yv)}, yw]*G[{1, yu^(-1), yv^(-1)}, yw])/4 - 
     (G[{1}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{1, yu^(-1), yv^(-1)}, yw])/16 - 
     (G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{1, yu^(-1), yv^(-1)}, yw])/16 - 
     (G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{1, yu^(-1), yv^(-1)}, yw])/16 + 
     (G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{1, yu^(-1), yv^(-1)}, yw])/16 + 
     (G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{1, yu^(-1), yv^(-1)}, yw])/8 - 
     (G[{0, 1}, yu^(-1)]*G[{1, yu^(-1), yv^(-1)}, yw])/16 - 
     (G[{0, 1}, yv^(-1)]*G[{1, yu^(-1), yv^(-1)}, yw])/8 + 
     (G[{0, yu}, yv^(-1)]*G[{1, yu^(-1), yv^(-1)}, yw])/8 - 
     (G[{1, yu^(-1)}, yw]*G[{1, yu^(-1), yv^(-1)}, yw])/8 - 
     (G[{1, yu}, yv^(-1)]*G[{1, yu^(-1), yv^(-1)}, yw])/16 + 
     (G[{1, 1/(yu*yv)}, yw]*G[{1, yu^(-1), yv^(-1)}, yw])/16 + 
     (G[{yu^(-1), 1/(yu*yv)}, yw]*G[{1, yu^(-1), yv^(-1)}, yw])/16 - 
     (G[{yv^(-1), 1/(yu*yv)}, yw]*G[{1, yu^(-1), yv^(-1)}, yw])/8 - 
     (Pi^2*G[{1, yu^(-1), 1/(yu*yv)}, yw])/96 + 
     (G[{0}, yu^(-1)]*G[{1}, yu^(-1)]*G[{1, yu^(-1), 1/(yu*yv)}, yw])/16 + 
     (G[{0}, yv^(-1)]*G[{1}, yu^(-1)]*G[{1, yu^(-1), 1/(yu*yv)}, yw])/16 - 
     (G[{0}, yw]*G[{1}, yu^(-1)]*G[{1, yu^(-1), 1/(yu*yv)}, yw])/16 - 
     (G[{0}, yu^(-1)]*G[{1}, yv^(-1)]*G[{1, yu^(-1), 1/(yu*yv)}, yw])/16 - 
     (G[{0}, yv^(-1)]*G[{1}, yv^(-1)]*G[{1, yu^(-1), 1/(yu*yv)}, yw])/16 + 
     (G[{0}, yw]*G[{1}, yv^(-1)]*G[{1, yu^(-1), 1/(yu*yv)}, yw])/16 - 
     (G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*G[{1, yu^(-1), 1/(yu*yv)}, yw])/8 + 
     (3*G[{1}, yv^(-1)]^2*G[{1, yu^(-1), 1/(yu*yv)}, yw])/32 + 
     (G[{1}, yu^(-1)]*G[{1}, yw]*G[{1, yu^(-1), 1/(yu*yv)}, yw])/16 + 
     (G[{1}, yw]^2*G[{1, yu^(-1), 1/(yu*yv)}, yw])/32 - 
     (G[{1}, yw]*G[{yu}, yv^(-1)]*G[{1, yu^(-1), 1/(yu*yv)}, yw])/16 - 
     (G[{0}, yu^(-1)]*G[{1/(yu*yv)}, yw]*G[{1, yu^(-1), 1/(yu*yv)}, yw])/16 - 
     (G[{0}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{1, yu^(-1), 1/(yu*yv)}, yw])/16 + 
     (G[{0}, yw]*G[{1/(yu*yv)}, yw]*G[{1, yu^(-1), 1/(yu*yv)}, yw])/16 + 
     (G[{1}, yu^(-1)]*G[{1/(yu*yv)}, yw]*G[{1, yu^(-1), 1/(yu*yv)}, yw])/8 - 
     (G[{1}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{1, yu^(-1), 1/(yu*yv)}, yw])/8 - 
     (G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{1, yu^(-1), 1/(yu*yv)}, yw])/8 + 
     (G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{1, yu^(-1), 1/(yu*yv)}, yw])/8 + 
     (G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{1, yu^(-1), 1/(yu*yv)}, yw])/8 - 
     (G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{1, yu^(-1), 1/(yu*yv)}, yw])/8 - 
     (G[{0, 1}, yu^(-1)]*G[{1, yu^(-1), 1/(yu*yv)}, yw])/16 + 
     (G[{1, yu}, yv^(-1)]*G[{1, yu^(-1), 1/(yu*yv)}, yw])/16 + 
     (G[{1, yv^(-1)}, yw]*G[{1, yu^(-1), 1/(yu*yv)}, yw])/8 + 
     (G[{1, 1/(yu*yv)}, yw]*G[{1, yu^(-1), 1/(yu*yv)}, yw])/8 - 
     (G[{yu^(-1), 1/(yu*yv)}, yw]*G[{1, yu^(-1), 1/(yu*yv)}, yw])/8 + 
     (G[{yv^(-1), 1/(yu*yv)}, yw]*G[{1, yu^(-1), 1/(yu*yv)}, yw])/8 - 
     (23*Pi^2*G[{1, yu, yu}, yv^(-1)])/256 - 
     (3*G[{0}, yu^(-1)]^2*G[{1, yu, yu}, yv^(-1)])/64 - 
     (3*G[{0}, yu^(-1)]*G[{0}, yv^(-1)]*G[{1, yu, yu}, yv^(-1)])/32 - 
     (3*G[{0}, yv^(-1)]^2*G[{1, yu, yu}, yv^(-1)])/64 + 
     (3*G[{0}, yu^(-1)]*G[{0}, yw]*G[{1, yu, yu}, yv^(-1)])/32 + 
     (3*G[{0}, yv^(-1)]*G[{0}, yw]*G[{1, yu, yu}, yv^(-1)])/32 - 
     (3*G[{0}, yw]^2*G[{1, yu, yu}, yv^(-1)])/64 - 
     (9*G[{0}, yu^(-1)]*G[{1}, yu^(-1)]*G[{1, yu, yu}, yv^(-1)])/32 - 
     (9*G[{0}, yv^(-1)]*G[{1}, yu^(-1)]*G[{1, yu, yu}, yv^(-1)])/32 + 
     (9*G[{0}, yw]*G[{1}, yu^(-1)]*G[{1, yu, yu}, yv^(-1)])/32 + 
     (3*G[{1}, yu^(-1)]^2*G[{1, yu, yu}, yv^(-1)])/16 - 
     (G[{0}, yu^(-1)]*G[{1}, yv^(-1)]*G[{1, yu, yu}, yv^(-1)])/32 - 
     (G[{0}, yv^(-1)]*G[{1}, yv^(-1)]*G[{1, yu, yu}, yv^(-1)])/32 + 
     (G[{0}, yw]*G[{1}, yv^(-1)]*G[{1, yu, yu}, yv^(-1)])/32 - 
     (3*G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*G[{1, yu, yu}, yv^(-1)])/32 + 
     (9*G[{1}, yv^(-1)]^2*G[{1, yu, yu}, yv^(-1)])/64 - 
     (7*G[{0}, yu^(-1)]*G[{1}, yw]*G[{1, yu, yu}, yv^(-1)])/32 - 
     (7*G[{0}, yv^(-1)]*G[{1}, yw]*G[{1, yu, yu}, yv^(-1)])/32 + 
     (7*G[{0}, yw]*G[{1}, yw]*G[{1, yu, yu}, yv^(-1)])/32 - 
     (3*G[{1}, yu^(-1)]*G[{1}, yw]*G[{1, yu, yu}, yv^(-1)])/64 - 
     (9*G[{1}, yv^(-1)]*G[{1}, yw]*G[{1, yu, yu}, yv^(-1)])/32 - 
     (7*G[{1}, yw]^2*G[{1, yu, yu}, yv^(-1)])/64 - 
     (3*G[{1}, yw]*G[{yu}, yv^(-1)]*G[{1, yu, yu}, yv^(-1)])/16 + 
     (G[{0}, yu^(-1)]*G[{1/(yu*yv)}, yw]*G[{1, yu, yu}, yv^(-1)])/32 + 
     (G[{0}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{1, yu, yu}, yv^(-1)])/32 - 
     (G[{0}, yw]*G[{1/(yu*yv)}, yw]*G[{1, yu, yu}, yv^(-1)])/32 - 
     (33*G[{1}, yu^(-1)]*G[{1/(yu*yv)}, yw]*G[{1, yu, yu}, yv^(-1)])/64 + 
     (7*G[{1}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{1, yu, yu}, yv^(-1)])/32 - 
     (9*G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{1, yu, yu}, yv^(-1)])/32 - 
     (3*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{1, yu, yu}, yv^(-1)])/32 + 
     (3*G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{1, yu, yu}, yv^(-1)])/16 + 
     (11*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{1, yu, yu}, yv^(-1)])/32 + 
     (3*G[{1/(yu*yv)}, yw]^2*G[{1, yu, yu}, yv^(-1)])/64 - 
     (G[{0, 1}, yu^(-1)]*G[{1, yu, yu}, yv^(-1)])/8 - 
     (G[{0, 1}, yv^(-1)]*G[{1, yu, yu}, yv^(-1)])/4 + 
     (G[{0, 1}, yw]*G[{1, yu, yu}, yv^(-1)])/32 + 
     (3*G[{0, yu^(-1)}, yw]*G[{1, yu, yu}, yv^(-1)])/32 + 
     (G[{0, yu}, yv^(-1)]*G[{1, yu, yu}, yv^(-1)])/4 - 
     (5*G[{0, yv^(-1)}, yw]*G[{1, yu, yu}, yv^(-1)])/32 + 
     (G[{0, 1/(yu*yv)}, yw]*G[{1, yu, yu}, yv^(-1)])/32 - 
     (3*G[{1, yu^(-1)}, yw]*G[{1, yu, yu}, yv^(-1)])/32 - 
     (G[{1, yu}, yv^(-1)]*G[{1, yu, yu}, yv^(-1)])/8 - 
     (G[{1, yv^(-1)}, yw]*G[{1, yu, yu}, yv^(-1)])/32 + 
     (3*G[{1, 1/(yu*yv)}, yw]*G[{1, yu, yu}, yv^(-1)])/16 + 
     (3*G[{yu^(-1), 1/(yu*yv)}, yw]*G[{1, yu, yu}, yv^(-1)])/32 - 
     (11*G[{yv^(-1), 1/(yu*yv)}, yw]*G[{1, yu, yu}, yv^(-1)])/32 - 
     (Pi^2*G[{1, yv^(-1), yu^(-1)}, yw])/32 - 
     (G[{0}, yu^(-1)]*G[{1}, yu^(-1)]*G[{1, yv^(-1), yu^(-1)}, yw])/8 - 
     (G[{0}, yv^(-1)]*G[{1}, yu^(-1)]*G[{1, yv^(-1), yu^(-1)}, yw])/8 + 
     (G[{0}, yw]*G[{1}, yu^(-1)]*G[{1, yv^(-1), yu^(-1)}, yw])/8 + 
     (3*G[{1}, yu^(-1)]^2*G[{1, yv^(-1), yu^(-1)}, yw])/32 + 
     (G[{0}, yu^(-1)]*G[{1}, yv^(-1)]*G[{1, yv^(-1), yu^(-1)}, yw])/8 + 
     (G[{0}, yv^(-1)]*G[{1}, yv^(-1)]*G[{1, yv^(-1), yu^(-1)}, yw])/8 - 
     (G[{0}, yw]*G[{1}, yv^(-1)]*G[{1, yv^(-1), yu^(-1)}, yw])/8 + 
     (G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*G[{1, yv^(-1), yu^(-1)}, yw])/16 - 
     (G[{1}, yv^(-1)]^2*G[{1, yv^(-1), yu^(-1)}, yw])/8 + 
     (G[{1}, yu^(-1)]*G[{1}, yw]*G[{1, yv^(-1), yu^(-1)}, yw])/16 + 
     (G[{1}, yv^(-1)]*G[{1}, yw]*G[{1, yv^(-1), yu^(-1)}, yw])/8 + 
     (3*G[{1}, yw]^2*G[{1, yv^(-1), yu^(-1)}, yw])/32 - 
     (3*G[{1}, yw]*G[{yu}, yv^(-1)]*G[{1, yv^(-1), yu^(-1)}, yw])/16 + 
     (G[{0}, yu^(-1)]*G[{1/(yu*yv)}, yw]*G[{1, yv^(-1), yu^(-1)}, yw])/8 + 
     (G[{0}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{1, yv^(-1), yu^(-1)}, yw])/8 - 
     (G[{0}, yw]*G[{1/(yu*yv)}, yw]*G[{1, yv^(-1), yu^(-1)}, yw])/8 - 
     (G[{1}, yu^(-1)]*G[{1/(yu*yv)}, yw]*G[{1, yv^(-1), yu^(-1)}, yw])/4 - 
     (G[{1}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{1, yv^(-1), yu^(-1)}, yw])/16 - 
     (G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{1, yv^(-1), yu^(-1)}, yw])/16 - 
     (G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{1, yv^(-1), yu^(-1)}, yw])/16 + 
     (G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{1, yv^(-1), yu^(-1)}, yw])/16 + 
     (G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{1, yv^(-1), yu^(-1)}, yw])/8 - 
     (G[{0, 1}, yu^(-1)]*G[{1, yv^(-1), yu^(-1)}, yw])/16 - 
     (G[{0, 1}, yv^(-1)]*G[{1, yv^(-1), yu^(-1)}, yw])/8 + 
     (G[{0, yu}, yv^(-1)]*G[{1, yv^(-1), yu^(-1)}, yw])/8 - 
     (G[{1, yu^(-1)}, yw]*G[{1, yv^(-1), yu^(-1)}, yw])/8 - 
     (G[{1, yu}, yv^(-1)]*G[{1, yv^(-1), yu^(-1)}, yw])/16 - 
     (G[{1, yv^(-1)}, yw]*G[{1, yv^(-1), yu^(-1)}, yw])/16 + 
     (G[{1, 1/(yu*yv)}, yw]*G[{1, yv^(-1), yu^(-1)}, yw])/16 + 
     (G[{yu^(-1), 1/(yu*yv)}, yw]*G[{1, yv^(-1), yu^(-1)}, yw])/16 - 
     (G[{yv^(-1), 1/(yu*yv)}, yw]*G[{1, yv^(-1), yu^(-1)}, yw])/8 - 
     (19*Pi^2*G[{1, yv^(-1), yv^(-1)}, yw])/768 + 
     (3*G[{0}, yu^(-1)]^2*G[{1, yv^(-1), yv^(-1)}, yw])/64 + 
     (3*G[{0}, yu^(-1)]*G[{0}, yv^(-1)]*G[{1, yv^(-1), yv^(-1)}, yw])/32 + 
     (3*G[{0}, yv^(-1)]^2*G[{1, yv^(-1), yv^(-1)}, yw])/64 - 
     (3*G[{0}, yu^(-1)]*G[{0}, yw]*G[{1, yv^(-1), yv^(-1)}, yw])/32 - 
     (3*G[{0}, yv^(-1)]*G[{0}, yw]*G[{1, yv^(-1), yv^(-1)}, yw])/32 + 
     (3*G[{0}, yw]^2*G[{1, yv^(-1), yv^(-1)}, yw])/64 - 
     (3*G[{0}, yu^(-1)]*G[{1}, yu^(-1)]*G[{1, yv^(-1), yv^(-1)}, yw])/32 - 
     (3*G[{0}, yv^(-1)]*G[{1}, yu^(-1)]*G[{1, yv^(-1), yv^(-1)}, yw])/32 + 
     (3*G[{0}, yw]*G[{1}, yu^(-1)]*G[{1, yv^(-1), yv^(-1)}, yw])/32 - 
     (G[{1}, yu^(-1)]^2*G[{1, yv^(-1), yv^(-1)}, yw])/32 - 
     (3*G[{0}, yu^(-1)]*G[{1}, yv^(-1)]*G[{1, yv^(-1), yv^(-1)}, yw])/32 - 
     (3*G[{0}, yv^(-1)]*G[{1}, yv^(-1)]*G[{1, yv^(-1), yv^(-1)}, yw])/32 + 
     (3*G[{0}, yw]*G[{1}, yv^(-1)]*G[{1, yv^(-1), yv^(-1)}, yw])/32 + 
     (G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*G[{1, yv^(-1), yv^(-1)}, yw])/32 + 
     (3*G[{1}, yv^(-1)]^2*G[{1, yv^(-1), yv^(-1)}, yw])/64 - 
     (G[{0}, yu^(-1)]*G[{1}, yw]*G[{1, yv^(-1), yv^(-1)}, yw])/32 - 
     (G[{0}, yv^(-1)]*G[{1}, yw]*G[{1, yv^(-1), yv^(-1)}, yw])/32 + 
     (G[{0}, yw]*G[{1}, yw]*G[{1, yv^(-1), yv^(-1)}, yw])/32 - 
     (G[{1}, yu^(-1)]*G[{1}, yw]*G[{1, yv^(-1), yv^(-1)}, yw])/8 + 
     (G[{1}, yv^(-1)]*G[{1}, yw]*G[{1, yv^(-1), yv^(-1)}, yw])/32 - 
     (5*G[{1}, yw]^2*G[{1, yv^(-1), yv^(-1)}, yw])/64 + 
     (7*G[{1}, yu^(-1)]*G[{yu}, yv^(-1)]*G[{1, yv^(-1), yv^(-1)}, yw])/32 + 
     (5*G[{1}, yw]*G[{yu}, yv^(-1)]*G[{1, yv^(-1), yv^(-1)}, yw])/32 - 
     (7*G[{yu}, yv^(-1)]^2*G[{1, yv^(-1), yv^(-1)}, yw])/64 + 
     (G[{0}, yu^(-1)]*G[{1/(yu*yv)}, yw]*G[{1, yv^(-1), yv^(-1)}, yw])/32 + 
     (G[{0}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{1, yv^(-1), yv^(-1)}, yw])/32 - 
     (G[{0}, yw]*G[{1/(yu*yv)}, yw]*G[{1, yv^(-1), yv^(-1)}, yw])/32 + 
     (G[{1}, yu^(-1)]*G[{1/(yu*yv)}, yw]*G[{1, yv^(-1), yv^(-1)}, yw])/64 - 
     (G[{1}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{1, yv^(-1), yv^(-1)}, yw])/32 + 
     (3*G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{1, yv^(-1), yv^(-1)}, yw])/64 - 
     (3*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{1, yv^(-1), yv^(-1)}, yw])/
      32 - (3*G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{1, yv^(-1), yv^(-1)}, 
        yw])/64 + (G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*
       G[{1, yv^(-1), yv^(-1)}, yw])/32 - 
     (3*G[{1/(yu*yv)}, yw]^2*G[{1, yv^(-1), yv^(-1)}, yw])/64 - 
     (G[{0, 1}, yu^(-1)]*G[{1, yv^(-1), yv^(-1)}, yw])/16 - 
     (G[{0, 1}, yw]*G[{1, yv^(-1), yv^(-1)}, yw])/32 + 
     (G[{0, yu^(-1)}, yw]*G[{1, yv^(-1), yv^(-1)}, yw])/32 + 
     (G[{0, yv^(-1)}, yw]*G[{1, yv^(-1), yv^(-1)}, yw])/32 - 
     (G[{0, 1/(yu*yv)}, yw]*G[{1, yv^(-1), yv^(-1)}, yw])/32 - 
     (G[{1, yu^(-1)}, yw]*G[{1, yv^(-1), yv^(-1)}, yw])/32 + 
     (G[{1, yu}, yv^(-1)]*G[{1, yv^(-1), yv^(-1)}, yw])/16 - 
     (3*G[{1, yv^(-1)}, yw]*G[{1, yv^(-1), yv^(-1)}, yw])/32 + 
     (G[{1, 1/(yu*yv)}, yw]*G[{1, yv^(-1), yv^(-1)}, yw])/8 + 
     (3*G[{yu^(-1), 1/(yu*yv)}, yw]*G[{1, yv^(-1), yv^(-1)}, yw])/32 - 
     (G[{yv^(-1), 1/(yu*yv)}, yw]*G[{1, yv^(-1), yv^(-1)}, yw])/32 + 
     (5*Pi^2*G[{1, yv^(-1), 1/(yu*yv)}, yw])/768 - 
     (3*G[{0}, yu^(-1)]^2*G[{1, yv^(-1), 1/(yu*yv)}, yw])/128 - 
     (3*G[{0}, yu^(-1)]*G[{0}, yv^(-1)]*G[{1, yv^(-1), 1/(yu*yv)}, yw])/64 - 
     (3*G[{0}, yv^(-1)]^2*G[{1, yv^(-1), 1/(yu*yv)}, yw])/128 + 
     (3*G[{0}, yu^(-1)]*G[{0}, yw]*G[{1, yv^(-1), 1/(yu*yv)}, yw])/64 + 
     (3*G[{0}, yv^(-1)]*G[{0}, yw]*G[{1, yv^(-1), 1/(yu*yv)}, yw])/64 - 
     (3*G[{0}, yw]^2*G[{1, yv^(-1), 1/(yu*yv)}, yw])/128 + 
     (3*G[{0}, yu^(-1)]*G[{1}, yu^(-1)]*G[{1, yv^(-1), 1/(yu*yv)}, yw])/64 + 
     (3*G[{0}, yv^(-1)]*G[{1}, yu^(-1)]*G[{1, yv^(-1), 1/(yu*yv)}, yw])/64 - 
     (3*G[{0}, yw]*G[{1}, yu^(-1)]*G[{1, yv^(-1), 1/(yu*yv)}, yw])/64 + 
     (5*G[{1}, yu^(-1)]^2*G[{1, yv^(-1), 1/(yu*yv)}, yw])/128 - 
     (5*G[{0}, yu^(-1)]*G[{1}, yv^(-1)]*G[{1, yv^(-1), 1/(yu*yv)}, yw])/64 - 
     (5*G[{0}, yv^(-1)]*G[{1}, yv^(-1)]*G[{1, yv^(-1), 1/(yu*yv)}, yw])/64 + 
     (5*G[{0}, yw]*G[{1}, yv^(-1)]*G[{1, yv^(-1), 1/(yu*yv)}, yw])/64 - 
     (G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*G[{1, yv^(-1), 1/(yu*yv)}, yw])/16 + 
     (13*G[{1}, yv^(-1)]^2*G[{1, yv^(-1), 1/(yu*yv)}, yw])/128 - 
     (7*G[{0}, yu^(-1)]*G[{1}, yw]*G[{1, yv^(-1), 1/(yu*yv)}, yw])/64 - 
     (7*G[{0}, yv^(-1)]*G[{1}, yw]*G[{1, yv^(-1), 1/(yu*yv)}, yw])/64 + 
     (7*G[{0}, yw]*G[{1}, yw]*G[{1, yv^(-1), 1/(yu*yv)}, yw])/64 + 
     (7*G[{1}, yu^(-1)]*G[{1}, yw]*G[{1, yv^(-1), 1/(yu*yv)}, yw])/64 - 
     (G[{1}, yv^(-1)]*G[{1}, yw]*G[{1, yv^(-1), 1/(yu*yv)}, yw])/64 - 
     (G[{1}, yw]^2*G[{1, yv^(-1), 1/(yu*yv)}, yw])/16 + 
     (G[{0}, yu^(-1)]*G[{yu}, yv^(-1)]*G[{1, yv^(-1), 1/(yu*yv)}, yw])/8 + 
     (G[{0}, yv^(-1)]*G[{yu}, yv^(-1)]*G[{1, yv^(-1), 1/(yu*yv)}, yw])/8 - 
     (G[{0}, yw]*G[{yu}, yv^(-1)]*G[{1, yv^(-1), 1/(yu*yv)}, yw])/8 - 
     (7*G[{1}, yu^(-1)]*G[{yu}, yv^(-1)]*G[{1, yv^(-1), 1/(yu*yv)}, yw])/64 + 
     (G[{1}, yw]*G[{yu}, yv^(-1)]*G[{1, yv^(-1), 1/(yu*yv)}, yw])/8 - 
     (9*G[{yu}, yv^(-1)]^2*G[{1, yv^(-1), 1/(yu*yv)}, yw])/128 - 
     (7*G[{0}, yu^(-1)]*G[{1/(yu*yv)}, yw]*G[{1, yv^(-1), 1/(yu*yv)}, yw])/
      64 - (7*G[{0}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{1, yv^(-1), 1/(yu*yv)}, 
        yw])/64 + (7*G[{0}, yw]*G[{1/(yu*yv)}, yw]*G[{1, yv^(-1), 1/(yu*yv)}, 
        yw])/64 + (7*G[{1}, yu^(-1)]*G[{1/(yu*yv)}, yw]*
       G[{1, yv^(-1), 1/(yu*yv)}, yw])/64 - 
     (5*G[{1}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{1, yv^(-1), 1/(yu*yv)}, yw])/
      64 - (3*G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{1, yv^(-1), 1/(yu*yv)}, yw])/
      16 + (5*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{1, yv^(-1), 1/(yu*yv)}, 
        yw])/64 + (3*G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw]*
       G[{1, yv^(-1), 1/(yu*yv)}, yw])/16 - 
     (13*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{1, yv^(-1), 1/(yu*yv)}, yw])/
      64 - (G[{0, 1}, yu^(-1)]*G[{1, yv^(-1), 1/(yu*yv)}, yw])/64 + 
     (G[{0, 1}, yw]*G[{1, yv^(-1), 1/(yu*yv)}, yw])/64 - 
     (G[{0, yu^(-1)}, yw]*G[{1, yv^(-1), 1/(yu*yv)}, yw])/64 - 
     (G[{0, yv^(-1)}, yw]*G[{1, yv^(-1), 1/(yu*yv)}, yw])/64 + 
     (G[{0, 1/(yu*yv)}, yw]*G[{1, yv^(-1), 1/(yu*yv)}, yw])/64 + 
     (G[{1, yu^(-1)}, yw]*G[{1, yv^(-1), 1/(yu*yv)}, yw])/64 + 
     (G[{1, yu}, yv^(-1)]*G[{1, yv^(-1), 1/(yu*yv)}, yw])/64 + 
     (3*G[{1, 1/(yu*yv)}, yw]*G[{1, yv^(-1), 1/(yu*yv)}, yw])/32 - 
     (5*G[{yu^(-1), 1/(yu*yv)}, yw]*G[{1, yv^(-1), 1/(yu*yv)}, yw])/64 + 
     (13*G[{yv^(-1), 1/(yu*yv)}, yw]*G[{1, yv^(-1), 1/(yu*yv)}, yw])/64 + 
     (G[{0}, yu^(-1)]*G[{1/(yu*yv)}, yw]*G[{1, 1/(yu*yv), yu^(-1)}, yw])/16 + 
     (G[{0}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{1, 1/(yu*yv), yu^(-1)}, yw])/16 - 
     (G[{0}, yw]*G[{1/(yu*yv)}, yw]*G[{1, 1/(yu*yv), yu^(-1)}, yw])/16 + 
     (G[{1}, yu^(-1)]*G[{1/(yu*yv)}, yw]*G[{1, 1/(yu*yv), yu^(-1)}, yw])/4 - 
     (G[{1}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{1, 1/(yu*yv), yu^(-1)}, yw])/4 + 
     (G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{1, 1/(yu*yv), yu^(-1)}, yw])/8 + 
     (G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{1, 1/(yu*yv), yu^(-1)}, yw])/8 - 
     (G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{1, 1/(yu*yv), yu^(-1)}, yw])/8 - 
     (G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{1, 1/(yu*yv), yu^(-1)}, yw])/4 - 
     (G[{yu^(-1), 1/(yu*yv)}, yw]*G[{1, 1/(yu*yv), yu^(-1)}, yw])/8 + 
     (G[{yv^(-1), 1/(yu*yv)}, yw]*G[{1, 1/(yu*yv), yu^(-1)}, yw])/4 - 
     (5*Pi^2*G[{1, 1/(yu*yv), yv^(-1)}, yw])/768 - 
     (3*G[{0}, yu^(-1)]^2*G[{1, 1/(yu*yv), yv^(-1)}, yw])/64 - 
     (3*G[{0}, yu^(-1)]*G[{0}, yv^(-1)]*G[{1, 1/(yu*yv), yv^(-1)}, yw])/32 - 
     (3*G[{0}, yv^(-1)]^2*G[{1, 1/(yu*yv), yv^(-1)}, yw])/64 + 
     (3*G[{0}, yu^(-1)]*G[{0}, yw]*G[{1, 1/(yu*yv), yv^(-1)}, yw])/32 + 
     (3*G[{0}, yv^(-1)]*G[{0}, yw]*G[{1, 1/(yu*yv), yv^(-1)}, yw])/32 - 
     (3*G[{0}, yw]^2*G[{1, 1/(yu*yv), yv^(-1)}, yw])/64 - 
     (G[{0}, yu^(-1)]*G[{1}, yu^(-1)]*G[{1, 1/(yu*yv), yv^(-1)}, yw])/32 - 
     (G[{0}, yv^(-1)]*G[{1}, yu^(-1)]*G[{1, 1/(yu*yv), yv^(-1)}, yw])/32 + 
     (G[{0}, yw]*G[{1}, yu^(-1)]*G[{1, 1/(yu*yv), yv^(-1)}, yw])/32 + 
     (G[{1}, yu^(-1)]^2*G[{1, 1/(yu*yv), yv^(-1)}, yw])/8 - 
     (G[{0}, yu^(-1)]*G[{1}, yv^(-1)]*G[{1, 1/(yu*yv), yv^(-1)}, yw])/32 - 
     (G[{0}, yv^(-1)]*G[{1}, yv^(-1)]*G[{1, 1/(yu*yv), yv^(-1)}, yw])/32 + 
     (G[{0}, yw]*G[{1}, yv^(-1)]*G[{1, 1/(yu*yv), yv^(-1)}, yw])/32 + 
     (G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*G[{1, 1/(yu*yv), yv^(-1)}, yw])/32 + 
     (5*G[{1}, yv^(-1)]^2*G[{1, 1/(yu*yv), yv^(-1)}, yw])/64 - 
     (7*G[{0}, yu^(-1)]*G[{1}, yw]*G[{1, 1/(yu*yv), yv^(-1)}, yw])/32 - 
     (7*G[{0}, yv^(-1)]*G[{1}, yw]*G[{1, 1/(yu*yv), yv^(-1)}, yw])/32 + 
     (7*G[{0}, yw]*G[{1}, yw]*G[{1, 1/(yu*yv), yv^(-1)}, yw])/32 + 
     (3*G[{1}, yu^(-1)]*G[{1}, yw]*G[{1, 1/(yu*yv), yv^(-1)}, yw])/16 + 
     (3*G[{1}, yv^(-1)]*G[{1}, yw]*G[{1, 1/(yu*yv), yv^(-1)}, yw])/32 - 
     (5*G[{1}, yw]^2*G[{1, 1/(yu*yv), yv^(-1)}, yw])/64 + 
     (G[{0}, yu^(-1)]*G[{yu}, yv^(-1)]*G[{1, 1/(yu*yv), yv^(-1)}, yw])/4 + 
     (G[{0}, yv^(-1)]*G[{yu}, yv^(-1)]*G[{1, 1/(yu*yv), yv^(-1)}, yw])/4 - 
     (G[{0}, yw]*G[{yu}, yv^(-1)]*G[{1, 1/(yu*yv), yv^(-1)}, yw])/4 - 
     (7*G[{1}, yu^(-1)]*G[{yu}, yv^(-1)]*G[{1, 1/(yu*yv), yv^(-1)}, yw])/32 + 
     (5*G[{1}, yw]*G[{yu}, yv^(-1)]*G[{1, 1/(yu*yv), yv^(-1)}, yw])/32 - 
     (9*G[{yu}, yv^(-1)]^2*G[{1, 1/(yu*yv), yv^(-1)}, yw])/64 + 
     (3*G[{0}, yu^(-1)]*G[{1/(yu*yv)}, yw]*G[{1, 1/(yu*yv), yv^(-1)}, yw])/
      32 + (3*G[{0}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{1, 1/(yu*yv), yv^(-1)}, 
        yw])/32 - (3*G[{0}, yw]*G[{1/(yu*yv)}, yw]*G[{1, 1/(yu*yv), yv^(-1)}, 
        yw])/32 - (17*G[{1}, yu^(-1)]*G[{1/(yu*yv)}, yw]*
       G[{1, 1/(yu*yv), yv^(-1)}, yw])/64 - 
     (G[{1}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{1, 1/(yu*yv), yv^(-1)}, yw])/32 - 
     (7*G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{1, 1/(yu*yv), yv^(-1)}, yw])/64 + 
     (G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{1, 1/(yu*yv), yv^(-1)}, yw])/
      32 + (7*G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{1, 1/(yu*yv), yv^(-1)}, 
        yw])/64 + (3*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*
       G[{1, 1/(yu*yv), yv^(-1)}, yw])/32 + 
     (3*G[{1/(yu*yv)}, yw]^2*G[{1, 1/(yu*yv), yv^(-1)}, yw])/64 - 
     (G[{0, 1}, yv^(-1)]*G[{1, 1/(yu*yv), yv^(-1)}, yw])/8 + 
     (G[{0, 1}, yw]*G[{1, 1/(yu*yv), yv^(-1)}, yw])/32 - 
     (G[{0, yu^(-1)}, yw]*G[{1, 1/(yu*yv), yv^(-1)}, yw])/32 + 
     (G[{0, yu}, yv^(-1)]*G[{1, 1/(yu*yv), yv^(-1)}, yw])/8 - 
     (G[{0, yv^(-1)}, yw]*G[{1, 1/(yu*yv), yv^(-1)}, yw])/32 + 
     (G[{0, 1/(yu*yv)}, yw]*G[{1, 1/(yu*yv), yv^(-1)}, yw])/32 - 
     (3*G[{1, yu^(-1)}, yw]*G[{1, 1/(yu*yv), yv^(-1)}, yw])/32 - 
     (G[{1, yu}, yv^(-1)]*G[{1, 1/(yu*yv), yv^(-1)}, yw])/8 + 
     (G[{1, yv^(-1)}, yw]*G[{1, 1/(yu*yv), yv^(-1)}, yw])/32 + 
     (G[{1, 1/(yu*yv)}, yw]*G[{1, 1/(yu*yv), yv^(-1)}, yw])/8 - 
     (G[{yu^(-1), 1/(yu*yv)}, yw]*G[{1, 1/(yu*yv), yv^(-1)}, yw])/32 - 
     (3*G[{yv^(-1), 1/(yu*yv)}, yw]*G[{1, 1/(yu*yv), yv^(-1)}, yw])/32 - 
     (13*Pi^2*G[{1, 1/(yu*yv), 1/(yu*yv)}, yw])/768 + 
     (3*G[{0}, yu^(-1)]^2*G[{1, 1/(yu*yv), 1/(yu*yv)}, yw])/128 + 
     (3*G[{0}, yu^(-1)]*G[{0}, yv^(-1)]*G[{1, 1/(yu*yv), 1/(yu*yv)}, yw])/
      64 + (3*G[{0}, yv^(-1)]^2*G[{1, 1/(yu*yv), 1/(yu*yv)}, yw])/128 - 
     (3*G[{0}, yu^(-1)]*G[{0}, yw]*G[{1, 1/(yu*yv), 1/(yu*yv)}, yw])/64 - 
     (3*G[{0}, yv^(-1)]*G[{0}, yw]*G[{1, 1/(yu*yv), 1/(yu*yv)}, yw])/64 + 
     (3*G[{0}, yw]^2*G[{1, 1/(yu*yv), 1/(yu*yv)}, yw])/128 + 
     (G[{0}, yu^(-1)]*G[{1}, yu^(-1)]*G[{1, 1/(yu*yv), 1/(yu*yv)}, yw])/64 + 
     (G[{0}, yv^(-1)]*G[{1}, yu^(-1)]*G[{1, 1/(yu*yv), 1/(yu*yv)}, yw])/64 - 
     (G[{0}, yw]*G[{1}, yu^(-1)]*G[{1, 1/(yu*yv), 1/(yu*yv)}, yw])/64 - 
     (5*G[{1}, yu^(-1)]^2*G[{1, 1/(yu*yv), 1/(yu*yv)}, yw])/128 + 
     (9*G[{0}, yu^(-1)]*G[{1}, yv^(-1)]*G[{1, 1/(yu*yv), 1/(yu*yv)}, yw])/
      64 + (9*G[{0}, yv^(-1)]*G[{1}, yv^(-1)]*G[{1, 1/(yu*yv), 1/(yu*yv)}, 
        yw])/64 - (9*G[{0}, yw]*G[{1}, yv^(-1)]*G[{1, 1/(yu*yv), 1/(yu*yv)}, 
        yw])/64 + (3*G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*
       G[{1, 1/(yu*yv), 1/(yu*yv)}, yw])/16 - 
     (25*G[{1}, yv^(-1)]^2*G[{1, 1/(yu*yv), 1/(yu*yv)}, yw])/128 + 
     (15*G[{0}, yu^(-1)]*G[{1}, yw]*G[{1, 1/(yu*yv), 1/(yu*yv)}, yw])/64 + 
     (15*G[{0}, yv^(-1)]*G[{1}, yw]*G[{1, 1/(yu*yv), 1/(yu*yv)}, yw])/64 - 
     (15*G[{0}, yw]*G[{1}, yw]*G[{1, 1/(yu*yv), 1/(yu*yv)}, yw])/64 + 
     (13*G[{1}, yu^(-1)]*G[{1}, yw]*G[{1, 1/(yu*yv), 1/(yu*yv)}, yw])/64 + 
     (9*G[{1}, yv^(-1)]*G[{1}, yw]*G[{1, 1/(yu*yv), 1/(yu*yv)}, yw])/64 + 
     (13*G[{1}, yw]^2*G[{1, 1/(yu*yv), 1/(yu*yv)}, yw])/32 - 
     (G[{0}, yu^(-1)]*G[{yu}, yv^(-1)]*G[{1, 1/(yu*yv), 1/(yu*yv)}, yw])/4 - 
     (G[{0}, yv^(-1)]*G[{yu}, yv^(-1)]*G[{1, 1/(yu*yv), 1/(yu*yv)}, yw])/4 + 
     (G[{0}, yw]*G[{yu}, yv^(-1)]*G[{1, 1/(yu*yv), 1/(yu*yv)}, yw])/4 - 
     (9*G[{1}, yu^(-1)]*G[{yu}, yv^(-1)]*G[{1, 1/(yu*yv), 1/(yu*yv)}, yw])/
      64 - (13*G[{1}, yw]*G[{yu}, yv^(-1)]*G[{1, 1/(yu*yv), 1/(yu*yv)}, yw])/
      16 + (41*G[{yu}, yv^(-1)]^2*G[{1, 1/(yu*yv), 1/(yu*yv)}, yw])/128 + 
     (3*G[{0}, yu^(-1)]*G[{1/(yu*yv)}, yw]*G[{1, 1/(yu*yv), 1/(yu*yv)}, yw])/
      64 + (3*G[{0}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{1, 1/(yu*yv), 1/(yu*yv)}, 
        yw])/64 - (3*G[{0}, yw]*G[{1/(yu*yv)}, yw]*
       G[{1, 1/(yu*yv), 1/(yu*yv)}, yw])/64 + 
     (G[{1}, yu^(-1)]*G[{1/(yu*yv)}, yw]*G[{1, 1/(yu*yv), 1/(yu*yv)}, yw])/
      64 + (5*G[{1}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{1, 1/(yu*yv), 1/(yu*yv)}, 
        yw])/64 + (3*G[{1}, yw]*G[{1/(yu*yv)}, yw]*
       G[{1, 1/(yu*yv), 1/(yu*yv)}, yw])/16 - 
     (5*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{1, 1/(yu*yv), 1/(yu*yv)}, yw])/
      64 - (3*G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw]*
       G[{1, 1/(yu*yv), 1/(yu*yv)}, yw])/16 + 
     (5*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{1, 1/(yu*yv), 1/(yu*yv)}, yw])/
      64 - (3*G[{0, 1}, yu^(-1)]*G[{1, 1/(yu*yv), 1/(yu*yv)}, yw])/64 - 
     (G[{0, 1}, yv^(-1)]*G[{1, 1/(yu*yv), 1/(yu*yv)}, yw])/8 - 
     (G[{0, 1}, yw]*G[{1, 1/(yu*yv), 1/(yu*yv)}, yw])/64 + 
     (G[{0, yu^(-1)}, yw]*G[{1, 1/(yu*yv), 1/(yu*yv)}, yw])/64 + 
     (G[{0, yu}, yv^(-1)]*G[{1, 1/(yu*yv), 1/(yu*yv)}, yw])/8 + 
     (G[{0, yv^(-1)}, yw]*G[{1, 1/(yu*yv), 1/(yu*yv)}, yw])/64 - 
     (G[{0, 1/(yu*yv)}, yw]*G[{1, 1/(yu*yv), 1/(yu*yv)}, yw])/64 - 
     (9*G[{1, yu^(-1)}, yw]*G[{1, 1/(yu*yv), 1/(yu*yv)}, yw])/64 - 
     (5*G[{1, yu}, yv^(-1)]*G[{1, 1/(yu*yv), 1/(yu*yv)}, yw])/64 - 
     (G[{1, yv^(-1)}, yw]*G[{1, 1/(yu*yv), 1/(yu*yv)}, yw])/16 + 
     (11*G[{1, 1/(yu*yv)}, yw]*G[{1, 1/(yu*yv), 1/(yu*yv)}, yw])/64 + 
     (5*G[{yu^(-1), 1/(yu*yv)}, yw]*G[{1, 1/(yu*yv), 1/(yu*yv)}, yw])/64 - 
     (5*G[{yv^(-1), 1/(yu*yv)}, yw]*G[{1, 1/(yu*yv), 1/(yu*yv)}, yw])/64 + 
     (Pi^2*G[{yu^(-1), yu^(-1), 1/(yu*yv)}, yw])/32 + 
     (5*G[{1}, yu^(-1)]^2*G[{yu^(-1), yu^(-1), 1/(yu*yv)}, yw])/32 - 
     (5*G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*G[{yu^(-1), yu^(-1), 1/(yu*yv)}, yw])/
      16 + (G[{1}, yv^(-1)]^2*G[{yu^(-1), yu^(-1), 1/(yu*yv)}, yw])/16 + 
     (G[{0}, yu^(-1)]*G[{1}, yw]*G[{yu^(-1), yu^(-1), 1/(yu*yv)}, yw])/8 + 
     (G[{0}, yv^(-1)]*G[{1}, yw]*G[{yu^(-1), yu^(-1), 1/(yu*yv)}, yw])/8 - 
     (G[{0}, yw]*G[{1}, yw]*G[{yu^(-1), yu^(-1), 1/(yu*yv)}, yw])/8 - 
     (G[{1}, yu^(-1)]*G[{1}, yw]*G[{yu^(-1), yu^(-1), 1/(yu*yv)}, yw])/16 - 
     (G[{1}, yv^(-1)]*G[{1}, yw]*G[{yu^(-1), yu^(-1), 1/(yu*yv)}, yw])/4 - 
     (G[{1}, yw]^2*G[{yu^(-1), yu^(-1), 1/(yu*yv)}, yw])/32 - 
     (G[{0}, yu^(-1)]*G[{yu^(-1)}, yw]*G[{yu^(-1), yu^(-1), 1/(yu*yv)}, yw])/
      8 - (G[{0}, yv^(-1)]*G[{yu^(-1)}, yw]*G[{yu^(-1), yu^(-1), 1/(yu*yv)}, 
        yw])/8 + (G[{0}, yw]*G[{yu^(-1)}, yw]*
       G[{yu^(-1), yu^(-1), 1/(yu*yv)}, yw])/8 + 
     (3*G[{1}, yu^(-1)]*G[{yu^(-1)}, yw]*G[{yu^(-1), yu^(-1), 1/(yu*yv)}, 
        yw])/8 - (G[{1}, yv^(-1)]*G[{yu^(-1)}, yw]*
       G[{yu^(-1), yu^(-1), 1/(yu*yv)}, yw])/8 + 
     (G[{yu^(-1)}, yw]^2*G[{yu^(-1), yu^(-1), 1/(yu*yv)}, yw])/16 + 
     (G[{1}, yw]*G[{yu}, yv^(-1)]*G[{yu^(-1), yu^(-1), 1/(yu*yv)}, yw])/16 + 
     (G[{0}, yu^(-1)]*G[{1/(yu*yv)}, yw]*G[{yu^(-1), yu^(-1), 1/(yu*yv)}, 
        yw])/16 + (G[{0}, yv^(-1)]*G[{1/(yu*yv)}, yw]*
       G[{yu^(-1), yu^(-1), 1/(yu*yv)}, yw])/16 - 
     (G[{0}, yw]*G[{1/(yu*yv)}, yw]*G[{yu^(-1), yu^(-1), 1/(yu*yv)}, yw])/
      16 - (G[{1}, yv^(-1)]*G[{1/(yu*yv)}, yw]*
       G[{yu^(-1), yu^(-1), 1/(yu*yv)}, yw])/16 + 
     (G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{yu^(-1), yu^(-1), 1/(yu*yv)}, yw])/
      16 + (G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*
       G[{yu^(-1), yu^(-1), 1/(yu*yv)}, yw])/16 - 
     (G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{yu^(-1), yu^(-1), 1/(yu*yv)}, 
        yw])/16 - (G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*
       G[{yu^(-1), yu^(-1), 1/(yu*yv)}, yw])/8 - 
     (G[{0, 1}, yu^(-1)]*G[{yu^(-1), yu^(-1), 1/(yu*yv)}, yw])/16 + 
     (G[{0, 1}, yv^(-1)]*G[{yu^(-1), yu^(-1), 1/(yu*yv)}, yw])/8 + 
     (G[{0, 1}, yw]*G[{yu^(-1), yu^(-1), 1/(yu*yv)}, yw])/8 - 
     (G[{0, yu^(-1)}, yw]*G[{yu^(-1), yu^(-1), 1/(yu*yv)}, yw])/8 - 
     (G[{0, yu}, yv^(-1)]*G[{yu^(-1), yu^(-1), 1/(yu*yv)}, yw])/8 - 
     (G[{0, yv^(-1)}, yw]*G[{yu^(-1), yu^(-1), 1/(yu*yv)}, yw])/8 + 
     (G[{0, 1/(yu*yv)}, yw]*G[{yu^(-1), yu^(-1), 1/(yu*yv)}, yw])/8 + 
     (G[{1, yu^(-1)}, yw]*G[{yu^(-1), yu^(-1), 1/(yu*yv)}, yw])/4 + 
     (3*G[{1, yu}, yv^(-1)]*G[{yu^(-1), yu^(-1), 1/(yu*yv)}, yw])/16 + 
     (G[{1, yv^(-1)}, yw]*G[{yu^(-1), yu^(-1), 1/(yu*yv)}, yw])/16 - 
     (G[{1, 1/(yu*yv)}, yw]*G[{yu^(-1), yu^(-1), 1/(yu*yv)}, yw])/16 - 
     (G[{yu^(-1), 1/(yu*yv)}, yw]*G[{yu^(-1), yu^(-1), 1/(yu*yv)}, yw])/16 + 
     (G[{yv^(-1), 1/(yu*yv)}, yw]*G[{yu^(-1), yu^(-1), 1/(yu*yv)}, yw])/8 + 
     (Pi^2*G[{yu^(-1), 1/(yu*yv), yv^(-1)}, yw])/32 + 
     (G[{0}, yu^(-1)]*G[{1}, yu^(-1)]*G[{yu^(-1), 1/(yu*yv), yv^(-1)}, yw])/
      8 + (G[{0}, yv^(-1)]*G[{1}, yu^(-1)]*G[{yu^(-1), 1/(yu*yv), yv^(-1)}, 
        yw])/8 - (G[{0}, yw]*G[{1}, yu^(-1)]*G[{yu^(-1), 1/(yu*yv), yv^(-1)}, 
        yw])/8 - (3*G[{1}, yu^(-1)]^2*G[{yu^(-1), 1/(yu*yv), yv^(-1)}, yw])/
      32 - (G[{0}, yu^(-1)]*G[{1}, yv^(-1)]*G[{yu^(-1), 1/(yu*yv), yv^(-1)}, 
        yw])/8 - (G[{0}, yv^(-1)]*G[{1}, yv^(-1)]*
       G[{yu^(-1), 1/(yu*yv), yv^(-1)}, yw])/8 + 
     (G[{0}, yw]*G[{1}, yv^(-1)]*G[{yu^(-1), 1/(yu*yv), yv^(-1)}, yw])/8 - 
     (G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*G[{yu^(-1), 1/(yu*yv), yv^(-1)}, yw])/
      16 + (G[{1}, yv^(-1)]^2*G[{yu^(-1), 1/(yu*yv), yv^(-1)}, yw])/8 - 
     (G[{1}, yu^(-1)]*G[{1}, yw]*G[{yu^(-1), 1/(yu*yv), yv^(-1)}, yw])/16 - 
     (G[{1}, yv^(-1)]*G[{1}, yw]*G[{yu^(-1), 1/(yu*yv), yv^(-1)}, yw])/8 - 
     (3*G[{1}, yw]^2*G[{yu^(-1), 1/(yu*yv), yv^(-1)}, yw])/32 + 
     (G[{0}, yu^(-1)]*G[{yu^(-1)}, yw]*G[{yu^(-1), 1/(yu*yv), yv^(-1)}, yw])/
      8 + (G[{0}, yv^(-1)]*G[{yu^(-1)}, yw]*G[{yu^(-1), 1/(yu*yv), yv^(-1)}, 
        yw])/8 - (G[{0}, yw]*G[{yu^(-1)}, yw]*
       G[{yu^(-1), 1/(yu*yv), yv^(-1)}, yw])/8 + 
     (G[{1}, yu^(-1)]*G[{yu^(-1)}, yw]*G[{yu^(-1), 1/(yu*yv), yv^(-1)}, yw])/
      8 - (3*G[{1}, yv^(-1)]*G[{yu^(-1)}, yw]*
       G[{yu^(-1), 1/(yu*yv), yv^(-1)}, yw])/8 + 
     (3*G[{yu^(-1)}, yw]^2*G[{yu^(-1), 1/(yu*yv), yv^(-1)}, yw])/16 + 
     (3*G[{1}, yw]*G[{yu}, yv^(-1)]*G[{yu^(-1), 1/(yu*yv), yv^(-1)}, yw])/
      16 - (G[{0}, yu^(-1)]*G[{1/(yu*yv)}, yw]*
       G[{yu^(-1), 1/(yu*yv), yv^(-1)}, yw])/8 - 
     (G[{0}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{yu^(-1), 1/(yu*yv), yv^(-1)}, 
        yw])/8 + (G[{0}, yw]*G[{1/(yu*yv)}, yw]*
       G[{yu^(-1), 1/(yu*yv), yv^(-1)}, yw])/8 + 
     (G[{1}, yu^(-1)]*G[{1/(yu*yv)}, yw]*G[{yu^(-1), 1/(yu*yv), yv^(-1)}, 
        yw])/4 + (G[{1}, yv^(-1)]*G[{1/(yu*yv)}, yw]*
       G[{yu^(-1), 1/(yu*yv), yv^(-1)}, yw])/16 + 
     (G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{yu^(-1), 1/(yu*yv), yv^(-1)}, yw])/
      16 - (G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*
       G[{yu^(-1), 1/(yu*yv), yv^(-1)}, yw])/16 - 
     (G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{yu^(-1), 1/(yu*yv), yv^(-1)}, 
        yw])/16 - (G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*
       G[{yu^(-1), 1/(yu*yv), yv^(-1)}, yw])/8 + 
     (G[{0, 1}, yu^(-1)]*G[{yu^(-1), 1/(yu*yv), yv^(-1)}, yw])/16 + 
     (G[{0, 1}, yv^(-1)]*G[{yu^(-1), 1/(yu*yv), yv^(-1)}, yw])/8 - 
     (G[{0, yu}, yv^(-1)]*G[{yu^(-1), 1/(yu*yv), yv^(-1)}, yw])/8 + 
     (G[{1, yu^(-1)}, yw]*G[{yu^(-1), 1/(yu*yv), yv^(-1)}, yw])/8 + 
     (G[{1, yu}, yv^(-1)]*G[{yu^(-1), 1/(yu*yv), yv^(-1)}, yw])/16 + 
     (G[{1, yv^(-1)}, yw]*G[{yu^(-1), 1/(yu*yv), yv^(-1)}, yw])/16 - 
     (3*G[{1, 1/(yu*yv)}, yw]*G[{yu^(-1), 1/(yu*yv), yv^(-1)}, yw])/16 + 
     (G[{yu^(-1), 1/(yu*yv)}, yw]*G[{yu^(-1), 1/(yu*yv), yv^(-1)}, yw])/8 + 
     (G[{yv^(-1), 1/(yu*yv)}, yw]*G[{yu^(-1), 1/(yu*yv), yv^(-1)}, yw])/8 + 
     (Pi^2*G[{yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/96 - 
     (G[{0}, yu^(-1)]*G[{1}, yu^(-1)]*G[{yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/
      16 - (G[{0}, yv^(-1)]*G[{1}, yu^(-1)]*
       G[{yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/16 + 
     (G[{0}, yw]*G[{1}, yu^(-1)]*G[{yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/16 + 
     (G[{0}, yu^(-1)]*G[{1}, yv^(-1)]*G[{yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/
      16 + (G[{0}, yv^(-1)]*G[{1}, yv^(-1)]*
       G[{yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/16 - 
     (G[{0}, yw]*G[{1}, yv^(-1)]*G[{yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/16 - 
     (G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*G[{yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/
      8 - (G[{1}, yv^(-1)]^2*G[{yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/32 - 
     (5*G[{1}, yu^(-1)]*G[{1}, yw]*G[{yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/
      16 - (G[{1}, yv^(-1)]*G[{1}, yw]*G[{yu^(-1), 1/(yu*yv), 1/(yu*yv)}, 
        yw])/8 - (7*G[{1}, yw]^2*G[{yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/32 - 
     (G[{0}, yu^(-1)]*G[{yu^(-1)}, yw]*G[{yu^(-1), 1/(yu*yv), 1/(yu*yv)}, 
        yw])/16 - (G[{0}, yv^(-1)]*G[{yu^(-1)}, yw]*
       G[{yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/16 + 
     (G[{0}, yw]*G[{yu^(-1)}, yw]*G[{yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/
      16 + (3*G[{1}, yu^(-1)]*G[{yu^(-1)}, yw]*
       G[{yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/16 - 
     (G[{1}, yv^(-1)]*G[{yu^(-1)}, yw]*G[{yu^(-1), 1/(yu*yv), 1/(yu*yv)}, 
        yw])/16 + (G[{yu^(-1)}, yw]^2*G[{yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/
      32 + (G[{1}, yu^(-1)]*G[{yu}, yv^(-1)]*
       G[{yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/4 + 
     (7*G[{1}, yw]*G[{yu}, yv^(-1)]*G[{yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/
      16 - (G[{yu}, yv^(-1)]^2*G[{yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/8 + 
     (G[{0}, yu^(-1)]*G[{1/(yu*yv)}, yw]*G[{yu^(-1), 1/(yu*yv), 1/(yu*yv)}, 
        yw])/16 + (G[{0}, yv^(-1)]*G[{1/(yu*yv)}, yw]*
       G[{yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/16 - 
     (G[{0}, yw]*G[{1/(yu*yv)}, yw]*G[{yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/
      16 - (G[{1}, yu^(-1)]*G[{1/(yu*yv)}, yw]*
       G[{yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/8 + 
     (G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{yu^(-1), 1/(yu*yv), 1/(yu*yv)}, 
        yw])/8 + (G[{0, 1}, yu^(-1)]*G[{yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/
      16 + (G[{0, 1}, yv^(-1)]*G[{yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/8 - 
     (G[{0, yu}, yv^(-1)]*G[{yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/8 + 
     (G[{1, yu^(-1)}, yw]*G[{yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/8 + 
     (G[{1, yu}, yv^(-1)]*G[{yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/16 + 
     (G[{1, yv^(-1)}, yw]*G[{yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/16 - 
     (3*G[{1, 1/(yu*yv)}, yw]*G[{yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/16 + 
     (G[{yu^(-1), 1/(yu*yv)}, yw]*G[{yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/8 - 
     (G[{yv^(-1), 1/(yu*yv)}, yw]*G[{yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/8 + 
     (Pi^2*G[{yv^(-1), yv^(-1), 1/(yu*yv)}, yw])/256 - 
     (3*G[{0}, yu^(-1)]^2*G[{yv^(-1), yv^(-1), 1/(yu*yv)}, yw])/64 - 
     (3*G[{0}, yu^(-1)]*G[{0}, yv^(-1)]*G[{yv^(-1), yv^(-1), 1/(yu*yv)}, yw])/
      32 - (3*G[{0}, yv^(-1)]^2*G[{yv^(-1), yv^(-1), 1/(yu*yv)}, yw])/64 + 
     (3*G[{0}, yu^(-1)]*G[{0}, yw]*G[{yv^(-1), yv^(-1), 1/(yu*yv)}, yw])/32 + 
     (3*G[{0}, yv^(-1)]*G[{0}, yw]*G[{yv^(-1), yv^(-1), 1/(yu*yv)}, yw])/32 - 
     (3*G[{0}, yw]^2*G[{yv^(-1), yv^(-1), 1/(yu*yv)}, yw])/64 + 
     (3*G[{0}, yu^(-1)]*G[{1}, yu^(-1)]*G[{yv^(-1), yv^(-1), 1/(yu*yv)}, yw])/
      32 + (3*G[{0}, yv^(-1)]*G[{1}, yu^(-1)]*
       G[{yv^(-1), yv^(-1), 1/(yu*yv)}, yw])/32 - 
     (3*G[{0}, yw]*G[{1}, yu^(-1)]*G[{yv^(-1), yv^(-1), 1/(yu*yv)}, yw])/32 - 
     (G[{1}, yu^(-1)]^2*G[{yv^(-1), yv^(-1), 1/(yu*yv)}, yw])/32 + 
     (3*G[{0}, yu^(-1)]*G[{1}, yv^(-1)]*G[{yv^(-1), yv^(-1), 1/(yu*yv)}, yw])/
      32 + (3*G[{0}, yv^(-1)]*G[{1}, yv^(-1)]*
       G[{yv^(-1), yv^(-1), 1/(yu*yv)}, yw])/32 - 
     (3*G[{0}, yw]*G[{1}, yv^(-1)]*G[{yv^(-1), yv^(-1), 1/(yu*yv)}, yw])/32 + 
     (3*G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*G[{yv^(-1), yv^(-1), 1/(yu*yv)}, yw])/
      32 - (3*G[{1}, yv^(-1)]^2*G[{yv^(-1), yv^(-1), 1/(yu*yv)}, yw])/64 - 
     (7*G[{0}, yu^(-1)]*G[{1}, yw]*G[{yv^(-1), yv^(-1), 1/(yu*yv)}, yw])/32 - 
     (7*G[{0}, yv^(-1)]*G[{1}, yw]*G[{yv^(-1), yv^(-1), 1/(yu*yv)}, yw])/32 + 
     (7*G[{0}, yw]*G[{1}, yw]*G[{yv^(-1), yv^(-1), 1/(yu*yv)}, yw])/32 + 
     (G[{1}, yu^(-1)]*G[{1}, yw]*G[{yv^(-1), yv^(-1), 1/(yu*yv)}, yw])/4 + 
     (7*G[{1}, yv^(-1)]*G[{1}, yw]*G[{yv^(-1), yv^(-1), 1/(yu*yv)}, yw])/32 + 
     (G[{1}, yw]^2*G[{yv^(-1), yv^(-1), 1/(yu*yv)}, yw])/64 + 
     (G[{0}, yu^(-1)]*G[{yu^(-1)}, yw]*G[{yv^(-1), yv^(-1), 1/(yu*yv)}, yw])/
      8 + (G[{0}, yv^(-1)]*G[{yu^(-1)}, yw]*G[{yv^(-1), yv^(-1), 1/(yu*yv)}, 
        yw])/8 - (G[{0}, yw]*G[{yu^(-1)}, yw]*
       G[{yv^(-1), yv^(-1), 1/(yu*yv)}, yw])/8 - 
     (G[{1}, yu^(-1)]*G[{yu^(-1)}, yw]*G[{yv^(-1), yv^(-1), 1/(yu*yv)}, yw])/
      8 - (G[{1}, yv^(-1)]*G[{yu^(-1)}, yw]*G[{yv^(-1), yv^(-1), 1/(yu*yv)}, 
        yw])/8 + (G[{yu^(-1)}, yw]^2*G[{yv^(-1), yv^(-1), 1/(yu*yv)}, yw])/
      16 - (7*G[{1}, yu^(-1)]*G[{yu}, yv^(-1)]*
       G[{yv^(-1), yv^(-1), 1/(yu*yv)}, yw])/32 - 
     (G[{1}, yw]*G[{yu}, yv^(-1)]*G[{yv^(-1), yv^(-1), 1/(yu*yv)}, yw])/32 + 
     (7*G[{yu}, yv^(-1)]^2*G[{yv^(-1), yv^(-1), 1/(yu*yv)}, yw])/64 + 
     (G[{0}, yu^(-1)]*G[{yv^(-1)}, yw]*G[{yv^(-1), yv^(-1), 1/(yu*yv)}, yw])/
      8 + (G[{0}, yv^(-1)]*G[{yv^(-1)}, yw]*G[{yv^(-1), yv^(-1), 1/(yu*yv)}, 
        yw])/8 - (G[{0}, yw]*G[{yv^(-1)}, yw]*
       G[{yv^(-1), yv^(-1), 1/(yu*yv)}, yw])/8 - 
     (11*G[{1}, yu^(-1)]*G[{yv^(-1)}, yw]*G[{yv^(-1), yv^(-1), 1/(yu*yv)}, 
        yw])/32 - (G[{1}, yv^(-1)]*G[{yv^(-1)}, yw]*
       G[{yv^(-1), yv^(-1), 1/(yu*yv)}, yw])/8 - 
     (7*G[{1}, yw]*G[{yv^(-1)}, yw]*G[{yv^(-1), yv^(-1), 1/(yu*yv)}, yw])/
      32 + (G[{yu^(-1)}, yw]*G[{yv^(-1)}, yw]*
       G[{yv^(-1), yv^(-1), 1/(yu*yv)}, yw])/8 + 
     (7*G[{yu}, yv^(-1)]*G[{yv^(-1)}, yw]*G[{yv^(-1), yv^(-1), 1/(yu*yv)}, 
        yw])/32 + (11*G[{yv^(-1)}, yw]^2*G[{yv^(-1), yv^(-1), 1/(yu*yv)}, 
        yw])/64 + (3*G[{0}, yu^(-1)]*G[{1/(yu*yv)}, yw]*
       G[{yv^(-1), yv^(-1), 1/(yu*yv)}, yw])/32 + 
     (3*G[{0}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{yv^(-1), yv^(-1), 1/(yu*yv)}, 
        yw])/32 - (3*G[{0}, yw]*G[{1/(yu*yv)}, yw]*
       G[{yv^(-1), yv^(-1), 1/(yu*yv)}, yw])/32 - 
     (17*G[{1}, yu^(-1)]*G[{1/(yu*yv)}, yw]*G[{yv^(-1), yv^(-1), 1/(yu*yv)}, 
        yw])/64 - (3*G[{1}, yv^(-1)]*G[{1/(yu*yv)}, yw]*
       G[{yv^(-1), yv^(-1), 1/(yu*yv)}, yw])/32 - 
     (11*G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{yv^(-1), yv^(-1), 1/(yu*yv)}, yw])/
      64 + (3*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*
       G[{yv^(-1), yv^(-1), 1/(yu*yv)}, yw])/32 + 
     (11*G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{yv^(-1), yv^(-1), 1/(yu*yv)}, 
        yw])/64 + (17*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*
       G[{yv^(-1), yv^(-1), 1/(yu*yv)}, yw])/64 + 
     (3*G[{1/(yu*yv)}, yw]^2*G[{yv^(-1), yv^(-1), 1/(yu*yv)}, yw])/64 + 
     (3*G[{0, 1}, yu^(-1)]*G[{yv^(-1), yv^(-1), 1/(yu*yv)}, yw])/16 - 
     (7*G[{0, 1}, yw]*G[{yv^(-1), yv^(-1), 1/(yu*yv)}, yw])/32 + 
     (7*G[{0, yu^(-1)}, yw]*G[{yv^(-1), yv^(-1), 1/(yu*yv)}, yw])/32 + 
     (7*G[{0, yv^(-1)}, yw]*G[{yv^(-1), yv^(-1), 1/(yu*yv)}, yw])/32 - 
     (7*G[{0, 1/(yu*yv)}, yw]*G[{yv^(-1), yv^(-1), 1/(yu*yv)}, yw])/32 - 
     (7*G[{1, yu^(-1)}, yw]*G[{yv^(-1), yv^(-1), 1/(yu*yv)}, yw])/32 - 
     (3*G[{1, yu}, yv^(-1)]*G[{yv^(-1), yv^(-1), 1/(yu*yv)}, yw])/16 - 
     (G[{1, yv^(-1)}, yw]*G[{yv^(-1), yv^(-1), 1/(yu*yv)}, yw])/32 - 
     (3*G[{1, 1/(yu*yv)}, yw]*G[{yv^(-1), yv^(-1), 1/(yu*yv)}, yw])/16 + 
     (7*G[{yu^(-1), 1/(yu*yv)}, yw]*G[{yv^(-1), yv^(-1), 1/(yu*yv)}, yw])/
      32 - (7*G[{yv^(-1), 1/(yu*yv)}, yw]*G[{yv^(-1), yv^(-1), 1/(yu*yv)}, 
        yw])/32 - (11*Pi^2*G[{yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/768 - 
     (3*G[{0}, yu^(-1)]^2*G[{yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/128 - 
     (3*G[{0}, yu^(-1)]*G[{0}, yv^(-1)]*G[{yv^(-1), 1/(yu*yv), 1/(yu*yv)}, 
        yw])/64 - (3*G[{0}, yv^(-1)]^2*G[{yv^(-1), 1/(yu*yv), 1/(yu*yv)}, 
        yw])/128 + (3*G[{0}, yu^(-1)]*G[{0}, yw]*
       G[{yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/64 + 
     (3*G[{0}, yv^(-1)]*G[{0}, yw]*G[{yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/
      64 - (3*G[{0}, yw]^2*G[{yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/128 - 
     (5*G[{0}, yu^(-1)]*G[{1}, yu^(-1)]*G[{yv^(-1), 1/(yu*yv), 1/(yu*yv)}, 
        yw])/64 - (5*G[{0}, yv^(-1)]*G[{1}, yu^(-1)]*
       G[{yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/64 + 
     (5*G[{0}, yw]*G[{1}, yu^(-1)]*G[{yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/
      64 + (29*G[{1}, yu^(-1)]^2*G[{yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/
      128 + (3*G[{0}, yu^(-1)]*G[{1}, yv^(-1)]*
       G[{yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/64 + 
     (3*G[{0}, yv^(-1)]*G[{1}, yv^(-1)]*G[{yv^(-1), 1/(yu*yv), 1/(yu*yv)}, 
        yw])/64 - (3*G[{0}, yw]*G[{1}, yv^(-1)]*
       G[{yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/64 + 
     (G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*G[{yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/
      16 - (11*G[{1}, yv^(-1)]^2*G[{yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/
      128 - (23*G[{0}, yu^(-1)]*G[{1}, yw]*G[{yv^(-1), 1/(yu*yv), 1/(yu*yv)}, 
        yw])/64 - (23*G[{0}, yv^(-1)]*G[{1}, yw]*
       G[{yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/64 + 
     (23*G[{0}, yw]*G[{1}, yw]*G[{yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/64 + 
     (39*G[{1}, yu^(-1)]*G[{1}, yw]*G[{yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/
      64 + (15*G[{1}, yv^(-1)]*G[{1}, yw]*G[{yv^(-1), 1/(yu*yv), 1/(yu*yv)}, 
        yw])/64 + (G[{1}, yw]^2*G[{yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/16 + 
     (3*G[{0}, yu^(-1)]*G[{yu^(-1)}, yw]*G[{yv^(-1), 1/(yu*yv), 1/(yu*yv)}, 
        yw])/16 + (3*G[{0}, yv^(-1)]*G[{yu^(-1)}, yw]*
       G[{yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/16 - 
     (3*G[{0}, yw]*G[{yu^(-1)}, yw]*G[{yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/
      16 - (5*G[{1}, yu^(-1)]*G[{yu^(-1)}, yw]*
       G[{yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/16 - 
     (G[{1}, yv^(-1)]*G[{yu^(-1)}, yw]*G[{yv^(-1), 1/(yu*yv), 1/(yu*yv)}, 
        yw])/16 + (G[{yu^(-1)}, yw]^2*G[{yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/
      32 + (G[{0}, yu^(-1)]*G[{yu}, yv^(-1)]*
       G[{yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/8 + 
     (G[{0}, yv^(-1)]*G[{yu}, yv^(-1)]*G[{yv^(-1), 1/(yu*yv), 1/(yu*yv)}, 
        yw])/8 - (G[{0}, yw]*G[{yu}, yv^(-1)]*
       G[{yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/8 - 
     (23*G[{1}, yu^(-1)]*G[{yu}, yv^(-1)]*G[{yv^(-1), 1/(yu*yv), 1/(yu*yv)}, 
        yw])/64 - (G[{1}, yw]*G[{yu}, yv^(-1)]*
       G[{yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/8 + 
     (7*G[{yu}, yv^(-1)]^2*G[{yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/128 + 
     (5*G[{0}, yu^(-1)]*G[{yv^(-1)}, yw]*G[{yv^(-1), 1/(yu*yv), 1/(yu*yv)}, 
        yw])/16 + (5*G[{0}, yv^(-1)]*G[{yv^(-1)}, yw]*
       G[{yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/16 - 
     (5*G[{0}, yw]*G[{yv^(-1)}, yw]*G[{yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/
      16 - (43*G[{1}, yu^(-1)]*G[{yv^(-1)}, yw]*
       G[{yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/64 - 
     (5*G[{1}, yv^(-1)]*G[{yv^(-1)}, yw]*G[{yv^(-1), 1/(yu*yv), 1/(yu*yv)}, 
        yw])/16 - (23*G[{1}, yw]*G[{yv^(-1)}, yw]*
       G[{yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/64 + 
     (5*G[{yu^(-1)}, yw]*G[{yv^(-1)}, yw]*G[{yv^(-1), 1/(yu*yv), 1/(yu*yv)}, 
        yw])/16 + (23*G[{yu}, yv^(-1)]*G[{yv^(-1)}, yw]*
       G[{yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/64 + 
     (43*G[{yv^(-1)}, yw]^2*G[{yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/128 + 
     (G[{0}, yu^(-1)]*G[{1/(yu*yv)}, yw]*G[{yv^(-1), 1/(yu*yv), 1/(yu*yv)}, 
        yw])/64 + (G[{0}, yv^(-1)]*G[{1/(yu*yv)}, yw]*
       G[{yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/64 - 
     (G[{0}, yw]*G[{1/(yu*yv)}, yw]*G[{yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/
      64 - (9*G[{1}, yu^(-1)]*G[{1/(yu*yv)}, yw]*
       G[{yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/64 + 
     (3*G[{1}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{yv^(-1), 1/(yu*yv), 1/(yu*yv)}, 
        yw])/64 - (G[{1}, yw]*G[{1/(yu*yv)}, yw]*
       G[{yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/16 - 
     (3*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*
       G[{yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/64 + 
     (G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{yv^(-1), 1/(yu*yv), 1/(yu*yv)}, 
        yw])/16 + (9*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*
       G[{yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/64 - 
     (G[{0, 1}, yu^(-1)]*G[{yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/64 - 
     (15*G[{0, 1}, yw]*G[{yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/64 + 
     (15*G[{0, yu^(-1)}, yw]*G[{yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/64 + 
     (15*G[{0, yv^(-1)}, yw]*G[{yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/64 - 
     (15*G[{0, 1/(yu*yv)}, yw]*G[{yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/64 - 
     (15*G[{1, yu^(-1)}, yw]*G[{yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/64 + 
     (G[{1, yu}, yv^(-1)]*G[{yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/64 - 
     (G[{1, yv^(-1)}, yw]*G[{yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/4 + 
     (G[{1, 1/(yu*yv)}, yw]*G[{yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/64 + 
     (15*G[{yu^(-1), 1/(yu*yv)}, yw]*G[{yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/
      64 + (7*G[{yv^(-1), 1/(yu*yv)}, yw]*G[{yv^(-1), 1/(yu*yv), 1/(yu*yv)}, 
        yw])/32 + (G[{0}, yu^(-1)]*G[{0, 0, 1, 1}, yu^(-1)])/8 + 
     (G[{0}, yv^(-1)]*G[{0, 0, 1, 1}, yu^(-1)])/8 - 
     (G[{0}, yw]*G[{0, 0, 1, 1}, yu^(-1)])/8 - 
     (3*G[{1}, yu^(-1)]*G[{0, 0, 1, 1}, yu^(-1)])/32 - 
     (G[{1}, yv^(-1)]*G[{0, 0, 1, 1}, yu^(-1)])/32 + 
     (G[{1}, yw]*G[{0, 0, 1, 1}, yu^(-1)])/32 + 
     (3*G[{1/(yu*yv)}, yw]*G[{0, 0, 1, 1}, yu^(-1)])/32 + 
     (G[{1}, yv^(-1)]*G[{0, 0, 1, 1}, yv^(-1)])/8 - 
     (G[{1}, yw]*G[{0, 0, 1, 1}, yv^(-1)])/8 - 
     (G[{0}, yu^(-1)]*G[{0, 0, 1, 1}, yw])/16 - 
     (G[{0}, yv^(-1)]*G[{0, 0, 1, 1}, yw])/16 + 
     (G[{0}, yw]*G[{0, 0, 1, 1}, yw])/16 + 
     (G[{1}, yu^(-1)]*G[{0, 0, 1, 1}, yw])/16 + 
     (G[{1}, yv^(-1)]*G[{0, 0, 1, 1}, yw])/16 + 
     (G[{1}, yw]*G[{0, 0, 1, 1}, yw])/8 - 
     (G[{1/(yu*yv)}, yw]*G[{0, 0, 1, 1}, yw])/8 - 
     (G[{0}, yu^(-1)]*G[{0, 0, 1, yu^(-1)}, yw])/16 - 
     (G[{0}, yv^(-1)]*G[{0, 0, 1, yu^(-1)}, yw])/16 + 
     (G[{0}, yw]*G[{0, 0, 1, yu^(-1)}, yw])/16 + 
     (G[{1}, yu^(-1)]*G[{0, 0, 1, yu^(-1)}, yw])/16 + 
     (G[{1}, yv^(-1)]*G[{0, 0, 1, yu^(-1)}, yw])/16 - 
     (G[{1}, yw]*G[{0, 0, 1, yu^(-1)}, yw])/8 + 
     (G[{1/(yu*yv)}, yw]*G[{0, 0, 1, yu^(-1)}, yw])/8 + 
     (G[{0}, yu^(-1)]*G[{0, 0, 1, yu}, yv^(-1)])/16 + 
     (G[{0}, yv^(-1)]*G[{0, 0, 1, yu}, yv^(-1)])/16 - 
     (G[{0}, yw]*G[{0, 0, 1, yu}, yv^(-1)])/16 - 
     (G[{1}, yv^(-1)]*G[{0, 0, 1, yu}, yv^(-1)])/4 + 
     (G[{1}, yw]*G[{0, 0, 1, yu}, yv^(-1)])/4 + 
     (G[{0}, yu^(-1)]*G[{0, 0, 1, yv^(-1)}, yw])/16 + 
     (G[{0}, yv^(-1)]*G[{0, 0, 1, yv^(-1)}, yw])/16 - 
     (G[{0}, yw]*G[{0, 0, 1, yv^(-1)}, yw])/16 - 
     (G[{1}, yu^(-1)]*G[{0, 0, 1, yv^(-1)}, yw])/16 - 
     (G[{1}, yv^(-1)]*G[{0, 0, 1, yv^(-1)}, yw])/16 - 
     (G[{1}, yw]*G[{0, 0, 1, yv^(-1)}, yw])/8 + 
     (G[{1/(yu*yv)}, yw]*G[{0, 0, 1, yv^(-1)}, yw])/8 + 
     (G[{0}, yu^(-1)]*G[{0, 0, 1, 1/(yu*yv)}, yw])/16 + 
     (G[{0}, yv^(-1)]*G[{0, 0, 1, 1/(yu*yv)}, yw])/16 - 
     (G[{0}, yw]*G[{0, 0, 1, 1/(yu*yv)}, yw])/16 - 
     (3*G[{1}, yu^(-1)]*G[{0, 0, 1, 1/(yu*yv)}, yw])/16 + 
     (G[{1}, yv^(-1)]*G[{0, 0, 1, 1/(yu*yv)}, yw])/16 - 
     (G[{0}, yu^(-1)]*G[{0, 0, yu^(-1), 1}, yw])/16 - 
     (G[{0}, yv^(-1)]*G[{0, 0, yu^(-1), 1}, yw])/16 + 
     (G[{0}, yw]*G[{0, 0, yu^(-1), 1}, yw])/16 + 
     (3*G[{1}, yu^(-1)]*G[{0, 0, yu^(-1), 1}, yw])/16 - 
     (G[{1}, yv^(-1)]*G[{0, 0, yu^(-1), 1}, yw])/16 + 
     (G[{0}, yu^(-1)]*G[{0, 0, yu^(-1), yu^(-1)}, yw])/16 + 
     (G[{0}, yv^(-1)]*G[{0, 0, yu^(-1), yu^(-1)}, yw])/16 - 
     (G[{0}, yw]*G[{0, 0, yu^(-1), yu^(-1)}, yw])/16 - 
     (3*G[{1}, yu^(-1)]*G[{0, 0, yu^(-1), yu^(-1)}, yw])/16 + 
     (G[{1}, yv^(-1)]*G[{0, 0, yu^(-1), yu^(-1)}, yw])/16 - 
     (G[{1}, yw]*G[{0, 0, yu^(-1), yu^(-1)}, yw])/8 - 
     (G[{0}, yu^(-1)]*G[{0, 0, yu^(-1), yv^(-1)}, yw])/16 - 
     (G[{0}, yv^(-1)]*G[{0, 0, yu^(-1), yv^(-1)}, yw])/16 + 
     (G[{0}, yw]*G[{0, 0, yu^(-1), yv^(-1)}, yw])/16 + 
     (G[{1}, yu^(-1)]*G[{0, 0, yu^(-1), yv^(-1)}, yw])/16 + 
     (G[{1}, yv^(-1)]*G[{0, 0, yu^(-1), yv^(-1)}, yw])/16 - 
     (G[{1/(yu*yv)}, yw]*G[{0, 0, yu^(-1), yv^(-1)}, yw])/8 - 
     (G[{0}, yu^(-1)]*G[{0, 0, yu^(-1), 1/(yu*yv)}, yw])/16 - 
     (G[{0}, yv^(-1)]*G[{0, 0, yu^(-1), 1/(yu*yv)}, yw])/16 + 
     (G[{0}, yw]*G[{0, 0, yu^(-1), 1/(yu*yv)}, yw])/16 + 
     (3*G[{1}, yu^(-1)]*G[{0, 0, yu^(-1), 1/(yu*yv)}, yw])/16 - 
     (G[{1}, yv^(-1)]*G[{0, 0, yu^(-1), 1/(yu*yv)}, yw])/16 + 
     (G[{1}, yw]*G[{0, 0, yu^(-1), 1/(yu*yv)}, yw])/8 + 
     (G[{0}, yu^(-1)]*G[{0, 0, yu, 1}, yv^(-1)])/16 + 
     (G[{0}, yv^(-1)]*G[{0, 0, yu, 1}, yv^(-1)])/16 - 
     (G[{0}, yw]*G[{0, 0, yu, 1}, yv^(-1)])/16 - 
     (G[{1}, yv^(-1)]*G[{0, 0, yu, 1}, yv^(-1)])/4 + 
     (G[{1}, yw]*G[{0, 0, yu, 1}, yv^(-1)])/4 + 
     (G[{1}, yv^(-1)]*G[{0, 0, yu, yu}, yv^(-1)])/4 - 
     (G[{1}, yw]*G[{0, 0, yu, yu}, yv^(-1)])/4 + 
     (G[{0}, yu^(-1)]*G[{0, 0, yv^(-1), 1}, yw])/16 + 
     (G[{0}, yv^(-1)]*G[{0, 0, yv^(-1), 1}, yw])/16 - 
     (G[{0}, yw]*G[{0, 0, yv^(-1), 1}, yw])/16 + 
     (3*G[{1}, yu^(-1)]*G[{0, 0, yv^(-1), 1}, yw])/16 - 
     (G[{1}, yv^(-1)]*G[{0, 0, yv^(-1), 1}, yw])/16 - 
     (G[{yu}, yv^(-1)]*G[{0, 0, yv^(-1), 1}, yw])/4 - 
     (G[{0}, yu^(-1)]*G[{0, 0, yv^(-1), yu^(-1)}, yw])/16 - 
     (G[{0}, yv^(-1)]*G[{0, 0, yv^(-1), yu^(-1)}, yw])/16 + 
     (G[{0}, yw]*G[{0, 0, yv^(-1), yu^(-1)}, yw])/16 + 
     (G[{1}, yu^(-1)]*G[{0, 0, yv^(-1), yu^(-1)}, yw])/16 + 
     (G[{1}, yv^(-1)]*G[{0, 0, yv^(-1), yu^(-1)}, yw])/16 - 
     (G[{1/(yu*yv)}, yw]*G[{0, 0, yv^(-1), yu^(-1)}, yw])/8 - 
     (G[{0}, yu^(-1)]*G[{0, 0, yv^(-1), yv^(-1)}, yw])/16 - 
     (G[{0}, yv^(-1)]*G[{0, 0, yv^(-1), yv^(-1)}, yw])/16 + 
     (G[{0}, yw]*G[{0, 0, yv^(-1), yv^(-1)}, yw])/16 + 
     (G[{1}, yu^(-1)]*G[{0, 0, yv^(-1), yv^(-1)}, yw])/16 + 
     (G[{1}, yv^(-1)]*G[{0, 0, yv^(-1), yv^(-1)}, yw])/16 + 
     (G[{1}, yw]*G[{0, 0, yv^(-1), yv^(-1)}, yw])/8 - 
     (G[{0}, yu^(-1)]*G[{0, 0, yv^(-1), 1/(yu*yv)}, yw])/16 - 
     (G[{0}, yv^(-1)]*G[{0, 0, yv^(-1), 1/(yu*yv)}, yw])/16 + 
     (G[{0}, yw]*G[{0, 0, yv^(-1), 1/(yu*yv)}, yw])/16 + 
     (G[{1}, yu^(-1)]*G[{0, 0, yv^(-1), 1/(yu*yv)}, yw])/16 + 
     (G[{1}, yv^(-1)]*G[{0, 0, yv^(-1), 1/(yu*yv)}, yw])/16 - 
     (G[{1}, yw]*G[{0, 0, yv^(-1), 1/(yu*yv)}, yw])/8 + 
     (G[{0}, yu^(-1)]*G[{0, 0, 1/(yu*yv), 1}, yw])/16 + 
     (G[{0}, yv^(-1)]*G[{0, 0, 1/(yu*yv), 1}, yw])/16 - 
     (G[{0}, yw]*G[{0, 0, 1/(yu*yv), 1}, yw])/16 - 
     (7*G[{1}, yu^(-1)]*G[{0, 0, 1/(yu*yv), 1}, yw])/16 + 
     (G[{1}, yv^(-1)]*G[{0, 0, 1/(yu*yv), 1}, yw])/16 - 
     (G[{1}, yw]*G[{0, 0, 1/(yu*yv), 1}, yw])/8 + 
     (G[{yu}, yv^(-1)]*G[{0, 0, 1/(yu*yv), 1}, yw])/4 + 
     (G[{1/(yu*yv)}, yw]*G[{0, 0, 1/(yu*yv), 1}, yw])/8 - 
     (G[{0}, yu^(-1)]*G[{0, 0, 1/(yu*yv), yu^(-1)}, yw])/16 - 
     (G[{0}, yv^(-1)]*G[{0, 0, 1/(yu*yv), yu^(-1)}, yw])/16 + 
     (G[{0}, yw]*G[{0, 0, 1/(yu*yv), yu^(-1)}, yw])/16 + 
     (3*G[{1}, yu^(-1)]*G[{0, 0, 1/(yu*yv), yu^(-1)}, yw])/16 - 
     (G[{1}, yv^(-1)]*G[{0, 0, 1/(yu*yv), yu^(-1)}, yw])/16 + 
     (G[{1}, yw]*G[{0, 0, 1/(yu*yv), yu^(-1)}, yw])/8 - 
     (G[{0}, yu^(-1)]*G[{0, 0, 1/(yu*yv), yv^(-1)}, yw])/16 - 
     (G[{0}, yv^(-1)]*G[{0, 0, 1/(yu*yv), yv^(-1)}, yw])/16 + 
     (G[{0}, yw]*G[{0, 0, 1/(yu*yv), yv^(-1)}, yw])/16 + 
     (3*G[{1}, yu^(-1)]*G[{0, 0, 1/(yu*yv), yv^(-1)}, yw])/16 + 
     (3*G[{1}, yv^(-1)]*G[{0, 0, 1/(yu*yv), yv^(-1)}, yw])/16 - 
     (G[{1}, yw]*G[{0, 0, 1/(yu*yv), yv^(-1)}, yw])/8 - 
     (G[{yu}, yv^(-1)]*G[{0, 0, 1/(yu*yv), yv^(-1)}, yw])/4 + 
     (G[{0}, yu^(-1)]*G[{0, 0, 1/(yu*yv), 1/(yu*yv)}, yw])/16 + 
     (G[{0}, yv^(-1)]*G[{0, 0, 1/(yu*yv), 1/(yu*yv)}, yw])/16 - 
     (G[{0}, yw]*G[{0, 0, 1/(yu*yv), 1/(yu*yv)}, yw])/16 - 
     (G[{1}, yu^(-1)]*G[{0, 0, 1/(yu*yv), 1/(yu*yv)}, yw])/16 - 
     (G[{1}, yv^(-1)]*G[{0, 0, 1/(yu*yv), 1/(yu*yv)}, yw])/16 - 
     (G[{0}, yu^(-1)]*G[{0, 1, 0, yu^(-1)}, yw])/16 - 
     (G[{0}, yv^(-1)]*G[{0, 1, 0, yu^(-1)}, yw])/16 + 
     (G[{0}, yw]*G[{0, 1, 0, yu^(-1)}, yw])/16 + 
     (G[{1}, yu^(-1)]*G[{0, 1, 0, yu^(-1)}, yw])/16 + 
     (G[{1}, yv^(-1)]*G[{0, 1, 0, yu^(-1)}, yw])/16 - 
     (G[{1}, yw]*G[{0, 1, 0, yu^(-1)}, yw])/16 + 
     (G[{0}, yu^(-1)]*G[{0, 1, 0, yu}, yv^(-1)])/16 + 
     (G[{0}, yv^(-1)]*G[{0, 1, 0, yu}, yv^(-1)])/16 - 
     (G[{0}, yw]*G[{0, 1, 0, yu}, yv^(-1)])/16 - 
     (G[{1}, yv^(-1)]*G[{0, 1, 0, yu}, yv^(-1)])/16 + 
     (G[{1}, yw]*G[{0, 1, 0, yu}, yv^(-1)])/16 + 
     (G[{1}, yu^(-1)]*G[{0, 1, 0, yv^(-1)}, yw])/8 + 
     (G[{1}, yw]*G[{0, 1, 0, yv^(-1)}, yw])/16 - 
     (G[{yu}, yv^(-1)]*G[{0, 1, 0, yv^(-1)}, yw])/8 + 
     (G[{0}, yu^(-1)]*G[{0, 1, 0, 1/(yu*yv)}, yw])/16 + 
     (G[{0}, yv^(-1)]*G[{0, 1, 0, 1/(yu*yv)}, yw])/16 - 
     (G[{0}, yw]*G[{0, 1, 0, 1/(yu*yv)}, yw])/16 - 
     (3*G[{1}, yu^(-1)]*G[{0, 1, 0, 1/(yu*yv)}, yw])/16 - 
     (G[{1}, yv^(-1)]*G[{0, 1, 0, 1/(yu*yv)}, yw])/16 + 
     (G[{yu}, yv^(-1)]*G[{0, 1, 0, 1/(yu*yv)}, yw])/8 + 
     (3*G[{0}, yu^(-1)]*G[{0, 1, 1, 1}, yu^(-1)])/16 + 
     (3*G[{0}, yv^(-1)]*G[{0, 1, 1, 1}, yu^(-1)])/16 - 
     (3*G[{0}, yw]*G[{0, 1, 1, 1}, yu^(-1)])/16 - 
     (9*G[{1}, yu^(-1)]*G[{0, 1, 1, 1}, yu^(-1)])/64 - 
     (3*G[{1}, yv^(-1)]*G[{0, 1, 1, 1}, yu^(-1)])/64 + 
     (3*G[{1}, yw]*G[{0, 1, 1, 1}, yu^(-1)])/64 + 
     (9*G[{1/(yu*yv)}, yw]*G[{0, 1, 1, 1}, yu^(-1)])/64 - 
     (3*G[{1}, yu^(-1)]*G[{0, 1, 1, 1}, yv^(-1)])/16 + 
     (3*G[{1}, yv^(-1)]*G[{0, 1, 1, 1}, yv^(-1)])/16 - 
     (3*G[{1}, yw]*G[{0, 1, 1, 1}, yv^(-1)])/16 - 
     (3*G[{0}, yu^(-1)]*G[{0, 1, 1, 1}, yw])/16 - 
     (3*G[{0}, yv^(-1)]*G[{0, 1, 1, 1}, yw])/16 + 
     (3*G[{0}, yw]*G[{0, 1, 1, 1}, yw])/16 + 
     (G[{1}, yu^(-1)]*G[{0, 1, 1, 1}, yw])/8 + 
     (3*G[{1}, yv^(-1)]*G[{0, 1, 1, 1}, yw])/16 + 
     (G[{1}, yw]*G[{0, 1, 1, 1}, yw])/8 + 
     (G[{yu}, yv^(-1)]*G[{0, 1, 1, 1}, yw])/16 - 
     (G[{1/(yu*yv)}, yw]*G[{0, 1, 1, 1}, yw])/8 + 
     (G[{0}, yu^(-1)]*G[{0, 1, 1, yu^(-1)}, yw])/8 + 
     (G[{0}, yv^(-1)]*G[{0, 1, 1, yu^(-1)}, yw])/8 - 
     (G[{0}, yw]*G[{0, 1, 1, yu^(-1)}, yw])/8 - 
     (G[{1}, yu^(-1)]*G[{0, 1, 1, yu^(-1)}, yw])/16 - 
     (3*G[{1}, yv^(-1)]*G[{0, 1, 1, yu^(-1)}, yw])/16 + 
     (G[{1}, yw]*G[{0, 1, 1, yu^(-1)}, yw])/16 - 
     (3*G[{0}, yu^(-1)]*G[{0, 1, 1, yu}, yv^(-1)])/16 - 
     (3*G[{0}, yv^(-1)]*G[{0, 1, 1, yu}, yv^(-1)])/16 + 
     (3*G[{0}, yw]*G[{0, 1, 1, yu}, yv^(-1)])/16 - 
     (G[{1}, yu^(-1)]*G[{0, 1, 1, yu}, yv^(-1)])/8 + 
     (3*G[{1}, yv^(-1)]*G[{0, 1, 1, yu}, yv^(-1)])/8 - 
     (3*G[{1}, yw]*G[{0, 1, 1, yu}, yv^(-1)])/8 + 
     (G[{1/(yu*yv)}, yw]*G[{0, 1, 1, yu}, yv^(-1)])/8 + 
     (G[{0}, yu^(-1)]*G[{0, 1, 1, yv^(-1)}, yw])/16 + 
     (G[{0}, yv^(-1)]*G[{0, 1, 1, yv^(-1)}, yw])/16 - 
     (G[{0}, yw]*G[{0, 1, 1, yv^(-1)}, yw])/16 - 
     (3*G[{1}, yu^(-1)]*G[{0, 1, 1, yv^(-1)}, yw])/16 - 
     (G[{1}, yv^(-1)]*G[{0, 1, 1, yv^(-1)}, yw])/16 - 
     (G[{1}, yw]*G[{0, 1, 1, yv^(-1)}, yw])/16 + 
     (G[{yu}, yv^(-1)]*G[{0, 1, 1, yv^(-1)}, yw])/8 + 
     (G[{1}, yu^(-1)]*G[{0, 1, 1, 1/(yu*yv)}, yw])/16 + 
     (G[{1}, yv^(-1)]*G[{0, 1, 1, 1/(yu*yv)}, yw])/4 - 
     (5*G[{yu}, yv^(-1)]*G[{0, 1, 1, 1/(yu*yv)}, yw])/16 + 
     (G[{0}, yu^(-1)]*G[{0, 1, yu^(-1), 1}, yw])/8 + 
     (G[{0}, yv^(-1)]*G[{0, 1, yu^(-1), 1}, yw])/8 - 
     (G[{0}, yw]*G[{0, 1, yu^(-1), 1}, yw])/8 - 
     (G[{1}, yu^(-1)]*G[{0, 1, yu^(-1), 1}, yw])/8 - 
     (G[{1}, yv^(-1)]*G[{0, 1, yu^(-1), 1}, yw])/8 - 
     (G[{0}, yu^(-1)]*G[{0, 1, yu^(-1), yu^(-1)}, yw])/8 - 
     (G[{0}, yv^(-1)]*G[{0, 1, yu^(-1), yu^(-1)}, yw])/8 + 
     (G[{0}, yw]*G[{0, 1, yu^(-1), yu^(-1)}, yw])/8 + 
     (G[{1}, yu^(-1)]*G[{0, 1, yu^(-1), yu^(-1)}, yw])/8 + 
     (G[{1}, yv^(-1)]*G[{0, 1, yu^(-1), yu^(-1)}, yw])/8 + 
     (G[{1/(yu*yv)}, yw]*G[{0, 1, yu^(-1), yu^(-1)}, yw])/8 - 
     (G[{1}, yu^(-1)]*G[{0, 1, yu^(-1), yv^(-1)}, yw])/8 + 
     (G[{1}, yv^(-1)]*G[{0, 1, yu^(-1), yv^(-1)}, yw])/8 - 
     (G[{1}, yw]*G[{0, 1, yu^(-1), yv^(-1)}, yw])/8 + 
     (G[{1/(yu*yv)}, yw]*G[{0, 1, yu^(-1), yv^(-1)}, yw])/8 - 
     (G[{0}, yu^(-1)]*G[{0, 1, yu^(-1), 1/(yu*yv)}, yw])/16 - 
     (G[{0}, yv^(-1)]*G[{0, 1, yu^(-1), 1/(yu*yv)}, yw])/16 + 
     (G[{0}, yw]*G[{0, 1, yu^(-1), 1/(yu*yv)}, yw])/16 + 
     (G[{1}, yu^(-1)]*G[{0, 1, yu^(-1), 1/(yu*yv)}, yw])/8 - 
     (G[{0}, yu^(-1)]*G[{0, 1, yu, 1}, yv^(-1)])/16 - 
     (G[{0}, yv^(-1)]*G[{0, 1, yu, 1}, yv^(-1)])/16 + 
     (G[{0}, yw]*G[{0, 1, yu, 1}, yv^(-1)])/16 - 
     (G[{1}, yu^(-1)]*G[{0, 1, yu, 1}, yv^(-1)])/16 + 
     (G[{1}, yv^(-1)]*G[{0, 1, yu, 1}, yv^(-1)])/4 - 
     (G[{1}, yw]*G[{0, 1, yu, 1}, yv^(-1)])/4 + 
     (G[{1/(yu*yv)}, yw]*G[{0, 1, yu, 1}, yv^(-1)])/8 + 
     (G[{0}, yu^(-1)]*G[{0, 1, yu, yu}, yv^(-1)])/8 + 
     (G[{0}, yv^(-1)]*G[{0, 1, yu, yu}, yv^(-1)])/8 - 
     (G[{0}, yw]*G[{0, 1, yu, yu}, yv^(-1)])/8 + 
     (G[{1}, yu^(-1)]*G[{0, 1, yu, yu}, yv^(-1)])/4 - 
     (5*G[{1}, yv^(-1)]*G[{0, 1, yu, yu}, yv^(-1)])/8 + 
     (5*G[{1}, yw]*G[{0, 1, yu, yu}, yv^(-1)])/8 - 
     (G[{1/(yu*yv)}, yw]*G[{0, 1, yu, yu}, yv^(-1)])/8 + 
     (G[{0}, yu^(-1)]*G[{0, 1, yv^(-1), 1}, yw])/16 + 
     (G[{0}, yv^(-1)]*G[{0, 1, yv^(-1), 1}, yw])/16 - 
     (G[{0}, yw]*G[{0, 1, yv^(-1), 1}, yw])/16 - 
     (3*G[{1}, yu^(-1)]*G[{0, 1, yv^(-1), 1}, yw])/16 - 
     (G[{1}, yv^(-1)]*G[{0, 1, yv^(-1), 1}, yw])/16 + 
     (G[{yu}, yv^(-1)]*G[{0, 1, yv^(-1), 1}, yw])/8 - 
     (G[{1}, yu^(-1)]*G[{0, 1, yv^(-1), yu^(-1)}, yw])/8 + 
     (G[{1}, yv^(-1)]*G[{0, 1, yv^(-1), yu^(-1)}, yw])/8 - 
     (G[{1}, yw]*G[{0, 1, yv^(-1), yu^(-1)}, yw])/8 + 
     (G[{1/(yu*yv)}, yw]*G[{0, 1, yv^(-1), yu^(-1)}, yw])/8 + 
     (G[{0}, yu^(-1)]*G[{0, 1, yv^(-1), yv^(-1)}, yw])/8 + 
     (G[{0}, yv^(-1)]*G[{0, 1, yv^(-1), yv^(-1)}, yw])/8 - 
     (G[{0}, yw]*G[{0, 1, yv^(-1), yv^(-1)}, yw])/8 - 
     (G[{1}, yu^(-1)]*G[{0, 1, yv^(-1), yv^(-1)}, yw])/8 - 
     (G[{1}, yv^(-1)]*G[{0, 1, yv^(-1), yv^(-1)}, yw])/8 - 
     (G[{1}, yw]*G[{0, 1, yv^(-1), yv^(-1)}, yw])/4 + 
     (G[{1/(yu*yv)}, yw]*G[{0, 1, yv^(-1), yv^(-1)}, yw])/8 - 
     (G[{0}, yu^(-1)]*G[{0, 1, yv^(-1), 1/(yu*yv)}, yw])/8 - 
     (G[{0}, yv^(-1)]*G[{0, 1, yv^(-1), 1/(yu*yv)}, yw])/8 + 
     (G[{0}, yw]*G[{0, 1, yv^(-1), 1/(yu*yv)}, yw])/8 + 
     (3*G[{1}, yu^(-1)]*G[{0, 1, yv^(-1), 1/(yu*yv)}, yw])/16 - 
     (G[{1}, yv^(-1)]*G[{0, 1, yv^(-1), 1/(yu*yv)}, yw])/16 + 
     (G[{yu}, yv^(-1)]*G[{0, 1, yv^(-1), 1/(yu*yv)}, yw])/8 + 
     (G[{1}, yu^(-1)]*G[{0, 1, 1/(yu*yv), 1}, yw])/8 + 
     (3*G[{1}, yv^(-1)]*G[{0, 1, 1/(yu*yv), 1}, yw])/16 - 
     (5*G[{yu}, yv^(-1)]*G[{0, 1, 1/(yu*yv), 1}, yw])/16 - 
     (G[{1}, yu^(-1)]*G[{0, 1, 1/(yu*yv), yu^(-1)}, yw])/16 + 
     (G[{1}, yv^(-1)]*G[{0, 1, 1/(yu*yv), yu^(-1)}, yw])/16 + 
     (G[{1}, yw]*G[{0, 1, 1/(yu*yv), yu^(-1)}, yw])/16 - 
     (G[{0}, yu^(-1)]*G[{0, 1, 1/(yu*yv), yv^(-1)}, yw])/16 - 
     (G[{0}, yv^(-1)]*G[{0, 1, 1/(yu*yv), yv^(-1)}, yw])/16 + 
     (G[{0}, yw]*G[{0, 1, 1/(yu*yv), yv^(-1)}, yw])/16 + 
     (G[{1}, yu^(-1)]*G[{0, 1, 1/(yu*yv), yv^(-1)}, yw])/16 - 
     (G[{1}, yv^(-1)]*G[{0, 1, 1/(yu*yv), yv^(-1)}, yw])/16 - 
     (G[{1}, yw]*G[{0, 1, 1/(yu*yv), yv^(-1)}, yw])/16 + 
     (G[{yu}, yv^(-1)]*G[{0, 1, 1/(yu*yv), yv^(-1)}, yw])/8 + 
     (G[{0}, yu^(-1)]*G[{0, 1, 1/(yu*yv), 1/(yu*yv)}, yw])/16 + 
     (G[{0}, yv^(-1)]*G[{0, 1, 1/(yu*yv), 1/(yu*yv)}, yw])/16 - 
     (G[{0}, yw]*G[{0, 1, 1/(yu*yv), 1/(yu*yv)}, yw])/16 - 
     (3*G[{1}, yu^(-1)]*G[{0, 1, 1/(yu*yv), 1/(yu*yv)}, yw])/16 + 
     (G[{yu}, yv^(-1)]*G[{0, 1, 1/(yu*yv), 1/(yu*yv)}, yw])/16 - 
     (G[{0}, yu^(-1)]*G[{0, yu^(-1), 0, yv^(-1)}, yw])/16 - 
     (G[{0}, yv^(-1)]*G[{0, yu^(-1), 0, yv^(-1)}, yw])/16 + 
     (G[{0}, yw]*G[{0, yu^(-1), 0, yv^(-1)}, yw])/16 + 
     (G[{1}, yv^(-1)]*G[{0, yu^(-1), 0, yv^(-1)}, yw])/8 - 
     (G[{1}, yw]*G[{0, yu^(-1), 0, yv^(-1)}, yw])/8 + 
     (G[{1}, yu^(-1)]*G[{0, yu^(-1), 0, 1/(yu*yv)}, yw])/16 - 
     (G[{1}, yv^(-1)]*G[{0, yu^(-1), 0, 1/(yu*yv)}, yw])/16 + 
     (G[{1}, yw]*G[{0, yu^(-1), 0, 1/(yu*yv)}, yw])/16 + 
     (G[{0}, yu^(-1)]*G[{0, yu^(-1), 1, 1}, yw])/16 + 
     (G[{0}, yv^(-1)]*G[{0, yu^(-1), 1, 1}, yw])/16 - 
     (G[{0}, yw]*G[{0, yu^(-1), 1, 1}, yw])/16 + 
     (G[{1}, yu^(-1)]*G[{0, yu^(-1), 1, 1}, yw])/16 - 
     (G[{1}, yv^(-1)]*G[{0, yu^(-1), 1, 1}, yw])/4 + 
     (G[{1}, yw]*G[{0, yu^(-1), 1, 1}, yw])/8 + 
     (G[{yu}, yv^(-1)]*G[{0, yu^(-1), 1, 1}, yw])/16 - 
     (G[{0}, yu^(-1)]*G[{0, yu^(-1), 1, yu^(-1)}, yw])/16 - 
     (G[{0}, yv^(-1)]*G[{0, yu^(-1), 1, yu^(-1)}, yw])/16 + 
     (G[{0}, yw]*G[{0, yu^(-1), 1, yu^(-1)}, yw])/16 + 
     (G[{1}, yu^(-1)]*G[{0, yu^(-1), 1, yu^(-1)}, yw])/16 + 
     (G[{1}, yv^(-1)]*G[{0, yu^(-1), 1, yu^(-1)}, yw])/16 - 
     (G[{1}, yw]*G[{0, yu^(-1), 1, yu^(-1)}, yw])/16 - 
     (G[{0}, yu^(-1)]*G[{0, yu^(-1), 1, yv^(-1)}, yw])/16 - 
     (G[{0}, yv^(-1)]*G[{0, yu^(-1), 1, yv^(-1)}, yw])/16 + 
     (G[{0}, yw]*G[{0, yu^(-1), 1, yv^(-1)}, yw])/16 - 
     (G[{1}, yu^(-1)]*G[{0, yu^(-1), 1, yv^(-1)}, yw])/16 + 
     (G[{1}, yv^(-1)]*G[{0, yu^(-1), 1, yv^(-1)}, yw])/16 + 
     (G[{1}, yw]*G[{0, yu^(-1), 1, yv^(-1)}, yw])/16 + 
     (G[{yu}, yv^(-1)]*G[{0, yu^(-1), 1, yv^(-1)}, yw])/8 + 
     (G[{1}, yu^(-1)]*G[{0, yu^(-1), 1, 1/(yu*yv)}, yw])/8 - 
     (G[{1}, yv^(-1)]*G[{0, yu^(-1), 1, 1/(yu*yv)}, yw])/16 - 
     (G[{yu}, yv^(-1)]*G[{0, yu^(-1), 1, 1/(yu*yv)}, yw])/16 - 
     (G[{0}, yu^(-1)]*G[{0, yu^(-1), yu^(-1), 1}, yw])/16 - 
     (G[{0}, yv^(-1)]*G[{0, yu^(-1), yu^(-1), 1}, yw])/16 + 
     (G[{0}, yw]*G[{0, yu^(-1), yu^(-1), 1}, yw])/16 + 
     (3*G[{1}, yu^(-1)]*G[{0, yu^(-1), yu^(-1), 1}, yw])/16 + 
     (G[{1}, yv^(-1)]*G[{0, yu^(-1), yu^(-1), 1}, yw])/16 - 
     (G[{yu}, yv^(-1)]*G[{0, yu^(-1), yu^(-1), 1}, yw])/8 + 
     (G[{0}, yu^(-1)]*G[{0, yu^(-1), yu^(-1), yu^(-1)}, yw])/8 + 
     (G[{0}, yv^(-1)]*G[{0, yu^(-1), yu^(-1), yu^(-1)}, yw])/8 - 
     (G[{0}, yw]*G[{0, yu^(-1), yu^(-1), yu^(-1)}, yw])/8 - 
     (3*G[{1}, yu^(-1)]*G[{0, yu^(-1), yu^(-1), yu^(-1)}, yw])/8 + 
     (G[{1}, yv^(-1)]*G[{0, yu^(-1), yu^(-1), yu^(-1)}, yw])/8 - 
     (G[{1}, yw]*G[{0, yu^(-1), yu^(-1), yu^(-1)}, yw])/4 + 
     (G[{0}, yu^(-1)]*G[{0, yu^(-1), yu^(-1), yv^(-1)}, yw])/8 + 
     (G[{0}, yv^(-1)]*G[{0, yu^(-1), yu^(-1), yv^(-1)}, yw])/8 - 
     (G[{0}, yw]*G[{0, yu^(-1), yu^(-1), yv^(-1)}, yw])/8 + 
     (G[{1}, yu^(-1)]*G[{0, yu^(-1), yu^(-1), yv^(-1)}, yw])/8 - 
     (3*G[{1}, yv^(-1)]*G[{0, yu^(-1), yu^(-1), yv^(-1)}, yw])/8 + 
     (G[{1}, yw]*G[{0, yu^(-1), yu^(-1), yv^(-1)}, yw])/8 - 
     (G[{1/(yu*yv)}, yw]*G[{0, yu^(-1), yu^(-1), yv^(-1)}, yw])/8 - 
     (G[{0}, yu^(-1)]*G[{0, yu^(-1), yu^(-1), 1/(yu*yv)}, yw])/16 - 
     (G[{0}, yv^(-1)]*G[{0, yu^(-1), yu^(-1), 1/(yu*yv)}, yw])/16 + 
     (G[{0}, yw]*G[{0, yu^(-1), yu^(-1), 1/(yu*yv)}, yw])/16 - 
     (G[{1}, yu^(-1)]*G[{0, yu^(-1), yu^(-1), 1/(yu*yv)}, yw])/16 + 
     (G[{1}, yv^(-1)]*G[{0, yu^(-1), yu^(-1), 1/(yu*yv)}, yw])/16 + 
     (G[{yu}, yv^(-1)]*G[{0, yu^(-1), yu^(-1), 1/(yu*yv)}, yw])/8 - 
     (G[{0}, yu^(-1)]*G[{0, yu^(-1), yv^(-1), 1}, yw])/8 - 
     (G[{0}, yv^(-1)]*G[{0, yu^(-1), yv^(-1), 1}, yw])/8 + 
     (G[{0}, yw]*G[{0, yu^(-1), yv^(-1), 1}, yw])/8 + 
     (G[{1}, yu^(-1)]*G[{0, yu^(-1), yv^(-1), 1}, yw])/16 + 
     (G[{1}, yv^(-1)]*G[{0, yu^(-1), yv^(-1), 1}, yw])/16 + 
     (G[{yu}, yv^(-1)]*G[{0, yu^(-1), yv^(-1), 1}, yw])/8 + 
     (G[{0}, yu^(-1)]*G[{0, yu^(-1), yv^(-1), yu^(-1)}, yw])/8 + 
     (G[{0}, yv^(-1)]*G[{0, yu^(-1), yv^(-1), yu^(-1)}, yw])/8 - 
     (G[{0}, yw]*G[{0, yu^(-1), yv^(-1), yu^(-1)}, yw])/8 + 
     (G[{1}, yu^(-1)]*G[{0, yu^(-1), yv^(-1), yu^(-1)}, yw])/8 - 
     (3*G[{1}, yv^(-1)]*G[{0, yu^(-1), yv^(-1), yu^(-1)}, yw])/8 + 
     (G[{1}, yw]*G[{0, yu^(-1), yv^(-1), yu^(-1)}, yw])/8 - 
     (G[{1/(yu*yv)}, yw]*G[{0, yu^(-1), yv^(-1), yu^(-1)}, yw])/8 - 
     (G[{0}, yu^(-1)]*G[{0, yu^(-1), yv^(-1), yv^(-1)}, yw])/8 - 
     (G[{0}, yv^(-1)]*G[{0, yu^(-1), yv^(-1), yv^(-1)}, yw])/8 + 
     (G[{0}, yw]*G[{0, yu^(-1), yv^(-1), yv^(-1)}, yw])/8 + 
     (G[{1}, yu^(-1)]*G[{0, yu^(-1), yv^(-1), yv^(-1)}, yw])/8 + 
     (G[{1}, yv^(-1)]*G[{0, yu^(-1), yv^(-1), yv^(-1)}, yw])/8 + 
     (G[{1}, yw]*G[{0, yu^(-1), yv^(-1), yv^(-1)}, yw])/8 - 
     (G[{1/(yu*yv)}, yw]*G[{0, yu^(-1), yv^(-1), yv^(-1)}, yw])/8 + 
     (G[{0}, yu^(-1)]*G[{0, yu^(-1), yv^(-1), 1/(yu*yv)}, yw])/8 + 
     (G[{0}, yv^(-1)]*G[{0, yu^(-1), yv^(-1), 1/(yu*yv)}, yw])/8 - 
     (G[{0}, yw]*G[{0, yu^(-1), yv^(-1), 1/(yu*yv)}, yw])/8 - 
     (3*G[{1}, yu^(-1)]*G[{0, yu^(-1), yv^(-1), 1/(yu*yv)}, yw])/16 + 
     (G[{1}, yv^(-1)]*G[{0, yu^(-1), yv^(-1), 1/(yu*yv)}, yw])/16 - 
     (G[{yu}, yv^(-1)]*G[{0, yu^(-1), yv^(-1), 1/(yu*yv)}, yw])/8 - 
     (G[{1}, yv^(-1)]*G[{0, yu^(-1), 1/(yu*yv), 1}, yw])/16 - 
     (G[{1}, yw]*G[{0, yu^(-1), 1/(yu*yv), 1}, yw])/8 + 
     (G[{yu}, yv^(-1)]*G[{0, yu^(-1), 1/(yu*yv), 1}, yw])/16 - 
     (G[{0}, yu^(-1)]*G[{0, yu^(-1), 1/(yu*yv), yu^(-1)}, yw])/16 - 
     (G[{0}, yv^(-1)]*G[{0, yu^(-1), 1/(yu*yv), yu^(-1)}, yw])/16 + 
     (G[{0}, yw]*G[{0, yu^(-1), 1/(yu*yv), yu^(-1)}, yw])/16 + 
     (G[{1}, yu^(-1)]*G[{0, yu^(-1), 1/(yu*yv), yu^(-1)}, yw])/16 + 
     (G[{1}, yv^(-1)]*G[{0, yu^(-1), 1/(yu*yv), yu^(-1)}, yw])/16 + 
     (G[{1}, yw]*G[{0, yu^(-1), 1/(yu*yv), yu^(-1)}, yw])/16 + 
     (G[{0}, yu^(-1)]*G[{0, yu^(-1), 1/(yu*yv), yv^(-1)}, yw])/16 + 
     (G[{0}, yv^(-1)]*G[{0, yu^(-1), 1/(yu*yv), yv^(-1)}, yw])/16 - 
     (G[{0}, yw]*G[{0, yu^(-1), 1/(yu*yv), yv^(-1)}, yw])/16 - 
     (G[{1}, yu^(-1)]*G[{0, yu^(-1), 1/(yu*yv), yv^(-1)}, yw])/16 + 
     (G[{1}, yv^(-1)]*G[{0, yu^(-1), 1/(yu*yv), yv^(-1)}, yw])/16 + 
     (3*G[{1}, yw]*G[{0, yu^(-1), 1/(yu*yv), yv^(-1)}, yw])/16 - 
     (G[{yu}, yv^(-1)]*G[{0, yu^(-1), 1/(yu*yv), yv^(-1)}, yw])/8 - 
     (G[{0}, yu^(-1)]*G[{0, yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/16 - 
     (G[{0}, yv^(-1)]*G[{0, yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/16 + 
     (G[{0}, yw]*G[{0, yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/16 + 
     (3*G[{1}, yu^(-1)]*G[{0, yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/16 - 
     (G[{yu}, yv^(-1)]*G[{0, yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/16 + 
     (G[{0}, yu^(-1)]*G[{0, yu, 1, 1}, yv^(-1)])/16 + 
     (G[{0}, yv^(-1)]*G[{0, yu, 1, 1}, yv^(-1)])/16 - 
     (G[{0}, yw]*G[{0, yu, 1, 1}, yv^(-1)])/16 - 
     (G[{1}, yv^(-1)]*G[{0, yu, 1, 1}, yv^(-1)])/16 + 
     (G[{1}, yw]*G[{0, yu, 1, 1}, yv^(-1)])/16 + 
     (G[{1/(yu*yv)}, yw]*G[{0, yu, 1, 1}, yv^(-1)])/8 + 
     (G[{0}, yu^(-1)]*G[{0, yu, 1, yu}, yv^(-1)])/16 + 
     (G[{0}, yv^(-1)]*G[{0, yu, 1, yu}, yv^(-1)])/16 - 
     (G[{0}, yw]*G[{0, yu, 1, yu}, yv^(-1)])/16 + 
     (G[{1}, yu^(-1)]*G[{0, yu, 1, yu}, yv^(-1)])/8 - 
     (3*G[{1}, yv^(-1)]*G[{0, yu, 1, yu}, yv^(-1)])/8 + 
     (3*G[{1}, yw]*G[{0, yu, 1, yu}, yv^(-1)])/8 - 
     (G[{1/(yu*yv)}, yw]*G[{0, yu, 1, yu}, yv^(-1)])/8 - 
     (G[{1}, yv^(-1)]*G[{0, yu, yu, 1}, yv^(-1)])/4 + 
     (G[{1}, yw]*G[{0, yu, yu, 1}, yv^(-1)])/4 - 
     (G[{1/(yu*yv)}, yw]*G[{0, yu, yu, 1}, yv^(-1)])/8 + 
     (G[{1}, yv^(-1)]*G[{0, yu, yu, yu}, yv^(-1)])/2 - 
     (G[{1}, yw]*G[{0, yu, yu, yu}, yv^(-1)])/2 - 
     (G[{0}, yu^(-1)]*G[{0, yv^(-1), 0, 1/(yu*yv)}, yw])/16 - 
     (G[{0}, yv^(-1)]*G[{0, yv^(-1), 0, 1/(yu*yv)}, yw])/16 + 
     (G[{0}, yw]*G[{0, yv^(-1), 0, 1/(yu*yv)}, yw])/16 + 
     (G[{1}, yu^(-1)]*G[{0, yv^(-1), 0, 1/(yu*yv)}, yw])/8 + 
     (G[{1}, yv^(-1)]*G[{0, yv^(-1), 0, 1/(yu*yv)}, yw])/8 - 
     (G[{1}, yw]*G[{0, yv^(-1), 0, 1/(yu*yv)}, yw])/16 - 
     (G[{yu}, yv^(-1)]*G[{0, yv^(-1), 0, 1/(yu*yv)}, yw])/8 + 
     (3*G[{0}, yu^(-1)]*G[{0, yv^(-1), 1, 1}, yw])/16 + 
     (3*G[{0}, yv^(-1)]*G[{0, yv^(-1), 1, 1}, yw])/16 - 
     (3*G[{0}, yw]*G[{0, yv^(-1), 1, 1}, yw])/16 - 
     (G[{1}, yu^(-1)]*G[{0, yv^(-1), 1, 1}, yw])/8 - 
     (3*G[{1}, yv^(-1)]*G[{0, yv^(-1), 1, 1}, yw])/16 - 
     (G[{1}, yw]*G[{0, yv^(-1), 1, 1}, yw])/8 - 
     (G[{yu}, yv^(-1)]*G[{0, yv^(-1), 1, 1}, yw])/16 - 
     (G[{0}, yu^(-1)]*G[{0, yv^(-1), 1, yu^(-1)}, yw])/16 - 
     (G[{0}, yv^(-1)]*G[{0, yv^(-1), 1, yu^(-1)}, yw])/16 + 
     (G[{0}, yw]*G[{0, yv^(-1), 1, yu^(-1)}, yw])/16 + 
     (G[{1}, yu^(-1)]*G[{0, yv^(-1), 1, yu^(-1)}, yw])/16 + 
     (G[{1}, yv^(-1)]*G[{0, yv^(-1), 1, yu^(-1)}, yw])/16 - 
     (G[{1}, yw]*G[{0, yv^(-1), 1, yu^(-1)}, yw])/16 - 
     (G[{0}, yu^(-1)]*G[{0, yv^(-1), 1, yv^(-1)}, yw])/16 - 
     (G[{0}, yv^(-1)]*G[{0, yv^(-1), 1, yv^(-1)}, yw])/16 + 
     (G[{0}, yw]*G[{0, yv^(-1), 1, yv^(-1)}, yw])/16 + 
     (3*G[{1}, yu^(-1)]*G[{0, yv^(-1), 1, yv^(-1)}, yw])/16 + 
     (G[{1}, yv^(-1)]*G[{0, yv^(-1), 1, yv^(-1)}, yw])/16 + 
     (G[{1}, yw]*G[{0, yv^(-1), 1, yv^(-1)}, yw])/16 - 
     (G[{yu}, yv^(-1)]*G[{0, yv^(-1), 1, yv^(-1)}, yw])/8 + 
     (G[{1}, yu^(-1)]*G[{0, yv^(-1), 1, 1/(yu*yv)}, yw])/16 - 
     (G[{1}, yv^(-1)]*G[{0, yv^(-1), 1, 1/(yu*yv)}, yw])/8 + 
     (G[{yu}, yv^(-1)]*G[{0, yv^(-1), 1, 1/(yu*yv)}, yw])/16 - 
     (G[{0}, yu^(-1)]*G[{0, yv^(-1), yu^(-1), 1}, yw])/8 - 
     (G[{0}, yv^(-1)]*G[{0, yv^(-1), yu^(-1), 1}, yw])/8 + 
     (G[{0}, yw]*G[{0, yv^(-1), yu^(-1), 1}, yw])/8 + 
     (G[{1}, yu^(-1)]*G[{0, yv^(-1), yu^(-1), 1}, yw])/16 + 
     (G[{1}, yv^(-1)]*G[{0, yv^(-1), yu^(-1), 1}, yw])/16 + 
     (G[{yu}, yv^(-1)]*G[{0, yv^(-1), yu^(-1), 1}, yw])/8 + 
     (G[{0}, yu^(-1)]*G[{0, yv^(-1), yu^(-1), yu^(-1)}, yw])/8 + 
     (G[{0}, yv^(-1)]*G[{0, yv^(-1), yu^(-1), yu^(-1)}, yw])/8 - 
     (G[{0}, yw]*G[{0, yv^(-1), yu^(-1), yu^(-1)}, yw])/8 + 
     (G[{1}, yu^(-1)]*G[{0, yv^(-1), yu^(-1), yu^(-1)}, yw])/8 - 
     (3*G[{1}, yv^(-1)]*G[{0, yv^(-1), yu^(-1), yu^(-1)}, yw])/8 + 
     (G[{1}, yw]*G[{0, yv^(-1), yu^(-1), yu^(-1)}, yw])/8 - 
     (G[{1/(yu*yv)}, yw]*G[{0, yv^(-1), yu^(-1), yu^(-1)}, yw])/8 - 
     (G[{0}, yu^(-1)]*G[{0, yv^(-1), yu^(-1), yv^(-1)}, yw])/8 - 
     (G[{0}, yv^(-1)]*G[{0, yv^(-1), yu^(-1), yv^(-1)}, yw])/8 + 
     (G[{0}, yw]*G[{0, yv^(-1), yu^(-1), yv^(-1)}, yw])/8 + 
     (G[{1}, yu^(-1)]*G[{0, yv^(-1), yu^(-1), yv^(-1)}, yw])/8 + 
     (G[{1}, yv^(-1)]*G[{0, yv^(-1), yu^(-1), yv^(-1)}, yw])/8 + 
     (G[{1}, yw]*G[{0, yv^(-1), yu^(-1), yv^(-1)}, yw])/8 - 
     (G[{1/(yu*yv)}, yw]*G[{0, yv^(-1), yu^(-1), yv^(-1)}, yw])/8 + 
     (G[{0}, yu^(-1)]*G[{0, yv^(-1), yu^(-1), 1/(yu*yv)}, yw])/8 + 
     (G[{0}, yv^(-1)]*G[{0, yv^(-1), yu^(-1), 1/(yu*yv)}, yw])/8 - 
     (G[{0}, yw]*G[{0, yv^(-1), yu^(-1), 1/(yu*yv)}, yw])/8 - 
     (3*G[{1}, yu^(-1)]*G[{0, yv^(-1), yu^(-1), 1/(yu*yv)}, yw])/16 + 
     (G[{1}, yv^(-1)]*G[{0, yv^(-1), yu^(-1), 1/(yu*yv)}, yw])/16 - 
     (G[{yu}, yv^(-1)]*G[{0, yv^(-1), yu^(-1), 1/(yu*yv)}, yw])/8 - 
     (G[{0}, yu^(-1)]*G[{0, yv^(-1), yv^(-1), 1}, yw])/16 - 
     (G[{0}, yv^(-1)]*G[{0, yv^(-1), yv^(-1), 1}, yw])/16 + 
     (G[{0}, yw]*G[{0, yv^(-1), yv^(-1), 1}, yw])/16 + 
     (3*G[{1}, yu^(-1)]*G[{0, yv^(-1), yv^(-1), 1}, yw])/16 + 
     (G[{1}, yv^(-1)]*G[{0, yv^(-1), yv^(-1), 1}, yw])/16 - 
     (G[{yu}, yv^(-1)]*G[{0, yv^(-1), yv^(-1), 1}, yw])/8 - 
     (G[{0}, yu^(-1)]*G[{0, yv^(-1), yv^(-1), yu^(-1)}, yw])/8 - 
     (G[{0}, yv^(-1)]*G[{0, yv^(-1), yv^(-1), yu^(-1)}, yw])/8 + 
     (G[{0}, yw]*G[{0, yv^(-1), yv^(-1), yu^(-1)}, yw])/8 + 
     (G[{1}, yu^(-1)]*G[{0, yv^(-1), yv^(-1), yu^(-1)}, yw])/8 + 
     (G[{1}, yv^(-1)]*G[{0, yv^(-1), yv^(-1), yu^(-1)}, yw])/8 + 
     (G[{1}, yw]*G[{0, yv^(-1), yv^(-1), yu^(-1)}, yw])/8 - 
     (G[{1/(yu*yv)}, yw]*G[{0, yv^(-1), yv^(-1), yu^(-1)}, yw])/8 - 
     (G[{0}, yu^(-1)]*G[{0, yv^(-1), yv^(-1), yv^(-1)}, yw])/8 - 
     (G[{0}, yv^(-1)]*G[{0, yv^(-1), yv^(-1), yv^(-1)}, yw])/8 + 
     (G[{0}, yw]*G[{0, yv^(-1), yv^(-1), yv^(-1)}, yw])/8 + 
     (G[{1}, yu^(-1)]*G[{0, yv^(-1), yv^(-1), yv^(-1)}, yw])/8 + 
     (G[{1}, yv^(-1)]*G[{0, yv^(-1), yv^(-1), yv^(-1)}, yw])/8 + 
     (G[{1}, yw]*G[{0, yv^(-1), yv^(-1), yv^(-1)}, yw])/4 + 
     (3*G[{0}, yu^(-1)]*G[{0, yv^(-1), yv^(-1), 1/(yu*yv)}, yw])/16 + 
     (3*G[{0}, yv^(-1)]*G[{0, yv^(-1), yv^(-1), 1/(yu*yv)}, yw])/16 - 
     (3*G[{0}, yw]*G[{0, yv^(-1), yv^(-1), 1/(yu*yv)}, yw])/16 - 
     (5*G[{1}, yu^(-1)]*G[{0, yv^(-1), yv^(-1), 1/(yu*yv)}, yw])/16 - 
     (3*G[{1}, yv^(-1)]*G[{0, yv^(-1), yv^(-1), 1/(yu*yv)}, yw])/16 + 
     (G[{yu}, yv^(-1)]*G[{0, yv^(-1), yv^(-1), 1/(yu*yv)}, yw])/8 + 
     (3*G[{1}, yu^(-1)]*G[{0, yv^(-1), 1/(yu*yv), 1}, yw])/16 - 
     (G[{1}, yv^(-1)]*G[{0, yv^(-1), 1/(yu*yv), 1}, yw])/8 + 
     (G[{1}, yw]*G[{0, yv^(-1), 1/(yu*yv), 1}, yw])/8 - 
     (G[{yu}, yv^(-1)]*G[{0, yv^(-1), 1/(yu*yv), 1}, yw])/16 + 
     (G[{0}, yu^(-1)]*G[{0, yv^(-1), 1/(yu*yv), yu^(-1)}, yw])/16 + 
     (G[{0}, yv^(-1)]*G[{0, yv^(-1), 1/(yu*yv), yu^(-1)}, yw])/16 - 
     (G[{0}, yw]*G[{0, yv^(-1), 1/(yu*yv), yu^(-1)}, yw])/16 - 
     (3*G[{1}, yu^(-1)]*G[{0, yv^(-1), 1/(yu*yv), yu^(-1)}, yw])/16 + 
     (G[{1}, yv^(-1)]*G[{0, yv^(-1), 1/(yu*yv), yu^(-1)}, yw])/16 - 
     (3*G[{1}, yw]*G[{0, yv^(-1), 1/(yu*yv), yu^(-1)}, yw])/16 + 
     (3*G[{0}, yu^(-1)]*G[{0, yv^(-1), 1/(yu*yv), yv^(-1)}, yw])/16 + 
     (3*G[{0}, yv^(-1)]*G[{0, yv^(-1), 1/(yu*yv), yv^(-1)}, yw])/16 - 
     (3*G[{0}, yw]*G[{0, yv^(-1), 1/(yu*yv), yv^(-1)}, yw])/16 - 
     (5*G[{1}, yu^(-1)]*G[{0, yv^(-1), 1/(yu*yv), yv^(-1)}, yw])/16 - 
     (3*G[{1}, yv^(-1)]*G[{0, yv^(-1), 1/(yu*yv), yv^(-1)}, yw])/16 - 
     (G[{1}, yw]*G[{0, yv^(-1), 1/(yu*yv), yv^(-1)}, yw])/16 + 
     (G[{yu}, yv^(-1)]*G[{0, yv^(-1), 1/(yu*yv), yv^(-1)}, yw])/8 - 
     (3*G[{0}, yu^(-1)]*G[{0, yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/16 - 
     (3*G[{0}, yv^(-1)]*G[{0, yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/16 + 
     (3*G[{0}, yw]*G[{0, yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/16 + 
     (G[{1}, yu^(-1)]*G[{0, yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/4 + 
     (G[{1}, yv^(-1)]*G[{0, yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/16 + 
     (G[{yu}, yv^(-1)]*G[{0, yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/16 - 
     (G[{0}, yu^(-1)]*G[{0, 1/(yu*yv), 1, 1}, yw])/16 - 
     (G[{0}, yv^(-1)]*G[{0, 1/(yu*yv), 1, 1}, yw])/16 + 
     (G[{0}, yw]*G[{0, 1/(yu*yv), 1, 1}, yw])/16 - 
     (G[{1}, yu^(-1)]*G[{0, 1/(yu*yv), 1, 1}, yw])/16 + 
     (G[{1}, yv^(-1)]*G[{0, 1/(yu*yv), 1, 1}, yw])/4 - 
     (G[{1}, yw]*G[{0, 1/(yu*yv), 1, 1}, yw])/8 - 
     (G[{yu}, yv^(-1)]*G[{0, 1/(yu*yv), 1, 1}, yw])/16 + 
     (G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv), 1, 1}, yw])/8 - 
     (G[{1}, yu^(-1)]*G[{0, 1/(yu*yv), 1, yu^(-1)}, yw])/16 + 
     (G[{1}, yv^(-1)]*G[{0, 1/(yu*yv), 1, yu^(-1)}, yw])/16 + 
     (G[{1}, yw]*G[{0, 1/(yu*yv), 1, yu^(-1)}, yw])/16 + 
     (G[{0}, yu^(-1)]*G[{0, 1/(yu*yv), 1, yv^(-1)}, yw])/16 + 
     (G[{0}, yv^(-1)]*G[{0, 1/(yu*yv), 1, yv^(-1)}, yw])/16 - 
     (G[{0}, yw]*G[{0, 1/(yu*yv), 1, yv^(-1)}, yw])/16 + 
     (G[{1}, yu^(-1)]*G[{0, 1/(yu*yv), 1, yv^(-1)}, yw])/16 - 
     (G[{1}, yv^(-1)]*G[{0, 1/(yu*yv), 1, yv^(-1)}, yw])/16 - 
     (G[{1}, yw]*G[{0, 1/(yu*yv), 1, yv^(-1)}, yw])/16 - 
     (G[{yu}, yv^(-1)]*G[{0, 1/(yu*yv), 1, yv^(-1)}, yw])/8 - 
     (G[{1}, yu^(-1)]*G[{0, 1/(yu*yv), 1, 1/(yu*yv)}, yw])/4 - 
     (G[{1}, yv^(-1)]*G[{0, 1/(yu*yv), 1, 1/(yu*yv)}, yw])/16 + 
     (5*G[{yu}, yv^(-1)]*G[{0, 1/(yu*yv), 1, 1/(yu*yv)}, yw])/16 + 
     (G[{0}, yu^(-1)]*G[{0, 1/(yu*yv), yu^(-1), 1}, yw])/16 + 
     (G[{0}, yv^(-1)]*G[{0, 1/(yu*yv), yu^(-1), 1}, yw])/16 - 
     (G[{0}, yw]*G[{0, 1/(yu*yv), yu^(-1), 1}, yw])/16 - 
     (G[{1}, yu^(-1)]*G[{0, 1/(yu*yv), yu^(-1), 1}, yw])/8 - 
     (G[{0}, yu^(-1)]*G[{0, 1/(yu*yv), yu^(-1), yu^(-1)}, yw])/8 - 
     (G[{0}, yv^(-1)]*G[{0, 1/(yu*yv), yu^(-1), yu^(-1)}, yw])/8 + 
     (G[{0}, yw]*G[{0, 1/(yu*yv), yu^(-1), yu^(-1)}, yw])/8 + 
     (G[{1}, yu^(-1)]*G[{0, 1/(yu*yv), yu^(-1), yu^(-1)}, yw])/8 + 
     (G[{1}, yv^(-1)]*G[{0, 1/(yu*yv), yu^(-1), yu^(-1)}, yw])/8 + 
     (G[{1}, yw]*G[{0, 1/(yu*yv), yu^(-1), yu^(-1)}, yw])/8 - 
     (G[{1}, yu^(-1)]*G[{0, 1/(yu*yv), yu^(-1), yv^(-1)}, yw])/8 + 
     (G[{1}, yv^(-1)]*G[{0, 1/(yu*yv), yu^(-1), yv^(-1)}, yw])/8 - 
     (G[{1}, yw]*G[{0, 1/(yu*yv), yu^(-1), yv^(-1)}, yw])/8 + 
     (G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv), yu^(-1), yv^(-1)}, yw])/8 + 
     (G[{1}, yu^(-1)]*G[{0, 1/(yu*yv), yu^(-1), 1/(yu*yv)}, yw])/8 - 
     (G[{1}, yv^(-1)]*G[{0, 1/(yu*yv), yu^(-1), 1/(yu*yv)}, yw])/8 + 
     (G[{0}, yu^(-1)]*G[{0, 1/(yu*yv), yv^(-1), 1}, yw])/8 + 
     (G[{0}, yv^(-1)]*G[{0, 1/(yu*yv), yv^(-1), 1}, yw])/8 - 
     (G[{0}, yw]*G[{0, 1/(yu*yv), yv^(-1), 1}, yw])/8 - 
     (G[{1}, yu^(-1)]*G[{0, 1/(yu*yv), yv^(-1), 1}, yw])/16 - 
     (G[{1}, yv^(-1)]*G[{0, 1/(yu*yv), yv^(-1), 1}, yw])/16 - 
     (G[{yu}, yv^(-1)]*G[{0, 1/(yu*yv), yv^(-1), 1}, yw])/8 - 
     (G[{1}, yu^(-1)]*G[{0, 1/(yu*yv), yv^(-1), yu^(-1)}, yw])/8 + 
     (G[{1}, yv^(-1)]*G[{0, 1/(yu*yv), yv^(-1), yu^(-1)}, yw])/8 - 
     (G[{1}, yw]*G[{0, 1/(yu*yv), yv^(-1), yu^(-1)}, yw])/8 + 
     (G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv), yv^(-1), yu^(-1)}, yw])/8 + 
     (G[{0}, yu^(-1)]*G[{0, 1/(yu*yv), yv^(-1), yv^(-1)}, yw])/8 + 
     (G[{0}, yv^(-1)]*G[{0, 1/(yu*yv), yv^(-1), yv^(-1)}, yw])/8 - 
     (G[{0}, yw]*G[{0, 1/(yu*yv), yv^(-1), yv^(-1)}, yw])/8 - 
     (G[{1}, yu^(-1)]*G[{0, 1/(yu*yv), yv^(-1), yv^(-1)}, yw])/8 - 
     (G[{1}, yv^(-1)]*G[{0, 1/(yu*yv), yv^(-1), yv^(-1)}, yw])/8 - 
     (G[{1}, yw]*G[{0, 1/(yu*yv), yv^(-1), yv^(-1)}, yw])/8 - 
     (3*G[{0}, yu^(-1)]*G[{0, 1/(yu*yv), yv^(-1), 1/(yu*yv)}, yw])/16 - 
     (3*G[{0}, yv^(-1)]*G[{0, 1/(yu*yv), yv^(-1), 1/(yu*yv)}, yw])/16 + 
     (3*G[{0}, yw]*G[{0, 1/(yu*yv), yv^(-1), 1/(yu*yv)}, yw])/16 + 
     (5*G[{1}, yu^(-1)]*G[{0, 1/(yu*yv), yv^(-1), 1/(yu*yv)}, yw])/16 + 
     (3*G[{1}, yv^(-1)]*G[{0, 1/(yu*yv), yv^(-1), 1/(yu*yv)}, yw])/16 - 
     (G[{yu}, yv^(-1)]*G[{0, 1/(yu*yv), yv^(-1), 1/(yu*yv)}, yw])/8 - 
     (5*G[{1}, yu^(-1)]*G[{0, 1/(yu*yv), 1/(yu*yv), 1}, yw])/16 + 
     (5*G[{yu}, yv^(-1)]*G[{0, 1/(yu*yv), 1/(yu*yv), 1}, yw])/16 + 
     (3*G[{1}, yu^(-1)]*G[{0, 1/(yu*yv), 1/(yu*yv), yu^(-1)}, yw])/16 - 
     (3*G[{1}, yv^(-1)]*G[{0, 1/(yu*yv), 1/(yu*yv), yu^(-1)}, yw])/16 + 
     (G[{1}, yw]*G[{0, 1/(yu*yv), 1/(yu*yv), yu^(-1)}, yw])/16 - 
     (3*G[{0}, yu^(-1)]*G[{0, 1/(yu*yv), 1/(yu*yv), yv^(-1)}, yw])/16 - 
     (3*G[{0}, yv^(-1)]*G[{0, 1/(yu*yv), 1/(yu*yv), yv^(-1)}, yw])/16 + 
     (3*G[{0}, yw]*G[{0, 1/(yu*yv), 1/(yu*yv), yv^(-1)}, yw])/16 + 
     (5*G[{1}, yu^(-1)]*G[{0, 1/(yu*yv), 1/(yu*yv), yv^(-1)}, yw])/16 + 
     (3*G[{1}, yv^(-1)]*G[{0, 1/(yu*yv), 1/(yu*yv), yv^(-1)}, yw])/16 - 
     (G[{1}, yw]*G[{0, 1/(yu*yv), 1/(yu*yv), yv^(-1)}, yw])/16 - 
     (G[{yu}, yv^(-1)]*G[{0, 1/(yu*yv), 1/(yu*yv), yv^(-1)}, yw])/8 + 
     (3*G[{0}, yu^(-1)]*G[{0, 1/(yu*yv), 1/(yu*yv), 1/(yu*yv)}, yw])/16 + 
     (3*G[{0}, yv^(-1)]*G[{0, 1/(yu*yv), 1/(yu*yv), 1/(yu*yv)}, yw])/16 - 
     (3*G[{0}, yw]*G[{0, 1/(yu*yv), 1/(yu*yv), 1/(yu*yv)}, yw])/16 - 
     (G[{1}, yu^(-1)]*G[{0, 1/(yu*yv), 1/(yu*yv), 1/(yu*yv)}, yw])/4 - 
     (G[{1}, yv^(-1)]*G[{0, 1/(yu*yv), 1/(yu*yv), 1/(yu*yv)}, yw])/16 - 
     (G[{yu}, yv^(-1)]*G[{0, 1/(yu*yv), 1/(yu*yv), 1/(yu*yv)}, yw])/16 - 
     (G[{1}, yu^(-1)]*G[{1, 1, 1, yu^(-1)}, yw])/16 + 
     (G[{1}, yv^(-1)]*G[{1, 1, 1, yu^(-1)}, yw])/4 + 
     (3*G[{1}, yw]*G[{1, 1, 1, yu^(-1)}, yw])/16 - 
     (3*G[{yu}, yv^(-1)]*G[{1, 1, 1, yu^(-1)}, yw])/16 - 
     (G[{1/(yu*yv)}, yw]*G[{1, 1, 1, yu^(-1)}, yw])/8 - 
     (G[{0}, yu^(-1)]*G[{1, 1, 1, yu}, yv^(-1)])/8 - 
     (G[{0}, yv^(-1)]*G[{1, 1, 1, yu}, yv^(-1)])/8 + 
     (G[{0}, yw]*G[{1, 1, 1, yu}, yv^(-1)])/8 + 
     (5*G[{1}, yu^(-1)]*G[{1, 1, 1, yu}, yv^(-1)])/64 + 
     (3*G[{1}, yv^(-1)]*G[{1, 1, 1, yu}, yv^(-1)])/16 - 
     (G[{1}, yw]*G[{1, 1, 1, yu}, yv^(-1)])/8 - 
     (G[{1/(yu*yv)}, yw]*G[{1, 1, 1, yu}, yv^(-1)])/8 - 
     (5*G[{0}, yu^(-1)]*G[{1, 1, 1, yv^(-1)}, yw])/16 - 
     (5*G[{0}, yv^(-1)]*G[{1, 1, 1, yv^(-1)}, yw])/16 + 
     (5*G[{0}, yw]*G[{1, 1, 1, yv^(-1)}, yw])/16 + 
     (23*G[{1}, yu^(-1)]*G[{1, 1, 1, yv^(-1)}, yw])/64 + 
     (5*G[{1}, yv^(-1)]*G[{1, 1, 1, yv^(-1)}, yw])/16 + 
     (3*G[{1}, yw]*G[{1, 1, 1, yv^(-1)}, yw])/64 - 
     (3*G[{yu}, yv^(-1)]*G[{1, 1, 1, yv^(-1)}, yw])/64 + 
     (G[{1/(yu*yv)}, yw]*G[{1, 1, 1, yv^(-1)}, yw])/64 - 
     (G[{0}, yu^(-1)]*G[{1, 1, 1, 1/(yu*yv)}, yw])/16 - 
     (G[{0}, yv^(-1)]*G[{1, 1, 1, 1/(yu*yv)}, yw])/16 + 
     (G[{0}, yw]*G[{1, 1, 1, 1/(yu*yv)}, yw])/16 - 
     (3*G[{1}, yu^(-1)]*G[{1, 1, 1, 1/(yu*yv)}, yw])/64 - 
     (3*G[{1}, yv^(-1)]*G[{1, 1, 1, 1/(yu*yv)}, yw])/16 - 
     (23*G[{1}, yw]*G[{1, 1, 1, 1/(yu*yv)}, yw])/64 + 
     (23*G[{yu}, yv^(-1)]*G[{1, 1, 1, 1/(yu*yv)}, yw])/64 - 
     (9*G[{1/(yu*yv)}, yw]*G[{1, 1, 1, 1/(yu*yv)}, yw])/64 - 
     (G[{0}, yu^(-1)]*G[{1, 1, yu^(-1), yu^(-1)}, yw])/16 - 
     (G[{0}, yv^(-1)]*G[{1, 1, yu^(-1), yu^(-1)}, yw])/16 + 
     (G[{0}, yw]*G[{1, 1, yu^(-1), yu^(-1)}, yw])/16 + 
     (3*G[{1}, yu^(-1)]*G[{1, 1, yu^(-1), yu^(-1)}, yw])/16 - 
     (G[{1}, yv^(-1)]*G[{1, 1, yu^(-1), yu^(-1)}, yw])/16 - 
     (G[{1/(yu*yv)}, yw]*G[{1, 1, yu^(-1), yu^(-1)}, yw])/8 - 
     (G[{0}, yu^(-1)]*G[{1, 1, yu^(-1), yv^(-1)}, yw])/16 - 
     (G[{0}, yv^(-1)]*G[{1, 1, yu^(-1), yv^(-1)}, yw])/16 + 
     (G[{0}, yw]*G[{1, 1, yu^(-1), yv^(-1)}, yw])/16 + 
     (3*G[{1}, yu^(-1)]*G[{1, 1, yu^(-1), yv^(-1)}, yw])/16 - 
     (G[{1}, yv^(-1)]*G[{1, 1, yu^(-1), yv^(-1)}, yw])/16 - 
     (3*G[{1}, yu^(-1)]*G[{1, 1, yu^(-1), 1/(yu*yv)}, yw])/16 + 
     (G[{1}, yv^(-1)]*G[{1, 1, yu^(-1), 1/(yu*yv)}, yw])/4 + 
     (G[{1}, yw]*G[{1, 1, yu^(-1), 1/(yu*yv)}, yw])/16 - 
     (G[{yu}, yv^(-1)]*G[{1, 1, yu^(-1), 1/(yu*yv)}, yw])/16 + 
     (G[{0}, yu^(-1)]*G[{1, 1, yu, yu}, yv^(-1)])/4 + 
     (G[{0}, yv^(-1)]*G[{1, 1, yu, yu}, yv^(-1)])/4 - 
     (G[{0}, yw]*G[{1, 1, yu, yu}, yv^(-1)])/4 + 
     (9*G[{1}, yu^(-1)]*G[{1, 1, yu, yu}, yv^(-1)])/64 + 
     (17*G[{1}, yw]*G[{1, 1, yu, yu}, yv^(-1)])/32 - 
     (G[{1/(yu*yv)}, yw]*G[{1, 1, yu, yu}, yv^(-1)])/32 - 
     (G[{0}, yu^(-1)]*G[{1, 1, yv^(-1), yu^(-1)}, yw])/16 - 
     (G[{0}, yv^(-1)]*G[{1, 1, yv^(-1), yu^(-1)}, yw])/16 + 
     (G[{0}, yw]*G[{1, 1, yv^(-1), yu^(-1)}, yw])/16 + 
     (3*G[{1}, yu^(-1)]*G[{1, 1, yv^(-1), yu^(-1)}, yw])/16 - 
     (G[{1}, yv^(-1)]*G[{1, 1, yv^(-1), yu^(-1)}, yw])/16 - 
     (3*G[{0}, yu^(-1)]*G[{1, 1, yv^(-1), yv^(-1)}, yw])/16 - 
     (3*G[{0}, yv^(-1)]*G[{1, 1, yv^(-1), yv^(-1)}, yw])/16 + 
     (3*G[{0}, yw]*G[{1, 1, yv^(-1), yv^(-1)}, yw])/16 + 
     (35*G[{1}, yu^(-1)]*G[{1, 1, yv^(-1), yv^(-1)}, yw])/64 + 
     (3*G[{1}, yv^(-1)]*G[{1, 1, yv^(-1), yv^(-1)}, yw])/16 + 
     (23*G[{1}, yw]*G[{1, 1, yv^(-1), yv^(-1)}, yw])/64 - 
     (23*G[{yu}, yv^(-1)]*G[{1, 1, yv^(-1), yv^(-1)}, yw])/64 - 
     (5*G[{1/(yu*yv)}, yw]*G[{1, 1, yv^(-1), yv^(-1)}, yw])/64 + 
     (5*G[{0}, yu^(-1)]*G[{1, 1, yv^(-1), 1/(yu*yv)}, yw])/16 + 
     (5*G[{0}, yv^(-1)]*G[{1, 1, yv^(-1), 1/(yu*yv)}, yw])/16 - 
     (5*G[{0}, yw]*G[{1, 1, yv^(-1), 1/(yu*yv)}, yw])/16 - 
     (5*G[{1}, yv^(-1)]*G[{1, 1, yv^(-1), 1/(yu*yv)}, yw])/16 + 
     (5*G[{1}, yw]*G[{1, 1, yv^(-1), 1/(yu*yv)}, yw])/16 - 
     (5*G[{yu}, yv^(-1)]*G[{1, 1, yv^(-1), 1/(yu*yv)}, yw])/16 + 
     (3*G[{1/(yu*yv)}, yw]*G[{1, 1, yv^(-1), 1/(yu*yv)}, yw])/32 - 
     (G[{0}, yu^(-1)]*G[{1, 1, 1/(yu*yv), yu^(-1)}, yw])/8 - 
     (G[{0}, yv^(-1)]*G[{1, 1, 1/(yu*yv), yu^(-1)}, yw])/8 + 
     (G[{0}, yw]*G[{1, 1, 1/(yu*yv), yu^(-1)}, yw])/8 - 
     (G[{1}, yu^(-1)]*G[{1, 1, 1/(yu*yv), yu^(-1)}, yw])/4 + 
     (G[{1}, yv^(-1)]*G[{1, 1, 1/(yu*yv), yu^(-1)}, yw])/2 + 
     (G[{1/(yu*yv)}, yw]*G[{1, 1, 1/(yu*yv), yu^(-1)}, yw])/8 + 
     (G[{0}, yu^(-1)]*G[{1, 1, 1/(yu*yv), yv^(-1)}, yw])/4 + 
     (G[{0}, yv^(-1)]*G[{1, 1, 1/(yu*yv), yv^(-1)}, yw])/4 - 
     (G[{0}, yw]*G[{1, 1, 1/(yu*yv), yv^(-1)}, yw])/4 - 
     (7*G[{1}, yu^(-1)]*G[{1, 1, 1/(yu*yv), yv^(-1)}, yw])/64 - 
     (G[{1}, yv^(-1)]*G[{1, 1, 1/(yu*yv), yv^(-1)}, yw])/4 + 
     (9*G[{1}, yw]*G[{1, 1, 1/(yu*yv), yv^(-1)}, yw])/64 - 
     (9*G[{yu}, yv^(-1)]*G[{1, 1, 1/(yu*yv), yv^(-1)}, yw])/64 + 
     (5*G[{1/(yu*yv)}, yw]*G[{1, 1, 1/(yu*yv), yv^(-1)}, yw])/64 - 
     (5*G[{0}, yu^(-1)]*G[{1, 1, 1/(yu*yv), 1/(yu*yv)}, yw])/16 - 
     (5*G[{0}, yv^(-1)]*G[{1, 1, 1/(yu*yv), 1/(yu*yv)}, yw])/16 + 
     (5*G[{0}, yw]*G[{1, 1, 1/(yu*yv), 1/(yu*yv)}, yw])/16 - 
     (3*G[{1}, yu^(-1)]*G[{1, 1, 1/(yu*yv), 1/(yu*yv)}, yw])/16 - 
     (3*G[{1}, yv^(-1)]*G[{1, 1, 1/(yu*yv), 1/(yu*yv)}, yw])/16 - 
     G[{1}, yw]*G[{1, 1, 1/(yu*yv), 1/(yu*yv)}, yw] + 
     G[{yu}, yv^(-1)]*G[{1, 1, 1/(yu*yv), 1/(yu*yv)}, yw] - 
     (3*G[{1/(yu*yv)}, yw]*G[{1, 1, 1/(yu*yv), 1/(yu*yv)}, yw])/32 + 
     (G[{0}, yu^(-1)]*G[{1, yu^(-1), 1, yv^(-1)}, yw])/16 + 
     (G[{0}, yv^(-1)]*G[{1, yu^(-1), 1, yv^(-1)}, yw])/16 - 
     (G[{0}, yw]*G[{1, yu^(-1), 1, yv^(-1)}, yw])/16 + 
     (G[{1}, yu^(-1)]*G[{1, yu^(-1), 1, yv^(-1)}, yw])/8 - 
     (G[{1}, yv^(-1)]*G[{1, yu^(-1), 1, yv^(-1)}, yw])/8 + 
     (G[{1}, yw]*G[{1, yu^(-1), 1, yv^(-1)}, yw])/8 - 
     (G[{yu}, yv^(-1)]*G[{1, yu^(-1), 1, yv^(-1)}, yw])/8 - 
     (G[{0}, yu^(-1)]*G[{1, yu^(-1), 1, 1/(yu*yv)}, yw])/16 - 
     (G[{0}, yv^(-1)]*G[{1, yu^(-1), 1, 1/(yu*yv)}, yw])/16 + 
     (G[{0}, yw]*G[{1, yu^(-1), 1, 1/(yu*yv)}, yw])/16 - 
     (G[{1}, yu^(-1)]*G[{1, yu^(-1), 1, 1/(yu*yv)}, yw])/4 + 
     (G[{1}, yv^(-1)]*G[{1, yu^(-1), 1, 1/(yu*yv)}, yw])/4 - 
     (G[{1}, yw]*G[{1, yu^(-1), 1, 1/(yu*yv)}, yw])/8 + 
     (G[{yu}, yv^(-1)]*G[{1, yu^(-1), 1, 1/(yu*yv)}, yw])/8 - 
     (G[{0}, yu^(-1)]*G[{1, yu^(-1), yu^(-1), yu^(-1)}, yw])/8 - 
     (G[{0}, yv^(-1)]*G[{1, yu^(-1), yu^(-1), yu^(-1)}, yw])/8 + 
     (G[{0}, yw]*G[{1, yu^(-1), yu^(-1), yu^(-1)}, yw])/8 + 
     (3*G[{1}, yu^(-1)]*G[{1, yu^(-1), yu^(-1), yu^(-1)}, yw])/8 - 
     (G[{1}, yv^(-1)]*G[{1, yu^(-1), yu^(-1), yu^(-1)}, yw])/8 - 
     (G[{0}, yu^(-1)]*G[{1, yu^(-1), yu^(-1), yv^(-1)}, yw])/8 - 
     (G[{0}, yv^(-1)]*G[{1, yu^(-1), yu^(-1), yv^(-1)}, yw])/8 + 
     (G[{0}, yw]*G[{1, yu^(-1), yu^(-1), yv^(-1)}, yw])/8 - 
     (G[{1}, yu^(-1)]*G[{1, yu^(-1), yu^(-1), yv^(-1)}, yw])/8 + 
     (3*G[{1}, yv^(-1)]*G[{1, yu^(-1), yu^(-1), yv^(-1)}, yw])/8 + 
     (G[{1/(yu*yv)}, yw]*G[{1, yu^(-1), yu^(-1), yv^(-1)}, yw])/8 + 
     (G[{0}, yu^(-1)]*G[{1, yu^(-1), yu^(-1), 1/(yu*yv)}, yw])/16 + 
     (G[{0}, yv^(-1)]*G[{1, yu^(-1), yu^(-1), 1/(yu*yv)}, yw])/16 - 
     (G[{0}, yw]*G[{1, yu^(-1), yu^(-1), 1/(yu*yv)}, yw])/16 + 
     (5*G[{1}, yu^(-1)]*G[{1, yu^(-1), yu^(-1), 1/(yu*yv)}, yw])/16 - 
     (3*G[{1}, yv^(-1)]*G[{1, yu^(-1), yu^(-1), 1/(yu*yv)}, yw])/16 + 
     (G[{1}, yw]*G[{1, yu^(-1), yu^(-1), 1/(yu*yv)}, yw])/4 - 
     (G[{yu}, yv^(-1)]*G[{1, yu^(-1), yu^(-1), 1/(yu*yv)}, yw])/4 - 
     (G[{0}, yu^(-1)]*G[{1, yu^(-1), yv^(-1), yu^(-1)}, yw])/8 - 
     (G[{0}, yv^(-1)]*G[{1, yu^(-1), yv^(-1), yu^(-1)}, yw])/8 + 
     (G[{0}, yw]*G[{1, yu^(-1), yv^(-1), yu^(-1)}, yw])/8 - 
     (G[{1}, yu^(-1)]*G[{1, yu^(-1), yv^(-1), yu^(-1)}, yw])/8 + 
     (3*G[{1}, yv^(-1)]*G[{1, yu^(-1), yv^(-1), yu^(-1)}, yw])/8 + 
     (G[{1/(yu*yv)}, yw]*G[{1, yu^(-1), yv^(-1), yu^(-1)}, yw])/8 + 
     (G[{0}, yu^(-1)]*G[{1, yu^(-1), yv^(-1), yv^(-1)}, yw])/8 + 
     (G[{0}, yv^(-1)]*G[{1, yu^(-1), yv^(-1), yv^(-1)}, yw])/8 - 
     (G[{0}, yw]*G[{1, yu^(-1), yv^(-1), yv^(-1)}, yw])/8 - 
     (G[{1}, yu^(-1)]*G[{1, yu^(-1), yv^(-1), yv^(-1)}, yw])/8 - 
     (G[{1}, yv^(-1)]*G[{1, yu^(-1), yv^(-1), yv^(-1)}, yw])/8 + 
     (G[{1/(yu*yv)}, yw]*G[{1, yu^(-1), yv^(-1), yv^(-1)}, yw])/8 - 
     (G[{0}, yu^(-1)]*G[{1, yu^(-1), yv^(-1), 1/(yu*yv)}, yw])/8 - 
     (G[{0}, yv^(-1)]*G[{1, yu^(-1), yv^(-1), 1/(yu*yv)}, yw])/8 + 
     (G[{0}, yw]*G[{1, yu^(-1), yv^(-1), 1/(yu*yv)}, yw])/8 + 
     (3*G[{1}, yu^(-1)]*G[{1, yu^(-1), yv^(-1), 1/(yu*yv)}, yw])/16 - 
     (G[{1}, yv^(-1)]*G[{1, yu^(-1), yv^(-1), 1/(yu*yv)}, yw])/16 - 
     (G[{1}, yw]*G[{1, yu^(-1), yv^(-1), 1/(yu*yv)}, yw])/8 + 
     (G[{yu}, yv^(-1)]*G[{1, yu^(-1), yv^(-1), 1/(yu*yv)}, yw])/8 + 
     (G[{0}, yu^(-1)]*G[{1, yu^(-1), 1/(yu*yv), yu^(-1)}, yw])/16 + 
     (G[{0}, yv^(-1)]*G[{1, yu^(-1), 1/(yu*yv), yu^(-1)}, yw])/16 - 
     (G[{0}, yw]*G[{1, yu^(-1), 1/(yu*yv), yu^(-1)}, yw])/16 + 
     (G[{1}, yu^(-1)]*G[{1, yu^(-1), 1/(yu*yv), yu^(-1)}, yw])/16 - 
     (3*G[{1}, yv^(-1)]*G[{1, yu^(-1), 1/(yu*yv), yu^(-1)}, yw])/16 - 
     (G[{0}, yu^(-1)]*G[{1, yu^(-1), 1/(yu*yv), yv^(-1)}, yw])/16 - 
     (G[{0}, yv^(-1)]*G[{1, yu^(-1), 1/(yu*yv), yv^(-1)}, yw])/16 + 
     (G[{0}, yw]*G[{1, yu^(-1), 1/(yu*yv), yv^(-1)}, yw])/16 + 
     (G[{1}, yu^(-1)]*G[{1, yu^(-1), 1/(yu*yv), yv^(-1)}, yw])/16 + 
     (G[{1}, yv^(-1)]*G[{1, yu^(-1), 1/(yu*yv), yv^(-1)}, yw])/16 + 
     (G[{0}, yu^(-1)]*G[{1, yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/16 + 
     (G[{0}, yv^(-1)]*G[{1, yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/16 - 
     (G[{0}, yw]*G[{1, yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/16 - 
     (3*G[{1}, yu^(-1)]*G[{1, yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/16 + 
     (G[{1}, yv^(-1)]*G[{1, yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/8 + 
     (G[{1}, yw]*G[{1, yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/16 - 
     (G[{yu}, yv^(-1)]*G[{1, yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/16 + 
     (G[{0}, yu^(-1)]*G[{1, yu, yu, yu}, yv^(-1)])/2 + 
     (G[{0}, yv^(-1)]*G[{1, yu, yu, yu}, yv^(-1)])/2 - 
     (G[{0}, yw]*G[{1, yu, yu, yu}, yv^(-1)])/2 + 
     (9*G[{1}, yu^(-1)]*G[{1, yu, yu, yu}, yv^(-1)])/32 + 
     (61*G[{1}, yw]*G[{1, yu, yu, yu}, yv^(-1)])/64 + 
     (3*G[{1/(yu*yv)}, yw]*G[{1, yu, yu, yu}, yv^(-1)])/64 + 
     (G[{0}, yu^(-1)]*G[{1, yv^(-1), 1, 1/(yu*yv)}, yw])/16 + 
     (G[{0}, yv^(-1)]*G[{1, yv^(-1), 1, 1/(yu*yv)}, yw])/16 - 
     (G[{0}, yw]*G[{1, yv^(-1), 1, 1/(yu*yv)}, yw])/16 + 
     (G[{1}, yu^(-1)]*G[{1, yv^(-1), 1, 1/(yu*yv)}, yw])/8 - 
     (G[{1}, yv^(-1)]*G[{1, yv^(-1), 1, 1/(yu*yv)}, yw])/8 + 
     (G[{1}, yw]*G[{1, yv^(-1), 1, 1/(yu*yv)}, yw])/8 - 
     (G[{yu}, yv^(-1)]*G[{1, yv^(-1), 1, 1/(yu*yv)}, yw])/8 - 
     (G[{0}, yu^(-1)]*G[{1, yv^(-1), yu^(-1), yu^(-1)}, yw])/8 - 
     (G[{0}, yv^(-1)]*G[{1, yv^(-1), yu^(-1), yu^(-1)}, yw])/8 + 
     (G[{0}, yw]*G[{1, yv^(-1), yu^(-1), yu^(-1)}, yw])/8 - 
     (G[{1}, yu^(-1)]*G[{1, yv^(-1), yu^(-1), yu^(-1)}, yw])/8 + 
     (3*G[{1}, yv^(-1)]*G[{1, yv^(-1), yu^(-1), yu^(-1)}, yw])/8 + 
     (G[{1/(yu*yv)}, yw]*G[{1, yv^(-1), yu^(-1), yu^(-1)}, yw])/8 + 
     (G[{0}, yu^(-1)]*G[{1, yv^(-1), yu^(-1), yv^(-1)}, yw])/8 + 
     (G[{0}, yv^(-1)]*G[{1, yv^(-1), yu^(-1), yv^(-1)}, yw])/8 - 
     (G[{0}, yw]*G[{1, yv^(-1), yu^(-1), yv^(-1)}, yw])/8 - 
     (G[{1}, yu^(-1)]*G[{1, yv^(-1), yu^(-1), yv^(-1)}, yw])/8 - 
     (G[{1}, yv^(-1)]*G[{1, yv^(-1), yu^(-1), yv^(-1)}, yw])/8 + 
     (G[{1/(yu*yv)}, yw]*G[{1, yv^(-1), yu^(-1), yv^(-1)}, yw])/8 - 
     (G[{0}, yu^(-1)]*G[{1, yv^(-1), yu^(-1), 1/(yu*yv)}, yw])/8 - 
     (G[{0}, yv^(-1)]*G[{1, yv^(-1), yu^(-1), 1/(yu*yv)}, yw])/8 + 
     (G[{0}, yw]*G[{1, yv^(-1), yu^(-1), 1/(yu*yv)}, yw])/8 + 
     (3*G[{1}, yu^(-1)]*G[{1, yv^(-1), yu^(-1), 1/(yu*yv)}, yw])/16 - 
     (G[{1}, yv^(-1)]*G[{1, yv^(-1), yu^(-1), 1/(yu*yv)}, yw])/16 - 
     (G[{1}, yw]*G[{1, yv^(-1), yu^(-1), 1/(yu*yv)}, yw])/8 + 
     (G[{yu}, yv^(-1)]*G[{1, yv^(-1), yu^(-1), 1/(yu*yv)}, yw])/8 + 
     (G[{0}, yu^(-1)]*G[{1, yv^(-1), yv^(-1), yu^(-1)}, yw])/8 + 
     (G[{0}, yv^(-1)]*G[{1, yv^(-1), yv^(-1), yu^(-1)}, yw])/8 - 
     (G[{0}, yw]*G[{1, yv^(-1), yv^(-1), yu^(-1)}, yw])/8 - 
     (G[{1}, yu^(-1)]*G[{1, yv^(-1), yv^(-1), yu^(-1)}, yw])/8 - 
     (G[{1}, yv^(-1)]*G[{1, yv^(-1), yv^(-1), yu^(-1)}, yw])/8 + 
     (G[{1/(yu*yv)}, yw]*G[{1, yv^(-1), yv^(-1), yu^(-1)}, yw])/8 + 
     (G[{0}, yu^(-1)]*G[{1, yv^(-1), yv^(-1), yv^(-1)}, yw])/8 + 
     (G[{0}, yv^(-1)]*G[{1, yv^(-1), yv^(-1), yv^(-1)}, yw])/8 - 
     (G[{0}, yw]*G[{1, yv^(-1), yv^(-1), yv^(-1)}, yw])/8 + 
     (3*G[{1}, yu^(-1)]*G[{1, yv^(-1), yv^(-1), yv^(-1)}, yw])/32 - 
     (G[{1}, yv^(-1)]*G[{1, yv^(-1), yv^(-1), yv^(-1)}, yw])/8 + 
     (7*G[{1}, yw]*G[{1, yv^(-1), yv^(-1), yv^(-1)}, yw])/32 - 
     (7*G[{yu}, yv^(-1)]*G[{1, yv^(-1), yv^(-1), yv^(-1)}, yw])/32 - 
     (3*G[{1/(yu*yv)}, yw]*G[{1, yv^(-1), yv^(-1), yv^(-1)}, yw])/64 - 
     (G[{0}, yu^(-1)]*G[{1, yv^(-1), yv^(-1), 1/(yu*yv)}, yw])/16 - 
     (G[{0}, yv^(-1)]*G[{1, yv^(-1), yv^(-1), 1/(yu*yv)}, yw])/16 + 
     (G[{0}, yw]*G[{1, yv^(-1), yv^(-1), 1/(yu*yv)}, yw])/16 - 
     (3*G[{1}, yu^(-1)]*G[{1, yv^(-1), yv^(-1), 1/(yu*yv)}, yw])/64 + 
     (G[{1}, yv^(-1)]*G[{1, yv^(-1), yv^(-1), 1/(yu*yv)}, yw])/16 - 
     (7*G[{1}, yw]*G[{1, yv^(-1), yv^(-1), 1/(yu*yv)}, yw])/64 + 
     (7*G[{yu}, yv^(-1)]*G[{1, yv^(-1), yv^(-1), 1/(yu*yv)}, yw])/64 + 
     (3*G[{1/(yu*yv)}, yw]*G[{1, yv^(-1), yv^(-1), 1/(yu*yv)}, yw])/32 + 
     (G[{0}, yu^(-1)]*G[{1, yv^(-1), 1/(yu*yv), yu^(-1)}, yw])/16 + 
     (G[{0}, yv^(-1)]*G[{1, yv^(-1), 1/(yu*yv), yu^(-1)}, yw])/16 - 
     (G[{0}, yw]*G[{1, yv^(-1), 1/(yu*yv), yu^(-1)}, yw])/16 + 
     (G[{1}, yu^(-1)]*G[{1, yv^(-1), 1/(yu*yv), yu^(-1)}, yw])/16 - 
     (3*G[{1}, yv^(-1)]*G[{1, yv^(-1), 1/(yu*yv), yu^(-1)}, yw])/16 - 
     (G[{0}, yu^(-1)]*G[{1, yv^(-1), 1/(yu*yv), yv^(-1)}, yw])/16 - 
     (G[{0}, yv^(-1)]*G[{1, yv^(-1), 1/(yu*yv), yv^(-1)}, yw])/16 + 
     (G[{0}, yw]*G[{1, yv^(-1), 1/(yu*yv), yv^(-1)}, yw])/16 - 
     (3*G[{1}, yu^(-1)]*G[{1, yv^(-1), 1/(yu*yv), yv^(-1)}, yw])/64 + 
     (G[{1}, yv^(-1)]*G[{1, yv^(-1), 1/(yu*yv), yv^(-1)}, yw])/16 - 
     (7*G[{1}, yw]*G[{1, yv^(-1), 1/(yu*yv), yv^(-1)}, yw])/64 + 
     (7*G[{yu}, yv^(-1)]*G[{1, yv^(-1), 1/(yu*yv), yv^(-1)}, yw])/64 + 
     (3*G[{1/(yu*yv)}, yw]*G[{1, yv^(-1), 1/(yu*yv), yv^(-1)}, yw])/32 + 
     (G[{0}, yu^(-1)]*G[{1, yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/8 + 
     (G[{0}, yv^(-1)]*G[{1, yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/8 - 
     (G[{0}, yw]*G[{1, yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/8 - 
     (9*G[{1}, yu^(-1)]*G[{1, yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/64 + 
     (G[{1}, yv^(-1)]*G[{1, yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/16 + 
     (11*G[{1}, yw]*G[{1, yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/64 - 
     (11*G[{yu}, yv^(-1)]*G[{1, yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/64 + 
     (G[{1/(yu*yv)}, yw]*G[{1, 1/(yu*yv), yu^(-1), yu^(-1)}, yw])/8 - 
     (G[{0}, yu^(-1)]*G[{1, 1/(yu*yv), yu^(-1), 1/(yu*yv)}, yw])/16 - 
     (G[{0}, yv^(-1)]*G[{1, 1/(yu*yv), yu^(-1), 1/(yu*yv)}, yw])/16 + 
     (G[{0}, yw]*G[{1, 1/(yu*yv), yu^(-1), 1/(yu*yv)}, yw])/16 - 
     (G[{1}, yu^(-1)]*G[{1, 1/(yu*yv), yu^(-1), 1/(yu*yv)}, yw])/4 + 
     (G[{1}, yv^(-1)]*G[{1, 1/(yu*yv), yu^(-1), 1/(yu*yv)}, yw])/4 - 
     (G[{1}, yw]*G[{1, 1/(yu*yv), yu^(-1), 1/(yu*yv)}, yw])/8 + 
     (G[{yu}, yv^(-1)]*G[{1, 1/(yu*yv), yu^(-1), 1/(yu*yv)}, yw])/8 - 
     (7*G[{1}, yu^(-1)]*G[{1, 1/(yu*yv), yv^(-1), yv^(-1)}, yw])/32 - 
     (7*G[{1}, yw]*G[{1, 1/(yu*yv), yv^(-1), yv^(-1)}, yw])/32 + 
     (7*G[{yu}, yv^(-1)]*G[{1, 1/(yu*yv), yv^(-1), yv^(-1)}, yw])/32 + 
     (11*G[{1/(yu*yv)}, yw]*G[{1, 1/(yu*yv), yv^(-1), yv^(-1)}, yw])/64 - 
     (G[{0}, yu^(-1)]*G[{1, 1/(yu*yv), yv^(-1), 1/(yu*yv)}, yw])/16 - 
     (G[{0}, yv^(-1)]*G[{1, 1/(yu*yv), yv^(-1), 1/(yu*yv)}, yw])/16 + 
     (G[{0}, yw]*G[{1, 1/(yu*yv), yv^(-1), 1/(yu*yv)}, yw])/16 + 
     (15*G[{1}, yu^(-1)]*G[{1, 1/(yu*yv), yv^(-1), 1/(yu*yv)}, yw])/64 - 
     (G[{1}, yv^(-1)]*G[{1, 1/(yu*yv), yv^(-1), 1/(yu*yv)}, yw])/8 - 
     (G[{1}, yw]*G[{1, 1/(yu*yv), yv^(-1), 1/(yu*yv)}, yw])/64 + 
     (G[{yu}, yv^(-1)]*G[{1, 1/(yu*yv), yv^(-1), 1/(yu*yv)}, yw])/64 - 
     (3*G[{1/(yu*yv)}, yw]*G[{1, 1/(yu*yv), yv^(-1), 1/(yu*yv)}, yw])/32 - 
     (G[{0}, yu^(-1)]*G[{1, 1/(yu*yv), 1/(yu*yv), yu^(-1)}, yw])/8 - 
     (G[{0}, yv^(-1)]*G[{1, 1/(yu*yv), 1/(yu*yv), yu^(-1)}, yw])/8 + 
     (G[{0}, yw]*G[{1, 1/(yu*yv), 1/(yu*yv), yu^(-1)}, yw])/8 - 
     (G[{1}, yu^(-1)]*G[{1, 1/(yu*yv), 1/(yu*yv), yu^(-1)}, yw])/4 + 
     (G[{1}, yv^(-1)]*G[{1, 1/(yu*yv), 1/(yu*yv), yu^(-1)}, yw])/2 + 
     (7*G[{1}, yu^(-1)]*G[{1, 1/(yu*yv), 1/(yu*yv), yv^(-1)}, yw])/64 - 
     (G[{1}, yv^(-1)]*G[{1, 1/(yu*yv), 1/(yu*yv), yv^(-1)}, yw])/4 - 
     (9*G[{1}, yw]*G[{1, 1/(yu*yv), 1/(yu*yv), yv^(-1)}, yw])/64 + 
     (9*G[{yu}, yv^(-1)]*G[{1, 1/(yu*yv), 1/(yu*yv), yv^(-1)}, yw])/64 - 
     (3*G[{1/(yu*yv)}, yw]*G[{1, 1/(yu*yv), 1/(yu*yv), yv^(-1)}, yw])/32 - 
     (G[{0}, yu^(-1)]*G[{1, 1/(yu*yv), 1/(yu*yv), 1/(yu*yv)}, yw])/16 - 
     (G[{0}, yv^(-1)]*G[{1, 1/(yu*yv), 1/(yu*yv), 1/(yu*yv)}, yw])/16 + 
     (G[{0}, yw]*G[{1, 1/(yu*yv), 1/(yu*yv), 1/(yu*yv)}, yw])/16 - 
     (3*G[{1}, yu^(-1)]*G[{1, 1/(yu*yv), 1/(yu*yv), 1/(yu*yv)}, yw])/64 - 
     (3*G[{1}, yv^(-1)]*G[{1, 1/(yu*yv), 1/(yu*yv), 1/(yu*yv)}, yw])/16 - 
     (23*G[{1}, yw]*G[{1, 1/(yu*yv), 1/(yu*yv), 1/(yu*yv)}, yw])/64 + 
     (23*G[{yu}, yv^(-1)]*G[{1, 1/(yu*yv), 1/(yu*yv), 1/(yu*yv)}, yw])/64 + 
     (G[{0}, yu^(-1)]*G[{yu^(-1), yu^(-1), yu^(-1), 1/(yu*yv)}, yw])/8 + 
     (G[{0}, yv^(-1)]*G[{yu^(-1), yu^(-1), yu^(-1), 1/(yu*yv)}, yw])/8 - 
     (G[{0}, yw]*G[{yu^(-1), yu^(-1), yu^(-1), 1/(yu*yv)}, yw])/8 - 
     (3*G[{1}, yu^(-1)]*G[{yu^(-1), yu^(-1), yu^(-1), 1/(yu*yv)}, yw])/8 + 
     (G[{1}, yv^(-1)]*G[{yu^(-1), yu^(-1), yu^(-1), 1/(yu*yv)}, yw])/8 - 
     (G[{yu^(-1)}, yw]*G[{yu^(-1), yu^(-1), yu^(-1), 1/(yu*yv)}, yw])/8 - 
     (G[{0}, yu^(-1)]*G[{yu^(-1), yu^(-1), 1/(yu*yv), yv^(-1)}, yw])/8 - 
     (G[{0}, yv^(-1)]*G[{yu^(-1), yu^(-1), 1/(yu*yv), yv^(-1)}, yw])/8 + 
     (G[{0}, yw]*G[{yu^(-1), yu^(-1), 1/(yu*yv), yv^(-1)}, yw])/8 - 
     (G[{1}, yu^(-1)]*G[{yu^(-1), yu^(-1), 1/(yu*yv), yv^(-1)}, yw])/8 + 
     (3*G[{1}, yv^(-1)]*G[{yu^(-1), yu^(-1), 1/(yu*yv), yv^(-1)}, yw])/8 - 
     (3*G[{yu^(-1)}, yw]*G[{yu^(-1), yu^(-1), 1/(yu*yv), yv^(-1)}, yw])/8 + 
     (G[{1/(yu*yv)}, yw]*G[{yu^(-1), yu^(-1), 1/(yu*yv), yv^(-1)}, yw])/8 + 
     (G[{0}, yu^(-1)]*G[{yu^(-1), yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/16 + 
     (G[{0}, yv^(-1)]*G[{yu^(-1), yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/16 - 
     (G[{0}, yw]*G[{yu^(-1), yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/16 - 
     (3*G[{1}, yu^(-1)]*G[{yu^(-1), yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/16 + 
     (G[{1}, yv^(-1)]*G[{yu^(-1), yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/16 - 
     (G[{yu^(-1)}, yw]*G[{yu^(-1), yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/16 - 
     (G[{0}, yu^(-1)]*G[{yu^(-1), 1/(yu*yv), yv^(-1), yv^(-1)}, yw])/8 - 
     (G[{0}, yv^(-1)]*G[{yu^(-1), 1/(yu*yv), yv^(-1), yv^(-1)}, yw])/8 + 
     (G[{0}, yw]*G[{yu^(-1), 1/(yu*yv), yv^(-1), yv^(-1)}, yw])/8 + 
     (G[{1}, yu^(-1)]*G[{yu^(-1), 1/(yu*yv), yv^(-1), yv^(-1)}, yw])/8 + 
     (G[{1}, yv^(-1)]*G[{yu^(-1), 1/(yu*yv), yv^(-1), yv^(-1)}, yw])/8 - 
     (G[{yu^(-1)}, yw]*G[{yu^(-1), 1/(yu*yv), yv^(-1), yv^(-1)}, yw])/8 - 
     (G[{1/(yu*yv)}, yw]*G[{yu^(-1), 1/(yu*yv), yv^(-1), yv^(-1)}, yw])/8 + 
     (G[{0}, yu^(-1)]*G[{yu^(-1), 1/(yu*yv), yv^(-1), 1/(yu*yv)}, yw])/8 + 
     (G[{0}, yv^(-1)]*G[{yu^(-1), 1/(yu*yv), yv^(-1), 1/(yu*yv)}, yw])/8 - 
     (G[{0}, yw]*G[{yu^(-1), 1/(yu*yv), yv^(-1), 1/(yu*yv)}, yw])/8 - 
     (3*G[{1}, yu^(-1)]*G[{yu^(-1), 1/(yu*yv), yv^(-1), 1/(yu*yv)}, yw])/16 + 
     (G[{1}, yv^(-1)]*G[{yu^(-1), 1/(yu*yv), yv^(-1), 1/(yu*yv)}, yw])/16 + 
     (G[{1}, yw]*G[{yu^(-1), 1/(yu*yv), yv^(-1), 1/(yu*yv)}, yw])/8 - 
     (G[{yu^(-1)}, yw]*G[{yu^(-1), 1/(yu*yv), yv^(-1), 1/(yu*yv)}, yw])/16 - 
     (G[{yu}, yv^(-1)]*G[{yu^(-1), 1/(yu*yv), yv^(-1), 1/(yu*yv)}, yw])/8 + 
     (G[{0}, yu^(-1)]*G[{yu^(-1), 1/(yu*yv), 1/(yu*yv), yv^(-1)}, yw])/16 + 
     (G[{0}, yv^(-1)]*G[{yu^(-1), 1/(yu*yv), 1/(yu*yv), yv^(-1)}, yw])/16 - 
     (G[{0}, yw]*G[{yu^(-1), 1/(yu*yv), 1/(yu*yv), yv^(-1)}, yw])/16 - 
     (G[{1}, yu^(-1)]*G[{yu^(-1), 1/(yu*yv), 1/(yu*yv), yv^(-1)}, yw])/16 + 
     (3*G[{1}, yv^(-1)]*G[{yu^(-1), 1/(yu*yv), 1/(yu*yv), yv^(-1)}, yw])/16 + 
     (G[{1}, yw]*G[{yu^(-1), 1/(yu*yv), 1/(yu*yv), yv^(-1)}, yw])/4 - 
     (3*G[{yu^(-1)}, yw]*G[{yu^(-1), 1/(yu*yv), 1/(yu*yv), yv^(-1)}, yw])/
      16 - (G[{yu}, yv^(-1)]*G[{yu^(-1), 1/(yu*yv), 1/(yu*yv), yv^(-1)}, yw])/
      4 - (G[{0}, yu^(-1)]*G[{yu^(-1), 1/(yu*yv), 1/(yu*yv), 1/(yu*yv)}, yw])/
      16 - (G[{0}, yv^(-1)]*G[{yu^(-1), 1/(yu*yv), 1/(yu*yv), 1/(yu*yv)}, 
        yw])/16 + (G[{0}, yw]*G[{yu^(-1), 1/(yu*yv), 1/(yu*yv), 1/(yu*yv)}, 
        yw])/16 + (3*G[{1}, yu^(-1)]*G[{yu^(-1), 1/(yu*yv), 1/(yu*yv), 
         1/(yu*yv)}, yw])/16 + 
     (G[{1}, yv^(-1)]*G[{yu^(-1), 1/(yu*yv), 1/(yu*yv), 1/(yu*yv)}, yw])/8 + 
     (3*G[{1}, yw]*G[{yu^(-1), 1/(yu*yv), 1/(yu*yv), 1/(yu*yv)}, yw])/16 - 
     (G[{yu^(-1)}, yw]*G[{yu^(-1), 1/(yu*yv), 1/(yu*yv), 1/(yu*yv)}, yw])/8 - 
     (3*G[{yu}, yv^(-1)]*G[{yu^(-1), 1/(yu*yv), 1/(yu*yv), 1/(yu*yv)}, yw])/
      16 - (G[{0}, yu^(-1)]*G[{yv^(-1), yv^(-1), yv^(-1), 1/(yu*yv)}, yw])/
      8 - (G[{0}, yv^(-1)]*G[{yv^(-1), yv^(-1), yv^(-1), 1/(yu*yv)}, yw])/8 + 
     (G[{0}, yw]*G[{yv^(-1), yv^(-1), yv^(-1), 1/(yu*yv)}, yw])/8 + 
     (11*G[{1}, yu^(-1)]*G[{yv^(-1), yv^(-1), yv^(-1), 1/(yu*yv)}, yw])/32 + 
     (G[{1}, yv^(-1)]*G[{yv^(-1), yv^(-1), yv^(-1), 1/(yu*yv)}, yw])/8 + 
     (7*G[{1}, yw]*G[{yv^(-1), yv^(-1), yv^(-1), 1/(yu*yv)}, yw])/32 - 
     (G[{yu^(-1)}, yw]*G[{yv^(-1), yv^(-1), yv^(-1), 1/(yu*yv)}, yw])/8 - 
     (7*G[{yu}, yv^(-1)]*G[{yv^(-1), yv^(-1), yv^(-1), 1/(yu*yv)}, yw])/32 - 
     (11*G[{yv^(-1)}, yw]*G[{yv^(-1), yv^(-1), yv^(-1), 1/(yu*yv)}, yw])/32 - 
     (3*G[{1/(yu*yv)}, yw]*G[{yv^(-1), yv^(-1), yv^(-1), 1/(yu*yv)}, yw])/
      64 - (5*G[{0}, yu^(-1)]*G[{yv^(-1), yv^(-1), 1/(yu*yv), 1/(yu*yv)}, 
        yw])/16 - (5*G[{0}, yv^(-1)]*G[{yv^(-1), yv^(-1), 1/(yu*yv), 
         1/(yu*yv)}, yw])/16 + 
     (5*G[{0}, yw]*G[{yv^(-1), yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/16 + 
     (43*G[{1}, yu^(-1)]*G[{yv^(-1), yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/
      64 + (5*G[{1}, yv^(-1)]*G[{yv^(-1), yv^(-1), 1/(yu*yv), 1/(yu*yv)}, 
        yw])/16 + (23*G[{1}, yw]*G[{yv^(-1), yv^(-1), 1/(yu*yv), 1/(yu*yv)}, 
        yw])/64 - (5*G[{yu^(-1)}, yw]*G[{yv^(-1), yv^(-1), 1/(yu*yv), 
         1/(yu*yv)}, yw])/16 - (23*G[{yu}, yv^(-1)]*
       G[{yv^(-1), yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/64 - 
     (43*G[{yv^(-1)}, yw]*G[{yv^(-1), yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/
      64 - (3*G[{1/(yu*yv)}, yw]*G[{yv^(-1), yv^(-1), 1/(yu*yv), 1/(yu*yv)}, 
        yw])/32 - (G[{0}, yu^(-1)]*G[{yv^(-1), 1/(yu*yv), 1/(yu*yv), 
         1/(yu*yv)}, yw])/4 - (G[{0}, yv^(-1)]*
       G[{yv^(-1), 1/(yu*yv), 1/(yu*yv), 1/(yu*yv)}, yw])/4 + 
     (G[{0}, yw]*G[{yv^(-1), 1/(yu*yv), 1/(yu*yv), 1/(yu*yv)}, yw])/4 + 
     (23*G[{1}, yu^(-1)]*G[{yv^(-1), 1/(yu*yv), 1/(yu*yv), 1/(yu*yv)}, yw])/
      64 + (3*G[{1}, yv^(-1)]*G[{yv^(-1), 1/(yu*yv), 1/(yu*yv), 1/(yu*yv)}, 
        yw])/16 + (3*G[{1}, yw]*G[{yv^(-1), 1/(yu*yv), 1/(yu*yv), 1/(yu*yv)}, 
        yw])/64 - (3*G[{yu^(-1)}, yw]*G[{yv^(-1), 1/(yu*yv), 1/(yu*yv), 
         1/(yu*yv)}, yw])/16 - (3*G[{yu}, yv^(-1)]*
       G[{yv^(-1), 1/(yu*yv), 1/(yu*yv), 1/(yu*yv)}, yw])/64 - 
     (23*G[{yv^(-1)}, yw]*G[{yv^(-1), 1/(yu*yv), 1/(yu*yv), 1/(yu*yv)}, yw])/
      64 + (3*G[{0, 0, 0, 1, 1}, yu^(-1)])/16 - (9*G[{0, 0, 0, 1, 1}, yw])/
      16 + (3*G[{0, 0, 0, 1, yu^(-1)}, yw])/16 + 
     (9*G[{0, 0, 0, 1, yv^(-1)}, yw])/16 - (3*G[{0, 0, 0, 1, 1/(yu*yv)}, yw])/
      16 + (3*G[{0, 0, 0, yu^(-1), 1}, yw])/16 + 
     (3*G[{0, 0, 0, yu^(-1), yu^(-1)}, yw])/16 - 
     (3*G[{0, 0, 0, yu^(-1), yv^(-1)}, yw])/16 - 
     (3*G[{0, 0, 0, yu^(-1), 1/(yu*yv)}, yw])/16 + 
     (9*G[{0, 0, 0, yv^(-1), 1}, yw])/16 - 
     (3*G[{0, 0, 0, yv^(-1), yu^(-1)}, yw])/16 - 
     (9*G[{0, 0, 0, yv^(-1), yv^(-1)}, yw])/16 + 
     (3*G[{0, 0, 0, yv^(-1), 1/(yu*yv)}, yw])/16 - 
     (3*G[{0, 0, 0, 1/(yu*yv), 1}, yw])/16 - 
     (3*G[{0, 0, 0, 1/(yu*yv), yu^(-1)}, yw])/16 + 
     (3*G[{0, 0, 0, 1/(yu*yv), yv^(-1)}, yw])/16 + 
     (3*G[{0, 0, 0, 1/(yu*yv), 1/(yu*yv)}, yw])/16 + 
     (7*G[{0, 0, 1, 0, 1}, yu^(-1)])/64 - (3*G[{0, 0, 1, 0, 1}, yw])/16 + 
     G[{0, 0, 1, 0, yu^(-1)}, yw]/16 + (3*G[{0, 0, 1, 0, yv^(-1)}, yw])/16 - 
     G[{0, 0, 1, 0, 1/(yu*yv)}, yw]/16 - (3*G[{0, 0, 1, 1, 1}, yu^(-1)])/4 - 
     (15*G[{0, 0, 1, 1, 1}, yv^(-1)])/16 + (3*G[{0, 0, 1, 1, 1}, yw])/8 + 
     (3*G[{0, 0, 1, 1, yu^(-1)}, yw])/16 + (5*G[{0, 0, 1, 1, yu}, yv^(-1)])/
      16 + (5*G[{0, 0, 1, 1, yv^(-1)}, yw])/16 + G[{0, 0, 1, yu^(-1), 1}, yw]/
      8 - (5*G[{0, 0, 1, yu^(-1), yu^(-1)}, yw])/16 - 
     G[{0, 0, 1, yu^(-1), yv^(-1)}, yw]/16 + (3*G[{0, 0, 1, yu, 1}, yv^(-1)])/
      8 - G[{0, 0, 1, yu, yu}, yv^(-1)]/8 + G[{0, 0, 1, yv^(-1), 1}, yw]/8 - 
     G[{0, 0, 1, yv^(-1), yu^(-1)}, yw]/16 + 
     (3*G[{0, 0, 1, yv^(-1), yv^(-1)}, yw])/16 - 
     G[{0, 0, 1, yv^(-1), 1/(yu*yv)}, yw]/8 + 
     G[{0, 0, 1, 1/(yu*yv), yu^(-1)}, yw]/16 + 
     G[{0, 0, 1, 1/(yu*yv), yv^(-1)}, yw]/16 + 
     G[{0, 0, 1, 1/(yu*yv), 1/(yu*yv)}, yw]/8 + G[{0, 0, yu^(-1), 0, 1}, yw]/
      16 + G[{0, 0, yu^(-1), 0, yu^(-1)}, yw]/16 - 
     G[{0, 0, yu^(-1), 0, yv^(-1)}, yw]/16 - 
     G[{0, 0, yu^(-1), 0, 1/(yu*yv)}, yw]/16 + 
     G[{0, 0, yu^(-1), 1, yu^(-1)}, yw]/16 - 
     (3*G[{0, 0, yu^(-1), 1, yv^(-1)}, yw])/16 + 
     (3*G[{0, 0, yu^(-1), yu^(-1), 1}, yw])/8 - 
     (7*G[{0, 0, yu^(-1), yu^(-1), yu^(-1)}, yw])/16 - 
     G[{0, 0, yu^(-1), yu^(-1), yv^(-1)}, yw]/16 - 
     G[{0, 0, yu^(-1), yv^(-1), yu^(-1)}, yw]/16 - 
     (3*G[{0, 0, yu^(-1), yv^(-1), yv^(-1)}, yw])/16 + 
     G[{0, 0, yu^(-1), yv^(-1), 1/(yu*yv)}, yw]/8 - 
     G[{0, 0, yu^(-1), 1/(yu*yv), 1}, yw]/8 + 
     G[{0, 0, yu^(-1), 1/(yu*yv), yu^(-1)}, yw]/16 - 
     G[{0, 0, yu^(-1), 1/(yu*yv), yv^(-1)}, yw]/16 - 
     G[{0, 0, yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw]/8 + 
     (7*G[{0, 0, yu, 1, 1}, yv^(-1)])/16 - (5*G[{0, 0, yu, 1, yu}, yv^(-1)])/
      16 - G[{0, 0, yu, yu, 1}, yv^(-1)]/2 + (3*G[{0, 0, yv^(-1), 0, 1}, yw])/
      16 - G[{0, 0, yv^(-1), 0, yu^(-1)}, yw]/16 - 
     (3*G[{0, 0, yv^(-1), 0, yv^(-1)}, yw])/16 + 
     G[{0, 0, yv^(-1), 0, 1/(yu*yv)}, yw]/16 + G[{0, 0, yv^(-1), 1, 1}, yw]/
      4 + G[{0, 0, yv^(-1), 1, yu^(-1)}, yw]/16 - 
     (3*G[{0, 0, yv^(-1), 1, yv^(-1)}, yw])/16 - 
     G[{0, 0, yv^(-1), yu^(-1), yu^(-1)}, yw]/16 - 
     G[{0, 0, yv^(-1), yu^(-1), yv^(-1)}, yw]/16 + 
     G[{0, 0, yv^(-1), yu^(-1), 1/(yu*yv)}, yw]/8 - 
     G[{0, 0, yv^(-1), yv^(-1), 1}, yw]/8 + 
     G[{0, 0, yv^(-1), yv^(-1), yu^(-1)}, yw]/16 + 
     (9*G[{0, 0, yv^(-1), yv^(-1), yv^(-1)}, yw])/16 + 
     G[{0, 0, yv^(-1), 1/(yu*yv), 1}, yw]/8 - 
     G[{0, 0, yv^(-1), 1/(yu*yv), yu^(-1)}, yw]/16 - 
     G[{0, 0, yv^(-1), 1/(yu*yv), yv^(-1)}, yw]/16 - 
     (3*G[{0, 0, yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/8 - 
     G[{0, 0, 1/(yu*yv), 0, 1}, yw]/16 - G[{0, 0, 1/(yu*yv), 0, yu^(-1)}, yw]/
      16 + G[{0, 0, 1/(yu*yv), 0, yv^(-1)}, yw]/16 + 
     G[{0, 0, 1/(yu*yv), 0, 1/(yu*yv)}, yw]/16 - 
     G[{0, 0, 1/(yu*yv), 1, 1}, yw]/8 - G[{0, 0, 1/(yu*yv), 1, yu^(-1)}, yw]/
      16 + (7*G[{0, 0, 1/(yu*yv), 1, yv^(-1)}, yw])/16 - 
     G[{0, 0, 1/(yu*yv), 1, 1/(yu*yv)}, yw]/8 - 
     G[{0, 0, 1/(yu*yv), yu^(-1), 1}, yw]/8 + 
     G[{0, 0, 1/(yu*yv), yu^(-1), yu^(-1)}, yw]/16 - 
     (3*G[{0, 0, 1/(yu*yv), yu^(-1), yv^(-1)}, yw])/16 + 
     (3*G[{0, 0, 1/(yu*yv), yv^(-1), 1}, yw])/8 - 
     (3*G[{0, 0, 1/(yu*yv), yv^(-1), yu^(-1)}, yw])/16 - 
     (3*G[{0, 0, 1/(yu*yv), yv^(-1), yv^(-1)}, yw])/16 - 
     G[{0, 0, 1/(yu*yv), 1/(yu*yv), 1}, yw]/4 + 
     G[{0, 0, 1/(yu*yv), 1/(yu*yv), yu^(-1)}, yw]/16 + 
     (7*G[{0, 0, 1/(yu*yv), 1/(yu*yv), yv^(-1)}, yw])/16 - 
     (3*G[{0, 0, 1/(yu*yv), 1/(yu*yv), 1/(yu*yv)}, yw])/8 - 
     (15*G[{0, 1, 0, 1, 1}, yu^(-1)])/64 - (5*G[{0, 1, 0, 1, 1}, yv^(-1)])/
      16 + G[{0, 1, 0, 1, 1}, yw]/4 + G[{0, 1, 0, 1, yu^(-1)}, yw]/8 + 
     G[{0, 1, 0, 1, yu}, yv^(-1)]/16 + (3*G[{0, 1, 0, 1, yv^(-1)}, yw])/16 - 
     G[{0, 1, 0, 1, 1/(yu*yv)}, yw]/16 + G[{0, 1, 0, yu^(-1), 1}, yw]/16 - 
     (3*G[{0, 1, 0, yu^(-1), yu^(-1)}, yw])/16 - 
     G[{0, 1, 0, yu^(-1), yv^(-1)}, yw]/16 + 
     G[{0, 1, 0, yu^(-1), 1/(yu*yv)}, yw]/16 + G[{0, 1, 0, yu, 1}, yv^(-1)]/
      8 - G[{0, 1, 0, yu, yu}, yv^(-1)]/8 + G[{0, 1, 0, yv^(-1), 1}, yw]/16 - 
     G[{0, 1, 0, yv^(-1), yu^(-1)}, yw]/16 - 
     G[{0, 1, 0, yv^(-1), yv^(-1)}, yw]/16 - G[{0, 1, 0, 1/(yu*yv), 1}, yw]/
      8 + G[{0, 1, 0, 1/(yu*yv), yu^(-1)}, yw]/8 + 
     G[{0, 1, 0, 1/(yu*yv), yv^(-1)}, yw]/8 + 
     G[{0, 1, 0, 1/(yu*yv), 1/(yu*yv)}, yw]/16 + 
     (3*G[{0, 1, 1, 0, yu^(-1)}, yw])/16 - (3*G[{0, 1, 1, 0, yu}, yv^(-1)])/
      16 + (3*G[{0, 1, 1, 0, yv^(-1)}, yw])/16 - 
     G[{0, 1, 1, 0, 1/(yu*yv)}, yw]/8 - G[{0, 1, 1, 1, 1}, yu^(-1)]/4 - 
     G[{0, 1, 1, 1, 1}, yv^(-1)]/8 - (3*G[{0, 1, 1, 1, 1}, yw])/16 - 
     (3*G[{0, 1, 1, 1, yu^(-1)}, yw])/16 + G[{0, 1, 1, 1, yu}, yv^(-1)]/8 - 
     G[{0, 1, 1, 1, yv^(-1)}, yw]/8 + G[{0, 1, 1, 1, 1/(yu*yv)}, yw]/8 - 
     G[{0, 1, 1, yu^(-1), 1}, yw]/16 + (3*G[{0, 1, 1, yu^(-1), yu^(-1)}, yw])/
      16 + G[{0, 1, 1, yu^(-1), yv^(-1)}, yw]/16 - 
     (3*G[{0, 1, 1, yu, 1}, yv^(-1)])/8 + G[{0, 1, 1, yu, yu}, yv^(-1)]/2 - 
     G[{0, 1, 1, yv^(-1), 1}, yw]/16 + G[{0, 1, 1, yv^(-1), yu^(-1)}, yw]/
      16 + (3*G[{0, 1, 1, yv^(-1), yv^(-1)}, yw])/16 + 
     (5*G[{0, 1, 1, 1/(yu*yv), 1}, yw])/16 - 
     G[{0, 1, 1, 1/(yu*yv), yu^(-1)}, yw]/4 - 
     G[{0, 1, 1, 1/(yu*yv), yv^(-1)}, yw]/16 - 
     G[{0, 1, yu^(-1), 0, yu^(-1)}, yw]/8 + 
     G[{0, 1, yu^(-1), 0, 1/(yu*yv)}, yw]/16 + 
     G[{0, 1, yu^(-1), 1, yu^(-1)}, yw]/8 + 
     G[{0, 1, yu^(-1), 1, yv^(-1)}, yw]/8 - 
     G[{0, 1, yu^(-1), yu^(-1), yu^(-1)}, yw]/8 - 
     G[{0, 1, yu^(-1), yu^(-1), yv^(-1)}, yw]/8 - 
     G[{0, 1, yu^(-1), yu^(-1), 1/(yu*yv)}, yw]/8 + 
     G[{0, 1, yu^(-1), yv^(-1), 1}, yw]/8 - 
     G[{0, 1, yu^(-1), yv^(-1), yu^(-1)}, yw]/8 + 
     G[{0, 1, yu^(-1), yv^(-1), yv^(-1)}, yw]/8 - 
     G[{0, 1, yu^(-1), yv^(-1), 1/(yu*yv)}, yw]/8 - 
     G[{0, 1, yu^(-1), 1/(yu*yv), yv^(-1)}, yw]/8 + 
     G[{0, 1, yu, 0, yu}, yv^(-1)]/16 - (7*G[{0, 1, yu, 1, 1}, yv^(-1)])/16 + 
     (3*G[{0, 1, yu, 1, yu}, yv^(-1)])/8 + (5*G[{0, 1, yu, yu, 1}, yv^(-1)])/
      8 - G[{0, 1, yu, yu, yu}, yv^(-1)]/2 - 
     G[{0, 1, yv^(-1), 0, yu^(-1)}, yw]/16 + 
     G[{0, 1, yv^(-1), 0, yv^(-1)}, yw]/16 - G[{0, 1, yv^(-1), 1, 1}, yw]/8 + 
     G[{0, 1, yv^(-1), 1, yu^(-1)}, yw]/16 + 
     (3*G[{0, 1, yv^(-1), 1, yv^(-1)}, yw])/16 + 
     G[{0, 1, yv^(-1), yu^(-1), 1}, yw]/8 - 
     G[{0, 1, yv^(-1), yu^(-1), yu^(-1)}, yw]/8 + 
     G[{0, 1, yv^(-1), yu^(-1), yv^(-1)}, yw]/8 - 
     G[{0, 1, yv^(-1), yu^(-1), 1/(yu*yv)}, yw]/8 + 
     G[{0, 1, yv^(-1), yv^(-1), 1}, yw]/4 + 
     G[{0, 1, yv^(-1), yv^(-1), yu^(-1)}, yw]/8 + 
     G[{0, 1, yv^(-1), yv^(-1), yv^(-1)}, yw]/8 - 
     G[{0, 1, yv^(-1), yv^(-1), 1/(yu*yv)}, yw]/8 - 
     G[{0, 1, yv^(-1), 1/(yu*yv), 1}, yw]/8 + 
     G[{0, 1, yv^(-1), 1/(yu*yv), yu^(-1)}, yw]/16 - 
     (3*G[{0, 1, yv^(-1), 1/(yu*yv), yv^(-1)}, yw])/16 + 
     G[{0, 1, 1/(yu*yv), 0, yu^(-1)}, yw]/16 - 
     G[{0, 1, 1/(yu*yv), 0, yv^(-1)}, yw]/16 + 
     G[{0, 1, 1/(yu*yv), 0, 1/(yu*yv)}, yw]/16 + 
     (5*G[{0, 1, 1/(yu*yv), 1, 1}, yw])/16 - 
     (3*G[{0, 1, 1/(yu*yv), 1, yu^(-1)}, yw])/16 - 
     G[{0, 1, 1/(yu*yv), 1, yv^(-1)}, yw]/8 - 
     G[{0, 1, 1/(yu*yv), yu^(-1), 1}, yw]/16 - 
     G[{0, 1, 1/(yu*yv), yu^(-1), yu^(-1)}, yw]/16 + 
     G[{0, 1, 1/(yu*yv), yu^(-1), yv^(-1)}, yw]/16 - 
     G[{0, 1, 1/(yu*yv), yv^(-1), 1}, yw]/16 + 
     G[{0, 1, 1/(yu*yv), yv^(-1), yu^(-1)}, yw]/16 - 
     G[{0, 1, 1/(yu*yv), yv^(-1), yv^(-1)}, yw]/16 - 
     G[{0, 1, 1/(yu*yv), 1/(yu*yv), 1}, yw]/16 + 
     (3*G[{0, 1, 1/(yu*yv), 1/(yu*yv), yv^(-1)}, yw])/16 + 
     G[{0, yu^(-1), 0, yu^(-1), 1}, yw]/8 - 
     (3*G[{0, yu^(-1), 0, yu^(-1), yu^(-1)}, yw])/16 - 
     G[{0, yu^(-1), 0, yu^(-1), yv^(-1)}, yw]/8 + 
     G[{0, yu^(-1), 0, yv^(-1), 1}, yw]/8 - 
     G[{0, yu^(-1), 0, yv^(-1), yu^(-1)}, yw]/8 - 
     G[{0, yu^(-1), 0, yv^(-1), yv^(-1)}, yw]/16 - 
     G[{0, yu^(-1), 0, 1/(yu*yv), 1}, yw]/16 + 
     G[{0, yu^(-1), 0, 1/(yu*yv), yu^(-1)}, yw]/16 - 
     G[{0, yu^(-1), 0, 1/(yu*yv), 1/(yu*yv)}, yw]/16 - 
     (3*G[{0, yu^(-1), 1, 1, 1}, yw])/16 + G[{0, yu^(-1), 1, 1, yu^(-1)}, yw]/
      4 - G[{0, yu^(-1), 1, 1, yv^(-1)}, yw]/16 + 
     G[{0, yu^(-1), 1, yu^(-1), 1}, yw]/16 - 
     G[{0, yu^(-1), 1, yu^(-1), yu^(-1)}, yw]/16 - 
     G[{0, yu^(-1), 1, yu^(-1), yv^(-1)}, yw]/16 - 
     (3*G[{0, yu^(-1), 1, yv^(-1), 1}, yw])/16 - 
     G[{0, yu^(-1), 1, yv^(-1), yu^(-1)}, yw]/16 + 
     G[{0, yu^(-1), 1, yv^(-1), yv^(-1)}, yw]/16 + 
     G[{0, yu^(-1), 1, 1/(yu*yv), 1}, yw]/16 + 
     G[{0, yu^(-1), 1, 1/(yu*yv), yu^(-1)}, yw]/16 - 
     G[{0, yu^(-1), 1, 1/(yu*yv), yv^(-1)}, yw]/8 - 
     G[{0, yu^(-1), yu^(-1), 0, yv^(-1)}, yw]/16 - 
     G[{0, yu^(-1), yu^(-1), 0, 1/(yu*yv)}, yw]/16 + 
     G[{0, yu^(-1), yu^(-1), 1, 1}, yw]/8 - 
     G[{0, yu^(-1), yu^(-1), 1, yu^(-1)}, yw]/16 - 
     (3*G[{0, yu^(-1), yu^(-1), 1, yv^(-1)}, yw])/16 + 
     G[{0, yu^(-1), yu^(-1), yu^(-1), 1}, yw]/4 - 
     G[{0, yu^(-1), yu^(-1), yu^(-1), yu^(-1)}, yw]/8 + 
     (3*G[{0, yu^(-1), yu^(-1), yu^(-1), yv^(-1)}, yw])/8 - 
     G[{0, yu^(-1), yu^(-1), yv^(-1), 1}, yw]/8 + 
     (3*G[{0, yu^(-1), yu^(-1), yv^(-1), yu^(-1)}, yw])/8 - 
     G[{0, yu^(-1), yu^(-1), yv^(-1), yv^(-1)}, yw]/8 + 
     G[{0, yu^(-1), yu^(-1), yv^(-1), 1/(yu*yv)}, yw]/8 - 
     G[{0, yu^(-1), yu^(-1), 1/(yu*yv), 1}, yw]/8 - 
     G[{0, yu^(-1), yu^(-1), 1/(yu*yv), yu^(-1)}, yw]/16 + 
     G[{0, yu^(-1), yu^(-1), 1/(yu*yv), yv^(-1)}, yw]/16 - 
     G[{0, yu^(-1), yv^(-1), 0, yv^(-1)}, yw]/16 - 
     G[{0, yu^(-1), yv^(-1), 1, 1}, yw]/8 - 
     G[{0, yu^(-1), yv^(-1), 1, yu^(-1)}, yw]/16 - 
     G[{0, yu^(-1), yv^(-1), 1, yv^(-1)}, yw]/16 - 
     G[{0, yu^(-1), yv^(-1), yu^(-1), 1}, yw]/8 + 
     (3*G[{0, yu^(-1), yv^(-1), yu^(-1), yu^(-1)}, yw])/8 - 
     G[{0, yu^(-1), yv^(-1), yu^(-1), yv^(-1)}, yw]/8 + 
     G[{0, yu^(-1), yv^(-1), yu^(-1), 1/(yu*yv)}, yw]/8 - 
     G[{0, yu^(-1), yv^(-1), yv^(-1), 1}, yw]/8 - 
     G[{0, yu^(-1), yv^(-1), yv^(-1), yu^(-1)}, yw]/8 - 
     G[{0, yu^(-1), yv^(-1), yv^(-1), yv^(-1)}, yw]/8 + 
     G[{0, yu^(-1), yv^(-1), yv^(-1), 1/(yu*yv)}, yw]/8 + 
     G[{0, yu^(-1), yv^(-1), 1/(yu*yv), 1}, yw]/8 - 
     G[{0, yu^(-1), yv^(-1), 1/(yu*yv), yu^(-1)}, yw]/16 + 
     (3*G[{0, yu^(-1), yv^(-1), 1/(yu*yv), yv^(-1)}, yw])/16 + 
     G[{0, yu^(-1), 1/(yu*yv), 0, yv^(-1)}, yw]/16 - 
     G[{0, yu^(-1), 1/(yu*yv), 0, 1/(yu*yv)}, yw]/16 + 
     G[{0, yu^(-1), 1/(yu*yv), 1, 1}, yw]/16 + 
     G[{0, yu^(-1), 1/(yu*yv), 1, yu^(-1)}, yw]/16 - 
     G[{0, yu^(-1), 1/(yu*yv), yu^(-1), 1}, yw]/16 - 
     G[{0, yu^(-1), 1/(yu*yv), yu^(-1), yu^(-1)}, yw]/16 - 
     G[{0, yu^(-1), 1/(yu*yv), yu^(-1), yv^(-1)}, yw]/16 - 
     G[{0, yu^(-1), 1/(yu*yv), yv^(-1), 1}, yw]/16 - 
     G[{0, yu^(-1), 1/(yu*yv), yv^(-1), yu^(-1)}, yw]/16 + 
     G[{0, yu^(-1), 1/(yu*yv), yv^(-1), yv^(-1)}, yw]/16 + 
     G[{0, yu^(-1), 1/(yu*yv), 1/(yu*yv), 1}, yw]/16 - 
     (3*G[{0, yu^(-1), 1/(yu*yv), 1/(yu*yv), yv^(-1)}, yw])/16 - 
     G[{0, yu, 0, yu, 1}, yv^(-1)]/8 - G[{0, yu, 1, 1, 1}, yv^(-1)]/16 + 
     (3*G[{0, yu, 1, yu, 1}, yv^(-1)])/8 - G[{0, yu, 1, yu, yu}, yv^(-1)]/4 + 
     G[{0, yu, yu, 1, 1}, yv^(-1)]/2 - G[{0, yu, yu, 1, yu}, yv^(-1)]/4 - 
     G[{0, yu, yu, yu, 1}, yv^(-1)]/2 + G[{0, yv^(-1), 0, yv^(-1), yu^(-1)}, 
       yw]/16 + (5*G[{0, yv^(-1), 0, yv^(-1), yv^(-1)}, yw])/16 + 
     (3*G[{0, yv^(-1), 0, 1/(yu*yv), 1}, yw])/16 - 
     G[{0, yv^(-1), 0, 1/(yu*yv), yu^(-1)}, yw]/8 - 
     G[{0, yv^(-1), 0, 1/(yu*yv), yv^(-1)}, yw]/8 - 
     (3*G[{0, yv^(-1), 0, 1/(yu*yv), 1/(yu*yv)}, yw])/16 + 
     (3*G[{0, yv^(-1), 1, 1, 1}, yw])/16 + 
     (3*G[{0, yv^(-1), 1, 1, yu^(-1)}, yw])/16 + 
     G[{0, yv^(-1), 1, 1, yv^(-1)}, yw]/8 + 
     G[{0, yv^(-1), 1, yu^(-1), 1}, yw]/16 - 
     G[{0, yv^(-1), 1, yu^(-1), yu^(-1)}, yw]/16 - 
     G[{0, yv^(-1), 1, yu^(-1), yv^(-1)}, yw]/16 + 
     G[{0, yv^(-1), 1, yv^(-1), 1}, yw]/16 - 
     G[{0, yv^(-1), 1, yv^(-1), yu^(-1)}, yw]/16 - 
     (3*G[{0, yv^(-1), 1, yv^(-1), yv^(-1)}, yw])/16 - 
     G[{0, yv^(-1), 1, 1/(yu*yv), 1}, yw]/16 + 
     G[{0, yv^(-1), 1, 1/(yu*yv), yu^(-1)}, yw]/8 - 
     G[{0, yv^(-1), 1, 1/(yu*yv), yv^(-1)}, yw]/16 - 
     G[{0, yv^(-1), yu^(-1), 1, 1}, yw]/8 - 
     G[{0, yv^(-1), yu^(-1), 1, yu^(-1)}, yw]/16 - 
     G[{0, yv^(-1), yu^(-1), 1, yv^(-1)}, yw]/16 - 
     G[{0, yv^(-1), yu^(-1), yu^(-1), 1}, yw]/8 + 
     (3*G[{0, yv^(-1), yu^(-1), yu^(-1), yu^(-1)}, yw])/8 - 
     G[{0, yv^(-1), yu^(-1), yu^(-1), yv^(-1)}, yw]/8 + 
     G[{0, yv^(-1), yu^(-1), yu^(-1), 1/(yu*yv)}, yw]/8 - 
     G[{0, yv^(-1), yu^(-1), yv^(-1), 1}, yw]/8 - 
     G[{0, yv^(-1), yu^(-1), yv^(-1), yu^(-1)}, yw]/8 - 
     G[{0, yv^(-1), yu^(-1), yv^(-1), yv^(-1)}, yw]/8 + 
     G[{0, yv^(-1), yu^(-1), yv^(-1), 1/(yu*yv)}, yw]/8 + 
     G[{0, yv^(-1), yu^(-1), 1/(yu*yv), 1}, yw]/8 - 
     G[{0, yv^(-1), yu^(-1), 1/(yu*yv), yu^(-1)}, yw]/16 + 
     (3*G[{0, yv^(-1), yu^(-1), 1/(yu*yv), yv^(-1)}, yw])/16 + 
     (3*G[{0, yv^(-1), yv^(-1), 0, 1/(yu*yv)}, yw])/16 + 
     G[{0, yv^(-1), yv^(-1), 1, 1}, yw]/8 - 
     G[{0, yv^(-1), yv^(-1), 1, yu^(-1)}, yw]/16 - 
     (3*G[{0, yv^(-1), yv^(-1), 1, yv^(-1)}, yw])/16 - 
     G[{0, yv^(-1), yv^(-1), yu^(-1), 1}, yw]/8 - 
     G[{0, yv^(-1), yv^(-1), yu^(-1), yu^(-1)}, yw]/8 - 
     G[{0, yv^(-1), yv^(-1), yu^(-1), yv^(-1)}, yw]/8 + 
     G[{0, yv^(-1), yv^(-1), yu^(-1), 1/(yu*yv)}, yw]/8 - 
     G[{0, yv^(-1), yv^(-1), yv^(-1), 1}, yw]/4 - 
     G[{0, yv^(-1), yv^(-1), yv^(-1), yu^(-1)}, yw]/8 - 
     G[{0, yv^(-1), yv^(-1), yv^(-1), yv^(-1)}, yw]/8 - 
     G[{0, yv^(-1), yv^(-1), 1/(yu*yv), 1}, yw]/8 + 
     (3*G[{0, yv^(-1), yv^(-1), 1/(yu*yv), yu^(-1)}, yw])/16 + 
     (5*G[{0, yv^(-1), yv^(-1), 1/(yu*yv), yv^(-1)}, yw])/16 - 
     (3*G[{0, yv^(-1), 1/(yu*yv), 0, 1/(yu*yv)}, yw])/16 - 
     G[{0, yv^(-1), 1/(yu*yv), 1, 1}, yw]/16 + 
     G[{0, yv^(-1), 1/(yu*yv), 1, yu^(-1)}, yw]/8 - 
     (3*G[{0, yv^(-1), 1/(yu*yv), 1, yv^(-1)}, yw])/16 + 
     (3*G[{0, yv^(-1), 1/(yu*yv), yu^(-1), 1}, yw])/16 - 
     G[{0, yv^(-1), 1/(yu*yv), yu^(-1), yu^(-1)}, yw]/16 + 
     (3*G[{0, yv^(-1), 1/(yu*yv), yu^(-1), yv^(-1)}, yw])/16 - 
     G[{0, yv^(-1), 1/(yu*yv), yv^(-1), 1}, yw]/16 + 
     (3*G[{0, yv^(-1), 1/(yu*yv), yv^(-1), yu^(-1)}, yw])/16 + 
     (5*G[{0, yv^(-1), 1/(yu*yv), yv^(-1), yv^(-1)}, yw])/16 - 
     G[{0, yv^(-1), 1/(yu*yv), 1/(yu*yv), 1}, yw]/16 - 
     G[{0, yv^(-1), 1/(yu*yv), 1/(yu*yv), yu^(-1)}, yw]/16 - 
     G[{0, yv^(-1), 1/(yu*yv), 1/(yu*yv), yv^(-1)}, yw]/4 - 
     G[{0, 1/(yu*yv), 0, 1/(yu*yv), 1}, yw]/8 + 
     (3*G[{0, 1/(yu*yv), 0, 1/(yu*yv), yv^(-1)}, yw])/16 - 
     (3*G[{0, 1/(yu*yv), 0, 1/(yu*yv), 1/(yu*yv)}, yw])/16 + 
     (3*G[{0, 1/(yu*yv), 1, 1, 1}, yw])/16 - 
     G[{0, 1/(yu*yv), 1, 1, yu^(-1)}, yw]/4 + 
     G[{0, 1/(yu*yv), 1, 1, yv^(-1)}, yw]/16 - 
     G[{0, 1/(yu*yv), 1, 1, 1/(yu*yv)}, yw]/8 - 
     G[{0, 1/(yu*yv), 1, yu^(-1), 1}, yw]/16 - 
     G[{0, 1/(yu*yv), 1, yu^(-1), yu^(-1)}, yw]/16 + 
     G[{0, 1/(yu*yv), 1, yu^(-1), yv^(-1)}, yw]/16 + 
     (3*G[{0, 1/(yu*yv), 1, yv^(-1), 1}, yw])/16 + 
     G[{0, 1/(yu*yv), 1, yv^(-1), yu^(-1)}, yw]/16 - 
     G[{0, 1/(yu*yv), 1, yv^(-1), yv^(-1)}, yw]/16 - 
     (5*G[{0, 1/(yu*yv), 1, 1/(yu*yv), 1}, yw])/16 + 
     G[{0, 1/(yu*yv), 1, 1/(yu*yv), yu^(-1)}, yw]/16 + 
     G[{0, 1/(yu*yv), 1, 1/(yu*yv), yv^(-1)}, yw]/4 + 
     G[{0, 1/(yu*yv), yu^(-1), 1, yv^(-1)}, yw]/8 - 
     G[{0, 1/(yu*yv), yu^(-1), yu^(-1), 1}, yw]/8 - 
     G[{0, 1/(yu*yv), yu^(-1), yu^(-1), yu^(-1)}, yw]/8 - 
     G[{0, 1/(yu*yv), yu^(-1), yu^(-1), yv^(-1)}, yw]/8 + 
     G[{0, 1/(yu*yv), yu^(-1), yv^(-1), 1}, yw]/8 - 
     G[{0, 1/(yu*yv), yu^(-1), yv^(-1), yu^(-1)}, yw]/8 + 
     G[{0, 1/(yu*yv), yu^(-1), yv^(-1), yv^(-1)}, yw]/8 - 
     G[{0, 1/(yu*yv), yu^(-1), yv^(-1), 1/(yu*yv)}, yw]/8 + 
     G[{0, 1/(yu*yv), yu^(-1), 1/(yu*yv), yu^(-1)}, yw]/8 - 
     G[{0, 1/(yu*yv), yu^(-1), 1/(yu*yv), yv^(-1)}, yw]/8 + 
     G[{0, 1/(yu*yv), yv^(-1), 1, 1}, yw]/8 + 
     G[{0, 1/(yu*yv), yv^(-1), 1, yu^(-1)}, yw]/16 + 
     G[{0, 1/(yu*yv), yv^(-1), 1, yv^(-1)}, yw]/16 + 
     G[{0, 1/(yu*yv), yv^(-1), yu^(-1), 1}, yw]/8 - 
     G[{0, 1/(yu*yv), yv^(-1), yu^(-1), yu^(-1)}, yw]/8 + 
     G[{0, 1/(yu*yv), yv^(-1), yu^(-1), yv^(-1)}, yw]/8 - 
     G[{0, 1/(yu*yv), yv^(-1), yu^(-1), 1/(yu*yv)}, yw]/8 + 
     G[{0, 1/(yu*yv), yv^(-1), yv^(-1), 1}, yw]/8 + 
     G[{0, 1/(yu*yv), yv^(-1), yv^(-1), yu^(-1)}, yw]/8 + 
     G[{0, 1/(yu*yv), yv^(-1), yv^(-1), yv^(-1)}, yw]/8 + 
     G[{0, 1/(yu*yv), yv^(-1), 1/(yu*yv), 1}, yw]/8 - 
     (3*G[{0, 1/(yu*yv), yv^(-1), 1/(yu*yv), yu^(-1)}, yw])/16 - 
     (5*G[{0, 1/(yu*yv), yv^(-1), 1/(yu*yv), yv^(-1)}, yw])/16 - 
     (5*G[{0, 1/(yu*yv), 1/(yu*yv), 1, 1}, yw])/16 + 
     (5*G[{0, 1/(yu*yv), 1/(yu*yv), 1, yv^(-1)}, yw])/16 - 
     G[{0, 1/(yu*yv), 1/(yu*yv), yu^(-1), 1}, yw]/16 + 
     (3*G[{0, 1/(yu*yv), 1/(yu*yv), yu^(-1), yu^(-1)}, yw])/16 - 
     (3*G[{0, 1/(yu*yv), 1/(yu*yv), yu^(-1), yv^(-1)}, yw])/16 + 
     (3*G[{0, 1/(yu*yv), 1/(yu*yv), yv^(-1), 1}, yw])/16 - 
     (3*G[{0, 1/(yu*yv), 1/(yu*yv), yv^(-1), yu^(-1)}, yw])/16 - 
     (5*G[{0, 1/(yu*yv), 1/(yu*yv), yv^(-1), yv^(-1)}, yw])/16 + 
     G[{0, 1/(yu*yv), 1/(yu*yv), 1/(yu*yv), 1}, yw]/16 + 
     G[{0, 1/(yu*yv), 1/(yu*yv), 1/(yu*yv), yu^(-1)}, yw]/16 + 
     G[{0, 1/(yu*yv), 1/(yu*yv), 1/(yu*yv), yv^(-1)}, yw]/4 - 
     (7*G[{1, 1, 1, 1, yu^(-1)}, yw])/16 - G[{1, 1, 1, 1, yu}, yv^(-1)]/16 + 
     (5*G[{1, 1, 1, 1, yv^(-1)}, yw])/16 + G[{1, 1, 1, 1, 1/(yu*yv)}, yw]/2 + 
     (7*G[{1, 1, 1, yu^(-1), yu^(-1)}, yw])/8 + 
     (5*G[{1, 1, 1, yu^(-1), yv^(-1)}, yw])/8 - 
     (19*G[{1, 1, 1, yu^(-1), 1/(yu*yv)}, yw])/16 - 
     (25*G[{1, 1, 1, yu, yu}, yv^(-1)])/16 + 
     (5*G[{1, 1, 1, yv^(-1), yu^(-1)}, yw])/8 - 
     G[{1, 1, 1, yv^(-1), yv^(-1)}, yw]/8 - 
     (7*G[{1, 1, 1, yv^(-1), 1/(yu*yv)}, yw])/16 - 
     (9*G[{1, 1, 1, 1/(yu*yv), yu^(-1)}, yw])/8 - 
     (3*G[{1, 1, 1, 1/(yu*yv), yv^(-1)}, yw])/8 + 
     3*G[{1, 1, 1, 1/(yu*yv), 1/(yu*yv)}, yw] + 
     (3*G[{1, 1, yu^(-1), 1, yu^(-1)}, yw])/8 + 
     (3*G[{1, 1, yu^(-1), 1, yv^(-1)}, yw])/16 - 
     (7*G[{1, 1, yu^(-1), 1, 1/(yu*yv)}, yw])/16 - 
     (13*G[{1, 1, yu^(-1), yu^(-1), yu^(-1)}, yw])/16 + 
     G[{1, 1, yu^(-1), yu^(-1), yv^(-1)}, yw]/16 - 
     (3*G[{1, 1, yu^(-1), yu^(-1), 1/(yu*yv)}, yw])/8 + 
     G[{1, 1, yu^(-1), yv^(-1), yu^(-1)}, yw]/16 - 
     (5*G[{1, 1, yu^(-1), yv^(-1), yv^(-1)}, yw])/16 - 
     G[{1, 1, yu^(-1), 1/(yu*yv), yu^(-1)}, yw]/4 - 
     (3*G[{1, 1, yu^(-1), 1/(yu*yv), yv^(-1)}, yw])/16 - 
     G[{1, 1, yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw]/8 - 
     (33*G[{1, 1, yu, 1, yu}, yv^(-1)])/64 - G[{1, 1, yu, yu, yu}, yv^(-1)]/
      64 + (5*G[{1, 1, yv^(-1), 1, yu^(-1)}, yw])/16 + 
     (5*G[{1, 1, yv^(-1), 1, yv^(-1)}, yw])/64 - 
     (9*G[{1, 1, yv^(-1), 1, 1/(yu*yv)}, yw])/64 + 
     G[{1, 1, yv^(-1), yu^(-1), yu^(-1)}, yw]/16 - 
     (3*G[{1, 1, yv^(-1), yu^(-1), yv^(-1)}, yw])/16 - 
     G[{1, 1, yv^(-1), yv^(-1), yu^(-1)}, yw]/16 - 
     (19*G[{1, 1, yv^(-1), yv^(-1), yv^(-1)}, yw])/64 - 
     (5*G[{1, 1, yv^(-1), yv^(-1), 1/(yu*yv)}, yw])/64 + 
     (5*G[{1, 1, yv^(-1), 1/(yu*yv), yu^(-1)}, yw])/16 - 
     G[{1, 1, yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw]/4 - 
     (7*G[{1, 1, 1/(yu*yv), 1, yu^(-1)}, yw])/16 - 
     (9*G[{1, 1, 1/(yu*yv), 1, yv^(-1)}, yw])/64 + 
     (61*G[{1, 1, 1/(yu*yv), 1, 1/(yu*yv)}, yw])/64 - 
     G[{1, 1, 1/(yu*yv), yu^(-1), yu^(-1)}, yw]/2 + 
     G[{1, 1, 1/(yu*yv), yu^(-1), yv^(-1)}, yw]/4 - 
     G[{1, 1, 1/(yu*yv), yu^(-1), 1/(yu*yv)}, yw]/8 + 
     G[{1, 1, 1/(yu*yv), yv^(-1), yu^(-1)}, yw]/4 + 
     (7*G[{1, 1, 1/(yu*yv), yv^(-1), yv^(-1)}, yw])/64 - 
     (5*G[{1, 1, 1/(yu*yv), yv^(-1), 1/(yu*yv)}, yw])/64 - 
     (5*G[{1, 1, 1/(yu*yv), 1/(yu*yv), yu^(-1)}, yw])/16 - 
     (3*G[{1, 1, 1/(yu*yv), 1/(yu*yv), yv^(-1)}, yw])/16 - 
     (7*G[{1, 1, 1/(yu*yv), 1/(yu*yv), 1/(yu*yv)}, yw])/16 - 
     (7*G[{1, yu^(-1), 1, yu^(-1), yu^(-1)}, yw])/16 + 
     G[{1, yu^(-1), 1, yu^(-1), yv^(-1)}, yw]/8 - 
     G[{1, yu^(-1), 1, yu^(-1), 1/(yu*yv)}, yw]/4 + 
     G[{1, yu^(-1), 1, yv^(-1), yu^(-1)}, yw]/8 - 
     (3*G[{1, yu^(-1), 1, yv^(-1), yv^(-1)}, yw])/16 - 
     G[{1, yu^(-1), 1, 1/(yu*yv), yu^(-1)}, yw]/4 + 
     G[{1, yu^(-1), 1, 1/(yu*yv), yv^(-1)}, yw]/16 - 
     G[{1, yu^(-1), 1, 1/(yu*yv), 1/(yu*yv)}, yw]/16 + 
     G[{1, yu^(-1), yu^(-1), 1, yv^(-1)}, yw]/16 - 
     (3*G[{1, yu^(-1), yu^(-1), 1, 1/(yu*yv)}, yw])/8 + 
     G[{1, yu^(-1), yu^(-1), yu^(-1), yu^(-1)}, yw]/8 - 
     (3*G[{1, yu^(-1), yu^(-1), yu^(-1), yv^(-1)}, yw])/8 - 
     (3*G[{1, yu^(-1), yu^(-1), yv^(-1), yu^(-1)}, yw])/8 + 
     G[{1, yu^(-1), yu^(-1), yv^(-1), yv^(-1)}, yw]/8 - 
     G[{1, yu^(-1), yu^(-1), yv^(-1), 1/(yu*yv)}, yw]/8 + 
     (3*G[{1, yu^(-1), yu^(-1), 1/(yu*yv), yu^(-1)}, yw])/16 - 
     (5*G[{1, yu^(-1), yu^(-1), 1/(yu*yv), yv^(-1)}, yw])/16 - 
     G[{1, yu^(-1), yv^(-1), 1, yv^(-1)}, yw]/16 + 
     G[{1, yu^(-1), yv^(-1), 1, 1/(yu*yv)}, yw]/8 - 
     (3*G[{1, yu^(-1), yv^(-1), yu^(-1), yu^(-1)}, yw])/8 + 
     G[{1, yu^(-1), yv^(-1), yu^(-1), yv^(-1)}, yw]/8 - 
     G[{1, yu^(-1), yv^(-1), yu^(-1), 1/(yu*yv)}, yw]/8 + 
     G[{1, yu^(-1), yv^(-1), yv^(-1), yu^(-1)}, yw]/8 + 
     G[{1, yu^(-1), yv^(-1), yv^(-1), yv^(-1)}, yw]/8 - 
     G[{1, yu^(-1), yv^(-1), yv^(-1), 1/(yu*yv)}, yw]/8 + 
     G[{1, yu^(-1), yv^(-1), 1/(yu*yv), yu^(-1)}, yw]/16 - 
     (3*G[{1, yu^(-1), yv^(-1), 1/(yu*yv), yv^(-1)}, yw])/16 - 
     (3*G[{1, yu^(-1), 1/(yu*yv), 1, yv^(-1)}, yw])/16 - 
     G[{1, yu^(-1), 1/(yu*yv), 1, 1/(yu*yv)}, yw]/16 + 
     (3*G[{1, yu^(-1), 1/(yu*yv), yu^(-1), yu^(-1)}, yw])/16 - 
     G[{1, yu^(-1), 1/(yu*yv), yu^(-1), yv^(-1)}, yw]/16 - 
     G[{1, yu^(-1), 1/(yu*yv), yv^(-1), yu^(-1)}, yw]/16 - 
     G[{1, yu^(-1), 1/(yu*yv), yv^(-1), yv^(-1)}, yw]/16 - 
     G[{1, yu^(-1), 1/(yu*yv), 1/(yu*yv), yu^(-1)}, yw]/8 + 
     (3*G[{1, yu^(-1), 1/(yu*yv), 1/(yu*yv), yv^(-1)}, yw])/16 + 
     (5*G[{1, yu, 1, yu, yu}, yv^(-1)])/16 - 
     (41*G[{1, yu, yu, yu, yu}, yv^(-1)])/32 + 
     G[{1, yv^(-1), 1, yv^(-1), yu^(-1)}, yw]/16 + 
     G[{1, yv^(-1), 1, yv^(-1), yv^(-1)}, yw]/8 - 
     (5*G[{1, yv^(-1), 1, yv^(-1), 1/(yu*yv)}, yw])/64 + 
     G[{1, yv^(-1), 1, 1/(yu*yv), yu^(-1)}, yw]/8 - 
     G[{1, yv^(-1), 1, 1/(yu*yv), yv^(-1)}, yw]/8 - 
     (5*G[{1, yv^(-1), 1, 1/(yu*yv), 1/(yu*yv)}, yw])/64 + 
     G[{1, yv^(-1), yu^(-1), 1, 1/(yu*yv)}, yw]/8 - 
     (3*G[{1, yv^(-1), yu^(-1), yu^(-1), yu^(-1)}, yw])/8 + 
     G[{1, yv^(-1), yu^(-1), yu^(-1), yv^(-1)}, yw]/8 - 
     G[{1, yv^(-1), yu^(-1), yu^(-1), 1/(yu*yv)}, yw]/8 + 
     G[{1, yv^(-1), yu^(-1), yv^(-1), yu^(-1)}, yw]/8 + 
     G[{1, yv^(-1), yu^(-1), yv^(-1), yv^(-1)}, yw]/8 - 
     G[{1, yv^(-1), yu^(-1), yv^(-1), 1/(yu*yv)}, yw]/8 + 
     G[{1, yv^(-1), yu^(-1), 1/(yu*yv), yu^(-1)}, yw]/16 - 
     (3*G[{1, yv^(-1), yu^(-1), 1/(yu*yv), yv^(-1)}, yw])/16 - 
     G[{1, yv^(-1), yv^(-1), 1, 1/(yu*yv)}, yw]/16 + 
     G[{1, yv^(-1), yv^(-1), yu^(-1), yu^(-1)}, yw]/8 + 
     G[{1, yv^(-1), yv^(-1), yu^(-1), yv^(-1)}, yw]/8 - 
     G[{1, yv^(-1), yv^(-1), yu^(-1), 1/(yu*yv)}, yw]/8 + 
     G[{1, yv^(-1), yv^(-1), yv^(-1), yu^(-1)}, yw]/8 - 
     (3*G[{1, yv^(-1), yv^(-1), yv^(-1), yv^(-1)}, yw])/32 + 
     (3*G[{1, yv^(-1), yv^(-1), yv^(-1), 1/(yu*yv)}, yw])/64 - 
     G[{1, yv^(-1), yv^(-1), 1/(yu*yv), yu^(-1)}, yw]/16 + 
     (3*G[{1, yv^(-1), yv^(-1), 1/(yu*yv), yv^(-1)}, yw])/64 - 
     (3*G[{1, yv^(-1), yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/32 - 
     (5*G[{1, yv^(-1), 1/(yu*yv), 1, 1/(yu*yv)}, yw])/64 + 
     (3*G[{1, yv^(-1), 1/(yu*yv), yu^(-1), yu^(-1)}, yw])/16 - 
     G[{1, yv^(-1), 1/(yu*yv), yu^(-1), yv^(-1)}, yw]/16 - 
     G[{1, yv^(-1), 1/(yu*yv), yv^(-1), yu^(-1)}, yw]/16 + 
     (3*G[{1, yv^(-1), 1/(yu*yv), yv^(-1), yv^(-1)}, yw])/64 - 
     (3*G[{1, yv^(-1), 1/(yu*yv), yv^(-1), 1/(yu*yv)}, yw])/32 - 
     G[{1, yv^(-1), 1/(yu*yv), 1/(yu*yv), yu^(-1)}, yw]/16 + 
     (9*G[{1, yv^(-1), 1/(yu*yv), 1/(yu*yv), yv^(-1)}, yw])/64 - 
     G[{1, 1/(yu*yv), 1, 1/(yu*yv), yu^(-1)}, yw]/4 - 
     (3*G[{1, 1/(yu*yv), 1, 1/(yu*yv), yv^(-1)}, yw])/16 - 
     (17*G[{1, 1/(yu*yv), 1, 1/(yu*yv), 1/(yu*yv)}, yw])/64 - 
     G[{1, 1/(yu*yv), yu^(-1), yu^(-1), 1/(yu*yv)}, yw]/8 - 
     G[{1, 1/(yu*yv), yu^(-1), 1/(yu*yv), yu^(-1)}, yw]/4 + 
     G[{1, 1/(yu*yv), yu^(-1), 1/(yu*yv), yv^(-1)}, yw]/4 + 
     (7*G[{1, 1/(yu*yv), yv^(-1), yv^(-1), yv^(-1)}, yw])/32 - 
     (11*G[{1, 1/(yu*yv), yv^(-1), yv^(-1), 1/(yu*yv)}, yw])/64 + 
     G[{1, 1/(yu*yv), yv^(-1), 1/(yu*yv), yu^(-1)}, yw]/8 - 
     (15*G[{1, 1/(yu*yv), yv^(-1), 1/(yu*yv), yv^(-1)}, yw])/64 + 
     (3*G[{1, 1/(yu*yv), yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/32 - 
     G[{1, 1/(yu*yv), 1/(yu*yv), yu^(-1), yu^(-1)}, yw]/2 + 
     G[{1, 1/(yu*yv), 1/(yu*yv), yu^(-1), yv^(-1)}, yw]/4 + 
     G[{1, 1/(yu*yv), 1/(yu*yv), yv^(-1), yu^(-1)}, yw]/4 - 
     (7*G[{1, 1/(yu*yv), 1/(yu*yv), yv^(-1), yv^(-1)}, yw])/64 + 
     (3*G[{1, 1/(yu*yv), 1/(yu*yv), yv^(-1), 1/(yu*yv)}, yw])/32 + 
     (3*G[{1, 1/(yu*yv), 1/(yu*yv), 1/(yu*yv), yu^(-1)}, yw])/16 + 
     (3*G[{1, 1/(yu*yv), 1/(yu*yv), 1/(yu*yv), yv^(-1)}, yw])/64 + 
     G[{yu^(-1), yu^(-1), yu^(-1), yu^(-1), 1/(yu*yv)}, yw]/8 + 
     (3*G[{yu^(-1), yu^(-1), yu^(-1), 1/(yu*yv), yv^(-1)}, yw])/8 + 
     (3*G[{yu^(-1), yu^(-1), yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/16 + 
     G[{yu^(-1), yu^(-1), 1/(yu*yv), yu^(-1), 1/(yu*yv)}, yw]/16 + 
     G[{yu^(-1), yu^(-1), 1/(yu*yv), yv^(-1), yv^(-1)}, yw]/8 - 
     G[{yu^(-1), yu^(-1), 1/(yu*yv), yv^(-1), 1/(yu*yv)}, yw]/8 - 
     (3*G[{yu^(-1), yu^(-1), 1/(yu*yv), 1/(yu*yv), yv^(-1)}, yw])/16 - 
     G[{yu^(-1), yu^(-1), 1/(yu*yv), 1/(yu*yv), 1/(yu*yv)}, yw]/4 - 
     (3*G[{yu^(-1), 1/(yu*yv), yu^(-1), 1/(yu*yv), yv^(-1)}, yw])/16 - 
     G[{yu^(-1), 1/(yu*yv), yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw]/8 - 
     G[{yu^(-1), 1/(yu*yv), yv^(-1), yv^(-1), yv^(-1)}, yw]/8 + 
     G[{yu^(-1), 1/(yu*yv), yv^(-1), yv^(-1), 1/(yu*yv)}, yw]/8 + 
     (3*G[{yu^(-1), 1/(yu*yv), yv^(-1), 1/(yu*yv), yv^(-1)}, yw])/16 + 
     G[{yu^(-1), 1/(yu*yv), 1/(yu*yv), yv^(-1), yv^(-1)}, yw]/16 - 
     (3*G[{yu^(-1), 1/(yu*yv), 1/(yu*yv), 1/(yu*yv), yv^(-1)}, yw])/16 + 
     (11*G[{yv^(-1), yv^(-1), yv^(-1), yv^(-1), 1/(yu*yv)}, yw])/32 + 
     (123*G[{yv^(-1), yv^(-1), yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/64 + 
     (5*G[{yv^(-1), yv^(-1), 1/(yu*yv), yv^(-1), 1/(yu*yv)}, yw])/8 - 
     (7*G[{yv^(-1), yv^(-1), 1/(yu*yv), 1/(yu*yv), 1/(yu*yv)}, yw])/16 - 
     (17*G[{yv^(-1), 1/(yu*yv), yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/64 - 
     (Pi^2*Zeta[3])/32 + (9*G[{1}, yu^(-1)]^2*Zeta[3])/64 + 
     (G[{0}, yu^(-1)]*G[{1}, yv^(-1)]*Zeta[3])/8 + 
     (G[{0}, yv^(-1)]*G[{1}, yv^(-1)]*Zeta[3])/8 - 
     (G[{0}, yw]*G[{1}, yv^(-1)]*Zeta[3])/8 - 
     (13*G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*Zeta[3])/32 - 
     (G[{0}, yu^(-1)]*G[{1}, yw]*Zeta[3])/8 - 
     (G[{0}, yv^(-1)]*G[{1}, yw]*Zeta[3])/8 + (G[{0}, yw]*G[{1}, yw]*Zeta[3])/
      8 + (13*G[{1}, yu^(-1)]*G[{1}, yw]*Zeta[3])/32 + 
     (9*G[{1}, yw]^2*Zeta[3])/64 - (9*G[{1}, yw]*G[{yu}, yv^(-1)]*Zeta[3])/
      32 - (9*G[{1}, yu^(-1)]*G[{1/(yu*yv)}, yw]*Zeta[3])/32 + 
     (G[{1}, yv^(-1)]*G[{1/(yu*yv)}, yw]*Zeta[3])/8 - 
     (9*G[{1}, yw]*G[{1/(yu*yv)}, yw]*Zeta[3])/32 - 
     (G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*Zeta[3])/8 + 
     (9*G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw]*Zeta[3])/32 + 
     (9*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*Zeta[3])/32 - 
     (9*G[{0, 1}, yu^(-1)]*Zeta[3])/32 + (G[{0, yu^(-1)}, yw]*Zeta[3])/8 - 
     (G[{0, yv^(-1)}, yw]*Zeta[3])/8 - (G[{1, yu^(-1)}, yw]*Zeta[3])/8 + 
     (9*G[{1, yu}, yv^(-1)]*Zeta[3])/32 - (9*G[{1, yv^(-1)}, yw]*Zeta[3])/
      32 + (9*G[{1, 1/(yu*yv)}, yw]*Zeta[3])/32 + 
     (G[{yu^(-1), 1/(yu*yv)}, yw]*Zeta[3])/8 - 
     (9*G[{yv^(-1), 1/(yu*yv)}, yw]*Zeta[3])/32 + Zeta[5]/4
 
QepuwvRegII = (Pi^4*G[{0}, yu^(-1)])/1152 + (Pi^4*G[{0}, yv^(-1)])/1152 - 
     (Pi^4*G[{0}, yw])/1152 - (Pi^4*G[{1}, yu^(-1)])/1152 + 
     (Pi^2*G[{0}, yu^(-1)]*G[{1}, yu^(-1)]^2)/768 - 
     (3*G[{0}, yu^(-1)]^3*G[{1}, yu^(-1)]^2)/256 + 
     (Pi^2*G[{0}, yv^(-1)]*G[{1}, yu^(-1)]^2)/768 - 
     (9*G[{0}, yu^(-1)]^2*G[{0}, yv^(-1)]*G[{1}, yu^(-1)]^2)/256 - 
     (9*G[{0}, yu^(-1)]*G[{0}, yv^(-1)]^2*G[{1}, yu^(-1)]^2)/256 - 
     (3*G[{0}, yv^(-1)]^3*G[{1}, yu^(-1)]^2)/256 - 
     (Pi^2*G[{0}, yw]*G[{1}, yu^(-1)]^2)/768 + 
     (9*G[{0}, yu^(-1)]^2*G[{0}, yw]*G[{1}, yu^(-1)]^2)/256 + 
     (9*G[{0}, yu^(-1)]*G[{0}, yv^(-1)]*G[{0}, yw]*G[{1}, yu^(-1)]^2)/128 + 
     (9*G[{0}, yv^(-1)]^2*G[{0}, yw]*G[{1}, yu^(-1)]^2)/256 - 
     (9*G[{0}, yu^(-1)]*G[{0}, yw]^2*G[{1}, yu^(-1)]^2)/256 - 
     (9*G[{0}, yv^(-1)]*G[{0}, yw]^2*G[{1}, yu^(-1)]^2)/256 + 
     (3*G[{0}, yw]^3*G[{1}, yu^(-1)]^2)/256 + (Pi^2*G[{1}, yu^(-1)]^3)/2304 + 
     (9*G[{0}, yu^(-1)]^2*G[{1}, yu^(-1)]^3)/256 + 
     (9*G[{0}, yu^(-1)]*G[{0}, yv^(-1)]*G[{1}, yu^(-1)]^3)/128 + 
     (9*G[{0}, yv^(-1)]^2*G[{1}, yu^(-1)]^3)/256 - 
     (9*G[{0}, yu^(-1)]*G[{0}, yw]*G[{1}, yu^(-1)]^3)/128 - 
     (9*G[{0}, yv^(-1)]*G[{0}, yw]*G[{1}, yu^(-1)]^3)/128 + 
     (9*G[{0}, yw]^2*G[{1}, yu^(-1)]^3)/256 - 
     (9*G[{0}, yu^(-1)]*G[{1}, yu^(-1)]^4)/256 - 
     (9*G[{0}, yv^(-1)]*G[{1}, yu^(-1)]^4)/256 + 
     (9*G[{0}, yw]*G[{1}, yu^(-1)]^4)/256 + (3*G[{1}, yu^(-1)]^5)/256 + 
     (Pi^2*G[{0}, yu^(-1)]^2*G[{1}, yv^(-1)])/64 + 
     (Pi^2*G[{0}, yu^(-1)]*G[{0}, yv^(-1)]*G[{1}, yv^(-1)])/32 + 
     (Pi^2*G[{0}, yv^(-1)]^2*G[{1}, yv^(-1)])/64 - 
     (Pi^2*G[{0}, yu^(-1)]*G[{0}, yw]*G[{1}, yv^(-1)])/32 - 
     (Pi^2*G[{0}, yv^(-1)]*G[{0}, yw]*G[{1}, yv^(-1)])/32 + 
     (Pi^2*G[{0}, yw]^2*G[{1}, yv^(-1)])/64 - 
     (5*Pi^2*G[{0}, yu^(-1)]*G[{1}, yu^(-1)]*G[{1}, yv^(-1)])/384 + 
     (3*G[{0}, yu^(-1)]^3*G[{1}, yu^(-1)]*G[{1}, yv^(-1)])/128 - 
     (5*Pi^2*G[{0}, yv^(-1)]*G[{1}, yu^(-1)]*G[{1}, yv^(-1)])/384 + 
     (9*G[{0}, yu^(-1)]^2*G[{0}, yv^(-1)]*G[{1}, yu^(-1)]*G[{1}, yv^(-1)])/
      128 + (9*G[{0}, yu^(-1)]*G[{0}, yv^(-1)]^2*G[{1}, yu^(-1)]*
       G[{1}, yv^(-1)])/128 + (3*G[{0}, yv^(-1)]^3*G[{1}, yu^(-1)]*
       G[{1}, yv^(-1)])/128 + (5*Pi^2*G[{0}, yw]*G[{1}, yu^(-1)]*
       G[{1}, yv^(-1)])/384 - (9*G[{0}, yu^(-1)]^2*G[{0}, yw]*G[{1}, yu^(-1)]*
       G[{1}, yv^(-1)])/128 - (9*G[{0}, yu^(-1)]*G[{0}, yv^(-1)]*G[{0}, yw]*
       G[{1}, yu^(-1)]*G[{1}, yv^(-1)])/64 - 
     (9*G[{0}, yv^(-1)]^2*G[{0}, yw]*G[{1}, yu^(-1)]*G[{1}, yv^(-1)])/128 + 
     (9*G[{0}, yu^(-1)]*G[{0}, yw]^2*G[{1}, yu^(-1)]*G[{1}, yv^(-1)])/128 + 
     (9*G[{0}, yv^(-1)]*G[{0}, yw]^2*G[{1}, yu^(-1)]*G[{1}, yv^(-1)])/128 - 
     (3*G[{0}, yw]^3*G[{1}, yu^(-1)]*G[{1}, yv^(-1)])/128 - 
     (Pi^2*G[{1}, yu^(-1)]^2*G[{1}, yv^(-1)])/256 - 
     (9*G[{0}, yu^(-1)]^2*G[{1}, yu^(-1)]^2*G[{1}, yv^(-1)])/256 - 
     (9*G[{0}, yu^(-1)]*G[{0}, yv^(-1)]*G[{1}, yu^(-1)]^2*G[{1}, yv^(-1)])/
      128 - (9*G[{0}, yv^(-1)]^2*G[{1}, yu^(-1)]^2*G[{1}, yv^(-1)])/256 + 
     (9*G[{0}, yu^(-1)]*G[{0}, yw]*G[{1}, yu^(-1)]^2*G[{1}, yv^(-1)])/128 + 
     (9*G[{0}, yv^(-1)]*G[{0}, yw]*G[{1}, yu^(-1)]^2*G[{1}, yv^(-1)])/128 - 
     (9*G[{0}, yw]^2*G[{1}, yu^(-1)]^2*G[{1}, yv^(-1)])/256 + 
     (3*G[{1}, yu^(-1)]^4*G[{1}, yv^(-1)])/256 - 
     (5*Pi^2*G[{0}, yu^(-1)]*G[{1}, yv^(-1)]^2)/192 - 
     (5*Pi^2*G[{0}, yv^(-1)]*G[{1}, yv^(-1)]^2)/192 + 
     (5*Pi^2*G[{0}, yw]*G[{1}, yv^(-1)]^2)/192 + 
     (Pi^2*G[{1}, yu^(-1)]*G[{1}, yv^(-1)]^2)/128 - 
     (5*G[{0}, yu^(-1)]^2*G[{1}, yu^(-1)]*G[{1}, yv^(-1)]^2)/128 - 
     (5*G[{0}, yu^(-1)]*G[{0}, yv^(-1)]*G[{1}, yu^(-1)]*G[{1}, yv^(-1)]^2)/
      64 - (5*G[{0}, yv^(-1)]^2*G[{1}, yu^(-1)]*G[{1}, yv^(-1)]^2)/128 + 
     (5*G[{0}, yu^(-1)]*G[{0}, yw]*G[{1}, yu^(-1)]*G[{1}, yv^(-1)]^2)/64 + 
     (5*G[{0}, yv^(-1)]*G[{0}, yw]*G[{1}, yu^(-1)]*G[{1}, yv^(-1)]^2)/64 - 
     (5*G[{0}, yw]^2*G[{1}, yu^(-1)]*G[{1}, yv^(-1)]^2)/128 + 
     (11*G[{0}, yu^(-1)]*G[{1}, yu^(-1)]^2*G[{1}, yv^(-1)]^2)/256 + 
     (11*G[{0}, yv^(-1)]*G[{1}, yu^(-1)]^2*G[{1}, yv^(-1)]^2)/256 - 
     (11*G[{0}, yw]*G[{1}, yu^(-1)]^2*G[{1}, yv^(-1)]^2)/256 - 
     (G[{1}, yu^(-1)]^3*G[{1}, yv^(-1)]^2)/256 + (5*Pi^2*G[{1}, yv^(-1)]^3)/
      576 - (G[{0}, yu^(-1)]*G[{1}, yu^(-1)]*G[{1}, yv^(-1)]^3)/384 - 
     (G[{0}, yv^(-1)]*G[{1}, yu^(-1)]*G[{1}, yv^(-1)]^3)/384 + 
     (G[{0}, yw]*G[{1}, yu^(-1)]*G[{1}, yv^(-1)]^3)/384 + 
     (11*G[{1}, yu^(-1)]^2*G[{1}, yv^(-1)]^3)/768 + 
     (G[{1}, yu^(-1)]*G[{1}, yv^(-1)]^4)/96 - 
     (Pi^2*G[{0}, yu^(-1)]^2*G[{1}, yw])/64 - 
     (Pi^2*G[{0}, yu^(-1)]*G[{0}, yv^(-1)]*G[{1}, yw])/32 - 
     (Pi^2*G[{0}, yv^(-1)]^2*G[{1}, yw])/64 + 
     (Pi^2*G[{0}, yu^(-1)]*G[{0}, yw]*G[{1}, yw])/32 + 
     (Pi^2*G[{0}, yv^(-1)]*G[{0}, yw]*G[{1}, yw])/32 - 
     (Pi^2*G[{0}, yw]^2*G[{1}, yw])/64 + 
     (5*Pi^2*G[{0}, yu^(-1)]*G[{1}, yu^(-1)]*G[{1}, yw])/384 - 
     (3*G[{0}, yu^(-1)]^3*G[{1}, yu^(-1)]*G[{1}, yw])/128 + 
     (5*Pi^2*G[{0}, yv^(-1)]*G[{1}, yu^(-1)]*G[{1}, yw])/384 - 
     (9*G[{0}, yu^(-1)]^2*G[{0}, yv^(-1)]*G[{1}, yu^(-1)]*G[{1}, yw])/128 - 
     (9*G[{0}, yu^(-1)]*G[{0}, yv^(-1)]^2*G[{1}, yu^(-1)]*G[{1}, yw])/128 - 
     (3*G[{0}, yv^(-1)]^3*G[{1}, yu^(-1)]*G[{1}, yw])/128 - 
     (5*Pi^2*G[{0}, yw]*G[{1}, yu^(-1)]*G[{1}, yw])/384 + 
     (9*G[{0}, yu^(-1)]^2*G[{0}, yw]*G[{1}, yu^(-1)]*G[{1}, yw])/128 + 
     (9*G[{0}, yu^(-1)]*G[{0}, yv^(-1)]*G[{0}, yw]*G[{1}, yu^(-1)]*
       G[{1}, yw])/64 + (9*G[{0}, yv^(-1)]^2*G[{0}, yw]*G[{1}, yu^(-1)]*
       G[{1}, yw])/128 - (9*G[{0}, yu^(-1)]*G[{0}, yw]^2*G[{1}, yu^(-1)]*
       G[{1}, yw])/128 - (9*G[{0}, yv^(-1)]*G[{0}, yw]^2*G[{1}, yu^(-1)]*
       G[{1}, yw])/128 + (3*G[{0}, yw]^3*G[{1}, yu^(-1)]*G[{1}, yw])/128 + 
     (Pi^2*G[{1}, yu^(-1)]^2*G[{1}, yw])/256 + 
     (9*G[{0}, yu^(-1)]^2*G[{1}, yu^(-1)]^2*G[{1}, yw])/256 + 
     (9*G[{0}, yu^(-1)]*G[{0}, yv^(-1)]*G[{1}, yu^(-1)]^2*G[{1}, yw])/128 + 
     (9*G[{0}, yv^(-1)]^2*G[{1}, yu^(-1)]^2*G[{1}, yw])/256 - 
     (9*G[{0}, yu^(-1)]*G[{0}, yw]*G[{1}, yu^(-1)]^2*G[{1}, yw])/128 - 
     (9*G[{0}, yv^(-1)]*G[{0}, yw]*G[{1}, yu^(-1)]^2*G[{1}, yw])/128 + 
     (9*G[{0}, yw]^2*G[{1}, yu^(-1)]^2*G[{1}, yw])/256 - 
     (3*G[{1}, yu^(-1)]^4*G[{1}, yw])/256 + 
     (5*Pi^2*G[{0}, yu^(-1)]*G[{1}, yv^(-1)]*G[{1}, yw])/96 + 
     (5*Pi^2*G[{0}, yv^(-1)]*G[{1}, yv^(-1)]*G[{1}, yw])/96 - 
     (5*Pi^2*G[{0}, yw]*G[{1}, yv^(-1)]*G[{1}, yw])/96 - 
     (Pi^2*G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*G[{1}, yw])/64 + 
     (5*G[{0}, yu^(-1)]^2*G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*G[{1}, yw])/64 + 
     (5*G[{0}, yu^(-1)]*G[{0}, yv^(-1)]*G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*
       G[{1}, yw])/32 + (5*G[{0}, yv^(-1)]^2*G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*
       G[{1}, yw])/64 - (5*G[{0}, yu^(-1)]*G[{0}, yw]*G[{1}, yu^(-1)]*
       G[{1}, yv^(-1)]*G[{1}, yw])/32 - (5*G[{0}, yv^(-1)]*G[{0}, yw]*
       G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*G[{1}, yw])/32 + 
     (5*G[{0}, yw]^2*G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*G[{1}, yw])/64 - 
     (11*G[{0}, yu^(-1)]*G[{1}, yu^(-1)]^2*G[{1}, yv^(-1)]*G[{1}, yw])/128 - 
     (11*G[{0}, yv^(-1)]*G[{1}, yu^(-1)]^2*G[{1}, yv^(-1)]*G[{1}, yw])/128 + 
     (11*G[{0}, yw]*G[{1}, yu^(-1)]^2*G[{1}, yv^(-1)]*G[{1}, yw])/128 + 
     (G[{1}, yu^(-1)]^3*G[{1}, yv^(-1)]*G[{1}, yw])/128 - 
     (5*Pi^2*G[{1}, yv^(-1)]^2*G[{1}, yw])/192 + 
     (G[{0}, yu^(-1)]*G[{1}, yu^(-1)]*G[{1}, yv^(-1)]^2*G[{1}, yw])/128 + 
     (G[{0}, yv^(-1)]*G[{1}, yu^(-1)]*G[{1}, yv^(-1)]^2*G[{1}, yw])/128 - 
     (G[{0}, yw]*G[{1}, yu^(-1)]*G[{1}, yv^(-1)]^2*G[{1}, yw])/128 - 
     (11*G[{1}, yu^(-1)]^2*G[{1}, yv^(-1)]^2*G[{1}, yw])/256 - 
     (G[{1}, yu^(-1)]*G[{1}, yv^(-1)]^3*G[{1}, yw])/24 - 
     (11*Pi^2*G[{0}, yu^(-1)]*G[{1}, yw]^2)/512 - 
     (3*G[{0}, yu^(-1)]^3*G[{1}, yw]^2)/256 - 
     (11*Pi^2*G[{0}, yv^(-1)]*G[{1}, yw]^2)/512 - 
     (9*G[{0}, yu^(-1)]^2*G[{0}, yv^(-1)]*G[{1}, yw]^2)/256 - 
     (9*G[{0}, yu^(-1)]*G[{0}, yv^(-1)]^2*G[{1}, yw]^2)/256 - 
     (3*G[{0}, yv^(-1)]^3*G[{1}, yw]^2)/256 + 
     (11*Pi^2*G[{0}, yw]*G[{1}, yw]^2)/512 + 
     (9*G[{0}, yu^(-1)]^2*G[{0}, yw]*G[{1}, yw]^2)/256 + 
     (9*G[{0}, yu^(-1)]*G[{0}, yv^(-1)]*G[{0}, yw]*G[{1}, yw]^2)/128 + 
     (9*G[{0}, yv^(-1)]^2*G[{0}, yw]*G[{1}, yw]^2)/256 - 
     (9*G[{0}, yu^(-1)]*G[{0}, yw]^2*G[{1}, yw]^2)/256 - 
     (9*G[{0}, yv^(-1)]*G[{0}, yw]^2*G[{1}, yw]^2)/256 + 
     (3*G[{0}, yw]^3*G[{1}, yw]^2)/256 + 
     (7*Pi^2*G[{1}, yu^(-1)]*G[{1}, yw]^2)/512 + 
     (3*G[{0}, yu^(-1)]^2*G[{1}, yu^(-1)]*G[{1}, yw]^2)/256 + 
     (3*G[{0}, yu^(-1)]*G[{0}, yv^(-1)]*G[{1}, yu^(-1)]*G[{1}, yw]^2)/128 + 
     (3*G[{0}, yv^(-1)]^2*G[{1}, yu^(-1)]*G[{1}, yw]^2)/256 - 
     (3*G[{0}, yu^(-1)]*G[{0}, yw]*G[{1}, yu^(-1)]*G[{1}, yw]^2)/128 - 
     (3*G[{0}, yv^(-1)]*G[{0}, yw]*G[{1}, yu^(-1)]*G[{1}, yw]^2)/128 + 
     (3*G[{0}, yw]^2*G[{1}, yu^(-1)]*G[{1}, yw]^2)/256 + 
     (11*Pi^2*G[{1}, yv^(-1)]*G[{1}, yw]^2)/512 + 
     (9*G[{0}, yu^(-1)]^2*G[{1}, yv^(-1)]*G[{1}, yw]^2)/256 + 
     (9*G[{0}, yu^(-1)]*G[{0}, yv^(-1)]*G[{1}, yv^(-1)]*G[{1}, yw]^2)/128 + 
     (9*G[{0}, yv^(-1)]^2*G[{1}, yv^(-1)]*G[{1}, yw]^2)/256 - 
     (9*G[{0}, yu^(-1)]*G[{0}, yw]*G[{1}, yv^(-1)]*G[{1}, yw]^2)/128 - 
     (9*G[{0}, yv^(-1)]*G[{0}, yw]*G[{1}, yv^(-1)]*G[{1}, yw]^2)/128 + 
     (9*G[{0}, yw]^2*G[{1}, yv^(-1)]*G[{1}, yw]^2)/256 - 
     (3*G[{0}, yu^(-1)]*G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*G[{1}, yw]^2)/32 - 
     (3*G[{0}, yv^(-1)]*G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*G[{1}, yw]^2)/32 + 
     (3*G[{0}, yw]*G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*G[{1}, yw]^2)/32 + 
     (9*G[{1}, yu^(-1)]^2*G[{1}, yv^(-1)]*G[{1}, yw]^2)/128 - 
     (9*G[{0}, yu^(-1)]*G[{1}, yv^(-1)]^2*G[{1}, yw]^2)/256 - 
     (9*G[{0}, yv^(-1)]*G[{1}, yv^(-1)]^2*G[{1}, yw]^2)/256 + 
     (9*G[{0}, yw]*G[{1}, yv^(-1)]^2*G[{1}, yw]^2)/256 + 
     (25*G[{1}, yu^(-1)]*G[{1}, yv^(-1)]^2*G[{1}, yw]^2)/256 + 
     (3*G[{1}, yv^(-1)]^3*G[{1}, yw]^2)/256 - (5*Pi^2*G[{1}, yw]^3)/2304 - 
     (G[{0}, yu^(-1)]^2*G[{1}, yw]^3)/256 - 
     (G[{0}, yu^(-1)]*G[{0}, yv^(-1)]*G[{1}, yw]^3)/128 - 
     (G[{0}, yv^(-1)]^2*G[{1}, yw]^3)/256 + 
     (G[{0}, yu^(-1)]*G[{0}, yw]*G[{1}, yw]^3)/128 + 
     (G[{0}, yv^(-1)]*G[{0}, yw]*G[{1}, yw]^3)/128 - 
     (G[{0}, yw]^2*G[{1}, yw]^3)/256 + (G[{0}, yu^(-1)]*G[{1}, yu^(-1)]*
       G[{1}, yw]^3)/192 + (G[{0}, yv^(-1)]*G[{1}, yu^(-1)]*G[{1}, yw]^3)/
      192 - (G[{0}, yw]*G[{1}, yu^(-1)]*G[{1}, yw]^3)/192 - 
     (G[{1}, yu^(-1)]^2*G[{1}, yw]^3)/768 + 
     (G[{0}, yu^(-1)]*G[{1}, yv^(-1)]*G[{1}, yw]^3)/128 + 
     (G[{0}, yv^(-1)]*G[{1}, yv^(-1)]*G[{1}, yw]^3)/128 - 
     (G[{0}, yw]*G[{1}, yv^(-1)]*G[{1}, yw]^3)/128 - 
     (G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*G[{1}, yw]^3)/64 - 
     (G[{1}, yv^(-1)]^2*G[{1}, yw]^3)/256 + (G[{0}, yu^(-1)]*G[{1}, yw]^4)/
      768 + (G[{0}, yv^(-1)]*G[{1}, yw]^4)/768 - (G[{0}, yw]*G[{1}, yw]^4)/
      768 - (G[{1}, yu^(-1)]*G[{1}, yw]^4)/768 - 
     (G[{1}, yv^(-1)]*G[{1}, yw]^4)/768 + 
     (7*Pi^2*G[{0}, yu^(-1)]*G[{1}, yw]*G[{yu}, yv^(-1)])/384 + 
     (3*G[{0}, yu^(-1)]^3*G[{1}, yw]*G[{yu}, yv^(-1)])/128 + 
     (7*Pi^2*G[{0}, yv^(-1)]*G[{1}, yw]*G[{yu}, yv^(-1)])/384 + 
     (9*G[{0}, yu^(-1)]^2*G[{0}, yv^(-1)]*G[{1}, yw]*G[{yu}, yv^(-1)])/128 + 
     (9*G[{0}, yu^(-1)]*G[{0}, yv^(-1)]^2*G[{1}, yw]*G[{yu}, yv^(-1)])/128 + 
     (3*G[{0}, yv^(-1)]^3*G[{1}, yw]*G[{yu}, yv^(-1)])/128 - 
     (7*Pi^2*G[{0}, yw]*G[{1}, yw]*G[{yu}, yv^(-1)])/384 - 
     (9*G[{0}, yu^(-1)]^2*G[{0}, yw]*G[{1}, yw]*G[{yu}, yv^(-1)])/128 - 
     (9*G[{0}, yu^(-1)]*G[{0}, yv^(-1)]*G[{0}, yw]*G[{1}, yw]*
       G[{yu}, yv^(-1)])/64 - (9*G[{0}, yv^(-1)]^2*G[{0}, yw]*G[{1}, yw]*
       G[{yu}, yv^(-1)])/128 + (9*G[{0}, yu^(-1)]*G[{0}, yw]^2*G[{1}, yw]*
       G[{yu}, yv^(-1)])/128 + (9*G[{0}, yv^(-1)]*G[{0}, yw]^2*G[{1}, yw]*
       G[{yu}, yv^(-1)])/128 - (3*G[{0}, yw]^3*G[{1}, yw]*G[{yu}, yv^(-1)])/
      128 - (7*Pi^2*G[{1}, yu^(-1)]*G[{1}, yw]*G[{yu}, yv^(-1)])/384 - 
     (G[{0}, yu^(-1)]^2*G[{1}, yu^(-1)]*G[{1}, yw]*G[{yu}, yv^(-1)])/128 - 
     (G[{0}, yu^(-1)]*G[{0}, yv^(-1)]*G[{1}, yu^(-1)]*G[{1}, yw]*
       G[{yu}, yv^(-1)])/64 - (G[{0}, yv^(-1)]^2*G[{1}, yu^(-1)]*G[{1}, yw]*
       G[{yu}, yv^(-1)])/128 + (G[{0}, yu^(-1)]*G[{0}, yw]*G[{1}, yu^(-1)]*
       G[{1}, yw]*G[{yu}, yv^(-1)])/64 + 
     (G[{0}, yv^(-1)]*G[{0}, yw]*G[{1}, yu^(-1)]*G[{1}, yw]*G[{yu}, yv^(-1)])/
      64 - (G[{0}, yw]^2*G[{1}, yu^(-1)]*G[{1}, yw]*G[{yu}, yv^(-1)])/128 - 
     (7*G[{0}, yu^(-1)]*G[{1}, yu^(-1)]^2*G[{1}, yw]*G[{yu}, yv^(-1)])/128 - 
     (7*G[{0}, yv^(-1)]*G[{1}, yu^(-1)]^2*G[{1}, yw]*G[{yu}, yv^(-1)])/128 + 
     (7*G[{0}, yw]*G[{1}, yu^(-1)]^2*G[{1}, yw]*G[{yu}, yv^(-1)])/128 + 
     (5*G[{1}, yu^(-1)]^3*G[{1}, yw]*G[{yu}, yv^(-1)])/128 + 
     (Pi^2*G[{1}, yv^(-1)]*G[{1}, yw]*G[{yu}, yv^(-1)])/384 + 
     (3*G[{0}, yu^(-1)]^2*G[{1}, yv^(-1)]*G[{1}, yw]*G[{yu}, yv^(-1)])/128 + 
     (3*G[{0}, yu^(-1)]*G[{0}, yv^(-1)]*G[{1}, yv^(-1)]*G[{1}, yw]*
       G[{yu}, yv^(-1)])/64 + (3*G[{0}, yv^(-1)]^2*G[{1}, yv^(-1)]*G[{1}, yw]*
       G[{yu}, yv^(-1)])/128 - (3*G[{0}, yu^(-1)]*G[{0}, yw]*G[{1}, yv^(-1)]*
       G[{1}, yw]*G[{yu}, yv^(-1)])/64 - (3*G[{0}, yv^(-1)]*G[{0}, yw]*
       G[{1}, yv^(-1)]*G[{1}, yw]*G[{yu}, yv^(-1)])/64 + 
     (3*G[{0}, yw]^2*G[{1}, yv^(-1)]*G[{1}, yw]*G[{yu}, yv^(-1)])/128 - 
     (11*G[{0}, yu^(-1)]*G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*G[{1}, yw]*
       G[{yu}, yv^(-1)])/64 - (11*G[{0}, yv^(-1)]*G[{1}, yu^(-1)]*
       G[{1}, yv^(-1)]*G[{1}, yw]*G[{yu}, yv^(-1)])/64 + 
     (11*G[{0}, yw]*G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*G[{1}, yw]*
       G[{yu}, yv^(-1)])/64 + (19*G[{1}, yu^(-1)]^2*G[{1}, yv^(-1)]*
       G[{1}, yw]*G[{yu}, yv^(-1)])/128 - 
     (11*G[{0}, yu^(-1)]*G[{1}, yv^(-1)]^2*G[{1}, yw]*G[{yu}, yv^(-1)])/128 - 
     (11*G[{0}, yv^(-1)]*G[{1}, yv^(-1)]^2*G[{1}, yw]*G[{yu}, yv^(-1)])/128 + 
     (11*G[{0}, yw]*G[{1}, yv^(-1)]^2*G[{1}, yw]*G[{yu}, yv^(-1)])/128 + 
     (11*G[{1}, yu^(-1)]*G[{1}, yv^(-1)]^2*G[{1}, yw]*G[{yu}, yv^(-1)])/128 + 
     (5*G[{1}, yv^(-1)]^3*G[{1}, yw]*G[{yu}, yv^(-1)])/128 + 
     (Pi^2*G[{1}, yw]^2*G[{yu}, yv^(-1)])/128 + 
     (3*G[{0}, yu^(-1)]^2*G[{1}, yw]^2*G[{yu}, yv^(-1)])/128 + 
     (3*G[{0}, yu^(-1)]*G[{0}, yv^(-1)]*G[{1}, yw]^2*G[{yu}, yv^(-1)])/64 + 
     (3*G[{0}, yv^(-1)]^2*G[{1}, yw]^2*G[{yu}, yv^(-1)])/128 - 
     (3*G[{0}, yu^(-1)]*G[{0}, yw]*G[{1}, yw]^2*G[{yu}, yv^(-1)])/64 - 
     (3*G[{0}, yv^(-1)]*G[{0}, yw]*G[{1}, yw]^2*G[{yu}, yv^(-1)])/64 + 
     (3*G[{0}, yw]^2*G[{1}, yw]^2*G[{yu}, yv^(-1)])/128 + 
     (3*G[{0}, yu^(-1)]*G[{1}, yu^(-1)]*G[{1}, yw]^2*G[{yu}, yv^(-1)])/64 + 
     (3*G[{0}, yv^(-1)]*G[{1}, yu^(-1)]*G[{1}, yw]^2*G[{yu}, yv^(-1)])/64 - 
     (3*G[{0}, yw]*G[{1}, yu^(-1)]*G[{1}, yw]^2*G[{yu}, yv^(-1)])/64 - 
     (9*G[{1}, yu^(-1)]^2*G[{1}, yw]^2*G[{yu}, yv^(-1)])/128 + 
     (3*G[{0}, yu^(-1)]*G[{1}, yv^(-1)]*G[{1}, yw]^2*G[{yu}, yv^(-1)])/64 + 
     (3*G[{0}, yv^(-1)]*G[{1}, yv^(-1)]*G[{1}, yw]^2*G[{yu}, yv^(-1)])/64 - 
     (3*G[{0}, yw]*G[{1}, yv^(-1)]*G[{1}, yw]^2*G[{yu}, yv^(-1)])/64 - 
     (7*G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*G[{1}, yw]^2*G[{yu}, yv^(-1)])/64 - 
     (7*G[{1}, yv^(-1)]^2*G[{1}, yw]^2*G[{yu}, yv^(-1)])/128 + 
     (G[{0}, yu^(-1)]*G[{1}, yw]^3*G[{yu}, yv^(-1)])/384 + 
     (G[{0}, yv^(-1)]*G[{1}, yw]^3*G[{yu}, yv^(-1)])/384 - 
     (G[{0}, yw]*G[{1}, yw]^3*G[{yu}, yv^(-1)])/384 + 
     (G[{1}, yu^(-1)]*G[{1}, yw]^3*G[{yu}, yv^(-1)])/128 + 
     (G[{1}, yv^(-1)]*G[{1}, yw]^3*G[{yu}, yv^(-1)])/128 - 
     (Pi^2*G[{1}, yw]*G[{yu}, yv^(-1)]^2)/96 - 
     (5*G[{0}, yu^(-1)]^2*G[{1}, yw]*G[{yu}, yv^(-1)]^2)/64 - 
     (5*G[{0}, yu^(-1)]*G[{0}, yv^(-1)]*G[{1}, yw]*G[{yu}, yv^(-1)]^2)/32 - 
     (5*G[{0}, yv^(-1)]^2*G[{1}, yw]*G[{yu}, yv^(-1)]^2)/64 + 
     (5*G[{0}, yu^(-1)]*G[{0}, yw]*G[{1}, yw]*G[{yu}, yv^(-1)]^2)/32 + 
     (5*G[{0}, yv^(-1)]*G[{0}, yw]*G[{1}, yw]*G[{yu}, yv^(-1)]^2)/32 - 
     (5*G[{0}, yw]^2*G[{1}, yw]*G[{yu}, yv^(-1)]^2)/64 + 
     (5*G[{0}, yu^(-1)]*G[{1}, yu^(-1)]*G[{1}, yw]*G[{yu}, yv^(-1)]^2)/32 + 
     (5*G[{0}, yv^(-1)]*G[{1}, yu^(-1)]*G[{1}, yw]*G[{yu}, yv^(-1)]^2)/32 - 
     (5*G[{0}, yw]*G[{1}, yu^(-1)]*G[{1}, yw]*G[{yu}, yv^(-1)]^2)/32 - 
     (5*G[{1}, yu^(-1)]^2*G[{1}, yw]*G[{yu}, yv^(-1)]^2)/64 + 
     (G[{0}, yu^(-1)]*G[{1}, yv^(-1)]*G[{1}, yw]*G[{yu}, yv^(-1)]^2)/32 + 
     (G[{0}, yv^(-1)]*G[{1}, yv^(-1)]*G[{1}, yw]*G[{yu}, yv^(-1)]^2)/32 - 
     (G[{0}, yw]*G[{1}, yv^(-1)]*G[{1}, yw]*G[{yu}, yv^(-1)]^2)/32 + 
     (G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*G[{1}, yw]*G[{yu}, yv^(-1)]^2)/32 + 
     (G[{1}, yv^(-1)]^2*G[{1}, yw]*G[{yu}, yv^(-1)]^2)/64 - 
     (3*G[{0}, yu^(-1)]*G[{1}, yw]^2*G[{yu}, yv^(-1)]^2)/32 - 
     (3*G[{0}, yv^(-1)]*G[{1}, yw]^2*G[{yu}, yv^(-1)]^2)/32 + 
     (3*G[{0}, yw]*G[{1}, yw]^2*G[{yu}, yv^(-1)]^2)/32 + 
     (5*G[{1}, yu^(-1)]*G[{1}, yw]^2*G[{yu}, yv^(-1)]^2)/64 + 
     (G[{1}, yv^(-1)]*G[{1}, yw]^2*G[{yu}, yv^(-1)]^2)/32 - 
     (G[{1}, yw]^3*G[{yu}, yv^(-1)]^2)/96 + 
     (G[{0}, yu^(-1)]*G[{1}, yw]*G[{yu}, yv^(-1)]^3)/24 + 
     (G[{0}, yv^(-1)]*G[{1}, yw]*G[{yu}, yv^(-1)]^3)/24 - 
     (G[{0}, yw]*G[{1}, yw]*G[{yu}, yv^(-1)]^3)/24 - 
     (G[{1}, yu^(-1)]*G[{1}, yw]*G[{yu}, yv^(-1)]^3)/16 + 
     (5*G[{1}, yw]^2*G[{yu}, yv^(-1)]^3)/192 - 
     (G[{1}, yw]*G[{yu}, yv^(-1)]^4)/192 + (Pi^4*G[{1/(yu*yv)}, yw])/1152 - 
     (Pi^2*G[{0}, yu^(-1)]*G[{1}, yu^(-1)]*G[{1/(yu*yv)}, yw])/384 + 
     (3*G[{0}, yu^(-1)]^3*G[{1}, yu^(-1)]*G[{1/(yu*yv)}, yw])/128 - 
     (Pi^2*G[{0}, yv^(-1)]*G[{1}, yu^(-1)]*G[{1/(yu*yv)}, yw])/384 + 
     (9*G[{0}, yu^(-1)]^2*G[{0}, yv^(-1)]*G[{1}, yu^(-1)]*G[{1/(yu*yv)}, yw])/
      128 + (9*G[{0}, yu^(-1)]*G[{0}, yv^(-1)]^2*G[{1}, yu^(-1)]*
       G[{1/(yu*yv)}, yw])/128 + (3*G[{0}, yv^(-1)]^3*G[{1}, yu^(-1)]*
       G[{1/(yu*yv)}, yw])/128 + (Pi^2*G[{0}, yw]*G[{1}, yu^(-1)]*
       G[{1/(yu*yv)}, yw])/384 - (9*G[{0}, yu^(-1)]^2*G[{0}, yw]*
       G[{1}, yu^(-1)]*G[{1/(yu*yv)}, yw])/128 - 
     (9*G[{0}, yu^(-1)]*G[{0}, yv^(-1)]*G[{0}, yw]*G[{1}, yu^(-1)]*
       G[{1/(yu*yv)}, yw])/64 - (9*G[{0}, yv^(-1)]^2*G[{0}, yw]*
       G[{1}, yu^(-1)]*G[{1/(yu*yv)}, yw])/128 + 
     (9*G[{0}, yu^(-1)]*G[{0}, yw]^2*G[{1}, yu^(-1)]*G[{1/(yu*yv)}, yw])/
      128 + (9*G[{0}, yv^(-1)]*G[{0}, yw]^2*G[{1}, yu^(-1)]*
       G[{1/(yu*yv)}, yw])/128 - (3*G[{0}, yw]^3*G[{1}, yu^(-1)]*
       G[{1/(yu*yv)}, yw])/128 - (Pi^2*G[{1}, yu^(-1)]^2*G[{1/(yu*yv)}, yw])/
      768 - (27*G[{0}, yu^(-1)]^2*G[{1}, yu^(-1)]^2*G[{1/(yu*yv)}, yw])/256 - 
     (27*G[{0}, yu^(-1)]*G[{0}, yv^(-1)]*G[{1}, yu^(-1)]^2*
       G[{1/(yu*yv)}, yw])/128 - (27*G[{0}, yv^(-1)]^2*G[{1}, yu^(-1)]^2*
       G[{1/(yu*yv)}, yw])/256 + (27*G[{0}, yu^(-1)]*G[{0}, yw]*
       G[{1}, yu^(-1)]^2*G[{1/(yu*yv)}, yw])/128 + 
     (27*G[{0}, yv^(-1)]*G[{0}, yw]*G[{1}, yu^(-1)]^2*G[{1/(yu*yv)}, yw])/
      128 - (27*G[{0}, yw]^2*G[{1}, yu^(-1)]^2*G[{1/(yu*yv)}, yw])/256 + 
     (9*G[{0}, yu^(-1)]*G[{1}, yu^(-1)]^3*G[{1/(yu*yv)}, yw])/64 + 
     (9*G[{0}, yv^(-1)]*G[{1}, yu^(-1)]^3*G[{1/(yu*yv)}, yw])/64 - 
     (9*G[{0}, yw]*G[{1}, yu^(-1)]^3*G[{1/(yu*yv)}, yw])/64 - 
     (15*G[{1}, yu^(-1)]^4*G[{1/(yu*yv)}, yw])/256 + 
     (Pi^2*G[{0}, yu^(-1)]*G[{1}, yv^(-1)]*G[{1/(yu*yv)}, yw])/32 + 
     (Pi^2*G[{0}, yv^(-1)]*G[{1}, yv^(-1)]*G[{1/(yu*yv)}, yw])/32 - 
     (Pi^2*G[{0}, yw]*G[{1}, yv^(-1)]*G[{1/(yu*yv)}, yw])/32 - 
     (Pi^2*G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*G[{1/(yu*yv)}, yw])/96 + 
     (G[{0}, yu^(-1)]^2*G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*G[{1/(yu*yv)}, yw])/
      16 + (G[{0}, yu^(-1)]*G[{0}, yv^(-1)]*G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*
       G[{1/(yu*yv)}, yw])/8 + (G[{0}, yv^(-1)]^2*G[{1}, yu^(-1)]*
       G[{1}, yv^(-1)]*G[{1/(yu*yv)}, yw])/16 - 
     (G[{0}, yu^(-1)]*G[{0}, yw]*G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*
       G[{1/(yu*yv)}, yw])/8 - (G[{0}, yv^(-1)]*G[{0}, yw]*G[{1}, yu^(-1)]*
       G[{1}, yv^(-1)]*G[{1/(yu*yv)}, yw])/8 + 
     (G[{0}, yw]^2*G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*G[{1/(yu*yv)}, yw])/16 - 
     (7*G[{0}, yu^(-1)]*G[{1}, yu^(-1)]^2*G[{1}, yv^(-1)]*G[{1/(yu*yv)}, yw])/
      128 - (7*G[{0}, yv^(-1)]*G[{1}, yu^(-1)]^2*G[{1}, yv^(-1)]*
       G[{1/(yu*yv)}, yw])/128 + (7*G[{0}, yw]*G[{1}, yu^(-1)]^2*
       G[{1}, yv^(-1)]*G[{1/(yu*yv)}, yw])/128 - 
     (G[{1}, yu^(-1)]^3*G[{1}, yv^(-1)]*G[{1/(yu*yv)}, yw])/128 - 
     (5*Pi^2*G[{1}, yv^(-1)]^2*G[{1/(yu*yv)}, yw])/192 - 
     (21*G[{0}, yu^(-1)]*G[{1}, yu^(-1)]*G[{1}, yv^(-1)]^2*
       G[{1/(yu*yv)}, yw])/128 - (21*G[{0}, yv^(-1)]*G[{1}, yu^(-1)]*
       G[{1}, yv^(-1)]^2*G[{1/(yu*yv)}, yw])/128 + 
     (21*G[{0}, yw]*G[{1}, yu^(-1)]*G[{1}, yv^(-1)]^2*G[{1/(yu*yv)}, yw])/
      128 + (33*G[{1}, yu^(-1)]^2*G[{1}, yv^(-1)]^2*G[{1/(yu*yv)}, yw])/256 + 
     (7*G[{1}, yu^(-1)]*G[{1}, yv^(-1)]^3*G[{1/(yu*yv)}, yw])/192 + 
     (19*Pi^2*G[{0}, yu^(-1)]*G[{1}, yw]*G[{1/(yu*yv)}, yw])/768 + 
     (3*G[{0}, yu^(-1)]^3*G[{1}, yw]*G[{1/(yu*yv)}, yw])/128 + 
     (19*Pi^2*G[{0}, yv^(-1)]*G[{1}, yw]*G[{1/(yu*yv)}, yw])/768 + 
     (9*G[{0}, yu^(-1)]^2*G[{0}, yv^(-1)]*G[{1}, yw]*G[{1/(yu*yv)}, yw])/
      128 + (9*G[{0}, yu^(-1)]*G[{0}, yv^(-1)]^2*G[{1}, yw]*
       G[{1/(yu*yv)}, yw])/128 + (3*G[{0}, yv^(-1)]^3*G[{1}, yw]*
       G[{1/(yu*yv)}, yw])/128 - (19*Pi^2*G[{0}, yw]*G[{1}, yw]*
       G[{1/(yu*yv)}, yw])/768 - (9*G[{0}, yu^(-1)]^2*G[{0}, yw]*G[{1}, yw]*
       G[{1/(yu*yv)}, yw])/128 - (9*G[{0}, yu^(-1)]*G[{0}, yv^(-1)]*
       G[{0}, yw]*G[{1}, yw]*G[{1/(yu*yv)}, yw])/64 - 
     (9*G[{0}, yv^(-1)]^2*G[{0}, yw]*G[{1}, yw]*G[{1/(yu*yv)}, yw])/128 + 
     (9*G[{0}, yu^(-1)]*G[{0}, yw]^2*G[{1}, yw]*G[{1/(yu*yv)}, yw])/128 + 
     (9*G[{0}, yv^(-1)]*G[{0}, yw]^2*G[{1}, yw]*G[{1/(yu*yv)}, yw])/128 - 
     (3*G[{0}, yw]^3*G[{1}, yw]*G[{1/(yu*yv)}, yw])/128 - 
     (11*Pi^2*G[{1}, yu^(-1)]*G[{1}, yw]*G[{1/(yu*yv)}, yw])/768 + 
     (3*G[{0}, yu^(-1)]^2*G[{1}, yu^(-1)]*G[{1}, yw]*G[{1/(yu*yv)}, yw])/
      128 + (3*G[{0}, yu^(-1)]*G[{0}, yv^(-1)]*G[{1}, yu^(-1)]*G[{1}, yw]*
       G[{1/(yu*yv)}, yw])/64 + (3*G[{0}, yv^(-1)]^2*G[{1}, yu^(-1)]*
       G[{1}, yw]*G[{1/(yu*yv)}, yw])/128 - 
     (3*G[{0}, yu^(-1)]*G[{0}, yw]*G[{1}, yu^(-1)]*G[{1}, yw]*
       G[{1/(yu*yv)}, yw])/64 - (3*G[{0}, yv^(-1)]*G[{0}, yw]*G[{1}, yu^(-1)]*
       G[{1}, yw]*G[{1/(yu*yv)}, yw])/64 + 
     (3*G[{0}, yw]^2*G[{1}, yu^(-1)]*G[{1}, yw]*G[{1/(yu*yv)}, yw])/128 - 
     (9*G[{0}, yu^(-1)]*G[{1}, yu^(-1)]^2*G[{1}, yw]*G[{1/(yu*yv)}, yw])/64 - 
     (9*G[{0}, yv^(-1)]*G[{1}, yu^(-1)]^2*G[{1}, yw]*G[{1/(yu*yv)}, yw])/64 + 
     (9*G[{0}, yw]*G[{1}, yu^(-1)]^2*G[{1}, yw]*G[{1/(yu*yv)}, yw])/64 + 
     (3*G[{1}, yu^(-1)]^3*G[{1}, yw]*G[{1/(yu*yv)}, yw])/32 - 
     (11*Pi^2*G[{1}, yv^(-1)]*G[{1}, yw]*G[{1/(yu*yv)}, yw])/768 - 
     (9*G[{0}, yu^(-1)]^2*G[{1}, yv^(-1)]*G[{1}, yw]*G[{1/(yu*yv)}, yw])/
      128 - (9*G[{0}, yu^(-1)]*G[{0}, yv^(-1)]*G[{1}, yv^(-1)]*G[{1}, yw]*
       G[{1/(yu*yv)}, yw])/64 - (9*G[{0}, yv^(-1)]^2*G[{1}, yv^(-1)]*
       G[{1}, yw]*G[{1/(yu*yv)}, yw])/128 + 
     (9*G[{0}, yu^(-1)]*G[{0}, yw]*G[{1}, yv^(-1)]*G[{1}, yw]*
       G[{1/(yu*yv)}, yw])/64 + (9*G[{0}, yv^(-1)]*G[{0}, yw]*G[{1}, yv^(-1)]*
       G[{1}, yw]*G[{1/(yu*yv)}, yw])/64 - 
     (9*G[{0}, yw]^2*G[{1}, yv^(-1)]*G[{1}, yw]*G[{1/(yu*yv)}, yw])/128 + 
     (G[{0}, yu^(-1)]*G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*G[{1}, yw]*
       G[{1/(yu*yv)}, yw])/16 + (G[{0}, yv^(-1)]*G[{1}, yu^(-1)]*
       G[{1}, yv^(-1)]*G[{1}, yw]*G[{1/(yu*yv)}, yw])/16 - 
     (G[{0}, yw]*G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*G[{1}, yw]*
       G[{1/(yu*yv)}, yw])/16 + (G[{1}, yu^(-1)]^2*G[{1}, yv^(-1)]*G[{1}, yw]*
       G[{1/(yu*yv)}, yw])/32 + (9*G[{0}, yu^(-1)]*G[{1}, yv^(-1)]^2*
       G[{1}, yw]*G[{1/(yu*yv)}, yw])/128 + 
     (9*G[{0}, yv^(-1)]*G[{1}, yv^(-1)]^2*G[{1}, yw]*G[{1/(yu*yv)}, yw])/
      128 - (9*G[{0}, yw]*G[{1}, yv^(-1)]^2*G[{1}, yw]*G[{1/(yu*yv)}, yw])/
      128 - (7*G[{1}, yu^(-1)]*G[{1}, yv^(-1)]^2*G[{1}, yw]*
       G[{1/(yu*yv)}, yw])/128 - (3*G[{1}, yv^(-1)]^3*G[{1}, yw]*
       G[{1/(yu*yv)}, yw])/128 + (7*Pi^2*G[{1}, yw]^2*G[{1/(yu*yv)}, yw])/
      768 + (9*G[{0}, yu^(-1)]^2*G[{1}, yw]^2*G[{1/(yu*yv)}, yw])/256 + 
     (9*G[{0}, yu^(-1)]*G[{0}, yv^(-1)]*G[{1}, yw]^2*G[{1/(yu*yv)}, yw])/
      128 + (9*G[{0}, yv^(-1)]^2*G[{1}, yw]^2*G[{1/(yu*yv)}, yw])/256 - 
     (9*G[{0}, yu^(-1)]*G[{0}, yw]*G[{1}, yw]^2*G[{1/(yu*yv)}, yw])/128 - 
     (9*G[{0}, yv^(-1)]*G[{0}, yw]*G[{1}, yw]^2*G[{1/(yu*yv)}, yw])/128 + 
     (9*G[{0}, yw]^2*G[{1}, yw]^2*G[{1/(yu*yv)}, yw])/256 - 
     (G[{0}, yu^(-1)]*G[{1}, yu^(-1)]*G[{1}, yw]^2*G[{1/(yu*yv)}, yw])/32 - 
     (G[{0}, yv^(-1)]*G[{1}, yu^(-1)]*G[{1}, yw]^2*G[{1/(yu*yv)}, yw])/32 + 
     (G[{0}, yw]*G[{1}, yu^(-1)]*G[{1}, yw]^2*G[{1/(yu*yv)}, yw])/32 - 
     (G[{1}, yu^(-1)]^2*G[{1}, yw]^2*G[{1/(yu*yv)}, yw])/256 - 
     (9*G[{0}, yu^(-1)]*G[{1}, yv^(-1)]*G[{1}, yw]^2*G[{1/(yu*yv)}, yw])/
      128 - (9*G[{0}, yv^(-1)]*G[{1}, yv^(-1)]*G[{1}, yw]^2*
       G[{1/(yu*yv)}, yw])/128 + (9*G[{0}, yw]*G[{1}, yv^(-1)]*G[{1}, yw]^2*
       G[{1/(yu*yv)}, yw])/128 + (G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*
       G[{1}, yw]^2*G[{1/(yu*yv)}, yw])/16 + 
     (9*G[{1}, yv^(-1)]^2*G[{1}, yw]^2*G[{1/(yu*yv)}, yw])/256 + 
     (G[{0}, yu^(-1)]*G[{1}, yw]^3*G[{1/(yu*yv)}, yw])/96 + 
     (G[{0}, yv^(-1)]*G[{1}, yw]^3*G[{1/(yu*yv)}, yw])/96 - 
     (G[{0}, yw]*G[{1}, yw]^3*G[{1/(yu*yv)}, yw])/96 - 
     (G[{1}, yu^(-1)]*G[{1}, yw]^3*G[{1/(yu*yv)}, yw])/96 - 
     (G[{1}, yv^(-1)]*G[{1}, yw]^3*G[{1/(yu*yv)}, yw])/96 - 
     (29*Pi^2*G[{0}, yu^(-1)]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw])/768 - 
     (29*Pi^2*G[{0}, yv^(-1)]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw])/768 + 
     (29*Pi^2*G[{0}, yw]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw])/768 + 
     (5*Pi^2*G[{1}, yu^(-1)]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw])/768 - 
     (3*G[{0}, yu^(-1)]^2*G[{1}, yu^(-1)]*G[{yu^(-1)}, yw]*
       G[{1/(yu*yv)}, yw])/32 - (3*G[{0}, yu^(-1)]*G[{0}, yv^(-1)]*
       G[{1}, yu^(-1)]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw])/16 - 
     (3*G[{0}, yv^(-1)]^2*G[{1}, yu^(-1)]*G[{yu^(-1)}, yw]*
       G[{1/(yu*yv)}, yw])/32 + (3*G[{0}, yu^(-1)]*G[{0}, yw]*G[{1}, yu^(-1)]*
       G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw])/16 + 
     (3*G[{0}, yv^(-1)]*G[{0}, yw]*G[{1}, yu^(-1)]*G[{yu^(-1)}, yw]*
       G[{1/(yu*yv)}, yw])/16 - (3*G[{0}, yw]^2*G[{1}, yu^(-1)]*
       G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw])/32 + 
     (9*G[{0}, yu^(-1)]*G[{1}, yu^(-1)]^2*G[{yu^(-1)}, yw]*
       G[{1/(yu*yv)}, yw])/64 + (9*G[{0}, yv^(-1)]*G[{1}, yu^(-1)]^2*
       G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw])/64 - 
     (9*G[{0}, yw]*G[{1}, yu^(-1)]^2*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw])/
      64 - (3*G[{1}, yu^(-1)]^3*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw])/64 + 
     (53*Pi^2*G[{1}, yv^(-1)]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw])/768 + 
     (3*G[{0}, yu^(-1)]^2*G[{1}, yv^(-1)]*G[{yu^(-1)}, yw]*
       G[{1/(yu*yv)}, yw])/32 + (3*G[{0}, yu^(-1)]*G[{0}, yv^(-1)]*
       G[{1}, yv^(-1)]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw])/16 + 
     (3*G[{0}, yv^(-1)]^2*G[{1}, yv^(-1)]*G[{yu^(-1)}, yw]*
       G[{1/(yu*yv)}, yw])/32 - (3*G[{0}, yu^(-1)]*G[{0}, yw]*G[{1}, yv^(-1)]*
       G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw])/16 - 
     (3*G[{0}, yv^(-1)]*G[{0}, yw]*G[{1}, yv^(-1)]*G[{yu^(-1)}, yw]*
       G[{1/(yu*yv)}, yw])/16 + (3*G[{0}, yw]^2*G[{1}, yv^(-1)]*
       G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw])/32 + 
     (3*G[{0}, yu^(-1)]*G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*G[{yu^(-1)}, yw]*
       G[{1/(yu*yv)}, yw])/32 + (3*G[{0}, yv^(-1)]*G[{1}, yu^(-1)]*
       G[{1}, yv^(-1)]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw])/32 - 
     (3*G[{0}, yw]*G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*G[{yu^(-1)}, yw]*
       G[{1/(yu*yv)}, yw])/32 - (9*G[{1}, yu^(-1)]^2*G[{1}, yv^(-1)]*
       G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw])/64 - 
     (5*G[{0}, yu^(-1)]*G[{1}, yv^(-1)]^2*G[{yu^(-1)}, yw]*
       G[{1/(yu*yv)}, yw])/32 - (5*G[{0}, yv^(-1)]*G[{1}, yv^(-1)]^2*
       G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw])/32 + 
     (5*G[{0}, yw]*G[{1}, yv^(-1)]^2*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw])/
      32 + (G[{1}, yu^(-1)]*G[{1}, yv^(-1)]^2*G[{yu^(-1)}, yw]*
       G[{1/(yu*yv)}, yw])/32 + (G[{1}, yv^(-1)]^3*G[{yu^(-1)}, yw]*
       G[{1/(yu*yv)}, yw])/16 + (Pi^2*G[{1}, yw]*G[{yu^(-1)}, yw]*
       G[{1/(yu*yv)}, yw])/192 + (3*G[{0}, yu^(-1)]^2*G[{1}, yw]*
       G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw])/64 + 
     (3*G[{0}, yu^(-1)]*G[{0}, yv^(-1)]*G[{1}, yw]*G[{yu^(-1)}, yw]*
       G[{1/(yu*yv)}, yw])/32 + (3*G[{0}, yv^(-1)]^2*G[{1}, yw]*
       G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw])/64 - 
     (3*G[{0}, yu^(-1)]*G[{0}, yw]*G[{1}, yw]*G[{yu^(-1)}, yw]*
       G[{1/(yu*yv)}, yw])/32 - (3*G[{0}, yv^(-1)]*G[{0}, yw]*G[{1}, yw]*
       G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw])/32 + 
     (3*G[{0}, yw]^2*G[{1}, yw]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw])/64 - 
     (3*G[{1}, yu^(-1)]^2*G[{1}, yw]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw])/
      64 + (G[{0}, yu^(-1)]*G[{1}, yv^(-1)]*G[{1}, yw]*G[{yu^(-1)}, yw]*
       G[{1/(yu*yv)}, yw])/32 + (G[{0}, yv^(-1)]*G[{1}, yv^(-1)]*G[{1}, yw]*
       G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw])/32 - 
     (G[{0}, yw]*G[{1}, yv^(-1)]*G[{1}, yw]*G[{yu^(-1)}, yw]*
       G[{1/(yu*yv)}, yw])/32 - (G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*G[{1}, yw]*
       G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw])/8 - 
     (3*G[{1}, yv^(-1)]^2*G[{1}, yw]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw])/
      64 + (G[{0}, yu^(-1)]*G[{1}, yw]^2*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw])/
      8 + (G[{0}, yv^(-1)]*G[{1}, yw]^2*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw])/
      8 - (G[{0}, yw]*G[{1}, yw]^2*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw])/8 - 
     (3*G[{1}, yu^(-1)]*G[{1}, yw]^2*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw])/
      32 - (G[{1}, yv^(-1)]*G[{1}, yw]^2*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw])/
      16 + (G[{1}, yw]^3*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw])/32 - 
     (19*Pi^2*G[{yu^(-1)}, yw]^2*G[{1/(yu*yv)}, yw])/512 - 
     (9*G[{0}, yu^(-1)]^2*G[{yu^(-1)}, yw]^2*G[{1/(yu*yv)}, yw])/128 - 
     (9*G[{0}, yu^(-1)]*G[{0}, yv^(-1)]*G[{yu^(-1)}, yw]^2*
       G[{1/(yu*yv)}, yw])/64 - (9*G[{0}, yv^(-1)]^2*G[{yu^(-1)}, yw]^2*
       G[{1/(yu*yv)}, yw])/128 + (9*G[{0}, yu^(-1)]*G[{0}, yw]*
       G[{yu^(-1)}, yw]^2*G[{1/(yu*yv)}, yw])/64 + 
     (9*G[{0}, yv^(-1)]*G[{0}, yw]*G[{yu^(-1)}, yw]^2*G[{1/(yu*yv)}, yw])/
      64 - (9*G[{0}, yw]^2*G[{yu^(-1)}, yw]^2*G[{1/(yu*yv)}, yw])/128 - 
     (3*G[{0}, yu^(-1)]*G[{1}, yu^(-1)]*G[{yu^(-1)}, yw]^2*
       G[{1/(yu*yv)}, yw])/64 - (3*G[{0}, yv^(-1)]*G[{1}, yu^(-1)]*
       G[{yu^(-1)}, yw]^2*G[{1/(yu*yv)}, yw])/64 + 
     (3*G[{0}, yw]*G[{1}, yu^(-1)]*G[{yu^(-1)}, yw]^2*G[{1/(yu*yv)}, yw])/
      64 + (3*G[{1}, yu^(-1)]^2*G[{yu^(-1)}, yw]^2*G[{1/(yu*yv)}, yw])/32 + 
     (21*G[{0}, yu^(-1)]*G[{1}, yv^(-1)]*G[{yu^(-1)}, yw]^2*
       G[{1/(yu*yv)}, yw])/64 + (21*G[{0}, yv^(-1)]*G[{1}, yv^(-1)]*
       G[{yu^(-1)}, yw]^2*G[{1/(yu*yv)}, yw])/64 - 
     (21*G[{0}, yw]*G[{1}, yv^(-1)]*G[{yu^(-1)}, yw]^2*G[{1/(yu*yv)}, yw])/
      64 - (3*G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*G[{yu^(-1)}, yw]^2*
       G[{1/(yu*yv)}, yw])/32 - (29*G[{1}, yv^(-1)]^2*G[{yu^(-1)}, yw]^2*
       G[{1/(yu*yv)}, yw])/128 + (G[{0}, yu^(-1)]*G[{1}, yw]*
       G[{yu^(-1)}, yw]^2*G[{1/(yu*yv)}, yw])/16 + 
     (G[{0}, yv^(-1)]*G[{1}, yw]*G[{yu^(-1)}, yw]^2*G[{1/(yu*yv)}, yw])/16 - 
     (G[{0}, yw]*G[{1}, yw]*G[{yu^(-1)}, yw]^2*G[{1/(yu*yv)}, yw])/16 - 
     (3*G[{1}, yu^(-1)]*G[{1}, yw]*G[{yu^(-1)}, yw]^2*G[{1/(yu*yv)}, yw])/
      64 + (G[{1}, yv^(-1)]*G[{1}, yw]*G[{yu^(-1)}, yw]^2*G[{1/(yu*yv)}, yw])/
      16 + (9*G[{1}, yw]^2*G[{yu^(-1)}, yw]^2*G[{1/(yu*yv)}, yw])/128 - 
     (25*G[{0}, yu^(-1)]*G[{yu^(-1)}, yw]^3*G[{1/(yu*yv)}, yw])/192 - 
     (25*G[{0}, yv^(-1)]*G[{yu^(-1)}, yw]^3*G[{1/(yu*yv)}, yw])/192 + 
     (25*G[{0}, yw]*G[{yu^(-1)}, yw]^3*G[{1/(yu*yv)}, yw])/192 + 
     (3*G[{1}, yu^(-1)]*G[{yu^(-1)}, yw]^3*G[{1/(yu*yv)}, yw])/64 + 
     (41*G[{1}, yv^(-1)]*G[{yu^(-1)}, yw]^3*G[{1/(yu*yv)}, yw])/192 - 
     (41*G[{yu^(-1)}, yw]^4*G[{1/(yu*yv)}, yw])/768 - 
     (7*Pi^2*G[{0}, yu^(-1)]*G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw])/384 - 
     (3*G[{0}, yu^(-1)]^3*G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw])/128 - 
     (7*Pi^2*G[{0}, yv^(-1)]*G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw])/384 - 
     (9*G[{0}, yu^(-1)]^2*G[{0}, yv^(-1)]*G[{yu}, yv^(-1)]*
       G[{1/(yu*yv)}, yw])/128 - (9*G[{0}, yu^(-1)]*G[{0}, yv^(-1)]^2*
       G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw])/128 - 
     (3*G[{0}, yv^(-1)]^3*G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw])/128 + 
     (7*Pi^2*G[{0}, yw]*G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw])/384 + 
     (9*G[{0}, yu^(-1)]^2*G[{0}, yw]*G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw])/
      128 + (9*G[{0}, yu^(-1)]*G[{0}, yv^(-1)]*G[{0}, yw]*G[{yu}, yv^(-1)]*
       G[{1/(yu*yv)}, yw])/64 + (9*G[{0}, yv^(-1)]^2*G[{0}, yw]*
       G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw])/128 - 
     (9*G[{0}, yu^(-1)]*G[{0}, yw]^2*G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw])/
      128 - (9*G[{0}, yv^(-1)]*G[{0}, yw]^2*G[{yu}, yv^(-1)]*
       G[{1/(yu*yv)}, yw])/128 + (3*G[{0}, yw]^3*G[{yu}, yv^(-1)]*
       G[{1/(yu*yv)}, yw])/128 + (7*Pi^2*G[{1}, yu^(-1)]*G[{yu}, yv^(-1)]*
       G[{1/(yu*yv)}, yw])/384 + (G[{0}, yu^(-1)]^2*G[{1}, yu^(-1)]*
       G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw])/128 + 
     (G[{0}, yu^(-1)]*G[{0}, yv^(-1)]*G[{1}, yu^(-1)]*G[{yu}, yv^(-1)]*
       G[{1/(yu*yv)}, yw])/64 + (G[{0}, yv^(-1)]^2*G[{1}, yu^(-1)]*
       G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw])/128 - 
     (G[{0}, yu^(-1)]*G[{0}, yw]*G[{1}, yu^(-1)]*G[{yu}, yv^(-1)]*
       G[{1/(yu*yv)}, yw])/64 - (G[{0}, yv^(-1)]*G[{0}, yw]*G[{1}, yu^(-1)]*
       G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw])/64 + 
     (G[{0}, yw]^2*G[{1}, yu^(-1)]*G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw])/128 + 
     (7*G[{0}, yu^(-1)]*G[{1}, yu^(-1)]^2*G[{yu}, yv^(-1)]*
       G[{1/(yu*yv)}, yw])/128 + (7*G[{0}, yv^(-1)]*G[{1}, yu^(-1)]^2*
       G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw])/128 - 
     (7*G[{0}, yw]*G[{1}, yu^(-1)]^2*G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw])/
      128 - (5*G[{1}, yu^(-1)]^3*G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw])/128 - 
     (Pi^2*G[{1}, yv^(-1)]*G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw])/384 - 
     (3*G[{0}, yu^(-1)]^2*G[{1}, yv^(-1)]*G[{yu}, yv^(-1)]*
       G[{1/(yu*yv)}, yw])/128 - (3*G[{0}, yu^(-1)]*G[{0}, yv^(-1)]*
       G[{1}, yv^(-1)]*G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw])/64 - 
     (3*G[{0}, yv^(-1)]^2*G[{1}, yv^(-1)]*G[{yu}, yv^(-1)]*
       G[{1/(yu*yv)}, yw])/128 + (3*G[{0}, yu^(-1)]*G[{0}, yw]*
       G[{1}, yv^(-1)]*G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw])/64 + 
     (3*G[{0}, yv^(-1)]*G[{0}, yw]*G[{1}, yv^(-1)]*G[{yu}, yv^(-1)]*
       G[{1/(yu*yv)}, yw])/64 - (3*G[{0}, yw]^2*G[{1}, yv^(-1)]*
       G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw])/128 + 
     (11*G[{0}, yu^(-1)]*G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*G[{yu}, yv^(-1)]*
       G[{1/(yu*yv)}, yw])/64 + (11*G[{0}, yv^(-1)]*G[{1}, yu^(-1)]*
       G[{1}, yv^(-1)]*G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw])/64 - 
     (11*G[{0}, yw]*G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*G[{yu}, yv^(-1)]*
       G[{1/(yu*yv)}, yw])/64 - (19*G[{1}, yu^(-1)]^2*G[{1}, yv^(-1)]*
       G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw])/128 + 
     (11*G[{0}, yu^(-1)]*G[{1}, yv^(-1)]^2*G[{yu}, yv^(-1)]*
       G[{1/(yu*yv)}, yw])/128 + (11*G[{0}, yv^(-1)]*G[{1}, yv^(-1)]^2*
       G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw])/128 - 
     (11*G[{0}, yw]*G[{1}, yv^(-1)]^2*G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw])/
      128 - (11*G[{1}, yu^(-1)]*G[{1}, yv^(-1)]^2*G[{yu}, yv^(-1)]*
       G[{1/(yu*yv)}, yw])/128 - (5*G[{1}, yv^(-1)]^3*G[{yu}, yv^(-1)]*
       G[{1/(yu*yv)}, yw])/128 - (Pi^2*G[{1}, yw]*G[{yu}, yv^(-1)]*
       G[{1/(yu*yv)}, yw])/48 - (3*G[{0}, yu^(-1)]^2*G[{1}, yw]*
       G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw])/32 - 
     (3*G[{0}, yu^(-1)]*G[{0}, yv^(-1)]*G[{1}, yw]*G[{yu}, yv^(-1)]*
       G[{1/(yu*yv)}, yw])/16 - (3*G[{0}, yv^(-1)]^2*G[{1}, yw]*
       G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw])/32 + 
     (3*G[{0}, yu^(-1)]*G[{0}, yw]*G[{1}, yw]*G[{yu}, yv^(-1)]*
       G[{1/(yu*yv)}, yw])/16 + (3*G[{0}, yv^(-1)]*G[{0}, yw]*G[{1}, yw]*
       G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw])/16 - 
     (3*G[{0}, yw]^2*G[{1}, yw]*G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw])/32 + 
     (G[{0}, yu^(-1)]*G[{1}, yu^(-1)]*G[{1}, yw]*G[{yu}, yv^(-1)]*
       G[{1/(yu*yv)}, yw])/8 + (G[{0}, yv^(-1)]*G[{1}, yu^(-1)]*G[{1}, yw]*
       G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw])/8 - 
     (G[{0}, yw]*G[{1}, yu^(-1)]*G[{1}, yw]*G[{yu}, yv^(-1)]*
       G[{1/(yu*yv)}, yw])/8 - (G[{1}, yu^(-1)]^2*G[{1}, yw]*G[{yu}, yv^(-1)]*
       G[{1/(yu*yv)}, yw])/32 + (G[{1}, yv^(-1)]^2*G[{1}, yw]*
       G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw])/16 - 
     (5*G[{0}, yu^(-1)]*G[{1}, yw]^2*G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw])/
      128 - (5*G[{0}, yv^(-1)]*G[{1}, yw]^2*G[{yu}, yv^(-1)]*
       G[{1/(yu*yv)}, yw])/128 + (5*G[{0}, yw]*G[{1}, yw]^2*G[{yu}, yv^(-1)]*
       G[{1/(yu*yv)}, yw])/128 + (G[{1}, yu^(-1)]*G[{1}, yw]^2*
       G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw])/128 + 
     (G[{1}, yv^(-1)]*G[{1}, yw]^2*G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw])/128 - 
     (7*G[{0}, yu^(-1)]*G[{1}, yw]*G[{yu^(-1)}, yw]*G[{yu}, yv^(-1)]*
       G[{1/(yu*yv)}, yw])/32 - (7*G[{0}, yv^(-1)]*G[{1}, yw]*
       G[{yu^(-1)}, yw]*G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw])/32 + 
     (7*G[{0}, yw]*G[{1}, yw]*G[{yu^(-1)}, yw]*G[{yu}, yv^(-1)]*
       G[{1/(yu*yv)}, yw])/32 + (7*G[{1}, yu^(-1)]*G[{1}, yw]*
       G[{yu^(-1)}, yw]*G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw])/32 + 
     (G[{1}, yv^(-1)]*G[{1}, yw]*G[{yu^(-1)}, yw]*G[{yu}, yv^(-1)]*
       G[{1/(yu*yv)}, yw])/32 - (3*G[{1}, yw]^2*G[{yu^(-1)}, yw]*
       G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw])/32 - 
     (9*G[{1}, yw]*G[{yu^(-1)}, yw]^2*G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw])/
      64 + (Pi^2*G[{yu}, yv^(-1)]^2*G[{1/(yu*yv)}, yw])/96 + 
     (5*G[{0}, yu^(-1)]^2*G[{yu}, yv^(-1)]^2*G[{1/(yu*yv)}, yw])/64 + 
     (5*G[{0}, yu^(-1)]*G[{0}, yv^(-1)]*G[{yu}, yv^(-1)]^2*
       G[{1/(yu*yv)}, yw])/32 + (5*G[{0}, yv^(-1)]^2*G[{yu}, yv^(-1)]^2*
       G[{1/(yu*yv)}, yw])/64 - (5*G[{0}, yu^(-1)]*G[{0}, yw]*
       G[{yu}, yv^(-1)]^2*G[{1/(yu*yv)}, yw])/32 - 
     (5*G[{0}, yv^(-1)]*G[{0}, yw]*G[{yu}, yv^(-1)]^2*G[{1/(yu*yv)}, yw])/
      32 + (5*G[{0}, yw]^2*G[{yu}, yv^(-1)]^2*G[{1/(yu*yv)}, yw])/64 - 
     (5*G[{0}, yu^(-1)]*G[{1}, yu^(-1)]*G[{yu}, yv^(-1)]^2*
       G[{1/(yu*yv)}, yw])/32 - (5*G[{0}, yv^(-1)]*G[{1}, yu^(-1)]*
       G[{yu}, yv^(-1)]^2*G[{1/(yu*yv)}, yw])/32 + 
     (5*G[{0}, yw]*G[{1}, yu^(-1)]*G[{yu}, yv^(-1)]^2*G[{1/(yu*yv)}, yw])/
      32 + (5*G[{1}, yu^(-1)]^2*G[{yu}, yv^(-1)]^2*G[{1/(yu*yv)}, yw])/64 - 
     (G[{0}, yu^(-1)]*G[{1}, yv^(-1)]*G[{yu}, yv^(-1)]^2*G[{1/(yu*yv)}, yw])/
      32 - (G[{0}, yv^(-1)]*G[{1}, yv^(-1)]*G[{yu}, yv^(-1)]^2*
       G[{1/(yu*yv)}, yw])/32 + (G[{0}, yw]*G[{1}, yv^(-1)]*
       G[{yu}, yv^(-1)]^2*G[{1/(yu*yv)}, yw])/32 - 
     (G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*G[{yu}, yv^(-1)]^2*G[{1/(yu*yv)}, yw])/
      32 - (G[{1}, yv^(-1)]^2*G[{yu}, yv^(-1)]^2*G[{1/(yu*yv)}, yw])/64 + 
     (G[{0}, yu^(-1)]*G[{1}, yw]*G[{yu}, yv^(-1)]^2*G[{1/(yu*yv)}, yw])/8 + 
     (G[{0}, yv^(-1)]*G[{1}, yw]*G[{yu}, yv^(-1)]^2*G[{1/(yu*yv)}, yw])/8 - 
     (G[{0}, yw]*G[{1}, yw]*G[{yu}, yv^(-1)]^2*G[{1/(yu*yv)}, yw])/8 - 
     (3*G[{1}, yu^(-1)]*G[{1}, yw]*G[{yu}, yv^(-1)]^2*G[{1/(yu*yv)}, yw])/
      32 + (G[{1}, yw]^2*G[{yu}, yv^(-1)]^2*G[{1/(yu*yv)}, yw])/32 + 
     (3*G[{1}, yw]*G[{yu^(-1)}, yw]*G[{yu}, yv^(-1)]^2*G[{1/(yu*yv)}, yw])/
      32 - (G[{0}, yu^(-1)]*G[{yu}, yv^(-1)]^3*G[{1/(yu*yv)}, yw])/24 - 
     (G[{0}, yv^(-1)]*G[{yu}, yv^(-1)]^3*G[{1/(yu*yv)}, yw])/24 + 
     (G[{0}, yw]*G[{yu}, yv^(-1)]^3*G[{1/(yu*yv)}, yw])/24 + 
     (G[{1}, yu^(-1)]*G[{yu}, yv^(-1)]^3*G[{1/(yu*yv)}, yw])/16 - 
     (5*G[{1}, yw]*G[{yu}, yv^(-1)]^3*G[{1/(yu*yv)}, yw])/96 + 
     (G[{yu}, yv^(-1)]^4*G[{1/(yu*yv)}, yw])/192 - 
     (Pi^2*G[{0}, yu^(-1)]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw])/256 - 
     (3*G[{0}, yu^(-1)]^3*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw])/128 - 
     (Pi^2*G[{0}, yv^(-1)]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw])/256 - 
     (9*G[{0}, yu^(-1)]^2*G[{0}, yv^(-1)]*G[{yv^(-1)}, yw]*
       G[{1/(yu*yv)}, yw])/128 - (9*G[{0}, yu^(-1)]*G[{0}, yv^(-1)]^2*
       G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw])/128 - 
     (3*G[{0}, yv^(-1)]^3*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw])/128 + 
     (Pi^2*G[{0}, yw]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw])/256 + 
     (9*G[{0}, yu^(-1)]^2*G[{0}, yw]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw])/
      128 + (9*G[{0}, yu^(-1)]*G[{0}, yv^(-1)]*G[{0}, yw]*G[{yv^(-1)}, yw]*
       G[{1/(yu*yv)}, yw])/64 + (9*G[{0}, yv^(-1)]^2*G[{0}, yw]*
       G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw])/128 - 
     (9*G[{0}, yu^(-1)]*G[{0}, yw]^2*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw])/
      128 - (9*G[{0}, yv^(-1)]*G[{0}, yw]^2*G[{yv^(-1)}, yw]*
       G[{1/(yu*yv)}, yw])/128 + (3*G[{0}, yw]^3*G[{yv^(-1)}, yw]*
       G[{1/(yu*yv)}, yw])/128 + (Pi^2*G[{1}, yu^(-1)]*G[{yv^(-1)}, yw]*
       G[{1/(yu*yv)}, yw])/256 + (13*G[{0}, yu^(-1)]^2*G[{1}, yu^(-1)]*
       G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw])/128 + 
     (13*G[{0}, yu^(-1)]*G[{0}, yv^(-1)]*G[{1}, yu^(-1)]*G[{yv^(-1)}, yw]*
       G[{1/(yu*yv)}, yw])/64 + (13*G[{0}, yv^(-1)]^2*G[{1}, yu^(-1)]*
       G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw])/128 - 
     (13*G[{0}, yu^(-1)]*G[{0}, yw]*G[{1}, yu^(-1)]*G[{yv^(-1)}, yw]*
       G[{1/(yu*yv)}, yw])/64 - (13*G[{0}, yv^(-1)]*G[{0}, yw]*
       G[{1}, yu^(-1)]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw])/64 + 
     (13*G[{0}, yw]^2*G[{1}, yu^(-1)]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw])/
      128 - (23*G[{0}, yu^(-1)]*G[{1}, yu^(-1)]^2*G[{yv^(-1)}, yw]*
       G[{1/(yu*yv)}, yw])/128 - (23*G[{0}, yv^(-1)]*G[{1}, yu^(-1)]^2*
       G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw])/128 + 
     (23*G[{0}, yw]*G[{1}, yu^(-1)]^2*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw])/
      128 + (13*G[{1}, yu^(-1)]^3*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw])/128 + 
     (19*Pi^2*G[{1}, yv^(-1)]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw])/768 + 
     (9*G[{0}, yu^(-1)]^2*G[{1}, yv^(-1)]*G[{yv^(-1)}, yw]*
       G[{1/(yu*yv)}, yw])/128 + (9*G[{0}, yu^(-1)]*G[{0}, yv^(-1)]*
       G[{1}, yv^(-1)]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw])/64 + 
     (9*G[{0}, yv^(-1)]^2*G[{1}, yv^(-1)]*G[{yv^(-1)}, yw]*
       G[{1/(yu*yv)}, yw])/128 - (9*G[{0}, yu^(-1)]*G[{0}, yw]*
       G[{1}, yv^(-1)]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw])/64 - 
     (9*G[{0}, yv^(-1)]*G[{0}, yw]*G[{1}, yv^(-1)]*G[{yv^(-1)}, yw]*
       G[{1/(yu*yv)}, yw])/64 + (9*G[{0}, yw]^2*G[{1}, yv^(-1)]*
       G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw])/128 + 
     (G[{0}, yu^(-1)]*G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*G[{yv^(-1)}, yw]*
       G[{1/(yu*yv)}, yw])/64 + (G[{0}, yv^(-1)]*G[{1}, yu^(-1)]*
       G[{1}, yv^(-1)]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw])/64 - 
     (G[{0}, yw]*G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*G[{yv^(-1)}, yw]*
       G[{1/(yu*yv)}, yw])/64 - (5*G[{1}, yu^(-1)]^2*G[{1}, yv^(-1)]*
       G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw])/128 - 
     (9*G[{0}, yu^(-1)]*G[{1}, yv^(-1)]^2*G[{yv^(-1)}, yw]*
       G[{1/(yu*yv)}, yw])/128 - (9*G[{0}, yv^(-1)]*G[{1}, yv^(-1)]^2*
       G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw])/128 + 
     (9*G[{0}, yw]*G[{1}, yv^(-1)]^2*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw])/
      128 - (7*G[{1}, yu^(-1)]*G[{1}, yv^(-1)]^2*G[{yv^(-1)}, yw]*
       G[{1/(yu*yv)}, yw])/128 + (3*G[{1}, yv^(-1)]^3*G[{yv^(-1)}, yw]*
       G[{1/(yu*yv)}, yw])/128 + (Pi^2*G[{1}, yw]*G[{yv^(-1)}, yw]*
       G[{1/(yu*yv)}, yw])/128 - (11*G[{0}, yu^(-1)]^2*G[{1}, yw]*
       G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw])/128 - 
     (11*G[{0}, yu^(-1)]*G[{0}, yv^(-1)]*G[{1}, yw]*G[{yv^(-1)}, yw]*
       G[{1/(yu*yv)}, yw])/64 - (11*G[{0}, yv^(-1)]^2*G[{1}, yw]*
       G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw])/128 + 
     (11*G[{0}, yu^(-1)]*G[{0}, yw]*G[{1}, yw]*G[{yv^(-1)}, yw]*
       G[{1/(yu*yv)}, yw])/64 + (11*G[{0}, yv^(-1)]*G[{0}, yw]*G[{1}, yw]*
       G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw])/64 - 
     (11*G[{0}, yw]^2*G[{1}, yw]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw])/128 + 
     (17*G[{0}, yu^(-1)]*G[{1}, yu^(-1)]*G[{1}, yw]*G[{yv^(-1)}, yw]*
       G[{1/(yu*yv)}, yw])/64 + (17*G[{0}, yv^(-1)]*G[{1}, yu^(-1)]*
       G[{1}, yw]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw])/64 - 
     (17*G[{0}, yw]*G[{1}, yu^(-1)]*G[{1}, yw]*G[{yv^(-1)}, yw]*
       G[{1/(yu*yv)}, yw])/64 - (23*G[{1}, yu^(-1)]^2*G[{1}, yw]*
       G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw])/128 + 
     (11*G[{0}, yu^(-1)]*G[{1}, yv^(-1)]*G[{1}, yw]*G[{yv^(-1)}, yw]*
       G[{1/(yu*yv)}, yw])/64 + (11*G[{0}, yv^(-1)]*G[{1}, yv^(-1)]*
       G[{1}, yw]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw])/64 - 
     (11*G[{0}, yw]*G[{1}, yv^(-1)]*G[{1}, yw]*G[{yv^(-1)}, yw]*
       G[{1/(yu*yv)}, yw])/64 - (9*G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*G[{1}, yw]*
       G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw])/64 - 
     (11*G[{1}, yv^(-1)]^2*G[{1}, yw]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw])/
      128 - (3*G[{0}, yu^(-1)]*G[{1}, yw]^2*G[{yv^(-1)}, yw]*
       G[{1/(yu*yv)}, yw])/128 - (3*G[{0}, yv^(-1)]*G[{1}, yw]^2*
       G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw])/128 + 
     (3*G[{0}, yw]*G[{1}, yw]^2*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw])/128 + 
     (3*G[{1}, yu^(-1)]*G[{1}, yw]^2*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw])/
      128 + (3*G[{1}, yv^(-1)]*G[{1}, yw]^2*G[{yv^(-1)}, yw]*
       G[{1/(yu*yv)}, yw])/128 - (3*Pi^2*G[{yu^(-1)}, yw]*G[{yv^(-1)}, yw]*
       G[{1/(yu*yv)}, yw])/256 + (3*G[{0}, yu^(-1)]^2*G[{yu^(-1)}, yw]*
       G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw])/64 + 
     (3*G[{0}, yu^(-1)]*G[{0}, yv^(-1)]*G[{yu^(-1)}, yw]*G[{yv^(-1)}, yw]*
       G[{1/(yu*yv)}, yw])/32 + (3*G[{0}, yv^(-1)]^2*G[{yu^(-1)}, yw]*
       G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw])/64 - 
     (3*G[{0}, yu^(-1)]*G[{0}, yw]*G[{yu^(-1)}, yw]*G[{yv^(-1)}, yw]*
       G[{1/(yu*yv)}, yw])/32 - (3*G[{0}, yv^(-1)]*G[{0}, yw]*
       G[{yu^(-1)}, yw]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw])/32 + 
     (3*G[{0}, yw]^2*G[{yu^(-1)}, yw]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw])/
      64 - (7*G[{0}, yu^(-1)]*G[{1}, yu^(-1)]*G[{yu^(-1)}, yw]*
       G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw])/32 - 
     (7*G[{0}, yv^(-1)]*G[{1}, yu^(-1)]*G[{yu^(-1)}, yw]*G[{yv^(-1)}, yw]*
       G[{1/(yu*yv)}, yw])/32 + (7*G[{0}, yw]*G[{1}, yu^(-1)]*
       G[{yu^(-1)}, yw]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw])/32 + 
     (G[{1}, yu^(-1)]^2*G[{yu^(-1)}, yw]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw])/
      8 + (G[{0}, yu^(-1)]*G[{1}, yv^(-1)]*G[{yu^(-1)}, yw]*G[{yv^(-1)}, yw]*
       G[{1/(yu*yv)}, yw])/32 + (G[{0}, yv^(-1)]*G[{1}, yv^(-1)]*
       G[{yu^(-1)}, yw]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw])/32 - 
     (G[{0}, yw]*G[{1}, yv^(-1)]*G[{yu^(-1)}, yw]*G[{yv^(-1)}, yw]*
       G[{1/(yu*yv)}, yw])/32 + (3*G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*
       G[{yu^(-1)}, yw]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw])/16 - 
     (5*G[{1}, yv^(-1)]^2*G[{yu^(-1)}, yw]*G[{yv^(-1)}, yw]*
       G[{1/(yu*yv)}, yw])/64 + (G[{1}, yu^(-1)]*G[{1}, yw]*G[{yu^(-1)}, yw]*
       G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw])/32 + 
     (G[{1}, yv^(-1)]*G[{1}, yw]*G[{yu^(-1)}, yw]*G[{yv^(-1)}, yw]*
       G[{1/(yu*yv)}, yw])/8 + (5*G[{1}, yw]^2*G[{yu^(-1)}, yw]*
       G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw])/64 - 
     (G[{0}, yu^(-1)]*G[{yu^(-1)}, yw]^2*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw])/
      64 - (G[{0}, yv^(-1)]*G[{yu^(-1)}, yw]^2*G[{yv^(-1)}, yw]*
       G[{1/(yu*yv)}, yw])/64 + (G[{0}, yw]*G[{yu^(-1)}, yw]^2*
       G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw])/64 - 
     (7*G[{1}, yu^(-1)]*G[{yu^(-1)}, yw]^2*G[{yv^(-1)}, yw]*
       G[{1/(yu*yv)}, yw])/64 + (9*G[{1}, yv^(-1)]*G[{yu^(-1)}, yw]^2*
       G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw])/64 - 
     (3*G[{yu^(-1)}, yw]^3*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw])/64 - 
     (Pi^2*G[{yu}, yv^(-1)]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw])/48 - 
     (G[{0}, yu^(-1)]^2*G[{yu}, yv^(-1)]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw])/
      32 - (G[{0}, yu^(-1)]*G[{0}, yv^(-1)]*G[{yu}, yv^(-1)]*G[{yv^(-1)}, yw]*
       G[{1/(yu*yv)}, yw])/16 - (G[{0}, yv^(-1)]^2*G[{yu}, yv^(-1)]*
       G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw])/32 + 
     (G[{0}, yu^(-1)]*G[{0}, yw]*G[{yu}, yv^(-1)]*G[{yv^(-1)}, yw]*
       G[{1/(yu*yv)}, yw])/16 + (G[{0}, yv^(-1)]*G[{0}, yw]*G[{yu}, yv^(-1)]*
       G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw])/16 - 
     (G[{0}, yw]^2*G[{yu}, yv^(-1)]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw])/32 - 
     (G[{0}, yu^(-1)]*G[{1}, yu^(-1)]*G[{yu}, yv^(-1)]*G[{yv^(-1)}, yw]*
       G[{1/(yu*yv)}, yw])/16 - (G[{0}, yv^(-1)]*G[{1}, yu^(-1)]*
       G[{yu}, yv^(-1)]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw])/16 + 
     (G[{0}, yw]*G[{1}, yu^(-1)]*G[{yu}, yv^(-1)]*G[{yv^(-1)}, yw]*
       G[{1/(yu*yv)}, yw])/16 + (3*G[{1}, yu^(-1)]^2*G[{yu}, yv^(-1)]*
       G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw])/32 - 
     (G[{0}, yu^(-1)]*G[{1}, yv^(-1)]*G[{yu}, yv^(-1)]*G[{yv^(-1)}, yw]*
       G[{1/(yu*yv)}, yw])/16 - (G[{0}, yv^(-1)]*G[{1}, yv^(-1)]*
       G[{yu}, yv^(-1)]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw])/16 + 
     (G[{0}, yw]*G[{1}, yv^(-1)]*G[{yu}, yv^(-1)]*G[{yv^(-1)}, yw]*
       G[{1/(yu*yv)}, yw])/16 + (G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*
       G[{yu}, yv^(-1)]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw])/16 + 
     (3*G[{1}, yv^(-1)]^2*G[{yu}, yv^(-1)]*G[{yv^(-1)}, yw]*
       G[{1/(yu*yv)}, yw])/32 - (3*G[{0}, yu^(-1)]*G[{1}, yw]*
       G[{yu}, yv^(-1)]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw])/32 - 
     (3*G[{0}, yv^(-1)]*G[{1}, yw]*G[{yu}, yv^(-1)]*G[{yv^(-1)}, yw]*
       G[{1/(yu*yv)}, yw])/32 + (3*G[{0}, yw]*G[{1}, yw]*G[{yu}, yv^(-1)]*
       G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw])/32 - 
     (G[{1}, yu^(-1)]*G[{1}, yw]*G[{yu}, yv^(-1)]*G[{yv^(-1)}, yw]*
       G[{1/(yu*yv)}, yw])/32 - (G[{1}, yv^(-1)]*G[{1}, yw]*G[{yu}, yv^(-1)]*
       G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw])/32 - 
     (5*G[{1}, yw]*G[{yu^(-1)}, yw]*G[{yu}, yv^(-1)]*G[{yv^(-1)}, yw]*
       G[{1/(yu*yv)}, yw])/32 + (G[{0}, yu^(-1)]*G[{yu}, yv^(-1)]^2*
       G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw])/8 + 
     (G[{0}, yv^(-1)]*G[{yu}, yv^(-1)]^2*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw])/
      8 - (G[{0}, yw]*G[{yu}, yv^(-1)]^2*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw])/
      8 - (G[{1}, yu^(-1)]*G[{yu}, yv^(-1)]^2*G[{yv^(-1)}, yw]*
       G[{1/(yu*yv)}, yw])/16 + (G[{1}, yw]*G[{yu}, yv^(-1)]^2*
       G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw])/8 - 
     (G[{yu}, yv^(-1)]^3*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw])/16 + 
     (7*Pi^2*G[{yv^(-1)}, yw]^2*G[{1/(yu*yv)}, yw])/1536 + 
     (G[{0}, yu^(-1)]^2*G[{yv^(-1)}, yw]^2*G[{1/(yu*yv)}, yw])/128 + 
     (G[{0}, yu^(-1)]*G[{0}, yv^(-1)]*G[{yv^(-1)}, yw]^2*G[{1/(yu*yv)}, yw])/
      64 + (G[{0}, yv^(-1)]^2*G[{yv^(-1)}, yw]^2*G[{1/(yu*yv)}, yw])/128 - 
     (G[{0}, yu^(-1)]*G[{0}, yw]*G[{yv^(-1)}, yw]^2*G[{1/(yu*yv)}, yw])/64 - 
     (G[{0}, yv^(-1)]*G[{0}, yw]*G[{yv^(-1)}, yw]^2*G[{1/(yu*yv)}, yw])/64 + 
     (G[{0}, yw]^2*G[{yv^(-1)}, yw]^2*G[{1/(yu*yv)}, yw])/128 - 
     (G[{0}, yu^(-1)]*G[{1}, yu^(-1)]*G[{yv^(-1)}, yw]^2*G[{1/(yu*yv)}, yw])/
      64 - (G[{0}, yv^(-1)]*G[{1}, yu^(-1)]*G[{yv^(-1)}, yw]^2*
       G[{1/(yu*yv)}, yw])/64 + (G[{0}, yw]*G[{1}, yu^(-1)]*
       G[{yv^(-1)}, yw]^2*G[{1/(yu*yv)}, yw])/64 - 
     (G[{1}, yu^(-1)]^2*G[{yv^(-1)}, yw]^2*G[{1/(yu*yv)}, yw])/64 - 
     (G[{0}, yu^(-1)]*G[{1}, yv^(-1)]*G[{yv^(-1)}, yw]^2*G[{1/(yu*yv)}, yw])/
      64 - (G[{0}, yv^(-1)]*G[{1}, yv^(-1)]*G[{yv^(-1)}, yw]^2*
       G[{1/(yu*yv)}, yw])/64 + (G[{0}, yw]*G[{1}, yv^(-1)]*
       G[{yv^(-1)}, yw]^2*G[{1/(yu*yv)}, yw])/64 + 
     (G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*G[{yv^(-1)}, yw]^2*G[{1/(yu*yv)}, yw])/
      8 + (G[{1}, yv^(-1)]^2*G[{yv^(-1)}, yw]^2*G[{1/(yu*yv)}, yw])/128 - 
     (3*G[{0}, yu^(-1)]*G[{1}, yw]*G[{yv^(-1)}, yw]^2*G[{1/(yu*yv)}, yw])/
      32 - (3*G[{0}, yv^(-1)]*G[{1}, yw]*G[{yv^(-1)}, yw]^2*
       G[{1/(yu*yv)}, yw])/32 + (3*G[{0}, yw]*G[{1}, yw]*G[{yv^(-1)}, yw]^2*
       G[{1/(yu*yv)}, yw])/32 + (3*G[{1}, yu^(-1)]*G[{1}, yw]*
       G[{yv^(-1)}, yw]^2*G[{1/(yu*yv)}, yw])/64 + 
     (3*G[{1}, yv^(-1)]*G[{1}, yw]*G[{yv^(-1)}, yw]^2*G[{1/(yu*yv)}, yw])/
      32 - (3*G[{1}, yw]^2*G[{yv^(-1)}, yw]^2*G[{1/(yu*yv)}, yw])/128 + 
     (7*G[{0}, yu^(-1)]*G[{yu^(-1)}, yw]*G[{yv^(-1)}, yw]^2*
       G[{1/(yu*yv)}, yw])/64 + (7*G[{0}, yv^(-1)]*G[{yu^(-1)}, yw]*
       G[{yv^(-1)}, yw]^2*G[{1/(yu*yv)}, yw])/64 - 
     (7*G[{0}, yw]*G[{yu^(-1)}, yw]*G[{yv^(-1)}, yw]^2*G[{1/(yu*yv)}, yw])/
      64 - (7*G[{1}, yu^(-1)]*G[{yu^(-1)}, yw]*G[{yv^(-1)}, yw]^2*
       G[{1/(yu*yv)}, yw])/64 - (7*G[{1}, yv^(-1)]*G[{yu^(-1)}, yw]*
       G[{yv^(-1)}, yw]^2*G[{1/(yu*yv)}, yw])/64 + 
     (7*G[{yu^(-1)}, yw]^2*G[{yv^(-1)}, yw]^2*G[{1/(yu*yv)}, yw])/128 - 
     (G[{1}, yu^(-1)]*G[{yu}, yv^(-1)]*G[{yv^(-1)}, yw]^2*G[{1/(yu*yv)}, yw])/
      16 + (3*G[{1}, yw]*G[{yu}, yv^(-1)]*G[{yv^(-1)}, yw]^2*
       G[{1/(yu*yv)}, yw])/64 + (G[{yu}, yv^(-1)]^2*G[{yv^(-1)}, yw]^2*
       G[{1/(yu*yv)}, yw])/32 + (7*G[{0}, yu^(-1)]*G[{yv^(-1)}, yw]^3*
       G[{1/(yu*yv)}, yw])/192 + (7*G[{0}, yv^(-1)]*G[{yv^(-1)}, yw]^3*
       G[{1/(yu*yv)}, yw])/192 - (7*G[{0}, yw]*G[{yv^(-1)}, yw]^3*
       G[{1/(yu*yv)}, yw])/192 - (11*G[{1}, yu^(-1)]*G[{yv^(-1)}, yw]^3*
       G[{1/(yu*yv)}, yw])/192 - (7*G[{1}, yv^(-1)]*G[{yv^(-1)}, yw]^3*
       G[{1/(yu*yv)}, yw])/192 - (G[{1}, yw]*G[{yv^(-1)}, yw]^3*
       G[{1/(yu*yv)}, yw])/48 + (7*G[{yu^(-1)}, yw]*G[{yv^(-1)}, yw]^3*
       G[{1/(yu*yv)}, yw])/192 + (G[{yu}, yv^(-1)]*G[{yv^(-1)}, yw]^3*
       G[{1/(yu*yv)}, yw])/48 + (11*G[{yv^(-1)}, yw]^4*G[{1/(yu*yv)}, yw])/
      768 + (5*Pi^2*G[{0}, yu^(-1)]*G[{1/(yu*yv)}, yw]^2)/1536 + 
     (5*Pi^2*G[{0}, yv^(-1)]*G[{1/(yu*yv)}, yw]^2)/1536 - 
     (5*Pi^2*G[{0}, yw]*G[{1/(yu*yv)}, yw]^2)/1536 - 
     (Pi^2*G[{1}, yu^(-1)]*G[{1/(yu*yv)}, yw]^2)/1536 + 
     (7*G[{0}, yu^(-1)]^2*G[{1}, yu^(-1)]*G[{1/(yu*yv)}, yw]^2)/128 + 
     (7*G[{0}, yu^(-1)]*G[{0}, yv^(-1)]*G[{1}, yu^(-1)]*G[{1/(yu*yv)}, yw]^2)/
      64 + (7*G[{0}, yv^(-1)]^2*G[{1}, yu^(-1)]*G[{1/(yu*yv)}, yw]^2)/128 - 
     (7*G[{0}, yu^(-1)]*G[{0}, yw]*G[{1}, yu^(-1)]*G[{1/(yu*yv)}, yw]^2)/64 - 
     (7*G[{0}, yv^(-1)]*G[{0}, yw]*G[{1}, yu^(-1)]*G[{1/(yu*yv)}, yw]^2)/64 + 
     (7*G[{0}, yw]^2*G[{1}, yu^(-1)]*G[{1/(yu*yv)}, yw]^2)/128 - 
     (31*G[{0}, yu^(-1)]*G[{1}, yu^(-1)]^2*G[{1/(yu*yv)}, yw]^2)/256 - 
     (31*G[{0}, yv^(-1)]*G[{1}, yu^(-1)]^2*G[{1/(yu*yv)}, yw]^2)/256 + 
     (31*G[{0}, yw]*G[{1}, yu^(-1)]^2*G[{1/(yu*yv)}, yw]^2)/256 + 
     (17*G[{1}, yu^(-1)]^3*G[{1/(yu*yv)}, yw]^2)/256 - 
     (13*Pi^2*G[{1}, yv^(-1)]*G[{1/(yu*yv)}, yw]^2)/1536 - 
     (3*G[{0}, yu^(-1)]^2*G[{1}, yv^(-1)]*G[{1/(yu*yv)}, yw]^2)/64 - 
     (3*G[{0}, yu^(-1)]*G[{0}, yv^(-1)]*G[{1}, yv^(-1)]*G[{1/(yu*yv)}, yw]^2)/
      32 - (3*G[{0}, yv^(-1)]^2*G[{1}, yv^(-1)]*G[{1/(yu*yv)}, yw]^2)/64 + 
     (3*G[{0}, yu^(-1)]*G[{0}, yw]*G[{1}, yv^(-1)]*G[{1/(yu*yv)}, yw]^2)/32 + 
     (3*G[{0}, yv^(-1)]*G[{0}, yw]*G[{1}, yv^(-1)]*G[{1/(yu*yv)}, yw]^2)/32 - 
     (3*G[{0}, yw]^2*G[{1}, yv^(-1)]*G[{1/(yu*yv)}, yw]^2)/64 + 
     (5*G[{0}, yu^(-1)]*G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*G[{1/(yu*yv)}, yw]^2)/
      128 + (5*G[{0}, yv^(-1)]*G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*
       G[{1/(yu*yv)}, yw]^2)/128 - (5*G[{0}, yw]*G[{1}, yu^(-1)]*
       G[{1}, yv^(-1)]*G[{1/(yu*yv)}, yw]^2)/128 + 
     (5*G[{1}, yu^(-1)]^2*G[{1}, yv^(-1)]*G[{1/(yu*yv)}, yw]^2)/256 + 
     (5*G[{0}, yu^(-1)]*G[{1}, yv^(-1)]^2*G[{1/(yu*yv)}, yw]^2)/64 + 
     (5*G[{0}, yv^(-1)]*G[{1}, yv^(-1)]^2*G[{1/(yu*yv)}, yw]^2)/64 - 
     (5*G[{0}, yw]*G[{1}, yv^(-1)]^2*G[{1/(yu*yv)}, yw]^2)/64 - 
     (G[{1}, yu^(-1)]*G[{1}, yv^(-1)]^2*G[{1/(yu*yv)}, yw]^2)/8 - 
     (G[{1}, yv^(-1)]^3*G[{1/(yu*yv)}, yw]^2)/32 - 
     (Pi^2*G[{1}, yw]*G[{1/(yu*yv)}, yw]^2)/384 + 
     (G[{0}, yu^(-1)]^2*G[{1}, yw]*G[{1/(yu*yv)}, yw]^2)/128 + 
     (G[{0}, yu^(-1)]*G[{0}, yv^(-1)]*G[{1}, yw]*G[{1/(yu*yv)}, yw]^2)/64 + 
     (G[{0}, yv^(-1)]^2*G[{1}, yw]*G[{1/(yu*yv)}, yw]^2)/128 - 
     (G[{0}, yu^(-1)]*G[{0}, yw]*G[{1}, yw]*G[{1/(yu*yv)}, yw]^2)/64 - 
     (G[{0}, yv^(-1)]*G[{0}, yw]*G[{1}, yw]*G[{1/(yu*yv)}, yw]^2)/64 + 
     (G[{0}, yw]^2*G[{1}, yw]*G[{1/(yu*yv)}, yw]^2)/128 + 
     (9*G[{0}, yu^(-1)]*G[{1}, yu^(-1)]*G[{1}, yw]*G[{1/(yu*yv)}, yw]^2)/
      128 + (9*G[{0}, yv^(-1)]*G[{1}, yu^(-1)]*G[{1}, yw]*
       G[{1/(yu*yv)}, yw]^2)/128 - (9*G[{0}, yw]*G[{1}, yu^(-1)]*G[{1}, yw]*
       G[{1/(yu*yv)}, yw]^2)/128 - (5*G[{1}, yu^(-1)]^2*G[{1}, yw]*
       G[{1/(yu*yv)}, yw]^2)/64 - (G[{0}, yu^(-1)]*G[{1}, yv^(-1)]*G[{1}, yw]*
       G[{1/(yu*yv)}, yw]^2)/64 - (G[{0}, yv^(-1)]*G[{1}, yv^(-1)]*G[{1}, yw]*
       G[{1/(yu*yv)}, yw]^2)/64 + (G[{0}, yw]*G[{1}, yv^(-1)]*G[{1}, yw]*
       G[{1/(yu*yv)}, yw]^2)/64 - (13*G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*
       G[{1}, yw]*G[{1/(yu*yv)}, yw]^2)/128 + 
     (3*G[{1}, yv^(-1)]^2*G[{1}, yw]*G[{1/(yu*yv)}, yw]^2)/128 + 
     (13*G[{0}, yu^(-1)]*G[{1}, yw]^2*G[{1/(yu*yv)}, yw]^2)/256 + 
     (13*G[{0}, yv^(-1)]*G[{1}, yw]^2*G[{1/(yu*yv)}, yw]^2)/256 - 
     (13*G[{0}, yw]*G[{1}, yw]^2*G[{1/(yu*yv)}, yw]^2)/256 - 
     (9*G[{1}, yu^(-1)]*G[{1}, yw]^2*G[{1/(yu*yv)}, yw]^2)/256 - 
     (5*G[{1}, yv^(-1)]*G[{1}, yw]^2*G[{1/(yu*yv)}, yw]^2)/256 + 
     (G[{1}, yw]^3*G[{1/(yu*yv)}, yw]^2)/64 + 
     (13*Pi^2*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2)/1536 + 
     (3*G[{0}, yu^(-1)]^2*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2)/64 + 
     (3*G[{0}, yu^(-1)]*G[{0}, yv^(-1)]*G[{yu^(-1)}, yw]*
       G[{1/(yu*yv)}, yw]^2)/32 + (3*G[{0}, yv^(-1)]^2*G[{yu^(-1)}, yw]*
       G[{1/(yu*yv)}, yw]^2)/64 - (3*G[{0}, yu^(-1)]*G[{0}, yw]*
       G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2)/32 - 
     (3*G[{0}, yv^(-1)]*G[{0}, yw]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2)/
      32 + (3*G[{0}, yw]^2*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2)/64 - 
     (3*G[{0}, yu^(-1)]*G[{1}, yu^(-1)]*G[{yu^(-1)}, yw]*
       G[{1/(yu*yv)}, yw]^2)/32 - (3*G[{0}, yv^(-1)]*G[{1}, yu^(-1)]*
       G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2)/32 + 
     (3*G[{0}, yw]*G[{1}, yu^(-1)]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2)/
      32 + (9*G[{1}, yu^(-1)]^2*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2)/256 - 
     (G[{0}, yu^(-1)]*G[{1}, yv^(-1)]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2)/
      8 - (G[{0}, yv^(-1)]*G[{1}, yv^(-1)]*G[{yu^(-1)}, yw]*
       G[{1/(yu*yv)}, yw]^2)/8 + (G[{0}, yw]*G[{1}, yv^(-1)]*G[{yu^(-1)}, yw]*
       G[{1/(yu*yv)}, yw]^2)/8 + (27*G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*
       G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2)/128 + 
     (G[{1}, yv^(-1)]^2*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2)/16 - 
     (3*G[{0}, yu^(-1)]*G[{1}, yw]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2)/
      128 - (3*G[{0}, yv^(-1)]*G[{1}, yw]*G[{yu^(-1)}, yw]*
       G[{1/(yu*yv)}, yw]^2)/128 + (3*G[{0}, yw]*G[{1}, yw]*G[{yu^(-1)}, yw]*
       G[{1/(yu*yv)}, yw]^2)/128 + (G[{1}, yu^(-1)]*G[{1}, yw]*
       G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2)/32 + 
     (3*G[{1}, yv^(-1)]*G[{1}, yw]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2)/
      128 + (G[{1}, yw]^2*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2)/256 + 
     (15*G[{0}, yu^(-1)]*G[{yu^(-1)}, yw]^2*G[{1/(yu*yv)}, yw]^2)/256 + 
     (15*G[{0}, yv^(-1)]*G[{yu^(-1)}, yw]^2*G[{1/(yu*yv)}, yw]^2)/256 - 
     (15*G[{0}, yw]*G[{yu^(-1)}, yw]^2*G[{1/(yu*yv)}, yw]^2)/256 - 
     (19*G[{1}, yu^(-1)]*G[{yu^(-1)}, yw]^2*G[{1/(yu*yv)}, yw]^2)/256 - 
     (15*G[{1}, yv^(-1)]*G[{yu^(-1)}, yw]^2*G[{1/(yu*yv)}, yw]^2)/256 - 
     (G[{1}, yw]*G[{yu^(-1)}, yw]^2*G[{1/(yu*yv)}, yw]^2)/64 + 
     (5*G[{yu^(-1)}, yw]^3*G[{1/(yu*yv)}, yw]^2)/256 + 
     (Pi^2*G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw]^2)/384 - 
     (G[{0}, yu^(-1)]^2*G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw]^2)/128 - 
     (G[{0}, yu^(-1)]*G[{0}, yv^(-1)]*G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw]^2)/
      64 - (G[{0}, yv^(-1)]^2*G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw]^2)/128 + 
     (G[{0}, yu^(-1)]*G[{0}, yw]*G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw]^2)/64 + 
     (G[{0}, yv^(-1)]*G[{0}, yw]*G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw]^2)/64 - 
     (G[{0}, yw]^2*G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw]^2)/128 - 
     (G[{0}, yu^(-1)]*G[{1}, yu^(-1)]*G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw]^2)/
      64 - (G[{0}, yv^(-1)]*G[{1}, yu^(-1)]*G[{yu}, yv^(-1)]*
       G[{1/(yu*yv)}, yw]^2)/64 + (G[{0}, yw]*G[{1}, yu^(-1)]*
       G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw]^2)/64 + 
     (3*G[{1}, yu^(-1)]^2*G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw]^2)/128 - 
     (G[{0}, yu^(-1)]*G[{1}, yv^(-1)]*G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw]^2)/
      64 - (G[{0}, yv^(-1)]*G[{1}, yv^(-1)]*G[{yu}, yv^(-1)]*
       G[{1/(yu*yv)}, yw]^2)/64 + (G[{0}, yw]*G[{1}, yv^(-1)]*
       G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw]^2)/64 + 
     (9*G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*G[{yu}, yv^(-1)]*
       G[{1/(yu*yv)}, yw]^2)/64 + (G[{1}, yv^(-1)]^2*G[{yu}, yv^(-1)]*
       G[{1/(yu*yv)}, yw]^2)/128 - (11*G[{0}, yu^(-1)]*G[{1}, yw]*
       G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw]^2)/128 - 
     (11*G[{0}, yv^(-1)]*G[{1}, yw]*G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw]^2)/
      128 + (11*G[{0}, yw]*G[{1}, yw]*G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw]^2)/
      128 + (15*G[{1}, yu^(-1)]*G[{1}, yw]*G[{yu}, yv^(-1)]*
       G[{1/(yu*yv)}, yw]^2)/128 + (3*G[{1}, yv^(-1)]*G[{1}, yw]*
       G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw]^2)/128 - 
     (3*G[{1}, yw]^2*G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw]^2)/64 + 
     (G[{0}, yu^(-1)]*G[{yu^(-1)}, yw]*G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw]^2)/
      32 + (G[{0}, yv^(-1)]*G[{yu^(-1)}, yw]*G[{yu}, yv^(-1)]*
       G[{1/(yu*yv)}, yw]^2)/32 - (G[{0}, yw]*G[{yu^(-1)}, yw]*
       G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw]^2)/32 - 
     (3*G[{1}, yu^(-1)]*G[{yu^(-1)}, yw]*G[{yu}, yv^(-1)]*
       G[{1/(yu*yv)}, yw]^2)/32 - (G[{1}, yv^(-1)]*G[{yu^(-1)}, yw]*
       G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw]^2)/32 - 
     (G[{1}, yw]*G[{yu^(-1)}, yw]*G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw]^2)/
      128 + (G[{yu^(-1)}, yw]^2*G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw]^2)/64 + 
     (G[{0}, yu^(-1)]*G[{yu}, yv^(-1)]^2*G[{1/(yu*yv)}, yw]^2)/32 + 
     (G[{0}, yv^(-1)]*G[{yu}, yv^(-1)]^2*G[{1/(yu*yv)}, yw]^2)/32 - 
     (G[{0}, yw]*G[{yu}, yv^(-1)]^2*G[{1/(yu*yv)}, yw]^2)/32 - 
     (5*G[{1}, yu^(-1)]*G[{yu}, yv^(-1)]^2*G[{1/(yu*yv)}, yw]^2)/64 - 
     (G[{1}, yv^(-1)]*G[{yu}, yv^(-1)]^2*G[{1/(yu*yv)}, yw]^2)/32 + 
     (G[{1}, yw]*G[{yu}, yv^(-1)]^2*G[{1/(yu*yv)}, yw]^2)/64 + 
     (G[{yu^(-1)}, yw]*G[{yu}, yv^(-1)]^2*G[{1/(yu*yv)}, yw]^2)/32 + 
     (G[{yu}, yv^(-1)]^3*G[{1/(yu*yv)}, yw]^2)/64 + 
     (Pi^2*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2)/1536 - 
     (7*G[{0}, yu^(-1)]^2*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2)/128 - 
     (7*G[{0}, yu^(-1)]*G[{0}, yv^(-1)]*G[{yv^(-1)}, yw]*
       G[{1/(yu*yv)}, yw]^2)/64 - (7*G[{0}, yv^(-1)]^2*G[{yv^(-1)}, yw]*
       G[{1/(yu*yv)}, yw]^2)/128 + (7*G[{0}, yu^(-1)]*G[{0}, yw]*
       G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2)/64 + 
     (7*G[{0}, yv^(-1)]*G[{0}, yw]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2)/
      64 - (7*G[{0}, yw]^2*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2)/128 + 
     (13*G[{0}, yu^(-1)]*G[{1}, yu^(-1)]*G[{yv^(-1)}, yw]*
       G[{1/(yu*yv)}, yw]^2)/64 + (13*G[{0}, yv^(-1)]*G[{1}, yu^(-1)]*
       G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2)/64 - 
     (13*G[{0}, yw]*G[{1}, yu^(-1)]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2)/
      64 - (41*G[{1}, yu^(-1)]^2*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2)/256 - 
     (G[{0}, yu^(-1)]*G[{1}, yv^(-1)]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2)/
      64 - (G[{0}, yv^(-1)]*G[{1}, yv^(-1)]*G[{yv^(-1)}, yw]*
       G[{1/(yu*yv)}, yw]^2)/64 + (G[{0}, yw]*G[{1}, yv^(-1)]*
       G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2)/64 + 
     (5*G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*G[{yv^(-1)}, yw]*
       G[{1/(yu*yv)}, yw]^2)/128 + (5*G[{1}, yv^(-1)]^2*G[{yv^(-1)}, yw]*
       G[{1/(yu*yv)}, yw]^2)/128 - (13*G[{0}, yu^(-1)]*G[{1}, yw]*
       G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2)/128 - 
     (13*G[{0}, yv^(-1)]*G[{1}, yw]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2)/
      128 + (13*G[{0}, yw]*G[{1}, yw]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2)/
      128 + (13*G[{1}, yu^(-1)]*G[{1}, yw]*G[{yv^(-1)}, yw]*
       G[{1/(yu*yv)}, yw]^2)/64 + (21*G[{1}, yv^(-1)]*G[{1}, yw]*
       G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2)/128 + 
     (21*G[{1}, yw]^2*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2)/256 + 
     (11*G[{0}, yu^(-1)]*G[{yu^(-1)}, yw]*G[{yv^(-1)}, yw]*
       G[{1/(yu*yv)}, yw]^2)/128 + (11*G[{0}, yv^(-1)]*G[{yu^(-1)}, yw]*
       G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2)/128 - 
     (11*G[{0}, yw]*G[{yu^(-1)}, yw]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2)/
      128 - (15*G[{1}, yu^(-1)]*G[{yu^(-1)}, yw]*G[{yv^(-1)}, yw]*
       G[{1/(yu*yv)}, yw]^2)/128 - (19*G[{1}, yv^(-1)]*G[{yu^(-1)}, yw]*
       G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2)/128 - 
     (3*G[{1}, yw]*G[{yu^(-1)}, yw]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2)/
      32 + (19*G[{yu^(-1)}, yw]^2*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2)/
      256 + (G[{0}, yu^(-1)]*G[{yu}, yv^(-1)]*G[{yv^(-1)}, yw]*
       G[{1/(yu*yv)}, yw]^2)/32 + (G[{0}, yv^(-1)]*G[{yu}, yv^(-1)]*
       G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2)/32 - 
     (G[{0}, yw]*G[{yu}, yv^(-1)]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2)/32 - 
     (G[{1}, yu^(-1)]*G[{yu}, yv^(-1)]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2)/
      8 - (3*G[{1}, yv^(-1)]*G[{yu}, yv^(-1)]*G[{yv^(-1)}, yw]*
       G[{1/(yu*yv)}, yw]^2)/32 - (21*G[{1}, yw]*G[{yu}, yv^(-1)]*
       G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2)/128 + 
     (3*G[{yu^(-1)}, yw]*G[{yu}, yv^(-1)]*G[{yv^(-1)}, yw]*
       G[{1/(yu*yv)}, yw]^2)/32 + (5*G[{yu}, yv^(-1)]^2*G[{yv^(-1)}, yw]*
       G[{1/(yu*yv)}, yw]^2)/64 - (17*G[{0}, yu^(-1)]*G[{yv^(-1)}, yw]^2*
       G[{1/(yu*yv)}, yw]^2)/256 - (17*G[{0}, yv^(-1)]*G[{yv^(-1)}, yw]^2*
       G[{1/(yu*yv)}, yw]^2)/256 + (17*G[{0}, yw]*G[{yv^(-1)}, yw]^2*
       G[{1/(yu*yv)}, yw]^2)/256 + (33*G[{1}, yu^(-1)]*G[{yv^(-1)}, yw]^2*
       G[{1/(yu*yv)}, yw]^2)/256 - (15*G[{1}, yv^(-1)]*G[{yv^(-1)}, yw]^2*
       G[{1/(yu*yv)}, yw]^2)/256 - (G[{1}, yw]*G[{yv^(-1)}, yw]^2*
       G[{1/(yu*yv)}, yw]^2)/16 + (15*G[{yu^(-1)}, yw]*G[{yv^(-1)}, yw]^2*
       G[{1/(yu*yv)}, yw]^2)/256 + (G[{yu}, yv^(-1)]*G[{yv^(-1)}, yw]^2*
       G[{1/(yu*yv)}, yw]^2)/16 - (11*G[{yv^(-1)}, yw]^3*
       G[{1/(yu*yv)}, yw]^2)/256 + (5*G[{0}, yu^(-1)]*G[{1}, yu^(-1)]*
       G[{1/(yu*yv)}, yw]^3)/384 + (5*G[{0}, yv^(-1)]*G[{1}, yu^(-1)]*
       G[{1/(yu*yv)}, yw]^3)/384 - (5*G[{0}, yw]*G[{1}, yu^(-1)]*
       G[{1/(yu*yv)}, yw]^3)/384 - (5*G[{1}, yu^(-1)]^2*G[{1/(yu*yv)}, yw]^3)/
      384 - (G[{0}, yu^(-1)]*G[{1}, yv^(-1)]*G[{1/(yu*yv)}, yw]^3)/96 - 
     (G[{0}, yv^(-1)]*G[{1}, yv^(-1)]*G[{1/(yu*yv)}, yw]^3)/96 + 
     (G[{0}, yw]*G[{1}, yv^(-1)]*G[{1/(yu*yv)}, yw]^3)/96 - 
     (3*G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*G[{1/(yu*yv)}, yw]^3)/128 + 
     (G[{1}, yv^(-1)]^2*G[{1/(yu*yv)}, yw]^3)/96 + 
     (G[{0}, yu^(-1)]*G[{1}, yw]*G[{1/(yu*yv)}, yw]^3)/384 + 
     (G[{0}, yv^(-1)]*G[{1}, yw]*G[{1/(yu*yv)}, yw]^3)/384 - 
     (G[{0}, yw]*G[{1}, yw]*G[{1/(yu*yv)}, yw]^3)/384 - 
     (3*G[{1}, yu^(-1)]*G[{1}, yw]*G[{1/(yu*yv)}, yw]^3)/128 - 
     (3*G[{1}, yv^(-1)]*G[{1}, yw]*G[{1/(yu*yv)}, yw]^3)/128 - 
     (G[{1}, yw]^2*G[{1/(yu*yv)}, yw]^3)/48 + 
     (G[{0}, yu^(-1)]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]^3)/96 + 
     (G[{0}, yv^(-1)]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]^3)/96 - 
     (G[{0}, yw]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]^3)/96 + 
     (3*G[{1}, yu^(-1)]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]^3)/128 - 
     (G[{1}, yv^(-1)]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]^3)/48 + 
     (3*G[{1}, yw]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]^3)/128 + 
     (G[{yu^(-1)}, yw]^2*G[{1/(yu*yv)}, yw]^3)/96 - 
     (G[{0}, yu^(-1)]*G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw]^3)/384 - 
     (G[{0}, yv^(-1)]*G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw]^3)/384 + 
     (G[{0}, yw]*G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw]^3)/384 + 
     (3*G[{1}, yu^(-1)]*G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw]^3)/128 + 
     (3*G[{1}, yv^(-1)]*G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw]^3)/128 + 
     (G[{1}, yw]*G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw]^3)/24 - 
     (3*G[{yu^(-1)}, yw]*G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw]^3)/128 - 
     (G[{yu}, yv^(-1)]^2*G[{1/(yu*yv)}, yw]^3)/48 - 
     (5*G[{0}, yu^(-1)]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]^3)/384 - 
     (5*G[{0}, yv^(-1)]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]^3)/384 + 
     (5*G[{0}, yw]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]^3)/384 + 
     (5*G[{1}, yu^(-1)]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]^3)/192 + 
     (3*G[{1}, yv^(-1)]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]^3)/128 + 
     (3*G[{1}, yw]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]^3)/128 - 
     (3*G[{yu^(-1)}, yw]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]^3)/128 - 
     (3*G[{yu}, yv^(-1)]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]^3)/128 - 
     (5*G[{yv^(-1)}, yw]^2*G[{1/(yu*yv)}, yw]^3)/384 - 
     (Pi^2*G[{0}, yu^(-1)]*G[{0, 1}, yu^(-1)])/384 + 
     (3*G[{0}, yu^(-1)]^3*G[{0, 1}, yu^(-1)])/128 - 
     (Pi^2*G[{0}, yv^(-1)]*G[{0, 1}, yu^(-1)])/384 + 
     (9*G[{0}, yu^(-1)]^2*G[{0}, yv^(-1)]*G[{0, 1}, yu^(-1)])/128 + 
     (9*G[{0}, yu^(-1)]*G[{0}, yv^(-1)]^2*G[{0, 1}, yu^(-1)])/128 + 
     (3*G[{0}, yv^(-1)]^3*G[{0, 1}, yu^(-1)])/128 + 
     (Pi^2*G[{0}, yw]*G[{0, 1}, yu^(-1)])/384 - 
     (9*G[{0}, yu^(-1)]^2*G[{0}, yw]*G[{0, 1}, yu^(-1)])/128 - 
     (9*G[{0}, yu^(-1)]*G[{0}, yv^(-1)]*G[{0}, yw]*G[{0, 1}, yu^(-1)])/64 - 
     (9*G[{0}, yv^(-1)]^2*G[{0}, yw]*G[{0, 1}, yu^(-1)])/128 + 
     (9*G[{0}, yu^(-1)]*G[{0}, yw]^2*G[{0, 1}, yu^(-1)])/128 + 
     (9*G[{0}, yv^(-1)]*G[{0}, yw]^2*G[{0, 1}, yu^(-1)])/128 - 
     (3*G[{0}, yw]^3*G[{0, 1}, yu^(-1)])/128 + 
     (Pi^2*G[{1}, yu^(-1)]*G[{0, 1}, yu^(-1)])/384 - 
     (5*G[{0}, yu^(-1)]^2*G[{1}, yu^(-1)]*G[{0, 1}, yu^(-1)])/128 - 
     (5*G[{0}, yu^(-1)]*G[{0}, yv^(-1)]*G[{1}, yu^(-1)]*G[{0, 1}, yu^(-1)])/
      64 - (5*G[{0}, yv^(-1)]^2*G[{1}, yu^(-1)]*G[{0, 1}, yu^(-1)])/128 + 
     (5*G[{0}, yu^(-1)]*G[{0}, yw]*G[{1}, yu^(-1)]*G[{0, 1}, yu^(-1)])/64 + 
     (5*G[{0}, yv^(-1)]*G[{0}, yw]*G[{1}, yu^(-1)]*G[{0, 1}, yu^(-1)])/64 - 
     (5*G[{0}, yw]^2*G[{1}, yu^(-1)]*G[{0, 1}, yu^(-1)])/128 + 
     (5*G[{0}, yu^(-1)]*G[{1}, yu^(-1)]^2*G[{0, 1}, yu^(-1)])/128 + 
     (5*G[{0}, yv^(-1)]*G[{1}, yu^(-1)]^2*G[{0, 1}, yu^(-1)])/128 - 
     (5*G[{0}, yw]*G[{1}, yu^(-1)]^2*G[{0, 1}, yu^(-1)])/128 - 
     (5*G[{1}, yu^(-1)]^3*G[{0, 1}, yu^(-1)])/384 + 
     (Pi^2*G[{1}, yv^(-1)]*G[{0, 1}, yu^(-1)])/384 - 
     (G[{0}, yu^(-1)]^2*G[{1}, yv^(-1)]*G[{0, 1}, yu^(-1)])/128 - 
     (G[{0}, yu^(-1)]*G[{0}, yv^(-1)]*G[{1}, yv^(-1)]*G[{0, 1}, yu^(-1)])/
      64 - (G[{0}, yv^(-1)]^2*G[{1}, yv^(-1)]*G[{0, 1}, yu^(-1)])/128 + 
     (G[{0}, yu^(-1)]*G[{0}, yw]*G[{1}, yv^(-1)]*G[{0, 1}, yu^(-1)])/64 + 
     (G[{0}, yv^(-1)]*G[{0}, yw]*G[{1}, yv^(-1)]*G[{0, 1}, yu^(-1)])/64 - 
     (G[{0}, yw]^2*G[{1}, yv^(-1)]*G[{0, 1}, yu^(-1)])/128 + 
     (G[{0}, yu^(-1)]*G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*G[{0, 1}, yu^(-1)])/
      64 + (G[{0}, yv^(-1)]*G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*
       G[{0, 1}, yu^(-1)])/64 - (G[{0}, yw]*G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*
       G[{0, 1}, yu^(-1)])/64 - (5*G[{1}, yu^(-1)]^2*G[{1}, yv^(-1)]*
       G[{0, 1}, yu^(-1)])/128 - (11*G[{0}, yu^(-1)]*G[{1}, yv^(-1)]^2*
       G[{0, 1}, yu^(-1)])/128 - (11*G[{0}, yv^(-1)]*G[{1}, yv^(-1)]^2*
       G[{0, 1}, yu^(-1)])/128 + (11*G[{0}, yw]*G[{1}, yv^(-1)]^2*
       G[{0, 1}, yu^(-1)])/128 + (7*G[{1}, yu^(-1)]*G[{1}, yv^(-1)]^2*
       G[{0, 1}, yu^(-1)])/128 + (5*G[{1}, yv^(-1)]^3*G[{0, 1}, yu^(-1)])/
      128 - (Pi^2*G[{1}, yw]*G[{0, 1}, yu^(-1)])/384 + 
     (G[{0}, yu^(-1)]^2*G[{1}, yw]*G[{0, 1}, yu^(-1)])/128 + 
     (G[{0}, yu^(-1)]*G[{0}, yv^(-1)]*G[{1}, yw]*G[{0, 1}, yu^(-1)])/64 + 
     (G[{0}, yv^(-1)]^2*G[{1}, yw]*G[{0, 1}, yu^(-1)])/128 - 
     (G[{0}, yu^(-1)]*G[{0}, yw]*G[{1}, yw]*G[{0, 1}, yu^(-1)])/64 - 
     (G[{0}, yv^(-1)]*G[{0}, yw]*G[{1}, yw]*G[{0, 1}, yu^(-1)])/64 + 
     (G[{0}, yw]^2*G[{1}, yw]*G[{0, 1}, yu^(-1)])/128 - 
     (G[{0}, yu^(-1)]*G[{1}, yu^(-1)]*G[{1}, yw]*G[{0, 1}, yu^(-1)])/64 - 
     (G[{0}, yv^(-1)]*G[{1}, yu^(-1)]*G[{1}, yw]*G[{0, 1}, yu^(-1)])/64 + 
     (G[{0}, yw]*G[{1}, yu^(-1)]*G[{1}, yw]*G[{0, 1}, yu^(-1)])/64 + 
     (5*G[{1}, yu^(-1)]^2*G[{1}, yw]*G[{0, 1}, yu^(-1)])/128 + 
     (11*G[{0}, yu^(-1)]*G[{1}, yv^(-1)]*G[{1}, yw]*G[{0, 1}, yu^(-1)])/64 + 
     (11*G[{0}, yv^(-1)]*G[{1}, yv^(-1)]*G[{1}, yw]*G[{0, 1}, yu^(-1)])/64 - 
     (11*G[{0}, yw]*G[{1}, yv^(-1)]*G[{1}, yw]*G[{0, 1}, yu^(-1)])/64 - 
     (7*G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*G[{1}, yw]*G[{0, 1}, yu^(-1)])/64 - 
     (15*G[{1}, yv^(-1)]^2*G[{1}, yw]*G[{0, 1}, yu^(-1)])/128 - 
     (9*G[{0}, yu^(-1)]*G[{1}, yw]^2*G[{0, 1}, yu^(-1)])/128 - 
     (9*G[{0}, yv^(-1)]*G[{1}, yw]^2*G[{0, 1}, yu^(-1)])/128 + 
     (9*G[{0}, yw]*G[{1}, yw]^2*G[{0, 1}, yu^(-1)])/128 + 
     (5*G[{1}, yu^(-1)]*G[{1}, yw]^2*G[{0, 1}, yu^(-1)])/128 + 
     (13*G[{1}, yv^(-1)]*G[{1}, yw]^2*G[{0, 1}, yu^(-1)])/128 - 
     (G[{1}, yw]^3*G[{0, 1}, yu^(-1)])/96 - 
     (G[{0}, yu^(-1)]*G[{1}, yw]*G[{yu}, yv^(-1)]*G[{0, 1}, yu^(-1)])/16 - 
     (G[{0}, yv^(-1)]*G[{1}, yw]*G[{yu}, yv^(-1)]*G[{0, 1}, yu^(-1)])/16 + 
     (G[{0}, yw]*G[{1}, yw]*G[{yu}, yv^(-1)]*G[{0, 1}, yu^(-1)])/16 + 
     (G[{1}, yu^(-1)]*G[{1}, yw]*G[{yu}, yv^(-1)]*G[{0, 1}, yu^(-1)])/16 - 
     (G[{1}, yv^(-1)]*G[{1}, yw]*G[{yu}, yv^(-1)]*G[{0, 1}, yu^(-1)])/16 + 
     (G[{1}, yw]*G[{yu}, yv^(-1)]^2*G[{0, 1}, yu^(-1)])/16 - 
     (Pi^2*G[{1/(yu*yv)}, yw]*G[{0, 1}, yu^(-1)])/384 + 
     (5*G[{0}, yu^(-1)]^2*G[{1/(yu*yv)}, yw]*G[{0, 1}, yu^(-1)])/128 + 
     (5*G[{0}, yu^(-1)]*G[{0}, yv^(-1)]*G[{1/(yu*yv)}, yw]*
       G[{0, 1}, yu^(-1)])/64 + (5*G[{0}, yv^(-1)]^2*G[{1/(yu*yv)}, yw]*
       G[{0, 1}, yu^(-1)])/128 - (5*G[{0}, yu^(-1)]*G[{0}, yw]*
       G[{1/(yu*yv)}, yw]*G[{0, 1}, yu^(-1)])/64 - 
     (5*G[{0}, yv^(-1)]*G[{0}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1}, yu^(-1)])/
      64 + (5*G[{0}, yw]^2*G[{1/(yu*yv)}, yw]*G[{0, 1}, yu^(-1)])/128 - 
     (5*G[{0}, yu^(-1)]*G[{1}, yu^(-1)]*G[{1/(yu*yv)}, yw]*
       G[{0, 1}, yu^(-1)])/64 - (5*G[{0}, yv^(-1)]*G[{1}, yu^(-1)]*
       G[{1/(yu*yv)}, yw]*G[{0, 1}, yu^(-1)])/64 + 
     (5*G[{0}, yw]*G[{1}, yu^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, 1}, yu^(-1)])/
      64 + (5*G[{1}, yu^(-1)]^2*G[{1/(yu*yv)}, yw]*G[{0, 1}, yu^(-1)])/128 - 
     (5*G[{0}, yu^(-1)]*G[{1}, yv^(-1)]*G[{1/(yu*yv)}, yw]*
       G[{0, 1}, yu^(-1)])/64 - (5*G[{0}, yv^(-1)]*G[{1}, yv^(-1)]*
       G[{1/(yu*yv)}, yw]*G[{0, 1}, yu^(-1)])/64 + 
     (5*G[{0}, yw]*G[{1}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, 1}, yu^(-1)])/
      64 + (9*G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*G[{1/(yu*yv)}, yw]*
       G[{0, 1}, yu^(-1)])/64 - (7*G[{1}, yv^(-1)]^2*G[{1/(yu*yv)}, yw]*
       G[{0, 1}, yu^(-1)])/128 + (3*G[{0}, yu^(-1)]*G[{1}, yw]*
       G[{1/(yu*yv)}, yw]*G[{0, 1}, yu^(-1)])/64 + 
     (3*G[{0}, yv^(-1)]*G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1}, yu^(-1)])/
      64 - (3*G[{0}, yw]*G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1}, yu^(-1)])/
      64 - (3*G[{1}, yu^(-1)]*G[{1}, yw]*G[{1/(yu*yv)}, yw]*
       G[{0, 1}, yu^(-1)])/64 - (3*G[{1}, yv^(-1)]*G[{1}, yw]*
       G[{1/(yu*yv)}, yw]*G[{0, 1}, yu^(-1)])/64 + 
     (G[{1}, yw]^2*G[{1/(yu*yv)}, yw]*G[{0, 1}, yu^(-1)])/32 - 
     (G[{0}, yu^(-1)]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1}, yu^(-1)])/
      32 - (G[{0}, yv^(-1)]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*
       G[{0, 1}, yu^(-1)])/32 + (G[{0}, yw]*G[{yu^(-1)}, yw]*
       G[{1/(yu*yv)}, yw]*G[{0, 1}, yu^(-1)])/32 - 
     (G[{1}, yu^(-1)]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1}, yu^(-1)])/
      32 + (3*G[{1}, yv^(-1)]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*
       G[{0, 1}, yu^(-1)])/32 - (G[{1}, yw]*G[{yu^(-1)}, yw]*
       G[{1/(yu*yv)}, yw]*G[{0, 1}, yu^(-1)])/16 - 
     (G[{yu^(-1)}, yw]^2*G[{1/(yu*yv)}, yw]*G[{0, 1}, yu^(-1)])/64 + 
     (G[{0}, yu^(-1)]*G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, 1}, yu^(-1)])/
      16 + (G[{0}, yv^(-1)]*G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw]*
       G[{0, 1}, yu^(-1)])/16 - (G[{0}, yw]*G[{yu}, yv^(-1)]*
       G[{1/(yu*yv)}, yw]*G[{0, 1}, yu^(-1)])/16 - 
     (G[{1}, yu^(-1)]*G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, 1}, yu^(-1)])/
      16 + (G[{1}, yv^(-1)]*G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw]*
       G[{0, 1}, yu^(-1)])/16 - (G[{yu}, yv^(-1)]^2*G[{1/(yu*yv)}, yw]*
       G[{0, 1}, yu^(-1)])/16 + (3*G[{0}, yu^(-1)]*G[{yv^(-1)}, yw]*
       G[{1/(yu*yv)}, yw]*G[{0, 1}, yu^(-1)])/32 + 
     (3*G[{0}, yv^(-1)]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*
       G[{0, 1}, yu^(-1)])/32 - (3*G[{0}, yw]*G[{yv^(-1)}, yw]*
       G[{1/(yu*yv)}, yw]*G[{0, 1}, yu^(-1)])/32 - 
     (3*G[{1}, yu^(-1)]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*
       G[{0, 1}, yu^(-1)])/32 - (3*G[{1}, yv^(-1)]*G[{yv^(-1)}, yw]*
       G[{1/(yu*yv)}, yw]*G[{0, 1}, yu^(-1)])/32 + 
     (G[{1}, yw]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1}, yu^(-1)])/8 - 
     (G[{yu^(-1)}, yw]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*
       G[{0, 1}, yu^(-1)])/32 + (7*G[{yv^(-1)}, yw]^2*G[{1/(yu*yv)}, yw]*
       G[{0, 1}, yu^(-1)])/64 - (G[{0}, yu^(-1)]*G[{1/(yu*yv)}, yw]^2*
       G[{0, 1}, yu^(-1)])/128 - (G[{0}, yv^(-1)]*G[{1/(yu*yv)}, yw]^2*
       G[{0, 1}, yu^(-1)])/128 + (G[{0}, yw]*G[{1/(yu*yv)}, yw]^2*
       G[{0, 1}, yu^(-1)])/128 + (G[{1}, yu^(-1)]*G[{1/(yu*yv)}, yw]^2*
       G[{0, 1}, yu^(-1)])/128 - (7*G[{1}, yv^(-1)]*G[{1/(yu*yv)}, yw]^2*
       G[{0, 1}, yu^(-1)])/128 - (G[{1}, yw]*G[{1/(yu*yv)}, yw]^2*
       G[{0, 1}, yu^(-1)])/16 + (7*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2*
       G[{0, 1}, yu^(-1)])/128 + (G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw]^2*
       G[{0, 1}, yu^(-1)])/16 - (G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2*
       G[{0, 1}, yu^(-1)])/128 - (G[{0}, yu^(-1)]*G[{0, 1}, yu^(-1)]^2)/32 - 
     (G[{0}, yv^(-1)]*G[{0, 1}, yu^(-1)]^2)/32 + 
     (G[{0}, yw]*G[{0, 1}, yu^(-1)]^2)/32 + 
     (G[{1}, yu^(-1)]*G[{0, 1}, yu^(-1)]^2)/32 + 
     (G[{1}, yv^(-1)]*G[{0, 1}, yu^(-1)]^2)/16 - 
     (G[{1}, yw]*G[{0, 1}, yu^(-1)]^2)/16 - 
     (G[{1/(yu*yv)}, yw]*G[{0, 1}, yu^(-1)]^2)/32 + 
     (Pi^2*G[{1}, yv^(-1)]*G[{0, 1}, yv^(-1)])/32 + 
     (3*G[{0}, yu^(-1)]^2*G[{1}, yv^(-1)]*G[{0, 1}, yv^(-1)])/32 + 
     (3*G[{0}, yu^(-1)]*G[{0}, yv^(-1)]*G[{1}, yv^(-1)]*G[{0, 1}, yv^(-1)])/
      16 + (3*G[{0}, yv^(-1)]^2*G[{1}, yv^(-1)]*G[{0, 1}, yv^(-1)])/32 - 
     (3*G[{0}, yu^(-1)]*G[{0}, yw]*G[{1}, yv^(-1)]*G[{0, 1}, yv^(-1)])/16 - 
     (3*G[{0}, yv^(-1)]*G[{0}, yw]*G[{1}, yv^(-1)]*G[{0, 1}, yv^(-1)])/16 + 
     (3*G[{0}, yw]^2*G[{1}, yv^(-1)]*G[{0, 1}, yv^(-1)])/32 - 
     (G[{0}, yu^(-1)]*G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*G[{0, 1}, yv^(-1)])/8 - 
     (G[{0}, yv^(-1)]*G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*G[{0, 1}, yv^(-1)])/8 + 
     (G[{0}, yw]*G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*G[{0, 1}, yv^(-1)])/8 + 
     (G[{1}, yu^(-1)]^2*G[{1}, yv^(-1)]*G[{0, 1}, yv^(-1)])/32 - 
     (5*G[{0}, yu^(-1)]*G[{1}, yv^(-1)]^2*G[{0, 1}, yv^(-1)])/32 - 
     (5*G[{0}, yv^(-1)]*G[{1}, yv^(-1)]^2*G[{0, 1}, yv^(-1)])/32 + 
     (5*G[{0}, yw]*G[{1}, yv^(-1)]^2*G[{0, 1}, yv^(-1)])/32 + 
     (G[{1}, yu^(-1)]*G[{1}, yv^(-1)]^2*G[{0, 1}, yv^(-1)])/16 + 
     (5*G[{1}, yv^(-1)]^3*G[{0, 1}, yv^(-1)])/96 - 
     (Pi^2*G[{1}, yw]*G[{0, 1}, yv^(-1)])/32 - 
     (3*G[{0}, yu^(-1)]^2*G[{1}, yw]*G[{0, 1}, yv^(-1)])/32 - 
     (3*G[{0}, yu^(-1)]*G[{0}, yv^(-1)]*G[{1}, yw]*G[{0, 1}, yv^(-1)])/16 - 
     (3*G[{0}, yv^(-1)]^2*G[{1}, yw]*G[{0, 1}, yv^(-1)])/32 + 
     (3*G[{0}, yu^(-1)]*G[{0}, yw]*G[{1}, yw]*G[{0, 1}, yv^(-1)])/16 + 
     (3*G[{0}, yv^(-1)]*G[{0}, yw]*G[{1}, yw]*G[{0, 1}, yv^(-1)])/16 - 
     (3*G[{0}, yw]^2*G[{1}, yw]*G[{0, 1}, yv^(-1)])/32 + 
     (G[{0}, yu^(-1)]*G[{1}, yu^(-1)]*G[{1}, yw]*G[{0, 1}, yv^(-1)])/8 + 
     (G[{0}, yv^(-1)]*G[{1}, yu^(-1)]*G[{1}, yw]*G[{0, 1}, yv^(-1)])/8 - 
     (G[{0}, yw]*G[{1}, yu^(-1)]*G[{1}, yw]*G[{0, 1}, yv^(-1)])/8 - 
     (G[{1}, yu^(-1)]^2*G[{1}, yw]*G[{0, 1}, yv^(-1)])/32 + 
     (5*G[{0}, yu^(-1)]*G[{1}, yv^(-1)]*G[{1}, yw]*G[{0, 1}, yv^(-1)])/16 + 
     (5*G[{0}, yv^(-1)]*G[{1}, yv^(-1)]*G[{1}, yw]*G[{0, 1}, yv^(-1)])/16 - 
     (5*G[{0}, yw]*G[{1}, yv^(-1)]*G[{1}, yw]*G[{0, 1}, yv^(-1)])/16 - 
     (G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*G[{1}, yw]*G[{0, 1}, yv^(-1)])/8 - 
     (5*G[{1}, yv^(-1)]^2*G[{1}, yw]*G[{0, 1}, yv^(-1)])/32 - 
     (3*G[{0}, yu^(-1)]*G[{1}, yw]^2*G[{0, 1}, yv^(-1)])/32 - 
     (3*G[{0}, yv^(-1)]*G[{1}, yw]^2*G[{0, 1}, yv^(-1)])/32 + 
     (3*G[{0}, yw]*G[{1}, yw]^2*G[{0, 1}, yv^(-1)])/32 + 
     (G[{1}, yu^(-1)]*G[{1}, yw]^2*G[{0, 1}, yv^(-1)])/16 + 
     (3*G[{1}, yv^(-1)]*G[{1}, yw]^2*G[{0, 1}, yv^(-1)])/32 - 
     (G[{1}, yw]^3*G[{0, 1}, yv^(-1)])/96 + 
     (G[{0}, yu^(-1)]*G[{1}, yw]*G[{yu}, yv^(-1)]*G[{0, 1}, yv^(-1)])/8 + 
     (G[{0}, yv^(-1)]*G[{1}, yw]*G[{yu}, yv^(-1)]*G[{0, 1}, yv^(-1)])/8 - 
     (G[{0}, yw]*G[{1}, yw]*G[{yu}, yv^(-1)]*G[{0, 1}, yv^(-1)])/8 - 
     (G[{1}, yu^(-1)]*G[{1}, yw]*G[{yu}, yv^(-1)]*G[{0, 1}, yv^(-1)])/8 - 
     (G[{1}, yv^(-1)]*G[{1}, yw]*G[{yu}, yv^(-1)]*G[{0, 1}, yv^(-1)])/16 + 
     (G[{1}, yw]^2*G[{yu}, yv^(-1)]*G[{0, 1}, yv^(-1)])/16 - 
     (G[{1}, yw]*G[{yu}, yv^(-1)]^2*G[{0, 1}, yv^(-1)])/16 + 
     (3*G[{0}, yu^(-1)]*G[{1}, yv^(-1)]*G[{1/(yu*yv)}, yw]*
       G[{0, 1}, yv^(-1)])/16 + (3*G[{0}, yv^(-1)]*G[{1}, yv^(-1)]*
       G[{1/(yu*yv)}, yw]*G[{0, 1}, yv^(-1)])/16 - 
     (3*G[{0}, yw]*G[{1}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, 1}, yv^(-1)])/
      16 - (G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*G[{1/(yu*yv)}, yw]*
       G[{0, 1}, yv^(-1)])/8 - (5*G[{1}, yv^(-1)]^2*G[{1/(yu*yv)}, yw]*
       G[{0, 1}, yv^(-1)])/32 + (G[{0}, yu^(-1)]*G[{1}, yw]*
       G[{1/(yu*yv)}, yw]*G[{0, 1}, yv^(-1)])/8 + 
     (G[{0}, yv^(-1)]*G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1}, yv^(-1)])/8 - 
     (G[{0}, yw]*G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1}, yv^(-1)])/8 - 
     (G[{1}, yu^(-1)]*G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1}, yv^(-1)])/8 - 
     (G[{1}, yv^(-1)]*G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1}, yv^(-1)])/16 + 
     (G[{1}, yw]^2*G[{1/(yu*yv)}, yw]*G[{0, 1}, yv^(-1)])/32 - 
     (3*G[{0}, yu^(-1)]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*
       G[{0, 1}, yv^(-1)])/16 - (3*G[{0}, yv^(-1)]*G[{yu^(-1)}, yw]*
       G[{1/(yu*yv)}, yw]*G[{0, 1}, yv^(-1)])/16 + 
     (3*G[{0}, yw]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1}, yv^(-1)])/
      16 + (G[{1}, yu^(-1)]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*
       G[{0, 1}, yv^(-1)])/8 + (5*G[{1}, yv^(-1)]*G[{yu^(-1)}, yw]*
       G[{1/(yu*yv)}, yw]*G[{0, 1}, yv^(-1)])/16 + 
     (G[{1}, yw]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1}, yv^(-1)])/16 - 
     (G[{yu^(-1)}, yw]^2*G[{1/(yu*yv)}, yw]*G[{0, 1}, yv^(-1)])/8 - 
     (G[{0}, yu^(-1)]*G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, 1}, yv^(-1)])/
      8 - (G[{0}, yv^(-1)]*G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw]*
       G[{0, 1}, yv^(-1)])/8 + (G[{0}, yw]*G[{yu}, yv^(-1)]*
       G[{1/(yu*yv)}, yw]*G[{0, 1}, yv^(-1)])/8 + 
     (G[{1}, yu^(-1)]*G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, 1}, yv^(-1)])/
      8 + (G[{1}, yv^(-1)]*G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw]*
       G[{0, 1}, yv^(-1)])/16 - (G[{1}, yw]*G[{yu}, yv^(-1)]*
       G[{1/(yu*yv)}, yw]*G[{0, 1}, yv^(-1)])/8 + 
     (G[{yu}, yv^(-1)]^2*G[{1/(yu*yv)}, yw]*G[{0, 1}, yv^(-1)])/16 + 
     (G[{1}, yv^(-1)]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1}, yv^(-1)])/
      8 + (G[{1}, yw]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1}, yv^(-1)])/
      8 - (G[{yu^(-1)}, yw]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*
       G[{0, 1}, yv^(-1)])/8 - (G[{yu}, yv^(-1)]*G[{yv^(-1)}, yw]*
       G[{1/(yu*yv)}, yw]*G[{0, 1}, yv^(-1)])/8 - 
     (G[{0}, yu^(-1)]*G[{0, 1}, yv^(-1)]^2)/32 - 
     (G[{0}, yv^(-1)]*G[{0, 1}, yv^(-1)]^2)/32 + 
     (G[{0}, yw]*G[{0, 1}, yv^(-1)]^2)/32 + 
     (G[{1}, yv^(-1)]*G[{0, 1}, yv^(-1)]^2)/16 - 
     (G[{1}, yw]*G[{0, 1}, yv^(-1)]^2)/16 - 
     (G[{1/(yu*yv)}, yw]*G[{0, 1}, yv^(-1)]^2)/32 - 
     (7*Pi^2*G[{0}, yu^(-1)]*G[{0, 1}, yw])/256 - 
     (7*Pi^2*G[{0}, yv^(-1)]*G[{0, 1}, yw])/256 + 
     (7*Pi^2*G[{0}, yw]*G[{0, 1}, yw])/256 + 
     (5*Pi^2*G[{1}, yu^(-1)]*G[{0, 1}, yw])/768 - 
     (3*G[{0}, yu^(-1)]^2*G[{1}, yu^(-1)]*G[{0, 1}, yw])/32 - 
     (3*G[{0}, yu^(-1)]*G[{0}, yv^(-1)]*G[{1}, yu^(-1)]*G[{0, 1}, yw])/16 - 
     (3*G[{0}, yv^(-1)]^2*G[{1}, yu^(-1)]*G[{0, 1}, yw])/32 + 
     (3*G[{0}, yu^(-1)]*G[{0}, yw]*G[{1}, yu^(-1)]*G[{0, 1}, yw])/16 + 
     (3*G[{0}, yv^(-1)]*G[{0}, yw]*G[{1}, yu^(-1)]*G[{0, 1}, yw])/16 - 
     (3*G[{0}, yw]^2*G[{1}, yu^(-1)]*G[{0, 1}, yw])/32 + 
     (9*G[{0}, yu^(-1)]*G[{1}, yu^(-1)]^2*G[{0, 1}, yw])/64 + 
     (9*G[{0}, yv^(-1)]*G[{1}, yu^(-1)]^2*G[{0, 1}, yw])/64 - 
     (9*G[{0}, yw]*G[{1}, yu^(-1)]^2*G[{0, 1}, yw])/64 - 
     (3*G[{1}, yu^(-1)]^3*G[{0, 1}, yw])/64 + 
     (29*Pi^2*G[{1}, yv^(-1)]*G[{0, 1}, yw])/768 + 
     (7*G[{0}, yu^(-1)]*G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*G[{0, 1}, yw])/32 + 
     (7*G[{0}, yv^(-1)]*G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*G[{0, 1}, yw])/32 - 
     (7*G[{0}, yw]*G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*G[{0, 1}, yw])/32 - 
     (11*G[{1}, yu^(-1)]^2*G[{1}, yv^(-1)]*G[{0, 1}, yw])/64 - 
     (G[{1}, yu^(-1)]*G[{1}, yv^(-1)]^2*G[{0, 1}, yw])/16 - 
     (23*Pi^2*G[{1}, yw]*G[{0, 1}, yw])/768 - 
     (3*G[{0}, yu^(-1)]^2*G[{1}, yw]*G[{0, 1}, yw])/64 - 
     (3*G[{0}, yu^(-1)]*G[{0}, yv^(-1)]*G[{1}, yw]*G[{0, 1}, yw])/32 - 
     (3*G[{0}, yv^(-1)]^2*G[{1}, yw]*G[{0, 1}, yw])/64 + 
     (3*G[{0}, yu^(-1)]*G[{0}, yw]*G[{1}, yw]*G[{0, 1}, yw])/32 + 
     (3*G[{0}, yv^(-1)]*G[{0}, yw]*G[{1}, yw]*G[{0, 1}, yw])/32 - 
     (3*G[{0}, yw]^2*G[{1}, yw]*G[{0, 1}, yw])/64 + 
     (3*G[{1}, yu^(-1)]^2*G[{1}, yw]*G[{0, 1}, yw])/128 + 
     (3*G[{0}, yu^(-1)]*G[{1}, yv^(-1)]*G[{1}, yw]*G[{0, 1}, yw])/32 + 
     (3*G[{0}, yv^(-1)]*G[{1}, yv^(-1)]*G[{1}, yw]*G[{0, 1}, yw])/32 - 
     (3*G[{0}, yw]*G[{1}, yv^(-1)]*G[{1}, yw]*G[{0, 1}, yw])/32 - 
     (9*G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*G[{1}, yw]*G[{0, 1}, yw])/64 - 
     (3*G[{1}, yv^(-1)]^2*G[{1}, yw]*G[{0, 1}, yw])/64 - 
     (7*G[{0}, yu^(-1)]*G[{1}, yw]^2*G[{0, 1}, yw])/128 - 
     (7*G[{0}, yv^(-1)]*G[{1}, yw]^2*G[{0, 1}, yw])/128 + 
     (7*G[{0}, yw]*G[{1}, yw]^2*G[{0, 1}, yw])/128 + 
     (9*G[{1}, yu^(-1)]*G[{1}, yw]^2*G[{0, 1}, yw])/128 + 
     (7*G[{1}, yv^(-1)]*G[{1}, yw]^2*G[{0, 1}, yw])/128 + 
     (G[{1}, yw]^3*G[{0, 1}, yw])/128 + (Pi^2*G[{yu}, yv^(-1)]*G[{0, 1}, yw])/
      48 + (3*G[{0}, yu^(-1)]^2*G[{yu}, yv^(-1)]*G[{0, 1}, yw])/32 + 
     (3*G[{0}, yu^(-1)]*G[{0}, yv^(-1)]*G[{yu}, yv^(-1)]*G[{0, 1}, yw])/16 + 
     (3*G[{0}, yv^(-1)]^2*G[{yu}, yv^(-1)]*G[{0, 1}, yw])/32 - 
     (3*G[{0}, yu^(-1)]*G[{0}, yw]*G[{yu}, yv^(-1)]*G[{0, 1}, yw])/16 - 
     (3*G[{0}, yv^(-1)]*G[{0}, yw]*G[{yu}, yv^(-1)]*G[{0, 1}, yw])/16 + 
     (3*G[{0}, yw]^2*G[{yu}, yv^(-1)]*G[{0, 1}, yw])/32 - 
     (G[{0}, yu^(-1)]*G[{1}, yu^(-1)]*G[{yu}, yv^(-1)]*G[{0, 1}, yw])/8 - 
     (G[{0}, yv^(-1)]*G[{1}, yu^(-1)]*G[{yu}, yv^(-1)]*G[{0, 1}, yw])/8 + 
     (G[{0}, yw]*G[{1}, yu^(-1)]*G[{yu}, yv^(-1)]*G[{0, 1}, yw])/8 + 
     (G[{1}, yu^(-1)]^2*G[{yu}, yv^(-1)]*G[{0, 1}, yw])/32 - 
     (G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*G[{yu}, yv^(-1)]*G[{0, 1}, yw])/16 - 
     (G[{1}, yv^(-1)]^2*G[{yu}, yv^(-1)]*G[{0, 1}, yw])/16 + 
     (3*G[{0}, yu^(-1)]*G[{1}, yw]*G[{yu}, yv^(-1)]*G[{0, 1}, yw])/32 + 
     (3*G[{0}, yv^(-1)]*G[{1}, yw]*G[{yu}, yv^(-1)]*G[{0, 1}, yw])/32 - 
     (3*G[{0}, yw]*G[{1}, yw]*G[{yu}, yv^(-1)]*G[{0, 1}, yw])/32 + 
     (3*G[{1}, yu^(-1)]*G[{1}, yw]*G[{yu}, yv^(-1)]*G[{0, 1}, yw])/32 + 
     (G[{1}, yv^(-1)]*G[{1}, yw]*G[{yu}, yv^(-1)]*G[{0, 1}, yw])/32 - 
     (G[{1}, yw]^2*G[{yu}, yv^(-1)]*G[{0, 1}, yw])/64 - 
     (G[{0}, yu^(-1)]*G[{yu}, yv^(-1)]^2*G[{0, 1}, yw])/8 - 
     (G[{0}, yv^(-1)]*G[{yu}, yv^(-1)]^2*G[{0, 1}, yw])/8 + 
     (G[{0}, yw]*G[{yu}, yv^(-1)]^2*G[{0, 1}, yw])/8 + 
     (G[{1}, yu^(-1)]*G[{yu}, yv^(-1)]^2*G[{0, 1}, yw])/8 - 
     (5*G[{1}, yw]*G[{yu}, yv^(-1)]^2*G[{0, 1}, yw])/32 + 
     (G[{yu}, yv^(-1)]^3*G[{0, 1}, yw])/24 + 
     (3*Pi^2*G[{1/(yu*yv)}, yw]*G[{0, 1}, yw])/256 + 
     (3*G[{0}, yu^(-1)]^2*G[{1/(yu*yv)}, yw]*G[{0, 1}, yw])/64 + 
     (3*G[{0}, yu^(-1)]*G[{0}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, 1}, yw])/
      32 + (3*G[{0}, yv^(-1)]^2*G[{1/(yu*yv)}, yw]*G[{0, 1}, yw])/64 - 
     (3*G[{0}, yu^(-1)]*G[{0}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1}, yw])/32 - 
     (3*G[{0}, yv^(-1)]*G[{0}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1}, yw])/32 + 
     (3*G[{0}, yw]^2*G[{1/(yu*yv)}, yw]*G[{0, 1}, yw])/64 - 
     (G[{0}, yu^(-1)]*G[{1}, yu^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, 1}, yw])/8 - 
     (G[{0}, yv^(-1)]*G[{1}, yu^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, 1}, yw])/8 + 
     (G[{0}, yw]*G[{1}, yu^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, 1}, yw])/8 + 
     (7*G[{1}, yu^(-1)]^2*G[{1/(yu*yv)}, yw]*G[{0, 1}, yw])/128 - 
     (5*G[{0}, yu^(-1)]*G[{1}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, 1}, yw])/
      32 - (5*G[{0}, yv^(-1)]*G[{1}, yv^(-1)]*G[{1/(yu*yv)}, yw]*
       G[{0, 1}, yw])/32 + (5*G[{0}, yw]*G[{1}, yv^(-1)]*G[{1/(yu*yv)}, yw]*
       G[{0, 1}, yw])/32 + (15*G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*
       G[{1/(yu*yv)}, yw]*G[{0, 1}, yw])/64 + 
     (5*G[{1}, yv^(-1)]^2*G[{1/(yu*yv)}, yw]*G[{0, 1}, yw])/64 + 
     (G[{0}, yu^(-1)]*G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1}, yw])/64 + 
     (G[{0}, yv^(-1)]*G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1}, yw])/64 - 
     (G[{0}, yw]*G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1}, yw])/64 + 
     (3*G[{1}, yu^(-1)]*G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1}, yw])/64 - 
     (5*G[{1}, yv^(-1)]*G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1}, yw])/64 - 
     (G[{1}, yw]^2*G[{1/(yu*yv)}, yw]*G[{0, 1}, yw])/128 + 
     (G[{1}, yu^(-1)]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1}, yw])/16 - 
     (G[{1}, yv^(-1)]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1}, yw])/16 + 
     (G[{1}, yw]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1}, yw])/32 + 
     (G[{yu^(-1)}, yw]^2*G[{1/(yu*yv)}, yw]*G[{0, 1}, yw])/16 + 
     (3*G[{0}, yu^(-1)]*G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, 1}, yw])/
      32 + (3*G[{0}, yv^(-1)]*G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw]*
       G[{0, 1}, yw])/32 - (3*G[{0}, yw]*G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw]*
       G[{0, 1}, yw])/32 - (3*G[{1}, yu^(-1)]*G[{yu}, yv^(-1)]*
       G[{1/(yu*yv)}, yw]*G[{0, 1}, yw])/32 - 
     (G[{1}, yv^(-1)]*G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, 1}, yw])/32 - 
     (G[{yu}, yv^(-1)]^2*G[{1/(yu*yv)}, yw]*G[{0, 1}, yw])/32 - 
     (G[{0}, yu^(-1)]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1}, yw])/32 - 
     (G[{0}, yv^(-1)]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1}, yw])/32 + 
     (G[{0}, yw]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1}, yw])/32 + 
     (3*G[{1}, yu^(-1)]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1}, yw])/
      32 - (3*G[{1}, yv^(-1)]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*
       G[{0, 1}, yw])/32 - (9*G[{1}, yw]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*
       G[{0, 1}, yw])/64 + (G[{yu}, yv^(-1)]*G[{yv^(-1)}, yw]*
       G[{1/(yu*yv)}, yw]*G[{0, 1}, yw])/16 - 
     (3*G[{yv^(-1)}, yw]^2*G[{1/(yu*yv)}, yw]*G[{0, 1}, yw])/32 + 
     (3*G[{0}, yu^(-1)]*G[{1/(yu*yv)}, yw]^2*G[{0, 1}, yw])/128 + 
     (3*G[{0}, yv^(-1)]*G[{1/(yu*yv)}, yw]^2*G[{0, 1}, yw])/128 - 
     (3*G[{0}, yw]*G[{1/(yu*yv)}, yw]^2*G[{0, 1}, yw])/128 + 
     (3*G[{1}, yu^(-1)]*G[{1/(yu*yv)}, yw]^2*G[{0, 1}, yw])/128 - 
     (7*G[{1}, yv^(-1)]*G[{1/(yu*yv)}, yw]^2*G[{0, 1}, yw])/128 + 
     (G[{1}, yw]*G[{1/(yu*yv)}, yw]^2*G[{0, 1}, yw])/64 + 
     (G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2*G[{0, 1}, yw])/128 - 
     (G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw]^2*G[{0, 1}, yw])/64 - 
     (9*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2*G[{0, 1}, yw])/128 + 
     (G[{0}, yu^(-1)]*G[{0, 1}, yu^(-1)]*G[{0, 1}, yw])/32 + 
     (G[{0}, yv^(-1)]*G[{0, 1}, yu^(-1)]*G[{0, 1}, yw])/32 - 
     (G[{0}, yw]*G[{0, 1}, yu^(-1)]*G[{0, 1}, yw])/32 - 
     (G[{1}, yu^(-1)]*G[{0, 1}, yu^(-1)]*G[{0, 1}, yw])/32 + 
     (3*G[{1}, yv^(-1)]*G[{0, 1}, yu^(-1)]*G[{0, 1}, yw])/32 - 
     (9*G[{1}, yw]*G[{0, 1}, yu^(-1)]*G[{0, 1}, yw])/64 - 
     (G[{yu}, yv^(-1)]*G[{0, 1}, yu^(-1)]*G[{0, 1}, yw])/16 + 
     (3*G[{1/(yu*yv)}, yw]*G[{0, 1}, yu^(-1)]*G[{0, 1}, yw])/64 - 
     (3*G[{0}, yu^(-1)]*G[{0, 1}, yv^(-1)]*G[{0, 1}, yw])/16 - 
     (3*G[{0}, yv^(-1)]*G[{0, 1}, yv^(-1)]*G[{0, 1}, yw])/16 + 
     (3*G[{0}, yw]*G[{0, 1}, yv^(-1)]*G[{0, 1}, yw])/16 + 
     (G[{1}, yu^(-1)]*G[{0, 1}, yv^(-1)]*G[{0, 1}, yw])/8 + 
     (G[{1}, yv^(-1)]*G[{0, 1}, yv^(-1)]*G[{0, 1}, yw])/4 - 
     (G[{1}, yw]*G[{0, 1}, yv^(-1)]*G[{0, 1}, yw])/8 + 
     (G[{yu}, yv^(-1)]*G[{0, 1}, yv^(-1)]*G[{0, 1}, yw])/8 + 
     (G[{0}, yu^(-1)]*G[{0, 1}, yw]^2)/32 + (G[{0}, yv^(-1)]*G[{0, 1}, yw]^2)/
      32 - (G[{0}, yw]*G[{0, 1}, yw]^2)/32 - 
     (G[{1}, yv^(-1)]*G[{0, 1}, yw]^2)/32 + (7*G[{1}, yw]*G[{0, 1}, yw]^2)/
      128 - (G[{yu}, yv^(-1)]*G[{0, 1}, yw]^2)/32 - 
     (G[{1/(yu*yv)}, yw]*G[{0, 1}, yw]^2)/128 + 
     (29*Pi^2*G[{0}, yu^(-1)]*G[{0, yu^(-1)}, yw])/768 + 
     (29*Pi^2*G[{0}, yv^(-1)]*G[{0, yu^(-1)}, yw])/768 - 
     (29*Pi^2*G[{0}, yw]*G[{0, yu^(-1)}, yw])/768 - 
     (5*Pi^2*G[{1}, yu^(-1)]*G[{0, yu^(-1)}, yw])/768 + 
     (3*G[{0}, yu^(-1)]^2*G[{1}, yu^(-1)]*G[{0, yu^(-1)}, yw])/32 + 
     (3*G[{0}, yu^(-1)]*G[{0}, yv^(-1)]*G[{1}, yu^(-1)]*G[{0, yu^(-1)}, yw])/
      16 + (3*G[{0}, yv^(-1)]^2*G[{1}, yu^(-1)]*G[{0, yu^(-1)}, yw])/32 - 
     (3*G[{0}, yu^(-1)]*G[{0}, yw]*G[{1}, yu^(-1)]*G[{0, yu^(-1)}, yw])/16 - 
     (3*G[{0}, yv^(-1)]*G[{0}, yw]*G[{1}, yu^(-1)]*G[{0, yu^(-1)}, yw])/16 + 
     (3*G[{0}, yw]^2*G[{1}, yu^(-1)]*G[{0, yu^(-1)}, yw])/32 - 
     (9*G[{0}, yu^(-1)]*G[{1}, yu^(-1)]^2*G[{0, yu^(-1)}, yw])/64 - 
     (9*G[{0}, yv^(-1)]*G[{1}, yu^(-1)]^2*G[{0, yu^(-1)}, yw])/64 + 
     (9*G[{0}, yw]*G[{1}, yu^(-1)]^2*G[{0, yu^(-1)}, yw])/64 + 
     (3*G[{1}, yu^(-1)]^3*G[{0, yu^(-1)}, yw])/64 - 
     (53*Pi^2*G[{1}, yv^(-1)]*G[{0, yu^(-1)}, yw])/768 - 
     (3*G[{0}, yu^(-1)]^2*G[{1}, yv^(-1)]*G[{0, yu^(-1)}, yw])/32 - 
     (3*G[{0}, yu^(-1)]*G[{0}, yv^(-1)]*G[{1}, yv^(-1)]*G[{0, yu^(-1)}, yw])/
      16 - (3*G[{0}, yv^(-1)]^2*G[{1}, yv^(-1)]*G[{0, yu^(-1)}, yw])/32 + 
     (3*G[{0}, yu^(-1)]*G[{0}, yw]*G[{1}, yv^(-1)]*G[{0, yu^(-1)}, yw])/16 + 
     (3*G[{0}, yv^(-1)]*G[{0}, yw]*G[{1}, yv^(-1)]*G[{0, yu^(-1)}, yw])/16 - 
     (3*G[{0}, yw]^2*G[{1}, yv^(-1)]*G[{0, yu^(-1)}, yw])/32 - 
     (3*G[{0}, yu^(-1)]*G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*G[{0, yu^(-1)}, yw])/
      32 - (3*G[{0}, yv^(-1)]*G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*
       G[{0, yu^(-1)}, yw])/32 + (3*G[{0}, yw]*G[{1}, yu^(-1)]*
       G[{1}, yv^(-1)]*G[{0, yu^(-1)}, yw])/32 + 
     (9*G[{1}, yu^(-1)]^2*G[{1}, yv^(-1)]*G[{0, yu^(-1)}, yw])/64 + 
     (5*G[{0}, yu^(-1)]*G[{1}, yv^(-1)]^2*G[{0, yu^(-1)}, yw])/32 + 
     (5*G[{0}, yv^(-1)]*G[{1}, yv^(-1)]^2*G[{0, yu^(-1)}, yw])/32 - 
     (5*G[{0}, yw]*G[{1}, yv^(-1)]^2*G[{0, yu^(-1)}, yw])/32 - 
     (G[{1}, yu^(-1)]*G[{1}, yv^(-1)]^2*G[{0, yu^(-1)}, yw])/32 - 
     (G[{1}, yv^(-1)]^3*G[{0, yu^(-1)}, yw])/16 + 
     (5*Pi^2*G[{1}, yw]*G[{0, yu^(-1)}, yw])/256 + 
     (3*G[{0}, yu^(-1)]^2*G[{1}, yw]*G[{0, yu^(-1)}, yw])/64 + 
     (3*G[{0}, yu^(-1)]*G[{0}, yv^(-1)]*G[{1}, yw]*G[{0, yu^(-1)}, yw])/32 + 
     (3*G[{0}, yv^(-1)]^2*G[{1}, yw]*G[{0, yu^(-1)}, yw])/64 - 
     (3*G[{0}, yu^(-1)]*G[{0}, yw]*G[{1}, yw]*G[{0, yu^(-1)}, yw])/32 - 
     (3*G[{0}, yv^(-1)]*G[{0}, yw]*G[{1}, yw]*G[{0, yu^(-1)}, yw])/32 + 
     (3*G[{0}, yw]^2*G[{1}, yw]*G[{0, yu^(-1)}, yw])/64 - 
     (3*G[{1}, yu^(-1)]^2*G[{1}, yw]*G[{0, yu^(-1)}, yw])/128 - 
     (7*G[{0}, yu^(-1)]*G[{1}, yv^(-1)]*G[{1}, yw]*G[{0, yu^(-1)}, yw])/32 - 
     (7*G[{0}, yv^(-1)]*G[{1}, yv^(-1)]*G[{1}, yw]*G[{0, yu^(-1)}, yw])/32 + 
     (7*G[{0}, yw]*G[{1}, yv^(-1)]*G[{1}, yw]*G[{0, yu^(-1)}, yw])/32 + 
     (9*G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*G[{1}, yw]*G[{0, yu^(-1)}, yw])/64 + 
     (11*G[{1}, yv^(-1)]^2*G[{1}, yw]*G[{0, yu^(-1)}, yw])/64 + 
     (7*G[{0}, yu^(-1)]*G[{1}, yw]^2*G[{0, yu^(-1)}, yw])/128 + 
     (7*G[{0}, yv^(-1)]*G[{1}, yw]^2*G[{0, yu^(-1)}, yw])/128 - 
     (7*G[{0}, yw]*G[{1}, yw]^2*G[{0, yu^(-1)}, yw])/128 - 
     (9*G[{1}, yu^(-1)]*G[{1}, yw]^2*G[{0, yu^(-1)}, yw])/128 - 
     (7*G[{1}, yv^(-1)]*G[{1}, yw]^2*G[{0, yu^(-1)}, yw])/128 - 
     (G[{1}, yw]^3*G[{0, yu^(-1)}, yw])/128 + 
     (G[{0}, yu^(-1)]*G[{1}, yw]*G[{yu}, yv^(-1)]*G[{0, yu^(-1)}, yw])/32 + 
     (G[{0}, yv^(-1)]*G[{1}, yw]*G[{yu}, yv^(-1)]*G[{0, yu^(-1)}, yw])/32 - 
     (G[{0}, yw]*G[{1}, yw]*G[{yu}, yv^(-1)]*G[{0, yu^(-1)}, yw])/32 - 
     (3*G[{1}, yu^(-1)]*G[{1}, yw]*G[{yu}, yv^(-1)]*G[{0, yu^(-1)}, yw])/32 - 
     (G[{1}, yv^(-1)]*G[{1}, yw]*G[{yu}, yv^(-1)]*G[{0, yu^(-1)}, yw])/32 + 
     (G[{1}, yw]^2*G[{yu}, yv^(-1)]*G[{0, yu^(-1)}, yw])/64 + 
     (G[{1}, yw]*G[{yu}, yv^(-1)]^2*G[{0, yu^(-1)}, yw])/32 - 
     (3*Pi^2*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1)}, yw])/256 - 
     (3*G[{0}, yu^(-1)]^2*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1)}, yw])/64 - 
     (3*G[{0}, yu^(-1)]*G[{0}, yv^(-1)]*G[{1/(yu*yv)}, yw]*
       G[{0, yu^(-1)}, yw])/32 - (3*G[{0}, yv^(-1)]^2*G[{1/(yu*yv)}, yw]*
       G[{0, yu^(-1)}, yw])/64 + (3*G[{0}, yu^(-1)]*G[{0}, yw]*
       G[{1/(yu*yv)}, yw]*G[{0, yu^(-1)}, yw])/32 + 
     (3*G[{0}, yv^(-1)]*G[{0}, yw]*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1)}, yw])/
      32 - (3*G[{0}, yw]^2*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1)}, yw])/64 + 
     (G[{0}, yu^(-1)]*G[{1}, yu^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1)}, yw])/
      8 + (G[{0}, yv^(-1)]*G[{1}, yu^(-1)]*G[{1/(yu*yv)}, yw]*
       G[{0, yu^(-1)}, yw])/8 - (G[{0}, yw]*G[{1}, yu^(-1)]*
       G[{1/(yu*yv)}, yw]*G[{0, yu^(-1)}, yw])/8 - 
     (7*G[{1}, yu^(-1)]^2*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1)}, yw])/128 + 
     (3*G[{0}, yu^(-1)]*G[{1}, yv^(-1)]*G[{1/(yu*yv)}, yw]*
       G[{0, yu^(-1)}, yw])/32 + (3*G[{0}, yv^(-1)]*G[{1}, yv^(-1)]*
       G[{1/(yu*yv)}, yw]*G[{0, yu^(-1)}, yw])/32 - 
     (3*G[{0}, yw]*G[{1}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1)}, yw])/
      32 - (15*G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*G[{1/(yu*yv)}, yw]*
       G[{0, yu^(-1)}, yw])/64 - (G[{1}, yv^(-1)]^2*G[{1/(yu*yv)}, yw]*
       G[{0, yu^(-1)}, yw])/64 - (G[{0}, yu^(-1)]*G[{1}, yw]*
       G[{1/(yu*yv)}, yw]*G[{0, yu^(-1)}, yw])/64 - 
     (G[{0}, yv^(-1)]*G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1)}, yw])/64 + 
     (G[{0}, yw]*G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1)}, yw])/64 - 
     (3*G[{1}, yu^(-1)]*G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1)}, yw])/
      64 + (5*G[{1}, yv^(-1)]*G[{1}, yw]*G[{1/(yu*yv)}, yw]*
       G[{0, yu^(-1)}, yw])/64 + (G[{1}, yw]^2*G[{1/(yu*yv)}, yw]*
       G[{0, yu^(-1)}, yw])/128 - (G[{1}, yu^(-1)]*G[{yu^(-1)}, yw]*
       G[{1/(yu*yv)}, yw]*G[{0, yu^(-1)}, yw])/16 + 
     (G[{1}, yv^(-1)]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*
       G[{0, yu^(-1)}, yw])/16 - (G[{1}, yw]*G[{yu^(-1)}, yw]*
       G[{1/(yu*yv)}, yw]*G[{0, yu^(-1)}, yw])/32 - 
     (G[{yu^(-1)}, yw]^2*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1)}, yw])/16 - 
     (G[{0}, yu^(-1)]*G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw]*
       G[{0, yu^(-1)}, yw])/32 - (G[{0}, yv^(-1)]*G[{yu}, yv^(-1)]*
       G[{1/(yu*yv)}, yw]*G[{0, yu^(-1)}, yw])/32 + 
     (G[{0}, yw]*G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1)}, yw])/
      32 + (3*G[{1}, yu^(-1)]*G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw]*
       G[{0, yu^(-1)}, yw])/32 + (G[{1}, yv^(-1)]*G[{yu}, yv^(-1)]*
       G[{1/(yu*yv)}, yw]*G[{0, yu^(-1)}, yw])/32 - 
     (G[{yu}, yv^(-1)]^2*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1)}, yw])/32 + 
     (G[{0}, yu^(-1)]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*
       G[{0, yu^(-1)}, yw])/32 + (G[{0}, yv^(-1)]*G[{yv^(-1)}, yw]*
       G[{1/(yu*yv)}, yw]*G[{0, yu^(-1)}, yw])/32 - 
     (G[{0}, yw]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1)}, yw])/
      32 - (3*G[{1}, yu^(-1)]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*
       G[{0, yu^(-1)}, yw])/32 + (3*G[{1}, yv^(-1)]*G[{yv^(-1)}, yw]*
       G[{1/(yu*yv)}, yw]*G[{0, yu^(-1)}, yw])/32 + 
     (9*G[{1}, yw]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1)}, yw])/
      64 - (G[{yu}, yv^(-1)]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*
       G[{0, yu^(-1)}, yw])/16 + (3*G[{yv^(-1)}, yw]^2*G[{1/(yu*yv)}, yw]*
       G[{0, yu^(-1)}, yw])/32 - (3*G[{0}, yu^(-1)]*G[{1/(yu*yv)}, yw]^2*
       G[{0, yu^(-1)}, yw])/128 - (3*G[{0}, yv^(-1)]*G[{1/(yu*yv)}, yw]^2*
       G[{0, yu^(-1)}, yw])/128 + (3*G[{0}, yw]*G[{1/(yu*yv)}, yw]^2*
       G[{0, yu^(-1)}, yw])/128 - (3*G[{1}, yu^(-1)]*G[{1/(yu*yv)}, yw]^2*
       G[{0, yu^(-1)}, yw])/128 + (7*G[{1}, yv^(-1)]*G[{1/(yu*yv)}, yw]^2*
       G[{0, yu^(-1)}, yw])/128 - (G[{1}, yw]*G[{1/(yu*yv)}, yw]^2*
       G[{0, yu^(-1)}, yw])/64 - (G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2*
       G[{0, yu^(-1)}, yw])/128 + (G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw]^2*
       G[{0, yu^(-1)}, yw])/64 + (9*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2*
       G[{0, yu^(-1)}, yw])/128 + (G[{0}, yu^(-1)]*G[{0, 1}, yu^(-1)]*
       G[{0, yu^(-1)}, yw])/32 + (G[{0}, yv^(-1)]*G[{0, 1}, yu^(-1)]*
       G[{0, yu^(-1)}, yw])/32 - (G[{0}, yw]*G[{0, 1}, yu^(-1)]*
       G[{0, yu^(-1)}, yw])/32 + (G[{1}, yu^(-1)]*G[{0, 1}, yu^(-1)]*
       G[{0, yu^(-1)}, yw])/32 - (3*G[{1}, yv^(-1)]*G[{0, 1}, yu^(-1)]*
       G[{0, yu^(-1)}, yw])/32 + (5*G[{1}, yw]*G[{0, 1}, yu^(-1)]*
       G[{0, yu^(-1)}, yw])/64 - (3*G[{1/(yu*yv)}, yw]*G[{0, 1}, yu^(-1)]*
       G[{0, yu^(-1)}, yw])/64 + (3*G[{0}, yu^(-1)]*G[{0, 1}, yv^(-1)]*
       G[{0, yu^(-1)}, yw])/16 + (3*G[{0}, yv^(-1)]*G[{0, 1}, yv^(-1)]*
       G[{0, yu^(-1)}, yw])/16 - (3*G[{0}, yw]*G[{0, 1}, yv^(-1)]*
       G[{0, yu^(-1)}, yw])/16 - (G[{1}, yu^(-1)]*G[{0, 1}, yv^(-1)]*
       G[{0, yu^(-1)}, yw])/8 - (5*G[{1}, yv^(-1)]*G[{0, 1}, yv^(-1)]*
       G[{0, yu^(-1)}, yw])/16 + (G[{1}, yw]*G[{0, 1}, yv^(-1)]*
       G[{0, yu^(-1)}, yw])/16 - (G[{1}, yu^(-1)]*G[{0, 1}, yw]*
       G[{0, yu^(-1)}, yw])/16 + (G[{1}, yv^(-1)]*G[{0, 1}, yw]*
       G[{0, yu^(-1)}, yw])/16 - (3*G[{1}, yw]*G[{0, 1}, yw]*
       G[{0, yu^(-1)}, yw])/64 + (G[{1/(yu*yv)}, yw]*G[{0, 1}, yw]*
       G[{0, yu^(-1)}, yw])/64 + (G[{1}, yu^(-1)]*G[{0, yu^(-1)}, yw]^2)/32 - 
     (G[{1}, yv^(-1)]*G[{0, yu^(-1)}, yw]^2)/32 + 
     (3*G[{1}, yw]*G[{0, yu^(-1)}, yw]^2)/128 - 
     (G[{1/(yu*yv)}, yw]*G[{0, yu^(-1)}, yw]^2)/128 - 
     (Pi^2*G[{1}, yv^(-1)]*G[{0, yu}, yv^(-1)])/48 - 
     (3*G[{0}, yu^(-1)]^2*G[{1}, yv^(-1)]*G[{0, yu}, yv^(-1)])/32 - 
     (3*G[{0}, yu^(-1)]*G[{0}, yv^(-1)]*G[{1}, yv^(-1)]*G[{0, yu}, yv^(-1)])/
      16 - (3*G[{0}, yv^(-1)]^2*G[{1}, yv^(-1)]*G[{0, yu}, yv^(-1)])/32 + 
     (3*G[{0}, yu^(-1)]*G[{0}, yw]*G[{1}, yv^(-1)]*G[{0, yu}, yv^(-1)])/16 + 
     (3*G[{0}, yv^(-1)]*G[{0}, yw]*G[{1}, yv^(-1)]*G[{0, yu}, yv^(-1)])/16 - 
     (3*G[{0}, yw]^2*G[{1}, yv^(-1)]*G[{0, yu}, yv^(-1)])/32 + 
     (G[{0}, yu^(-1)]*G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*G[{0, yu}, yv^(-1)])/
      8 + (G[{0}, yv^(-1)]*G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*
       G[{0, yu}, yv^(-1)])/8 - (G[{0}, yw]*G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*
       G[{0, yu}, yv^(-1)])/8 - (G[{1}, yu^(-1)]^2*G[{1}, yv^(-1)]*
       G[{0, yu}, yv^(-1)])/32 + (5*G[{0}, yu^(-1)]*G[{1}, yv^(-1)]^2*
       G[{0, yu}, yv^(-1)])/32 + (5*G[{0}, yv^(-1)]*G[{1}, yv^(-1)]^2*
       G[{0, yu}, yv^(-1)])/32 - (5*G[{0}, yw]*G[{1}, yv^(-1)]^2*
       G[{0, yu}, yv^(-1)])/32 - (G[{1}, yu^(-1)]*G[{1}, yv^(-1)]^2*
       G[{0, yu}, yv^(-1)])/16 - (5*G[{1}, yv^(-1)]^3*G[{0, yu}, yv^(-1)])/
      96 + (Pi^2*G[{1}, yw]*G[{0, yu}, yv^(-1)])/48 + 
     (3*G[{0}, yu^(-1)]^2*G[{1}, yw]*G[{0, yu}, yv^(-1)])/32 + 
     (3*G[{0}, yu^(-1)]*G[{0}, yv^(-1)]*G[{1}, yw]*G[{0, yu}, yv^(-1)])/16 + 
     (3*G[{0}, yv^(-1)]^2*G[{1}, yw]*G[{0, yu}, yv^(-1)])/32 - 
     (3*G[{0}, yu^(-1)]*G[{0}, yw]*G[{1}, yw]*G[{0, yu}, yv^(-1)])/16 - 
     (3*G[{0}, yv^(-1)]*G[{0}, yw]*G[{1}, yw]*G[{0, yu}, yv^(-1)])/16 + 
     (3*G[{0}, yw]^2*G[{1}, yw]*G[{0, yu}, yv^(-1)])/32 - 
     (G[{0}, yu^(-1)]*G[{1}, yu^(-1)]*G[{1}, yw]*G[{0, yu}, yv^(-1)])/8 - 
     (G[{0}, yv^(-1)]*G[{1}, yu^(-1)]*G[{1}, yw]*G[{0, yu}, yv^(-1)])/8 + 
     (G[{0}, yw]*G[{1}, yu^(-1)]*G[{1}, yw]*G[{0, yu}, yv^(-1)])/8 + 
     (G[{1}, yu^(-1)]^2*G[{1}, yw]*G[{0, yu}, yv^(-1)])/32 - 
     (5*G[{0}, yu^(-1)]*G[{1}, yv^(-1)]*G[{1}, yw]*G[{0, yu}, yv^(-1)])/16 - 
     (5*G[{0}, yv^(-1)]*G[{1}, yv^(-1)]*G[{1}, yw]*G[{0, yu}, yv^(-1)])/16 + 
     (5*G[{0}, yw]*G[{1}, yv^(-1)]*G[{1}, yw]*G[{0, yu}, yv^(-1)])/16 + 
     (G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*G[{1}, yw]*G[{0, yu}, yv^(-1)])/8 + 
     (5*G[{1}, yv^(-1)]^2*G[{1}, yw]*G[{0, yu}, yv^(-1)])/32 + 
     (3*G[{0}, yu^(-1)]*G[{1}, yw]^2*G[{0, yu}, yv^(-1)])/32 + 
     (3*G[{0}, yv^(-1)]*G[{1}, yw]^2*G[{0, yu}, yv^(-1)])/32 - 
     (3*G[{0}, yw]*G[{1}, yw]^2*G[{0, yu}, yv^(-1)])/32 - 
     (G[{1}, yu^(-1)]*G[{1}, yw]^2*G[{0, yu}, yv^(-1)])/16 - 
     (3*G[{1}, yv^(-1)]*G[{1}, yw]^2*G[{0, yu}, yv^(-1)])/32 + 
     (G[{1}, yw]^3*G[{0, yu}, yv^(-1)])/96 - 
     (G[{0}, yu^(-1)]*G[{1}, yw]*G[{yu}, yv^(-1)]*G[{0, yu}, yv^(-1)])/8 - 
     (G[{0}, yv^(-1)]*G[{1}, yw]*G[{yu}, yv^(-1)]*G[{0, yu}, yv^(-1)])/8 + 
     (G[{0}, yw]*G[{1}, yw]*G[{yu}, yv^(-1)]*G[{0, yu}, yv^(-1)])/8 + 
     (G[{1}, yu^(-1)]*G[{1}, yw]*G[{yu}, yv^(-1)]*G[{0, yu}, yv^(-1)])/8 + 
     (G[{1}, yv^(-1)]*G[{1}, yw]*G[{yu}, yv^(-1)]*G[{0, yu}, yv^(-1)])/16 - 
     (G[{1}, yw]^2*G[{yu}, yv^(-1)]*G[{0, yu}, yv^(-1)])/16 + 
     (G[{1}, yw]*G[{yu}, yv^(-1)]^2*G[{0, yu}, yv^(-1)])/16 - 
     (3*G[{0}, yu^(-1)]*G[{1}, yv^(-1)]*G[{1/(yu*yv)}, yw]*
       G[{0, yu}, yv^(-1)])/16 - (3*G[{0}, yv^(-1)]*G[{1}, yv^(-1)]*
       G[{1/(yu*yv)}, yw]*G[{0, yu}, yv^(-1)])/16 + 
     (3*G[{0}, yw]*G[{1}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, yu}, yv^(-1)])/
      16 + (G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*G[{1/(yu*yv)}, yw]*
       G[{0, yu}, yv^(-1)])/8 + (5*G[{1}, yv^(-1)]^2*G[{1/(yu*yv)}, yw]*
       G[{0, yu}, yv^(-1)])/32 - (G[{0}, yu^(-1)]*G[{1}, yw]*
       G[{1/(yu*yv)}, yw]*G[{0, yu}, yv^(-1)])/8 - 
     (G[{0}, yv^(-1)]*G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{0, yu}, yv^(-1)])/8 + 
     (G[{0}, yw]*G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{0, yu}, yv^(-1)])/8 + 
     (G[{1}, yu^(-1)]*G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{0, yu}, yv^(-1)])/8 + 
     (G[{1}, yv^(-1)]*G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{0, yu}, yv^(-1)])/16 - 
     (G[{1}, yw]^2*G[{1/(yu*yv)}, yw]*G[{0, yu}, yv^(-1)])/32 + 
     (3*G[{0}, yu^(-1)]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*
       G[{0, yu}, yv^(-1)])/16 + (3*G[{0}, yv^(-1)]*G[{yu^(-1)}, yw]*
       G[{1/(yu*yv)}, yw]*G[{0, yu}, yv^(-1)])/16 - 
     (3*G[{0}, yw]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{0, yu}, yv^(-1)])/
      16 - (G[{1}, yu^(-1)]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*
       G[{0, yu}, yv^(-1)])/8 - (5*G[{1}, yv^(-1)]*G[{yu^(-1)}, yw]*
       G[{1/(yu*yv)}, yw]*G[{0, yu}, yv^(-1)])/16 - 
     (G[{1}, yw]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{0, yu}, yv^(-1)])/
      16 + (G[{yu^(-1)}, yw]^2*G[{1/(yu*yv)}, yw]*G[{0, yu}, yv^(-1)])/8 + 
     (G[{0}, yu^(-1)]*G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw]*
       G[{0, yu}, yv^(-1)])/8 + (G[{0}, yv^(-1)]*G[{yu}, yv^(-1)]*
       G[{1/(yu*yv)}, yw]*G[{0, yu}, yv^(-1)])/8 - 
     (G[{0}, yw]*G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, yu}, yv^(-1)])/8 - 
     (G[{1}, yu^(-1)]*G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw]*
       G[{0, yu}, yv^(-1)])/8 - (G[{1}, yv^(-1)]*G[{yu}, yv^(-1)]*
       G[{1/(yu*yv)}, yw]*G[{0, yu}, yv^(-1)])/16 + 
     (G[{1}, yw]*G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, yu}, yv^(-1)])/8 - 
     (G[{yu}, yv^(-1)]^2*G[{1/(yu*yv)}, yw]*G[{0, yu}, yv^(-1)])/16 - 
     (G[{1}, yv^(-1)]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*
       G[{0, yu}, yv^(-1)])/8 - (G[{1}, yw]*G[{yv^(-1)}, yw]*
       G[{1/(yu*yv)}, yw]*G[{0, yu}, yv^(-1)])/8 + 
     (G[{yu^(-1)}, yw]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*
       G[{0, yu}, yv^(-1)])/8 + (G[{yu}, yv^(-1)]*G[{yv^(-1)}, yw]*
       G[{1/(yu*yv)}, yw]*G[{0, yu}, yv^(-1)])/8 + 
     (G[{1}, yv^(-1)]*G[{0, 1}, yu^(-1)]*G[{0, yu}, yv^(-1)])/16 - 
     (G[{1}, yw]*G[{0, 1}, yu^(-1)]*G[{0, yu}, yv^(-1)])/16 - 
     (G[{1}, yv^(-1)]*G[{0, 1}, yv^(-1)]*G[{0, yu}, yv^(-1)])/16 + 
     (G[{1}, yw]*G[{0, 1}, yv^(-1)]*G[{0, yu}, yv^(-1)])/16 + 
     (G[{1/(yu*yv)}, yw]*G[{0, 1}, yv^(-1)]*G[{0, yu}, yv^(-1)])/16 + 
     (3*G[{0}, yu^(-1)]*G[{0, 1}, yw]*G[{0, yu}, yv^(-1)])/16 + 
     (3*G[{0}, yv^(-1)]*G[{0, 1}, yw]*G[{0, yu}, yv^(-1)])/16 - 
     (3*G[{0}, yw]*G[{0, 1}, yw]*G[{0, yu}, yv^(-1)])/16 - 
     (G[{1}, yu^(-1)]*G[{0, 1}, yw]*G[{0, yu}, yv^(-1)])/8 - 
     (G[{1}, yv^(-1)]*G[{0, 1}, yw]*G[{0, yu}, yv^(-1)])/4 + 
     (G[{1}, yw]*G[{0, 1}, yw]*G[{0, yu}, yv^(-1)])/8 - 
     (G[{yu}, yv^(-1)]*G[{0, 1}, yw]*G[{0, yu}, yv^(-1)])/8 - 
     (3*G[{0}, yu^(-1)]*G[{0, yu^(-1)}, yw]*G[{0, yu}, yv^(-1)])/16 - 
     (3*G[{0}, yv^(-1)]*G[{0, yu^(-1)}, yw]*G[{0, yu}, yv^(-1)])/16 + 
     (3*G[{0}, yw]*G[{0, yu^(-1)}, yw]*G[{0, yu}, yv^(-1)])/16 + 
     (G[{1}, yu^(-1)]*G[{0, yu^(-1)}, yw]*G[{0, yu}, yv^(-1)])/8 + 
     (5*G[{1}, yv^(-1)]*G[{0, yu^(-1)}, yw]*G[{0, yu}, yv^(-1)])/16 - 
     (G[{1}, yw]*G[{0, yu^(-1)}, yw]*G[{0, yu}, yv^(-1)])/16 + 
     (G[{1}, yv^(-1)]*G[{0, yu}, yv^(-1)]^2)/32 - 
     (G[{1}, yw]*G[{0, yu}, yv^(-1)]^2)/32 - 
     (G[{1/(yu*yv)}, yw]*G[{0, yu}, yv^(-1)]^2)/32 - 
     (Pi^2*G[{0}, yu^(-1)]*G[{0, yv^(-1)}, yw])/256 - 
     (Pi^2*G[{0}, yv^(-1)]*G[{0, yv^(-1)}, yw])/256 + 
     (Pi^2*G[{0}, yw]*G[{0, yv^(-1)}, yw])/256 + 
     (Pi^2*G[{1}, yu^(-1)]*G[{0, yv^(-1)}, yw])/256 + 
     (3*G[{0}, yu^(-1)]*G[{1}, yu^(-1)]^2*G[{0, yv^(-1)}, yw])/64 + 
     (3*G[{0}, yv^(-1)]*G[{1}, yu^(-1)]^2*G[{0, yv^(-1)}, yw])/64 - 
     (3*G[{0}, yw]*G[{1}, yu^(-1)]^2*G[{0, yv^(-1)}, yw])/64 - 
     (3*G[{1}, yu^(-1)]^3*G[{0, yv^(-1)}, yw])/64 - 
     (13*Pi^2*G[{1}, yv^(-1)]*G[{0, yv^(-1)}, yw])/768 - 
     (3*G[{0}, yu^(-1)]*G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*G[{0, yv^(-1)}, yw])/
      32 - (3*G[{0}, yv^(-1)]*G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*
       G[{0, yv^(-1)}, yw])/32 + (3*G[{0}, yw]*G[{1}, yu^(-1)]*
       G[{1}, yv^(-1)]*G[{0, yv^(-1)}, yw])/32 + 
     (3*G[{1}, yu^(-1)]^2*G[{1}, yv^(-1)]*G[{0, yv^(-1)}, yw])/64 + 
     (G[{1}, yu^(-1)]*G[{1}, yv^(-1)]^2*G[{0, yv^(-1)}, yw])/16 + 
     (7*Pi^2*G[{1}, yw]*G[{0, yv^(-1)}, yw])/768 + 
     (3*G[{0}, yu^(-1)]^2*G[{1}, yw]*G[{0, yv^(-1)}, yw])/64 + 
     (3*G[{0}, yu^(-1)]*G[{0}, yv^(-1)]*G[{1}, yw]*G[{0, yv^(-1)}, yw])/32 + 
     (3*G[{0}, yv^(-1)]^2*G[{1}, yw]*G[{0, yv^(-1)}, yw])/64 - 
     (3*G[{0}, yu^(-1)]*G[{0}, yw]*G[{1}, yw]*G[{0, yv^(-1)}, yw])/32 - 
     (3*G[{0}, yv^(-1)]*G[{0}, yw]*G[{1}, yw]*G[{0, yv^(-1)}, yw])/32 + 
     (3*G[{0}, yw]^2*G[{1}, yw]*G[{0, yv^(-1)}, yw])/64 - 
     (G[{0}, yu^(-1)]*G[{1}, yu^(-1)]*G[{1}, yw]*G[{0, yv^(-1)}, yw])/8 - 
     (G[{0}, yv^(-1)]*G[{1}, yu^(-1)]*G[{1}, yw]*G[{0, yv^(-1)}, yw])/8 + 
     (G[{0}, yw]*G[{1}, yu^(-1)]*G[{1}, yw]*G[{0, yv^(-1)}, yw])/8 + 
     (13*G[{1}, yu^(-1)]^2*G[{1}, yw]*G[{0, yv^(-1)}, yw])/128 - 
     (3*G[{0}, yu^(-1)]*G[{1}, yv^(-1)]*G[{1}, yw]*G[{0, yv^(-1)}, yw])/32 - 
     (3*G[{0}, yv^(-1)]*G[{1}, yv^(-1)]*G[{1}, yw]*G[{0, yv^(-1)}, yw])/32 + 
     (3*G[{0}, yw]*G[{1}, yv^(-1)]*G[{1}, yw]*G[{0, yv^(-1)}, yw])/32 + 
     (9*G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*G[{1}, yw]*G[{0, yv^(-1)}, yw])/64 + 
     (3*G[{1}, yv^(-1)]^2*G[{1}, yw]*G[{0, yv^(-1)}, yw])/64 + 
     (7*G[{0}, yu^(-1)]*G[{1}, yw]^2*G[{0, yv^(-1)}, yw])/128 + 
     (7*G[{0}, yv^(-1)]*G[{1}, yw]^2*G[{0, yv^(-1)}, yw])/128 - 
     (7*G[{0}, yw]*G[{1}, yw]^2*G[{0, yv^(-1)}, yw])/128 - 
     (9*G[{1}, yu^(-1)]*G[{1}, yw]^2*G[{0, yv^(-1)}, yw])/128 - 
     (7*G[{1}, yv^(-1)]*G[{1}, yw]^2*G[{0, yv^(-1)}, yw])/128 - 
     (G[{1}, yw]^3*G[{0, yv^(-1)}, yw])/128 + 
     (G[{0}, yu^(-1)]*G[{1}, yw]*G[{yu}, yv^(-1)]*G[{0, yv^(-1)}, yw])/32 + 
     (G[{0}, yv^(-1)]*G[{1}, yw]*G[{yu}, yv^(-1)]*G[{0, yv^(-1)}, yw])/32 - 
     (G[{0}, yw]*G[{1}, yw]*G[{yu}, yv^(-1)]*G[{0, yv^(-1)}, yw])/32 - 
     (3*G[{1}, yu^(-1)]*G[{1}, yw]*G[{yu}, yv^(-1)]*G[{0, yv^(-1)}, yw])/32 - 
     (G[{1}, yv^(-1)]*G[{1}, yw]*G[{yu}, yv^(-1)]*G[{0, yv^(-1)}, yw])/32 + 
     (G[{1}, yw]^2*G[{yu}, yv^(-1)]*G[{0, yv^(-1)}, yw])/64 + 
     (G[{1}, yw]*G[{yu}, yv^(-1)]^2*G[{0, yv^(-1)}, yw])/32 - 
     (3*Pi^2*G[{1/(yu*yv)}, yw]*G[{0, yv^(-1)}, yw])/256 - 
     (3*G[{0}, yu^(-1)]^2*G[{1/(yu*yv)}, yw]*G[{0, yv^(-1)}, yw])/64 - 
     (3*G[{0}, yu^(-1)]*G[{0}, yv^(-1)]*G[{1/(yu*yv)}, yw]*
       G[{0, yv^(-1)}, yw])/32 - (3*G[{0}, yv^(-1)]^2*G[{1/(yu*yv)}, yw]*
       G[{0, yv^(-1)}, yw])/64 + (3*G[{0}, yu^(-1)]*G[{0}, yw]*
       G[{1/(yu*yv)}, yw]*G[{0, yv^(-1)}, yw])/32 + 
     (3*G[{0}, yv^(-1)]*G[{0}, yw]*G[{1/(yu*yv)}, yw]*G[{0, yv^(-1)}, yw])/
      32 - (3*G[{0}, yw]^2*G[{1/(yu*yv)}, yw]*G[{0, yv^(-1)}, yw])/64 + 
     (G[{0}, yu^(-1)]*G[{1}, yu^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, yv^(-1)}, yw])/
      16 + (G[{0}, yv^(-1)]*G[{1}, yu^(-1)]*G[{1/(yu*yv)}, yw]*
       G[{0, yv^(-1)}, yw])/16 - (G[{0}, yw]*G[{1}, yu^(-1)]*
       G[{1/(yu*yv)}, yw]*G[{0, yv^(-1)}, yw])/16 + 
     (G[{1}, yu^(-1)]^2*G[{1/(yu*yv)}, yw]*G[{0, yv^(-1)}, yw])/128 + 
     (5*G[{0}, yu^(-1)]*G[{1}, yv^(-1)]*G[{1/(yu*yv)}, yw]*
       G[{0, yv^(-1)}, yw])/32 + (5*G[{0}, yv^(-1)]*G[{1}, yv^(-1)]*
       G[{1/(yu*yv)}, yw]*G[{0, yv^(-1)}, yw])/32 - 
     (5*G[{0}, yw]*G[{1}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, yv^(-1)}, yw])/
      32 - (15*G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*G[{1/(yu*yv)}, yw]*
       G[{0, yv^(-1)}, yw])/64 - (5*G[{1}, yv^(-1)]^2*G[{1/(yu*yv)}, yw]*
       G[{0, yv^(-1)}, yw])/64 - (G[{0}, yu^(-1)]*G[{1}, yw]*
       G[{1/(yu*yv)}, yw]*G[{0, yv^(-1)}, yw])/64 - 
     (G[{0}, yv^(-1)]*G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{0, yv^(-1)}, yw])/64 + 
     (G[{0}, yw]*G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{0, yv^(-1)}, yw])/64 - 
     (3*G[{1}, yu^(-1)]*G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{0, yv^(-1)}, yw])/
      64 + (5*G[{1}, yv^(-1)]*G[{1}, yw]*G[{1/(yu*yv)}, yw]*
       G[{0, yv^(-1)}, yw])/64 + (G[{1}, yw]^2*G[{1/(yu*yv)}, yw]*
       G[{0, yv^(-1)}, yw])/128 - (G[{1}, yu^(-1)]*G[{yu^(-1)}, yw]*
       G[{1/(yu*yv)}, yw]*G[{0, yv^(-1)}, yw])/16 + 
     (G[{1}, yv^(-1)]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*
       G[{0, yv^(-1)}, yw])/16 - (G[{1}, yw]*G[{yu^(-1)}, yw]*
       G[{1/(yu*yv)}, yw]*G[{0, yv^(-1)}, yw])/32 - 
     (G[{yu^(-1)}, yw]^2*G[{1/(yu*yv)}, yw]*G[{0, yv^(-1)}, yw])/16 - 
     (G[{0}, yu^(-1)]*G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw]*
       G[{0, yv^(-1)}, yw])/32 - (G[{0}, yv^(-1)]*G[{yu}, yv^(-1)]*
       G[{1/(yu*yv)}, yw]*G[{0, yv^(-1)}, yw])/32 + 
     (G[{0}, yw]*G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, yv^(-1)}, yw])/
      32 + (3*G[{1}, yu^(-1)]*G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw]*
       G[{0, yv^(-1)}, yw])/32 + (G[{1}, yv^(-1)]*G[{yu}, yv^(-1)]*
       G[{1/(yu*yv)}, yw]*G[{0, yv^(-1)}, yw])/32 - 
     (G[{yu}, yv^(-1)]^2*G[{1/(yu*yv)}, yw]*G[{0, yv^(-1)}, yw])/32 + 
     (G[{0}, yu^(-1)]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*
       G[{0, yv^(-1)}, yw])/32 + (G[{0}, yv^(-1)]*G[{yv^(-1)}, yw]*
       G[{1/(yu*yv)}, yw]*G[{0, yv^(-1)}, yw])/32 - 
     (G[{0}, yw]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{0, yv^(-1)}, yw])/
      32 - (3*G[{1}, yu^(-1)]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*
       G[{0, yv^(-1)}, yw])/32 + (3*G[{1}, yv^(-1)]*G[{yv^(-1)}, yw]*
       G[{1/(yu*yv)}, yw]*G[{0, yv^(-1)}, yw])/32 + 
     (9*G[{1}, yw]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{0, yv^(-1)}, yw])/
      64 - (G[{yu}, yv^(-1)]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*
       G[{0, yv^(-1)}, yw])/16 + (3*G[{yv^(-1)}, yw]^2*G[{1/(yu*yv)}, yw]*
       G[{0, yv^(-1)}, yw])/32 - (3*G[{0}, yu^(-1)]*G[{1/(yu*yv)}, yw]^2*
       G[{0, yv^(-1)}, yw])/128 - (3*G[{0}, yv^(-1)]*G[{1/(yu*yv)}, yw]^2*
       G[{0, yv^(-1)}, yw])/128 + (3*G[{0}, yw]*G[{1/(yu*yv)}, yw]^2*
       G[{0, yv^(-1)}, yw])/128 - (3*G[{1}, yu^(-1)]*G[{1/(yu*yv)}, yw]^2*
       G[{0, yv^(-1)}, yw])/128 + (7*G[{1}, yv^(-1)]*G[{1/(yu*yv)}, yw]^2*
       G[{0, yv^(-1)}, yw])/128 - (G[{1}, yw]*G[{1/(yu*yv)}, yw]^2*
       G[{0, yv^(-1)}, yw])/64 - (G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2*
       G[{0, yv^(-1)}, yw])/128 + (G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw]^2*
       G[{0, yv^(-1)}, yw])/64 + (9*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2*
       G[{0, yv^(-1)}, yw])/128 - (3*G[{0}, yu^(-1)]*G[{0, 1}, yu^(-1)]*
       G[{0, yv^(-1)}, yw])/32 - (3*G[{0}, yv^(-1)]*G[{0, 1}, yu^(-1)]*
       G[{0, yv^(-1)}, yw])/32 + (3*G[{0}, yw]*G[{0, 1}, yu^(-1)]*
       G[{0, yv^(-1)}, yw])/32 + (G[{1}, yu^(-1)]*G[{0, 1}, yu^(-1)]*
       G[{0, yv^(-1)}, yw])/32 + (G[{1}, yv^(-1)]*G[{0, 1}, yu^(-1)]*
       G[{0, yv^(-1)}, yw])/32 + (G[{1}, yw]*G[{0, 1}, yu^(-1)]*
       G[{0, yv^(-1)}, yw])/64 - (3*G[{1/(yu*yv)}, yw]*G[{0, 1}, yu^(-1)]*
       G[{0, yv^(-1)}, yw])/64 - (G[{1}, yv^(-1)]*G[{0, 1}, yv^(-1)]*
       G[{0, yv^(-1)}, yw])/8 - (G[{0}, yu^(-1)]*G[{0, 1}, yw]*
       G[{0, yv^(-1)}, yw])/16 - (G[{0}, yv^(-1)]*G[{0, 1}, yw]*
       G[{0, yv^(-1)}, yw])/16 + (G[{0}, yw]*G[{0, 1}, yw]*
       G[{0, yv^(-1)}, yw])/16 - (G[{1}, yu^(-1)]*G[{0, 1}, yw]*
       G[{0, yv^(-1)}, yw])/16 + (G[{1}, yv^(-1)]*G[{0, 1}, yw]*
       G[{0, yv^(-1)}, yw])/16 + (G[{1}, yw]*G[{0, 1}, yw]*
       G[{0, yv^(-1)}, yw])/64 + (G[{yu}, yv^(-1)]*G[{0, 1}, yw]*
       G[{0, yv^(-1)}, yw])/8 + (G[{1/(yu*yv)}, yw]*G[{0, 1}, yw]*
       G[{0, yv^(-1)}, yw])/64 + (G[{0}, yu^(-1)]*G[{0, yu^(-1)}, yw]*
       G[{0, yv^(-1)}, yw])/16 + (G[{0}, yv^(-1)]*G[{0, yu^(-1)}, yw]*
       G[{0, yv^(-1)}, yw])/16 - (G[{0}, yw]*G[{0, yu^(-1)}, yw]*
       G[{0, yv^(-1)}, yw])/16 + (G[{1}, yu^(-1)]*G[{0, yu^(-1)}, yw]*
       G[{0, yv^(-1)}, yw])/16 - (3*G[{1}, yv^(-1)]*G[{0, yu^(-1)}, yw]*
       G[{0, yv^(-1)}, yw])/16 - (G[{1}, yw]*G[{0, yu^(-1)}, yw]*
       G[{0, yv^(-1)}, yw])/64 - (G[{1/(yu*yv)}, yw]*G[{0, yu^(-1)}, yw]*
       G[{0, yv^(-1)}, yw])/64 + (G[{1}, yv^(-1)]*G[{0, yu}, yv^(-1)]*
       G[{0, yv^(-1)}, yw])/8 + (G[{0}, yu^(-1)]*G[{0, yv^(-1)}, yw]^2)/32 + 
     (G[{0}, yv^(-1)]*G[{0, yv^(-1)}, yw]^2)/32 - 
     (G[{0}, yw]*G[{0, yv^(-1)}, yw]^2)/32 - 
     (G[{1}, yu^(-1)]*G[{0, yv^(-1)}, yw]^2)/32 - 
     (G[{1}, yv^(-1)]*G[{0, yv^(-1)}, yw]^2)/32 - 
     (G[{1}, yw]*G[{0, yv^(-1)}, yw]^2)/128 - 
     (G[{1/(yu*yv)}, yw]*G[{0, yv^(-1)}, yw]^2)/128 - 
     (5*Pi^2*G[{0}, yu^(-1)]*G[{0, 1/(yu*yv)}, yw])/768 - 
     (5*Pi^2*G[{0}, yv^(-1)]*G[{0, 1/(yu*yv)}, yw])/768 + 
     (5*Pi^2*G[{0}, yw]*G[{0, 1/(yu*yv)}, yw])/768 - 
     (Pi^2*G[{1}, yu^(-1)]*G[{0, 1/(yu*yv)}, yw])/256 - 
     (3*G[{0}, yu^(-1)]*G[{1}, yu^(-1)]^2*G[{0, 1/(yu*yv)}, yw])/64 - 
     (3*G[{0}, yv^(-1)]*G[{1}, yu^(-1)]^2*G[{0, 1/(yu*yv)}, yw])/64 + 
     (3*G[{0}, yw]*G[{1}, yu^(-1)]^2*G[{0, 1/(yu*yv)}, yw])/64 + 
     (3*G[{1}, yu^(-1)]^3*G[{0, 1/(yu*yv)}, yw])/64 + 
     (37*Pi^2*G[{1}, yv^(-1)]*G[{0, 1/(yu*yv)}, yw])/768 + 
     (3*G[{0}, yu^(-1)]^2*G[{1}, yv^(-1)]*G[{0, 1/(yu*yv)}, yw])/32 + 
     (3*G[{0}, yu^(-1)]*G[{0}, yv^(-1)]*G[{1}, yv^(-1)]*
       G[{0, 1/(yu*yv)}, yw])/16 + (3*G[{0}, yv^(-1)]^2*G[{1}, yv^(-1)]*
       G[{0, 1/(yu*yv)}, yw])/32 - (3*G[{0}, yu^(-1)]*G[{0}, yw]*
       G[{1}, yv^(-1)]*G[{0, 1/(yu*yv)}, yw])/16 - 
     (3*G[{0}, yv^(-1)]*G[{0}, yw]*G[{1}, yv^(-1)]*G[{0, 1/(yu*yv)}, yw])/
      16 + (3*G[{0}, yw]^2*G[{1}, yv^(-1)]*G[{0, 1/(yu*yv)}, yw])/32 - 
     (G[{0}, yu^(-1)]*G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*G[{0, 1/(yu*yv)}, yw])/
      32 - (G[{0}, yv^(-1)]*G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*
       G[{0, 1/(yu*yv)}, yw])/32 + (G[{0}, yw]*G[{1}, yu^(-1)]*
       G[{1}, yv^(-1)]*G[{0, 1/(yu*yv)}, yw])/32 - 
     (G[{1}, yu^(-1)]^2*G[{1}, yv^(-1)]*G[{0, 1/(yu*yv)}, yw])/64 - 
     (5*G[{0}, yu^(-1)]*G[{1}, yv^(-1)]^2*G[{0, 1/(yu*yv)}, yw])/32 - 
     (5*G[{0}, yv^(-1)]*G[{1}, yv^(-1)]^2*G[{0, 1/(yu*yv)}, yw])/32 + 
     (5*G[{0}, yw]*G[{1}, yv^(-1)]^2*G[{0, 1/(yu*yv)}, yw])/32 + 
     (G[{1}, yu^(-1)]*G[{1}, yv^(-1)]^2*G[{0, 1/(yu*yv)}, yw])/32 + 
     (G[{1}, yv^(-1)]^3*G[{0, 1/(yu*yv)}, yw])/16 + 
     (Pi^2*G[{1}, yw]*G[{0, 1/(yu*yv)}, yw])/768 - 
     (3*G[{0}, yu^(-1)]^2*G[{1}, yw]*G[{0, 1/(yu*yv)}, yw])/64 - 
     (3*G[{0}, yu^(-1)]*G[{0}, yv^(-1)]*G[{1}, yw]*G[{0, 1/(yu*yv)}, yw])/
      32 - (3*G[{0}, yv^(-1)]^2*G[{1}, yw]*G[{0, 1/(yu*yv)}, yw])/64 + 
     (3*G[{0}, yu^(-1)]*G[{0}, yw]*G[{1}, yw]*G[{0, 1/(yu*yv)}, yw])/32 + 
     (3*G[{0}, yv^(-1)]*G[{0}, yw]*G[{1}, yw]*G[{0, 1/(yu*yv)}, yw])/32 - 
     (3*G[{0}, yw]^2*G[{1}, yw]*G[{0, 1/(yu*yv)}, yw])/64 + 
     (G[{0}, yu^(-1)]*G[{1}, yu^(-1)]*G[{1}, yw]*G[{0, 1/(yu*yv)}, yw])/8 + 
     (G[{0}, yv^(-1)]*G[{1}, yu^(-1)]*G[{1}, yw]*G[{0, 1/(yu*yv)}, yw])/8 - 
     (G[{0}, yw]*G[{1}, yu^(-1)]*G[{1}, yw]*G[{0, 1/(yu*yv)}, yw])/8 - 
     (13*G[{1}, yu^(-1)]^2*G[{1}, yw]*G[{0, 1/(yu*yv)}, yw])/128 + 
     (7*G[{0}, yu^(-1)]*G[{1}, yv^(-1)]*G[{1}, yw]*G[{0, 1/(yu*yv)}, yw])/
      32 + (7*G[{0}, yv^(-1)]*G[{1}, yv^(-1)]*G[{1}, yw]*
       G[{0, 1/(yu*yv)}, yw])/32 - (7*G[{0}, yw]*G[{1}, yv^(-1)]*G[{1}, yw]*
       G[{0, 1/(yu*yv)}, yw])/32 - (9*G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*
       G[{1}, yw]*G[{0, 1/(yu*yv)}, yw])/64 - 
     (11*G[{1}, yv^(-1)]^2*G[{1}, yw]*G[{0, 1/(yu*yv)}, yw])/64 - 
     (7*G[{0}, yu^(-1)]*G[{1}, yw]^2*G[{0, 1/(yu*yv)}, yw])/128 - 
     (7*G[{0}, yv^(-1)]*G[{1}, yw]^2*G[{0, 1/(yu*yv)}, yw])/128 + 
     (7*G[{0}, yw]*G[{1}, yw]^2*G[{0, 1/(yu*yv)}, yw])/128 + 
     (9*G[{1}, yu^(-1)]*G[{1}, yw]^2*G[{0, 1/(yu*yv)}, yw])/128 + 
     (7*G[{1}, yv^(-1)]*G[{1}, yw]^2*G[{0, 1/(yu*yv)}, yw])/128 + 
     (G[{1}, yw]^3*G[{0, 1/(yu*yv)}, yw])/128 - 
     (Pi^2*G[{yu}, yv^(-1)]*G[{0, 1/(yu*yv)}, yw])/48 - 
     (3*G[{0}, yu^(-1)]^2*G[{yu}, yv^(-1)]*G[{0, 1/(yu*yv)}, yw])/32 - 
     (3*G[{0}, yu^(-1)]*G[{0}, yv^(-1)]*G[{yu}, yv^(-1)]*
       G[{0, 1/(yu*yv)}, yw])/16 - (3*G[{0}, yv^(-1)]^2*G[{yu}, yv^(-1)]*
       G[{0, 1/(yu*yv)}, yw])/32 + (3*G[{0}, yu^(-1)]*G[{0}, yw]*
       G[{yu}, yv^(-1)]*G[{0, 1/(yu*yv)}, yw])/16 + 
     (3*G[{0}, yv^(-1)]*G[{0}, yw]*G[{yu}, yv^(-1)]*G[{0, 1/(yu*yv)}, yw])/
      16 - (3*G[{0}, yw]^2*G[{yu}, yv^(-1)]*G[{0, 1/(yu*yv)}, yw])/32 + 
     (G[{0}, yu^(-1)]*G[{1}, yu^(-1)]*G[{yu}, yv^(-1)]*G[{0, 1/(yu*yv)}, yw])/
      8 + (G[{0}, yv^(-1)]*G[{1}, yu^(-1)]*G[{yu}, yv^(-1)]*
       G[{0, 1/(yu*yv)}, yw])/8 - (G[{0}, yw]*G[{1}, yu^(-1)]*
       G[{yu}, yv^(-1)]*G[{0, 1/(yu*yv)}, yw])/8 - 
     (G[{1}, yu^(-1)]^2*G[{yu}, yv^(-1)]*G[{0, 1/(yu*yv)}, yw])/32 + 
     (G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*G[{yu}, yv^(-1)]*G[{0, 1/(yu*yv)}, yw])/
      16 + (G[{1}, yv^(-1)]^2*G[{yu}, yv^(-1)]*G[{0, 1/(yu*yv)}, yw])/16 - 
     (5*G[{0}, yu^(-1)]*G[{1}, yw]*G[{yu}, yv^(-1)]*G[{0, 1/(yu*yv)}, yw])/
      32 - (5*G[{0}, yv^(-1)]*G[{1}, yw]*G[{yu}, yv^(-1)]*
       G[{0, 1/(yu*yv)}, yw])/32 + (5*G[{0}, yw]*G[{1}, yw]*G[{yu}, yv^(-1)]*
       G[{0, 1/(yu*yv)}, yw])/32 + (3*G[{1}, yu^(-1)]*G[{1}, yw]*
       G[{yu}, yv^(-1)]*G[{0, 1/(yu*yv)}, yw])/32 + 
     (G[{1}, yv^(-1)]*G[{1}, yw]*G[{yu}, yv^(-1)]*G[{0, 1/(yu*yv)}, yw])/32 - 
     (G[{1}, yw]^2*G[{yu}, yv^(-1)]*G[{0, 1/(yu*yv)}, yw])/64 + 
     (G[{0}, yu^(-1)]*G[{yu}, yv^(-1)]^2*G[{0, 1/(yu*yv)}, yw])/8 + 
     (G[{0}, yv^(-1)]*G[{yu}, yv^(-1)]^2*G[{0, 1/(yu*yv)}, yw])/8 - 
     (G[{0}, yw]*G[{yu}, yv^(-1)]^2*G[{0, 1/(yu*yv)}, yw])/8 - 
     (G[{1}, yu^(-1)]*G[{yu}, yv^(-1)]^2*G[{0, 1/(yu*yv)}, yw])/8 + 
     (3*G[{1}, yw]*G[{yu}, yv^(-1)]^2*G[{0, 1/(yu*yv)}, yw])/32 - 
     (G[{yu}, yv^(-1)]^3*G[{0, 1/(yu*yv)}, yw])/24 + 
     (3*Pi^2*G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv)}, yw])/256 + 
     (3*G[{0}, yu^(-1)]^2*G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv)}, yw])/64 + 
     (3*G[{0}, yu^(-1)]*G[{0}, yv^(-1)]*G[{1/(yu*yv)}, yw]*
       G[{0, 1/(yu*yv)}, yw])/32 + (3*G[{0}, yv^(-1)]^2*G[{1/(yu*yv)}, yw]*
       G[{0, 1/(yu*yv)}, yw])/64 - (3*G[{0}, yu^(-1)]*G[{0}, yw]*
       G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv)}, yw])/32 - 
     (3*G[{0}, yv^(-1)]*G[{0}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv)}, yw])/
      32 + (3*G[{0}, yw]^2*G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv)}, yw])/64 - 
     (G[{0}, yu^(-1)]*G[{1}, yu^(-1)]*G[{1/(yu*yv)}, yw]*
       G[{0, 1/(yu*yv)}, yw])/16 - (G[{0}, yv^(-1)]*G[{1}, yu^(-1)]*
       G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv)}, yw])/16 + 
     (G[{0}, yw]*G[{1}, yu^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv)}, yw])/
      16 - (G[{1}, yu^(-1)]^2*G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv)}, yw])/128 - 
     (3*G[{0}, yu^(-1)]*G[{1}, yv^(-1)]*G[{1/(yu*yv)}, yw]*
       G[{0, 1/(yu*yv)}, yw])/32 - (3*G[{0}, yv^(-1)]*G[{1}, yv^(-1)]*
       G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv)}, yw])/32 + 
     (3*G[{0}, yw]*G[{1}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv)}, yw])/
      32 + (15*G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*G[{1/(yu*yv)}, yw]*
       G[{0, 1/(yu*yv)}, yw])/64 + (G[{1}, yv^(-1)]^2*G[{1/(yu*yv)}, yw]*
       G[{0, 1/(yu*yv)}, yw])/64 + (G[{0}, yu^(-1)]*G[{1}, yw]*
       G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv)}, yw])/64 + 
     (G[{0}, yv^(-1)]*G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv)}, yw])/
      64 - (G[{0}, yw]*G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv)}, yw])/
      64 + (3*G[{1}, yu^(-1)]*G[{1}, yw]*G[{1/(yu*yv)}, yw]*
       G[{0, 1/(yu*yv)}, yw])/64 - (5*G[{1}, yv^(-1)]*G[{1}, yw]*
       G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv)}, yw])/64 - 
     (G[{1}, yw]^2*G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv)}, yw])/128 + 
     (G[{1}, yu^(-1)]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*
       G[{0, 1/(yu*yv)}, yw])/16 - (G[{1}, yv^(-1)]*G[{yu^(-1)}, yw]*
       G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv)}, yw])/16 + 
     (G[{1}, yw]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv)}, yw])/
      32 + (G[{yu^(-1)}, yw]^2*G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv)}, yw])/16 - 
     (G[{0}, yu^(-1)]*G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw]*
       G[{0, 1/(yu*yv)}, yw])/32 - (G[{0}, yv^(-1)]*G[{yu}, yv^(-1)]*
       G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv)}, yw])/32 + 
     (G[{0}, yw]*G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv)}, yw])/
      32 - (3*G[{1}, yu^(-1)]*G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw]*
       G[{0, 1/(yu*yv)}, yw])/32 - (G[{1}, yv^(-1)]*G[{yu}, yv^(-1)]*
       G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv)}, yw])/32 + 
     (3*G[{yu}, yv^(-1)]^2*G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv)}, yw])/32 - 
     (G[{0}, yu^(-1)]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*
       G[{0, 1/(yu*yv)}, yw])/32 - (G[{0}, yv^(-1)]*G[{yv^(-1)}, yw]*
       G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv)}, yw])/32 + 
     (G[{0}, yw]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv)}, yw])/
      32 + (3*G[{1}, yu^(-1)]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*
       G[{0, 1/(yu*yv)}, yw])/32 - (3*G[{1}, yv^(-1)]*G[{yv^(-1)}, yw]*
       G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv)}, yw])/32 - 
     (9*G[{1}, yw]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv)}, yw])/
      64 + (G[{yu}, yv^(-1)]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*
       G[{0, 1/(yu*yv)}, yw])/16 - (3*G[{yv^(-1)}, yw]^2*G[{1/(yu*yv)}, yw]*
       G[{0, 1/(yu*yv)}, yw])/32 + (3*G[{0}, yu^(-1)]*G[{1/(yu*yv)}, yw]^2*
       G[{0, 1/(yu*yv)}, yw])/128 + (3*G[{0}, yv^(-1)]*G[{1/(yu*yv)}, yw]^2*
       G[{0, 1/(yu*yv)}, yw])/128 - (3*G[{0}, yw]*G[{1/(yu*yv)}, yw]^2*
       G[{0, 1/(yu*yv)}, yw])/128 + (3*G[{1}, yu^(-1)]*G[{1/(yu*yv)}, yw]^2*
       G[{0, 1/(yu*yv)}, yw])/128 - (7*G[{1}, yv^(-1)]*G[{1/(yu*yv)}, yw]^2*
       G[{0, 1/(yu*yv)}, yw])/128 + (G[{1}, yw]*G[{1/(yu*yv)}, yw]^2*
       G[{0, 1/(yu*yv)}, yw])/64 + (G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2*
       G[{0, 1/(yu*yv)}, yw])/128 - (G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw]^2*
       G[{0, 1/(yu*yv)}, yw])/64 - (9*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2*
       G[{0, 1/(yu*yv)}, yw])/128 + (G[{0}, yu^(-1)]*G[{0, 1}, yu^(-1)]*
       G[{0, 1/(yu*yv)}, yw])/32 + (G[{0}, yv^(-1)]*G[{0, 1}, yu^(-1)]*
       G[{0, 1/(yu*yv)}, yw])/32 - (G[{0}, yw]*G[{0, 1}, yu^(-1)]*
       G[{0, 1/(yu*yv)}, yw])/32 - (G[{1}, yu^(-1)]*G[{0, 1}, yu^(-1)]*
       G[{0, 1/(yu*yv)}, yw])/32 - (G[{1}, yv^(-1)]*G[{0, 1}, yu^(-1)]*
       G[{0, 1/(yu*yv)}, yw])/32 + (3*G[{1}, yw]*G[{0, 1}, yu^(-1)]*
       G[{0, 1/(yu*yv)}, yw])/64 + (G[{yu}, yv^(-1)]*G[{0, 1}, yu^(-1)]*
       G[{0, 1/(yu*yv)}, yw])/16 + (3*G[{1/(yu*yv)}, yw]*G[{0, 1}, yu^(-1)]*
       G[{0, 1/(yu*yv)}, yw])/64 + (3*G[{1}, yv^(-1)]*G[{0, 1}, yv^(-1)]*
       G[{0, 1/(yu*yv)}, yw])/16 + (G[{1}, yw]*G[{0, 1}, yv^(-1)]*
       G[{0, 1/(yu*yv)}, yw])/16 - (G[{yu}, yv^(-1)]*G[{0, 1}, yv^(-1)]*
       G[{0, 1/(yu*yv)}, yw])/8 + (G[{1}, yu^(-1)]*G[{0, 1}, yw]*
       G[{0, 1/(yu*yv)}, yw])/8 - (G[{1}, yv^(-1)]*G[{0, 1}, yw]*
       G[{0, 1/(yu*yv)}, yw])/16 - (5*G[{1}, yw]*G[{0, 1}, yw]*
       G[{0, 1/(yu*yv)}, yw])/64 - (G[{yu}, yv^(-1)]*G[{0, 1}, yw]*
       G[{0, 1/(yu*yv)}, yw])/16 - (G[{1/(yu*yv)}, yw]*G[{0, 1}, yw]*
       G[{0, 1/(yu*yv)}, yw])/64 - (G[{1}, yu^(-1)]*G[{0, yu^(-1)}, yw]*
       G[{0, 1/(yu*yv)}, yw])/8 + (G[{1}, yv^(-1)]*G[{0, yu^(-1)}, yw]*
       G[{0, 1/(yu*yv)}, yw])/8 + (5*G[{1}, yw]*G[{0, yu^(-1)}, yw]*
       G[{0, 1/(yu*yv)}, yw])/64 + (G[{1/(yu*yv)}, yw]*G[{0, yu^(-1)}, yw]*
       G[{0, 1/(yu*yv)}, yw])/64 - (3*G[{1}, yv^(-1)]*G[{0, yu}, yv^(-1)]*
       G[{0, 1/(yu*yv)}, yw])/16 - (G[{1}, yw]*G[{0, yu}, yv^(-1)]*
       G[{0, 1/(yu*yv)}, yw])/16 + (G[{yu}, yv^(-1)]*G[{0, yu}, yv^(-1)]*
       G[{0, 1/(yu*yv)}, yw])/8 - (G[{1}, yu^(-1)]*G[{0, yv^(-1)}, yw]*
       G[{0, 1/(yu*yv)}, yw])/16 + (G[{1}, yv^(-1)]*G[{0, yv^(-1)}, yw]*
       G[{0, 1/(yu*yv)}, yw])/16 + (5*G[{1}, yw]*G[{0, yv^(-1)}, yw]*
       G[{0, 1/(yu*yv)}, yw])/64 + (G[{1/(yu*yv)}, yw]*G[{0, yv^(-1)}, yw]*
       G[{0, 1/(yu*yv)}, yw])/64 + (G[{1}, yu^(-1)]*G[{0, 1/(yu*yv)}, yw]^2)/
      32 - (G[{1}, yv^(-1)]*G[{0, 1/(yu*yv)}, yw]^2)/16 - 
     (5*G[{1}, yw]*G[{0, 1/(yu*yv)}, yw]^2)/128 + 
     (G[{yu}, yv^(-1)]*G[{0, 1/(yu*yv)}, yw]^2)/32 - 
     (G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv)}, yw]^2)/128 - 
     (29*Pi^2*G[{0}, yu^(-1)]*G[{1, yu^(-1)}, yw])/768 - 
     (29*Pi^2*G[{0}, yv^(-1)]*G[{1, yu^(-1)}, yw])/768 + 
     (29*Pi^2*G[{0}, yw]*G[{1, yu^(-1)}, yw])/768 + 
     (5*Pi^2*G[{1}, yu^(-1)]*G[{1, yu^(-1)}, yw])/768 - 
     (3*G[{0}, yu^(-1)]^2*G[{1}, yu^(-1)]*G[{1, yu^(-1)}, yw])/32 - 
     (3*G[{0}, yu^(-1)]*G[{0}, yv^(-1)]*G[{1}, yu^(-1)]*G[{1, yu^(-1)}, yw])/
      16 - (3*G[{0}, yv^(-1)]^2*G[{1}, yu^(-1)]*G[{1, yu^(-1)}, yw])/32 + 
     (3*G[{0}, yu^(-1)]*G[{0}, yw]*G[{1}, yu^(-1)]*G[{1, yu^(-1)}, yw])/16 + 
     (3*G[{0}, yv^(-1)]*G[{0}, yw]*G[{1}, yu^(-1)]*G[{1, yu^(-1)}, yw])/16 - 
     (3*G[{0}, yw]^2*G[{1}, yu^(-1)]*G[{1, yu^(-1)}, yw])/32 + 
     (9*G[{0}, yu^(-1)]*G[{1}, yu^(-1)]^2*G[{1, yu^(-1)}, yw])/64 + 
     (9*G[{0}, yv^(-1)]*G[{1}, yu^(-1)]^2*G[{1, yu^(-1)}, yw])/64 - 
     (9*G[{0}, yw]*G[{1}, yu^(-1)]^2*G[{1, yu^(-1)}, yw])/64 - 
     (3*G[{1}, yu^(-1)]^3*G[{1, yu^(-1)}, yw])/64 + 
     (53*Pi^2*G[{1}, yv^(-1)]*G[{1, yu^(-1)}, yw])/768 + 
     (3*G[{0}, yu^(-1)]^2*G[{1}, yv^(-1)]*G[{1, yu^(-1)}, yw])/32 + 
     (3*G[{0}, yu^(-1)]*G[{0}, yv^(-1)]*G[{1}, yv^(-1)]*G[{1, yu^(-1)}, yw])/
      16 + (3*G[{0}, yv^(-1)]^2*G[{1}, yv^(-1)]*G[{1, yu^(-1)}, yw])/32 - 
     (3*G[{0}, yu^(-1)]*G[{0}, yw]*G[{1}, yv^(-1)]*G[{1, yu^(-1)}, yw])/16 - 
     (3*G[{0}, yv^(-1)]*G[{0}, yw]*G[{1}, yv^(-1)]*G[{1, yu^(-1)}, yw])/16 + 
     (3*G[{0}, yw]^2*G[{1}, yv^(-1)]*G[{1, yu^(-1)}, yw])/32 + 
     (3*G[{0}, yu^(-1)]*G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*G[{1, yu^(-1)}, yw])/
      32 + (3*G[{0}, yv^(-1)]*G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*
       G[{1, yu^(-1)}, yw])/32 - (3*G[{0}, yw]*G[{1}, yu^(-1)]*
       G[{1}, yv^(-1)]*G[{1, yu^(-1)}, yw])/32 - 
     (9*G[{1}, yu^(-1)]^2*G[{1}, yv^(-1)]*G[{1, yu^(-1)}, yw])/64 - 
     (5*G[{0}, yu^(-1)]*G[{1}, yv^(-1)]^2*G[{1, yu^(-1)}, yw])/32 - 
     (5*G[{0}, yv^(-1)]*G[{1}, yv^(-1)]^2*G[{1, yu^(-1)}, yw])/32 + 
     (5*G[{0}, yw]*G[{1}, yv^(-1)]^2*G[{1, yu^(-1)}, yw])/32 + 
     (G[{1}, yu^(-1)]*G[{1}, yv^(-1)]^2*G[{1, yu^(-1)}, yw])/32 + 
     (G[{1}, yv^(-1)]^3*G[{1, yu^(-1)}, yw])/16 + 
     (Pi^2*G[{1}, yw]*G[{1, yu^(-1)}, yw])/192 + 
     (3*G[{0}, yu^(-1)]^2*G[{1}, yw]*G[{1, yu^(-1)}, yw])/64 + 
     (3*G[{0}, yu^(-1)]*G[{0}, yv^(-1)]*G[{1}, yw]*G[{1, yu^(-1)}, yw])/32 + 
     (3*G[{0}, yv^(-1)]^2*G[{1}, yw]*G[{1, yu^(-1)}, yw])/64 - 
     (3*G[{0}, yu^(-1)]*G[{0}, yw]*G[{1}, yw]*G[{1, yu^(-1)}, yw])/32 - 
     (3*G[{0}, yv^(-1)]*G[{0}, yw]*G[{1}, yw]*G[{1, yu^(-1)}, yw])/32 + 
     (3*G[{0}, yw]^2*G[{1}, yw]*G[{1, yu^(-1)}, yw])/64 - 
     (3*G[{1}, yu^(-1)]^2*G[{1}, yw]*G[{1, yu^(-1)}, yw])/64 + 
     (G[{0}, yu^(-1)]*G[{1}, yv^(-1)]*G[{1}, yw]*G[{1, yu^(-1)}, yw])/32 + 
     (G[{0}, yv^(-1)]*G[{1}, yv^(-1)]*G[{1}, yw]*G[{1, yu^(-1)}, yw])/32 - 
     (G[{0}, yw]*G[{1}, yv^(-1)]*G[{1}, yw]*G[{1, yu^(-1)}, yw])/32 - 
     (G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*G[{1}, yw]*G[{1, yu^(-1)}, yw])/8 - 
     (3*G[{1}, yv^(-1)]^2*G[{1}, yw]*G[{1, yu^(-1)}, yw])/64 + 
     (G[{0}, yu^(-1)]*G[{1}, yw]^2*G[{1, yu^(-1)}, yw])/8 + 
     (G[{0}, yv^(-1)]*G[{1}, yw]^2*G[{1, yu^(-1)}, yw])/8 - 
     (G[{0}, yw]*G[{1}, yw]^2*G[{1, yu^(-1)}, yw])/8 - 
     (3*G[{1}, yu^(-1)]*G[{1}, yw]^2*G[{1, yu^(-1)}, yw])/32 - 
     (G[{1}, yv^(-1)]*G[{1}, yw]^2*G[{1, yu^(-1)}, yw])/16 + 
     (G[{1}, yw]^3*G[{1, yu^(-1)}, yw])/32 - 
     (7*G[{0}, yu^(-1)]*G[{1}, yw]*G[{yu}, yv^(-1)]*G[{1, yu^(-1)}, yw])/32 - 
     (7*G[{0}, yv^(-1)]*G[{1}, yw]*G[{yu}, yv^(-1)]*G[{1, yu^(-1)}, yw])/32 + 
     (7*G[{0}, yw]*G[{1}, yw]*G[{yu}, yv^(-1)]*G[{1, yu^(-1)}, yw])/32 + 
     (7*G[{1}, yu^(-1)]*G[{1}, yw]*G[{yu}, yv^(-1)]*G[{1, yu^(-1)}, yw])/32 + 
     (G[{1}, yv^(-1)]*G[{1}, yw]*G[{yu}, yv^(-1)]*G[{1, yu^(-1)}, yw])/32 - 
     (3*G[{1}, yw]^2*G[{yu}, yv^(-1)]*G[{1, yu^(-1)}, yw])/32 + 
     (3*G[{1}, yw]*G[{yu}, yv^(-1)]^2*G[{1, yu^(-1)}, yw])/32 + 
     (3*Pi^2*G[{1/(yu*yv)}, yw]*G[{1, yu^(-1)}, yw])/256 + 
     (3*G[{0}, yu^(-1)]^2*G[{1/(yu*yv)}, yw]*G[{1, yu^(-1)}, yw])/64 + 
     (3*G[{0}, yu^(-1)]*G[{0}, yv^(-1)]*G[{1/(yu*yv)}, yw]*
       G[{1, yu^(-1)}, yw])/32 + (3*G[{0}, yv^(-1)]^2*G[{1/(yu*yv)}, yw]*
       G[{1, yu^(-1)}, yw])/64 - (3*G[{0}, yu^(-1)]*G[{0}, yw]*
       G[{1/(yu*yv)}, yw]*G[{1, yu^(-1)}, yw])/32 - 
     (3*G[{0}, yv^(-1)]*G[{0}, yw]*G[{1/(yu*yv)}, yw]*G[{1, yu^(-1)}, yw])/
      32 + (3*G[{0}, yw]^2*G[{1/(yu*yv)}, yw]*G[{1, yu^(-1)}, yw])/64 - 
     (G[{0}, yu^(-1)]*G[{1}, yu^(-1)]*G[{1/(yu*yv)}, yw]*G[{1, yu^(-1)}, yw])/
      8 - (G[{0}, yv^(-1)]*G[{1}, yu^(-1)]*G[{1/(yu*yv)}, yw]*
       G[{1, yu^(-1)}, yw])/8 + (G[{0}, yw]*G[{1}, yu^(-1)]*
       G[{1/(yu*yv)}, yw]*G[{1, yu^(-1)}, yw])/8 + 
     (7*G[{1}, yu^(-1)]^2*G[{1/(yu*yv)}, yw]*G[{1, yu^(-1)}, yw])/128 - 
     (9*G[{0}, yu^(-1)]*G[{1}, yv^(-1)]*G[{1/(yu*yv)}, yw]*
       G[{1, yu^(-1)}, yw])/32 - (9*G[{0}, yv^(-1)]*G[{1}, yv^(-1)]*
       G[{1/(yu*yv)}, yw]*G[{1, yu^(-1)}, yw])/32 + 
     (9*G[{0}, yw]*G[{1}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{1, yu^(-1)}, yw])/
      32 + (23*G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*G[{1/(yu*yv)}, yw]*
       G[{1, yu^(-1)}, yw])/64 + (11*G[{1}, yv^(-1)]^2*G[{1/(yu*yv)}, yw]*
       G[{1, yu^(-1)}, yw])/64 - (15*G[{0}, yu^(-1)]*G[{1}, yw]*
       G[{1/(yu*yv)}, yw]*G[{1, yu^(-1)}, yw])/64 - 
     (15*G[{0}, yv^(-1)]*G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{1, yu^(-1)}, yw])/
      64 + (15*G[{0}, yw]*G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{1, yu^(-1)}, yw])/
      64 + (3*G[{1}, yu^(-1)]*G[{1}, yw]*G[{1/(yu*yv)}, yw]*
       G[{1, yu^(-1)}, yw])/16 + (7*G[{1}, yv^(-1)]*G[{1}, yw]*
       G[{1/(yu*yv)}, yw]*G[{1, yu^(-1)}, yw])/64 - 
     (11*G[{1}, yw]^2*G[{1/(yu*yv)}, yw]*G[{1, yu^(-1)}, yw])/128 - 
     (3*G[{0}, yu^(-1)]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*
       G[{1, yu^(-1)}, yw])/16 - (3*G[{0}, yv^(-1)]*G[{yu^(-1)}, yw]*
       G[{1/(yu*yv)}, yw]*G[{1, yu^(-1)}, yw])/16 + 
     (3*G[{0}, yw]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{1, yu^(-1)}, yw])/
      16 + (3*G[{1}, yu^(-1)]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*
       G[{1, yu^(-1)}, yw])/16 - (G[{1}, yv^(-1)]*G[{yu^(-1)}, yw]*
       G[{1/(yu*yv)}, yw]*G[{1, yu^(-1)}, yw])/16 - 
     (G[{1}, yw]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{1, yu^(-1)}, yw])/4 - 
     (G[{yu^(-1)}, yw]^2*G[{1/(yu*yv)}, yw]*G[{1, yu^(-1)}, yw])/16 + 
     (7*G[{0}, yu^(-1)]*G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw]*
       G[{1, yu^(-1)}, yw])/32 + (7*G[{0}, yv^(-1)]*G[{yu}, yv^(-1)]*
       G[{1/(yu*yv)}, yw]*G[{1, yu^(-1)}, yw])/32 - 
     (7*G[{0}, yw]*G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{1, yu^(-1)}, yw])/
      32 - (7*G[{1}, yu^(-1)]*G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw]*
       G[{1, yu^(-1)}, yw])/32 - (G[{1}, yv^(-1)]*G[{yu}, yv^(-1)]*
       G[{1/(yu*yv)}, yw]*G[{1, yu^(-1)}, yw])/32 + 
     (11*G[{1}, yw]*G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{1, yu^(-1)}, yw])/
      64 + (G[{yu^(-1)}, yw]*G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw]*
       G[{1, yu^(-1)}, yw])/4 - (3*G[{yu}, yv^(-1)]^2*G[{1/(yu*yv)}, yw]*
       G[{1, yu^(-1)}, yw])/32 - (G[{0}, yu^(-1)]*G[{yv^(-1)}, yw]*
       G[{1/(yu*yv)}, yw]*G[{1, yu^(-1)}, yw])/32 - 
     (G[{0}, yv^(-1)]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*
       G[{1, yu^(-1)}, yw])/32 + (G[{0}, yw]*G[{yv^(-1)}, yw]*
       G[{1/(yu*yv)}, yw]*G[{1, yu^(-1)}, yw])/32 + 
     (3*G[{1}, yu^(-1)]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*
       G[{1, yu^(-1)}, yw])/32 - (7*G[{1}, yv^(-1)]*G[{yv^(-1)}, yw]*
       G[{1/(yu*yv)}, yw]*G[{1, yu^(-1)}, yw])/32 - 
     (3*G[{1}, yw]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{1, yu^(-1)}, yw])/
      16 - (G[{yu^(-1)}, yw]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*
       G[{1, yu^(-1)}, yw])/8 + (3*G[{yu}, yv^(-1)]*G[{yv^(-1)}, yw]*
       G[{1/(yu*yv)}, yw]*G[{1, yu^(-1)}, yw])/16 - 
     (3*G[{yv^(-1)}, yw]^2*G[{1/(yu*yv)}, yw]*G[{1, yu^(-1)}, yw])/32 + 
     (3*G[{0}, yu^(-1)]*G[{1/(yu*yv)}, yw]^2*G[{1, yu^(-1)}, yw])/128 + 
     (3*G[{0}, yv^(-1)]*G[{1/(yu*yv)}, yw]^2*G[{1, yu^(-1)}, yw])/128 - 
     (3*G[{0}, yw]*G[{1/(yu*yv)}, yw]^2*G[{1, yu^(-1)}, yw])/128 + 
     (3*G[{1}, yu^(-1)]*G[{1/(yu*yv)}, yw]^2*G[{1, yu^(-1)}, yw])/128 - 
     (7*G[{1}, yv^(-1)]*G[{1/(yu*yv)}, yw]^2*G[{1, yu^(-1)}, yw])/128 + 
     (G[{1}, yw]*G[{1/(yu*yv)}, yw]^2*G[{1, yu^(-1)}, yw])/64 + 
     (G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2*G[{1, yu^(-1)}, yw])/128 - 
     (G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw]^2*G[{1, yu^(-1)}, yw])/64 - 
     (9*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2*G[{1, yu^(-1)}, yw])/128 - 
     (G[{0}, yu^(-1)]*G[{0, 1}, yu^(-1)]*G[{1, yu^(-1)}, yw])/32 - 
     (G[{0}, yv^(-1)]*G[{0, 1}, yu^(-1)]*G[{1, yu^(-1)}, yw])/32 + 
     (G[{0}, yw]*G[{0, 1}, yu^(-1)]*G[{1, yu^(-1)}, yw])/32 - 
     (G[{1}, yu^(-1)]*G[{0, 1}, yu^(-1)]*G[{1, yu^(-1)}, yw])/32 + 
     (3*G[{1}, yv^(-1)]*G[{0, 1}, yu^(-1)]*G[{1, yu^(-1)}, yw])/32 - 
     (G[{1}, yw]*G[{0, 1}, yu^(-1)]*G[{1, yu^(-1)}, yw])/16 + 
     (3*G[{1/(yu*yv)}, yw]*G[{0, 1}, yu^(-1)]*G[{1, yu^(-1)}, yw])/64 - 
     (3*G[{0}, yu^(-1)]*G[{0, 1}, yv^(-1)]*G[{1, yu^(-1)}, yw])/16 - 
     (3*G[{0}, yv^(-1)]*G[{0, 1}, yv^(-1)]*G[{1, yu^(-1)}, yw])/16 + 
     (3*G[{0}, yw]*G[{0, 1}, yv^(-1)]*G[{1, yu^(-1)}, yw])/16 + 
     (G[{1}, yu^(-1)]*G[{0, 1}, yv^(-1)]*G[{1, yu^(-1)}, yw])/8 + 
     (5*G[{1}, yv^(-1)]*G[{0, 1}, yv^(-1)]*G[{1, yu^(-1)}, yw])/16 + 
     (G[{1}, yw]*G[{0, 1}, yv^(-1)]*G[{1, yu^(-1)}, yw])/16 - 
     (G[{1/(yu*yv)}, yw]*G[{0, 1}, yv^(-1)]*G[{1, yu^(-1)}, yw])/16 + 
     (G[{1}, yu^(-1)]*G[{0, 1}, yw]*G[{1, yu^(-1)}, yw])/16 - 
     (G[{1}, yv^(-1)]*G[{0, 1}, yw]*G[{1, yu^(-1)}, yw])/16 + 
     (G[{1}, yw]*G[{0, 1}, yw]*G[{1, yu^(-1)}, yw])/32 - 
     (G[{1/(yu*yv)}, yw]*G[{0, 1}, yw]*G[{1, yu^(-1)}, yw])/64 - 
     (G[{1}, yu^(-1)]*G[{0, yu^(-1)}, yw]*G[{1, yu^(-1)}, yw])/16 + 
     (G[{1}, yv^(-1)]*G[{0, yu^(-1)}, yw]*G[{1, yu^(-1)}, yw])/16 - 
     (G[{1}, yw]*G[{0, yu^(-1)}, yw]*G[{1, yu^(-1)}, yw])/32 + 
     (G[{1/(yu*yv)}, yw]*G[{0, yu^(-1)}, yw]*G[{1, yu^(-1)}, yw])/64 + 
     (3*G[{0}, yu^(-1)]*G[{0, yu}, yv^(-1)]*G[{1, yu^(-1)}, yw])/16 + 
     (3*G[{0}, yv^(-1)]*G[{0, yu}, yv^(-1)]*G[{1, yu^(-1)}, yw])/16 - 
     (3*G[{0}, yw]*G[{0, yu}, yv^(-1)]*G[{1, yu^(-1)}, yw])/16 - 
     (G[{1}, yu^(-1)]*G[{0, yu}, yv^(-1)]*G[{1, yu^(-1)}, yw])/8 - 
     (5*G[{1}, yv^(-1)]*G[{0, yu}, yv^(-1)]*G[{1, yu^(-1)}, yw])/16 - 
     (G[{1}, yw]*G[{0, yu}, yv^(-1)]*G[{1, yu^(-1)}, yw])/16 + 
     (G[{1/(yu*yv)}, yw]*G[{0, yu}, yv^(-1)]*G[{1, yu^(-1)}, yw])/16 - 
     (G[{1}, yu^(-1)]*G[{0, yv^(-1)}, yw]*G[{1, yu^(-1)}, yw])/16 + 
     (G[{1}, yv^(-1)]*G[{0, yv^(-1)}, yw]*G[{1, yu^(-1)}, yw])/16 - 
     (G[{1}, yw]*G[{0, yv^(-1)}, yw]*G[{1, yu^(-1)}, yw])/32 + 
     (G[{1/(yu*yv)}, yw]*G[{0, yv^(-1)}, yw]*G[{1, yu^(-1)}, yw])/64 + 
     (G[{1}, yu^(-1)]*G[{0, 1/(yu*yv)}, yw]*G[{1, yu^(-1)}, yw])/16 - 
     (G[{1}, yv^(-1)]*G[{0, 1/(yu*yv)}, yw]*G[{1, yu^(-1)}, yw])/16 + 
     (G[{1}, yw]*G[{0, 1/(yu*yv)}, yw]*G[{1, yu^(-1)}, yw])/32 - 
     (G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv)}, yw]*G[{1, yu^(-1)}, yw])/64 - 
     (3*G[{0}, yu^(-1)]*G[{1, yu^(-1)}, yw]^2)/32 - 
     (3*G[{0}, yv^(-1)]*G[{1, yu^(-1)}, yw]^2)/32 + 
     (3*G[{0}, yw]*G[{1, yu^(-1)}, yw]^2)/32 + 
     (3*G[{1}, yu^(-1)]*G[{1, yu^(-1)}, yw]^2)/32 - 
     (G[{1}, yv^(-1)]*G[{1, yu^(-1)}, yw]^2)/32 - 
     (G[{1}, yw]*G[{1, yu^(-1)}, yw]^2)/8 + 
     (G[{yu}, yv^(-1)]*G[{1, yu^(-1)}, yw]^2)/8 - 
     (5*G[{1/(yu*yv)}, yw]*G[{1, yu^(-1)}, yw]^2)/128 - 
     (7*Pi^2*G[{0}, yu^(-1)]*G[{1, yu}, yv^(-1)])/384 - 
     (3*G[{0}, yu^(-1)]^3*G[{1, yu}, yv^(-1)])/128 - 
     (7*Pi^2*G[{0}, yv^(-1)]*G[{1, yu}, yv^(-1)])/384 - 
     (9*G[{0}, yu^(-1)]^2*G[{0}, yv^(-1)]*G[{1, yu}, yv^(-1)])/128 - 
     (9*G[{0}, yu^(-1)]*G[{0}, yv^(-1)]^2*G[{1, yu}, yv^(-1)])/128 - 
     (3*G[{0}, yv^(-1)]^3*G[{1, yu}, yv^(-1)])/128 + 
     (7*Pi^2*G[{0}, yw]*G[{1, yu}, yv^(-1)])/384 + 
     (9*G[{0}, yu^(-1)]^2*G[{0}, yw]*G[{1, yu}, yv^(-1)])/128 + 
     (9*G[{0}, yu^(-1)]*G[{0}, yv^(-1)]*G[{0}, yw]*G[{1, yu}, yv^(-1)])/64 + 
     (9*G[{0}, yv^(-1)]^2*G[{0}, yw]*G[{1, yu}, yv^(-1)])/128 - 
     (9*G[{0}, yu^(-1)]*G[{0}, yw]^2*G[{1, yu}, yv^(-1)])/128 - 
     (9*G[{0}, yv^(-1)]*G[{0}, yw]^2*G[{1, yu}, yv^(-1)])/128 + 
     (3*G[{0}, yw]^3*G[{1, yu}, yv^(-1)])/128 + 
     (7*Pi^2*G[{1}, yu^(-1)]*G[{1, yu}, yv^(-1)])/384 + 
     (G[{0}, yu^(-1)]^2*G[{1}, yu^(-1)]*G[{1, yu}, yv^(-1)])/128 + 
     (G[{0}, yu^(-1)]*G[{0}, yv^(-1)]*G[{1}, yu^(-1)]*G[{1, yu}, yv^(-1)])/
      64 + (G[{0}, yv^(-1)]^2*G[{1}, yu^(-1)]*G[{1, yu}, yv^(-1)])/128 - 
     (G[{0}, yu^(-1)]*G[{0}, yw]*G[{1}, yu^(-1)]*G[{1, yu}, yv^(-1)])/64 - 
     (G[{0}, yv^(-1)]*G[{0}, yw]*G[{1}, yu^(-1)]*G[{1, yu}, yv^(-1)])/64 + 
     (G[{0}, yw]^2*G[{1}, yu^(-1)]*G[{1, yu}, yv^(-1)])/128 + 
     (7*G[{0}, yu^(-1)]*G[{1}, yu^(-1)]^2*G[{1, yu}, yv^(-1)])/128 + 
     (7*G[{0}, yv^(-1)]*G[{1}, yu^(-1)]^2*G[{1, yu}, yv^(-1)])/128 - 
     (7*G[{0}, yw]*G[{1}, yu^(-1)]^2*G[{1, yu}, yv^(-1)])/128 - 
     (5*G[{1}, yu^(-1)]^3*G[{1, yu}, yv^(-1)])/128 - 
     (Pi^2*G[{1}, yv^(-1)]*G[{1, yu}, yv^(-1)])/384 - 
     (3*G[{0}, yu^(-1)]^2*G[{1}, yv^(-1)]*G[{1, yu}, yv^(-1)])/128 - 
     (3*G[{0}, yu^(-1)]*G[{0}, yv^(-1)]*G[{1}, yv^(-1)]*G[{1, yu}, yv^(-1)])/
      64 - (3*G[{0}, yv^(-1)]^2*G[{1}, yv^(-1)]*G[{1, yu}, yv^(-1)])/128 + 
     (3*G[{0}, yu^(-1)]*G[{0}, yw]*G[{1}, yv^(-1)]*G[{1, yu}, yv^(-1)])/64 + 
     (3*G[{0}, yv^(-1)]*G[{0}, yw]*G[{1}, yv^(-1)]*G[{1, yu}, yv^(-1)])/64 - 
     (3*G[{0}, yw]^2*G[{1}, yv^(-1)]*G[{1, yu}, yv^(-1)])/128 + 
     (11*G[{0}, yu^(-1)]*G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*G[{1, yu}, yv^(-1)])/
      64 + (11*G[{0}, yv^(-1)]*G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*
       G[{1, yu}, yv^(-1)])/64 - (11*G[{0}, yw]*G[{1}, yu^(-1)]*
       G[{1}, yv^(-1)]*G[{1, yu}, yv^(-1)])/64 - 
     (19*G[{1}, yu^(-1)]^2*G[{1}, yv^(-1)]*G[{1, yu}, yv^(-1)])/128 + 
     (11*G[{0}, yu^(-1)]*G[{1}, yv^(-1)]^2*G[{1, yu}, yv^(-1)])/128 + 
     (11*G[{0}, yv^(-1)]*G[{1}, yv^(-1)]^2*G[{1, yu}, yv^(-1)])/128 - 
     (11*G[{0}, yw]*G[{1}, yv^(-1)]^2*G[{1, yu}, yv^(-1)])/128 - 
     (11*G[{1}, yu^(-1)]*G[{1}, yv^(-1)]^2*G[{1, yu}, yv^(-1)])/128 - 
     (5*G[{1}, yv^(-1)]^3*G[{1, yu}, yv^(-1)])/128 - 
     (5*Pi^2*G[{1}, yw]*G[{1, yu}, yv^(-1)])/128 - 
     (13*G[{0}, yu^(-1)]^2*G[{1}, yw]*G[{1, yu}, yv^(-1)])/128 - 
     (13*G[{0}, yu^(-1)]*G[{0}, yv^(-1)]*G[{1}, yw]*G[{1, yu}, yv^(-1)])/64 - 
     (13*G[{0}, yv^(-1)]^2*G[{1}, yw]*G[{1, yu}, yv^(-1)])/128 + 
     (13*G[{0}, yu^(-1)]*G[{0}, yw]*G[{1}, yw]*G[{1, yu}, yv^(-1)])/64 + 
     (13*G[{0}, yv^(-1)]*G[{0}, yw]*G[{1}, yw]*G[{1, yu}, yv^(-1)])/64 - 
     (13*G[{0}, yw]^2*G[{1}, yw]*G[{1, yu}, yv^(-1)])/128 + 
     (G[{0}, yu^(-1)]*G[{1}, yu^(-1)]*G[{1}, yw]*G[{1, yu}, yv^(-1)])/64 + 
     (G[{0}, yv^(-1)]*G[{1}, yu^(-1)]*G[{1}, yw]*G[{1, yu}, yv^(-1)])/64 - 
     (G[{0}, yw]*G[{1}, yu^(-1)]*G[{1}, yw]*G[{1, yu}, yv^(-1)])/64 + 
     (11*G[{1}, yu^(-1)]^2*G[{1}, yw]*G[{1, yu}, yv^(-1)])/128 + 
     (G[{0}, yu^(-1)]*G[{1}, yv^(-1)]*G[{1}, yw]*G[{1, yu}, yv^(-1)])/64 + 
     (G[{0}, yv^(-1)]*G[{1}, yv^(-1)]*G[{1}, yw]*G[{1, yu}, yv^(-1)])/64 - 
     (G[{0}, yw]*G[{1}, yv^(-1)]*G[{1}, yw]*G[{1, yu}, yv^(-1)])/64 + 
     (7*G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*G[{1}, yw]*G[{1, yu}, yv^(-1)])/64 + 
     (11*G[{1}, yv^(-1)]^2*G[{1}, yw]*G[{1, yu}, yv^(-1)])/128 - 
     (3*G[{0}, yu^(-1)]*G[{1}, yw]^2*G[{1, yu}, yv^(-1)])/128 - 
     (3*G[{0}, yv^(-1)]*G[{1}, yw]^2*G[{1, yu}, yv^(-1)])/128 + 
     (3*G[{0}, yw]*G[{1}, yw]^2*G[{1, yu}, yv^(-1)])/128 - 
     (5*G[{1}, yu^(-1)]*G[{1}, yw]^2*G[{1, yu}, yv^(-1)])/128 - 
     (G[{1}, yv^(-1)]*G[{1}, yw]^2*G[{1, yu}, yv^(-1)])/128 + 
     (3*G[{0}, yu^(-1)]*G[{1}, yw]*G[{yu}, yv^(-1)]*G[{1, yu}, yv^(-1)])/16 + 
     (3*G[{0}, yv^(-1)]*G[{1}, yw]*G[{yu}, yv^(-1)]*G[{1, yu}, yv^(-1)])/16 - 
     (3*G[{0}, yw]*G[{1}, yw]*G[{yu}, yv^(-1)]*G[{1, yu}, yv^(-1)])/16 - 
     (3*G[{1}, yu^(-1)]*G[{1}, yw]*G[{yu}, yv^(-1)]*G[{1, yu}, yv^(-1)])/16 - 
     (G[{1}, yv^(-1)]*G[{1}, yw]*G[{yu}, yv^(-1)]*G[{1, yu}, yv^(-1)])/8 + 
     (G[{1}, yw]^2*G[{yu}, yv^(-1)]*G[{1, yu}, yv^(-1)])/16 - 
     (G[{1}, yw]*G[{yu}, yv^(-1)]^2*G[{1, yu}, yv^(-1)])/8 + 
     (Pi^2*G[{1/(yu*yv)}, yw]*G[{1, yu}, yv^(-1)])/384 - 
     (5*G[{0}, yu^(-1)]^2*G[{1/(yu*yv)}, yw]*G[{1, yu}, yv^(-1)])/128 - 
     (5*G[{0}, yu^(-1)]*G[{0}, yv^(-1)]*G[{1/(yu*yv)}, yw]*
       G[{1, yu}, yv^(-1)])/64 - (5*G[{0}, yv^(-1)]^2*G[{1/(yu*yv)}, yw]*
       G[{1, yu}, yv^(-1)])/128 + (5*G[{0}, yu^(-1)]*G[{0}, yw]*
       G[{1/(yu*yv)}, yw]*G[{1, yu}, yv^(-1)])/64 + 
     (5*G[{0}, yv^(-1)]*G[{0}, yw]*G[{1/(yu*yv)}, yw]*G[{1, yu}, yv^(-1)])/
      64 - (5*G[{0}, yw]^2*G[{1/(yu*yv)}, yw]*G[{1, yu}, yv^(-1)])/128 + 
     (G[{0}, yu^(-1)]*G[{1}, yu^(-1)]*G[{1/(yu*yv)}, yw]*G[{1, yu}, yv^(-1)])/
      64 + (G[{0}, yv^(-1)]*G[{1}, yu^(-1)]*G[{1/(yu*yv)}, yw]*
       G[{1, yu}, yv^(-1)])/64 - (G[{0}, yw]*G[{1}, yu^(-1)]*
       G[{1/(yu*yv)}, yw]*G[{1, yu}, yv^(-1)])/64 + 
     (3*G[{1}, yu^(-1)]^2*G[{1/(yu*yv)}, yw]*G[{1, yu}, yv^(-1)])/128 - 
     (7*G[{0}, yu^(-1)]*G[{1}, yv^(-1)]*G[{1/(yu*yv)}, yw]*
       G[{1, yu}, yv^(-1)])/64 - (7*G[{0}, yv^(-1)]*G[{1}, yv^(-1)]*
       G[{1/(yu*yv)}, yw]*G[{1, yu}, yv^(-1)])/64 + 
     (7*G[{0}, yw]*G[{1}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{1, yu}, yv^(-1)])/
      64 + (15*G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*G[{1/(yu*yv)}, yw]*
       G[{1, yu}, yv^(-1)])/64 + (11*G[{1}, yv^(-1)]^2*G[{1/(yu*yv)}, yw]*
       G[{1, yu}, yv^(-1)])/128 + (5*G[{0}, yu^(-1)]*G[{1}, yw]*
       G[{1/(yu*yv)}, yw]*G[{1, yu}, yv^(-1)])/64 + 
     (5*G[{0}, yv^(-1)]*G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{1, yu}, yv^(-1)])/
      64 - (5*G[{0}, yw]*G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{1, yu}, yv^(-1)])/
      64 - (5*G[{1}, yu^(-1)]*G[{1}, yw]*G[{1/(yu*yv)}, yw]*
       G[{1, yu}, yv^(-1)])/64 - (9*G[{1}, yv^(-1)]*G[{1}, yw]*
       G[{1/(yu*yv)}, yw]*G[{1, yu}, yv^(-1)])/64 - 
     (5*G[{0}, yu^(-1)]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*
       G[{1, yu}, yv^(-1)])/32 - (5*G[{0}, yv^(-1)]*G[{yu^(-1)}, yw]*
       G[{1/(yu*yv)}, yw]*G[{1, yu}, yv^(-1)])/32 + 
     (5*G[{0}, yw]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{1, yu}, yv^(-1)])/
      32 + (G[{1}, yu^(-1)]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*
       G[{1, yu}, yv^(-1)])/32 - (G[{1}, yv^(-1)]*G[{yu^(-1)}, yw]*
       G[{1/(yu*yv)}, yw]*G[{1, yu}, yv^(-1)])/32 + 
     (G[{1}, yw]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{1, yu}, yv^(-1)])/8 - 
     (7*G[{yu^(-1)}, yw]^2*G[{1/(yu*yv)}, yw]*G[{1, yu}, yv^(-1)])/64 - 
     (3*G[{0}, yu^(-1)]*G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw]*
       G[{1, yu}, yv^(-1)])/16 - (3*G[{0}, yv^(-1)]*G[{yu}, yv^(-1)]*
       G[{1/(yu*yv)}, yw]*G[{1, yu}, yv^(-1)])/16 + 
     (3*G[{0}, yw]*G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{1, yu}, yv^(-1)])/
      16 + (3*G[{1}, yu^(-1)]*G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw]*
       G[{1, yu}, yv^(-1)])/16 + (G[{1}, yv^(-1)]*G[{yu}, yv^(-1)]*
       G[{1/(yu*yv)}, yw]*G[{1, yu}, yv^(-1)])/8 - 
     (G[{1}, yw]*G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{1, yu}, yv^(-1)])/8 + 
     (G[{yu}, yv^(-1)]^2*G[{1/(yu*yv)}, yw]*G[{1, yu}, yv^(-1)])/8 - 
     (3*G[{0}, yu^(-1)]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*
       G[{1, yu}, yv^(-1)])/32 - (3*G[{0}, yv^(-1)]*G[{yv^(-1)}, yw]*
       G[{1/(yu*yv)}, yw]*G[{1, yu}, yv^(-1)])/32 + 
     (3*G[{0}, yw]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{1, yu}, yv^(-1)])/
      32 + (3*G[{1}, yu^(-1)]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*
       G[{1, yu}, yv^(-1)])/32 - (5*G[{1}, yv^(-1)]*G[{yv^(-1)}, yw]*
       G[{1/(yu*yv)}, yw]*G[{1, yu}, yv^(-1)])/32 - 
     (3*G[{yu^(-1)}, yw]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*
       G[{1, yu}, yv^(-1)])/32 - (G[{yu}, yv^(-1)]*G[{yv^(-1)}, yw]*
       G[{1/(yu*yv)}, yw]*G[{1, yu}, yv^(-1)])/8 - 
     (7*G[{yv^(-1)}, yw]^2*G[{1/(yu*yv)}, yw]*G[{1, yu}, yv^(-1)])/64 + 
     (G[{0}, yu^(-1)]*G[{1/(yu*yv)}, yw]^2*G[{1, yu}, yv^(-1)])/128 + 
     (G[{0}, yv^(-1)]*G[{1/(yu*yv)}, yw]^2*G[{1, yu}, yv^(-1)])/128 - 
     (G[{0}, yw]*G[{1/(yu*yv)}, yw]^2*G[{1, yu}, yv^(-1)])/128 - 
     (G[{1}, yu^(-1)]*G[{1/(yu*yv)}, yw]^2*G[{1, yu}, yv^(-1)])/128 + 
     (7*G[{1}, yv^(-1)]*G[{1/(yu*yv)}, yw]^2*G[{1, yu}, yv^(-1)])/128 + 
     (G[{1}, yw]*G[{1/(yu*yv)}, yw]^2*G[{1, yu}, yv^(-1)])/16 - 
     (7*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2*G[{1, yu}, yv^(-1)])/128 - 
     (G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw]^2*G[{1, yu}, yv^(-1)])/16 + 
     (G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2*G[{1, yu}, yv^(-1)])/128 + 
     (G[{0}, yu^(-1)]*G[{0, 1}, yu^(-1)]*G[{1, yu}, yv^(-1)])/16 + 
     (G[{0}, yv^(-1)]*G[{0, 1}, yu^(-1)]*G[{1, yu}, yv^(-1)])/16 - 
     (G[{0}, yw]*G[{0, 1}, yu^(-1)]*G[{1, yu}, yv^(-1)])/16 - 
     (G[{1}, yu^(-1)]*G[{0, 1}, yu^(-1)]*G[{1, yu}, yv^(-1)])/16 + 
     (G[{1}, yv^(-1)]*G[{0, 1}, yu^(-1)]*G[{1, yu}, yv^(-1)])/16 + 
     (G[{1}, yw]*G[{0, 1}, yu^(-1)]*G[{1, yu}, yv^(-1)])/16 + 
     (G[{1/(yu*yv)}, yw]*G[{0, 1}, yu^(-1)]*G[{1, yu}, yv^(-1)])/16 - 
     (G[{0}, yu^(-1)]*G[{0, 1}, yv^(-1)]*G[{1, yu}, yv^(-1)])/8 - 
     (G[{0}, yv^(-1)]*G[{0, 1}, yv^(-1)]*G[{1, yu}, yv^(-1)])/8 + 
     (G[{0}, yw]*G[{0, 1}, yv^(-1)]*G[{1, yu}, yv^(-1)])/8 + 
     (G[{1}, yu^(-1)]*G[{0, 1}, yv^(-1)]*G[{1, yu}, yv^(-1)])/8 + 
     (G[{1}, yv^(-1)]*G[{0, 1}, yv^(-1)]*G[{1, yu}, yv^(-1)])/16 - 
     (3*G[{1}, yw]*G[{0, 1}, yv^(-1)]*G[{1, yu}, yv^(-1)])/16 - 
     (G[{1/(yu*yv)}, yw]*G[{0, 1}, yv^(-1)]*G[{1, yu}, yv^(-1)])/16 - 
     (7*G[{0}, yu^(-1)]*G[{0, 1}, yw]*G[{1, yu}, yv^(-1)])/32 - 
     (7*G[{0}, yv^(-1)]*G[{0, 1}, yw]*G[{1, yu}, yv^(-1)])/32 + 
     (7*G[{0}, yw]*G[{0, 1}, yw]*G[{1, yu}, yv^(-1)])/32 + 
     (3*G[{1}, yu^(-1)]*G[{0, 1}, yw]*G[{1, yu}, yv^(-1)])/32 + 
     (3*G[{1}, yv^(-1)]*G[{0, 1}, yw]*G[{1, yu}, yv^(-1)])/32 + 
     (G[{1}, yw]*G[{0, 1}, yw]*G[{1, yu}, yv^(-1)])/64 + 
     (3*G[{yu}, yv^(-1)]*G[{0, 1}, yw]*G[{1, yu}, yv^(-1)])/16 - 
     (3*G[{1/(yu*yv)}, yw]*G[{0, 1}, yw]*G[{1, yu}, yv^(-1)])/64 + 
     (5*G[{0}, yu^(-1)]*G[{0, yu^(-1)}, yw]*G[{1, yu}, yv^(-1)])/32 + 
     (5*G[{0}, yv^(-1)]*G[{0, yu^(-1)}, yw]*G[{1, yu}, yv^(-1)])/32 - 
     (5*G[{0}, yw]*G[{0, yu^(-1)}, yw]*G[{1, yu}, yv^(-1)])/32 - 
     (G[{1}, yu^(-1)]*G[{0, yu^(-1)}, yw]*G[{1, yu}, yv^(-1)])/32 + 
     (G[{1}, yv^(-1)]*G[{0, yu^(-1)}, yw]*G[{1, yu}, yv^(-1)])/32 - 
     (G[{1}, yw]*G[{0, yu^(-1)}, yw]*G[{1, yu}, yv^(-1)])/64 + 
     (3*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1)}, yw]*G[{1, yu}, yv^(-1)])/64 + 
     (G[{0}, yu^(-1)]*G[{0, yu}, yv^(-1)]*G[{1, yu}, yv^(-1)])/8 + 
     (G[{0}, yv^(-1)]*G[{0, yu}, yv^(-1)]*G[{1, yu}, yv^(-1)])/8 - 
     (G[{0}, yw]*G[{0, yu}, yv^(-1)]*G[{1, yu}, yv^(-1)])/8 - 
     (G[{1}, yu^(-1)]*G[{0, yu}, yv^(-1)]*G[{1, yu}, yv^(-1)])/8 - 
     (G[{1}, yv^(-1)]*G[{0, yu}, yv^(-1)]*G[{1, yu}, yv^(-1)])/16 + 
     (3*G[{1}, yw]*G[{0, yu}, yv^(-1)]*G[{1, yu}, yv^(-1)])/16 + 
     (G[{1/(yu*yv)}, yw]*G[{0, yu}, yv^(-1)]*G[{1, yu}, yv^(-1)])/16 + 
     (3*G[{0}, yu^(-1)]*G[{0, yv^(-1)}, yw]*G[{1, yu}, yv^(-1)])/32 + 
     (3*G[{0}, yv^(-1)]*G[{0, yv^(-1)}, yw]*G[{1, yu}, yv^(-1)])/32 - 
     (3*G[{0}, yw]*G[{0, yv^(-1)}, yw]*G[{1, yu}, yv^(-1)])/32 - 
     (G[{1}, yu^(-1)]*G[{0, yv^(-1)}, yw]*G[{1, yu}, yv^(-1)])/32 + 
     (G[{1}, yv^(-1)]*G[{0, yv^(-1)}, yw]*G[{1, yu}, yv^(-1)])/32 - 
     (G[{1}, yw]*G[{0, yv^(-1)}, yw]*G[{1, yu}, yv^(-1)])/64 + 
     (3*G[{1/(yu*yv)}, yw]*G[{0, yv^(-1)}, yw]*G[{1, yu}, yv^(-1)])/64 - 
     (G[{0}, yu^(-1)]*G[{0, 1/(yu*yv)}, yw]*G[{1, yu}, yv^(-1)])/32 - 
     (G[{0}, yv^(-1)]*G[{0, 1/(yu*yv)}, yw]*G[{1, yu}, yv^(-1)])/32 + 
     (G[{0}, yw]*G[{0, 1/(yu*yv)}, yw]*G[{1, yu}, yv^(-1)])/32 - 
     (G[{1}, yu^(-1)]*G[{0, 1/(yu*yv)}, yw]*G[{1, yu}, yv^(-1)])/32 - 
     (5*G[{1}, yv^(-1)]*G[{0, 1/(yu*yv)}, yw]*G[{1, yu}, yv^(-1)])/32 + 
     (G[{1}, yw]*G[{0, 1/(yu*yv)}, yw]*G[{1, yu}, yv^(-1)])/64 - 
     (3*G[{yu}, yv^(-1)]*G[{0, 1/(yu*yv)}, yw]*G[{1, yu}, yv^(-1)])/16 - 
     (3*G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv)}, yw]*G[{1, yu}, yv^(-1)])/64 - 
     (5*G[{0}, yu^(-1)]*G[{1, yu^(-1)}, yw]*G[{1, yu}, yv^(-1)])/32 - 
     (5*G[{0}, yv^(-1)]*G[{1, yu^(-1)}, yw]*G[{1, yu}, yv^(-1)])/32 + 
     (5*G[{0}, yw]*G[{1, yu^(-1)}, yw]*G[{1, yu}, yv^(-1)])/32 + 
     (G[{1}, yu^(-1)]*G[{1, yu^(-1)}, yw]*G[{1, yu}, yv^(-1)])/32 - 
     (G[{1}, yv^(-1)]*G[{1, yu^(-1)}, yw]*G[{1, yu}, yv^(-1)])/32 + 
     (G[{1}, yw]*G[{1, yu^(-1)}, yw]*G[{1, yu}, yv^(-1)])/8 - 
     (7*G[{1/(yu*yv)}, yw]*G[{1, yu^(-1)}, yw]*G[{1, yu}, yv^(-1)])/64 - 
     (3*G[{0}, yu^(-1)]*G[{1, yu}, yv^(-1)]^2)/32 - 
     (3*G[{0}, yv^(-1)]*G[{1, yu}, yv^(-1)]^2)/32 + 
     (3*G[{0}, yw]*G[{1, yu}, yv^(-1)]^2)/32 + 
     (3*G[{1}, yu^(-1)]*G[{1, yu}, yv^(-1)]^2)/32 + 
     (G[{1}, yv^(-1)]*G[{1, yu}, yv^(-1)]^2)/16 - 
     (G[{1}, yw]*G[{1, yu}, yv^(-1)]^2)/8 - 
     (G[{1/(yu*yv)}, yw]*G[{1, yu}, yv^(-1)]^2)/16 - 
     (7*Pi^2*G[{0}, yu^(-1)]*G[{1, yv^(-1)}, yw])/768 + 
     (3*G[{0}, yu^(-1)]^3*G[{1, yv^(-1)}, yw])/128 - 
     (7*Pi^2*G[{0}, yv^(-1)]*G[{1, yv^(-1)}, yw])/768 + 
     (9*G[{0}, yu^(-1)]^2*G[{0}, yv^(-1)]*G[{1, yv^(-1)}, yw])/128 + 
     (9*G[{0}, yu^(-1)]*G[{0}, yv^(-1)]^2*G[{1, yv^(-1)}, yw])/128 + 
     (3*G[{0}, yv^(-1)]^3*G[{1, yv^(-1)}, yw])/128 + 
     (7*Pi^2*G[{0}, yw]*G[{1, yv^(-1)}, yw])/768 - 
     (9*G[{0}, yu^(-1)]^2*G[{0}, yw]*G[{1, yv^(-1)}, yw])/128 - 
     (9*G[{0}, yu^(-1)]*G[{0}, yv^(-1)]*G[{0}, yw]*G[{1, yv^(-1)}, yw])/64 - 
     (9*G[{0}, yv^(-1)]^2*G[{0}, yw]*G[{1, yv^(-1)}, yw])/128 + 
     (9*G[{0}, yu^(-1)]*G[{0}, yw]^2*G[{1, yv^(-1)}, yw])/128 + 
     (9*G[{0}, yv^(-1)]*G[{0}, yw]^2*G[{1, yv^(-1)}, yw])/128 - 
     (3*G[{0}, yw]^3*G[{1, yv^(-1)}, yw])/128 - 
     (3*Pi^2*G[{1}, yu^(-1)]*G[{1, yv^(-1)}, yw])/256 - 
     (13*G[{0}, yu^(-1)]^2*G[{1}, yu^(-1)]*G[{1, yv^(-1)}, yw])/128 - 
     (13*G[{0}, yu^(-1)]*G[{0}, yv^(-1)]*G[{1}, yu^(-1)]*G[{1, yv^(-1)}, yw])/
      64 - (13*G[{0}, yv^(-1)]^2*G[{1}, yu^(-1)]*G[{1, yv^(-1)}, yw])/128 + 
     (13*G[{0}, yu^(-1)]*G[{0}, yw]*G[{1}, yu^(-1)]*G[{1, yv^(-1)}, yw])/64 + 
     (13*G[{0}, yv^(-1)]*G[{0}, yw]*G[{1}, yu^(-1)]*G[{1, yv^(-1)}, yw])/64 - 
     (13*G[{0}, yw]^2*G[{1}, yu^(-1)]*G[{1, yv^(-1)}, yw])/128 + 
     (11*G[{0}, yu^(-1)]*G[{1}, yu^(-1)]^2*G[{1, yv^(-1)}, yw])/128 + 
     (11*G[{0}, yv^(-1)]*G[{1}, yu^(-1)]^2*G[{1, yv^(-1)}, yw])/128 - 
     (11*G[{0}, yw]*G[{1}, yu^(-1)]^2*G[{1, yv^(-1)}, yw])/128 - 
     (G[{1}, yu^(-1)]^3*G[{1, yv^(-1)}, yw])/128 + 
     (7*Pi^2*G[{1}, yv^(-1)]*G[{1, yv^(-1)}, yw])/768 - 
     (9*G[{0}, yu^(-1)]^2*G[{1}, yv^(-1)]*G[{1, yv^(-1)}, yw])/128 - 
     (9*G[{0}, yu^(-1)]*G[{0}, yv^(-1)]*G[{1}, yv^(-1)]*G[{1, yv^(-1)}, yw])/
      64 - (9*G[{0}, yv^(-1)]^2*G[{1}, yv^(-1)]*G[{1, yv^(-1)}, yw])/128 + 
     (9*G[{0}, yu^(-1)]*G[{0}, yw]*G[{1}, yv^(-1)]*G[{1, yv^(-1)}, yw])/64 + 
     (9*G[{0}, yv^(-1)]*G[{0}, yw]*G[{1}, yv^(-1)]*G[{1, yv^(-1)}, yw])/64 - 
     (9*G[{0}, yw]^2*G[{1}, yv^(-1)]*G[{1, yv^(-1)}, yw])/128 + 
     (11*G[{0}, yu^(-1)]*G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*G[{1, yv^(-1)}, yw])/
      64 + (11*G[{0}, yv^(-1)]*G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*
       G[{1, yv^(-1)}, yw])/64 - (11*G[{0}, yw]*G[{1}, yu^(-1)]*
       G[{1}, yv^(-1)]*G[{1, yv^(-1)}, yw])/64 - 
     (7*G[{1}, yu^(-1)]^2*G[{1}, yv^(-1)]*G[{1, yv^(-1)}, yw])/128 + 
     (9*G[{0}, yu^(-1)]*G[{1}, yv^(-1)]^2*G[{1, yv^(-1)}, yw])/128 + 
     (9*G[{0}, yv^(-1)]*G[{1}, yv^(-1)]^2*G[{1, yv^(-1)}, yw])/128 - 
     (9*G[{0}, yw]*G[{1}, yv^(-1)]^2*G[{1, yv^(-1)}, yw])/128 - 
     (9*G[{1}, yu^(-1)]*G[{1}, yv^(-1)]^2*G[{1, yv^(-1)}, yw])/128 - 
     (3*G[{1}, yv^(-1)]^3*G[{1, yv^(-1)}, yw])/128 - 
     (7*Pi^2*G[{1}, yw]*G[{1, yv^(-1)}, yw])/384 - 
     (G[{0}, yu^(-1)]^2*G[{1}, yw]*G[{1, yv^(-1)}, yw])/128 - 
     (G[{0}, yu^(-1)]*G[{0}, yv^(-1)]*G[{1}, yw]*G[{1, yv^(-1)}, yw])/64 - 
     (G[{0}, yv^(-1)]^2*G[{1}, yw]*G[{1, yv^(-1)}, yw])/128 + 
     (G[{0}, yu^(-1)]*G[{0}, yw]*G[{1}, yw]*G[{1, yv^(-1)}, yw])/64 + 
     (G[{0}, yv^(-1)]*G[{0}, yw]*G[{1}, yw]*G[{1, yv^(-1)}, yw])/64 - 
     (G[{0}, yw]^2*G[{1}, yw]*G[{1, yv^(-1)}, yw])/128 - 
     (G[{0}, yu^(-1)]*G[{1}, yu^(-1)]*G[{1}, yw]*G[{1, yv^(-1)}, yw])/64 - 
     (G[{0}, yv^(-1)]*G[{1}, yu^(-1)]*G[{1}, yw]*G[{1, yv^(-1)}, yw])/64 + 
     (G[{0}, yw]*G[{1}, yu^(-1)]*G[{1}, yw]*G[{1, yv^(-1)}, yw])/64 + 
     (3*G[{1}, yu^(-1)]^2*G[{1}, yw]*G[{1, yv^(-1)}, yw])/128 + 
     (G[{0}, yu^(-1)]*G[{1}, yv^(-1)]*G[{1}, yw]*G[{1, yv^(-1)}, yw])/64 + 
     (G[{0}, yv^(-1)]*G[{1}, yv^(-1)]*G[{1}, yw]*G[{1, yv^(-1)}, yw])/64 - 
     (G[{0}, yw]*G[{1}, yv^(-1)]*G[{1}, yw]*G[{1, yv^(-1)}, yw])/64 + 
     (G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*G[{1}, yw]*G[{1, yv^(-1)}, yw])/64 - 
     (G[{1}, yv^(-1)]^2*G[{1}, yw]*G[{1, yv^(-1)}, yw])/128 + 
     (3*G[{0}, yu^(-1)]*G[{1}, yw]^2*G[{1, yv^(-1)}, yw])/128 + 
     (3*G[{0}, yv^(-1)]*G[{1}, yw]^2*G[{1, yv^(-1)}, yw])/128 - 
     (3*G[{0}, yw]*G[{1}, yw]^2*G[{1, yv^(-1)}, yw])/128 - 
     (3*G[{1}, yu^(-1)]*G[{1}, yw]^2*G[{1, yv^(-1)}, yw])/128 - 
     (3*G[{1}, yv^(-1)]*G[{1}, yw]^2*G[{1, yv^(-1)}, yw])/128 + 
     (Pi^2*G[{yu}, yv^(-1)]*G[{1, yv^(-1)}, yw])/48 + 
     (G[{0}, yu^(-1)]^2*G[{yu}, yv^(-1)]*G[{1, yv^(-1)}, yw])/32 + 
     (G[{0}, yu^(-1)]*G[{0}, yv^(-1)]*G[{yu}, yv^(-1)]*G[{1, yv^(-1)}, yw])/
      16 + (G[{0}, yv^(-1)]^2*G[{yu}, yv^(-1)]*G[{1, yv^(-1)}, yw])/32 - 
     (G[{0}, yu^(-1)]*G[{0}, yw]*G[{yu}, yv^(-1)]*G[{1, yv^(-1)}, yw])/16 - 
     (G[{0}, yv^(-1)]*G[{0}, yw]*G[{yu}, yv^(-1)]*G[{1, yv^(-1)}, yw])/16 + 
     (G[{0}, yw]^2*G[{yu}, yv^(-1)]*G[{1, yv^(-1)}, yw])/32 + 
     (G[{0}, yu^(-1)]*G[{1}, yu^(-1)]*G[{yu}, yv^(-1)]*G[{1, yv^(-1)}, yw])/
      16 + (G[{0}, yv^(-1)]*G[{1}, yu^(-1)]*G[{yu}, yv^(-1)]*
       G[{1, yv^(-1)}, yw])/16 - (G[{0}, yw]*G[{1}, yu^(-1)]*G[{yu}, yv^(-1)]*
       G[{1, yv^(-1)}, yw])/16 - (3*G[{1}, yu^(-1)]^2*G[{yu}, yv^(-1)]*
       G[{1, yv^(-1)}, yw])/32 + (G[{0}, yu^(-1)]*G[{1}, yv^(-1)]*
       G[{yu}, yv^(-1)]*G[{1, yv^(-1)}, yw])/16 + 
     (G[{0}, yv^(-1)]*G[{1}, yv^(-1)]*G[{yu}, yv^(-1)]*G[{1, yv^(-1)}, yw])/
      16 - (G[{0}, yw]*G[{1}, yv^(-1)]*G[{yu}, yv^(-1)]*G[{1, yv^(-1)}, yw])/
      16 - (G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*G[{yu}, yv^(-1)]*
       G[{1, yv^(-1)}, yw])/16 - (3*G[{1}, yv^(-1)]^2*G[{yu}, yv^(-1)]*
       G[{1, yv^(-1)}, yw])/32 + (G[{0}, yu^(-1)]*G[{1}, yw]*G[{yu}, yv^(-1)]*
       G[{1, yv^(-1)}, yw])/32 + (G[{0}, yv^(-1)]*G[{1}, yw]*G[{yu}, yv^(-1)]*
       G[{1, yv^(-1)}, yw])/32 - (G[{0}, yw]*G[{1}, yw]*G[{yu}, yv^(-1)]*
       G[{1, yv^(-1)}, yw])/32 - (G[{1}, yu^(-1)]*G[{1}, yw]*G[{yu}, yv^(-1)]*
       G[{1, yv^(-1)}, yw])/32 + (3*G[{1}, yv^(-1)]*G[{1}, yw]*
       G[{yu}, yv^(-1)]*G[{1, yv^(-1)}, yw])/32 - 
     (G[{0}, yu^(-1)]*G[{yu}, yv^(-1)]^2*G[{1, yv^(-1)}, yw])/8 - 
     (G[{0}, yv^(-1)]*G[{yu}, yv^(-1)]^2*G[{1, yv^(-1)}, yw])/8 + 
     (G[{0}, yw]*G[{yu}, yv^(-1)]^2*G[{1, yv^(-1)}, yw])/8 + 
     (G[{1}, yu^(-1)]*G[{yu}, yv^(-1)]^2*G[{1, yv^(-1)}, yw])/16 - 
     (G[{1}, yw]*G[{yu}, yv^(-1)]^2*G[{1, yv^(-1)}, yw])/16 + 
     (G[{yu}, yv^(-1)]^3*G[{1, yv^(-1)}, yw])/16 + 
     (7*Pi^2*G[{1/(yu*yv)}, yw]*G[{1, yv^(-1)}, yw])/768 + 
     (11*G[{0}, yu^(-1)]^2*G[{1/(yu*yv)}, yw]*G[{1, yv^(-1)}, yw])/128 + 
     (11*G[{0}, yu^(-1)]*G[{0}, yv^(-1)]*G[{1/(yu*yv)}, yw]*
       G[{1, yv^(-1)}, yw])/64 + (11*G[{0}, yv^(-1)]^2*G[{1/(yu*yv)}, yw]*
       G[{1, yv^(-1)}, yw])/128 - (11*G[{0}, yu^(-1)]*G[{0}, yw]*
       G[{1/(yu*yv)}, yw]*G[{1, yv^(-1)}, yw])/64 - 
     (11*G[{0}, yv^(-1)]*G[{0}, yw]*G[{1/(yu*yv)}, yw]*G[{1, yv^(-1)}, yw])/
      64 + (11*G[{0}, yw]^2*G[{1/(yu*yv)}, yw]*G[{1, yv^(-1)}, yw])/128 - 
     (9*G[{0}, yu^(-1)]*G[{1}, yu^(-1)]*G[{1/(yu*yv)}, yw]*
       G[{1, yv^(-1)}, yw])/64 - (9*G[{0}, yv^(-1)]*G[{1}, yu^(-1)]*
       G[{1/(yu*yv)}, yw]*G[{1, yv^(-1)}, yw])/64 + 
     (9*G[{0}, yw]*G[{1}, yu^(-1)]*G[{1/(yu*yv)}, yw]*G[{1, yv^(-1)}, yw])/
      64 + (G[{1}, yu^(-1)]^2*G[{1/(yu*yv)}, yw]*G[{1, yv^(-1)}, yw])/32 - 
     (11*G[{0}, yu^(-1)]*G[{1}, yv^(-1)]*G[{1/(yu*yv)}, yw]*
       G[{1, yv^(-1)}, yw])/64 - (11*G[{0}, yv^(-1)]*G[{1}, yv^(-1)]*
       G[{1/(yu*yv)}, yw]*G[{1, yv^(-1)}, yw])/64 + 
     (11*G[{0}, yw]*G[{1}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{1, yv^(-1)}, yw])/
      64 + (G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*G[{1/(yu*yv)}, yw]*
       G[{1, yv^(-1)}, yw])/8 + (11*G[{1}, yv^(-1)]^2*G[{1/(yu*yv)}, yw]*
       G[{1, yv^(-1)}, yw])/128 + (G[{0}, yu^(-1)]*G[{1}, yw]*
       G[{1/(yu*yv)}, yw]*G[{1, yv^(-1)}, yw])/16 + 
     (G[{0}, yv^(-1)]*G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{1, yv^(-1)}, yw])/16 - 
     (G[{0}, yw]*G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{1, yv^(-1)}, yw])/16 - 
     (7*G[{1}, yu^(-1)]*G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{1, yv^(-1)}, yw])/
      64 - (G[{1}, yv^(-1)]*G[{1}, yw]*G[{1/(yu*yv)}, yw]*
       G[{1, yv^(-1)}, yw])/16 - (3*G[{1}, yw]^2*G[{1/(yu*yv)}, yw]*
       G[{1, yv^(-1)}, yw])/128 - (G[{0}, yu^(-1)]*G[{yu^(-1)}, yw]*
       G[{1/(yu*yv)}, yw]*G[{1, yv^(-1)}, yw])/32 - 
     (G[{0}, yv^(-1)]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*
       G[{1, yv^(-1)}, yw])/32 + (G[{0}, yw]*G[{yu^(-1)}, yw]*
       G[{1/(yu*yv)}, yw]*G[{1, yv^(-1)}, yw])/32 + 
     (5*G[{1}, yu^(-1)]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*
       G[{1, yv^(-1)}, yw])/32 - (G[{1}, yv^(-1)]*G[{yu^(-1)}, yw]*
       G[{1/(yu*yv)}, yw]*G[{1, yv^(-1)}, yw])/32 + 
     (G[{1}, yw]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{1, yv^(-1)}, yw])/
      16 + (3*G[{yu^(-1)}, yw]^2*G[{1/(yu*yv)}, yw]*G[{1, yv^(-1)}, yw])/64 - 
     (G[{0}, yu^(-1)]*G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw]*
       G[{1, yv^(-1)}, yw])/32 - (G[{0}, yv^(-1)]*G[{yu}, yv^(-1)]*
       G[{1/(yu*yv)}, yw]*G[{1, yv^(-1)}, yw])/32 + 
     (G[{0}, yw]*G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{1, yv^(-1)}, yw])/
      32 + (3*G[{1}, yu^(-1)]*G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw]*
       G[{1, yv^(-1)}, yw])/32 + (G[{1}, yv^(-1)]*G[{yu}, yv^(-1)]*
       G[{1/(yu*yv)}, yw]*G[{1, yv^(-1)}, yw])/32 + 
     (3*G[{1}, yw]*G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{1, yv^(-1)}, yw])/
      64 - (G[{yu^(-1)}, yw]*G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw]*
       G[{1, yv^(-1)}, yw])/16 - (G[{yu}, yv^(-1)]^2*G[{1/(yu*yv)}, yw]*
       G[{1, yv^(-1)}, yw])/32 + (G[{0}, yu^(-1)]*G[{yv^(-1)}, yw]*
       G[{1/(yu*yv)}, yw]*G[{1, yv^(-1)}, yw])/16 + 
     (G[{0}, yv^(-1)]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*
       G[{1, yv^(-1)}, yw])/16 - (G[{0}, yw]*G[{yv^(-1)}, yw]*
       G[{1/(yu*yv)}, yw]*G[{1, yv^(-1)}, yw])/16 - 
     (G[{1}, yv^(-1)]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*
       G[{1, yv^(-1)}, yw])/16 + (G[{1}, yw]*G[{yv^(-1)}, yw]*
       G[{1/(yu*yv)}, yw]*G[{1, yv^(-1)}, yw])/16 - 
     (G[{yu^(-1)}, yw]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*
       G[{1, yv^(-1)}, yw])/32 - (G[{yu}, yv^(-1)]*G[{yv^(-1)}, yw]*
       G[{1/(yu*yv)}, yw]*G[{1, yv^(-1)}, yw])/16 + 
     (G[{yv^(-1)}, yw]^2*G[{1/(yu*yv)}, yw]*G[{1, yv^(-1)}, yw])/64 + 
     (G[{0}, yu^(-1)]*G[{1/(yu*yv)}, yw]^2*G[{1, yv^(-1)}, yw])/64 + 
     (G[{0}, yv^(-1)]*G[{1/(yu*yv)}, yw]^2*G[{1, yv^(-1)}, yw])/64 - 
     (G[{0}, yw]*G[{1/(yu*yv)}, yw]^2*G[{1, yv^(-1)}, yw])/64 + 
     (G[{1}, yu^(-1)]*G[{1/(yu*yv)}, yw]^2*G[{1, yv^(-1)}, yw])/32 - 
     (7*G[{1}, yv^(-1)]*G[{1/(yu*yv)}, yw]^2*G[{1, yv^(-1)}, yw])/64 - 
     (3*G[{1}, yw]*G[{1/(yu*yv)}, yw]^2*G[{1, yv^(-1)}, yw])/64 + 
     (G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2*G[{1, yv^(-1)}, yw])/16 + 
     (3*G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw]^2*G[{1, yv^(-1)}, yw])/64 - 
     (5*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2*G[{1, yv^(-1)}, yw])/64 - 
     (G[{0}, yu^(-1)]*G[{0, 1}, yu^(-1)]*G[{1, yv^(-1)}, yw])/32 - 
     (G[{0}, yv^(-1)]*G[{0, 1}, yu^(-1)]*G[{1, yv^(-1)}, yw])/32 + 
     (G[{0}, yw]*G[{0, 1}, yu^(-1)]*G[{1, yv^(-1)}, yw])/32 + 
     (G[{1}, yu^(-1)]*G[{0, 1}, yu^(-1)]*G[{1, yv^(-1)}, yw])/32 + 
     (G[{1}, yv^(-1)]*G[{0, 1}, yu^(-1)]*G[{1, yv^(-1)}, yw])/32 - 
     (G[{1/(yu*yv)}, yw]*G[{0, 1}, yu^(-1)]*G[{1, yv^(-1)}, yw])/64 - 
     (G[{0}, yu^(-1)]*G[{0, 1}, yv^(-1)]*G[{1, yv^(-1)}, yw])/8 - 
     (G[{0}, yv^(-1)]*G[{0, 1}, yv^(-1)]*G[{1, yv^(-1)}, yw])/8 + 
     (G[{0}, yw]*G[{0, 1}, yv^(-1)]*G[{1, yv^(-1)}, yw])/8 + 
     (G[{1}, yv^(-1)]*G[{0, 1}, yv^(-1)]*G[{1, yv^(-1)}, yw])/8 - 
     (G[{1}, yw]*G[{0, 1}, yv^(-1)]*G[{1, yv^(-1)}, yw])/8 + 
     (G[{yu}, yv^(-1)]*G[{0, 1}, yv^(-1)]*G[{1, yv^(-1)}, yw])/8 + 
     (G[{0}, yu^(-1)]*G[{0, 1}, yw]*G[{1, yv^(-1)}, yw])/32 + 
     (G[{0}, yv^(-1)]*G[{0, 1}, yw]*G[{1, yv^(-1)}, yw])/32 - 
     (G[{0}, yw]*G[{0, 1}, yw]*G[{1, yv^(-1)}, yw])/32 + 
     (G[{1}, yu^(-1)]*G[{0, 1}, yw]*G[{1, yv^(-1)}, yw])/32 - 
     (G[{1}, yv^(-1)]*G[{0, 1}, yw]*G[{1, yv^(-1)}, yw])/32 + 
     (5*G[{1}, yw]*G[{0, 1}, yw]*G[{1, yv^(-1)}, yw])/64 - 
     (G[{yu}, yv^(-1)]*G[{0, 1}, yw]*G[{1, yv^(-1)}, yw])/16 + 
     (G[{1/(yu*yv)}, yw]*G[{0, 1}, yw]*G[{1, yv^(-1)}, yw])/32 - 
     (G[{0}, yu^(-1)]*G[{0, yu^(-1)}, yw]*G[{1, yv^(-1)}, yw])/32 - 
     (G[{0}, yv^(-1)]*G[{0, yu^(-1)}, yw]*G[{1, yv^(-1)}, yw])/32 + 
     (G[{0}, yw]*G[{0, yu^(-1)}, yw]*G[{1, yv^(-1)}, yw])/32 - 
     (G[{1}, yu^(-1)]*G[{0, yu^(-1)}, yw]*G[{1, yv^(-1)}, yw])/32 + 
     (G[{1}, yv^(-1)]*G[{0, yu^(-1)}, yw]*G[{1, yv^(-1)}, yw])/32 - 
     (5*G[{1}, yw]*G[{0, yu^(-1)}, yw]*G[{1, yv^(-1)}, yw])/64 + 
     (G[{yu}, yv^(-1)]*G[{0, yu^(-1)}, yw]*G[{1, yv^(-1)}, yw])/16 - 
     (G[{1/(yu*yv)}, yw]*G[{0, yu^(-1)}, yw]*G[{1, yv^(-1)}, yw])/32 + 
     (G[{0}, yu^(-1)]*G[{0, yu}, yv^(-1)]*G[{1, yv^(-1)}, yw])/8 + 
     (G[{0}, yv^(-1)]*G[{0, yu}, yv^(-1)]*G[{1, yv^(-1)}, yw])/8 - 
     (G[{0}, yw]*G[{0, yu}, yv^(-1)]*G[{1, yv^(-1)}, yw])/8 - 
     (G[{1}, yv^(-1)]*G[{0, yu}, yv^(-1)]*G[{1, yv^(-1)}, yw])/8 + 
     (G[{1}, yw]*G[{0, yu}, yv^(-1)]*G[{1, yv^(-1)}, yw])/8 - 
     (G[{yu}, yv^(-1)]*G[{0, yu}, yv^(-1)]*G[{1, yv^(-1)}, yw])/8 - 
     (G[{0}, yu^(-1)]*G[{0, yv^(-1)}, yw]*G[{1, yv^(-1)}, yw])/32 - 
     (G[{0}, yv^(-1)]*G[{0, yv^(-1)}, yw]*G[{1, yv^(-1)}, yw])/32 + 
     (G[{0}, yw]*G[{0, yv^(-1)}, yw]*G[{1, yv^(-1)}, yw])/32 - 
     (G[{1}, yu^(-1)]*G[{0, yv^(-1)}, yw]*G[{1, yv^(-1)}, yw])/32 + 
     (G[{1}, yv^(-1)]*G[{0, yv^(-1)}, yw]*G[{1, yv^(-1)}, yw])/32 - 
     (5*G[{1}, yw]*G[{0, yv^(-1)}, yw]*G[{1, yv^(-1)}, yw])/64 + 
     (G[{yu}, yv^(-1)]*G[{0, yv^(-1)}, yw]*G[{1, yv^(-1)}, yw])/16 - 
     (G[{1/(yu*yv)}, yw]*G[{0, yv^(-1)}, yw]*G[{1, yv^(-1)}, yw])/32 + 
     (G[{0}, yu^(-1)]*G[{0, 1/(yu*yv)}, yw]*G[{1, yv^(-1)}, yw])/32 + 
     (G[{0}, yv^(-1)]*G[{0, 1/(yu*yv)}, yw]*G[{1, yv^(-1)}, yw])/32 - 
     (G[{0}, yw]*G[{0, 1/(yu*yv)}, yw]*G[{1, yv^(-1)}, yw])/32 + 
     (G[{1}, yu^(-1)]*G[{0, 1/(yu*yv)}, yw]*G[{1, yv^(-1)}, yw])/32 - 
     (G[{1}, yv^(-1)]*G[{0, 1/(yu*yv)}, yw]*G[{1, yv^(-1)}, yw])/32 + 
     (5*G[{1}, yw]*G[{0, 1/(yu*yv)}, yw]*G[{1, yv^(-1)}, yw])/64 - 
     (G[{yu}, yv^(-1)]*G[{0, 1/(yu*yv)}, yw]*G[{1, yv^(-1)}, yw])/16 + 
     (G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv)}, yw]*G[{1, yv^(-1)}, yw])/32 - 
     (3*G[{0}, yu^(-1)]*G[{1, yu^(-1)}, yw]*G[{1, yv^(-1)}, yw])/32 - 
     (3*G[{0}, yv^(-1)]*G[{1, yu^(-1)}, yw]*G[{1, yv^(-1)}, yw])/32 + 
     (3*G[{0}, yw]*G[{1, yu^(-1)}, yw]*G[{1, yv^(-1)}, yw])/32 + 
     (G[{1}, yu^(-1)]*G[{1, yu^(-1)}, yw]*G[{1, yv^(-1)}, yw])/32 + 
     (3*G[{1}, yv^(-1)]*G[{1, yu^(-1)}, yw]*G[{1, yv^(-1)}, yw])/32 - 
     (G[{1}, yw]*G[{1, yu^(-1)}, yw]*G[{1, yv^(-1)}, yw])/16 + 
     (G[{yu}, yv^(-1)]*G[{1, yu^(-1)}, yw]*G[{1, yv^(-1)}, yw])/16 + 
     (G[{1/(yu*yv)}, yw]*G[{1, yu^(-1)}, yw]*G[{1, yv^(-1)}, yw])/32 - 
     (3*G[{0}, yu^(-1)]*G[{1, yu}, yv^(-1)]*G[{1, yv^(-1)}, yw])/32 - 
     (3*G[{0}, yv^(-1)]*G[{1, yu}, yv^(-1)]*G[{1, yv^(-1)}, yw])/32 + 
     (3*G[{0}, yw]*G[{1, yu}, yv^(-1)]*G[{1, yv^(-1)}, yw])/32 - 
     (G[{1}, yu^(-1)]*G[{1, yu}, yv^(-1)]*G[{1, yv^(-1)}, yw])/32 + 
     (3*G[{1}, yv^(-1)]*G[{1, yu}, yv^(-1)]*G[{1, yv^(-1)}, yw])/32 - 
     (G[{1}, yw]*G[{1, yu}, yv^(-1)]*G[{1, yv^(-1)}, yw])/8 + 
     (G[{yu}, yv^(-1)]*G[{1, yu}, yv^(-1)]*G[{1, yv^(-1)}, yw])/8 + 
     (G[{1/(yu*yv)}, yw]*G[{1, yu}, yv^(-1)]*G[{1, yv^(-1)}, yw])/64 + 
     (G[{1}, yu^(-1)]*G[{1, yv^(-1)}, yw]^2)/32 + 
     (G[{1}, yw]*G[{1, yv^(-1)}, yw]^2)/32 - 
     (G[{yu}, yv^(-1)]*G[{1, yv^(-1)}, yw]^2)/32 + 
     (G[{1/(yu*yv)}, yw]*G[{1, yv^(-1)}, yw]^2)/128 - 
     (7*Pi^2*G[{0}, yu^(-1)]*G[{1, 1/(yu*yv)}, yw])/384 - 
     (3*G[{0}, yu^(-1)]^3*G[{1, 1/(yu*yv)}, yw])/128 - 
     (7*Pi^2*G[{0}, yv^(-1)]*G[{1, 1/(yu*yv)}, yw])/384 - 
     (9*G[{0}, yu^(-1)]^2*G[{0}, yv^(-1)]*G[{1, 1/(yu*yv)}, yw])/128 - 
     (9*G[{0}, yu^(-1)]*G[{0}, yv^(-1)]^2*G[{1, 1/(yu*yv)}, yw])/128 - 
     (3*G[{0}, yv^(-1)]^3*G[{1, 1/(yu*yv)}, yw])/128 + 
     (7*Pi^2*G[{0}, yw]*G[{1, 1/(yu*yv)}, yw])/384 + 
     (9*G[{0}, yu^(-1)]^2*G[{0}, yw]*G[{1, 1/(yu*yv)}, yw])/128 + 
     (9*G[{0}, yu^(-1)]*G[{0}, yv^(-1)]*G[{0}, yw]*G[{1, 1/(yu*yv)}, yw])/
      64 + (9*G[{0}, yv^(-1)]^2*G[{0}, yw]*G[{1, 1/(yu*yv)}, yw])/128 - 
     (9*G[{0}, yu^(-1)]*G[{0}, yw]^2*G[{1, 1/(yu*yv)}, yw])/128 - 
     (9*G[{0}, yv^(-1)]*G[{0}, yw]^2*G[{1, 1/(yu*yv)}, yw])/128 + 
     (3*G[{0}, yw]^3*G[{1, 1/(yu*yv)}, yw])/128 + 
     (7*Pi^2*G[{1}, yu^(-1)]*G[{1, 1/(yu*yv)}, yw])/384 + 
     (G[{0}, yu^(-1)]^2*G[{1}, yu^(-1)]*G[{1, 1/(yu*yv)}, yw])/128 + 
     (G[{0}, yu^(-1)]*G[{0}, yv^(-1)]*G[{1}, yu^(-1)]*G[{1, 1/(yu*yv)}, yw])/
      64 + (G[{0}, yv^(-1)]^2*G[{1}, yu^(-1)]*G[{1, 1/(yu*yv)}, yw])/128 - 
     (G[{0}, yu^(-1)]*G[{0}, yw]*G[{1}, yu^(-1)]*G[{1, 1/(yu*yv)}, yw])/64 - 
     (G[{0}, yv^(-1)]*G[{0}, yw]*G[{1}, yu^(-1)]*G[{1, 1/(yu*yv)}, yw])/64 + 
     (G[{0}, yw]^2*G[{1}, yu^(-1)]*G[{1, 1/(yu*yv)}, yw])/128 + 
     (7*G[{0}, yu^(-1)]*G[{1}, yu^(-1)]^2*G[{1, 1/(yu*yv)}, yw])/128 + 
     (7*G[{0}, yv^(-1)]*G[{1}, yu^(-1)]^2*G[{1, 1/(yu*yv)}, yw])/128 - 
     (7*G[{0}, yw]*G[{1}, yu^(-1)]^2*G[{1, 1/(yu*yv)}, yw])/128 - 
     (5*G[{1}, yu^(-1)]^3*G[{1, 1/(yu*yv)}, yw])/128 - 
     (Pi^2*G[{1}, yv^(-1)]*G[{1, 1/(yu*yv)}, yw])/384 - 
     (3*G[{0}, yu^(-1)]^2*G[{1}, yv^(-1)]*G[{1, 1/(yu*yv)}, yw])/128 - 
     (3*G[{0}, yu^(-1)]*G[{0}, yv^(-1)]*G[{1}, yv^(-1)]*
       G[{1, 1/(yu*yv)}, yw])/64 - (3*G[{0}, yv^(-1)]^2*G[{1}, yv^(-1)]*
       G[{1, 1/(yu*yv)}, yw])/128 + (3*G[{0}, yu^(-1)]*G[{0}, yw]*
       G[{1}, yv^(-1)]*G[{1, 1/(yu*yv)}, yw])/64 + 
     (3*G[{0}, yv^(-1)]*G[{0}, yw]*G[{1}, yv^(-1)]*G[{1, 1/(yu*yv)}, yw])/
      64 - (3*G[{0}, yw]^2*G[{1}, yv^(-1)]*G[{1, 1/(yu*yv)}, yw])/128 + 
     (11*G[{0}, yu^(-1)]*G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*
       G[{1, 1/(yu*yv)}, yw])/64 + (11*G[{0}, yv^(-1)]*G[{1}, yu^(-1)]*
       G[{1}, yv^(-1)]*G[{1, 1/(yu*yv)}, yw])/64 - 
     (11*G[{0}, yw]*G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*G[{1, 1/(yu*yv)}, yw])/
      64 - (19*G[{1}, yu^(-1)]^2*G[{1}, yv^(-1)]*G[{1, 1/(yu*yv)}, yw])/128 + 
     (11*G[{0}, yu^(-1)]*G[{1}, yv^(-1)]^2*G[{1, 1/(yu*yv)}, yw])/128 + 
     (11*G[{0}, yv^(-1)]*G[{1}, yv^(-1)]^2*G[{1, 1/(yu*yv)}, yw])/128 - 
     (11*G[{0}, yw]*G[{1}, yv^(-1)]^2*G[{1, 1/(yu*yv)}, yw])/128 - 
     (11*G[{1}, yu^(-1)]*G[{1}, yv^(-1)]^2*G[{1, 1/(yu*yv)}, yw])/128 - 
     (5*G[{1}, yv^(-1)]^3*G[{1, 1/(yu*yv)}, yw])/128 - 
     (7*Pi^2*G[{1}, yw]*G[{1, 1/(yu*yv)}, yw])/384 - 
     (17*G[{0}, yu^(-1)]^2*G[{1}, yw]*G[{1, 1/(yu*yv)}, yw])/128 - 
     (17*G[{0}, yu^(-1)]*G[{0}, yv^(-1)]*G[{1}, yw]*G[{1, 1/(yu*yv)}, yw])/
      64 - (17*G[{0}, yv^(-1)]^2*G[{1}, yw]*G[{1, 1/(yu*yv)}, yw])/128 + 
     (17*G[{0}, yu^(-1)]*G[{0}, yw]*G[{1}, yw]*G[{1, 1/(yu*yv)}, yw])/64 + 
     (17*G[{0}, yv^(-1)]*G[{0}, yw]*G[{1}, yw]*G[{1, 1/(yu*yv)}, yw])/64 - 
     (17*G[{0}, yw]^2*G[{1}, yw]*G[{1, 1/(yu*yv)}, yw])/128 + 
     (9*G[{0}, yu^(-1)]*G[{1}, yu^(-1)]*G[{1}, yw]*G[{1, 1/(yu*yv)}, yw])/
      64 + (9*G[{0}, yv^(-1)]*G[{1}, yu^(-1)]*G[{1}, yw]*
       G[{1, 1/(yu*yv)}, yw])/64 - (9*G[{0}, yw]*G[{1}, yu^(-1)]*G[{1}, yw]*
       G[{1, 1/(yu*yv)}, yw])/64 - (G[{1}, yu^(-1)]^2*G[{1}, yw]*
       G[{1, 1/(yu*yv)}, yw])/128 + (9*G[{0}, yu^(-1)]*G[{1}, yv^(-1)]*
       G[{1}, yw]*G[{1, 1/(yu*yv)}, yw])/64 + 
     (9*G[{0}, yv^(-1)]*G[{1}, yv^(-1)]*G[{1}, yw]*G[{1, 1/(yu*yv)}, yw])/
      64 - (9*G[{0}, yw]*G[{1}, yv^(-1)]*G[{1}, yw]*G[{1, 1/(yu*yv)}, yw])/
      64 - (G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*G[{1}, yw]*G[{1, 1/(yu*yv)}, yw])/
      64 - (5*G[{1}, yv^(-1)]^2*G[{1}, yw]*G[{1, 1/(yu*yv)}, yw])/128 - 
     (19*G[{0}, yu^(-1)]*G[{1}, yw]^2*G[{1, 1/(yu*yv)}, yw])/128 - 
     (19*G[{0}, yv^(-1)]*G[{1}, yw]^2*G[{1, 1/(yu*yv)}, yw])/128 + 
     (19*G[{0}, yw]*G[{1}, yw]^2*G[{1, 1/(yu*yv)}, yw])/128 + 
     (15*G[{1}, yu^(-1)]*G[{1}, yw]^2*G[{1, 1/(yu*yv)}, yw])/128 + 
     (11*G[{1}, yv^(-1)]*G[{1}, yw]^2*G[{1, 1/(yu*yv)}, yw])/128 - 
     (G[{1}, yw]^3*G[{1, 1/(yu*yv)}, yw])/32 + 
     (Pi^2*G[{yu}, yv^(-1)]*G[{1, 1/(yu*yv)}, yw])/48 + 
     (5*G[{0}, yu^(-1)]^2*G[{yu}, yv^(-1)]*G[{1, 1/(yu*yv)}, yw])/32 + 
     (5*G[{0}, yu^(-1)]*G[{0}, yv^(-1)]*G[{yu}, yv^(-1)]*
       G[{1, 1/(yu*yv)}, yw])/16 + (5*G[{0}, yv^(-1)]^2*G[{yu}, yv^(-1)]*
       G[{1, 1/(yu*yv)}, yw])/32 - (5*G[{0}, yu^(-1)]*G[{0}, yw]*
       G[{yu}, yv^(-1)]*G[{1, 1/(yu*yv)}, yw])/16 - 
     (5*G[{0}, yv^(-1)]*G[{0}, yw]*G[{yu}, yv^(-1)]*G[{1, 1/(yu*yv)}, yw])/
      16 + (5*G[{0}, yw]^2*G[{yu}, yv^(-1)]*G[{1, 1/(yu*yv)}, yw])/32 - 
     (5*G[{0}, yu^(-1)]*G[{1}, yu^(-1)]*G[{yu}, yv^(-1)]*
       G[{1, 1/(yu*yv)}, yw])/16 - (5*G[{0}, yv^(-1)]*G[{1}, yu^(-1)]*
       G[{yu}, yv^(-1)]*G[{1, 1/(yu*yv)}, yw])/16 + 
     (5*G[{0}, yw]*G[{1}, yu^(-1)]*G[{yu}, yv^(-1)]*G[{1, 1/(yu*yv)}, yw])/
      16 + (5*G[{1}, yu^(-1)]^2*G[{yu}, yv^(-1)]*G[{1, 1/(yu*yv)}, yw])/32 - 
     (G[{0}, yu^(-1)]*G[{1}, yv^(-1)]*G[{yu}, yv^(-1)]*G[{1, 1/(yu*yv)}, yw])/
      16 - (G[{0}, yv^(-1)]*G[{1}, yv^(-1)]*G[{yu}, yv^(-1)]*
       G[{1, 1/(yu*yv)}, yw])/16 + (G[{0}, yw]*G[{1}, yv^(-1)]*
       G[{yu}, yv^(-1)]*G[{1, 1/(yu*yv)}, yw])/16 - 
     (G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*G[{yu}, yv^(-1)]*G[{1, 1/(yu*yv)}, yw])/
      16 - (G[{1}, yv^(-1)]^2*G[{yu}, yv^(-1)]*G[{1, 1/(yu*yv)}, yw])/32 + 
     (G[{0}, yu^(-1)]*G[{1}, yw]*G[{yu}, yv^(-1)]*G[{1, 1/(yu*yv)}, yw])/4 + 
     (G[{0}, yv^(-1)]*G[{1}, yw]*G[{yu}, yv^(-1)]*G[{1, 1/(yu*yv)}, yw])/4 - 
     (G[{0}, yw]*G[{1}, yw]*G[{yu}, yv^(-1)]*G[{1, 1/(yu*yv)}, yw])/4 - 
     (G[{1}, yu^(-1)]*G[{1}, yw]*G[{yu}, yv^(-1)]*G[{1, 1/(yu*yv)}, yw])/4 - 
     (G[{1}, yv^(-1)]*G[{1}, yw]*G[{yu}, yv^(-1)]*G[{1, 1/(yu*yv)}, yw])/16 + 
     (3*G[{1}, yw]^2*G[{yu}, yv^(-1)]*G[{1, 1/(yu*yv)}, yw])/32 - 
     (G[{0}, yu^(-1)]*G[{yu}, yv^(-1)]^2*G[{1, 1/(yu*yv)}, yw])/8 - 
     (G[{0}, yv^(-1)]*G[{yu}, yv^(-1)]^2*G[{1, 1/(yu*yv)}, yw])/8 + 
     (G[{0}, yw]*G[{yu}, yv^(-1)]^2*G[{1, 1/(yu*yv)}, yw])/8 + 
     (3*G[{1}, yu^(-1)]*G[{yu}, yv^(-1)]^2*G[{1, 1/(yu*yv)}, yw])/16 - 
     (3*G[{1}, yw]*G[{yu}, yv^(-1)]^2*G[{1, 1/(yu*yv)}, yw])/32 + 
     (G[{yu}, yv^(-1)]^3*G[{1, 1/(yu*yv)}, yw])/48 + 
     (Pi^2*G[{1/(yu*yv)}, yw]*G[{1, 1/(yu*yv)}, yw])/384 - 
     (5*G[{0}, yu^(-1)]^2*G[{1/(yu*yv)}, yw]*G[{1, 1/(yu*yv)}, yw])/128 - 
     (5*G[{0}, yu^(-1)]*G[{0}, yv^(-1)]*G[{1/(yu*yv)}, yw]*
       G[{1, 1/(yu*yv)}, yw])/64 - (5*G[{0}, yv^(-1)]^2*G[{1/(yu*yv)}, yw]*
       G[{1, 1/(yu*yv)}, yw])/128 + (5*G[{0}, yu^(-1)]*G[{0}, yw]*
       G[{1/(yu*yv)}, yw]*G[{1, 1/(yu*yv)}, yw])/64 + 
     (5*G[{0}, yv^(-1)]*G[{0}, yw]*G[{1/(yu*yv)}, yw]*G[{1, 1/(yu*yv)}, yw])/
      64 - (5*G[{0}, yw]^2*G[{1/(yu*yv)}, yw]*G[{1, 1/(yu*yv)}, yw])/128 + 
     (G[{0}, yu^(-1)]*G[{1}, yu^(-1)]*G[{1/(yu*yv)}, yw]*
       G[{1, 1/(yu*yv)}, yw])/64 + (G[{0}, yv^(-1)]*G[{1}, yu^(-1)]*
       G[{1/(yu*yv)}, yw]*G[{1, 1/(yu*yv)}, yw])/64 - 
     (G[{0}, yw]*G[{1}, yu^(-1)]*G[{1/(yu*yv)}, yw]*G[{1, 1/(yu*yv)}, yw])/
      64 + (3*G[{1}, yu^(-1)]^2*G[{1/(yu*yv)}, yw]*G[{1, 1/(yu*yv)}, yw])/
      128 + (9*G[{0}, yu^(-1)]*G[{1}, yv^(-1)]*G[{1/(yu*yv)}, yw]*
       G[{1, 1/(yu*yv)}, yw])/64 + (9*G[{0}, yv^(-1)]*G[{1}, yv^(-1)]*
       G[{1/(yu*yv)}, yw]*G[{1, 1/(yu*yv)}, yw])/64 - 
     (9*G[{0}, yw]*G[{1}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{1, 1/(yu*yv)}, yw])/
      64 - (G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*G[{1/(yu*yv)}, yw]*
       G[{1, 1/(yu*yv)}, yw])/64 - (13*G[{1}, yv^(-1)]^2*G[{1/(yu*yv)}, yw]*
       G[{1, 1/(yu*yv)}, yw])/128 - (3*G[{0}, yu^(-1)]*G[{1}, yw]*
       G[{1/(yu*yv)}, yw]*G[{1, 1/(yu*yv)}, yw])/64 - 
     (3*G[{0}, yv^(-1)]*G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{1, 1/(yu*yv)}, yw])/
      64 + (3*G[{0}, yw]*G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{1, 1/(yu*yv)}, yw])/
      64 + (3*G[{1}, yu^(-1)]*G[{1}, yw]*G[{1/(yu*yv)}, yw]*
       G[{1, 1/(yu*yv)}, yw])/64 + (3*G[{1}, yv^(-1)]*G[{1}, yw]*
       G[{1/(yu*yv)}, yw]*G[{1, 1/(yu*yv)}, yw])/64 + 
     (7*G[{0}, yu^(-1)]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*
       G[{1, 1/(yu*yv)}, yw])/32 + (7*G[{0}, yv^(-1)]*G[{yu^(-1)}, yw]*
       G[{1/(yu*yv)}, yw]*G[{1, 1/(yu*yv)}, yw])/32 - 
     (7*G[{0}, yw]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{1, 1/(yu*yv)}, yw])/
      32 - (7*G[{1}, yu^(-1)]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*
       G[{1, 1/(yu*yv)}, yw])/32 - (G[{1}, yv^(-1)]*G[{yu^(-1)}, yw]*
       G[{1/(yu*yv)}, yw]*G[{1, 1/(yu*yv)}, yw])/32 + 
     (3*G[{1}, yw]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{1, 1/(yu*yv)}, yw])/
      16 + (9*G[{yu^(-1)}, yw]^2*G[{1/(yu*yv)}, yw]*G[{1, 1/(yu*yv)}, yw])/
      64 - (G[{1}, yu^(-1)]*G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw]*
       G[{1, 1/(yu*yv)}, yw])/16 - (G[{1}, yv^(-1)]*G[{yu}, yv^(-1)]*
       G[{1/(yu*yv)}, yw]*G[{1, 1/(yu*yv)}, yw])/16 - 
     (3*G[{yu^(-1)}, yw]*G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw]*
       G[{1, 1/(yu*yv)}, yw])/16 + (G[{yu}, yv^(-1)]^2*G[{1/(yu*yv)}, yw]*
       G[{1, 1/(yu*yv)}, yw])/16 - (3*G[{0}, yu^(-1)]*G[{yv^(-1)}, yw]*
       G[{1/(yu*yv)}, yw]*G[{1, 1/(yu*yv)}, yw])/32 - 
     (3*G[{0}, yv^(-1)]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*
       G[{1, 1/(yu*yv)}, yw])/32 + (3*G[{0}, yw]*G[{yv^(-1)}, yw]*
       G[{1/(yu*yv)}, yw]*G[{1, 1/(yu*yv)}, yw])/32 + 
     (3*G[{1}, yu^(-1)]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*
       G[{1, 1/(yu*yv)}, yw])/32 + (3*G[{1}, yv^(-1)]*G[{yv^(-1)}, yw]*
       G[{1/(yu*yv)}, yw]*G[{1, 1/(yu*yv)}, yw])/32 + 
     (5*G[{yu^(-1)}, yw]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*
       G[{1, 1/(yu*yv)}, yw])/32 - (7*G[{yv^(-1)}, yw]^2*G[{1/(yu*yv)}, yw]*
       G[{1, 1/(yu*yv)}, yw])/64 + (G[{0}, yu^(-1)]*G[{1/(yu*yv)}, yw]^2*
       G[{1, 1/(yu*yv)}, yw])/128 + (G[{0}, yv^(-1)]*G[{1/(yu*yv)}, yw]^2*
       G[{1, 1/(yu*yv)}, yw])/128 - (G[{0}, yw]*G[{1/(yu*yv)}, yw]^2*
       G[{1, 1/(yu*yv)}, yw])/128 - (G[{1}, yu^(-1)]*G[{1/(yu*yv)}, yw]^2*
       G[{1, 1/(yu*yv)}, yw])/128 + (7*G[{1}, yv^(-1)]*G[{1/(yu*yv)}, yw]^2*
       G[{1, 1/(yu*yv)}, yw])/128 + (G[{1}, yw]*G[{1/(yu*yv)}, yw]^2*
       G[{1, 1/(yu*yv)}, yw])/16 - (7*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2*
       G[{1, 1/(yu*yv)}, yw])/128 - (G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw]^2*
       G[{1, 1/(yu*yv)}, yw])/16 + (G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2*
       G[{1, 1/(yu*yv)}, yw])/128 + (G[{0}, yu^(-1)]*G[{0, 1}, yu^(-1)]*
       G[{1, 1/(yu*yv)}, yw])/16 + (G[{0}, yv^(-1)]*G[{0, 1}, yu^(-1)]*
       G[{1, 1/(yu*yv)}, yw])/16 - (G[{0}, yw]*G[{0, 1}, yu^(-1)]*
       G[{1, 1/(yu*yv)}, yw])/16 - (G[{1}, yu^(-1)]*G[{0, 1}, yu^(-1)]*
       G[{1, 1/(yu*yv)}, yw])/16 + (G[{1}, yv^(-1)]*G[{0, 1}, yu^(-1)]*
       G[{1, 1/(yu*yv)}, yw])/16 + (G[{1}, yw]*G[{0, 1}, yu^(-1)]*
       G[{1, 1/(yu*yv)}, yw])/16 - (G[{yu}, yv^(-1)]*G[{0, 1}, yu^(-1)]*
       G[{1, 1/(yu*yv)}, yw])/8 + (G[{1/(yu*yv)}, yw]*G[{0, 1}, yu^(-1)]*
       G[{1, 1/(yu*yv)}, yw])/16 - (G[{0}, yu^(-1)]*G[{0, 1}, yv^(-1)]*
       G[{1, 1/(yu*yv)}, yw])/8 - (G[{0}, yv^(-1)]*G[{0, 1}, yv^(-1)]*
       G[{1, 1/(yu*yv)}, yw])/8 + (G[{0}, yw]*G[{0, 1}, yv^(-1)]*
       G[{1, 1/(yu*yv)}, yw])/8 + (G[{1}, yu^(-1)]*G[{0, 1}, yv^(-1)]*
       G[{1, 1/(yu*yv)}, yw])/8 + (G[{1}, yv^(-1)]*G[{0, 1}, yv^(-1)]*
       G[{1, 1/(yu*yv)}, yw])/16 - (G[{1}, yw]*G[{0, 1}, yv^(-1)]*
       G[{1, 1/(yu*yv)}, yw])/16 + (G[{yu}, yv^(-1)]*G[{0, 1}, yv^(-1)]*
       G[{1, 1/(yu*yv)}, yw])/8 + (G[{1/(yu*yv)}, yw]*G[{0, 1}, yv^(-1)]*
       G[{1, 1/(yu*yv)}, yw])/16 + (G[{0}, yu^(-1)]*G[{0, 1}, yw]*
       G[{1, 1/(yu*yv)}, yw])/32 + (G[{0}, yv^(-1)]*G[{0, 1}, yw]*
       G[{1, 1/(yu*yv)}, yw])/32 - (G[{0}, yw]*G[{0, 1}, yw]*
       G[{1, 1/(yu*yv)}, yw])/32 - (3*G[{1}, yu^(-1)]*G[{0, 1}, yw]*
       G[{1, 1/(yu*yv)}, yw])/32 - (G[{1}, yv^(-1)]*G[{0, 1}, yw]*
       G[{1, 1/(yu*yv)}, yw])/32 - (3*G[{1}, yw]*G[{0, 1}, yw]*
       G[{1, 1/(yu*yv)}, yw])/64 + (G[{yu}, yv^(-1)]*G[{0, 1}, yw]*
       G[{1, 1/(yu*yv)}, yw])/16 - (3*G[{1/(yu*yv)}, yw]*G[{0, 1}, yw]*
       G[{1, 1/(yu*yv)}, yw])/64 - (G[{0}, yu^(-1)]*G[{0, yu^(-1)}, yw]*
       G[{1, 1/(yu*yv)}, yw])/32 - (G[{0}, yv^(-1)]*G[{0, yu^(-1)}, yw]*
       G[{1, 1/(yu*yv)}, yw])/32 + (G[{0}, yw]*G[{0, yu^(-1)}, yw]*
       G[{1, 1/(yu*yv)}, yw])/32 + (3*G[{1}, yu^(-1)]*G[{0, yu^(-1)}, yw]*
       G[{1, 1/(yu*yv)}, yw])/32 + (G[{1}, yv^(-1)]*G[{0, yu^(-1)}, yw]*
       G[{1, 1/(yu*yv)}, yw])/32 + (3*G[{1}, yw]*G[{0, yu^(-1)}, yw]*
       G[{1, 1/(yu*yv)}, yw])/64 - (G[{yu}, yv^(-1)]*G[{0, yu^(-1)}, yw]*
       G[{1, 1/(yu*yv)}, yw])/16 + (3*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1)}, yw]*
       G[{1, 1/(yu*yv)}, yw])/64 + (G[{0}, yu^(-1)]*G[{0, yu}, yv^(-1)]*
       G[{1, 1/(yu*yv)}, yw])/8 + (G[{0}, yv^(-1)]*G[{0, yu}, yv^(-1)]*
       G[{1, 1/(yu*yv)}, yw])/8 - (G[{0}, yw]*G[{0, yu}, yv^(-1)]*
       G[{1, 1/(yu*yv)}, yw])/8 - (G[{1}, yu^(-1)]*G[{0, yu}, yv^(-1)]*
       G[{1, 1/(yu*yv)}, yw])/8 - (G[{1}, yv^(-1)]*G[{0, yu}, yv^(-1)]*
       G[{1, 1/(yu*yv)}, yw])/16 + (G[{1}, yw]*G[{0, yu}, yv^(-1)]*
       G[{1, 1/(yu*yv)}, yw])/16 - (G[{yu}, yv^(-1)]*G[{0, yu}, yv^(-1)]*
       G[{1, 1/(yu*yv)}, yw])/8 - (G[{1/(yu*yv)}, yw]*G[{0, yu}, yv^(-1)]*
       G[{1, 1/(yu*yv)}, yw])/16 - (G[{0}, yu^(-1)]*G[{0, yv^(-1)}, yw]*
       G[{1, 1/(yu*yv)}, yw])/32 - (G[{0}, yv^(-1)]*G[{0, yv^(-1)}, yw]*
       G[{1, 1/(yu*yv)}, yw])/32 + (G[{0}, yw]*G[{0, yv^(-1)}, yw]*
       G[{1, 1/(yu*yv)}, yw])/32 + (3*G[{1}, yu^(-1)]*G[{0, yv^(-1)}, yw]*
       G[{1, 1/(yu*yv)}, yw])/32 + (G[{1}, yv^(-1)]*G[{0, yv^(-1)}, yw]*
       G[{1, 1/(yu*yv)}, yw])/32 + (3*G[{1}, yw]*G[{0, yv^(-1)}, yw]*
       G[{1, 1/(yu*yv)}, yw])/64 - (G[{yu}, yv^(-1)]*G[{0, yv^(-1)}, yw]*
       G[{1, 1/(yu*yv)}, yw])/16 + (3*G[{1/(yu*yv)}, yw]*G[{0, yv^(-1)}, yw]*
       G[{1, 1/(yu*yv)}, yw])/64 + (G[{0}, yu^(-1)]*G[{0, 1/(yu*yv)}, yw]*
       G[{1, 1/(yu*yv)}, yw])/32 + (G[{0}, yv^(-1)]*G[{0, 1/(yu*yv)}, yw]*
       G[{1, 1/(yu*yv)}, yw])/32 - (G[{0}, yw]*G[{0, 1/(yu*yv)}, yw]*
       G[{1, 1/(yu*yv)}, yw])/32 - (3*G[{1}, yu^(-1)]*G[{0, 1/(yu*yv)}, yw]*
       G[{1, 1/(yu*yv)}, yw])/32 - (G[{1}, yv^(-1)]*G[{0, 1/(yu*yv)}, yw]*
       G[{1, 1/(yu*yv)}, yw])/32 - (3*G[{1}, yw]*G[{0, 1/(yu*yv)}, yw]*
       G[{1, 1/(yu*yv)}, yw])/64 + (G[{yu}, yv^(-1)]*G[{0, 1/(yu*yv)}, yw]*
       G[{1, 1/(yu*yv)}, yw])/16 - (3*G[{1/(yu*yv)}, yw]*
       G[{0, 1/(yu*yv)}, yw]*G[{1, 1/(yu*yv)}, yw])/64 - 
     (3*G[{0}, yu^(-1)]*G[{1, yu^(-1)}, yw]*G[{1, 1/(yu*yv)}, yw])/32 - 
     (3*G[{0}, yv^(-1)]*G[{1, yu^(-1)}, yw]*G[{1, 1/(yu*yv)}, yw])/32 + 
     (3*G[{0}, yw]*G[{1, yu^(-1)}, yw]*G[{1, 1/(yu*yv)}, yw])/32 + 
     (G[{1}, yu^(-1)]*G[{1, yu^(-1)}, yw]*G[{1, 1/(yu*yv)}, yw])/32 + 
     (3*G[{1}, yv^(-1)]*G[{1, yu^(-1)}, yw]*G[{1, 1/(yu*yv)}, yw])/32 - 
     (G[{1}, yw]*G[{1, yu^(-1)}, yw]*G[{1, 1/(yu*yv)}, yw])/16 + 
     (G[{yu}, yv^(-1)]*G[{1, yu^(-1)}, yw]*G[{1, 1/(yu*yv)}, yw])/16 + 
     (G[{1/(yu*yv)}, yw]*G[{1, yu^(-1)}, yw]*G[{1, 1/(yu*yv)}, yw])/64 - 
     (3*G[{0}, yu^(-1)]*G[{1, yu}, yv^(-1)]*G[{1, 1/(yu*yv)}, yw])/16 - 
     (3*G[{0}, yv^(-1)]*G[{1, yu}, yv^(-1)]*G[{1, 1/(yu*yv)}, yw])/16 + 
     (3*G[{0}, yw]*G[{1, yu}, yv^(-1)]*G[{1, 1/(yu*yv)}, yw])/16 + 
     (3*G[{1}, yu^(-1)]*G[{1, yu}, yv^(-1)]*G[{1, 1/(yu*yv)}, yw])/16 + 
     (G[{1}, yv^(-1)]*G[{1, yu}, yv^(-1)]*G[{1, 1/(yu*yv)}, yw])/8 - 
     (G[{1}, yw]*G[{1, yu}, yv^(-1)]*G[{1, 1/(yu*yv)}, yw])/8 + 
     (G[{yu}, yv^(-1)]*G[{1, yu}, yv^(-1)]*G[{1, 1/(yu*yv)}, yw])/4 + 
     (3*G[{0}, yu^(-1)]*G[{1, yv^(-1)}, yw]*G[{1, 1/(yu*yv)}, yw])/32 + 
     (3*G[{0}, yv^(-1)]*G[{1, yv^(-1)}, yw]*G[{1, 1/(yu*yv)}, yw])/32 - 
     (3*G[{0}, yw]*G[{1, yv^(-1)}, yw]*G[{1, 1/(yu*yv)}, yw])/32 - 
     (5*G[{1}, yu^(-1)]*G[{1, yv^(-1)}, yw]*G[{1, 1/(yu*yv)}, yw])/32 - 
     (G[{1}, yv^(-1)]*G[{1, yv^(-1)}, yw]*G[{1, 1/(yu*yv)}, yw])/32 + 
     (G[{1/(yu*yv)}, yw]*G[{1, yv^(-1)}, yw]*G[{1, 1/(yu*yv)}, yw])/64 + 
     (G[{0}, yu^(-1)]*G[{1, 1/(yu*yv)}, yw]^2)/32 + 
     (G[{0}, yv^(-1)]*G[{1, 1/(yu*yv)}, yw]^2)/32 - 
     (G[{0}, yw]*G[{1, 1/(yu*yv)}, yw]^2)/32 - 
     (G[{1}, yu^(-1)]*G[{1, 1/(yu*yv)}, yw]^2)/32 - 
     (G[{1}, yv^(-1)]*G[{1, 1/(yu*yv)}, yw]^2)/16 - 
     (G[{1}, yw]*G[{1, 1/(yu*yv)}, yw]^2)/32 + 
     (G[{yu}, yv^(-1)]*G[{1, 1/(yu*yv)}, yw]^2)/32 - 
     (G[{1/(yu*yv)}, yw]*G[{1, 1/(yu*yv)}, yw]^2)/16 + 
     (29*Pi^2*G[{0}, yu^(-1)]*G[{yu^(-1), 1/(yu*yv)}, yw])/768 + 
     (29*Pi^2*G[{0}, yv^(-1)]*G[{yu^(-1), 1/(yu*yv)}, yw])/768 - 
     (29*Pi^2*G[{0}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw])/768 - 
     (5*Pi^2*G[{1}, yu^(-1)]*G[{yu^(-1), 1/(yu*yv)}, yw])/768 + 
     (3*G[{0}, yu^(-1)]^2*G[{1}, yu^(-1)]*G[{yu^(-1), 1/(yu*yv)}, yw])/32 + 
     (3*G[{0}, yu^(-1)]*G[{0}, yv^(-1)]*G[{1}, yu^(-1)]*
       G[{yu^(-1), 1/(yu*yv)}, yw])/16 + (3*G[{0}, yv^(-1)]^2*G[{1}, yu^(-1)]*
       G[{yu^(-1), 1/(yu*yv)}, yw])/32 - (3*G[{0}, yu^(-1)]*G[{0}, yw]*
       G[{1}, yu^(-1)]*G[{yu^(-1), 1/(yu*yv)}, yw])/16 - 
     (3*G[{0}, yv^(-1)]*G[{0}, yw]*G[{1}, yu^(-1)]*G[{yu^(-1), 1/(yu*yv)}, 
        yw])/16 + (3*G[{0}, yw]^2*G[{1}, yu^(-1)]*G[{yu^(-1), 1/(yu*yv)}, 
        yw])/32 - (9*G[{0}, yu^(-1)]*G[{1}, yu^(-1)]^2*
       G[{yu^(-1), 1/(yu*yv)}, yw])/64 - (9*G[{0}, yv^(-1)]*G[{1}, yu^(-1)]^2*
       G[{yu^(-1), 1/(yu*yv)}, yw])/64 + (9*G[{0}, yw]*G[{1}, yu^(-1)]^2*
       G[{yu^(-1), 1/(yu*yv)}, yw])/64 + 
     (3*G[{1}, yu^(-1)]^3*G[{yu^(-1), 1/(yu*yv)}, yw])/64 - 
     (53*Pi^2*G[{1}, yv^(-1)]*G[{yu^(-1), 1/(yu*yv)}, yw])/768 - 
     (3*G[{0}, yu^(-1)]^2*G[{1}, yv^(-1)]*G[{yu^(-1), 1/(yu*yv)}, yw])/32 - 
     (3*G[{0}, yu^(-1)]*G[{0}, yv^(-1)]*G[{1}, yv^(-1)]*
       G[{yu^(-1), 1/(yu*yv)}, yw])/16 - (3*G[{0}, yv^(-1)]^2*G[{1}, yv^(-1)]*
       G[{yu^(-1), 1/(yu*yv)}, yw])/32 + (3*G[{0}, yu^(-1)]*G[{0}, yw]*
       G[{1}, yv^(-1)]*G[{yu^(-1), 1/(yu*yv)}, yw])/16 + 
     (3*G[{0}, yv^(-1)]*G[{0}, yw]*G[{1}, yv^(-1)]*G[{yu^(-1), 1/(yu*yv)}, 
        yw])/16 - (3*G[{0}, yw]^2*G[{1}, yv^(-1)]*G[{yu^(-1), 1/(yu*yv)}, 
        yw])/32 - (3*G[{0}, yu^(-1)]*G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*
       G[{yu^(-1), 1/(yu*yv)}, yw])/32 - (3*G[{0}, yv^(-1)]*G[{1}, yu^(-1)]*
       G[{1}, yv^(-1)]*G[{yu^(-1), 1/(yu*yv)}, yw])/32 + 
     (3*G[{0}, yw]*G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*G[{yu^(-1), 1/(yu*yv)}, 
        yw])/32 + (9*G[{1}, yu^(-1)]^2*G[{1}, yv^(-1)]*
       G[{yu^(-1), 1/(yu*yv)}, yw])/64 + (5*G[{0}, yu^(-1)]*G[{1}, yv^(-1)]^2*
       G[{yu^(-1), 1/(yu*yv)}, yw])/32 + (5*G[{0}, yv^(-1)]*G[{1}, yv^(-1)]^2*
       G[{yu^(-1), 1/(yu*yv)}, yw])/32 - (5*G[{0}, yw]*G[{1}, yv^(-1)]^2*
       G[{yu^(-1), 1/(yu*yv)}, yw])/32 - (G[{1}, yu^(-1)]*G[{1}, yv^(-1)]^2*
       G[{yu^(-1), 1/(yu*yv)}, yw])/32 - 
     (G[{1}, yv^(-1)]^3*G[{yu^(-1), 1/(yu*yv)}, yw])/16 - 
     (Pi^2*G[{1}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw])/192 - 
     (3*G[{0}, yu^(-1)]^2*G[{1}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw])/64 - 
     (3*G[{0}, yu^(-1)]*G[{0}, yv^(-1)]*G[{1}, yw]*G[{yu^(-1), 1/(yu*yv)}, 
        yw])/32 - (3*G[{0}, yv^(-1)]^2*G[{1}, yw]*G[{yu^(-1), 1/(yu*yv)}, 
        yw])/64 + (3*G[{0}, yu^(-1)]*G[{0}, yw]*G[{1}, yw]*
       G[{yu^(-1), 1/(yu*yv)}, yw])/32 + (3*G[{0}, yv^(-1)]*G[{0}, yw]*
       G[{1}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw])/32 - 
     (3*G[{0}, yw]^2*G[{1}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw])/64 + 
     (3*G[{1}, yu^(-1)]^2*G[{1}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw])/64 - 
     (G[{0}, yu^(-1)]*G[{1}, yv^(-1)]*G[{1}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw])/
      32 - (G[{0}, yv^(-1)]*G[{1}, yv^(-1)]*G[{1}, yw]*
       G[{yu^(-1), 1/(yu*yv)}, yw])/32 + 
     (G[{0}, yw]*G[{1}, yv^(-1)]*G[{1}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw])/32 + 
     (G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*G[{1}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw])/
      8 + (3*G[{1}, yv^(-1)]^2*G[{1}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw])/64 - 
     (G[{0}, yu^(-1)]*G[{1}, yw]^2*G[{yu^(-1), 1/(yu*yv)}, yw])/8 - 
     (G[{0}, yv^(-1)]*G[{1}, yw]^2*G[{yu^(-1), 1/(yu*yv)}, yw])/8 + 
     (G[{0}, yw]*G[{1}, yw]^2*G[{yu^(-1), 1/(yu*yv)}, yw])/8 + 
     (3*G[{1}, yu^(-1)]*G[{1}, yw]^2*G[{yu^(-1), 1/(yu*yv)}, yw])/32 + 
     (G[{1}, yv^(-1)]*G[{1}, yw]^2*G[{yu^(-1), 1/(yu*yv)}, yw])/16 - 
     (G[{1}, yw]^3*G[{yu^(-1), 1/(yu*yv)}, yw])/32 + 
     (19*Pi^2*G[{yu^(-1)}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw])/256 + 
     (9*G[{0}, yu^(-1)]^2*G[{yu^(-1)}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw])/64 + 
     (9*G[{0}, yu^(-1)]*G[{0}, yv^(-1)]*G[{yu^(-1)}, yw]*
       G[{yu^(-1), 1/(yu*yv)}, yw])/32 + 
     (9*G[{0}, yv^(-1)]^2*G[{yu^(-1)}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw])/64 - 
     (9*G[{0}, yu^(-1)]*G[{0}, yw]*G[{yu^(-1)}, yw]*G[{yu^(-1), 1/(yu*yv)}, 
        yw])/32 - (9*G[{0}, yv^(-1)]*G[{0}, yw]*G[{yu^(-1)}, yw]*
       G[{yu^(-1), 1/(yu*yv)}, yw])/32 + (9*G[{0}, yw]^2*G[{yu^(-1)}, yw]*
       G[{yu^(-1), 1/(yu*yv)}, yw])/64 + (3*G[{0}, yu^(-1)]*G[{1}, yu^(-1)]*
       G[{yu^(-1)}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw])/32 + 
     (3*G[{0}, yv^(-1)]*G[{1}, yu^(-1)]*G[{yu^(-1)}, yw]*
       G[{yu^(-1), 1/(yu*yv)}, yw])/32 - (3*G[{0}, yw]*G[{1}, yu^(-1)]*
       G[{yu^(-1)}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw])/32 - 
     (3*G[{1}, yu^(-1)]^2*G[{yu^(-1)}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw])/16 - 
     (21*G[{0}, yu^(-1)]*G[{1}, yv^(-1)]*G[{yu^(-1)}, yw]*
       G[{yu^(-1), 1/(yu*yv)}, yw])/32 - (21*G[{0}, yv^(-1)]*G[{1}, yv^(-1)]*
       G[{yu^(-1)}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw])/32 + 
     (21*G[{0}, yw]*G[{1}, yv^(-1)]*G[{yu^(-1)}, yw]*G[{yu^(-1), 1/(yu*yv)}, 
        yw])/32 + (3*G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*G[{yu^(-1)}, yw]*
       G[{yu^(-1), 1/(yu*yv)}, yw])/16 + 
     (29*G[{1}, yv^(-1)]^2*G[{yu^(-1)}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw])/64 - 
     (G[{0}, yu^(-1)]*G[{1}, yw]*G[{yu^(-1)}, yw]*G[{yu^(-1), 1/(yu*yv)}, 
        yw])/8 - (G[{0}, yv^(-1)]*G[{1}, yw]*G[{yu^(-1)}, yw]*
       G[{yu^(-1), 1/(yu*yv)}, yw])/8 + 
     (G[{0}, yw]*G[{1}, yw]*G[{yu^(-1)}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw])/8 + 
     (3*G[{1}, yu^(-1)]*G[{1}, yw]*G[{yu^(-1)}, yw]*G[{yu^(-1), 1/(yu*yv)}, 
        yw])/32 - (G[{1}, yv^(-1)]*G[{1}, yw]*G[{yu^(-1)}, yw]*
       G[{yu^(-1), 1/(yu*yv)}, yw])/8 - (9*G[{1}, yw]^2*G[{yu^(-1)}, yw]*
       G[{yu^(-1), 1/(yu*yv)}, yw])/64 + 
     (25*G[{0}, yu^(-1)]*G[{yu^(-1)}, yw]^2*G[{yu^(-1), 1/(yu*yv)}, yw])/64 + 
     (25*G[{0}, yv^(-1)]*G[{yu^(-1)}, yw]^2*G[{yu^(-1), 1/(yu*yv)}, yw])/64 - 
     (25*G[{0}, yw]*G[{yu^(-1)}, yw]^2*G[{yu^(-1), 1/(yu*yv)}, yw])/64 - 
     (9*G[{1}, yu^(-1)]*G[{yu^(-1)}, yw]^2*G[{yu^(-1), 1/(yu*yv)}, yw])/64 - 
     (41*G[{1}, yv^(-1)]*G[{yu^(-1)}, yw]^2*G[{yu^(-1), 1/(yu*yv)}, yw])/64 + 
     (41*G[{yu^(-1)}, yw]^3*G[{yu^(-1), 1/(yu*yv)}, yw])/192 + 
     (7*G[{0}, yu^(-1)]*G[{1}, yw]*G[{yu}, yv^(-1)]*G[{yu^(-1), 1/(yu*yv)}, 
        yw])/32 + (7*G[{0}, yv^(-1)]*G[{1}, yw]*G[{yu}, yv^(-1)]*
       G[{yu^(-1), 1/(yu*yv)}, yw])/32 - 
     (7*G[{0}, yw]*G[{1}, yw]*G[{yu}, yv^(-1)]*G[{yu^(-1), 1/(yu*yv)}, yw])/
      32 - (7*G[{1}, yu^(-1)]*G[{1}, yw]*G[{yu}, yv^(-1)]*
       G[{yu^(-1), 1/(yu*yv)}, yw])/32 - 
     (G[{1}, yv^(-1)]*G[{1}, yw]*G[{yu}, yv^(-1)]*G[{yu^(-1), 1/(yu*yv)}, 
        yw])/32 + (3*G[{1}, yw]^2*G[{yu}, yv^(-1)]*G[{yu^(-1), 1/(yu*yv)}, 
        yw])/32 + (9*G[{1}, yw]*G[{yu^(-1)}, yw]*G[{yu}, yv^(-1)]*
       G[{yu^(-1), 1/(yu*yv)}, yw])/32 - (3*G[{1}, yw]*G[{yu}, yv^(-1)]^2*
       G[{yu^(-1), 1/(yu*yv)}, yw])/32 - 
     (3*Pi^2*G[{1/(yu*yv)}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw])/256 - 
     (3*G[{0}, yu^(-1)]^2*G[{1/(yu*yv)}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw])/
      64 - (3*G[{0}, yu^(-1)]*G[{0}, yv^(-1)]*G[{1/(yu*yv)}, yw]*
       G[{yu^(-1), 1/(yu*yv)}, yw])/32 - 
     (3*G[{0}, yv^(-1)]^2*G[{1/(yu*yv)}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw])/
      64 + (3*G[{0}, yu^(-1)]*G[{0}, yw]*G[{1/(yu*yv)}, yw]*
       G[{yu^(-1), 1/(yu*yv)}, yw])/32 + (3*G[{0}, yv^(-1)]*G[{0}, yw]*
       G[{1/(yu*yv)}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw])/32 - 
     (3*G[{0}, yw]^2*G[{1/(yu*yv)}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw])/64 + 
     (G[{0}, yu^(-1)]*G[{1}, yu^(-1)]*G[{1/(yu*yv)}, yw]*
       G[{yu^(-1), 1/(yu*yv)}, yw])/8 + (G[{0}, yv^(-1)]*G[{1}, yu^(-1)]*
       G[{1/(yu*yv)}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw])/8 - 
     (G[{0}, yw]*G[{1}, yu^(-1)]*G[{1/(yu*yv)}, yw]*G[{yu^(-1), 1/(yu*yv)}, 
        yw])/8 - (7*G[{1}, yu^(-1)]^2*G[{1/(yu*yv)}, yw]*
       G[{yu^(-1), 1/(yu*yv)}, yw])/128 - 
     (3*G[{0}, yu^(-1)]*G[{1}, yv^(-1)]*G[{1/(yu*yv)}, yw]*
       G[{yu^(-1), 1/(yu*yv)}, yw])/32 - (3*G[{0}, yv^(-1)]*G[{1}, yv^(-1)]*
       G[{1/(yu*yv)}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw])/32 + 
     (3*G[{0}, yw]*G[{1}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{yu^(-1), 1/(yu*yv)}, 
        yw])/32 - (7*G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*G[{1/(yu*yv)}, yw]*
       G[{yu^(-1), 1/(yu*yv)}, yw])/64 + 
     (9*G[{1}, yv^(-1)]^2*G[{1/(yu*yv)}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw])/
      64 - (9*G[{0}, yu^(-1)]*G[{1}, yw]*G[{1/(yu*yv)}, yw]*
       G[{yu^(-1), 1/(yu*yv)}, yw])/64 - (9*G[{0}, yv^(-1)]*G[{1}, yw]*
       G[{1/(yu*yv)}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw])/64 + 
     (9*G[{0}, yw]*G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw])/
      64 + (G[{1}, yu^(-1)]*G[{1}, yw]*G[{1/(yu*yv)}, yw]*
       G[{yu^(-1), 1/(yu*yv)}, yw])/16 + 
     (G[{1}, yv^(-1)]*G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{yu^(-1), 1/(yu*yv)}, 
        yw])/64 - (13*G[{1}, yw]^2*G[{1/(yu*yv)}, yw]*G[{yu^(-1), 1/(yu*yv)}, 
        yw])/128 + (5*G[{0}, yu^(-1)]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*
       G[{yu^(-1), 1/(yu*yv)}, yw])/64 + (5*G[{0}, yv^(-1)]*G[{yu^(-1)}, yw]*
       G[{1/(yu*yv)}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw])/64 - 
     (5*G[{0}, yw]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*
       G[{yu^(-1), 1/(yu*yv)}, yw])/64 + (5*G[{1}, yu^(-1)]*G[{yu^(-1)}, yw]*
       G[{1/(yu*yv)}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw])/64 - 
     (13*G[{1}, yv^(-1)]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*
       G[{yu^(-1), 1/(yu*yv)}, yw])/64 + 
     (G[{1}, yw]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{yu^(-1), 1/(yu*yv)}, 
        yw])/32 + (13*G[{yu^(-1)}, yw]^2*G[{1/(yu*yv)}, yw]*
       G[{yu^(-1), 1/(yu*yv)}, yw])/128 + 
     (5*G[{0}, yu^(-1)]*G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw]*
       G[{yu^(-1), 1/(yu*yv)}, yw])/32 + (5*G[{0}, yv^(-1)]*G[{yu}, yv^(-1)]*
       G[{1/(yu*yv)}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw])/32 - 
     (5*G[{0}, yw]*G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw]*
       G[{yu^(-1), 1/(yu*yv)}, yw])/32 - (G[{1}, yu^(-1)]*G[{yu}, yv^(-1)]*
       G[{1/(yu*yv)}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw])/32 + 
     (G[{1}, yv^(-1)]*G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw]*
       G[{yu^(-1), 1/(yu*yv)}, yw])/32 + (13*G[{1}, yw]*G[{yu}, yv^(-1)]*
       G[{1/(yu*yv)}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw])/64 - 
     (G[{yu^(-1)}, yw]*G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw]*
       G[{yu^(-1), 1/(yu*yv)}, yw])/32 - 
     (5*G[{yu}, yv^(-1)]^2*G[{1/(yu*yv)}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw])/
      32 + (G[{0}, yu^(-1)]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*
       G[{yu^(-1), 1/(yu*yv)}, yw])/32 + (G[{0}, yv^(-1)]*G[{yv^(-1)}, yw]*
       G[{1/(yu*yv)}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw])/32 - 
     (G[{0}, yw]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{yu^(-1), 1/(yu*yv)}, 
        yw])/32 - (3*G[{1}, yu^(-1)]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*
       G[{yu^(-1), 1/(yu*yv)}, yw])/32 - (G[{1}, yv^(-1)]*G[{yv^(-1)}, yw]*
       G[{1/(yu*yv)}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw])/32 - 
     (G[{1}, yw]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{yu^(-1), 1/(yu*yv)}, 
        yw])/16 + (G[{yu^(-1)}, yw]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*
       G[{yu^(-1), 1/(yu*yv)}, yw])/32 + (G[{yu}, yv^(-1)]*G[{yv^(-1)}, yw]*
       G[{1/(yu*yv)}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw])/16 + 
     (3*G[{yv^(-1)}, yw]^2*G[{1/(yu*yv)}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw])/
      32 - (3*G[{0}, yu^(-1)]*G[{1/(yu*yv)}, yw]^2*G[{yu^(-1), 1/(yu*yv)}, 
        yw])/128 - (3*G[{0}, yv^(-1)]*G[{1/(yu*yv)}, yw]^2*
       G[{yu^(-1), 1/(yu*yv)}, yw])/128 + 
     (3*G[{0}, yw]*G[{1/(yu*yv)}, yw]^2*G[{yu^(-1), 1/(yu*yv)}, yw])/128 - 
     (3*G[{1}, yu^(-1)]*G[{1/(yu*yv)}, yw]^2*G[{yu^(-1), 1/(yu*yv)}, yw])/
      128 + (7*G[{1}, yv^(-1)]*G[{1/(yu*yv)}, yw]^2*G[{yu^(-1), 1/(yu*yv)}, 
        yw])/128 - (G[{1}, yw]*G[{1/(yu*yv)}, yw]^2*G[{yu^(-1), 1/(yu*yv)}, 
        yw])/64 - (7*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2*
       G[{yu^(-1), 1/(yu*yv)}, yw])/128 + 
     (G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw]^2*G[{yu^(-1), 1/(yu*yv)}, yw])/64 + 
     (9*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2*G[{yu^(-1), 1/(yu*yv)}, yw])/
      128 + (G[{0}, yu^(-1)]*G[{0, 1}, yu^(-1)]*G[{yu^(-1), 1/(yu*yv)}, yw])/
      32 + (G[{0}, yv^(-1)]*G[{0, 1}, yu^(-1)]*G[{yu^(-1), 1/(yu*yv)}, yw])/
      32 - (G[{0}, yw]*G[{0, 1}, yu^(-1)]*G[{yu^(-1), 1/(yu*yv)}, yw])/32 + 
     (G[{1}, yu^(-1)]*G[{0, 1}, yu^(-1)]*G[{yu^(-1), 1/(yu*yv)}, yw])/32 - 
     (3*G[{1}, yv^(-1)]*G[{0, 1}, yu^(-1)]*G[{yu^(-1), 1/(yu*yv)}, yw])/32 + 
     (G[{1}, yw]*G[{0, 1}, yu^(-1)]*G[{yu^(-1), 1/(yu*yv)}, yw])/16 + 
     (G[{yu^(-1)}, yw]*G[{0, 1}, yu^(-1)]*G[{yu^(-1), 1/(yu*yv)}, yw])/32 - 
     (3*G[{1/(yu*yv)}, yw]*G[{0, 1}, yu^(-1)]*G[{yu^(-1), 1/(yu*yv)}, yw])/
      64 + (3*G[{0}, yu^(-1)]*G[{0, 1}, yv^(-1)]*G[{yu^(-1), 1/(yu*yv)}, yw])/
      16 + (3*G[{0}, yv^(-1)]*G[{0, 1}, yv^(-1)]*G[{yu^(-1), 1/(yu*yv)}, yw])/
      16 - (3*G[{0}, yw]*G[{0, 1}, yv^(-1)]*G[{yu^(-1), 1/(yu*yv)}, yw])/16 - 
     (G[{1}, yu^(-1)]*G[{0, 1}, yv^(-1)]*G[{yu^(-1), 1/(yu*yv)}, yw])/8 - 
     (5*G[{1}, yv^(-1)]*G[{0, 1}, yv^(-1)]*G[{yu^(-1), 1/(yu*yv)}, yw])/16 - 
     (G[{1}, yw]*G[{0, 1}, yv^(-1)]*G[{yu^(-1), 1/(yu*yv)}, yw])/16 + 
     (G[{yu^(-1)}, yw]*G[{0, 1}, yv^(-1)]*G[{yu^(-1), 1/(yu*yv)}, yw])/4 - 
     (G[{1/(yu*yv)}, yw]*G[{0, 1}, yv^(-1)]*G[{yu^(-1), 1/(yu*yv)}, yw])/16 - 
     (G[{1}, yu^(-1)]*G[{0, 1}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw])/16 + 
     (G[{1}, yv^(-1)]*G[{0, 1}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw])/16 - 
     (G[{1}, yw]*G[{0, 1}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw])/32 - 
     (G[{yu^(-1)}, yw]*G[{0, 1}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw])/8 + 
     (G[{1/(yu*yv)}, yw]*G[{0, 1}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw])/64 + 
     (G[{1}, yu^(-1)]*G[{0, yu^(-1)}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw])/16 - 
     (G[{1}, yv^(-1)]*G[{0, yu^(-1)}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw])/16 + 
     (G[{1}, yw]*G[{0, yu^(-1)}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw])/32 + 
     (G[{yu^(-1)}, yw]*G[{0, yu^(-1)}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw])/8 - 
     (G[{1/(yu*yv)}, yw]*G[{0, yu^(-1)}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw])/
      64 - (3*G[{0}, yu^(-1)]*G[{0, yu}, yv^(-1)]*G[{yu^(-1), 1/(yu*yv)}, 
        yw])/16 - (3*G[{0}, yv^(-1)]*G[{0, yu}, yv^(-1)]*
       G[{yu^(-1), 1/(yu*yv)}, yw])/16 + (3*G[{0}, yw]*G[{0, yu}, yv^(-1)]*
       G[{yu^(-1), 1/(yu*yv)}, yw])/16 + (G[{1}, yu^(-1)]*G[{0, yu}, yv^(-1)]*
       G[{yu^(-1), 1/(yu*yv)}, yw])/8 + 
     (5*G[{1}, yv^(-1)]*G[{0, yu}, yv^(-1)]*G[{yu^(-1), 1/(yu*yv)}, yw])/16 + 
     (G[{1}, yw]*G[{0, yu}, yv^(-1)]*G[{yu^(-1), 1/(yu*yv)}, yw])/16 - 
     (G[{yu^(-1)}, yw]*G[{0, yu}, yv^(-1)]*G[{yu^(-1), 1/(yu*yv)}, yw])/4 + 
     (G[{1/(yu*yv)}, yw]*G[{0, yu}, yv^(-1)]*G[{yu^(-1), 1/(yu*yv)}, yw])/
      16 + (G[{1}, yu^(-1)]*G[{0, yv^(-1)}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw])/
      16 - (G[{1}, yv^(-1)]*G[{0, yv^(-1)}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw])/
      16 + (G[{1}, yw]*G[{0, yv^(-1)}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw])/32 + 
     (G[{yu^(-1)}, yw]*G[{0, yv^(-1)}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw])/8 - 
     (G[{1/(yu*yv)}, yw]*G[{0, yv^(-1)}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw])/
      64 - (G[{1}, yu^(-1)]*G[{0, 1/(yu*yv)}, yw]*G[{yu^(-1), 1/(yu*yv)}, 
        yw])/16 + (G[{1}, yv^(-1)]*G[{0, 1/(yu*yv)}, yw]*
       G[{yu^(-1), 1/(yu*yv)}, yw])/16 - (G[{1}, yw]*G[{0, 1/(yu*yv)}, yw]*
       G[{yu^(-1), 1/(yu*yv)}, yw])/32 - 
     (G[{yu^(-1)}, yw]*G[{0, 1/(yu*yv)}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw])/8 + 
     (G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv)}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw])/
      64 + (3*G[{0}, yu^(-1)]*G[{1, yu^(-1)}, yw]*G[{yu^(-1), 1/(yu*yv)}, 
        yw])/16 + (3*G[{0}, yv^(-1)]*G[{1, yu^(-1)}, yw]*
       G[{yu^(-1), 1/(yu*yv)}, yw])/16 - (3*G[{0}, yw]*G[{1, yu^(-1)}, yw]*
       G[{yu^(-1), 1/(yu*yv)}, yw])/16 - 
     (3*G[{1}, yu^(-1)]*G[{1, yu^(-1)}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw])/16 + 
     (G[{1}, yv^(-1)]*G[{1, yu^(-1)}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw])/16 + 
     (G[{1}, yw]*G[{1, yu^(-1)}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw])/4 + 
     (G[{yu^(-1)}, yw]*G[{1, yu^(-1)}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw])/8 - 
     (G[{yu}, yv^(-1)]*G[{1, yu^(-1)}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw])/4 - 
     (3*G[{1/(yu*yv)}, yw]*G[{1, yu^(-1)}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw])/
      64 + (5*G[{0}, yu^(-1)]*G[{1, yu}, yv^(-1)]*G[{yu^(-1), 1/(yu*yv)}, 
        yw])/32 + (5*G[{0}, yv^(-1)]*G[{1, yu}, yv^(-1)]*
       G[{yu^(-1), 1/(yu*yv)}, yw])/32 - (5*G[{0}, yw]*G[{1, yu}, yv^(-1)]*
       G[{yu^(-1), 1/(yu*yv)}, yw])/32 - (G[{1}, yu^(-1)]*G[{1, yu}, yv^(-1)]*
       G[{yu^(-1), 1/(yu*yv)}, yw])/32 + (G[{1}, yv^(-1)]*G[{1, yu}, yv^(-1)]*
       G[{yu^(-1), 1/(yu*yv)}, yw])/32 - (G[{1}, yw]*G[{1, yu}, yv^(-1)]*
       G[{yu^(-1), 1/(yu*yv)}, yw])/8 + 
     (7*G[{yu^(-1)}, yw]*G[{1, yu}, yv^(-1)]*G[{yu^(-1), 1/(yu*yv)}, yw])/
      32 - (G[{1/(yu*yv)}, yw]*G[{1, yu}, yv^(-1)]*G[{yu^(-1), 1/(yu*yv)}, 
        yw])/64 + (G[{0}, yu^(-1)]*G[{1, yv^(-1)}, yw]*
       G[{yu^(-1), 1/(yu*yv)}, yw])/32 + (G[{0}, yv^(-1)]*G[{1, yv^(-1)}, yw]*
       G[{yu^(-1), 1/(yu*yv)}, yw])/32 - (G[{0}, yw]*G[{1, yv^(-1)}, yw]*
       G[{yu^(-1), 1/(yu*yv)}, yw])/32 - 
     (5*G[{1}, yu^(-1)]*G[{1, yv^(-1)}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw])/32 + 
     (G[{1}, yv^(-1)]*G[{1, yv^(-1)}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw])/32 - 
     (G[{1}, yw]*G[{1, yv^(-1)}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw])/16 - 
     (3*G[{yu^(-1)}, yw]*G[{1, yv^(-1)}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw])/
      32 + (G[{yu}, yv^(-1)]*G[{1, yv^(-1)}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw])/
      16 - (G[{1/(yu*yv)}, yw]*G[{1, yv^(-1)}, yw]*G[{yu^(-1), 1/(yu*yv)}, 
        yw])/32 - (7*G[{0}, yu^(-1)]*G[{1, 1/(yu*yv)}, yw]*
       G[{yu^(-1), 1/(yu*yv)}, yw])/32 - 
     (7*G[{0}, yv^(-1)]*G[{1, 1/(yu*yv)}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw])/
      32 + (7*G[{0}, yw]*G[{1, 1/(yu*yv)}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw])/
      32 + (7*G[{1}, yu^(-1)]*G[{1, 1/(yu*yv)}, yw]*G[{yu^(-1), 1/(yu*yv)}, 
        yw])/32 + (G[{1}, yv^(-1)]*G[{1, 1/(yu*yv)}, yw]*
       G[{yu^(-1), 1/(yu*yv)}, yw])/32 - (3*G[{1}, yw]*G[{1, 1/(yu*yv)}, yw]*
       G[{yu^(-1), 1/(yu*yv)}, yw])/16 - 
     (9*G[{yu^(-1)}, yw]*G[{1, 1/(yu*yv)}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw])/
      32 + (3*G[{yu}, yv^(-1)]*G[{1, 1/(yu*yv)}, yw]*G[{yu^(-1), 1/(yu*yv)}, 
        yw])/16 + (7*G[{1/(yu*yv)}, yw]*G[{1, 1/(yu*yv)}, yw]*
       G[{yu^(-1), 1/(yu*yv)}, yw])/64 + 
     (3*G[{0}, yu^(-1)]*G[{yu^(-1), 1/(yu*yv)}, yw]^2)/32 + 
     (3*G[{0}, yv^(-1)]*G[{yu^(-1), 1/(yu*yv)}, yw]^2)/32 - 
     (3*G[{0}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw]^2)/32 - 
     (G[{1}, yu^(-1)]*G[{yu^(-1), 1/(yu*yv)}, yw]^2)/32 - 
     (G[{1}, yv^(-1)]*G[{yu^(-1), 1/(yu*yv)}, yw]^2)/32 + 
     (G[{1}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw]^2)/8 + 
     (G[{yu^(-1)}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw]^2)/32 - 
     (G[{yu}, yv^(-1)]*G[{yu^(-1), 1/(yu*yv)}, yw]^2)/8 - 
     (5*G[{1/(yu*yv)}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw]^2)/128 + 
     (Pi^2*G[{0}, yu^(-1)]*G[{yv^(-1), 1/(yu*yv)}, yw])/256 + 
     (3*G[{0}, yu^(-1)]^3*G[{yv^(-1), 1/(yu*yv)}, yw])/128 + 
     (Pi^2*G[{0}, yv^(-1)]*G[{yv^(-1), 1/(yu*yv)}, yw])/256 + 
     (9*G[{0}, yu^(-1)]^2*G[{0}, yv^(-1)]*G[{yv^(-1), 1/(yu*yv)}, yw])/128 + 
     (9*G[{0}, yu^(-1)]*G[{0}, yv^(-1)]^2*G[{yv^(-1), 1/(yu*yv)}, yw])/128 + 
     (3*G[{0}, yv^(-1)]^3*G[{yv^(-1), 1/(yu*yv)}, yw])/128 - 
     (Pi^2*G[{0}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw])/256 - 
     (9*G[{0}, yu^(-1)]^2*G[{0}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw])/128 - 
     (9*G[{0}, yu^(-1)]*G[{0}, yv^(-1)]*G[{0}, yw]*G[{yv^(-1), 1/(yu*yv)}, 
        yw])/64 - (9*G[{0}, yv^(-1)]^2*G[{0}, yw]*G[{yv^(-1), 1/(yu*yv)}, 
        yw])/128 + (9*G[{0}, yu^(-1)]*G[{0}, yw]^2*G[{yv^(-1), 1/(yu*yv)}, 
        yw])/128 + (9*G[{0}, yv^(-1)]*G[{0}, yw]^2*G[{yv^(-1), 1/(yu*yv)}, 
        yw])/128 - (3*G[{0}, yw]^3*G[{yv^(-1), 1/(yu*yv)}, yw])/128 - 
     (Pi^2*G[{1}, yu^(-1)]*G[{yv^(-1), 1/(yu*yv)}, yw])/256 - 
     (13*G[{0}, yu^(-1)]^2*G[{1}, yu^(-1)]*G[{yv^(-1), 1/(yu*yv)}, yw])/128 - 
     (13*G[{0}, yu^(-1)]*G[{0}, yv^(-1)]*G[{1}, yu^(-1)]*
       G[{yv^(-1), 1/(yu*yv)}, yw])/64 - 
     (13*G[{0}, yv^(-1)]^2*G[{1}, yu^(-1)]*G[{yv^(-1), 1/(yu*yv)}, yw])/128 + 
     (13*G[{0}, yu^(-1)]*G[{0}, yw]*G[{1}, yu^(-1)]*G[{yv^(-1), 1/(yu*yv)}, 
        yw])/64 + (13*G[{0}, yv^(-1)]*G[{0}, yw]*G[{1}, yu^(-1)]*
       G[{yv^(-1), 1/(yu*yv)}, yw])/64 - (13*G[{0}, yw]^2*G[{1}, yu^(-1)]*
       G[{yv^(-1), 1/(yu*yv)}, yw])/128 + 
     (23*G[{0}, yu^(-1)]*G[{1}, yu^(-1)]^2*G[{yv^(-1), 1/(yu*yv)}, yw])/128 + 
     (23*G[{0}, yv^(-1)]*G[{1}, yu^(-1)]^2*G[{yv^(-1), 1/(yu*yv)}, yw])/128 - 
     (23*G[{0}, yw]*G[{1}, yu^(-1)]^2*G[{yv^(-1), 1/(yu*yv)}, yw])/128 - 
     (13*G[{1}, yu^(-1)]^3*G[{yv^(-1), 1/(yu*yv)}, yw])/128 - 
     (19*Pi^2*G[{1}, yv^(-1)]*G[{yv^(-1), 1/(yu*yv)}, yw])/768 - 
     (9*G[{0}, yu^(-1)]^2*G[{1}, yv^(-1)]*G[{yv^(-1), 1/(yu*yv)}, yw])/128 - 
     (9*G[{0}, yu^(-1)]*G[{0}, yv^(-1)]*G[{1}, yv^(-1)]*
       G[{yv^(-1), 1/(yu*yv)}, yw])/64 - (9*G[{0}, yv^(-1)]^2*G[{1}, yv^(-1)]*
       G[{yv^(-1), 1/(yu*yv)}, yw])/128 + 
     (9*G[{0}, yu^(-1)]*G[{0}, yw]*G[{1}, yv^(-1)]*G[{yv^(-1), 1/(yu*yv)}, 
        yw])/64 + (9*G[{0}, yv^(-1)]*G[{0}, yw]*G[{1}, yv^(-1)]*
       G[{yv^(-1), 1/(yu*yv)}, yw])/64 - (9*G[{0}, yw]^2*G[{1}, yv^(-1)]*
       G[{yv^(-1), 1/(yu*yv)}, yw])/128 - 
     (G[{0}, yu^(-1)]*G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*G[{yv^(-1), 1/(yu*yv)}, 
        yw])/64 - (G[{0}, yv^(-1)]*G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*
       G[{yv^(-1), 1/(yu*yv)}, yw])/64 + 
     (G[{0}, yw]*G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*G[{yv^(-1), 1/(yu*yv)}, yw])/
      64 + (5*G[{1}, yu^(-1)]^2*G[{1}, yv^(-1)]*G[{yv^(-1), 1/(yu*yv)}, yw])/
      128 + (9*G[{0}, yu^(-1)]*G[{1}, yv^(-1)]^2*G[{yv^(-1), 1/(yu*yv)}, yw])/
      128 + (9*G[{0}, yv^(-1)]*G[{1}, yv^(-1)]^2*G[{yv^(-1), 1/(yu*yv)}, yw])/
      128 - (9*G[{0}, yw]*G[{1}, yv^(-1)]^2*G[{yv^(-1), 1/(yu*yv)}, yw])/
      128 + (7*G[{1}, yu^(-1)]*G[{1}, yv^(-1)]^2*G[{yv^(-1), 1/(yu*yv)}, yw])/
      128 - (3*G[{1}, yv^(-1)]^3*G[{yv^(-1), 1/(yu*yv)}, yw])/128 - 
     (Pi^2*G[{1}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw])/128 + 
     (11*G[{0}, yu^(-1)]^2*G[{1}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw])/128 + 
     (11*G[{0}, yu^(-1)]*G[{0}, yv^(-1)]*G[{1}, yw]*G[{yv^(-1), 1/(yu*yv)}, 
        yw])/64 + (11*G[{0}, yv^(-1)]^2*G[{1}, yw]*G[{yv^(-1), 1/(yu*yv)}, 
        yw])/128 - (11*G[{0}, yu^(-1)]*G[{0}, yw]*G[{1}, yw]*
       G[{yv^(-1), 1/(yu*yv)}, yw])/64 - (11*G[{0}, yv^(-1)]*G[{0}, yw]*
       G[{1}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw])/64 + 
     (11*G[{0}, yw]^2*G[{1}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw])/128 - 
     (17*G[{0}, yu^(-1)]*G[{1}, yu^(-1)]*G[{1}, yw]*G[{yv^(-1), 1/(yu*yv)}, 
        yw])/64 - (17*G[{0}, yv^(-1)]*G[{1}, yu^(-1)]*G[{1}, yw]*
       G[{yv^(-1), 1/(yu*yv)}, yw])/64 + (17*G[{0}, yw]*G[{1}, yu^(-1)]*
       G[{1}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw])/64 + 
     (23*G[{1}, yu^(-1)]^2*G[{1}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw])/128 - 
     (11*G[{0}, yu^(-1)]*G[{1}, yv^(-1)]*G[{1}, yw]*G[{yv^(-1), 1/(yu*yv)}, 
        yw])/64 - (11*G[{0}, yv^(-1)]*G[{1}, yv^(-1)]*G[{1}, yw]*
       G[{yv^(-1), 1/(yu*yv)}, yw])/64 + (11*G[{0}, yw]*G[{1}, yv^(-1)]*
       G[{1}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw])/64 + 
     (9*G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*G[{1}, yw]*G[{yv^(-1), 1/(yu*yv)}, 
        yw])/64 + (11*G[{1}, yv^(-1)]^2*G[{1}, yw]*G[{yv^(-1), 1/(yu*yv)}, 
        yw])/128 + (3*G[{0}, yu^(-1)]*G[{1}, yw]^2*G[{yv^(-1), 1/(yu*yv)}, 
        yw])/128 + (3*G[{0}, yv^(-1)]*G[{1}, yw]^2*G[{yv^(-1), 1/(yu*yv)}, 
        yw])/128 - (3*G[{0}, yw]*G[{1}, yw]^2*G[{yv^(-1), 1/(yu*yv)}, yw])/
      128 - (3*G[{1}, yu^(-1)]*G[{1}, yw]^2*G[{yv^(-1), 1/(yu*yv)}, yw])/
      128 - (3*G[{1}, yv^(-1)]*G[{1}, yw]^2*G[{yv^(-1), 1/(yu*yv)}, yw])/
      128 + (3*Pi^2*G[{yu^(-1)}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw])/256 - 
     (3*G[{0}, yu^(-1)]^2*G[{yu^(-1)}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw])/64 - 
     (3*G[{0}, yu^(-1)]*G[{0}, yv^(-1)]*G[{yu^(-1)}, yw]*
       G[{yv^(-1), 1/(yu*yv)}, yw])/32 - 
     (3*G[{0}, yv^(-1)]^2*G[{yu^(-1)}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw])/64 + 
     (3*G[{0}, yu^(-1)]*G[{0}, yw]*G[{yu^(-1)}, yw]*G[{yv^(-1), 1/(yu*yv)}, 
        yw])/32 + (3*G[{0}, yv^(-1)]*G[{0}, yw]*G[{yu^(-1)}, yw]*
       G[{yv^(-1), 1/(yu*yv)}, yw])/32 - (3*G[{0}, yw]^2*G[{yu^(-1)}, yw]*
       G[{yv^(-1), 1/(yu*yv)}, yw])/64 + (7*G[{0}, yu^(-1)]*G[{1}, yu^(-1)]*
       G[{yu^(-1)}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw])/32 + 
     (7*G[{0}, yv^(-1)]*G[{1}, yu^(-1)]*G[{yu^(-1)}, yw]*
       G[{yv^(-1), 1/(yu*yv)}, yw])/32 - (7*G[{0}, yw]*G[{1}, yu^(-1)]*
       G[{yu^(-1)}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw])/32 - 
     (G[{1}, yu^(-1)]^2*G[{yu^(-1)}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw])/8 - 
     (G[{0}, yu^(-1)]*G[{1}, yv^(-1)]*G[{yu^(-1)}, yw]*
       G[{yv^(-1), 1/(yu*yv)}, yw])/32 - (G[{0}, yv^(-1)]*G[{1}, yv^(-1)]*
       G[{yu^(-1)}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw])/32 + 
     (G[{0}, yw]*G[{1}, yv^(-1)]*G[{yu^(-1)}, yw]*G[{yv^(-1), 1/(yu*yv)}, 
        yw])/32 - (3*G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*G[{yu^(-1)}, yw]*
       G[{yv^(-1), 1/(yu*yv)}, yw])/16 + 
     (5*G[{1}, yv^(-1)]^2*G[{yu^(-1)}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw])/64 - 
     (G[{1}, yu^(-1)]*G[{1}, yw]*G[{yu^(-1)}, yw]*G[{yv^(-1), 1/(yu*yv)}, 
        yw])/32 - (G[{1}, yv^(-1)]*G[{1}, yw]*G[{yu^(-1)}, yw]*
       G[{yv^(-1), 1/(yu*yv)}, yw])/8 - (5*G[{1}, yw]^2*G[{yu^(-1)}, yw]*
       G[{yv^(-1), 1/(yu*yv)}, yw])/64 + (G[{0}, yu^(-1)]*G[{yu^(-1)}, yw]^2*
       G[{yv^(-1), 1/(yu*yv)}, yw])/64 + (G[{0}, yv^(-1)]*G[{yu^(-1)}, yw]^2*
       G[{yv^(-1), 1/(yu*yv)}, yw])/64 - (G[{0}, yw]*G[{yu^(-1)}, yw]^2*
       G[{yv^(-1), 1/(yu*yv)}, yw])/64 + 
     (7*G[{1}, yu^(-1)]*G[{yu^(-1)}, yw]^2*G[{yv^(-1), 1/(yu*yv)}, yw])/64 - 
     (9*G[{1}, yv^(-1)]*G[{yu^(-1)}, yw]^2*G[{yv^(-1), 1/(yu*yv)}, yw])/64 + 
     (3*G[{yu^(-1)}, yw]^3*G[{yv^(-1), 1/(yu*yv)}, yw])/64 + 
     (Pi^2*G[{yu}, yv^(-1)]*G[{yv^(-1), 1/(yu*yv)}, yw])/48 + 
     (G[{0}, yu^(-1)]^2*G[{yu}, yv^(-1)]*G[{yv^(-1), 1/(yu*yv)}, yw])/32 + 
     (G[{0}, yu^(-1)]*G[{0}, yv^(-1)]*G[{yu}, yv^(-1)]*
       G[{yv^(-1), 1/(yu*yv)}, yw])/16 + (G[{0}, yv^(-1)]^2*G[{yu}, yv^(-1)]*
       G[{yv^(-1), 1/(yu*yv)}, yw])/32 - 
     (G[{0}, yu^(-1)]*G[{0}, yw]*G[{yu}, yv^(-1)]*G[{yv^(-1), 1/(yu*yv)}, 
        yw])/16 - (G[{0}, yv^(-1)]*G[{0}, yw]*G[{yu}, yv^(-1)]*
       G[{yv^(-1), 1/(yu*yv)}, yw])/16 + (G[{0}, yw]^2*G[{yu}, yv^(-1)]*
       G[{yv^(-1), 1/(yu*yv)}, yw])/32 + (G[{0}, yu^(-1)]*G[{1}, yu^(-1)]*
       G[{yu}, yv^(-1)]*G[{yv^(-1), 1/(yu*yv)}, yw])/16 + 
     (G[{0}, yv^(-1)]*G[{1}, yu^(-1)]*G[{yu}, yv^(-1)]*
       G[{yv^(-1), 1/(yu*yv)}, yw])/16 - 
     (G[{0}, yw]*G[{1}, yu^(-1)]*G[{yu}, yv^(-1)]*G[{yv^(-1), 1/(yu*yv)}, 
        yw])/16 - (3*G[{1}, yu^(-1)]^2*G[{yu}, yv^(-1)]*
       G[{yv^(-1), 1/(yu*yv)}, yw])/32 + (G[{0}, yu^(-1)]*G[{1}, yv^(-1)]*
       G[{yu}, yv^(-1)]*G[{yv^(-1), 1/(yu*yv)}, yw])/16 + 
     (G[{0}, yv^(-1)]*G[{1}, yv^(-1)]*G[{yu}, yv^(-1)]*
       G[{yv^(-1), 1/(yu*yv)}, yw])/16 - 
     (G[{0}, yw]*G[{1}, yv^(-1)]*G[{yu}, yv^(-1)]*G[{yv^(-1), 1/(yu*yv)}, 
        yw])/16 - (G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*G[{yu}, yv^(-1)]*
       G[{yv^(-1), 1/(yu*yv)}, yw])/16 - 
     (3*G[{1}, yv^(-1)]^2*G[{yu}, yv^(-1)]*G[{yv^(-1), 1/(yu*yv)}, yw])/32 + 
     (3*G[{0}, yu^(-1)]*G[{1}, yw]*G[{yu}, yv^(-1)]*G[{yv^(-1), 1/(yu*yv)}, 
        yw])/32 + (3*G[{0}, yv^(-1)]*G[{1}, yw]*G[{yu}, yv^(-1)]*
       G[{yv^(-1), 1/(yu*yv)}, yw])/32 - 
     (3*G[{0}, yw]*G[{1}, yw]*G[{yu}, yv^(-1)]*G[{yv^(-1), 1/(yu*yv)}, yw])/
      32 + (G[{1}, yu^(-1)]*G[{1}, yw]*G[{yu}, yv^(-1)]*
       G[{yv^(-1), 1/(yu*yv)}, yw])/32 + 
     (G[{1}, yv^(-1)]*G[{1}, yw]*G[{yu}, yv^(-1)]*G[{yv^(-1), 1/(yu*yv)}, 
        yw])/32 + (5*G[{1}, yw]*G[{yu^(-1)}, yw]*G[{yu}, yv^(-1)]*
       G[{yv^(-1), 1/(yu*yv)}, yw])/32 - (G[{0}, yu^(-1)]*G[{yu}, yv^(-1)]^2*
       G[{yv^(-1), 1/(yu*yv)}, yw])/8 - (G[{0}, yv^(-1)]*G[{yu}, yv^(-1)]^2*
       G[{yv^(-1), 1/(yu*yv)}, yw])/8 + (G[{0}, yw]*G[{yu}, yv^(-1)]^2*
       G[{yv^(-1), 1/(yu*yv)}, yw])/8 + (G[{1}, yu^(-1)]*G[{yu}, yv^(-1)]^2*
       G[{yv^(-1), 1/(yu*yv)}, yw])/16 - (G[{1}, yw]*G[{yu}, yv^(-1)]^2*
       G[{yv^(-1), 1/(yu*yv)}, yw])/8 + 
     (G[{yu}, yv^(-1)]^3*G[{yv^(-1), 1/(yu*yv)}, yw])/16 - 
     (7*Pi^2*G[{yv^(-1)}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw])/768 - 
     (G[{0}, yu^(-1)]^2*G[{yv^(-1)}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw])/64 - 
     (G[{0}, yu^(-1)]*G[{0}, yv^(-1)]*G[{yv^(-1)}, yw]*
       G[{yv^(-1), 1/(yu*yv)}, yw])/32 - (G[{0}, yv^(-1)]^2*G[{yv^(-1)}, yw]*
       G[{yv^(-1), 1/(yu*yv)}, yw])/64 + 
     (G[{0}, yu^(-1)]*G[{0}, yw]*G[{yv^(-1)}, yw]*G[{yv^(-1), 1/(yu*yv)}, 
        yw])/32 + (G[{0}, yv^(-1)]*G[{0}, yw]*G[{yv^(-1)}, yw]*
       G[{yv^(-1), 1/(yu*yv)}, yw])/32 - (G[{0}, yw]^2*G[{yv^(-1)}, yw]*
       G[{yv^(-1), 1/(yu*yv)}, yw])/64 + (G[{0}, yu^(-1)]*G[{1}, yu^(-1)]*
       G[{yv^(-1)}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw])/32 + 
     (G[{0}, yv^(-1)]*G[{1}, yu^(-1)]*G[{yv^(-1)}, yw]*
       G[{yv^(-1), 1/(yu*yv)}, yw])/32 - 
     (G[{0}, yw]*G[{1}, yu^(-1)]*G[{yv^(-1)}, yw]*G[{yv^(-1), 1/(yu*yv)}, 
        yw])/32 + (G[{1}, yu^(-1)]^2*G[{yv^(-1)}, yw]*G[{yv^(-1), 1/(yu*yv)}, 
        yw])/32 + (G[{0}, yu^(-1)]*G[{1}, yv^(-1)]*G[{yv^(-1)}, yw]*
       G[{yv^(-1), 1/(yu*yv)}, yw])/32 + (G[{0}, yv^(-1)]*G[{1}, yv^(-1)]*
       G[{yv^(-1)}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw])/32 - 
     (G[{0}, yw]*G[{1}, yv^(-1)]*G[{yv^(-1)}, yw]*G[{yv^(-1), 1/(yu*yv)}, 
        yw])/32 - (G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*G[{yv^(-1)}, yw]*
       G[{yv^(-1), 1/(yu*yv)}, yw])/4 - (G[{1}, yv^(-1)]^2*G[{yv^(-1)}, yw]*
       G[{yv^(-1), 1/(yu*yv)}, yw])/64 + (3*G[{0}, yu^(-1)]*G[{1}, yw]*
       G[{yv^(-1)}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw])/16 + 
     (3*G[{0}, yv^(-1)]*G[{1}, yw]*G[{yv^(-1)}, yw]*G[{yv^(-1), 1/(yu*yv)}, 
        yw])/16 - (3*G[{0}, yw]*G[{1}, yw]*G[{yv^(-1)}, yw]*
       G[{yv^(-1), 1/(yu*yv)}, yw])/16 - (3*G[{1}, yu^(-1)]*G[{1}, yw]*
       G[{yv^(-1)}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw])/32 - 
     (3*G[{1}, yv^(-1)]*G[{1}, yw]*G[{yv^(-1)}, yw]*G[{yv^(-1), 1/(yu*yv)}, 
        yw])/16 + (3*G[{1}, yw]^2*G[{yv^(-1)}, yw]*G[{yv^(-1), 1/(yu*yv)}, 
        yw])/64 - (7*G[{0}, yu^(-1)]*G[{yu^(-1)}, yw]*G[{yv^(-1)}, yw]*
       G[{yv^(-1), 1/(yu*yv)}, yw])/32 - (7*G[{0}, yv^(-1)]*G[{yu^(-1)}, yw]*
       G[{yv^(-1)}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw])/32 + 
     (7*G[{0}, yw]*G[{yu^(-1)}, yw]*G[{yv^(-1)}, yw]*G[{yv^(-1), 1/(yu*yv)}, 
        yw])/32 + (7*G[{1}, yu^(-1)]*G[{yu^(-1)}, yw]*G[{yv^(-1)}, yw]*
       G[{yv^(-1), 1/(yu*yv)}, yw])/32 + (7*G[{1}, yv^(-1)]*G[{yu^(-1)}, yw]*
       G[{yv^(-1)}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw])/32 - 
     (7*G[{yu^(-1)}, yw]^2*G[{yv^(-1)}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw])/64 + 
     (G[{1}, yu^(-1)]*G[{yu}, yv^(-1)]*G[{yv^(-1)}, yw]*
       G[{yv^(-1), 1/(yu*yv)}, yw])/8 - (3*G[{1}, yw]*G[{yu}, yv^(-1)]*
       G[{yv^(-1)}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw])/32 - 
     (G[{yu}, yv^(-1)]^2*G[{yv^(-1)}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw])/16 - 
     (7*G[{0}, yu^(-1)]*G[{yv^(-1)}, yw]^2*G[{yv^(-1), 1/(yu*yv)}, yw])/64 - 
     (7*G[{0}, yv^(-1)]*G[{yv^(-1)}, yw]^2*G[{yv^(-1), 1/(yu*yv)}, yw])/64 + 
     (7*G[{0}, yw]*G[{yv^(-1)}, yw]^2*G[{yv^(-1), 1/(yu*yv)}, yw])/64 + 
     (11*G[{1}, yu^(-1)]*G[{yv^(-1)}, yw]^2*G[{yv^(-1), 1/(yu*yv)}, yw])/64 + 
     (7*G[{1}, yv^(-1)]*G[{yv^(-1)}, yw]^2*G[{yv^(-1), 1/(yu*yv)}, yw])/64 + 
     (G[{1}, yw]*G[{yv^(-1)}, yw]^2*G[{yv^(-1), 1/(yu*yv)}, yw])/16 - 
     (7*G[{yu^(-1)}, yw]*G[{yv^(-1)}, yw]^2*G[{yv^(-1), 1/(yu*yv)}, yw])/64 - 
     (G[{yu}, yv^(-1)]*G[{yv^(-1)}, yw]^2*G[{yv^(-1), 1/(yu*yv)}, yw])/16 - 
     (11*G[{yv^(-1)}, yw]^3*G[{yv^(-1), 1/(yu*yv)}, yw])/192 - 
     (11*Pi^2*G[{1/(yu*yv)}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw])/768 - 
     (G[{0}, yu^(-1)]^2*G[{1/(yu*yv)}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw])/128 - 
     (G[{0}, yu^(-1)]*G[{0}, yv^(-1)]*G[{1/(yu*yv)}, yw]*
       G[{yv^(-1), 1/(yu*yv)}, yw])/64 - 
     (G[{0}, yv^(-1)]^2*G[{1/(yu*yv)}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw])/128 + 
     (G[{0}, yu^(-1)]*G[{0}, yw]*G[{1/(yu*yv)}, yw]*G[{yv^(-1), 1/(yu*yv)}, 
        yw])/64 + (G[{0}, yv^(-1)]*G[{0}, yw]*G[{1/(yu*yv)}, yw]*
       G[{yv^(-1), 1/(yu*yv)}, yw])/64 - (G[{0}, yw]^2*G[{1/(yu*yv)}, yw]*
       G[{yv^(-1), 1/(yu*yv)}, yw])/128 - 
     (G[{0}, yu^(-1)]*G[{1}, yu^(-1)]*G[{1/(yu*yv)}, yw]*
       G[{yv^(-1), 1/(yu*yv)}, yw])/64 - (G[{0}, yv^(-1)]*G[{1}, yu^(-1)]*
       G[{1/(yu*yv)}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw])/64 + 
     (G[{0}, yw]*G[{1}, yu^(-1)]*G[{1/(yu*yv)}, yw]*G[{yv^(-1), 1/(yu*yv)}, 
        yw])/64 + (3*G[{1}, yu^(-1)]^2*G[{1/(yu*yv)}, yw]*
       G[{yv^(-1), 1/(yu*yv)}, yw])/64 + (9*G[{0}, yu^(-1)]*G[{1}, yv^(-1)]*
       G[{1/(yu*yv)}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw])/64 + 
     (9*G[{0}, yv^(-1)]*G[{1}, yv^(-1)]*G[{1/(yu*yv)}, yw]*
       G[{yv^(-1), 1/(yu*yv)}, yw])/64 - (9*G[{0}, yw]*G[{1}, yv^(-1)]*
       G[{1/(yu*yv)}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw])/64 - 
     (11*G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*G[{1/(yu*yv)}, yw]*
       G[{yv^(-1), 1/(yu*yv)}, yw])/32 - 
     (9*G[{1}, yv^(-1)]^2*G[{1/(yu*yv)}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw])/
      128 + (5*G[{0}, yu^(-1)]*G[{1}, yw]*G[{1/(yu*yv)}, yw]*
       G[{yv^(-1), 1/(yu*yv)}, yw])/32 + (5*G[{0}, yv^(-1)]*G[{1}, yw]*
       G[{1/(yu*yv)}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw])/32 - 
     (5*G[{0}, yw]*G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw])/
      32 - (15*G[{1}, yu^(-1)]*G[{1}, yw]*G[{1/(yu*yv)}, yw]*
       G[{yv^(-1), 1/(yu*yv)}, yw])/64 - (5*G[{1}, yv^(-1)]*G[{1}, yw]*
       G[{1/(yu*yv)}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw])/32 - 
     (5*G[{1}, yw]^2*G[{1/(yu*yv)}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw])/128 - 
     (13*G[{0}, yu^(-1)]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*
       G[{yv^(-1), 1/(yu*yv)}, yw])/64 - (13*G[{0}, yv^(-1)]*G[{yu^(-1)}, yw]*
       G[{1/(yu*yv)}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw])/64 + 
     (13*G[{0}, yw]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*
       G[{yv^(-1), 1/(yu*yv)}, yw])/64 + (19*G[{1}, yu^(-1)]*G[{yu^(-1)}, yw]*
       G[{1/(yu*yv)}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw])/64 + 
     (13*G[{1}, yv^(-1)]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*
       G[{yv^(-1), 1/(yu*yv)}, yw])/64 + (3*G[{1}, yw]*G[{yu^(-1)}, yw]*
       G[{1/(yu*yv)}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw])/32 - 
     (13*G[{yu^(-1)}, yw]^2*G[{1/(yu*yv)}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw])/
      128 - (3*G[{0}, yu^(-1)]*G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw]*
       G[{yv^(-1), 1/(yu*yv)}, yw])/32 - (3*G[{0}, yv^(-1)]*G[{yu}, yv^(-1)]*
       G[{1/(yu*yv)}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw])/32 + 
     (3*G[{0}, yw]*G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw]*
       G[{yv^(-1), 1/(yu*yv)}, yw])/32 + (9*G[{1}, yu^(-1)]*G[{yu}, yv^(-1)]*
       G[{1/(yu*yv)}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw])/32 + 
     (3*G[{1}, yv^(-1)]*G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw]*
       G[{yv^(-1), 1/(yu*yv)}, yw])/32 + (5*G[{1}, yw]*G[{yu}, yv^(-1)]*
       G[{1/(yu*yv)}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw])/64 - 
     (3*G[{yu^(-1)}, yw]*G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw]*
       G[{yv^(-1), 1/(yu*yv)}, yw])/32 - 
     (3*G[{yu}, yv^(-1)]^2*G[{1/(yu*yv)}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw])/
      32 - (3*G[{0}, yu^(-1)]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*
       G[{yv^(-1), 1/(yu*yv)}, yw])/64 - (3*G[{0}, yv^(-1)]*G[{yv^(-1)}, yw]*
       G[{1/(yu*yv)}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw])/64 + 
     (3*G[{0}, yw]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*
       G[{yv^(-1), 1/(yu*yv)}, yw])/64 + (5*G[{1}, yu^(-1)]*G[{yv^(-1)}, yw]*
       G[{1/(yu*yv)}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw])/64 + 
     (19*G[{1}, yv^(-1)]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*
       G[{yv^(-1), 1/(yu*yv)}, yw])/64 + (9*G[{1}, yw]*G[{yv^(-1)}, yw]*
       G[{1/(yu*yv)}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw])/32 - 
     (19*G[{yu^(-1)}, yw]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*
       G[{yv^(-1), 1/(yu*yv)}, yw])/64 - (9*G[{yu}, yv^(-1)]*G[{yv^(-1)}, yw]*
       G[{1/(yu*yv)}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw])/32 - 
     (5*G[{yv^(-1)}, yw]^2*G[{1/(yu*yv)}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw])/
      128 - (G[{0}, yu^(-1)]*G[{1/(yu*yv)}, yw]^2*G[{yv^(-1), 1/(yu*yv)}, 
        yw])/32 - (G[{0}, yv^(-1)]*G[{1/(yu*yv)}, yw]^2*
       G[{yv^(-1), 1/(yu*yv)}, yw])/32 + (G[{0}, yw]*G[{1/(yu*yv)}, yw]^2*
       G[{yv^(-1), 1/(yu*yv)}, yw])/32 - 
     (G[{1}, yu^(-1)]*G[{1/(yu*yv)}, yw]^2*G[{yv^(-1), 1/(yu*yv)}, yw])/64 - 
     (5*G[{1}, yw]*G[{1/(yu*yv)}, yw]^2*G[{yv^(-1), 1/(yu*yv)}, yw])/64 + 
     (5*G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw]^2*G[{yv^(-1), 1/(yu*yv)}, yw])/
      64 + (G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2*G[{yv^(-1), 1/(yu*yv)}, 
        yw])/64 - (3*G[{0}, yu^(-1)]*G[{0, 1}, yu^(-1)]*
       G[{yv^(-1), 1/(yu*yv)}, yw])/32 - 
     (3*G[{0}, yv^(-1)]*G[{0, 1}, yu^(-1)]*G[{yv^(-1), 1/(yu*yv)}, yw])/32 + 
     (3*G[{0}, yw]*G[{0, 1}, yu^(-1)]*G[{yv^(-1), 1/(yu*yv)}, yw])/32 + 
     (3*G[{1}, yu^(-1)]*G[{0, 1}, yu^(-1)]*G[{yv^(-1), 1/(yu*yv)}, yw])/32 + 
     (3*G[{1}, yv^(-1)]*G[{0, 1}, yu^(-1)]*G[{yv^(-1), 1/(yu*yv)}, yw])/32 - 
     (G[{1}, yw]*G[{0, 1}, yu^(-1)]*G[{yv^(-1), 1/(yu*yv)}, yw])/8 + 
     (G[{yu^(-1)}, yw]*G[{0, 1}, yu^(-1)]*G[{yv^(-1), 1/(yu*yv)}, yw])/32 - 
     (7*G[{yv^(-1)}, yw]*G[{0, 1}, yu^(-1)]*G[{yv^(-1), 1/(yu*yv)}, yw])/32 - 
     (7*G[{1/(yu*yv)}, yw]*G[{0, 1}, yu^(-1)]*G[{yv^(-1), 1/(yu*yv)}, yw])/
      64 - (G[{1}, yv^(-1)]*G[{0, 1}, yv^(-1)]*G[{yv^(-1), 1/(yu*yv)}, yw])/
      8 - (G[{1}, yw]*G[{0, 1}, yv^(-1)]*G[{yv^(-1), 1/(yu*yv)}, yw])/8 + 
     (G[{yu^(-1)}, yw]*G[{0, 1}, yv^(-1)]*G[{yv^(-1), 1/(yu*yv)}, yw])/8 + 
     (G[{yu}, yv^(-1)]*G[{0, 1}, yv^(-1)]*G[{yv^(-1), 1/(yu*yv)}, yw])/8 + 
     (G[{0}, yu^(-1)]*G[{0, 1}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw])/32 + 
     (G[{0}, yv^(-1)]*G[{0, 1}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw])/32 - 
     (G[{0}, yw]*G[{0, 1}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw])/32 - 
     (3*G[{1}, yu^(-1)]*G[{0, 1}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw])/32 + 
     (3*G[{1}, yv^(-1)]*G[{0, 1}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw])/32 + 
     (9*G[{1}, yw]*G[{0, 1}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw])/64 - 
     (G[{yu}, yv^(-1)]*G[{0, 1}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw])/16 + 
     (3*G[{yv^(-1)}, yw]*G[{0, 1}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw])/16 + 
     (G[{1/(yu*yv)}, yw]*G[{0, 1}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw])/16 - 
     (G[{0}, yu^(-1)]*G[{0, yu^(-1)}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw])/32 - 
     (G[{0}, yv^(-1)]*G[{0, yu^(-1)}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw])/32 + 
     (G[{0}, yw]*G[{0, yu^(-1)}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw])/32 + 
     (3*G[{1}, yu^(-1)]*G[{0, yu^(-1)}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw])/32 - 
     (3*G[{1}, yv^(-1)]*G[{0, yu^(-1)}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw])/32 - 
     (9*G[{1}, yw]*G[{0, yu^(-1)}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw])/64 + 
     (G[{yu}, yv^(-1)]*G[{0, yu^(-1)}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw])/16 - 
     (3*G[{yv^(-1)}, yw]*G[{0, yu^(-1)}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw])/
      16 - (G[{1/(yu*yv)}, yw]*G[{0, yu^(-1)}, yw]*G[{yv^(-1), 1/(yu*yv)}, 
        yw])/16 + (G[{1}, yv^(-1)]*G[{0, yu}, yv^(-1)]*
       G[{yv^(-1), 1/(yu*yv)}, yw])/8 + (G[{1}, yw]*G[{0, yu}, yv^(-1)]*
       G[{yv^(-1), 1/(yu*yv)}, yw])/8 - (G[{yu^(-1)}, yw]*G[{0, yu}, yv^(-1)]*
       G[{yv^(-1), 1/(yu*yv)}, yw])/8 - (G[{yu}, yv^(-1)]*G[{0, yu}, yv^(-1)]*
       G[{yv^(-1), 1/(yu*yv)}, yw])/8 - (G[{0}, yu^(-1)]*G[{0, yv^(-1)}, yw]*
       G[{yv^(-1), 1/(yu*yv)}, yw])/32 - (G[{0}, yv^(-1)]*G[{0, yv^(-1)}, yw]*
       G[{yv^(-1), 1/(yu*yv)}, yw])/32 + (G[{0}, yw]*G[{0, yv^(-1)}, yw]*
       G[{yv^(-1), 1/(yu*yv)}, yw])/32 + 
     (3*G[{1}, yu^(-1)]*G[{0, yv^(-1)}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw])/32 - 
     (3*G[{1}, yv^(-1)]*G[{0, yv^(-1)}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw])/32 - 
     (9*G[{1}, yw]*G[{0, yv^(-1)}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw])/64 + 
     (G[{yu}, yv^(-1)]*G[{0, yv^(-1)}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw])/16 - 
     (3*G[{yv^(-1)}, yw]*G[{0, yv^(-1)}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw])/
      16 - (G[{1/(yu*yv)}, yw]*G[{0, yv^(-1)}, yw]*G[{yv^(-1), 1/(yu*yv)}, 
        yw])/16 + (G[{0}, yu^(-1)]*G[{0, 1/(yu*yv)}, yw]*
       G[{yv^(-1), 1/(yu*yv)}, yw])/32 + 
     (G[{0}, yv^(-1)]*G[{0, 1/(yu*yv)}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw])/32 - 
     (G[{0}, yw]*G[{0, 1/(yu*yv)}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw])/32 - 
     (3*G[{1}, yu^(-1)]*G[{0, 1/(yu*yv)}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw])/
      32 + (3*G[{1}, yv^(-1)]*G[{0, 1/(yu*yv)}, yw]*G[{yv^(-1), 1/(yu*yv)}, 
        yw])/32 + (9*G[{1}, yw]*G[{0, 1/(yu*yv)}, yw]*G[{yv^(-1), 1/(yu*yv)}, 
        yw])/64 - (G[{yu}, yv^(-1)]*G[{0, 1/(yu*yv)}, yw]*
       G[{yv^(-1), 1/(yu*yv)}, yw])/16 + 
     (3*G[{yv^(-1)}, yw]*G[{0, 1/(yu*yv)}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw])/
      16 + (G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv)}, yw]*G[{yv^(-1), 1/(yu*yv)}, 
        yw])/16 + (G[{0}, yu^(-1)]*G[{1, yu^(-1)}, yw]*
       G[{yv^(-1), 1/(yu*yv)}, yw])/32 + (G[{0}, yv^(-1)]*G[{1, yu^(-1)}, yw]*
       G[{yv^(-1), 1/(yu*yv)}, yw])/32 - (G[{0}, yw]*G[{1, yu^(-1)}, yw]*
       G[{yv^(-1), 1/(yu*yv)}, yw])/32 - 
     (3*G[{1}, yu^(-1)]*G[{1, yu^(-1)}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw])/32 + 
     (7*G[{1}, yv^(-1)]*G[{1, yu^(-1)}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw])/32 + 
     (3*G[{1}, yw]*G[{1, yu^(-1)}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw])/16 + 
     (G[{yu^(-1)}, yw]*G[{1, yu^(-1)}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw])/8 - 
     (3*G[{yu}, yv^(-1)]*G[{1, yu^(-1)}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw])/
      16 + (3*G[{yv^(-1)}, yw]*G[{1, yu^(-1)}, yw]*G[{yv^(-1), 1/(yu*yv)}, 
        yw])/16 + (G[{1/(yu*yv)}, yw]*G[{1, yu^(-1)}, yw]*
       G[{yv^(-1), 1/(yu*yv)}, yw])/16 + 
     (3*G[{0}, yu^(-1)]*G[{1, yu}, yv^(-1)]*G[{yv^(-1), 1/(yu*yv)}, yw])/32 + 
     (3*G[{0}, yv^(-1)]*G[{1, yu}, yv^(-1)]*G[{yv^(-1), 1/(yu*yv)}, yw])/32 - 
     (3*G[{0}, yw]*G[{1, yu}, yv^(-1)]*G[{yv^(-1), 1/(yu*yv)}, yw])/32 - 
     (3*G[{1}, yu^(-1)]*G[{1, yu}, yv^(-1)]*G[{yv^(-1), 1/(yu*yv)}, yw])/32 + 
     (5*G[{1}, yv^(-1)]*G[{1, yu}, yv^(-1)]*G[{yv^(-1), 1/(yu*yv)}, yw])/32 + 
     (3*G[{yu^(-1)}, yw]*G[{1, yu}, yv^(-1)]*G[{yv^(-1), 1/(yu*yv)}, yw])/
      32 + (G[{yu}, yv^(-1)]*G[{1, yu}, yv^(-1)]*G[{yv^(-1), 1/(yu*yv)}, yw])/
      8 + (7*G[{yv^(-1)}, yw]*G[{1, yu}, yv^(-1)]*G[{yv^(-1), 1/(yu*yv)}, 
        yw])/32 + (7*G[{1/(yu*yv)}, yw]*G[{1, yu}, yv^(-1)]*
       G[{yv^(-1), 1/(yu*yv)}, yw])/64 - (G[{0}, yu^(-1)]*G[{1, yv^(-1)}, yw]*
       G[{yv^(-1), 1/(yu*yv)}, yw])/16 - (G[{0}, yv^(-1)]*G[{1, yv^(-1)}, yw]*
       G[{yv^(-1), 1/(yu*yv)}, yw])/16 + (G[{0}, yw]*G[{1, yv^(-1)}, yw]*
       G[{yv^(-1), 1/(yu*yv)}, yw])/16 + (G[{1}, yv^(-1)]*G[{1, yv^(-1)}, yw]*
       G[{yv^(-1), 1/(yu*yv)}, yw])/16 - (G[{1}, yw]*G[{1, yv^(-1)}, yw]*
       G[{yv^(-1), 1/(yu*yv)}, yw])/16 + 
     (G[{yu^(-1)}, yw]*G[{1, yv^(-1)}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw])/32 + 
     (G[{yu}, yv^(-1)]*G[{1, yv^(-1)}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw])/16 - 
     (G[{yv^(-1)}, yw]*G[{1, yv^(-1)}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw])/32 - 
     (3*G[{1/(yu*yv)}, yw]*G[{1, yv^(-1)}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw])/
      64 + (3*G[{0}, yu^(-1)]*G[{1, 1/(yu*yv)}, yw]*G[{yv^(-1), 1/(yu*yv)}, 
        yw])/32 + (3*G[{0}, yv^(-1)]*G[{1, 1/(yu*yv)}, yw]*
       G[{yv^(-1), 1/(yu*yv)}, yw])/32 - (3*G[{0}, yw]*G[{1, 1/(yu*yv)}, yw]*
       G[{yv^(-1), 1/(yu*yv)}, yw])/32 - 
     (3*G[{1}, yu^(-1)]*G[{1, 1/(yu*yv)}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw])/
      32 - (3*G[{1}, yv^(-1)]*G[{1, 1/(yu*yv)}, yw]*G[{yv^(-1), 1/(yu*yv)}, 
        yw])/32 - (5*G[{yu^(-1)}, yw]*G[{1, 1/(yu*yv)}, yw]*
       G[{yv^(-1), 1/(yu*yv)}, yw])/32 + 
     (7*G[{yv^(-1)}, yw]*G[{1, 1/(yu*yv)}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw])/
      32 + (7*G[{1/(yu*yv)}, yw]*G[{1, 1/(yu*yv)}, yw]*
       G[{yv^(-1), 1/(yu*yv)}, yw])/64 - 
     (G[{0}, yu^(-1)]*G[{yu^(-1), 1/(yu*yv)}, yw]*G[{yv^(-1), 1/(yu*yv)}, 
        yw])/32 - (G[{0}, yv^(-1)]*G[{yu^(-1), 1/(yu*yv)}, yw]*
       G[{yv^(-1), 1/(yu*yv)}, yw])/32 + 
     (G[{0}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw])/
      32 + (3*G[{1}, yu^(-1)]*G[{yu^(-1), 1/(yu*yv)}, yw]*
       G[{yv^(-1), 1/(yu*yv)}, yw])/32 + 
     (G[{1}, yv^(-1)]*G[{yu^(-1), 1/(yu*yv)}, yw]*G[{yv^(-1), 1/(yu*yv)}, 
        yw])/32 + (G[{1}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw]*
       G[{yv^(-1), 1/(yu*yv)}, yw])/16 - 
     (G[{yu^(-1)}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw]*G[{yv^(-1), 1/(yu*yv)}, 
        yw])/32 - (G[{yu}, yv^(-1)]*G[{yu^(-1), 1/(yu*yv)}, yw]*
       G[{yv^(-1), 1/(yu*yv)}, yw])/16 - 
     (3*G[{yv^(-1)}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw]*G[{yv^(-1), 1/(yu*yv)}, 
        yw])/16 - (G[{1/(yu*yv)}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw]*
       G[{yv^(-1), 1/(yu*yv)}, yw])/16 - 
     (G[{0}, yu^(-1)]*G[{yv^(-1), 1/(yu*yv)}, yw]^2)/16 - 
     (G[{0}, yv^(-1)]*G[{yv^(-1), 1/(yu*yv)}, yw]^2)/16 + 
     (G[{0}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw]^2)/16 + 
     (3*G[{1}, yu^(-1)]*G[{yv^(-1), 1/(yu*yv)}, yw]^2)/32 - 
     (G[{1}, yv^(-1)]*G[{yv^(-1), 1/(yu*yv)}, yw]^2)/16 - 
     (3*G[{1}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw]^2)/32 + 
     (G[{yu^(-1)}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw]^2)/16 + 
     (3*G[{yu}, yv^(-1)]*G[{yv^(-1), 1/(yu*yv)}, yw]^2)/32 - 
     (3*G[{yv^(-1)}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw]^2)/32 - 
     (11*G[{1/(yu*yv)}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw]^2)/128 - 
     (G[{0}, yu^(-1)]^2*G[{0, 0, 1}, yu^(-1)])/32 - 
     (G[{0}, yu^(-1)]*G[{0}, yv^(-1)]*G[{0, 0, 1}, yu^(-1)])/16 - 
     (G[{0}, yv^(-1)]^2*G[{0, 0, 1}, yu^(-1)])/32 + 
     (G[{0}, yu^(-1)]*G[{0}, yw]*G[{0, 0, 1}, yu^(-1)])/16 + 
     (G[{0}, yv^(-1)]*G[{0}, yw]*G[{0, 0, 1}, yu^(-1)])/16 - 
     (G[{0}, yw]^2*G[{0, 0, 1}, yu^(-1)])/32 + 
     (G[{0}, yu^(-1)]*G[{1}, yu^(-1)]*G[{0, 0, 1}, yu^(-1)])/16 + 
     (G[{0}, yv^(-1)]*G[{1}, yu^(-1)]*G[{0, 0, 1}, yu^(-1)])/16 - 
     (G[{0}, yw]*G[{1}, yu^(-1)]*G[{0, 0, 1}, yu^(-1)])/16 - 
     (G[{1}, yu^(-1)]^2*G[{0, 0, 1}, yu^(-1)])/16 - 
     (G[{0}, yu^(-1)]*G[{1}, yv^(-1)]*G[{0, 0, 1}, yu^(-1)])/16 - 
     (G[{0}, yv^(-1)]*G[{1}, yv^(-1)]*G[{0, 0, 1}, yu^(-1)])/16 + 
     (G[{0}, yw]*G[{1}, yv^(-1)]*G[{0, 0, 1}, yu^(-1)])/16 + 
     (G[{1}, yv^(-1)]^2*G[{0, 0, 1}, yu^(-1)])/32 + 
     (G[{0}, yu^(-1)]*G[{1}, yw]*G[{0, 0, 1}, yu^(-1)])/16 + 
     (G[{0}, yv^(-1)]*G[{1}, yw]*G[{0, 0, 1}, yu^(-1)])/16 - 
     (G[{0}, yw]*G[{1}, yw]*G[{0, 0, 1}, yu^(-1)])/16 - 
     (G[{1}, yv^(-1)]*G[{1}, yw]*G[{0, 0, 1}, yu^(-1)])/16 + 
     (G[{1}, yw]^2*G[{0, 0, 1}, yu^(-1)])/32 - 
     (G[{1}, yw]*G[{yu}, yv^(-1)]*G[{0, 0, 1}, yu^(-1)])/16 - 
     (G[{0}, yu^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, 0, 1}, yu^(-1)])/16 - 
     (G[{0}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, 0, 1}, yu^(-1)])/16 + 
     (G[{0}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 0, 1}, yu^(-1)])/16 + 
     (G[{1}, yu^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, 0, 1}, yu^(-1)])/8 - 
     (G[{1}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, 0, 1}, yu^(-1)])/16 - 
     (G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 0, 1}, yu^(-1)])/16 + 
     (G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 0, 1}, yu^(-1)])/16 + 
     (G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, 0, 1}, yu^(-1)])/16 - 
     (G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 0, 1}, yu^(-1)])/8 + 
     (G[{0, 1}, yu^(-1)]*G[{0, 0, 1}, yu^(-1)])/16 + 
     (G[{0, 1}, yw]*G[{0, 0, 1}, yu^(-1)])/16 - 
     (G[{0, yu^(-1)}, yw]*G[{0, 0, 1}, yu^(-1)])/16 + 
     (G[{0, yv^(-1)}, yw]*G[{0, 0, 1}, yu^(-1)])/16 - 
     (G[{0, 1/(yu*yv)}, yw]*G[{0, 0, 1}, yu^(-1)])/16 + 
     (G[{1, yu^(-1)}, yw]*G[{0, 0, 1}, yu^(-1)])/16 + 
     (G[{1, yu}, yv^(-1)]*G[{0, 0, 1}, yu^(-1)])/16 + 
     (G[{1, 1/(yu*yv)}, yw]*G[{0, 0, 1}, yu^(-1)])/16 - 
     (G[{yu^(-1), 1/(yu*yv)}, yw]*G[{0, 0, 1}, yu^(-1)])/16 + 
     (G[{yv^(-1), 1/(yu*yv)}, yw]*G[{0, 0, 1}, yu^(-1)])/8 + 
     (G[{0}, yu^(-1)]*G[{1}, yv^(-1)]*G[{0, 0, 1}, yv^(-1)])/16 + 
     (G[{0}, yv^(-1)]*G[{1}, yv^(-1)]*G[{0, 0, 1}, yv^(-1)])/16 - 
     (G[{0}, yw]*G[{1}, yv^(-1)]*G[{0, 0, 1}, yv^(-1)])/16 - 
     (G[{1}, yv^(-1)]^2*G[{0, 0, 1}, yv^(-1)])/32 - 
     (G[{0}, yu^(-1)]*G[{1}, yw]*G[{0, 0, 1}, yv^(-1)])/16 - 
     (G[{0}, yv^(-1)]*G[{1}, yw]*G[{0, 0, 1}, yv^(-1)])/16 + 
     (G[{0}, yw]*G[{1}, yw]*G[{0, 0, 1}, yv^(-1)])/16 + 
     (G[{1}, yv^(-1)]*G[{1}, yw]*G[{0, 0, 1}, yv^(-1)])/16 - 
     (G[{1}, yw]^2*G[{0, 0, 1}, yv^(-1)])/32 + 
     (G[{1}, yw]*G[{yu}, yv^(-1)]*G[{0, 0, 1}, yv^(-1)])/16 + 
     (G[{1}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, 0, 1}, yv^(-1)])/16 + 
     (G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 0, 1}, yv^(-1)])/16 - 
     (G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 0, 1}, yv^(-1)])/16 - 
     (G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, 0, 1}, yv^(-1)])/16 - 
     (G[{0, 1}, yw]*G[{0, 0, 1}, yv^(-1)])/16 + 
     (G[{0, yu^(-1)}, yw]*G[{0, 0, 1}, yv^(-1)])/16 - 
     (G[{1, yu^(-1)}, yw]*G[{0, 0, 1}, yv^(-1)])/16 - 
     (G[{1, yu}, yv^(-1)]*G[{0, 0, 1}, yv^(-1)])/16 - 
     (G[{1, 1/(yu*yv)}, yw]*G[{0, 0, 1}, yv^(-1)])/16 + 
     (G[{yu^(-1), 1/(yu*yv)}, yw]*G[{0, 0, 1}, yv^(-1)])/16 - 
     (11*Pi^2*G[{0, 0, 1}, yw])/384 - (3*G[{0}, yu^(-1)]^2*G[{0, 0, 1}, yw])/
      64 - (3*G[{0}, yu^(-1)]*G[{0}, yv^(-1)]*G[{0, 0, 1}, yw])/32 - 
     (3*G[{0}, yv^(-1)]^2*G[{0, 0, 1}, yw])/64 + 
     (3*G[{0}, yu^(-1)]*G[{0}, yw]*G[{0, 0, 1}, yw])/32 + 
     (3*G[{0}, yv^(-1)]*G[{0}, yw]*G[{0, 0, 1}, yw])/32 - 
     (3*G[{0}, yw]^2*G[{0, 0, 1}, yw])/64 - 
     (3*G[{0}, yu^(-1)]*G[{1}, yu^(-1)]*G[{0, 0, 1}, yw])/32 - 
     (3*G[{0}, yv^(-1)]*G[{1}, yu^(-1)]*G[{0, 0, 1}, yw])/32 + 
     (3*G[{0}, yw]*G[{1}, yu^(-1)]*G[{0, 0, 1}, yw])/32 + 
     (15*G[{1}, yu^(-1)]^2*G[{0, 0, 1}, yw])/128 + 
     (3*G[{0}, yu^(-1)]*G[{1}, yv^(-1)]*G[{0, 0, 1}, yw])/32 + 
     (3*G[{0}, yv^(-1)]*G[{1}, yv^(-1)]*G[{0, 0, 1}, yw])/32 - 
     (3*G[{0}, yw]*G[{1}, yv^(-1)]*G[{0, 0, 1}, yw])/32 + 
     (13*G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*G[{0, 0, 1}, yw])/64 - 
     (3*G[{1}, yv^(-1)]^2*G[{0, 0, 1}, yw])/64 - 
     (9*G[{0}, yu^(-1)]*G[{1}, yw]*G[{0, 0, 1}, yw])/64 - 
     (9*G[{0}, yv^(-1)]*G[{1}, yw]*G[{0, 0, 1}, yw])/64 + 
     (9*G[{0}, yw]*G[{1}, yw]*G[{0, 0, 1}, yw])/64 - 
     (3*G[{1}, yu^(-1)]*G[{1}, yw]*G[{0, 0, 1}, yw])/32 + 
     (9*G[{1}, yv^(-1)]*G[{1}, yw]*G[{0, 0, 1}, yw])/64 - 
     (17*G[{1}, yw]^2*G[{0, 0, 1}, yw])/128 + 
     (3*G[{0}, yu^(-1)]*G[{yu}, yv^(-1)]*G[{0, 0, 1}, yw])/16 + 
     (3*G[{0}, yv^(-1)]*G[{yu}, yv^(-1)]*G[{0, 0, 1}, yw])/16 - 
     (3*G[{0}, yw]*G[{yu}, yv^(-1)]*G[{0, 0, 1}, yw])/16 - 
     (G[{1}, yu^(-1)]*G[{yu}, yv^(-1)]*G[{0, 0, 1}, yw])/4 + 
     (15*G[{1}, yw]*G[{yu}, yv^(-1)]*G[{0, 0, 1}, yw])/64 - 
     (G[{yu}, yv^(-1)]^2*G[{0, 0, 1}, yw])/16 + 
     (3*G[{0}, yu^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, 0, 1}, yw])/64 + 
     (3*G[{0}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, 0, 1}, yw])/64 - 
     (3*G[{0}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 0, 1}, yw])/64 - 
     (G[{1}, yu^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, 0, 1}, yw])/4 + 
     (G[{1}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, 0, 1}, yw])/64 + 
     (5*G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 0, 1}, yw])/64 - 
     (3*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 0, 1}, yw])/32 + 
     (9*G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, 0, 1}, yw])/64 + 
     (11*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 0, 1}, yw])/64 + 
     (3*G[{1/(yu*yv)}, yw]^2*G[{0, 0, 1}, yw])/64 + 
     (7*G[{0, 1}, yu^(-1)]*G[{0, 0, 1}, yw])/64 - 
     (3*G[{0, 1}, yv^(-1)]*G[{0, 0, 1}, yw])/16 + 
     (G[{0, 1}, yw]*G[{0, 0, 1}, yw])/32 + 
     (3*G[{0, yu^(-1)}, yw]*G[{0, 0, 1}, yw])/32 + 
     (3*G[{0, yu}, yv^(-1)]*G[{0, 0, 1}, yw])/16 - 
     (7*G[{0, yv^(-1)}, yw]*G[{0, 0, 1}, yw])/32 + 
     (3*G[{0, 1/(yu*yv)}, yw]*G[{0, 0, 1}, yw])/32 - 
     (3*G[{1, yu^(-1)}, yw]*G[{0, 0, 1}, yw])/32 - 
     (19*G[{1, yu}, yv^(-1)]*G[{0, 0, 1}, yw])/64 + 
     (G[{1, yv^(-1)}, yw]*G[{0, 0, 1}, yw])/64 + 
     (G[{1, 1/(yu*yv)}, yw]*G[{0, 0, 1}, yw])/64 + 
     (3*G[{yu^(-1), 1/(yu*yv)}, yw]*G[{0, 0, 1}, yw])/32 - 
     (11*G[{yv^(-1), 1/(yu*yv)}, yw]*G[{0, 0, 1}, yw])/64 + 
     (19*Pi^2*G[{0, 0, yu^(-1)}, yw])/384 + 
     (3*G[{0}, yu^(-1)]^2*G[{0, 0, yu^(-1)}, yw])/64 + 
     (3*G[{0}, yu^(-1)]*G[{0}, yv^(-1)]*G[{0, 0, yu^(-1)}, yw])/32 + 
     (3*G[{0}, yv^(-1)]^2*G[{0, 0, yu^(-1)}, yw])/64 - 
     (3*G[{0}, yu^(-1)]*G[{0}, yw]*G[{0, 0, yu^(-1)}, yw])/32 - 
     (3*G[{0}, yv^(-1)]*G[{0}, yw]*G[{0, 0, yu^(-1)}, yw])/32 + 
     (3*G[{0}, yw]^2*G[{0, 0, yu^(-1)}, yw])/64 + 
     (3*G[{0}, yu^(-1)]*G[{1}, yu^(-1)]*G[{0, 0, yu^(-1)}, yw])/32 + 
     (3*G[{0}, yv^(-1)]*G[{1}, yu^(-1)]*G[{0, 0, yu^(-1)}, yw])/32 - 
     (3*G[{0}, yw]*G[{1}, yu^(-1)]*G[{0, 0, yu^(-1)}, yw])/32 - 
     (15*G[{1}, yu^(-1)]^2*G[{0, 0, yu^(-1)}, yw])/128 - 
     (9*G[{0}, yu^(-1)]*G[{1}, yv^(-1)]*G[{0, 0, yu^(-1)}, yw])/32 - 
     (9*G[{0}, yv^(-1)]*G[{1}, yv^(-1)]*G[{0, 0, yu^(-1)}, yw])/32 + 
     (9*G[{0}, yw]*G[{1}, yv^(-1)]*G[{0, 0, yu^(-1)}, yw])/32 + 
     (3*G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*G[{0, 0, yu^(-1)}, yw])/64 + 
     (11*G[{1}, yv^(-1)]^2*G[{0, 0, yu^(-1)}, yw])/64 + 
     (9*G[{0}, yu^(-1)]*G[{1}, yw]*G[{0, 0, yu^(-1)}, yw])/64 + 
     (9*G[{0}, yv^(-1)]*G[{1}, yw]*G[{0, 0, yu^(-1)}, yw])/64 - 
     (9*G[{0}, yw]*G[{1}, yw]*G[{0, 0, yu^(-1)}, yw])/64 + 
     (3*G[{1}, yu^(-1)]*G[{1}, yw]*G[{0, 0, yu^(-1)}, yw])/32 - 
     (25*G[{1}, yv^(-1)]*G[{1}, yw]*G[{0, 0, yu^(-1)}, yw])/64 + 
     (17*G[{1}, yw]^2*G[{0, 0, yu^(-1)}, yw])/128 + 
     (G[{1}, yw]*G[{yu}, yv^(-1)]*G[{0, 0, yu^(-1)}, yw])/64 - 
     (3*G[{0}, yu^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, 0, yu^(-1)}, yw])/64 - 
     (3*G[{0}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, 0, yu^(-1)}, yw])/64 + 
     (3*G[{0}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 0, yu^(-1)}, yw])/64 + 
     (G[{1}, yu^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, 0, yu^(-1)}, yw])/4 - 
     (9*G[{1}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, 0, yu^(-1)}, yw])/64 - 
     (5*G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 0, yu^(-1)}, yw])/64 + 
     (3*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 0, yu^(-1)}, yw])/32 - 
     (G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, 0, yu^(-1)}, yw])/64 - 
     (11*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 0, yu^(-1)}, yw])/64 - 
     (3*G[{1/(yu*yv)}, yw]^2*G[{0, 0, yu^(-1)}, yw])/64 + 
     (G[{0, 1}, yu^(-1)]*G[{0, 0, yu^(-1)}, yw])/64 + 
     (3*G[{0, 1}, yv^(-1)]*G[{0, 0, yu^(-1)}, yw])/16 - 
     (G[{0, 1}, yw]*G[{0, 0, yu^(-1)}, yw])/32 - 
     (3*G[{0, yu^(-1)}, yw]*G[{0, 0, yu^(-1)}, yw])/32 - 
     (3*G[{0, yu}, yv^(-1)]*G[{0, 0, yu^(-1)}, yw])/16 + 
     (7*G[{0, yv^(-1)}, yw]*G[{0, 0, yu^(-1)}, yw])/32 - 
     (3*G[{0, 1/(yu*yv)}, yw]*G[{0, 0, yu^(-1)}, yw])/32 + 
     (3*G[{1, yu^(-1)}, yw]*G[{0, 0, yu^(-1)}, yw])/32 + 
     (11*G[{1, yu}, yv^(-1)]*G[{0, 0, yu^(-1)}, yw])/64 - 
     (G[{1, yv^(-1)}, yw]*G[{0, 0, yu^(-1)}, yw])/64 - 
     (G[{1, 1/(yu*yv)}, yw]*G[{0, 0, yu^(-1)}, yw])/64 - 
     (3*G[{yu^(-1), 1/(yu*yv)}, yw]*G[{0, 0, yu^(-1)}, yw])/32 + 
     (11*G[{yv^(-1), 1/(yu*yv)}, yw]*G[{0, 0, yu^(-1)}, yw])/64 - 
     (G[{0}, yu^(-1)]*G[{1}, yv^(-1)]*G[{0, 0, yu}, yv^(-1)])/16 - 
     (G[{0}, yv^(-1)]*G[{1}, yv^(-1)]*G[{0, 0, yu}, yv^(-1)])/16 + 
     (G[{0}, yw]*G[{1}, yv^(-1)]*G[{0, 0, yu}, yv^(-1)])/16 + 
     (G[{1}, yv^(-1)]^2*G[{0, 0, yu}, yv^(-1)])/32 + 
     (G[{0}, yu^(-1)]*G[{1}, yw]*G[{0, 0, yu}, yv^(-1)])/16 + 
     (G[{0}, yv^(-1)]*G[{1}, yw]*G[{0, 0, yu}, yv^(-1)])/16 - 
     (G[{0}, yw]*G[{1}, yw]*G[{0, 0, yu}, yv^(-1)])/16 - 
     (G[{1}, yv^(-1)]*G[{1}, yw]*G[{0, 0, yu}, yv^(-1)])/16 + 
     (G[{1}, yw]^2*G[{0, 0, yu}, yv^(-1)])/32 - 
     (G[{1}, yw]*G[{yu}, yv^(-1)]*G[{0, 0, yu}, yv^(-1)])/16 - 
     (G[{1}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, 0, yu}, yv^(-1)])/16 - 
     (G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 0, yu}, yv^(-1)])/16 + 
     (G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 0, yu}, yv^(-1)])/16 + 
     (G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, 0, yu}, yv^(-1)])/16 + 
     (G[{0, 1}, yw]*G[{0, 0, yu}, yv^(-1)])/16 - 
     (G[{0, yu^(-1)}, yw]*G[{0, 0, yu}, yv^(-1)])/16 + 
     (G[{1, yu^(-1)}, yw]*G[{0, 0, yu}, yv^(-1)])/16 + 
     (G[{1, yu}, yv^(-1)]*G[{0, 0, yu}, yv^(-1)])/16 + 
     (G[{1, 1/(yu*yv)}, yw]*G[{0, 0, yu}, yv^(-1)])/16 - 
     (G[{yu^(-1), 1/(yu*yv)}, yw]*G[{0, 0, yu}, yv^(-1)])/16 - 
     (Pi^2*G[{0, 0, yv^(-1)}, yw])/384 + 
     (3*G[{0}, yu^(-1)]^2*G[{0, 0, yv^(-1)}, yw])/64 + 
     (3*G[{0}, yu^(-1)]*G[{0}, yv^(-1)]*G[{0, 0, yv^(-1)}, yw])/32 + 
     (3*G[{0}, yv^(-1)]^2*G[{0, 0, yv^(-1)}, yw])/64 - 
     (3*G[{0}, yu^(-1)]*G[{0}, yw]*G[{0, 0, yv^(-1)}, yw])/32 - 
     (3*G[{0}, yv^(-1)]*G[{0}, yw]*G[{0, 0, yv^(-1)}, yw])/32 + 
     (3*G[{0}, yw]^2*G[{0, 0, yv^(-1)}, yw])/64 - 
     (3*G[{0}, yu^(-1)]*G[{1}, yu^(-1)]*G[{0, 0, yv^(-1)}, yw])/32 - 
     (3*G[{0}, yv^(-1)]*G[{1}, yu^(-1)]*G[{0, 0, yv^(-1)}, yw])/32 + 
     (3*G[{0}, yw]*G[{1}, yu^(-1)]*G[{0, 0, yv^(-1)}, yw])/32 + 
     (9*G[{1}, yu^(-1)]^2*G[{0, 0, yv^(-1)}, yw])/128 - 
     (3*G[{0}, yu^(-1)]*G[{1}, yv^(-1)]*G[{0, 0, yv^(-1)}, yw])/32 - 
     (3*G[{0}, yv^(-1)]*G[{1}, yv^(-1)]*G[{0, 0, yv^(-1)}, yw])/32 + 
     (3*G[{0}, yw]*G[{1}, yv^(-1)]*G[{0, 0, yv^(-1)}, yw])/32 + 
     (3*G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*G[{0, 0, yv^(-1)}, yw])/64 + 
     (3*G[{1}, yv^(-1)]^2*G[{0, 0, yv^(-1)}, yw])/64 + 
     (9*G[{0}, yu^(-1)]*G[{1}, yw]*G[{0, 0, yv^(-1)}, yw])/64 + 
     (9*G[{0}, yv^(-1)]*G[{1}, yw]*G[{0, 0, yv^(-1)}, yw])/64 - 
     (9*G[{0}, yw]*G[{1}, yw]*G[{0, 0, yv^(-1)}, yw])/64 - 
     (5*G[{1}, yu^(-1)]*G[{1}, yw]*G[{0, 0, yv^(-1)}, yw])/32 - 
     (9*G[{1}, yv^(-1)]*G[{1}, yw]*G[{0, 0, yv^(-1)}, yw])/64 + 
     (17*G[{1}, yw]^2*G[{0, 0, yv^(-1)}, yw])/128 + 
     (G[{1}, yw]*G[{yu}, yv^(-1)]*G[{0, 0, yv^(-1)}, yw])/64 - 
     (3*G[{0}, yu^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, 0, yv^(-1)}, yw])/64 - 
     (3*G[{0}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, 0, yv^(-1)}, yw])/64 + 
     (3*G[{0}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 0, yv^(-1)}, yw])/64 + 
     (G[{1}, yu^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, 0, yv^(-1)}, yw])/8 - 
     (G[{1}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, 0, yv^(-1)}, yw])/64 - 
     (5*G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 0, yv^(-1)}, yw])/64 + 
     (3*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 0, yv^(-1)}, yw])/32 - 
     (G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, 0, yv^(-1)}, yw])/64 - 
     (11*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 0, yv^(-1)}, yw])/64 - 
     (3*G[{1/(yu*yv)}, yw]^2*G[{0, 0, yv^(-1)}, yw])/64 - 
     (3*G[{0, 1}, yu^(-1)]*G[{0, 0, yv^(-1)}, yw])/64 - 
     (G[{0, 1}, yw]*G[{0, 0, yv^(-1)}, yw])/32 - 
     (3*G[{0, yu^(-1)}, yw]*G[{0, 0, yv^(-1)}, yw])/32 + 
     (7*G[{0, yv^(-1)}, yw]*G[{0, 0, yv^(-1)}, yw])/32 - 
     (3*G[{0, 1/(yu*yv)}, yw]*G[{0, 0, yv^(-1)}, yw])/32 + 
     (3*G[{1, yu^(-1)}, yw]*G[{0, 0, yv^(-1)}, yw])/32 + 
     (3*G[{1, yu}, yv^(-1)]*G[{0, 0, yv^(-1)}, yw])/64 - 
     (G[{1, yv^(-1)}, yw]*G[{0, 0, yv^(-1)}, yw])/64 - 
     (G[{1, 1/(yu*yv)}, yw]*G[{0, 0, yv^(-1)}, yw])/64 - 
     (3*G[{yu^(-1), 1/(yu*yv)}, yw]*G[{0, 0, yv^(-1)}, yw])/32 + 
     (11*G[{yv^(-1), 1/(yu*yv)}, yw]*G[{0, 0, yv^(-1)}, yw])/64 - 
     (7*Pi^2*G[{0, 0, 1/(yu*yv)}, yw])/384 - 
     (3*G[{0}, yu^(-1)]^2*G[{0, 0, 1/(yu*yv)}, yw])/64 - 
     (3*G[{0}, yu^(-1)]*G[{0}, yv^(-1)]*G[{0, 0, 1/(yu*yv)}, yw])/32 - 
     (3*G[{0}, yv^(-1)]^2*G[{0, 0, 1/(yu*yv)}, yw])/64 + 
     (3*G[{0}, yu^(-1)]*G[{0}, yw]*G[{0, 0, 1/(yu*yv)}, yw])/32 + 
     (3*G[{0}, yv^(-1)]*G[{0}, yw]*G[{0, 0, 1/(yu*yv)}, yw])/32 - 
     (3*G[{0}, yw]^2*G[{0, 0, 1/(yu*yv)}, yw])/64 + 
     (3*G[{0}, yu^(-1)]*G[{1}, yu^(-1)]*G[{0, 0, 1/(yu*yv)}, yw])/32 + 
     (3*G[{0}, yv^(-1)]*G[{1}, yu^(-1)]*G[{0, 0, 1/(yu*yv)}, yw])/32 - 
     (3*G[{0}, yw]*G[{1}, yu^(-1)]*G[{0, 0, 1/(yu*yv)}, yw])/32 - 
     (9*G[{1}, yu^(-1)]^2*G[{0, 0, 1/(yu*yv)}, yw])/128 + 
     (9*G[{0}, yu^(-1)]*G[{1}, yv^(-1)]*G[{0, 0, 1/(yu*yv)}, yw])/32 + 
     (9*G[{0}, yv^(-1)]*G[{1}, yv^(-1)]*G[{0, 0, 1/(yu*yv)}, yw])/32 - 
     (9*G[{0}, yw]*G[{1}, yv^(-1)]*G[{0, 0, 1/(yu*yv)}, yw])/32 - 
     (19*G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*G[{0, 0, 1/(yu*yv)}, yw])/64 - 
     (11*G[{1}, yv^(-1)]^2*G[{0, 0, 1/(yu*yv)}, yw])/64 - 
     (9*G[{0}, yu^(-1)]*G[{1}, yw]*G[{0, 0, 1/(yu*yv)}, yw])/64 - 
     (9*G[{0}, yv^(-1)]*G[{1}, yw]*G[{0, 0, 1/(yu*yv)}, yw])/64 + 
     (9*G[{0}, yw]*G[{1}, yw]*G[{0, 0, 1/(yu*yv)}, yw])/64 + 
     (5*G[{1}, yu^(-1)]*G[{1}, yw]*G[{0, 0, 1/(yu*yv)}, yw])/32 + 
     (25*G[{1}, yv^(-1)]*G[{1}, yw]*G[{0, 0, 1/(yu*yv)}, yw])/64 - 
     (17*G[{1}, yw]^2*G[{0, 0, 1/(yu*yv)}, yw])/128 - 
     (3*G[{0}, yu^(-1)]*G[{yu}, yv^(-1)]*G[{0, 0, 1/(yu*yv)}, yw])/16 - 
     (3*G[{0}, yv^(-1)]*G[{yu}, yv^(-1)]*G[{0, 0, 1/(yu*yv)}, yw])/16 + 
     (3*G[{0}, yw]*G[{yu}, yv^(-1)]*G[{0, 0, 1/(yu*yv)}, yw])/16 + 
     (G[{1}, yu^(-1)]*G[{yu}, yv^(-1)]*G[{0, 0, 1/(yu*yv)}, yw])/4 - 
     (17*G[{1}, yw]*G[{yu}, yv^(-1)]*G[{0, 0, 1/(yu*yv)}, yw])/64 + 
     (G[{yu}, yv^(-1)]^2*G[{0, 0, 1/(yu*yv)}, yw])/16 + 
     (3*G[{0}, yu^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, 0, 1/(yu*yv)}, yw])/64 + 
     (3*G[{0}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, 0, 1/(yu*yv)}, yw])/64 - 
     (3*G[{0}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 0, 1/(yu*yv)}, yw])/64 - 
     (G[{1}, yu^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, 0, 1/(yu*yv)}, yw])/8 + 
     (9*G[{1}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, 0, 1/(yu*yv)}, yw])/64 + 
     (5*G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 0, 1/(yu*yv)}, yw])/64 - 
     (3*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 0, 1/(yu*yv)}, yw])/32 - 
     (7*G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, 0, 1/(yu*yv)}, yw])/64 + 
     (11*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 0, 1/(yu*yv)}, yw])/64 + 
     (3*G[{1/(yu*yv)}, yw]^2*G[{0, 0, 1/(yu*yv)}, yw])/64 - 
     (5*G[{0, 1}, yu^(-1)]*G[{0, 0, 1/(yu*yv)}, yw])/64 + 
     (G[{0, 1}, yw]*G[{0, 0, 1/(yu*yv)}, yw])/32 + 
     (3*G[{0, yu^(-1)}, yw]*G[{0, 0, 1/(yu*yv)}, yw])/32 - 
     (7*G[{0, yv^(-1)}, yw]*G[{0, 0, 1/(yu*yv)}, yw])/32 + 
     (3*G[{0, 1/(yu*yv)}, yw]*G[{0, 0, 1/(yu*yv)}, yw])/32 - 
     (3*G[{1, yu^(-1)}, yw]*G[{0, 0, 1/(yu*yv)}, yw])/32 + 
     (5*G[{1, yu}, yv^(-1)]*G[{0, 0, 1/(yu*yv)}, yw])/64 + 
     (G[{1, yv^(-1)}, yw]*G[{0, 0, 1/(yu*yv)}, yw])/64 + 
     (G[{1, 1/(yu*yv)}, yw]*G[{0, 0, 1/(yu*yv)}, yw])/64 + 
     (3*G[{yu^(-1), 1/(yu*yv)}, yw]*G[{0, 0, 1/(yu*yv)}, yw])/32 - 
     (11*G[{yv^(-1), 1/(yu*yv)}, yw]*G[{0, 0, 1/(yu*yv)}, yw])/64 - 
     (Pi^2*G[{0, 1, 1}, yu^(-1)])/96 - 
     (G[{0}, yu^(-1)]^2*G[{0, 1, 1}, yu^(-1)])/16 - 
     (G[{0}, yu^(-1)]*G[{0}, yv^(-1)]*G[{0, 1, 1}, yu^(-1)])/8 - 
     (G[{0}, yv^(-1)]^2*G[{0, 1, 1}, yu^(-1)])/16 + 
     (G[{0}, yu^(-1)]*G[{0}, yw]*G[{0, 1, 1}, yu^(-1)])/8 + 
     (G[{0}, yv^(-1)]*G[{0}, yw]*G[{0, 1, 1}, yu^(-1)])/8 - 
     (G[{0}, yw]^2*G[{0, 1, 1}, yu^(-1)])/16 + 
     (G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*G[{0, 1, 1}, yu^(-1)])/8 + 
     (G[{1}, yv^(-1)]^2*G[{0, 1, 1}, yu^(-1)])/16 - 
     (G[{1}, yu^(-1)]*G[{1}, yw]*G[{0, 1, 1}, yu^(-1)])/8 - 
     (G[{1}, yv^(-1)]*G[{1}, yw]*G[{0, 1, 1}, yu^(-1)])/8 + 
     (G[{1}, yw]^2*G[{0, 1, 1}, yu^(-1)])/16 - 
     (G[{1}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, 1, 1}, yu^(-1)])/8 + 
     (G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1, 1}, yu^(-1)])/8 - 
     (G[{0, yu^(-1)}, yw]*G[{0, 1, 1}, yu^(-1)])/8 + 
     (G[{0, yv^(-1)}, yw]*G[{0, 1, 1}, yu^(-1)])/8 + 
     (G[{1, yu^(-1)}, yw]*G[{0, 1, 1}, yu^(-1)])/8 - 
     (G[{yu^(-1), 1/(yu*yv)}, yw]*G[{0, 1, 1}, yu^(-1)])/8 - 
     (Pi^2*G[{0, 1, 1}, yv^(-1)])/16 - 
     (3*G[{0}, yu^(-1)]^2*G[{0, 1, 1}, yv^(-1)])/16 - 
     (3*G[{0}, yu^(-1)]*G[{0}, yv^(-1)]*G[{0, 1, 1}, yv^(-1)])/8 - 
     (3*G[{0}, yv^(-1)]^2*G[{0, 1, 1}, yv^(-1)])/16 + 
     (3*G[{0}, yu^(-1)]*G[{0}, yw]*G[{0, 1, 1}, yv^(-1)])/8 + 
     (3*G[{0}, yv^(-1)]*G[{0}, yw]*G[{0, 1, 1}, yv^(-1)])/8 - 
     (3*G[{0}, yw]^2*G[{0, 1, 1}, yv^(-1)])/16 + 
     (G[{0}, yu^(-1)]*G[{1}, yu^(-1)]*G[{0, 1, 1}, yv^(-1)])/4 + 
     (G[{0}, yv^(-1)]*G[{1}, yu^(-1)]*G[{0, 1, 1}, yv^(-1)])/4 - 
     (G[{0}, yw]*G[{1}, yu^(-1)]*G[{0, 1, 1}, yv^(-1)])/4 - 
     (G[{1}, yu^(-1)]^2*G[{0, 1, 1}, yv^(-1)])/16 + 
     (5*G[{0}, yu^(-1)]*G[{1}, yv^(-1)]*G[{0, 1, 1}, yv^(-1)])/16 + 
     (5*G[{0}, yv^(-1)]*G[{1}, yv^(-1)]*G[{0, 1, 1}, yv^(-1)])/16 - 
     (5*G[{0}, yw]*G[{1}, yv^(-1)]*G[{0, 1, 1}, yv^(-1)])/16 - 
     (G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*G[{0, 1, 1}, yv^(-1)])/16 - 
     (G[{1}, yv^(-1)]^2*G[{0, 1, 1}, yv^(-1)])/32 - 
     (5*G[{0}, yu^(-1)]*G[{1}, yw]*G[{0, 1, 1}, yv^(-1)])/16 - 
     (5*G[{0}, yv^(-1)]*G[{1}, yw]*G[{0, 1, 1}, yv^(-1)])/16 + 
     (5*G[{0}, yw]*G[{1}, yw]*G[{0, 1, 1}, yv^(-1)])/16 + 
     (G[{1}, yu^(-1)]*G[{1}, yw]*G[{0, 1, 1}, yv^(-1)])/16 + 
     (G[{1}, yv^(-1)]*G[{1}, yw]*G[{0, 1, 1}, yv^(-1)])/16 - 
     (G[{1}, yw]^2*G[{0, 1, 1}, yv^(-1)])/32 - 
     (G[{1}, yw]*G[{yu}, yv^(-1)]*G[{0, 1, 1}, yv^(-1)])/16 - 
     (3*G[{0}, yu^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, 1, 1}, yv^(-1)])/8 - 
     (3*G[{0}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, 1, 1}, yv^(-1)])/8 + 
     (3*G[{0}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1, 1}, yv^(-1)])/8 + 
     (G[{1}, yu^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, 1, 1}, yv^(-1)])/4 + 
     (5*G[{1}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, 1, 1}, yv^(-1)])/16 - 
     (G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1, 1}, yv^(-1)])/16 - 
     (5*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1, 1}, yv^(-1)])/16 + 
     (G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, 1, 1}, yv^(-1)])/16 - 
     (G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1, 1}, yv^(-1)])/4 - 
     (3*G[{0, 1}, yv^(-1)]*G[{0, 1, 1}, yv^(-1)])/16 - 
     (3*G[{0, 1}, yw]*G[{0, 1, 1}, yv^(-1)])/16 + 
     (5*G[{0, yu^(-1)}, yw]*G[{0, 1, 1}, yv^(-1)])/16 + 
     (G[{0, yv^(-1)}, yw]*G[{0, 1, 1}, yv^(-1)])/4 - 
     (3*G[{0, 1/(yu*yv)}, yw]*G[{0, 1, 1}, yv^(-1)])/8 - 
     (5*G[{1, yu^(-1)}, yw]*G[{0, 1, 1}, yv^(-1)])/16 + 
     (G[{1, yu}, yv^(-1)]*G[{0, 1, 1}, yv^(-1)])/16 + 
     (G[{1, 1/(yu*yv)}, yw]*G[{0, 1, 1}, yv^(-1)])/16 + 
     (5*G[{yu^(-1), 1/(yu*yv)}, yw]*G[{0, 1, 1}, yv^(-1)])/16 + 
     (G[{yv^(-1), 1/(yu*yv)}, yw]*G[{0, 1, 1}, yv^(-1)])/4 + 
     (11*Pi^2*G[{0, 1, 1}, yw])/768 + (G[{0}, yu^(-1)]*G[{1}, yu^(-1)]*
       G[{0, 1, 1}, yw])/16 + (G[{0}, yv^(-1)]*G[{1}, yu^(-1)]*
       G[{0, 1, 1}, yw])/16 - (G[{0}, yw]*G[{1}, yu^(-1)]*G[{0, 1, 1}, yw])/
      16 - (5*G[{1}, yu^(-1)]^2*G[{0, 1, 1}, yw])/128 + 
     (5*G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*G[{0, 1, 1}, yw])/64 + 
     (G[{0}, yu^(-1)]*G[{1}, yw]*G[{0, 1, 1}, yw])/8 + 
     (G[{0}, yv^(-1)]*G[{1}, yw]*G[{0, 1, 1}, yw])/8 - 
     (G[{0}, yw]*G[{1}, yw]*G[{0, 1, 1}, yw])/8 - 
     (13*G[{1}, yu^(-1)]*G[{1}, yw]*G[{0, 1, 1}, yw])/64 - 
     (G[{1}, yv^(-1)]*G[{1}, yw]*G[{0, 1, 1}, yw])/8 - 
     (G[{1}, yw]^2*G[{0, 1, 1}, yw])/128 - 
     (G[{0}, yu^(-1)]*G[{yu}, yv^(-1)]*G[{0, 1, 1}, yw])/16 - 
     (G[{0}, yv^(-1)]*G[{yu}, yv^(-1)]*G[{0, 1, 1}, yw])/16 + 
     (G[{0}, yw]*G[{yu}, yv^(-1)]*G[{0, 1, 1}, yw])/16 - 
     (G[{1}, yu^(-1)]*G[{yu}, yv^(-1)]*G[{0, 1, 1}, yw])/8 + 
     (5*G[{1}, yw]*G[{yu}, yv^(-1)]*G[{0, 1, 1}, yw])/64 + 
     (G[{yu}, yv^(-1)]^2*G[{0, 1, 1}, yw])/8 - 
     (G[{0}, yu^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, 1, 1}, yw])/8 - 
     (G[{0}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, 1, 1}, yw])/8 + 
     (G[{0}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1, 1}, yw])/8 + 
     (G[{1}, yu^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, 1, 1}, yw])/64 + 
     (G[{1}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, 1, 1}, yw])/8 + 
     (G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1, 1}, yw])/64 - 
     (G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1, 1}, yw])/32 + 
     (7*G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, 1, 1}, yw])/64 + 
     (5*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1, 1}, yw])/64 + 
     (9*G[{0, 1}, yu^(-1)]*G[{0, 1, 1}, yw])/64 + 
     (G[{0, 1}, yv^(-1)]*G[{0, 1, 1}, yw])/16 - 
     (5*G[{0, 1}, yw]*G[{0, 1, 1}, yw])/64 + 
     (G[{0, yu^(-1)}, yw]*G[{0, 1, 1}, yw])/32 - 
     (G[{0, yu}, yv^(-1)]*G[{0, 1, 1}, yw])/16 - 
     (5*G[{0, yv^(-1)}, yw]*G[{0, 1, 1}, yw])/32 + 
     (3*G[{0, 1/(yu*yv)}, yw]*G[{0, 1, 1}, yw])/32 - 
     (G[{1, yu^(-1)}, yw]*G[{0, 1, 1}, yw])/32 - 
     (5*G[{1, yu}, yv^(-1)]*G[{0, 1, 1}, yw])/64 - 
     (G[{1, yv^(-1)}, yw]*G[{0, 1, 1}, yw])/64 - 
     (G[{1, 1/(yu*yv)}, yw]*G[{0, 1, 1}, yw])/64 + 
     (G[{yu^(-1), 1/(yu*yv)}, yw]*G[{0, 1, 1}, yw])/32 - 
     (5*G[{yv^(-1), 1/(yu*yv)}, yw]*G[{0, 1, 1}, yw])/64 - 
     (11*Pi^2*G[{0, 1, yu^(-1)}, yw])/256 - 
     (3*G[{0}, yu^(-1)]^2*G[{0, 1, yu^(-1)}, yw])/64 - 
     (3*G[{0}, yu^(-1)]*G[{0}, yv^(-1)]*G[{0, 1, yu^(-1)}, yw])/32 - 
     (3*G[{0}, yv^(-1)]^2*G[{0, 1, yu^(-1)}, yw])/64 + 
     (3*G[{0}, yu^(-1)]*G[{0}, yw]*G[{0, 1, yu^(-1)}, yw])/32 + 
     (3*G[{0}, yv^(-1)]*G[{0}, yw]*G[{0, 1, yu^(-1)}, yw])/32 - 
     (3*G[{0}, yw]^2*G[{0, 1, yu^(-1)}, yw])/64 - 
     (5*G[{0}, yu^(-1)]*G[{1}, yu^(-1)]*G[{0, 1, yu^(-1)}, yw])/32 - 
     (5*G[{0}, yv^(-1)]*G[{1}, yu^(-1)]*G[{0, 1, yu^(-1)}, yw])/32 + 
     (5*G[{0}, yw]*G[{1}, yu^(-1)]*G[{0, 1, yu^(-1)}, yw])/32 + 
     (5*G[{1}, yu^(-1)]^2*G[{0, 1, yu^(-1)}, yw])/32 + 
     (11*G[{0}, yu^(-1)]*G[{1}, yv^(-1)]*G[{0, 1, yu^(-1)}, yw])/32 + 
     (11*G[{0}, yv^(-1)]*G[{1}, yv^(-1)]*G[{0, 1, yu^(-1)}, yw])/32 - 
     (11*G[{0}, yw]*G[{1}, yv^(-1)]*G[{0, 1, yu^(-1)}, yw])/32 - 
     (17*G[{1}, yv^(-1)]^2*G[{0, 1, yu^(-1)}, yw])/64 - 
     (13*G[{0}, yu^(-1)]*G[{1}, yw]*G[{0, 1, yu^(-1)}, yw])/64 - 
     (13*G[{0}, yv^(-1)]*G[{1}, yw]*G[{0, 1, yu^(-1)}, yw])/64 + 
     (13*G[{0}, yw]*G[{1}, yw]*G[{0, 1, yu^(-1)}, yw])/64 + 
     (3*G[{1}, yu^(-1)]*G[{1}, yw]*G[{0, 1, yu^(-1)}, yw])/64 + 
     (25*G[{1}, yv^(-1)]*G[{1}, yw]*G[{0, 1, yu^(-1)}, yw])/64 - 
     (G[{1}, yw]^2*G[{0, 1, yu^(-1)}, yw])/8 - 
     (G[{1}, yw]*G[{yu}, yv^(-1)]*G[{0, 1, yu^(-1)}, yw])/32 + 
     (11*G[{0}, yu^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, 1, yu^(-1)}, yw])/64 + 
     (11*G[{0}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, 1, yu^(-1)}, yw])/64 - 
     (11*G[{0}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1, yu^(-1)}, yw])/64 - 
     (17*G[{1}, yu^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, 1, yu^(-1)}, yw])/64 - 
     (7*G[{1}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, 1, yu^(-1)}, yw])/64 + 
     (G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1, yu^(-1)}, yw])/16 - 
     (G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1, yu^(-1)}, yw])/16 + 
     (G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, 1, yu^(-1)}, yw])/32 + 
     (3*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1, yu^(-1)}, yw])/32 + 
     (3*G[{1/(yu*yv)}, yw]^2*G[{0, 1, yu^(-1)}, yw])/64 - 
     (G[{0, 1}, yu^(-1)]*G[{0, 1, yu^(-1)}, yw])/32 - 
     (3*G[{0, 1}, yv^(-1)]*G[{0, 1, yu^(-1)}, yw])/16 + 
     (G[{0, 1}, yw]*G[{0, 1, yu^(-1)}, yw])/16 + 
     (G[{0, yu^(-1)}, yw]*G[{0, 1, yu^(-1)}, yw])/16 + 
     (3*G[{0, yu}, yv^(-1)]*G[{0, 1, yu^(-1)}, yw])/16 - 
     (G[{0, yv^(-1)}, yw]*G[{0, 1, yu^(-1)}, yw])/16 - 
     (G[{1, yu^(-1)}, yw]*G[{0, 1, yu^(-1)}, yw])/16 - 
     (5*G[{1, yu}, yv^(-1)]*G[{0, 1, yu^(-1)}, yw])/32 + 
     (G[{1, yv^(-1)}, yw]*G[{0, 1, yu^(-1)}, yw])/32 + 
     (G[{1, 1/(yu*yv)}, yw]*G[{0, 1, yu^(-1)}, yw])/32 + 
     (G[{yu^(-1), 1/(yu*yv)}, yw]*G[{0, 1, yu^(-1)}, yw])/16 - 
     (3*G[{yv^(-1), 1/(yu*yv)}, yw]*G[{0, 1, yu^(-1)}, yw])/32 + 
     (Pi^2*G[{0, 1, yu}, yv^(-1)])/48 + 
     (3*G[{0}, yu^(-1)]^2*G[{0, 1, yu}, yv^(-1)])/32 + 
     (3*G[{0}, yu^(-1)]*G[{0}, yv^(-1)]*G[{0, 1, yu}, yv^(-1)])/16 + 
     (3*G[{0}, yv^(-1)]^2*G[{0, 1, yu}, yv^(-1)])/32 - 
     (3*G[{0}, yu^(-1)]*G[{0}, yw]*G[{0, 1, yu}, yv^(-1)])/16 - 
     (3*G[{0}, yv^(-1)]*G[{0}, yw]*G[{0, 1, yu}, yv^(-1)])/16 + 
     (3*G[{0}, yw]^2*G[{0, 1, yu}, yv^(-1)])/32 - 
     (G[{0}, yu^(-1)]*G[{1}, yu^(-1)]*G[{0, 1, yu}, yv^(-1)])/8 - 
     (G[{0}, yv^(-1)]*G[{1}, yu^(-1)]*G[{0, 1, yu}, yv^(-1)])/8 + 
     (G[{0}, yw]*G[{1}, yu^(-1)]*G[{0, 1, yu}, yv^(-1)])/8 + 
     (G[{1}, yu^(-1)]^2*G[{0, 1, yu}, yv^(-1)])/32 - 
     (G[{0}, yu^(-1)]*G[{1}, yv^(-1)]*G[{0, 1, yu}, yv^(-1)])/8 - 
     (G[{0}, yv^(-1)]*G[{1}, yv^(-1)]*G[{0, 1, yu}, yv^(-1)])/8 + 
     (G[{0}, yw]*G[{1}, yv^(-1)]*G[{0, 1, yu}, yv^(-1)])/8 + 
     (G[{0}, yu^(-1)]*G[{1}, yw]*G[{0, 1, yu}, yv^(-1)])/8 + 
     (G[{0}, yv^(-1)]*G[{1}, yw]*G[{0, 1, yu}, yv^(-1)])/8 - 
     (G[{0}, yw]*G[{1}, yw]*G[{0, 1, yu}, yv^(-1)])/8 + 
     (G[{1}, yw]*G[{yu}, yv^(-1)]*G[{0, 1, yu}, yv^(-1)])/8 + 
     (5*G[{0}, yu^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, 1, yu}, yv^(-1)])/16 + 
     (5*G[{0}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, 1, yu}, yv^(-1)])/16 - 
     (5*G[{0}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1, yu}, yv^(-1)])/16 - 
     (G[{1}, yu^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, 1, yu}, yv^(-1)])/4 - 
     (G[{1}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, 1, yu}, yv^(-1)])/4 + 
     (G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1, yu}, yv^(-1)])/8 + 
     (G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1, yu}, yv^(-1)])/4 - 
     (G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, 1, yu}, yv^(-1)])/8 + 
     (G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1, yu}, yv^(-1)])/4 - 
     (G[{0, 1}, yu^(-1)]*G[{0, 1, yu}, yv^(-1)])/16 + 
     (G[{0, 1}, yv^(-1)]*G[{0, 1, yu}, yv^(-1)])/8 + 
     (G[{0, 1}, yw]*G[{0, 1, yu}, yv^(-1)])/16 - 
     (G[{0, yu^(-1)}, yw]*G[{0, 1, yu}, yv^(-1)])/4 - 
     (G[{0, yv^(-1)}, yw]*G[{0, 1, yu}, yv^(-1)])/8 + 
     (5*G[{0, 1/(yu*yv)}, yw]*G[{0, 1, yu}, yv^(-1)])/16 + 
     (G[{1, yu^(-1)}, yw]*G[{0, 1, yu}, yv^(-1)])/4 - 
     (G[{1, yu}, yv^(-1)]*G[{0, 1, yu}, yv^(-1)])/8 - 
     (G[{1, 1/(yu*yv)}, yw]*G[{0, 1, yu}, yv^(-1)])/8 - 
     (G[{yu^(-1), 1/(yu*yv)}, yw]*G[{0, 1, yu}, yv^(-1)])/4 - 
     (G[{yv^(-1), 1/(yu*yv)}, yw]*G[{0, 1, yu}, yv^(-1)])/4 - 
     (3*Pi^2*G[{0, 1, yv^(-1)}, yw])/256 + 
     (3*G[{0}, yu^(-1)]^2*G[{0, 1, yv^(-1)}, yw])/64 + 
     (3*G[{0}, yu^(-1)]*G[{0}, yv^(-1)]*G[{0, 1, yv^(-1)}, yw])/32 + 
     (3*G[{0}, yv^(-1)]^2*G[{0, 1, yv^(-1)}, yw])/64 - 
     (3*G[{0}, yu^(-1)]*G[{0}, yw]*G[{0, 1, yv^(-1)}, yw])/32 - 
     (3*G[{0}, yv^(-1)]*G[{0}, yw]*G[{0, 1, yv^(-1)}, yw])/32 + 
     (3*G[{0}, yw]^2*G[{0, 1, yv^(-1)}, yw])/64 - 
     (7*G[{0}, yu^(-1)]*G[{1}, yu^(-1)]*G[{0, 1, yv^(-1)}, yw])/32 - 
     (7*G[{0}, yv^(-1)]*G[{1}, yu^(-1)]*G[{0, 1, yv^(-1)}, yw])/32 + 
     (7*G[{0}, yw]*G[{1}, yu^(-1)]*G[{0, 1, yv^(-1)}, yw])/32 + 
     (G[{1}, yu^(-1)]^2*G[{0, 1, yv^(-1)}, yw])/8 - 
     (3*G[{0}, yu^(-1)]*G[{1}, yv^(-1)]*G[{0, 1, yv^(-1)}, yw])/32 - 
     (3*G[{0}, yv^(-1)]*G[{1}, yv^(-1)]*G[{0, 1, yv^(-1)}, yw])/32 + 
     (3*G[{0}, yw]*G[{1}, yv^(-1)]*G[{0, 1, yv^(-1)}, yw])/32 + 
     (3*G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*G[{0, 1, yv^(-1)}, yw])/16 + 
     (3*G[{1}, yv^(-1)]^2*G[{0, 1, yv^(-1)}, yw])/64 - 
     (9*G[{0}, yu^(-1)]*G[{1}, yw]*G[{0, 1, yv^(-1)}, yw])/64 - 
     (9*G[{0}, yv^(-1)]*G[{1}, yw]*G[{0, 1, yv^(-1)}, yw])/64 + 
     (9*G[{0}, yw]*G[{1}, yw]*G[{0, 1, yv^(-1)}, yw])/64 + 
     (11*G[{1}, yu^(-1)]*G[{1}, yw]*G[{0, 1, yv^(-1)}, yw])/64 + 
     (9*G[{1}, yv^(-1)]*G[{1}, yw]*G[{0, 1, yv^(-1)}, yw])/64 - 
     (G[{1}, yw]^2*G[{0, 1, yv^(-1)}, yw])/8 + 
     (G[{0}, yu^(-1)]*G[{yu}, yv^(-1)]*G[{0, 1, yv^(-1)}, yw])/8 + 
     (G[{0}, yv^(-1)]*G[{yu}, yv^(-1)]*G[{0, 1, yv^(-1)}, yw])/8 - 
     (G[{0}, yw]*G[{yu}, yv^(-1)]*G[{0, 1, yv^(-1)}, yw])/8 - 
     (G[{1}, yw]*G[{yu}, yv^(-1)]*G[{0, 1, yv^(-1)}, yw])/32 - 
     (G[{yu}, yv^(-1)]^2*G[{0, 1, yv^(-1)}, yw])/8 + 
     (11*G[{0}, yu^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, 1, yv^(-1)}, yw])/64 + 
     (11*G[{0}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, 1, yv^(-1)}, yw])/64 - 
     (11*G[{0}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1, yv^(-1)}, yw])/64 - 
     (17*G[{1}, yu^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, 1, yv^(-1)}, yw])/64 - 
     (7*G[{1}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, 1, yv^(-1)}, yw])/64 + 
     (G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1, yv^(-1)}, yw])/16 - 
     (G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1, yv^(-1)}, yw])/16 + 
     (G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, 1, yv^(-1)}, yw])/32 + 
     (3*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1, yv^(-1)}, yw])/32 + 
     (3*G[{1/(yu*yv)}, yw]^2*G[{0, 1, yv^(-1)}, yw])/64 - 
     (G[{0, 1}, yu^(-1)]*G[{0, 1, yv^(-1)}, yw])/32 - 
     (G[{0, 1}, yv^(-1)]*G[{0, 1, yv^(-1)}, yw])/8 + 
     (G[{0, yu^(-1)}, yw]*G[{0, 1, yv^(-1)}, yw])/64 + 
     (G[{0, yu}, yv^(-1)]*G[{0, 1, yv^(-1)}, yw])/8 - 
     (G[{0, yv^(-1)}, yw]*G[{0, 1, yv^(-1)}, yw])/16 - 
     (G[{1, yu^(-1)}, yw]*G[{0, 1, yv^(-1)}, yw])/16 - 
     (3*G[{1, yu}, yv^(-1)]*G[{0, 1, yv^(-1)}, yw])/32 + 
     (G[{1, yv^(-1)}, yw]*G[{0, 1, yv^(-1)}, yw])/32 + 
     (G[{1, 1/(yu*yv)}, yw]*G[{0, 1, yv^(-1)}, yw])/32 + 
     (G[{yu^(-1), 1/(yu*yv)}, yw]*G[{0, 1, yv^(-1)}, yw])/16 - 
     (3*G[{yv^(-1), 1/(yu*yv)}, yw]*G[{0, 1, yv^(-1)}, yw])/32 - 
     (5*Pi^2*G[{0, 1, 1/(yu*yv)}, yw])/768 + 
     (G[{0}, yu^(-1)]*G[{1}, yu^(-1)]*G[{0, 1, 1/(yu*yv)}, yw])/16 + 
     (G[{0}, yv^(-1)]*G[{1}, yu^(-1)]*G[{0, 1, 1/(yu*yv)}, yw])/16 - 
     (G[{0}, yw]*G[{1}, yu^(-1)]*G[{0, 1, 1/(yu*yv)}, yw])/16 - 
     (5*G[{1}, yu^(-1)]^2*G[{0, 1, 1/(yu*yv)}, yw])/128 - 
     (3*G[{0}, yu^(-1)]*G[{1}, yv^(-1)]*G[{0, 1, 1/(yu*yv)}, yw])/16 - 
     (3*G[{0}, yv^(-1)]*G[{1}, yv^(-1)]*G[{0, 1, 1/(yu*yv)}, yw])/16 + 
     (3*G[{0}, yw]*G[{1}, yv^(-1)]*G[{0, 1, 1/(yu*yv)}, yw])/16 + 
     (5*G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*G[{0, 1, 1/(yu*yv)}, yw])/64 + 
     (3*G[{1}, yv^(-1)]^2*G[{0, 1, 1/(yu*yv)}, yw])/16 + 
     (G[{0}, yu^(-1)]*G[{1}, yw]*G[{0, 1, 1/(yu*yv)}, yw])/16 + 
     (G[{0}, yv^(-1)]*G[{1}, yw]*G[{0, 1, 1/(yu*yv)}, yw])/16 - 
     (G[{0}, yw]*G[{1}, yw]*G[{0, 1, 1/(yu*yv)}, yw])/16 - 
     (13*G[{1}, yu^(-1)]*G[{1}, yw]*G[{0, 1, 1/(yu*yv)}, yw])/64 - 
     (G[{1}, yv^(-1)]*G[{1}, yw]*G[{0, 1, 1/(yu*yv)}, yw])/8 - 
     (G[{1}, yw]^2*G[{0, 1, 1/(yu*yv)}, yw])/128 + 
     (G[{0}, yu^(-1)]*G[{yu}, yv^(-1)]*G[{0, 1, 1/(yu*yv)}, yw])/8 + 
     (G[{0}, yv^(-1)]*G[{yu}, yv^(-1)]*G[{0, 1, 1/(yu*yv)}, yw])/8 - 
     (G[{0}, yw]*G[{yu}, yv^(-1)]*G[{0, 1, 1/(yu*yv)}, yw])/8 - 
     (G[{1}, yu^(-1)]*G[{yu}, yv^(-1)]*G[{0, 1, 1/(yu*yv)}, yw])/8 + 
     (13*G[{1}, yw]*G[{yu}, yv^(-1)]*G[{0, 1, 1/(yu*yv)}, yw])/64 - 
     (G[{yu}, yv^(-1)]^2*G[{0, 1, 1/(yu*yv)}, yw])/16 - 
     (G[{0}, yu^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, 1, 1/(yu*yv)}, yw])/16 - 
     (G[{0}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, 1, 1/(yu*yv)}, yw])/16 + 
     (G[{0}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1, 1/(yu*yv)}, yw])/16 + 
     (G[{1}, yu^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, 1, 1/(yu*yv)}, yw])/64 + 
     (G[{1}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, 1, 1/(yu*yv)}, yw])/8 + 
     (G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1, 1/(yu*yv)}, yw])/64 - 
     (G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1, 1/(yu*yv)}, yw])/32 - 
     (G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, 1, 1/(yu*yv)}, yw])/64 + 
     (5*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1, 1/(yu*yv)}, yw])/64 + 
     (G[{0, 1}, yu^(-1)]*G[{0, 1, 1/(yu*yv)}, yw])/64 - 
     (G[{0, 1}, yv^(-1)]*G[{0, 1, 1/(yu*yv)}, yw])/16 + 
     (3*G[{0, 1}, yw]*G[{0, 1, 1/(yu*yv)}, yw])/64 + 
     (5*G[{0, yu^(-1)}, yw]*G[{0, 1, 1/(yu*yv)}, yw])/64 + 
     (G[{0, yu}, yv^(-1)]*G[{0, 1, 1/(yu*yv)}, yw])/16 + 
     (G[{0, yv^(-1)}, yw]*G[{0, 1, 1/(yu*yv)}, yw])/64 + 
     (G[{0, 1/(yu*yv)}, yw]*G[{0, 1, 1/(yu*yv)}, yw])/32 - 
     (G[{1, yu^(-1)}, yw]*G[{0, 1, 1/(yu*yv)}, yw])/32 - 
     (5*G[{1, yu}, yv^(-1)]*G[{0, 1, 1/(yu*yv)}, yw])/64 - 
     (G[{1, yv^(-1)}, yw]*G[{0, 1, 1/(yu*yv)}, yw])/64 - 
     (G[{1, 1/(yu*yv)}, yw]*G[{0, 1, 1/(yu*yv)}, yw])/64 + 
     (G[{yu^(-1), 1/(yu*yv)}, yw]*G[{0, 1, 1/(yu*yv)}, yw])/32 - 
     (5*G[{yv^(-1), 1/(yu*yv)}, yw]*G[{0, 1, 1/(yu*yv)}, yw])/64 - 
     (19*Pi^2*G[{0, yu^(-1), 1}, yw])/768 - 
     (3*G[{0}, yu^(-1)]^2*G[{0, yu^(-1), 1}, yw])/32 - 
     (3*G[{0}, yu^(-1)]*G[{0}, yv^(-1)]*G[{0, yu^(-1), 1}, yw])/16 - 
     (3*G[{0}, yv^(-1)]^2*G[{0, yu^(-1), 1}, yw])/32 + 
     (3*G[{0}, yu^(-1)]*G[{0}, yw]*G[{0, yu^(-1), 1}, yw])/16 + 
     (3*G[{0}, yv^(-1)]*G[{0}, yw]*G[{0, yu^(-1), 1}, yw])/16 - 
     (3*G[{0}, yw]^2*G[{0, yu^(-1), 1}, yw])/32 + 
     (9*G[{1}, yu^(-1)]^2*G[{0, yu^(-1), 1}, yw])/128 + 
     (3*G[{0}, yu^(-1)]*G[{1}, yv^(-1)]*G[{0, yu^(-1), 1}, yw])/16 + 
     (3*G[{0}, yv^(-1)]*G[{1}, yv^(-1)]*G[{0, yu^(-1), 1}, yw])/16 - 
     (3*G[{0}, yw]*G[{1}, yv^(-1)]*G[{0, yu^(-1), 1}, yw])/16 - 
     (G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*G[{0, yu^(-1), 1}, yw])/64 - 
     (G[{1}, yv^(-1)]^2*G[{0, yu^(-1), 1}, yw])/8 - 
     (3*G[{0}, yu^(-1)]*G[{1}, yw]*G[{0, yu^(-1), 1}, yw])/16 - 
     (3*G[{0}, yv^(-1)]*G[{1}, yw]*G[{0, yu^(-1), 1}, yw])/16 + 
     (3*G[{0}, yw]*G[{1}, yw]*G[{0, yu^(-1), 1}, yw])/16 + 
     (13*G[{1}, yu^(-1)]*G[{1}, yw]*G[{0, yu^(-1), 1}, yw])/64 + 
     (G[{1}, yv^(-1)]*G[{1}, yw]*G[{0, yu^(-1), 1}, yw])/8 + 
     (G[{1}, yw]^2*G[{0, yu^(-1), 1}, yw])/128 + 
     (3*G[{0}, yu^(-1)]*G[{yu}, yv^(-1)]*G[{0, yu^(-1), 1}, yw])/16 + 
     (3*G[{0}, yv^(-1)]*G[{yu}, yv^(-1)]*G[{0, yu^(-1), 1}, yw])/16 - 
     (3*G[{0}, yw]*G[{yu}, yv^(-1)]*G[{0, yu^(-1), 1}, yw])/16 - 
     (G[{1}, yu^(-1)]*G[{yu}, yv^(-1)]*G[{0, yu^(-1), 1}, yw])/8 + 
     (3*G[{1}, yw]*G[{yu}, yv^(-1)]*G[{0, yu^(-1), 1}, yw])/64 - 
     (G[{yu}, yv^(-1)]^2*G[{0, yu^(-1), 1}, yw])/8 + 
     (G[{0}, yu^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1), 1}, yw])/16 + 
     (G[{0}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1), 1}, yw])/16 - 
     (G[{0}, yw]*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1), 1}, yw])/16 - 
     (G[{1}, yu^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1), 1}, yw])/64 - 
     (G[{1}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1), 1}, yw])/8 - 
     (G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1), 1}, yw])/64 + 
     (G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1), 1}, yw])/32 + 
     (G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1), 1}, yw])/64 - 
     (5*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1), 1}, yw])/64 - 
     (G[{0, 1}, yu^(-1)]*G[{0, yu^(-1), 1}, yw])/64 - 
     (G[{0, 1}, yv^(-1)]*G[{0, yu^(-1), 1}, yw])/8 + 
     (G[{0, 1}, yw]*G[{0, yu^(-1), 1}, yw])/64 - 
     (G[{0, yu^(-1)}, yw]*G[{0, yu^(-1), 1}, yw])/64 + 
     (G[{0, yu}, yv^(-1)]*G[{0, yu^(-1), 1}, yw])/8 + 
     (G[{0, yv^(-1)}, yw]*G[{0, yu^(-1), 1}, yw])/32 - 
     (G[{0, 1/(yu*yv)}, yw]*G[{0, yu^(-1), 1}, yw])/32 + 
     (G[{1, yu^(-1)}, yw]*G[{0, yu^(-1), 1}, yw])/32 - 
     (7*G[{1, yu}, yv^(-1)]*G[{0, yu^(-1), 1}, yw])/64 + 
     (G[{1, yv^(-1)}, yw]*G[{0, yu^(-1), 1}, yw])/64 + 
     (G[{1, 1/(yu*yv)}, yw]*G[{0, yu^(-1), 1}, yw])/64 - 
     (G[{yu^(-1), 1/(yu*yv)}, yw]*G[{0, yu^(-1), 1}, yw])/32 + 
     (5*G[{yv^(-1), 1/(yu*yv)}, yw]*G[{0, yu^(-1), 1}, yw])/64 + 
     (19*Pi^2*G[{0, yu^(-1), yu^(-1)}, yw])/256 + 
     (9*G[{0}, yu^(-1)]^2*G[{0, yu^(-1), yu^(-1)}, yw])/64 + 
     (9*G[{0}, yu^(-1)]*G[{0}, yv^(-1)]*G[{0, yu^(-1), yu^(-1)}, yw])/32 + 
     (9*G[{0}, yv^(-1)]^2*G[{0, yu^(-1), yu^(-1)}, yw])/64 - 
     (9*G[{0}, yu^(-1)]*G[{0}, yw]*G[{0, yu^(-1), yu^(-1)}, yw])/32 - 
     (9*G[{0}, yv^(-1)]*G[{0}, yw]*G[{0, yu^(-1), yu^(-1)}, yw])/32 + 
     (9*G[{0}, yw]^2*G[{0, yu^(-1), yu^(-1)}, yw])/64 + 
     (3*G[{0}, yu^(-1)]*G[{1}, yu^(-1)]*G[{0, yu^(-1), yu^(-1)}, yw])/32 + 
     (3*G[{0}, yv^(-1)]*G[{1}, yu^(-1)]*G[{0, yu^(-1), yu^(-1)}, yw])/32 - 
     (3*G[{0}, yw]*G[{1}, yu^(-1)]*G[{0, yu^(-1), yu^(-1)}, yw])/32 - 
     (3*G[{1}, yu^(-1)]^2*G[{0, yu^(-1), yu^(-1)}, yw])/16 - 
     (21*G[{0}, yu^(-1)]*G[{1}, yv^(-1)]*G[{0, yu^(-1), yu^(-1)}, yw])/32 - 
     (21*G[{0}, yv^(-1)]*G[{1}, yv^(-1)]*G[{0, yu^(-1), yu^(-1)}, yw])/32 + 
     (21*G[{0}, yw]*G[{1}, yv^(-1)]*G[{0, yu^(-1), yu^(-1)}, yw])/32 + 
     (3*G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*G[{0, yu^(-1), yu^(-1)}, yw])/16 + 
     (29*G[{1}, yv^(-1)]^2*G[{0, yu^(-1), yu^(-1)}, yw])/64 + 
     (17*G[{0}, yu^(-1)]*G[{1}, yw]*G[{0, yu^(-1), yu^(-1)}, yw])/64 + 
     (17*G[{0}, yv^(-1)]*G[{1}, yw]*G[{0, yu^(-1), yu^(-1)}, yw])/64 - 
     (17*G[{0}, yw]*G[{1}, yw]*G[{0, yu^(-1), yu^(-1)}, yw])/64 - 
     (3*G[{1}, yu^(-1)]*G[{1}, yw]*G[{0, yu^(-1), yu^(-1)}, yw])/64 - 
     (33*G[{1}, yv^(-1)]*G[{1}, yw]*G[{0, yu^(-1), yu^(-1)}, yw])/64 + 
     (G[{1}, yw]^2*G[{0, yu^(-1), yu^(-1)}, yw])/8 + 
     (G[{1}, yw]*G[{yu}, yv^(-1)]*G[{0, yu^(-1), yu^(-1)}, yw])/32 - 
     (7*G[{0}, yu^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1), yu^(-1)}, yw])/64 - 
     (7*G[{0}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1), yu^(-1)}, yw])/64 + 
     (7*G[{0}, yw]*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1), yu^(-1)}, yw])/64 + 
     (17*G[{1}, yu^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1), yu^(-1)}, yw])/
      64 - (G[{1}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1), yu^(-1)}, yw])/
      64 - (G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1), yu^(-1)}, yw])/16 + 
     (G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1), yu^(-1)}, yw])/16 - 
     (G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1), yu^(-1)}, yw])/32 - 
     (3*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1), yu^(-1)}, yw])/
      32 - (3*G[{1/(yu*yv)}, yw]^2*G[{0, yu^(-1), yu^(-1)}, yw])/64 + 
     (G[{0, 1}, yu^(-1)]*G[{0, yu^(-1), yu^(-1)}, yw])/32 + 
     (G[{0, 1}, yv^(-1)]*G[{0, yu^(-1), yu^(-1)}, yw])/4 - 
     (G[{0, 1}, yw]*G[{0, yu^(-1), yu^(-1)}, yw])/8 + 
     (G[{0, yu^(-1)}, yw]*G[{0, yu^(-1), yu^(-1)}, yw])/8 - 
     (G[{0, yu}, yv^(-1)]*G[{0, yu^(-1), yu^(-1)}, yw])/4 + 
     (3*G[{0, yv^(-1)}, yw]*G[{0, yu^(-1), yu^(-1)}, yw])/16 - 
     (G[{0, 1/(yu*yv)}, yw]*G[{0, yu^(-1), yu^(-1)}, yw])/16 + 
     (G[{1, yu^(-1)}, yw]*G[{0, yu^(-1), yu^(-1)}, yw])/16 + 
     (7*G[{1, yu}, yv^(-1)]*G[{0, yu^(-1), yu^(-1)}, yw])/32 - 
     (G[{1, yv^(-1)}, yw]*G[{0, yu^(-1), yu^(-1)}, yw])/32 - 
     (G[{1, 1/(yu*yv)}, yw]*G[{0, yu^(-1), yu^(-1)}, yw])/32 - 
     (G[{yu^(-1), 1/(yu*yv)}, yw]*G[{0, yu^(-1), yu^(-1)}, yw])/16 + 
     (3*G[{yv^(-1), 1/(yu*yv)}, yw]*G[{0, yu^(-1), yu^(-1)}, yw])/32 + 
     (3*Pi^2*G[{0, yu^(-1), yv^(-1)}, yw])/256 - 
     (3*G[{0}, yu^(-1)]^2*G[{0, yu^(-1), yv^(-1)}, yw])/64 - 
     (3*G[{0}, yu^(-1)]*G[{0}, yv^(-1)]*G[{0, yu^(-1), yv^(-1)}, yw])/32 - 
     (3*G[{0}, yv^(-1)]^2*G[{0, yu^(-1), yv^(-1)}, yw])/64 + 
     (3*G[{0}, yu^(-1)]*G[{0}, yw]*G[{0, yu^(-1), yv^(-1)}, yw])/32 + 
     (3*G[{0}, yv^(-1)]*G[{0}, yw]*G[{0, yu^(-1), yv^(-1)}, yw])/32 - 
     (3*G[{0}, yw]^2*G[{0, yu^(-1), yv^(-1)}, yw])/64 + 
     (7*G[{0}, yu^(-1)]*G[{1}, yu^(-1)]*G[{0, yu^(-1), yv^(-1)}, yw])/32 + 
     (7*G[{0}, yv^(-1)]*G[{1}, yu^(-1)]*G[{0, yu^(-1), yv^(-1)}, yw])/32 - 
     (7*G[{0}, yw]*G[{1}, yu^(-1)]*G[{0, yu^(-1), yv^(-1)}, yw])/32 - 
     (G[{1}, yu^(-1)]^2*G[{0, yu^(-1), yv^(-1)}, yw])/8 - 
     (G[{0}, yu^(-1)]*G[{1}, yv^(-1)]*G[{0, yu^(-1), yv^(-1)}, yw])/32 - 
     (G[{0}, yv^(-1)]*G[{1}, yv^(-1)]*G[{0, yu^(-1), yv^(-1)}, yw])/32 + 
     (G[{0}, yw]*G[{1}, yv^(-1)]*G[{0, yu^(-1), yv^(-1)}, yw])/32 - 
     (3*G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*G[{0, yu^(-1), yv^(-1)}, yw])/16 + 
     (5*G[{1}, yv^(-1)]^2*G[{0, yu^(-1), yv^(-1)}, yw])/64 + 
     (5*G[{0}, yu^(-1)]*G[{1}, yw]*G[{0, yu^(-1), yv^(-1)}, yw])/64 + 
     (5*G[{0}, yv^(-1)]*G[{1}, yw]*G[{0, yu^(-1), yv^(-1)}, yw])/64 - 
     (5*G[{0}, yw]*G[{1}, yw]*G[{0, yu^(-1), yv^(-1)}, yw])/64 - 
     (3*G[{1}, yu^(-1)]*G[{1}, yw]*G[{0, yu^(-1), yv^(-1)}, yw])/64 - 
     (9*G[{1}, yv^(-1)]*G[{1}, yw]*G[{0, yu^(-1), yv^(-1)}, yw])/64 + 
     (G[{1}, yw]^2*G[{0, yu^(-1), yv^(-1)}, yw])/8 + 
     (G[{1}, yw]*G[{yu}, yv^(-1)]*G[{0, yu^(-1), yv^(-1)}, yw])/32 - 
     (11*G[{0}, yu^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1), yv^(-1)}, yw])/
      64 - (11*G[{0}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1), yv^(-1)}, 
        yw])/64 + (11*G[{0}, yw]*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1), yv^(-1)}, 
        yw])/64 + (17*G[{1}, yu^(-1)]*G[{1/(yu*yv)}, yw]*
       G[{0, yu^(-1), yv^(-1)}, yw])/64 + 
     (7*G[{1}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1), yv^(-1)}, yw])/64 - 
     (G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1), yv^(-1)}, yw])/16 + 
     (G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1), yv^(-1)}, yw])/16 - 
     (G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1), yv^(-1)}, yw])/32 - 
     (3*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1), yv^(-1)}, yw])/
      32 - (3*G[{1/(yu*yv)}, yw]^2*G[{0, yu^(-1), yv^(-1)}, yw])/64 + 
     (G[{0, 1}, yu^(-1)]*G[{0, yu^(-1), yv^(-1)}, yw])/32 + 
     (G[{0, 1}, yv^(-1)]*G[{0, yu^(-1), yv^(-1)}, yw])/8 - 
     (G[{0, yu}, yv^(-1)]*G[{0, yu^(-1), yv^(-1)}, yw])/8 + 
     (G[{0, yv^(-1)}, yw]*G[{0, yu^(-1), yv^(-1)}, yw])/16 + 
     (G[{1, yu^(-1)}, yw]*G[{0, yu^(-1), yv^(-1)}, yw])/16 + 
     (3*G[{1, yu}, yv^(-1)]*G[{0, yu^(-1), yv^(-1)}, yw])/32 - 
     (G[{1, yv^(-1)}, yw]*G[{0, yu^(-1), yv^(-1)}, yw])/32 - 
     (G[{1, 1/(yu*yv)}, yw]*G[{0, yu^(-1), yv^(-1)}, yw])/32 - 
     (G[{yu^(-1), 1/(yu*yv)}, yw]*G[{0, yu^(-1), yv^(-1)}, yw])/16 + 
     (3*G[{yv^(-1), 1/(yu*yv)}, yw]*G[{0, yu^(-1), yv^(-1)}, yw])/32 + 
     (5*Pi^2*G[{0, yu^(-1), 1/(yu*yv)}, yw])/768 - 
     (G[{0}, yu^(-1)]*G[{1}, yu^(-1)]*G[{0, yu^(-1), 1/(yu*yv)}, yw])/16 - 
     (G[{0}, yv^(-1)]*G[{1}, yu^(-1)]*G[{0, yu^(-1), 1/(yu*yv)}, yw])/16 + 
     (G[{0}, yw]*G[{1}, yu^(-1)]*G[{0, yu^(-1), 1/(yu*yv)}, yw])/16 + 
     (5*G[{1}, yu^(-1)]^2*G[{0, yu^(-1), 1/(yu*yv)}, yw])/128 + 
     (G[{0}, yu^(-1)]*G[{1}, yv^(-1)]*G[{0, yu^(-1), 1/(yu*yv)}, yw])/4 + 
     (G[{0}, yv^(-1)]*G[{1}, yv^(-1)]*G[{0, yu^(-1), 1/(yu*yv)}, yw])/4 - 
     (G[{0}, yw]*G[{1}, yv^(-1)]*G[{0, yu^(-1), 1/(yu*yv)}, yw])/4 - 
     (5*G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*G[{0, yu^(-1), 1/(yu*yv)}, yw])/64 - 
     (G[{1}, yv^(-1)]^2*G[{0, yu^(-1), 1/(yu*yv)}, yw])/4 + 
     (5*G[{1}, yu^(-1)]*G[{1}, yw]*G[{0, yu^(-1), 1/(yu*yv)}, yw])/64 + 
     (G[{1}, yw]^2*G[{0, yu^(-1), 1/(yu*yv)}, yw])/128 - 
     (3*G[{0}, yu^(-1)]*G[{yu}, yv^(-1)]*G[{0, yu^(-1), 1/(yu*yv)}, yw])/16 - 
     (3*G[{0}, yv^(-1)]*G[{yu}, yv^(-1)]*G[{0, yu^(-1), 1/(yu*yv)}, yw])/16 + 
     (3*G[{0}, yw]*G[{yu}, yv^(-1)]*G[{0, yu^(-1), 1/(yu*yv)}, yw])/16 + 
     (G[{1}, yu^(-1)]*G[{yu}, yv^(-1)]*G[{0, yu^(-1), 1/(yu*yv)}, yw])/8 - 
     (5*G[{1}, yw]*G[{yu}, yv^(-1)]*G[{0, yu^(-1), 1/(yu*yv)}, yw])/64 + 
     (G[{yu}, yv^(-1)]^2*G[{0, yu^(-1), 1/(yu*yv)}, yw])/8 + 
     (G[{0}, yu^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1), 1/(yu*yv)}, yw])/16 + 
     (G[{0}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1), 1/(yu*yv)}, yw])/16 - 
     (G[{0}, yw]*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1), 1/(yu*yv)}, yw])/16 - 
     (G[{1}, yu^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1), 1/(yu*yv)}, yw])/64 - 
     (G[{1}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1), 1/(yu*yv)}, yw])/8 - 
     (G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1), 1/(yu*yv)}, yw])/64 + 
     (G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1), 1/(yu*yv)}, yw])/
      32 + (G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1), 1/(yu*yv)}, 
        yw])/64 - (5*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*
       G[{0, yu^(-1), 1/(yu*yv)}, yw])/64 - 
     (G[{0, 1}, yu^(-1)]*G[{0, yu^(-1), 1/(yu*yv)}, yw])/64 + 
     (G[{0, 1}, yv^(-1)]*G[{0, yu^(-1), 1/(yu*yv)}, yw])/16 - 
     (3*G[{0, 1}, yw]*G[{0, yu^(-1), 1/(yu*yv)}, yw])/64 + 
     (3*G[{0, yu^(-1)}, yw]*G[{0, yu^(-1), 1/(yu*yv)}, yw])/64 - 
     (G[{0, yu}, yv^(-1)]*G[{0, yu^(-1), 1/(yu*yv)}, yw])/16 + 
     (G[{0, yv^(-1)}, yw]*G[{0, yu^(-1), 1/(yu*yv)}, yw])/32 - 
     (G[{0, 1/(yu*yv)}, yw]*G[{0, yu^(-1), 1/(yu*yv)}, yw])/32 + 
     (G[{1, yu^(-1)}, yw]*G[{0, yu^(-1), 1/(yu*yv)}, yw])/32 + 
     (5*G[{1, yu}, yv^(-1)]*G[{0, yu^(-1), 1/(yu*yv)}, yw])/64 + 
     (G[{1, yv^(-1)}, yw]*G[{0, yu^(-1), 1/(yu*yv)}, yw])/64 + 
     (G[{1, 1/(yu*yv)}, yw]*G[{0, yu^(-1), 1/(yu*yv)}, yw])/64 - 
     (G[{yu^(-1), 1/(yu*yv)}, yw]*G[{0, yu^(-1), 1/(yu*yv)}, yw])/32 + 
     (5*G[{yv^(-1), 1/(yu*yv)}, yw]*G[{0, yu^(-1), 1/(yu*yv)}, yw])/64 + 
     (Pi^2*G[{0, yu, 1}, yv^(-1)])/48 + 
     (3*G[{0}, yu^(-1)]^2*G[{0, yu, 1}, yv^(-1)])/32 + 
     (3*G[{0}, yu^(-1)]*G[{0}, yv^(-1)]*G[{0, yu, 1}, yv^(-1)])/16 + 
     (3*G[{0}, yv^(-1)]^2*G[{0, yu, 1}, yv^(-1)])/32 - 
     (3*G[{0}, yu^(-1)]*G[{0}, yw]*G[{0, yu, 1}, yv^(-1)])/16 - 
     (3*G[{0}, yv^(-1)]*G[{0}, yw]*G[{0, yu, 1}, yv^(-1)])/16 + 
     (3*G[{0}, yw]^2*G[{0, yu, 1}, yv^(-1)])/32 - 
     (G[{0}, yu^(-1)]*G[{1}, yu^(-1)]*G[{0, yu, 1}, yv^(-1)])/8 - 
     (G[{0}, yv^(-1)]*G[{1}, yu^(-1)]*G[{0, yu, 1}, yv^(-1)])/8 + 
     (G[{0}, yw]*G[{1}, yu^(-1)]*G[{0, yu, 1}, yv^(-1)])/8 + 
     (G[{1}, yu^(-1)]^2*G[{0, yu, 1}, yv^(-1)])/32 - 
     (3*G[{0}, yu^(-1)]*G[{1}, yv^(-1)]*G[{0, yu, 1}, yv^(-1)])/16 - 
     (3*G[{0}, yv^(-1)]*G[{1}, yv^(-1)]*G[{0, yu, 1}, yv^(-1)])/16 + 
     (3*G[{0}, yw]*G[{1}, yv^(-1)]*G[{0, yu, 1}, yv^(-1)])/16 + 
     (G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*G[{0, yu, 1}, yv^(-1)])/16 + 
     (G[{1}, yv^(-1)]^2*G[{0, yu, 1}, yv^(-1)])/32 + 
     (3*G[{0}, yu^(-1)]*G[{1}, yw]*G[{0, yu, 1}, yv^(-1)])/16 + 
     (3*G[{0}, yv^(-1)]*G[{1}, yw]*G[{0, yu, 1}, yv^(-1)])/16 - 
     (3*G[{0}, yw]*G[{1}, yw]*G[{0, yu, 1}, yv^(-1)])/16 - 
     (G[{1}, yu^(-1)]*G[{1}, yw]*G[{0, yu, 1}, yv^(-1)])/16 - 
     (G[{1}, yv^(-1)]*G[{1}, yw]*G[{0, yu, 1}, yv^(-1)])/16 + 
     (G[{1}, yw]^2*G[{0, yu, 1}, yv^(-1)])/32 + 
     (G[{1}, yw]*G[{yu}, yv^(-1)]*G[{0, yu, 1}, yv^(-1)])/16 + 
     (5*G[{0}, yu^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, yu, 1}, yv^(-1)])/16 + 
     (5*G[{0}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, yu, 1}, yv^(-1)])/16 - 
     (5*G[{0}, yw]*G[{1/(yu*yv)}, yw]*G[{0, yu, 1}, yv^(-1)])/16 - 
     (G[{1}, yu^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, yu, 1}, yv^(-1)])/4 - 
     (5*G[{1}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, yu, 1}, yv^(-1)])/16 + 
     (G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{0, yu, 1}, yv^(-1)])/16 + 
     (5*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{0, yu, 1}, yv^(-1)])/16 - 
     (G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, yu, 1}, yv^(-1)])/16 + 
     (G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{0, yu, 1}, yv^(-1)])/4 - 
     (G[{0, 1}, yu^(-1)]*G[{0, yu, 1}, yv^(-1)])/16 + 
     (G[{0, 1}, yv^(-1)]*G[{0, yu, 1}, yv^(-1)])/16 + 
     (G[{0, 1}, yw]*G[{0, yu, 1}, yv^(-1)])/8 - 
     (5*G[{0, yu^(-1)}, yw]*G[{0, yu, 1}, yv^(-1)])/16 - 
     (G[{0, yu}, yv^(-1)]*G[{0, yu, 1}, yv^(-1)])/16 - 
     (G[{0, yv^(-1)}, yw]*G[{0, yu, 1}, yv^(-1)])/8 + 
     (5*G[{0, 1/(yu*yv)}, yw]*G[{0, yu, 1}, yv^(-1)])/16 + 
     (5*G[{1, yu^(-1)}, yw]*G[{0, yu, 1}, yv^(-1)])/16 - 
     (G[{1, yu}, yv^(-1)]*G[{0, yu, 1}, yv^(-1)])/16 - 
     (G[{1, 1/(yu*yv)}, yw]*G[{0, yu, 1}, yv^(-1)])/16 - 
     (5*G[{yu^(-1), 1/(yu*yv)}, yw]*G[{0, yu, 1}, yv^(-1)])/16 - 
     (G[{yv^(-1), 1/(yu*yv)}, yw]*G[{0, yu, 1}, yv^(-1)])/4 - 
     (G[{1}, yw]*G[{yu}, yv^(-1)]*G[{0, yu, yu}, yv^(-1)])/8 - 
     (G[{0}, yu^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, yu, yu}, yv^(-1)])/4 - 
     (G[{0}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, yu, yu}, yv^(-1)])/4 + 
     (G[{0}, yw]*G[{1/(yu*yv)}, yw]*G[{0, yu, yu}, yv^(-1)])/4 + 
     (G[{1}, yu^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, yu, yu}, yv^(-1)])/4 + 
     (G[{1}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, yu, yu}, yv^(-1)])/4 - 
     (G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{0, yu, yu}, yv^(-1)])/8 - 
     (G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{0, yu, yu}, yv^(-1)])/4 + 
     (G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, yu, yu}, yv^(-1)])/8 - 
     (G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{0, yu, yu}, yv^(-1)])/4 + 
     (G[{0, yu^(-1)}, yw]*G[{0, yu, yu}, yv^(-1)])/4 - 
     (G[{0, 1/(yu*yv)}, yw]*G[{0, yu, yu}, yv^(-1)])/4 - 
     (G[{1, yu^(-1)}, yw]*G[{0, yu, yu}, yv^(-1)])/4 + 
     (G[{1, yu}, yv^(-1)]*G[{0, yu, yu}, yv^(-1)])/8 + 
     (G[{1, 1/(yu*yv)}, yw]*G[{0, yu, yu}, yv^(-1)])/8 + 
     (G[{yu^(-1), 1/(yu*yv)}, yw]*G[{0, yu, yu}, yv^(-1)])/4 + 
     (G[{yv^(-1), 1/(yu*yv)}, yw]*G[{0, yu, yu}, yv^(-1)])/4 - 
     (Pi^2*G[{0, yv^(-1), 1}, yw])/256 - 
     (3*G[{1}, yu^(-1)]^2*G[{0, yv^(-1), 1}, yw])/128 - 
     (5*G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*G[{0, yv^(-1), 1}, yw])/64 - 
     (G[{0}, yu^(-1)]*G[{1}, yw]*G[{0, yv^(-1), 1}, yw])/8 - 
     (G[{0}, yv^(-1)]*G[{1}, yw]*G[{0, yv^(-1), 1}, yw])/8 + 
     (G[{0}, yw]*G[{1}, yw]*G[{0, yv^(-1), 1}, yw])/8 + 
     (13*G[{1}, yu^(-1)]*G[{1}, yw]*G[{0, yv^(-1), 1}, yw])/64 + 
     (G[{1}, yv^(-1)]*G[{1}, yw]*G[{0, yv^(-1), 1}, yw])/8 + 
     (G[{1}, yw]^2*G[{0, yv^(-1), 1}, yw])/128 + 
     (G[{1}, yu^(-1)]*G[{yu}, yv^(-1)]*G[{0, yv^(-1), 1}, yw])/8 - 
     (5*G[{1}, yw]*G[{yu}, yv^(-1)]*G[{0, yv^(-1), 1}, yw])/64 - 
     (G[{yu}, yv^(-1)]^2*G[{0, yv^(-1), 1}, yw])/16 + 
     (G[{0}, yu^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, yv^(-1), 1}, yw])/16 + 
     (G[{0}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, yv^(-1), 1}, yw])/16 - 
     (G[{0}, yw]*G[{1/(yu*yv)}, yw]*G[{0, yv^(-1), 1}, yw])/16 - 
     (G[{1}, yu^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, yv^(-1), 1}, yw])/64 - 
     (G[{1}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, yv^(-1), 1}, yw])/8 - 
     (G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{0, yv^(-1), 1}, yw])/64 + 
     (G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{0, yv^(-1), 1}, yw])/32 + 
     (G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, yv^(-1), 1}, yw])/64 - 
     (5*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{0, yv^(-1), 1}, yw])/64 - 
     (5*G[{0, 1}, yu^(-1)]*G[{0, yv^(-1), 1}, yw])/64 + 
     (G[{0, 1}, yw]*G[{0, yv^(-1), 1}, yw])/64 - 
     (G[{0, yu^(-1)}, yw]*G[{0, yv^(-1), 1}, yw])/64 - 
     (G[{0, yv^(-1)}, yw]*G[{0, yv^(-1), 1}, yw])/64 - 
     (G[{0, 1/(yu*yv)}, yw]*G[{0, yv^(-1), 1}, yw])/32 + 
     (G[{1, yu^(-1)}, yw]*G[{0, yv^(-1), 1}, yw])/32 + 
     (5*G[{1, yu}, yv^(-1)]*G[{0, yv^(-1), 1}, yw])/64 + 
     (G[{1, yv^(-1)}, yw]*G[{0, yv^(-1), 1}, yw])/64 + 
     (G[{1, 1/(yu*yv)}, yw]*G[{0, yv^(-1), 1}, yw])/64 - 
     (G[{yu^(-1), 1/(yu*yv)}, yw]*G[{0, yv^(-1), 1}, yw])/32 + 
     (5*G[{yv^(-1), 1/(yu*yv)}, yw]*G[{0, yv^(-1), 1}, yw])/64 + 
     (3*Pi^2*G[{0, yv^(-1), yu^(-1)}, yw])/256 - 
     (3*G[{0}, yu^(-1)]^2*G[{0, yv^(-1), yu^(-1)}, yw])/64 - 
     (3*G[{0}, yu^(-1)]*G[{0}, yv^(-1)]*G[{0, yv^(-1), yu^(-1)}, yw])/32 - 
     (3*G[{0}, yv^(-1)]^2*G[{0, yv^(-1), yu^(-1)}, yw])/64 + 
     (3*G[{0}, yu^(-1)]*G[{0}, yw]*G[{0, yv^(-1), yu^(-1)}, yw])/32 + 
     (3*G[{0}, yv^(-1)]*G[{0}, yw]*G[{0, yv^(-1), yu^(-1)}, yw])/32 - 
     (3*G[{0}, yw]^2*G[{0, yv^(-1), yu^(-1)}, yw])/64 + 
     (7*G[{0}, yu^(-1)]*G[{1}, yu^(-1)]*G[{0, yv^(-1), yu^(-1)}, yw])/32 + 
     (7*G[{0}, yv^(-1)]*G[{1}, yu^(-1)]*G[{0, yv^(-1), yu^(-1)}, yw])/32 - 
     (7*G[{0}, yw]*G[{1}, yu^(-1)]*G[{0, yv^(-1), yu^(-1)}, yw])/32 - 
     (G[{1}, yu^(-1)]^2*G[{0, yv^(-1), yu^(-1)}, yw])/8 - 
     (G[{0}, yu^(-1)]*G[{1}, yv^(-1)]*G[{0, yv^(-1), yu^(-1)}, yw])/32 - 
     (G[{0}, yv^(-1)]*G[{1}, yv^(-1)]*G[{0, yv^(-1), yu^(-1)}, yw])/32 + 
     (G[{0}, yw]*G[{1}, yv^(-1)]*G[{0, yv^(-1), yu^(-1)}, yw])/32 - 
     (3*G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*G[{0, yv^(-1), yu^(-1)}, yw])/16 + 
     (5*G[{1}, yv^(-1)]^2*G[{0, yv^(-1), yu^(-1)}, yw])/64 + 
     (5*G[{0}, yu^(-1)]*G[{1}, yw]*G[{0, yv^(-1), yu^(-1)}, yw])/64 + 
     (5*G[{0}, yv^(-1)]*G[{1}, yw]*G[{0, yv^(-1), yu^(-1)}, yw])/64 - 
     (5*G[{0}, yw]*G[{1}, yw]*G[{0, yv^(-1), yu^(-1)}, yw])/64 - 
     (3*G[{1}, yu^(-1)]*G[{1}, yw]*G[{0, yv^(-1), yu^(-1)}, yw])/64 - 
     (9*G[{1}, yv^(-1)]*G[{1}, yw]*G[{0, yv^(-1), yu^(-1)}, yw])/64 + 
     (G[{1}, yw]^2*G[{0, yv^(-1), yu^(-1)}, yw])/8 + 
     (G[{1}, yw]*G[{yu}, yv^(-1)]*G[{0, yv^(-1), yu^(-1)}, yw])/32 - 
     (11*G[{0}, yu^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, yv^(-1), yu^(-1)}, yw])/
      64 - (11*G[{0}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, yv^(-1), yu^(-1)}, 
        yw])/64 + (11*G[{0}, yw]*G[{1/(yu*yv)}, yw]*G[{0, yv^(-1), yu^(-1)}, 
        yw])/64 + (17*G[{1}, yu^(-1)]*G[{1/(yu*yv)}, yw]*
       G[{0, yv^(-1), yu^(-1)}, yw])/64 + 
     (7*G[{1}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, yv^(-1), yu^(-1)}, yw])/64 - 
     (G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{0, yv^(-1), yu^(-1)}, yw])/16 + 
     (G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{0, yv^(-1), yu^(-1)}, yw])/16 - 
     (G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, yv^(-1), yu^(-1)}, yw])/32 - 
     (3*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{0, yv^(-1), yu^(-1)}, yw])/
      32 - (3*G[{1/(yu*yv)}, yw]^2*G[{0, yv^(-1), yu^(-1)}, yw])/64 + 
     (G[{0, 1}, yu^(-1)]*G[{0, yv^(-1), yu^(-1)}, yw])/32 + 
     (G[{0, 1}, yv^(-1)]*G[{0, yv^(-1), yu^(-1)}, yw])/8 - 
     (G[{0, yu}, yv^(-1)]*G[{0, yv^(-1), yu^(-1)}, yw])/8 + 
     (G[{1, yu^(-1)}, yw]*G[{0, yv^(-1), yu^(-1)}, yw])/16 + 
     (3*G[{1, yu}, yv^(-1)]*G[{0, yv^(-1), yu^(-1)}, yw])/32 - 
     (G[{1, yv^(-1)}, yw]*G[{0, yv^(-1), yu^(-1)}, yw])/32 - 
     (G[{1, 1/(yu*yv)}, yw]*G[{0, yv^(-1), yu^(-1)}, yw])/32 - 
     (G[{yu^(-1), 1/(yu*yv)}, yw]*G[{0, yv^(-1), yu^(-1)}, yw])/16 + 
     (3*G[{yv^(-1), 1/(yu*yv)}, yw]*G[{0, yv^(-1), yu^(-1)}, yw])/32 - 
     (7*Pi^2*G[{0, yv^(-1), yv^(-1)}, yw])/768 - 
     (3*G[{0}, yu^(-1)]^2*G[{0, yv^(-1), yv^(-1)}, yw])/64 - 
     (3*G[{0}, yu^(-1)]*G[{0}, yv^(-1)]*G[{0, yv^(-1), yv^(-1)}, yw])/32 - 
     (3*G[{0}, yv^(-1)]^2*G[{0, yv^(-1), yv^(-1)}, yw])/64 + 
     (3*G[{0}, yu^(-1)]*G[{0}, yw]*G[{0, yv^(-1), yv^(-1)}, yw])/32 + 
     (3*G[{0}, yv^(-1)]*G[{0}, yw]*G[{0, yv^(-1), yv^(-1)}, yw])/32 - 
     (3*G[{0}, yw]^2*G[{0, yv^(-1), yv^(-1)}, yw])/64 + 
     (3*G[{0}, yu^(-1)]*G[{1}, yu^(-1)]*G[{0, yv^(-1), yv^(-1)}, yw])/32 + 
     (3*G[{0}, yv^(-1)]*G[{1}, yu^(-1)]*G[{0, yv^(-1), yv^(-1)}, yw])/32 - 
     (3*G[{0}, yw]*G[{1}, yu^(-1)]*G[{0, yv^(-1), yv^(-1)}, yw])/32 + 
     (3*G[{0}, yu^(-1)]*G[{1}, yv^(-1)]*G[{0, yv^(-1), yv^(-1)}, yw])/32 + 
     (3*G[{0}, yv^(-1)]*G[{1}, yv^(-1)]*G[{0, yv^(-1), yv^(-1)}, yw])/32 - 
     (3*G[{0}, yw]*G[{1}, yv^(-1)]*G[{0, yv^(-1), yv^(-1)}, yw])/32 - 
     (3*G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*G[{0, yv^(-1), yv^(-1)}, yw])/16 - 
     (3*G[{1}, yv^(-1)]^2*G[{0, yv^(-1), yv^(-1)}, yw])/64 + 
     (9*G[{0}, yu^(-1)]*G[{1}, yw]*G[{0, yv^(-1), yv^(-1)}, yw])/64 + 
     (9*G[{0}, yv^(-1)]*G[{1}, yw]*G[{0, yv^(-1), yv^(-1)}, yw])/64 - 
     (9*G[{0}, yw]*G[{1}, yw]*G[{0, yv^(-1), yv^(-1)}, yw])/64 - 
     (11*G[{1}, yu^(-1)]*G[{1}, yw]*G[{0, yv^(-1), yv^(-1)}, yw])/64 - 
     (9*G[{1}, yv^(-1)]*G[{1}, yw]*G[{0, yv^(-1), yv^(-1)}, yw])/64 + 
     (G[{1}, yw]^2*G[{0, yv^(-1), yv^(-1)}, yw])/8 + 
     (G[{1}, yw]*G[{yu}, yv^(-1)]*G[{0, yv^(-1), yv^(-1)}, yw])/32 - 
     (7*G[{0}, yu^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, yv^(-1), yv^(-1)}, yw])/64 - 
     (7*G[{0}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, yv^(-1), yv^(-1)}, yw])/64 + 
     (7*G[{0}, yw]*G[{1/(yu*yv)}, yw]*G[{0, yv^(-1), yv^(-1)}, yw])/64 + 
     (9*G[{1}, yu^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, yv^(-1), yv^(-1)}, yw])/64 + 
     (7*G[{1}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, yv^(-1), yv^(-1)}, yw])/64 - 
     (G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{0, yv^(-1), yv^(-1)}, yw])/16 + 
     (G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{0, yv^(-1), yv^(-1)}, yw])/16 - 
     (G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, yv^(-1), yv^(-1)}, yw])/32 - 
     (3*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{0, yv^(-1), yv^(-1)}, yw])/
      32 - (3*G[{1/(yu*yv)}, yw]^2*G[{0, yv^(-1), yv^(-1)}, yw])/64 - 
     (3*G[{0, 1}, yu^(-1)]*G[{0, yv^(-1), yv^(-1)}, yw])/32 + 
     (G[{0, 1}, yw]*G[{0, yv^(-1), yv^(-1)}, yw])/8 - 
     (G[{0, yu^(-1)}, yw]*G[{0, yv^(-1), yv^(-1)}, yw])/8 - 
     (G[{0, yv^(-1)}, yw]*G[{0, yv^(-1), yv^(-1)}, yw])/8 - 
     (G[{0, 1/(yu*yv)}, yw]*G[{0, yv^(-1), yv^(-1)}, yw])/16 + 
     (G[{1, yu^(-1)}, yw]*G[{0, yv^(-1), yv^(-1)}, yw])/16 + 
     (3*G[{1, yu}, yv^(-1)]*G[{0, yv^(-1), yv^(-1)}, yw])/32 - 
     (G[{1, yv^(-1)}, yw]*G[{0, yv^(-1), yv^(-1)}, yw])/32 - 
     (G[{1, 1/(yu*yv)}, yw]*G[{0, yv^(-1), yv^(-1)}, yw])/32 - 
     (G[{yu^(-1), 1/(yu*yv)}, yw]*G[{0, yv^(-1), yv^(-1)}, yw])/16 + 
     (3*G[{yv^(-1), 1/(yu*yv)}, yw]*G[{0, yv^(-1), yv^(-1)}, yw])/32 + 
     (13*Pi^2*G[{0, yv^(-1), 1/(yu*yv)}, yw])/768 + 
     (3*G[{0}, yu^(-1)]^2*G[{0, yv^(-1), 1/(yu*yv)}, yw])/32 + 
     (3*G[{0}, yu^(-1)]*G[{0}, yv^(-1)]*G[{0, yv^(-1), 1/(yu*yv)}, yw])/16 + 
     (3*G[{0}, yv^(-1)]^2*G[{0, yv^(-1), 1/(yu*yv)}, yw])/32 - 
     (3*G[{0}, yu^(-1)]*G[{0}, yw]*G[{0, yv^(-1), 1/(yu*yv)}, yw])/16 - 
     (3*G[{0}, yv^(-1)]*G[{0}, yw]*G[{0, yv^(-1), 1/(yu*yv)}, yw])/16 + 
     (3*G[{0}, yw]^2*G[{0, yv^(-1), 1/(yu*yv)}, yw])/32 - 
     (G[{0}, yu^(-1)]*G[{1}, yu^(-1)]*G[{0, yv^(-1), 1/(yu*yv)}, yw])/4 - 
     (G[{0}, yv^(-1)]*G[{1}, yu^(-1)]*G[{0, yv^(-1), 1/(yu*yv)}, yw])/4 + 
     (G[{0}, yw]*G[{1}, yu^(-1)]*G[{0, yv^(-1), 1/(yu*yv)}, yw])/4 + 
     (17*G[{1}, yu^(-1)]^2*G[{0, yv^(-1), 1/(yu*yv)}, yw])/128 - 
     (G[{0}, yu^(-1)]*G[{1}, yv^(-1)]*G[{0, yv^(-1), 1/(yu*yv)}, yw])/8 - 
     (G[{0}, yv^(-1)]*G[{1}, yv^(-1)]*G[{0, yv^(-1), 1/(yu*yv)}, yw])/8 + 
     (G[{0}, yw]*G[{1}, yv^(-1)]*G[{0, yv^(-1), 1/(yu*yv)}, yw])/8 + 
     (23*G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*G[{0, yv^(-1), 1/(yu*yv)}, yw])/64 + 
     (G[{0}, yu^(-1)]*G[{1}, yw]*G[{0, yv^(-1), 1/(yu*yv)}, yw])/16 + 
     (G[{0}, yv^(-1)]*G[{1}, yw]*G[{0, yv^(-1), 1/(yu*yv)}, yw])/16 - 
     (G[{0}, yw]*G[{1}, yw]*G[{0, yv^(-1), 1/(yu*yv)}, yw])/16 - 
     (3*G[{1}, yu^(-1)]*G[{1}, yw]*G[{0, yv^(-1), 1/(yu*yv)}, yw])/64 - 
     (G[{1}, yv^(-1)]*G[{1}, yw]*G[{0, yv^(-1), 1/(yu*yv)}, yw])/8 + 
     (G[{1}, yw]^2*G[{0, yv^(-1), 1/(yu*yv)}, yw])/128 - 
     (G[{1}, yu^(-1)]*G[{yu}, yv^(-1)]*G[{0, yv^(-1), 1/(yu*yv)}, yw])/8 + 
     (3*G[{1}, yw]*G[{yu}, yv^(-1)]*G[{0, yv^(-1), 1/(yu*yv)}, yw])/64 + 
     (G[{yu}, yv^(-1)]^2*G[{0, yv^(-1), 1/(yu*yv)}, yw])/16 + 
     (G[{0}, yu^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, yv^(-1), 1/(yu*yv)}, yw])/16 + 
     (G[{0}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, yv^(-1), 1/(yu*yv)}, yw])/16 - 
     (G[{0}, yw]*G[{1/(yu*yv)}, yw]*G[{0, yv^(-1), 1/(yu*yv)}, yw])/16 - 
     (G[{1}, yu^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, yv^(-1), 1/(yu*yv)}, yw])/64 - 
     (G[{1}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, yv^(-1), 1/(yu*yv)}, yw])/8 - 
     (G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{0, yv^(-1), 1/(yu*yv)}, yw])/64 + 
     (G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{0, yv^(-1), 1/(yu*yv)}, yw])/
      32 + (G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, yv^(-1), 1/(yu*yv)}, 
        yw])/64 - (5*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*
       G[{0, yv^(-1), 1/(yu*yv)}, yw])/64 + 
     (7*G[{0, 1}, yu^(-1)]*G[{0, yv^(-1), 1/(yu*yv)}, yw])/64 + 
     (G[{0, 1}, yw]*G[{0, yv^(-1), 1/(yu*yv)}, yw])/64 - 
     (G[{0, yu^(-1)}, yw]*G[{0, yv^(-1), 1/(yu*yv)}, yw])/64 - 
     (G[{0, yv^(-1)}, yw]*G[{0, yv^(-1), 1/(yu*yv)}, yw])/64 - 
     (G[{0, 1/(yu*yv)}, yw]*G[{0, yv^(-1), 1/(yu*yv)}, yw])/32 + 
     (G[{1, yu^(-1)}, yw]*G[{0, yv^(-1), 1/(yu*yv)}, yw])/32 - 
     (7*G[{1, yu}, yv^(-1)]*G[{0, yv^(-1), 1/(yu*yv)}, yw])/64 + 
     (G[{1, yv^(-1)}, yw]*G[{0, yv^(-1), 1/(yu*yv)}, yw])/64 + 
     (G[{1, 1/(yu*yv)}, yw]*G[{0, yv^(-1), 1/(yu*yv)}, yw])/64 - 
     (G[{yu^(-1), 1/(yu*yv)}, yw]*G[{0, yv^(-1), 1/(yu*yv)}, yw])/32 + 
     (5*G[{yv^(-1), 1/(yu*yv)}, yw]*G[{0, yv^(-1), 1/(yu*yv)}, yw])/64 + 
     (11*Pi^2*G[{0, 1/(yu*yv), 1}, yw])/768 + 
     (3*G[{0}, yu^(-1)]^2*G[{0, 1/(yu*yv), 1}, yw])/32 + 
     (3*G[{0}, yu^(-1)]*G[{0}, yv^(-1)]*G[{0, 1/(yu*yv), 1}, yw])/16 + 
     (3*G[{0}, yv^(-1)]^2*G[{0, 1/(yu*yv), 1}, yw])/32 - 
     (3*G[{0}, yu^(-1)]*G[{0}, yw]*G[{0, 1/(yu*yv), 1}, yw])/16 - 
     (3*G[{0}, yv^(-1)]*G[{0}, yw]*G[{0, 1/(yu*yv), 1}, yw])/16 + 
     (3*G[{0}, yw]^2*G[{0, 1/(yu*yv), 1}, yw])/32 - 
     (G[{0}, yu^(-1)]*G[{1}, yu^(-1)]*G[{0, 1/(yu*yv), 1}, yw])/16 - 
     (G[{0}, yv^(-1)]*G[{1}, yu^(-1)]*G[{0, 1/(yu*yv), 1}, yw])/16 + 
     (G[{0}, yw]*G[{1}, yu^(-1)]*G[{0, 1/(yu*yv), 1}, yw])/16 - 
     (G[{1}, yu^(-1)]^2*G[{0, 1/(yu*yv), 1}, yw])/128 - 
     (3*G[{0}, yu^(-1)]*G[{1}, yv^(-1)]*G[{0, 1/(yu*yv), 1}, yw])/16 - 
     (3*G[{0}, yv^(-1)]*G[{1}, yv^(-1)]*G[{0, 1/(yu*yv), 1}, yw])/16 + 
     (3*G[{0}, yw]*G[{1}, yv^(-1)]*G[{0, 1/(yu*yv), 1}, yw])/16 + 
     (G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*G[{0, 1/(yu*yv), 1}, yw])/64 + 
     (G[{1}, yv^(-1)]^2*G[{0, 1/(yu*yv), 1}, yw])/8 + 
     (3*G[{0}, yu^(-1)]*G[{1}, yw]*G[{0, 1/(yu*yv), 1}, yw])/16 + 
     (3*G[{0}, yv^(-1)]*G[{1}, yw]*G[{0, 1/(yu*yv), 1}, yw])/16 - 
     (3*G[{0}, yw]*G[{1}, yw]*G[{0, 1/(yu*yv), 1}, yw])/16 - 
     (13*G[{1}, yu^(-1)]*G[{1}, yw]*G[{0, 1/(yu*yv), 1}, yw])/64 - 
     (G[{1}, yv^(-1)]*G[{1}, yw]*G[{0, 1/(yu*yv), 1}, yw])/8 - 
     (G[{1}, yw]^2*G[{0, 1/(yu*yv), 1}, yw])/128 - 
     (G[{0}, yu^(-1)]*G[{yu}, yv^(-1)]*G[{0, 1/(yu*yv), 1}, yw])/8 - 
     (G[{0}, yv^(-1)]*G[{yu}, yv^(-1)]*G[{0, 1/(yu*yv), 1}, yw])/8 + 
     (G[{0}, yw]*G[{yu}, yv^(-1)]*G[{0, 1/(yu*yv), 1}, yw])/8 + 
     (G[{1}, yu^(-1)]*G[{yu}, yv^(-1)]*G[{0, 1/(yu*yv), 1}, yw])/8 - 
     (3*G[{1}, yw]*G[{yu}, yv^(-1)]*G[{0, 1/(yu*yv), 1}, yw])/64 + 
     (G[{yu}, yv^(-1)]^2*G[{0, 1/(yu*yv), 1}, yw])/16 + 
     (G[{1}, yu^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv), 1}, yw])/64 + 
     (G[{1}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv), 1}, yw])/8 + 
     (G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv), 1}, yw])/64 - 
     (G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv), 1}, yw])/32 - 
     (9*G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv), 1}, yw])/64 + 
     (5*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv), 1}, yw])/64 - 
     (3*G[{0, 1}, yu^(-1)]*G[{0, 1/(yu*yv), 1}, yw])/64 + 
     (G[{0, 1}, yv^(-1)]*G[{0, 1/(yu*yv), 1}, yw])/16 + 
     (3*G[{0, 1}, yw]*G[{0, 1/(yu*yv), 1}, yw])/64 - 
     (3*G[{0, yu^(-1)}, yw]*G[{0, 1/(yu*yv), 1}, yw])/64 - 
     (G[{0, yu}, yv^(-1)]*G[{0, 1/(yu*yv), 1}, yw])/16 - 
     (3*G[{0, yv^(-1)}, yw]*G[{0, 1/(yu*yv), 1}, yw])/64 + 
     (3*G[{0, 1/(yu*yv)}, yw]*G[{0, 1/(yu*yv), 1}, yw])/64 - 
     (G[{1, yu^(-1)}, yw]*G[{0, 1/(yu*yv), 1}, yw])/32 + 
     (7*G[{1, yu}, yv^(-1)]*G[{0, 1/(yu*yv), 1}, yw])/64 - 
     (G[{1, yv^(-1)}, yw]*G[{0, 1/(yu*yv), 1}, yw])/64 - 
     (G[{1, 1/(yu*yv)}, yw]*G[{0, 1/(yu*yv), 1}, yw])/64 + 
     (G[{yu^(-1), 1/(yu*yv)}, yw]*G[{0, 1/(yu*yv), 1}, yw])/32 - 
     (5*G[{yv^(-1), 1/(yu*yv)}, yw]*G[{0, 1/(yu*yv), 1}, yw])/64 - 
     (11*Pi^2*G[{0, 1/(yu*yv), yu^(-1)}, yw])/256 - 
     (3*G[{0}, yu^(-1)]^2*G[{0, 1/(yu*yv), yu^(-1)}, yw])/64 - 
     (3*G[{0}, yu^(-1)]*G[{0}, yv^(-1)]*G[{0, 1/(yu*yv), yu^(-1)}, yw])/32 - 
     (3*G[{0}, yv^(-1)]^2*G[{0, 1/(yu*yv), yu^(-1)}, yw])/64 + 
     (3*G[{0}, yu^(-1)]*G[{0}, yw]*G[{0, 1/(yu*yv), yu^(-1)}, yw])/32 + 
     (3*G[{0}, yv^(-1)]*G[{0}, yw]*G[{0, 1/(yu*yv), yu^(-1)}, yw])/32 - 
     (3*G[{0}, yw]^2*G[{0, 1/(yu*yv), yu^(-1)}, yw])/64 - 
     (5*G[{0}, yu^(-1)]*G[{1}, yu^(-1)]*G[{0, 1/(yu*yv), yu^(-1)}, yw])/32 - 
     (5*G[{0}, yv^(-1)]*G[{1}, yu^(-1)]*G[{0, 1/(yu*yv), yu^(-1)}, yw])/32 + 
     (5*G[{0}, yw]*G[{1}, yu^(-1)]*G[{0, 1/(yu*yv), yu^(-1)}, yw])/32 + 
     (5*G[{1}, yu^(-1)]^2*G[{0, 1/(yu*yv), yu^(-1)}, yw])/32 + 
     (11*G[{0}, yu^(-1)]*G[{1}, yv^(-1)]*G[{0, 1/(yu*yv), yu^(-1)}, yw])/32 + 
     (11*G[{0}, yv^(-1)]*G[{1}, yv^(-1)]*G[{0, 1/(yu*yv), yu^(-1)}, yw])/32 - 
     (11*G[{0}, yw]*G[{1}, yv^(-1)]*G[{0, 1/(yu*yv), yu^(-1)}, yw])/32 - 
     (17*G[{1}, yv^(-1)]^2*G[{0, 1/(yu*yv), yu^(-1)}, yw])/64 - 
     (9*G[{0}, yu^(-1)]*G[{1}, yw]*G[{0, 1/(yu*yv), yu^(-1)}, yw])/64 - 
     (9*G[{0}, yv^(-1)]*G[{1}, yw]*G[{0, 1/(yu*yv), yu^(-1)}, yw])/64 + 
     (9*G[{0}, yw]*G[{1}, yw]*G[{0, 1/(yu*yv), yu^(-1)}, yw])/64 + 
     (3*G[{1}, yu^(-1)]*G[{1}, yw]*G[{0, 1/(yu*yv), yu^(-1)}, yw])/64 + 
     (17*G[{1}, yv^(-1)]*G[{1}, yw]*G[{0, 1/(yu*yv), yu^(-1)}, yw])/64 - 
     (G[{1}, yw]^2*G[{0, 1/(yu*yv), yu^(-1)}, yw])/8 - 
     (G[{1}, yw]*G[{yu}, yv^(-1)]*G[{0, 1/(yu*yv), yu^(-1)}, yw])/32 + 
     (7*G[{0}, yu^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv), yu^(-1)}, yw])/
      64 + (7*G[{0}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv), yu^(-1)}, 
        yw])/64 - (7*G[{0}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv), yu^(-1)}, 
        yw])/64 - (17*G[{1}, yu^(-1)]*G[{1/(yu*yv)}, yw]*
       G[{0, 1/(yu*yv), yu^(-1)}, yw])/64 + 
     (G[{1}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv), yu^(-1)}, yw])/64 + 
     (G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv), yu^(-1)}, yw])/16 - 
     (G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv), yu^(-1)}, yw])/
      16 + (G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv), yu^(-1)}, 
        yw])/32 + (3*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*
       G[{0, 1/(yu*yv), yu^(-1)}, yw])/32 + 
     (3*G[{1/(yu*yv)}, yw]^2*G[{0, 1/(yu*yv), yu^(-1)}, yw])/64 - 
     (G[{0, 1}, yu^(-1)]*G[{0, 1/(yu*yv), yu^(-1)}, yw])/32 - 
     (3*G[{0, 1}, yv^(-1)]*G[{0, 1/(yu*yv), yu^(-1)}, yw])/16 + 
     (G[{0, 1}, yw]*G[{0, 1/(yu*yv), yu^(-1)}, yw])/16 - 
     (G[{0, yu^(-1)}, yw]*G[{0, 1/(yu*yv), yu^(-1)}, yw])/16 + 
     (3*G[{0, yu}, yv^(-1)]*G[{0, 1/(yu*yv), yu^(-1)}, yw])/16 - 
     (G[{0, yv^(-1)}, yw]*G[{0, 1/(yu*yv), yu^(-1)}, yw])/16 + 
     (G[{0, 1/(yu*yv)}, yw]*G[{0, 1/(yu*yv), yu^(-1)}, yw])/16 - 
     (G[{1, yu^(-1)}, yw]*G[{0, 1/(yu*yv), yu^(-1)}, yw])/16 - 
     (5*G[{1, yu}, yv^(-1)]*G[{0, 1/(yu*yv), yu^(-1)}, yw])/32 + 
     (G[{1, yv^(-1)}, yw]*G[{0, 1/(yu*yv), yu^(-1)}, yw])/32 + 
     (G[{1, 1/(yu*yv)}, yw]*G[{0, 1/(yu*yv), yu^(-1)}, yw])/32 + 
     (G[{yu^(-1), 1/(yu*yv)}, yw]*G[{0, 1/(yu*yv), yu^(-1)}, yw])/16 - 
     (3*G[{yv^(-1), 1/(yu*yv)}, yw]*G[{0, 1/(yu*yv), yu^(-1)}, yw])/32 + 
     (7*Pi^2*G[{0, 1/(yu*yv), yv^(-1)}, yw])/768 + 
     (3*G[{0}, yu^(-1)]^2*G[{0, 1/(yu*yv), yv^(-1)}, yw])/64 + 
     (3*G[{0}, yu^(-1)]*G[{0}, yv^(-1)]*G[{0, 1/(yu*yv), yv^(-1)}, yw])/32 + 
     (3*G[{0}, yv^(-1)]^2*G[{0, 1/(yu*yv), yv^(-1)}, yw])/64 - 
     (3*G[{0}, yu^(-1)]*G[{0}, yw]*G[{0, 1/(yu*yv), yv^(-1)}, yw])/32 - 
     (3*G[{0}, yv^(-1)]*G[{0}, yw]*G[{0, 1/(yu*yv), yv^(-1)}, yw])/32 + 
     (3*G[{0}, yw]^2*G[{0, 1/(yu*yv), yv^(-1)}, yw])/64 - 
     (3*G[{0}, yu^(-1)]*G[{1}, yu^(-1)]*G[{0, 1/(yu*yv), yv^(-1)}, yw])/32 - 
     (3*G[{0}, yv^(-1)]*G[{1}, yu^(-1)]*G[{0, 1/(yu*yv), yv^(-1)}, yw])/32 + 
     (3*G[{0}, yw]*G[{1}, yu^(-1)]*G[{0, 1/(yu*yv), yv^(-1)}, yw])/32 + 
     (G[{0}, yu^(-1)]*G[{1}, yv^(-1)]*G[{0, 1/(yu*yv), yv^(-1)}, yw])/32 + 
     (G[{0}, yv^(-1)]*G[{1}, yv^(-1)]*G[{0, 1/(yu*yv), yv^(-1)}, yw])/32 - 
     (G[{0}, yw]*G[{1}, yv^(-1)]*G[{0, 1/(yu*yv), yv^(-1)}, yw])/32 + 
     (3*G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*G[{0, 1/(yu*yv), yv^(-1)}, yw])/16 - 
     (5*G[{1}, yv^(-1)]^2*G[{0, 1/(yu*yv), yv^(-1)}, yw])/64 - 
     (5*G[{0}, yu^(-1)]*G[{1}, yw]*G[{0, 1/(yu*yv), yv^(-1)}, yw])/64 - 
     (5*G[{0}, yv^(-1)]*G[{1}, yw]*G[{0, 1/(yu*yv), yv^(-1)}, yw])/64 + 
     (5*G[{0}, yw]*G[{1}, yw]*G[{0, 1/(yu*yv), yv^(-1)}, yw])/64 + 
     (3*G[{1}, yu^(-1)]*G[{1}, yw]*G[{0, 1/(yu*yv), yv^(-1)}, yw])/64 + 
     (9*G[{1}, yv^(-1)]*G[{1}, yw]*G[{0, 1/(yu*yv), yv^(-1)}, yw])/64 - 
     (G[{1}, yw]^2*G[{0, 1/(yu*yv), yv^(-1)}, yw])/8 - 
     (G[{0}, yu^(-1)]*G[{yu}, yv^(-1)]*G[{0, 1/(yu*yv), yv^(-1)}, yw])/8 - 
     (G[{0}, yv^(-1)]*G[{yu}, yv^(-1)]*G[{0, 1/(yu*yv), yv^(-1)}, yw])/8 + 
     (G[{0}, yw]*G[{yu}, yv^(-1)]*G[{0, 1/(yu*yv), yv^(-1)}, yw])/8 - 
     (G[{1}, yw]*G[{yu}, yv^(-1)]*G[{0, 1/(yu*yv), yv^(-1)}, yw])/32 + 
     (G[{yu}, yv^(-1)]^2*G[{0, 1/(yu*yv), yv^(-1)}, yw])/8 + 
     (7*G[{0}, yu^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv), yv^(-1)}, yw])/
      64 + (7*G[{0}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv), yv^(-1)}, 
        yw])/64 - (7*G[{0}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv), yv^(-1)}, 
        yw])/64 - (9*G[{1}, yu^(-1)]*G[{1/(yu*yv)}, yw]*
       G[{0, 1/(yu*yv), yv^(-1)}, yw])/64 - 
     (7*G[{1}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv), yv^(-1)}, yw])/
      64 + (G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv), yv^(-1)}, yw])/
      16 - (G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv), yv^(-1)}, 
        yw])/16 + (G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw]*
       G[{0, 1/(yu*yv), yv^(-1)}, yw])/32 + 
     (3*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv), yv^(-1)}, yw])/
      32 + (3*G[{1/(yu*yv)}, yw]^2*G[{0, 1/(yu*yv), yv^(-1)}, yw])/64 + 
     (3*G[{0, 1}, yu^(-1)]*G[{0, 1/(yu*yv), yv^(-1)}, yw])/32 - 
     (G[{0, 1}, yw]*G[{0, 1/(yu*yv), yv^(-1)}, yw])/8 + 
     (G[{0, yu^(-1)}, yw]*G[{0, 1/(yu*yv), yv^(-1)}, yw])/8 + 
     (G[{0, yv^(-1)}, yw]*G[{0, 1/(yu*yv), yv^(-1)}, yw])/8 - 
     (G[{0, 1/(yu*yv)}, yw]*G[{0, 1/(yu*yv), yv^(-1)}, yw])/8 - 
     (G[{1, yu^(-1)}, yw]*G[{0, 1/(yu*yv), yv^(-1)}, yw])/16 - 
     (3*G[{1, yu}, yv^(-1)]*G[{0, 1/(yu*yv), yv^(-1)}, yw])/32 + 
     (G[{1, yv^(-1)}, yw]*G[{0, 1/(yu*yv), yv^(-1)}, yw])/32 + 
     (G[{1, 1/(yu*yv)}, yw]*G[{0, 1/(yu*yv), yv^(-1)}, yw])/32 + 
     (G[{yu^(-1), 1/(yu*yv)}, yw]*G[{0, 1/(yu*yv), yv^(-1)}, yw])/16 - 
     (3*G[{yv^(-1), 1/(yu*yv)}, yw]*G[{0, 1/(yu*yv), yv^(-1)}, yw])/32 - 
     (13*Pi^2*G[{0, 1/(yu*yv), 1/(yu*yv)}, yw])/768 - 
     (3*G[{0}, yu^(-1)]^2*G[{0, 1/(yu*yv), 1/(yu*yv)}, yw])/32 - 
     (3*G[{0}, yu^(-1)]*G[{0}, yv^(-1)]*G[{0, 1/(yu*yv), 1/(yu*yv)}, yw])/
      16 - (3*G[{0}, yv^(-1)]^2*G[{0, 1/(yu*yv), 1/(yu*yv)}, yw])/32 + 
     (3*G[{0}, yu^(-1)]*G[{0}, yw]*G[{0, 1/(yu*yv), 1/(yu*yv)}, yw])/16 + 
     (3*G[{0}, yv^(-1)]*G[{0}, yw]*G[{0, 1/(yu*yv), 1/(yu*yv)}, yw])/16 - 
     (3*G[{0}, yw]^2*G[{0, 1/(yu*yv), 1/(yu*yv)}, yw])/32 + 
     (G[{0}, yu^(-1)]*G[{1}, yu^(-1)]*G[{0, 1/(yu*yv), 1/(yu*yv)}, yw])/4 + 
     (G[{0}, yv^(-1)]*G[{1}, yu^(-1)]*G[{0, 1/(yu*yv), 1/(yu*yv)}, yw])/4 - 
     (G[{0}, yw]*G[{1}, yu^(-1)]*G[{0, 1/(yu*yv), 1/(yu*yv)}, yw])/4 - 
     (17*G[{1}, yu^(-1)]^2*G[{0, 1/(yu*yv), 1/(yu*yv)}, yw])/128 + 
     (G[{0}, yu^(-1)]*G[{1}, yv^(-1)]*G[{0, 1/(yu*yv), 1/(yu*yv)}, yw])/16 + 
     (G[{0}, yv^(-1)]*G[{1}, yv^(-1)]*G[{0, 1/(yu*yv), 1/(yu*yv)}, yw])/16 - 
     (G[{0}, yw]*G[{1}, yv^(-1)]*G[{0, 1/(yu*yv), 1/(yu*yv)}, yw])/16 - 
     (23*G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*G[{0, 1/(yu*yv), 1/(yu*yv)}, yw])/
      64 + (G[{1}, yv^(-1)]^2*G[{0, 1/(yu*yv), 1/(yu*yv)}, yw])/16 - 
     (G[{0}, yu^(-1)]*G[{1}, yw]*G[{0, 1/(yu*yv), 1/(yu*yv)}, yw])/8 - 
     (G[{0}, yv^(-1)]*G[{1}, yw]*G[{0, 1/(yu*yv), 1/(yu*yv)}, yw])/8 + 
     (G[{0}, yw]*G[{1}, yw]*G[{0, 1/(yu*yv), 1/(yu*yv)}, yw])/8 + 
     (11*G[{1}, yu^(-1)]*G[{1}, yw]*G[{0, 1/(yu*yv), 1/(yu*yv)}, yw])/64 + 
     (G[{1}, yv^(-1)]*G[{1}, yw]*G[{0, 1/(yu*yv), 1/(yu*yv)}, yw])/4 - 
     (G[{1}, yw]^2*G[{0, 1/(yu*yv), 1/(yu*yv)}, yw])/128 + 
     (G[{0}, yu^(-1)]*G[{yu}, yv^(-1)]*G[{0, 1/(yu*yv), 1/(yu*yv)}, yw])/16 + 
     (G[{0}, yv^(-1)]*G[{yu}, yv^(-1)]*G[{0, 1/(yu*yv), 1/(yu*yv)}, yw])/16 - 
     (G[{0}, yw]*G[{yu}, yv^(-1)]*G[{0, 1/(yu*yv), 1/(yu*yv)}, yw])/16 + 
     (G[{1}, yu^(-1)]*G[{yu}, yv^(-1)]*G[{0, 1/(yu*yv), 1/(yu*yv)}, yw])/8 - 
     (11*G[{1}, yw]*G[{yu}, yv^(-1)]*G[{0, 1/(yu*yv), 1/(yu*yv)}, yw])/64 - 
     (G[{yu}, yv^(-1)]^2*G[{0, 1/(yu*yv), 1/(yu*yv)}, yw])/8 - 
     (G[{0}, yu^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv), 1/(yu*yv)}, yw])/
      16 - (G[{0}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv), 1/(yu*yv)}, 
        yw])/16 + (G[{0}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv), 1/(yu*yv)}, 
        yw])/16 + (G[{1}, yu^(-1)]*G[{1/(yu*yv)}, yw]*
       G[{0, 1/(yu*yv), 1/(yu*yv)}, yw])/64 + 
     (G[{1}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv), 1/(yu*yv)}, yw])/
      8 + (G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv), 1/(yu*yv)}, yw])/
      64 - (G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv), 1/(yu*yv)}, 
        yw])/32 - (G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw]*
       G[{0, 1/(yu*yv), 1/(yu*yv)}, yw])/64 + 
     (5*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv), 1/(yu*yv)}, yw])/
      64 - (7*G[{0, 1}, yu^(-1)]*G[{0, 1/(yu*yv), 1/(yu*yv)}, yw])/64 - 
     (G[{0, 1}, yw]*G[{0, 1/(yu*yv), 1/(yu*yv)}, yw])/64 + 
     (G[{0, yu^(-1)}, yw]*G[{0, 1/(yu*yv), 1/(yu*yv)}, yw])/64 + 
     (G[{0, yv^(-1)}, yw]*G[{0, 1/(yu*yv), 1/(yu*yv)}, yw])/64 - 
     (G[{0, 1/(yu*yv)}, yw]*G[{0, 1/(yu*yv), 1/(yu*yv)}, yw])/64 - 
     (G[{1, yu^(-1)}, yw]*G[{0, 1/(yu*yv), 1/(yu*yv)}, yw])/32 + 
     (7*G[{1, yu}, yv^(-1)]*G[{0, 1/(yu*yv), 1/(yu*yv)}, yw])/64 - 
     (G[{1, yv^(-1)}, yw]*G[{0, 1/(yu*yv), 1/(yu*yv)}, yw])/64 - 
     (G[{1, 1/(yu*yv)}, yw]*G[{0, 1/(yu*yv), 1/(yu*yv)}, yw])/64 + 
     (G[{yu^(-1), 1/(yu*yv)}, yw]*G[{0, 1/(yu*yv), 1/(yu*yv)}, yw])/32 - 
     (5*G[{yv^(-1), 1/(yu*yv)}, yw]*G[{0, 1/(yu*yv), 1/(yu*yv)}, yw])/64 - 
     (43*Pi^2*G[{1, 1, yu^(-1)}, yw])/768 - 
     (3*G[{0}, yu^(-1)]^2*G[{1, 1, yu^(-1)}, yw])/16 - 
     (3*G[{0}, yu^(-1)]*G[{0}, yv^(-1)]*G[{1, 1, yu^(-1)}, yw])/8 - 
     (3*G[{0}, yv^(-1)]^2*G[{1, 1, yu^(-1)}, yw])/16 + 
     (3*G[{0}, yu^(-1)]*G[{0}, yw]*G[{1, 1, yu^(-1)}, yw])/8 + 
     (3*G[{0}, yv^(-1)]*G[{0}, yw]*G[{1, 1, yu^(-1)}, yw])/8 - 
     (3*G[{0}, yw]^2*G[{1, 1, yu^(-1)}, yw])/16 + 
     (G[{0}, yu^(-1)]*G[{1}, yu^(-1)]*G[{1, 1, yu^(-1)}, yw])/16 + 
     (G[{0}, yv^(-1)]*G[{1}, yu^(-1)]*G[{1, 1, yu^(-1)}, yw])/16 - 
     (G[{0}, yw]*G[{1}, yu^(-1)]*G[{1, 1, yu^(-1)}, yw])/16 + 
     (13*G[{1}, yu^(-1)]^2*G[{1, 1, yu^(-1)}, yw])/128 + 
     (5*G[{0}, yu^(-1)]*G[{1}, yv^(-1)]*G[{1, 1, yu^(-1)}, yw])/16 + 
     (5*G[{0}, yv^(-1)]*G[{1}, yv^(-1)]*G[{1, 1, yu^(-1)}, yw])/16 - 
     (5*G[{0}, yw]*G[{1}, yv^(-1)]*G[{1, 1, yu^(-1)}, yw])/16 - 
     (5*G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*G[{1, 1, yu^(-1)}, yw])/64 - 
     (5*G[{1}, yv^(-1)]^2*G[{1, 1, yu^(-1)}, yw])/32 - 
     (19*G[{0}, yu^(-1)]*G[{1}, yw]*G[{1, 1, yu^(-1)}, yw])/64 - 
     (19*G[{0}, yv^(-1)]*G[{1}, yw]*G[{1, 1, yu^(-1)}, yw])/64 + 
     (19*G[{0}, yw]*G[{1}, yw]*G[{1, 1, yu^(-1)}, yw])/64 + 
     (3*G[{1}, yu^(-1)]*G[{1}, yw]*G[{1, 1, yu^(-1)}, yw])/16 + 
     (11*G[{1}, yv^(-1)]*G[{1}, yw]*G[{1, 1, yu^(-1)}, yw])/64 - 
     (15*G[{1}, yw]^2*G[{1, 1, yu^(-1)}, yw])/128 + 
     (3*G[{0}, yu^(-1)]*G[{yu}, yv^(-1)]*G[{1, 1, yu^(-1)}, yw])/8 + 
     (3*G[{0}, yv^(-1)]*G[{yu}, yv^(-1)]*G[{1, 1, yu^(-1)}, yw])/8 - 
     (3*G[{0}, yw]*G[{yu}, yv^(-1)]*G[{1, 1, yu^(-1)}, yw])/8 - 
     (G[{1}, yu^(-1)]*G[{yu}, yv^(-1)]*G[{1, 1, yu^(-1)}, yw])/4 + 
     (15*G[{1}, yw]*G[{yu}, yv^(-1)]*G[{1, 1, yu^(-1)}, yw])/64 - 
     (G[{yu}, yv^(-1)]^2*G[{1, 1, yu^(-1)}, yw])/4 + 
     (3*G[{0}, yu^(-1)]*G[{1/(yu*yv)}, yw]*G[{1, 1, yu^(-1)}, yw])/8 + 
     (3*G[{0}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{1, 1, yu^(-1)}, yw])/8 - 
     (3*G[{0}, yw]*G[{1/(yu*yv)}, yw]*G[{1, 1, yu^(-1)}, yw])/8 - 
     (17*G[{1}, yu^(-1)]*G[{1/(yu*yv)}, yw]*G[{1, 1, yu^(-1)}, yw])/64 - 
     (5*G[{1}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{1, 1, yu^(-1)}, yw])/16 + 
     (11*G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{1, 1, yu^(-1)}, yw])/64 + 
     (11*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{1, 1, yu^(-1)}, yw])/32 - 
     (11*G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{1, 1, yu^(-1)}, yw])/64 + 
     (11*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{1, 1, yu^(-1)}, yw])/64 - 
     (G[{0, 1}, yu^(-1)]*G[{1, 1, yu^(-1)}, yw])/64 - 
     (G[{0, 1}, yv^(-1)]*G[{1, 1, yu^(-1)}, yw])/4 + 
     (5*G[{0, 1}, yw]*G[{1, 1, yu^(-1)}, yw])/64 - 
     (5*G[{0, yu^(-1)}, yw]*G[{1, 1, yu^(-1)}, yw])/64 + 
     (G[{0, yu}, yv^(-1)]*G[{1, 1, yu^(-1)}, yw])/4 - 
     (5*G[{0, yv^(-1)}, yw]*G[{1, 1, yu^(-1)}, yw])/64 + 
     (5*G[{0, 1/(yu*yv)}, yw]*G[{1, 1, yu^(-1)}, yw])/64 + 
     (11*G[{1, yu^(-1)}, yw]*G[{1, 1, yu^(-1)}, yw])/32 - 
     (15*G[{1, yu}, yv^(-1)]*G[{1, 1, yu^(-1)}, yw])/64 + 
     (G[{1, yv^(-1)}, yw]*G[{1, 1, yu^(-1)}, yw])/64 - 
     (3*G[{1, 1/(yu*yv)}, yw]*G[{1, 1, yu^(-1)}, yw])/64 - 
     (11*G[{yu^(-1), 1/(yu*yv)}, yw]*G[{1, 1, yu^(-1)}, yw])/32 - 
     (11*G[{yv^(-1), 1/(yu*yv)}, yw]*G[{1, 1, yu^(-1)}, yw])/64 + 
     (Pi^2*G[{1, 1, yu}, yv^(-1)])/24 + 
     (G[{0}, yu^(-1)]^2*G[{1, 1, yu}, yv^(-1)])/8 + 
     (G[{0}, yu^(-1)]*G[{0}, yv^(-1)]*G[{1, 1, yu}, yv^(-1)])/4 + 
     (G[{0}, yv^(-1)]^2*G[{1, 1, yu}, yv^(-1)])/8 - 
     (G[{0}, yu^(-1)]*G[{0}, yw]*G[{1, 1, yu}, yv^(-1)])/4 - 
     (G[{0}, yv^(-1)]*G[{0}, yw]*G[{1, 1, yu}, yv^(-1)])/4 + 
     (G[{0}, yw]^2*G[{1, 1, yu}, yv^(-1)])/8 - 
     (3*G[{0}, yu^(-1)]*G[{1}, yu^(-1)]*G[{1, 1, yu}, yv^(-1)])/16 - 
     (3*G[{0}, yv^(-1)]*G[{1}, yu^(-1)]*G[{1, 1, yu}, yv^(-1)])/16 + 
     (3*G[{0}, yw]*G[{1}, yu^(-1)]*G[{1, 1, yu}, yv^(-1)])/16 + 
     (G[{1}, yu^(-1)]^2*G[{1, 1, yu}, yv^(-1)])/16 - 
     (3*G[{0}, yu^(-1)]*G[{1}, yv^(-1)]*G[{1, 1, yu}, yv^(-1)])/16 - 
     (3*G[{0}, yv^(-1)]*G[{1}, yv^(-1)]*G[{1, 1, yu}, yv^(-1)])/16 + 
     (3*G[{0}, yw]*G[{1}, yv^(-1)]*G[{1, 1, yu}, yv^(-1)])/16 + 
     (G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*G[{1, 1, yu}, yv^(-1)])/16 + 
     (G[{1}, yv^(-1)]^2*G[{1, 1, yu}, yv^(-1)])/32 + 
     (G[{0}, yu^(-1)]*G[{1}, yw]*G[{1, 1, yu}, yv^(-1)])/8 + 
     (G[{0}, yv^(-1)]*G[{1}, yw]*G[{1, 1, yu}, yv^(-1)])/8 - 
     (G[{0}, yw]*G[{1}, yw]*G[{1, 1, yu}, yv^(-1)])/8 - 
     (G[{1}, yv^(-1)]*G[{1}, yw]*G[{1, 1, yu}, yv^(-1)])/4 + 
     (G[{1}, yw]*G[{yu}, yv^(-1)]*G[{1, 1, yu}, yv^(-1)])/8 + 
     (3*G[{0}, yu^(-1)]*G[{1/(yu*yv)}, yw]*G[{1, 1, yu}, yv^(-1)])/8 + 
     (3*G[{0}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{1, 1, yu}, yv^(-1)])/8 - 
     (3*G[{0}, yw]*G[{1/(yu*yv)}, yw]*G[{1, 1, yu}, yv^(-1)])/8 - 
     (3*G[{1}, yu^(-1)]*G[{1/(yu*yv)}, yw]*G[{1, 1, yu}, yv^(-1)])/8 - 
     (G[{1}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{1, 1, yu}, yv^(-1)])/8 + 
     (G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{1, 1, yu}, yv^(-1)])/8 + 
     (G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{1, 1, yu}, yv^(-1)])/4 - 
     (G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{1, 1, yu}, yv^(-1)])/8 + 
     (3*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{1, 1, yu}, yv^(-1)])/8 - 
     (G[{0, 1}, yu^(-1)]*G[{1, 1, yu}, yv^(-1)])/8 + 
     (G[{0, 1}, yv^(-1)]*G[{1, 1, yu}, yv^(-1)])/8 + 
     (G[{0, 1}, yw]*G[{1, 1, yu}, yv^(-1)])/16 - 
     (G[{0, yu^(-1)}, yw]*G[{1, 1, yu}, yv^(-1)])/4 - 
     (G[{0, yu}, yv^(-1)]*G[{1, 1, yu}, yv^(-1)])/8 - 
     (3*G[{0, yv^(-1)}, yw]*G[{1, 1, yu}, yv^(-1)])/16 + 
     (3*G[{0, 1/(yu*yv)}, yw]*G[{1, 1, yu}, yv^(-1)])/8 + 
     (G[{1, yu^(-1)}, yw]*G[{1, 1, yu}, yv^(-1)])/4 - 
     (G[{1, yu}, yv^(-1)]*G[{1, 1, yu}, yv^(-1)])/8 - 
     (G[{1, 1/(yu*yv)}, yw]*G[{1, 1, yu}, yv^(-1)])/8 - 
     (G[{yu^(-1), 1/(yu*yv)}, yw]*G[{1, 1, yu}, yv^(-1)])/4 - 
     (3*G[{yv^(-1), 1/(yu*yv)}, yw]*G[{1, 1, yu}, yv^(-1)])/8 + 
     (5*Pi^2*G[{1, 1, yv^(-1)}, yw])/768 - 
     (G[{0}, yu^(-1)]^2*G[{1, 1, yv^(-1)}, yw])/32 - 
     (G[{0}, yu^(-1)]*G[{0}, yv^(-1)]*G[{1, 1, yv^(-1)}, yw])/16 - 
     (G[{0}, yv^(-1)]^2*G[{1, 1, yv^(-1)}, yw])/32 + 
     (G[{0}, yu^(-1)]*G[{0}, yw]*G[{1, 1, yv^(-1)}, yw])/16 + 
     (G[{0}, yv^(-1)]*G[{0}, yw]*G[{1, 1, yv^(-1)}, yw])/16 - 
     (G[{0}, yw]^2*G[{1, 1, yv^(-1)}, yw])/32 + 
     (3*G[{0}, yu^(-1)]*G[{1}, yu^(-1)]*G[{1, 1, yv^(-1)}, yw])/16 + 
     (3*G[{0}, yv^(-1)]*G[{1}, yu^(-1)]*G[{1, 1, yv^(-1)}, yw])/16 - 
     (3*G[{0}, yw]*G[{1}, yu^(-1)]*G[{1, 1, yv^(-1)}, yw])/16 - 
     (23*G[{1}, yu^(-1)]^2*G[{1, 1, yv^(-1)}, yw])/128 + 
     (G[{0}, yu^(-1)]*G[{1}, yv^(-1)]*G[{1, 1, yv^(-1)}, yw])/16 + 
     (G[{0}, yv^(-1)]*G[{1}, yv^(-1)]*G[{1, 1, yv^(-1)}, yw])/16 - 
     (G[{0}, yw]*G[{1}, yv^(-1)]*G[{1, 1, yv^(-1)}, yw])/16 - 
     (21*G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*G[{1, 1, yv^(-1)}, yw])/64 - 
     (G[{1}, yv^(-1)]^2*G[{1, 1, yv^(-1)}, yw])/32 + 
     (5*G[{0}, yu^(-1)]*G[{1}, yw]*G[{1, 1, yv^(-1)}, yw])/64 + 
     (5*G[{0}, yv^(-1)]*G[{1}, yw]*G[{1, 1, yv^(-1)}, yw])/64 - 
     (5*G[{0}, yw]*G[{1}, yw]*G[{1, 1, yv^(-1)}, yw])/64 - 
     (G[{1}, yu^(-1)]*G[{1}, yw]*G[{1, 1, yv^(-1)}, yw])/8 - 
     (5*G[{1}, yv^(-1)]*G[{1}, yw]*G[{1, 1, yv^(-1)}, yw])/64 - 
     (3*G[{1}, yw]^2*G[{1, 1, yv^(-1)}, yw])/128 - 
     (G[{0}, yu^(-1)]*G[{yu}, yv^(-1)]*G[{1, 1, yv^(-1)}, yw])/8 - 
     (G[{0}, yv^(-1)]*G[{yu}, yv^(-1)]*G[{1, 1, yv^(-1)}, yw])/8 + 
     (G[{0}, yw]*G[{yu}, yv^(-1)]*G[{1, 1, yv^(-1)}, yw])/8 + 
     (5*G[{1}, yu^(-1)]*G[{yu}, yv^(-1)]*G[{1, 1, yv^(-1)}, yw])/16 + 
     (3*G[{1}, yw]*G[{yu}, yv^(-1)]*G[{1, 1, yv^(-1)}, yw])/64 - 
     (G[{yu}, yv^(-1)]^2*G[{1, 1, yv^(-1)}, yw])/32 + 
     (7*G[{1}, yu^(-1)]*G[{1/(yu*yv)}, yw]*G[{1, 1, yv^(-1)}, yw])/64 + 
     (7*G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{1, 1, yv^(-1)}, yw])/64 - 
     (3*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{1, 1, yv^(-1)}, yw])/32 - 
     (7*G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{1, 1, yv^(-1)}, yw])/64 - 
     (5*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{1, 1, yv^(-1)}, yw])/64 - 
     (9*G[{0, 1}, yu^(-1)]*G[{1, 1, yv^(-1)}, yw])/64 + 
     (G[{0, 1}, yv^(-1)]*G[{1, 1, yv^(-1)}, yw])/8 - 
     (3*G[{0, 1}, yw]*G[{1, 1, yv^(-1)}, yw])/64 + 
     (3*G[{0, yu^(-1)}, yw]*G[{1, 1, yv^(-1)}, yw])/64 - 
     (G[{0, yu}, yv^(-1)]*G[{1, 1, yv^(-1)}, yw])/8 + 
     (3*G[{0, yv^(-1)}, yw]*G[{1, 1, yv^(-1)}, yw])/64 - 
     (3*G[{0, 1/(yu*yv)}, yw]*G[{1, 1, yv^(-1)}, yw])/64 - 
     (3*G[{1, yu^(-1)}, yw]*G[{1, 1, yv^(-1)}, yw])/32 + 
     (17*G[{1, yu}, yv^(-1)]*G[{1, 1, yv^(-1)}, yw])/64 + 
     (G[{1, yv^(-1)}, yw]*G[{1, 1, yv^(-1)}, yw])/64 + 
     (G[{1, 1/(yu*yv)}, yw]*G[{1, 1, yv^(-1)}, yw])/64 + 
     (3*G[{yu^(-1), 1/(yu*yv)}, yw]*G[{1, 1, yv^(-1)}, yw])/32 + 
     (5*G[{yv^(-1), 1/(yu*yv)}, yw]*G[{1, 1, yv^(-1)}, yw])/64 + 
     (Pi^2*G[{1, 1, 1/(yu*yv)}, yw])/48 + 
     (7*G[{0}, yu^(-1)]^2*G[{1, 1, 1/(yu*yv)}, yw])/32 + 
     (7*G[{0}, yu^(-1)]*G[{0}, yv^(-1)]*G[{1, 1, 1/(yu*yv)}, yw])/16 + 
     (7*G[{0}, yv^(-1)]^2*G[{1, 1, 1/(yu*yv)}, yw])/32 - 
     (7*G[{0}, yu^(-1)]*G[{0}, yw]*G[{1, 1, 1/(yu*yv)}, yw])/16 - 
     (7*G[{0}, yv^(-1)]*G[{0}, yw]*G[{1, 1, 1/(yu*yv)}, yw])/16 + 
     (7*G[{0}, yw]^2*G[{1, 1, 1/(yu*yv)}, yw])/32 - 
     (3*G[{0}, yu^(-1)]*G[{1}, yu^(-1)]*G[{1, 1, 1/(yu*yv)}, yw])/8 - 
     (3*G[{0}, yv^(-1)]*G[{1}, yu^(-1)]*G[{1, 1, 1/(yu*yv)}, yw])/8 + 
     (3*G[{0}, yw]*G[{1}, yu^(-1)]*G[{1, 1, 1/(yu*yv)}, yw])/8 + 
     (5*G[{1}, yu^(-1)]^2*G[{1, 1, 1/(yu*yv)}, yw])/32 - 
     (3*G[{0}, yu^(-1)]*G[{1}, yv^(-1)]*G[{1, 1, 1/(yu*yv)}, yw])/8 - 
     (3*G[{0}, yv^(-1)]*G[{1}, yv^(-1)]*G[{1, 1, 1/(yu*yv)}, yw])/8 + 
     (3*G[{0}, yw]*G[{1}, yv^(-1)]*G[{1, 1, 1/(yu*yv)}, yw])/8 + 
     (G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*G[{1, 1, 1/(yu*yv)}, yw])/4 + 
     (3*G[{1}, yv^(-1)]^2*G[{1, 1, 1/(yu*yv)}, yw])/16 + 
     (G[{0}, yu^(-1)]*G[{1}, yw]*G[{1, 1, 1/(yu*yv)}, yw])/4 + 
     (G[{0}, yv^(-1)]*G[{1}, yw]*G[{1, 1, 1/(yu*yv)}, yw])/4 - 
     (G[{0}, yw]*G[{1}, yw]*G[{1, 1, 1/(yu*yv)}, yw])/4 - 
     (3*G[{1}, yu^(-1)]*G[{1}, yw]*G[{1, 1, 1/(yu*yv)}, yw])/16 - 
     (G[{1}, yv^(-1)]*G[{1}, yw]*G[{1, 1, 1/(yu*yv)}, yw])/8 + 
     (3*G[{1}, yw]^2*G[{1, 1, 1/(yu*yv)}, yw])/32 - 
     (G[{0}, yu^(-1)]*G[{yu}, yv^(-1)]*G[{1, 1, 1/(yu*yv)}, yw])/8 - 
     (G[{0}, yv^(-1)]*G[{yu}, yv^(-1)]*G[{1, 1, 1/(yu*yv)}, yw])/8 + 
     (G[{0}, yw]*G[{yu}, yv^(-1)]*G[{1, 1, 1/(yu*yv)}, yw])/8 + 
     (3*G[{1}, yu^(-1)]*G[{yu}, yv^(-1)]*G[{1, 1, 1/(yu*yv)}, yw])/16 - 
     (3*G[{1}, yw]*G[{yu}, yv^(-1)]*G[{1, 1, 1/(yu*yv)}, yw])/16 + 
     (G[{yu}, yv^(-1)]^2*G[{1, 1, 1/(yu*yv)}, yw])/32 - 
     (G[{0}, yu^(-1)]*G[{1/(yu*yv)}, yw]*G[{1, 1, 1/(yu*yv)}, yw])/8 - 
     (G[{0}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{1, 1, 1/(yu*yv)}, yw])/8 + 
     (G[{0}, yw]*G[{1/(yu*yv)}, yw]*G[{1, 1, 1/(yu*yv)}, yw])/8 + 
     (G[{1}, yu^(-1)]*G[{1/(yu*yv)}, yw]*G[{1, 1, 1/(yu*yv)}, yw])/8 + 
     (G[{1}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{1, 1, 1/(yu*yv)}, yw])/16 - 
     (G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{1, 1, 1/(yu*yv)}, yw])/16 - 
     (3*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{1, 1, 1/(yu*yv)}, yw])/16 + 
     (G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{1, 1, 1/(yu*yv)}, yw])/16 - 
     (G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{1, 1, 1/(yu*yv)}, yw])/4 - 
     (G[{0, 1}, yu^(-1)]*G[{1, 1, 1/(yu*yv)}, yw])/8 + 
     (G[{0, 1}, yw]*G[{1, 1, 1/(yu*yv)}, yw])/8 - 
     (G[{0, yu^(-1)}, yw]*G[{1, 1, 1/(yu*yv)}, yw])/8 - 
     (G[{0, yv^(-1)}, yw]*G[{1, 1, 1/(yu*yv)}, yw])/8 + 
     (G[{0, 1/(yu*yv)}, yw]*G[{1, 1, 1/(yu*yv)}, yw])/8 - 
     (3*G[{1, yu^(-1)}, yw]*G[{1, 1, 1/(yu*yv)}, yw])/16 + 
     (G[{1, yu}, yv^(-1)]*G[{1, 1, 1/(yu*yv)}, yw])/8 + 
     (G[{1, 1/(yu*yv)}, yw]*G[{1, 1, 1/(yu*yv)}, yw])/16 + 
     (3*G[{yu^(-1), 1/(yu*yv)}, yw]*G[{1, 1, 1/(yu*yv)}, yw])/16 + 
     (G[{yv^(-1), 1/(yu*yv)}, yw]*G[{1, 1, 1/(yu*yv)}, yw])/4 - 
     (19*Pi^2*G[{1, yu^(-1), yu^(-1)}, yw])/256 - 
     (9*G[{0}, yu^(-1)]^2*G[{1, yu^(-1), yu^(-1)}, yw])/64 - 
     (9*G[{0}, yu^(-1)]*G[{0}, yv^(-1)]*G[{1, yu^(-1), yu^(-1)}, yw])/32 - 
     (9*G[{0}, yv^(-1)]^2*G[{1, yu^(-1), yu^(-1)}, yw])/64 + 
     (9*G[{0}, yu^(-1)]*G[{0}, yw]*G[{1, yu^(-1), yu^(-1)}, yw])/32 + 
     (9*G[{0}, yv^(-1)]*G[{0}, yw]*G[{1, yu^(-1), yu^(-1)}, yw])/32 - 
     (9*G[{0}, yw]^2*G[{1, yu^(-1), yu^(-1)}, yw])/64 - 
     (3*G[{0}, yu^(-1)]*G[{1}, yu^(-1)]*G[{1, yu^(-1), yu^(-1)}, yw])/32 - 
     (3*G[{0}, yv^(-1)]*G[{1}, yu^(-1)]*G[{1, yu^(-1), yu^(-1)}, yw])/32 + 
     (3*G[{0}, yw]*G[{1}, yu^(-1)]*G[{1, yu^(-1), yu^(-1)}, yw])/32 + 
     (3*G[{1}, yu^(-1)]^2*G[{1, yu^(-1), yu^(-1)}, yw])/16 + 
     (21*G[{0}, yu^(-1)]*G[{1}, yv^(-1)]*G[{1, yu^(-1), yu^(-1)}, yw])/32 + 
     (21*G[{0}, yv^(-1)]*G[{1}, yv^(-1)]*G[{1, yu^(-1), yu^(-1)}, yw])/32 - 
     (21*G[{0}, yw]*G[{1}, yv^(-1)]*G[{1, yu^(-1), yu^(-1)}, yw])/32 - 
     (3*G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*G[{1, yu^(-1), yu^(-1)}, yw])/16 - 
     (29*G[{1}, yv^(-1)]^2*G[{1, yu^(-1), yu^(-1)}, yw])/64 + 
     (G[{0}, yu^(-1)]*G[{1}, yw]*G[{1, yu^(-1), yu^(-1)}, yw])/8 + 
     (G[{0}, yv^(-1)]*G[{1}, yw]*G[{1, yu^(-1), yu^(-1)}, yw])/8 - 
     (G[{0}, yw]*G[{1}, yw]*G[{1, yu^(-1), yu^(-1)}, yw])/8 - 
     (3*G[{1}, yu^(-1)]*G[{1}, yw]*G[{1, yu^(-1), yu^(-1)}, yw])/32 + 
     (G[{1}, yv^(-1)]*G[{1}, yw]*G[{1, yu^(-1), yu^(-1)}, yw])/8 + 
     (9*G[{1}, yw]^2*G[{1, yu^(-1), yu^(-1)}, yw])/64 - 
     (9*G[{1}, yw]*G[{yu}, yv^(-1)]*G[{1, yu^(-1), yu^(-1)}, yw])/32 + 
     (31*G[{0}, yu^(-1)]*G[{1/(yu*yv)}, yw]*G[{1, yu^(-1), yu^(-1)}, yw])/
      64 + (31*G[{0}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{1, yu^(-1), yu^(-1)}, 
        yw])/64 - (31*G[{0}, yw]*G[{1/(yu*yv)}, yw]*G[{1, yu^(-1), yu^(-1)}, 
        yw])/64 - (33*G[{1}, yu^(-1)]*G[{1/(yu*yv)}, yw]*
       G[{1, yu^(-1), yu^(-1)}, yw])/64 - 
     (15*G[{1}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{1, yu^(-1), yu^(-1)}, yw])/
      64 + (7*G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{1, yu^(-1), yu^(-1)}, yw])/
      32 + (3*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{1, yu^(-1), yu^(-1)}, 
        yw])/16 - (7*G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw]*
       G[{1, yu^(-1), yu^(-1)}, yw])/32 + 
     (11*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{1, yu^(-1), yu^(-1)}, yw])/
      32 + (3*G[{1/(yu*yv)}, yw]^2*G[{1, yu^(-1), yu^(-1)}, yw])/64 - 
     (G[{0, 1}, yu^(-1)]*G[{1, yu^(-1), yu^(-1)}, yw])/32 - 
     (G[{0, 1}, yv^(-1)]*G[{1, yu^(-1), yu^(-1)}, yw])/4 + 
     (G[{0, 1}, yw]*G[{1, yu^(-1), yu^(-1)}, yw])/8 - 
     (G[{0, yu^(-1)}, yw]*G[{1, yu^(-1), yu^(-1)}, yw])/8 + 
     (G[{0, yu}, yv^(-1)]*G[{1, yu^(-1), yu^(-1)}, yw])/4 - 
     (G[{0, yv^(-1)}, yw]*G[{1, yu^(-1), yu^(-1)}, yw])/8 + 
     (G[{0, 1/(yu*yv)}, yw]*G[{1, yu^(-1), yu^(-1)}, yw])/8 - 
     (G[{1, yu^(-1)}, yw]*G[{1, yu^(-1), yu^(-1)}, yw])/8 - 
     (7*G[{1, yu}, yv^(-1)]*G[{1, yu^(-1), yu^(-1)}, yw])/32 + 
     (G[{1, yv^(-1)}, yw]*G[{1, yu^(-1), yu^(-1)}, yw])/32 - 
     (3*G[{1, 1/(yu*yv)}, yw]*G[{1, yu^(-1), yu^(-1)}, yw])/32 - 
     (3*G[{yu^(-1), 1/(yu*yv)}, yw]*G[{1, yu^(-1), yu^(-1)}, yw])/16 - 
     (11*G[{yv^(-1), 1/(yu*yv)}, yw]*G[{1, yu^(-1), yu^(-1)}, yw])/32 - 
     (3*Pi^2*G[{1, yu^(-1), yv^(-1)}, yw])/256 + 
     (3*G[{0}, yu^(-1)]^2*G[{1, yu^(-1), yv^(-1)}, yw])/64 + 
     (3*G[{0}, yu^(-1)]*G[{0}, yv^(-1)]*G[{1, yu^(-1), yv^(-1)}, yw])/32 + 
     (3*G[{0}, yv^(-1)]^2*G[{1, yu^(-1), yv^(-1)}, yw])/64 - 
     (3*G[{0}, yu^(-1)]*G[{0}, yw]*G[{1, yu^(-1), yv^(-1)}, yw])/32 - 
     (3*G[{0}, yv^(-1)]*G[{0}, yw]*G[{1, yu^(-1), yv^(-1)}, yw])/32 + 
     (3*G[{0}, yw]^2*G[{1, yu^(-1), yv^(-1)}, yw])/64 - 
     (7*G[{0}, yu^(-1)]*G[{1}, yu^(-1)]*G[{1, yu^(-1), yv^(-1)}, yw])/32 - 
     (7*G[{0}, yv^(-1)]*G[{1}, yu^(-1)]*G[{1, yu^(-1), yv^(-1)}, yw])/32 + 
     (7*G[{0}, yw]*G[{1}, yu^(-1)]*G[{1, yu^(-1), yv^(-1)}, yw])/32 + 
     (G[{1}, yu^(-1)]^2*G[{1, yu^(-1), yv^(-1)}, yw])/8 + 
     (G[{0}, yu^(-1)]*G[{1}, yv^(-1)]*G[{1, yu^(-1), yv^(-1)}, yw])/32 + 
     (G[{0}, yv^(-1)]*G[{1}, yv^(-1)]*G[{1, yu^(-1), yv^(-1)}, yw])/32 - 
     (G[{0}, yw]*G[{1}, yv^(-1)]*G[{1, yu^(-1), yv^(-1)}, yw])/32 + 
     (3*G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*G[{1, yu^(-1), yv^(-1)}, yw])/16 - 
     (5*G[{1}, yv^(-1)]^2*G[{1, yu^(-1), yv^(-1)}, yw])/64 + 
     (G[{1}, yu^(-1)]*G[{1}, yw]*G[{1, yu^(-1), yv^(-1)}, yw])/32 + 
     (G[{1}, yv^(-1)]*G[{1}, yw]*G[{1, yu^(-1), yv^(-1)}, yw])/8 + 
     (5*G[{1}, yw]^2*G[{1, yu^(-1), yv^(-1)}, yw])/64 - 
     (5*G[{1}, yw]*G[{yu}, yv^(-1)]*G[{1, yu^(-1), yv^(-1)}, yw])/32 + 
     (11*G[{0}, yu^(-1)]*G[{1/(yu*yv)}, yw]*G[{1, yu^(-1), yv^(-1)}, yw])/
      64 + (11*G[{0}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{1, yu^(-1), yv^(-1)}, 
        yw])/64 - (11*G[{0}, yw]*G[{1/(yu*yv)}, yw]*G[{1, yu^(-1), yv^(-1)}, 
        yw])/64 - (17*G[{1}, yu^(-1)]*G[{1/(yu*yv)}, yw]*
       G[{1, yu^(-1), yv^(-1)}, yw])/64 - 
     (7*G[{1}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{1, yu^(-1), yv^(-1)}, yw])/64 - 
     (G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{1, yu^(-1), yv^(-1)}, yw])/32 - 
     (G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{1, yu^(-1), yv^(-1)}, yw])/16 + 
     (G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{1, yu^(-1), yv^(-1)}, yw])/32 + 
     (3*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{1, yu^(-1), yv^(-1)}, yw])/
      32 + (3*G[{1/(yu*yv)}, yw]^2*G[{1, yu^(-1), yv^(-1)}, yw])/64 - 
     (G[{0, 1}, yu^(-1)]*G[{1, yu^(-1), yv^(-1)}, yw])/32 - 
     (G[{0, 1}, yv^(-1)]*G[{1, yu^(-1), yv^(-1)}, yw])/8 + 
     (G[{0, yu}, yv^(-1)]*G[{1, yu^(-1), yv^(-1)}, yw])/8 - 
     (G[{1, yu^(-1)}, yw]*G[{1, yu^(-1), yv^(-1)}, yw])/8 - 
     (3*G[{1, yu}, yv^(-1)]*G[{1, yu^(-1), yv^(-1)}, yw])/32 + 
     (G[{1, yv^(-1)}, yw]*G[{1, yu^(-1), yv^(-1)}, yw])/32 + 
     (G[{1, 1/(yu*yv)}, yw]*G[{1, yu^(-1), yv^(-1)}, yw])/32 + 
     (G[{yu^(-1), 1/(yu*yv)}, yw]*G[{1, yu^(-1), yv^(-1)}, yw])/16 - 
     (3*G[{yv^(-1), 1/(yu*yv)}, yw]*G[{1, yu^(-1), yv^(-1)}, yw])/32 - 
     (5*Pi^2*G[{1, yu^(-1), 1/(yu*yv)}, yw])/768 + 
     (G[{0}, yu^(-1)]*G[{1}, yu^(-1)]*G[{1, yu^(-1), 1/(yu*yv)}, yw])/16 + 
     (G[{0}, yv^(-1)]*G[{1}, yu^(-1)]*G[{1, yu^(-1), 1/(yu*yv)}, yw])/16 - 
     (G[{0}, yw]*G[{1}, yu^(-1)]*G[{1, yu^(-1), 1/(yu*yv)}, yw])/16 - 
     (5*G[{1}, yu^(-1)]^2*G[{1, yu^(-1), 1/(yu*yv)}, yw])/128 - 
     (G[{0}, yu^(-1)]*G[{1}, yv^(-1)]*G[{1, yu^(-1), 1/(yu*yv)}, yw])/16 - 
     (G[{0}, yv^(-1)]*G[{1}, yv^(-1)]*G[{1, yu^(-1), 1/(yu*yv)}, yw])/16 + 
     (G[{0}, yw]*G[{1}, yv^(-1)]*G[{1, yu^(-1), 1/(yu*yv)}, yw])/16 - 
     (3*G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*G[{1, yu^(-1), 1/(yu*yv)}, yw])/64 + 
     (3*G[{1}, yv^(-1)]^2*G[{1, yu^(-1), 1/(yu*yv)}, yw])/32 + 
     (3*G[{0}, yu^(-1)]*G[{1}, yw]*G[{1, yu^(-1), 1/(yu*yv)}, yw])/64 + 
     (3*G[{0}, yv^(-1)]*G[{1}, yw]*G[{1, yu^(-1), 1/(yu*yv)}, yw])/64 - 
     (3*G[{0}, yw]*G[{1}, yw]*G[{1, yu^(-1), 1/(yu*yv)}, yw])/64 - 
     (G[{1}, yu^(-1)]*G[{1}, yw]*G[{1, yu^(-1), 1/(yu*yv)}, yw])/16 - 
     (3*G[{1}, yv^(-1)]*G[{1}, yw]*G[{1, yu^(-1), 1/(yu*yv)}, yw])/64 - 
     (G[{1}, yw]^2*G[{1, yu^(-1), 1/(yu*yv)}, yw])/128 + 
     (G[{1}, yw]*G[{yu}, yv^(-1)]*G[{1, yu^(-1), 1/(yu*yv)}, yw])/64 - 
     (G[{0}, yu^(-1)]*G[{1/(yu*yv)}, yw]*G[{1, yu^(-1), 1/(yu*yv)}, yw])/16 - 
     (G[{0}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{1, yu^(-1), 1/(yu*yv)}, yw])/16 + 
     (G[{0}, yw]*G[{1/(yu*yv)}, yw]*G[{1, yu^(-1), 1/(yu*yv)}, yw])/16 + 
     (G[{1}, yu^(-1)]*G[{1/(yu*yv)}, yw]*G[{1, yu^(-1), 1/(yu*yv)}, yw])/64 + 
     (G[{1}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{1, yu^(-1), 1/(yu*yv)}, yw])/16 - 
     (3*G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{1, yu^(-1), 1/(yu*yv)}, yw])/64 + 
     (G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{1, yu^(-1), 1/(yu*yv)}, yw])/
      32 + (3*G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{1, yu^(-1), 1/(yu*yv)}, 
        yw])/64 + (5*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*
       G[{1, yu^(-1), 1/(yu*yv)}, yw])/64 + 
     (G[{0, 1}, yu^(-1)]*G[{1, yu^(-1), 1/(yu*yv)}, yw])/64 + 
     (3*G[{0, 1}, yw]*G[{1, yu^(-1), 1/(yu*yv)}, yw])/64 - 
     (3*G[{0, yu^(-1)}, yw]*G[{1, yu^(-1), 1/(yu*yv)}, yw])/64 - 
     (3*G[{0, yv^(-1)}, yw]*G[{1, yu^(-1), 1/(yu*yv)}, yw])/64 + 
     (3*G[{0, 1/(yu*yv)}, yw]*G[{1, yu^(-1), 1/(yu*yv)}, yw])/64 + 
     (3*G[{1, yu^(-1)}, yw]*G[{1, yu^(-1), 1/(yu*yv)}, yw])/64 - 
     (G[{1, yu}, yv^(-1)]*G[{1, yu^(-1), 1/(yu*yv)}, yw])/64 + 
     (7*G[{1, yv^(-1)}, yw]*G[{1, yu^(-1), 1/(yu*yv)}, yw])/64 + 
     (3*G[{1, 1/(yu*yv)}, yw]*G[{1, yu^(-1), 1/(yu*yv)}, yw])/64 - 
     (G[{yu^(-1), 1/(yu*yv)}, yw]*G[{1, yu^(-1), 1/(yu*yv)}, yw])/32 - 
     (5*G[{yv^(-1), 1/(yu*yv)}, yw]*G[{1, yu^(-1), 1/(yu*yv)}, yw])/64 + 
     (Pi^2*G[{1, yu, yu}, yv^(-1)])/48 + 
     (5*G[{0}, yu^(-1)]^2*G[{1, yu, yu}, yv^(-1)])/32 + 
     (5*G[{0}, yu^(-1)]*G[{0}, yv^(-1)]*G[{1, yu, yu}, yv^(-1)])/16 + 
     (5*G[{0}, yv^(-1)]^2*G[{1, yu, yu}, yv^(-1)])/32 - 
     (5*G[{0}, yu^(-1)]*G[{0}, yw]*G[{1, yu, yu}, yv^(-1)])/16 - 
     (5*G[{0}, yv^(-1)]*G[{0}, yw]*G[{1, yu, yu}, yv^(-1)])/16 + 
     (5*G[{0}, yw]^2*G[{1, yu, yu}, yv^(-1)])/32 - 
     (5*G[{0}, yu^(-1)]*G[{1}, yu^(-1)]*G[{1, yu, yu}, yv^(-1)])/16 - 
     (5*G[{0}, yv^(-1)]*G[{1}, yu^(-1)]*G[{1, yu, yu}, yv^(-1)])/16 + 
     (5*G[{0}, yw]*G[{1}, yu^(-1)]*G[{1, yu, yu}, yv^(-1)])/16 + 
     (5*G[{1}, yu^(-1)]^2*G[{1, yu, yu}, yv^(-1)])/32 - 
     (G[{0}, yu^(-1)]*G[{1}, yv^(-1)]*G[{1, yu, yu}, yv^(-1)])/16 - 
     (G[{0}, yv^(-1)]*G[{1}, yv^(-1)]*G[{1, yu, yu}, yv^(-1)])/16 + 
     (G[{0}, yw]*G[{1}, yv^(-1)]*G[{1, yu, yu}, yv^(-1)])/16 - 
     (G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*G[{1, yu, yu}, yv^(-1)])/16 - 
     (G[{1}, yv^(-1)]^2*G[{1, yu, yu}, yv^(-1)])/32 + 
     (3*G[{0}, yu^(-1)]*G[{1}, yw]*G[{1, yu, yu}, yv^(-1)])/16 + 
     (3*G[{0}, yv^(-1)]*G[{1}, yw]*G[{1, yu, yu}, yv^(-1)])/16 - 
     (3*G[{0}, yw]*G[{1}, yw]*G[{1, yu, yu}, yv^(-1)])/16 - 
     (G[{1}, yu^(-1)]*G[{1}, yw]*G[{1, yu, yu}, yv^(-1)])/8 + 
     (G[{1}, yv^(-1)]*G[{1}, yw]*G[{1, yu, yu}, yv^(-1)])/16 + 
     (G[{1}, yw]^2*G[{1, yu, yu}, yv^(-1)])/32 + 
     (3*G[{1}, yw]*G[{yu}, yv^(-1)]*G[{1, yu, yu}, yv^(-1)])/16 + 
     (7*G[{0}, yu^(-1)]*G[{1/(yu*yv)}, yw]*G[{1, yu, yu}, yv^(-1)])/16 + 
     (7*G[{0}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{1, yu, yu}, yv^(-1)])/16 - 
     (7*G[{0}, yw]*G[{1/(yu*yv)}, yw]*G[{1, yu, yu}, yv^(-1)])/16 - 
     (G[{1}, yu^(-1)]*G[{1/(yu*yv)}, yw]*G[{1, yu, yu}, yv^(-1)])/2 - 
     (3*G[{1}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{1, yu, yu}, yv^(-1)])/16 + 
     (3*G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{1, yu, yu}, yv^(-1)])/16 + 
     (5*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{1, yu, yu}, yv^(-1)])/16 - 
     (3*G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{1, yu, yu}, yv^(-1)])/16 + 
     (3*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{1, yu, yu}, yv^(-1)])/8 - 
     (G[{0, 1}, yu^(-1)]*G[{1, yu, yu}, yv^(-1)])/8 + 
     (G[{0, 1}, yv^(-1)]*G[{1, yu, yu}, yv^(-1)])/8 + 
     (G[{0, 1}, yw]*G[{1, yu, yu}, yv^(-1)])/16 - 
     (5*G[{0, yu^(-1)}, yw]*G[{1, yu, yu}, yv^(-1)])/16 - 
     (G[{0, yu}, yv^(-1)]*G[{1, yu, yu}, yv^(-1)])/8 - 
     (3*G[{0, yv^(-1)}, yw]*G[{1, yu, yu}, yv^(-1)])/16 + 
     (7*G[{0, 1/(yu*yv)}, yw]*G[{1, yu, yu}, yv^(-1)])/16 + 
     (5*G[{1, yu^(-1)}, yw]*G[{1, yu, yu}, yv^(-1)])/16 + 
     (G[{1, yu}, yv^(-1)]*G[{1, yu, yu}, yv^(-1)])/4 - 
     (3*G[{1, 1/(yu*yv)}, yw]*G[{1, yu, yu}, yv^(-1)])/16 - 
     (5*G[{yu^(-1), 1/(yu*yv)}, yw]*G[{1, yu, yu}, yv^(-1)])/16 - 
     (3*G[{yv^(-1), 1/(yu*yv)}, yw]*G[{1, yu, yu}, yv^(-1)])/8 - 
     (3*Pi^2*G[{1, yv^(-1), yu^(-1)}, yw])/256 + 
     (3*G[{0}, yu^(-1)]^2*G[{1, yv^(-1), yu^(-1)}, yw])/64 + 
     (3*G[{0}, yu^(-1)]*G[{0}, yv^(-1)]*G[{1, yv^(-1), yu^(-1)}, yw])/32 + 
     (3*G[{0}, yv^(-1)]^2*G[{1, yv^(-1), yu^(-1)}, yw])/64 - 
     (3*G[{0}, yu^(-1)]*G[{0}, yw]*G[{1, yv^(-1), yu^(-1)}, yw])/32 - 
     (3*G[{0}, yv^(-1)]*G[{0}, yw]*G[{1, yv^(-1), yu^(-1)}, yw])/32 + 
     (3*G[{0}, yw]^2*G[{1, yv^(-1), yu^(-1)}, yw])/64 - 
     (7*G[{0}, yu^(-1)]*G[{1}, yu^(-1)]*G[{1, yv^(-1), yu^(-1)}, yw])/32 - 
     (7*G[{0}, yv^(-1)]*G[{1}, yu^(-1)]*G[{1, yv^(-1), yu^(-1)}, yw])/32 + 
     (7*G[{0}, yw]*G[{1}, yu^(-1)]*G[{1, yv^(-1), yu^(-1)}, yw])/32 + 
     (G[{1}, yu^(-1)]^2*G[{1, yv^(-1), yu^(-1)}, yw])/8 + 
     (G[{0}, yu^(-1)]*G[{1}, yv^(-1)]*G[{1, yv^(-1), yu^(-1)}, yw])/32 + 
     (G[{0}, yv^(-1)]*G[{1}, yv^(-1)]*G[{1, yv^(-1), yu^(-1)}, yw])/32 - 
     (G[{0}, yw]*G[{1}, yv^(-1)]*G[{1, yv^(-1), yu^(-1)}, yw])/32 + 
     (3*G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*G[{1, yv^(-1), yu^(-1)}, yw])/16 - 
     (5*G[{1}, yv^(-1)]^2*G[{1, yv^(-1), yu^(-1)}, yw])/64 + 
     (G[{1}, yu^(-1)]*G[{1}, yw]*G[{1, yv^(-1), yu^(-1)}, yw])/32 + 
     (G[{1}, yv^(-1)]*G[{1}, yw]*G[{1, yv^(-1), yu^(-1)}, yw])/8 + 
     (5*G[{1}, yw]^2*G[{1, yv^(-1), yu^(-1)}, yw])/64 - 
     (5*G[{1}, yw]*G[{yu}, yv^(-1)]*G[{1, yv^(-1), yu^(-1)}, yw])/32 + 
     (11*G[{0}, yu^(-1)]*G[{1/(yu*yv)}, yw]*G[{1, yv^(-1), yu^(-1)}, yw])/
      64 + (11*G[{0}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{1, yv^(-1), yu^(-1)}, 
        yw])/64 - (11*G[{0}, yw]*G[{1/(yu*yv)}, yw]*G[{1, yv^(-1), yu^(-1)}, 
        yw])/64 - (17*G[{1}, yu^(-1)]*G[{1/(yu*yv)}, yw]*
       G[{1, yv^(-1), yu^(-1)}, yw])/64 - 
     (7*G[{1}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{1, yv^(-1), yu^(-1)}, yw])/64 - 
     (G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{1, yv^(-1), yu^(-1)}, yw])/32 - 
     (G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{1, yv^(-1), yu^(-1)}, yw])/16 + 
     (G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{1, yv^(-1), yu^(-1)}, yw])/32 + 
     (3*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{1, yv^(-1), yu^(-1)}, yw])/
      32 + (3*G[{1/(yu*yv)}, yw]^2*G[{1, yv^(-1), yu^(-1)}, yw])/64 - 
     (G[{0, 1}, yu^(-1)]*G[{1, yv^(-1), yu^(-1)}, yw])/32 - 
     (G[{0, 1}, yv^(-1)]*G[{1, yv^(-1), yu^(-1)}, yw])/8 + 
     (G[{0, yu}, yv^(-1)]*G[{1, yv^(-1), yu^(-1)}, yw])/8 - 
     (G[{1, yu^(-1)}, yw]*G[{1, yv^(-1), yu^(-1)}, yw])/8 - 
     (3*G[{1, yu}, yv^(-1)]*G[{1, yv^(-1), yu^(-1)}, yw])/32 - 
     (G[{1, yv^(-1)}, yw]*G[{1, yv^(-1), yu^(-1)}, yw])/32 + 
     (G[{1, 1/(yu*yv)}, yw]*G[{1, yv^(-1), yu^(-1)}, yw])/32 + 
     (G[{yu^(-1), 1/(yu*yv)}, yw]*G[{1, yv^(-1), yu^(-1)}, yw])/16 - 
     (3*G[{yv^(-1), 1/(yu*yv)}, yw]*G[{1, yv^(-1), yu^(-1)}, yw])/32 + 
     (7*Pi^2*G[{1, yv^(-1), yv^(-1)}, yw])/768 + 
     (5*G[{0}, yu^(-1)]^2*G[{1, yv^(-1), yv^(-1)}, yw])/64 + 
     (5*G[{0}, yu^(-1)]*G[{0}, yv^(-1)]*G[{1, yv^(-1), yv^(-1)}, yw])/32 + 
     (5*G[{0}, yv^(-1)]^2*G[{1, yv^(-1), yv^(-1)}, yw])/64 - 
     (5*G[{0}, yu^(-1)]*G[{0}, yw]*G[{1, yv^(-1), yv^(-1)}, yw])/32 - 
     (5*G[{0}, yv^(-1)]*G[{0}, yw]*G[{1, yv^(-1), yv^(-1)}, yw])/32 + 
     (5*G[{0}, yw]^2*G[{1, yv^(-1), yv^(-1)}, yw])/64 - 
     (5*G[{0}, yu^(-1)]*G[{1}, yu^(-1)]*G[{1, yv^(-1), yv^(-1)}, yw])/32 - 
     (5*G[{0}, yv^(-1)]*G[{1}, yu^(-1)]*G[{1, yv^(-1), yv^(-1)}, yw])/32 + 
     (5*G[{0}, yw]*G[{1}, yu^(-1)]*G[{1, yv^(-1), yv^(-1)}, yw])/32 + 
     (G[{1}, yu^(-1)]^2*G[{1, yv^(-1), yv^(-1)}, yw])/32 - 
     (5*G[{0}, yu^(-1)]*G[{1}, yv^(-1)]*G[{1, yv^(-1), yv^(-1)}, yw])/32 - 
     (5*G[{0}, yv^(-1)]*G[{1}, yv^(-1)]*G[{1, yv^(-1), yv^(-1)}, yw])/32 + 
     (5*G[{0}, yw]*G[{1}, yv^(-1)]*G[{1, yv^(-1), yv^(-1)}, yw])/32 + 
     (G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*G[{1, yv^(-1), yv^(-1)}, yw])/8 + 
     (5*G[{1}, yv^(-1)]^2*G[{1, yv^(-1), yv^(-1)}, yw])/64 - 
     (G[{0}, yu^(-1)]*G[{1}, yw]*G[{1, yv^(-1), yv^(-1)}, yw])/16 - 
     (G[{0}, yv^(-1)]*G[{1}, yw]*G[{1, yv^(-1), yv^(-1)}, yw])/16 + 
     (G[{0}, yw]*G[{1}, yw]*G[{1, yv^(-1), yv^(-1)}, yw])/16 - 
     (G[{1}, yu^(-1)]*G[{1}, yw]*G[{1, yv^(-1), yv^(-1)}, yw])/32 + 
     (G[{1}, yv^(-1)]*G[{1}, yw]*G[{1, yv^(-1), yv^(-1)}, yw])/16 - 
     (3*G[{1}, yw]^2*G[{1, yv^(-1), yv^(-1)}, yw])/64 + 
     (G[{1}, yu^(-1)]*G[{yu}, yv^(-1)]*G[{1, yv^(-1), yv^(-1)}, yw])/8 + 
     (3*G[{1}, yw]*G[{yu}, yv^(-1)]*G[{1, yv^(-1), yv^(-1)}, yw])/32 - 
     (G[{yu}, yv^(-1)]^2*G[{1, yv^(-1), yv^(-1)}, yw])/16 + 
     (3*G[{0}, yu^(-1)]*G[{1/(yu*yv)}, yw]*G[{1, yv^(-1), yv^(-1)}, yw])/64 + 
     (3*G[{0}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{1, yv^(-1), yv^(-1)}, yw])/64 - 
     (3*G[{0}, yw]*G[{1/(yu*yv)}, yw]*G[{1, yv^(-1), yv^(-1)}, yw])/64 - 
     (G[{1}, yu^(-1)]*G[{1/(yu*yv)}, yw]*G[{1, yv^(-1), yv^(-1)}, yw])/64 - 
     (3*G[{1}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{1, yv^(-1), yv^(-1)}, yw])/64 + 
     (G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{1, yv^(-1), yv^(-1)}, yw])/32 - 
     (G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{1, yv^(-1), yv^(-1)}, yw])/8 - 
     (G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{1, yv^(-1), yv^(-1)}, yw])/32 - 
     (G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{1, yv^(-1), yv^(-1)}, yw])/32 + 
     (3*G[{1/(yu*yv)}, yw]^2*G[{1, yv^(-1), yv^(-1)}, yw])/64 - 
     (G[{0, 1}, yu^(-1)]*G[{1, yv^(-1), yv^(-1)}, yw])/32 - 
     (G[{0, 1}, yw]*G[{1, yv^(-1), yv^(-1)}, yw])/16 + 
     (G[{0, yu^(-1)}, yw]*G[{1, yv^(-1), yv^(-1)}, yw])/16 + 
     (G[{0, yv^(-1)}, yw]*G[{1, yv^(-1), yv^(-1)}, yw])/16 - 
     (G[{0, 1/(yu*yv)}, yw]*G[{1, yv^(-1), yv^(-1)}, yw])/16 - 
     (G[{1, yu^(-1)}, yw]*G[{1, yv^(-1), yv^(-1)}, yw])/16 + 
     (G[{1, yu}, yv^(-1)]*G[{1, yv^(-1), yv^(-1)}, yw])/32 - 
     (3*G[{1, yv^(-1)}, yw]*G[{1, yv^(-1), yv^(-1)}, yw])/32 + 
     (3*G[{1, 1/(yu*yv)}, yw]*G[{1, yv^(-1), yv^(-1)}, yw])/32 + 
     (G[{yu^(-1), 1/(yu*yv)}, yw]*G[{1, yv^(-1), yv^(-1)}, yw])/8 + 
     (G[{yv^(-1), 1/(yu*yv)}, yw]*G[{1, yv^(-1), yv^(-1)}, yw])/32 - 
     (5*Pi^2*G[{1, yv^(-1), 1/(yu*yv)}, yw])/768 - 
     (G[{0}, yu^(-1)]^2*G[{1, yv^(-1), 1/(yu*yv)}, yw])/16 - 
     (G[{0}, yu^(-1)]*G[{0}, yv^(-1)]*G[{1, yv^(-1), 1/(yu*yv)}, yw])/8 - 
     (G[{0}, yv^(-1)]^2*G[{1, yv^(-1), 1/(yu*yv)}, yw])/16 + 
     (G[{0}, yu^(-1)]*G[{0}, yw]*G[{1, yv^(-1), 1/(yu*yv)}, yw])/8 + 
     (G[{0}, yv^(-1)]*G[{0}, yw]*G[{1, yv^(-1), 1/(yu*yv)}, yw])/8 - 
     (G[{0}, yw]^2*G[{1, yv^(-1), 1/(yu*yv)}, yw])/16 + 
     (G[{0}, yu^(-1)]*G[{1}, yu^(-1)]*G[{1, yv^(-1), 1/(yu*yv)}, yw])/8 + 
     (G[{0}, yv^(-1)]*G[{1}, yu^(-1)]*G[{1, yv^(-1), 1/(yu*yv)}, yw])/8 - 
     (G[{0}, yw]*G[{1}, yu^(-1)]*G[{1, yv^(-1), 1/(yu*yv)}, yw])/8 - 
     (5*G[{1}, yu^(-1)]^2*G[{1, yv^(-1), 1/(yu*yv)}, yw])/128 - 
     (7*G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*G[{1, yv^(-1), 1/(yu*yv)}, yw])/64 + 
     (G[{1}, yv^(-1)]^2*G[{1, yv^(-1), 1/(yu*yv)}, yw])/16 - 
     (9*G[{0}, yu^(-1)]*G[{1}, yw]*G[{1, yv^(-1), 1/(yu*yv)}, yw])/64 - 
     (9*G[{0}, yv^(-1)]*G[{1}, yw]*G[{1, yv^(-1), 1/(yu*yv)}, yw])/64 + 
     (9*G[{0}, yw]*G[{1}, yw]*G[{1, yv^(-1), 1/(yu*yv)}, yw])/64 + 
     (G[{1}, yu^(-1)]*G[{1}, yw]*G[{1, yv^(-1), 1/(yu*yv)}, yw])/16 + 
     (G[{1}, yv^(-1)]*G[{1}, yw]*G[{1, yv^(-1), 1/(yu*yv)}, yw])/64 - 
     (13*G[{1}, yw]^2*G[{1, yv^(-1), 1/(yu*yv)}, yw])/128 + 
     (G[{0}, yu^(-1)]*G[{yu}, yv^(-1)]*G[{1, yv^(-1), 1/(yu*yv)}, yw])/8 + 
     (G[{0}, yv^(-1)]*G[{yu}, yv^(-1)]*G[{1, yv^(-1), 1/(yu*yv)}, yw])/8 - 
     (G[{0}, yw]*G[{yu}, yv^(-1)]*G[{1, yv^(-1), 1/(yu*yv)}, yw])/8 - 
     (G[{1}, yu^(-1)]*G[{yu}, yv^(-1)]*G[{1, yv^(-1), 1/(yu*yv)}, yw])/16 + 
     (13*G[{1}, yw]*G[{yu}, yv^(-1)]*G[{1, yv^(-1), 1/(yu*yv)}, yw])/64 - 
     (3*G[{yu}, yv^(-1)]^2*G[{1, yv^(-1), 1/(yu*yv)}, yw])/32 - 
     (7*G[{1}, yu^(-1)]*G[{1/(yu*yv)}, yw]*G[{1, yv^(-1), 1/(yu*yv)}, yw])/
      64 + (3*G[{1}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{1, yv^(-1), 1/(yu*yv)}, 
        yw])/16 + (5*G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{1, yv^(-1), 1/(yu*yv)}, 
        yw])/64 - (3*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*
       G[{1, yv^(-1), 1/(yu*yv)}, yw])/32 - 
     (5*G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{1, yv^(-1), 1/(yu*yv)}, yw])/
      64 + (13*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{1, yv^(-1), 1/(yu*yv)}, 
        yw])/64 + (G[{0, 1}, yu^(-1)]*G[{1, yv^(-1), 1/(yu*yv)}, yw])/64 - 
     (G[{0, 1}, yw]*G[{1, yv^(-1), 1/(yu*yv)}, yw])/64 + 
     (G[{0, yu^(-1)}, yw]*G[{1, yv^(-1), 1/(yu*yv)}, yw])/64 + 
     (G[{0, yv^(-1)}, yw]*G[{1, yv^(-1), 1/(yu*yv)}, yw])/64 - 
     (G[{0, 1/(yu*yv)}, yw]*G[{1, yv^(-1), 1/(yu*yv)}, yw])/64 - 
     (G[{1, yu^(-1)}, yw]*G[{1, yv^(-1), 1/(yu*yv)}, yw])/64 - 
     (G[{1, yu}, yv^(-1)]*G[{1, yv^(-1), 1/(yu*yv)}, yw])/64 - 
     (5*G[{1, 1/(yu*yv)}, yw]*G[{1, yv^(-1), 1/(yu*yv)}, yw])/64 + 
     (3*G[{yu^(-1), 1/(yu*yv)}, yw]*G[{1, yv^(-1), 1/(yu*yv)}, yw])/32 - 
     (13*G[{yv^(-1), 1/(yu*yv)}, yw]*G[{1, yv^(-1), 1/(yu*yv)}, yw])/64 - 
     (5*G[{0}, yu^(-1)]*G[{1/(yu*yv)}, yw]*G[{1, 1/(yu*yv), yu^(-1)}, yw])/
      16 - (5*G[{0}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{1, 1/(yu*yv), yu^(-1)}, 
        yw])/16 + (5*G[{0}, yw]*G[{1/(yu*yv)}, yw]*G[{1, 1/(yu*yv), yu^(-1)}, 
        yw])/16 + (G[{1}, yu^(-1)]*G[{1/(yu*yv)}, yw]*
       G[{1, 1/(yu*yv), yu^(-1)}, yw])/4 + 
     (G[{1}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{1, 1/(yu*yv), yu^(-1)}, yw])/8 - 
     (G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{1, 1/(yu*yv), yu^(-1)}, yw])/4 - 
     (G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{1, 1/(yu*yv), yu^(-1)}, yw])/4 + 
     (G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{1, 1/(yu*yv), yu^(-1)}, yw])/4 - 
     (G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{1, 1/(yu*yv), yu^(-1)}, yw])/4 + 
     (G[{yu^(-1), 1/(yu*yv)}, yw]*G[{1, 1/(yu*yv), yu^(-1)}, yw])/4 + 
     (G[{yv^(-1), 1/(yu*yv)}, yw]*G[{1, 1/(yu*yv), yu^(-1)}, yw])/4 - 
     (Pi^2*G[{1, 1/(yu*yv), yv^(-1)}, yw])/48 - 
     (G[{0}, yu^(-1)]^2*G[{1, 1/(yu*yv), yv^(-1)}, yw])/32 - 
     (G[{0}, yu^(-1)]*G[{0}, yv^(-1)]*G[{1, 1/(yu*yv), yv^(-1)}, yw])/16 - 
     (G[{0}, yv^(-1)]^2*G[{1, 1/(yu*yv), yv^(-1)}, yw])/32 + 
     (G[{0}, yu^(-1)]*G[{0}, yw]*G[{1, 1/(yu*yv), yv^(-1)}, yw])/16 + 
     (G[{0}, yv^(-1)]*G[{0}, yw]*G[{1, 1/(yu*yv), yv^(-1)}, yw])/16 - 
     (G[{0}, yw]^2*G[{1, 1/(yu*yv), yv^(-1)}, yw])/32 - 
     (G[{0}, yu^(-1)]*G[{1}, yu^(-1)]*G[{1, 1/(yu*yv), yv^(-1)}, yw])/16 - 
     (G[{0}, yv^(-1)]*G[{1}, yu^(-1)]*G[{1, 1/(yu*yv), yv^(-1)}, yw])/16 + 
     (G[{0}, yw]*G[{1}, yu^(-1)]*G[{1, 1/(yu*yv), yv^(-1)}, yw])/16 + 
     (3*G[{1}, yu^(-1)]^2*G[{1, 1/(yu*yv), yv^(-1)}, yw])/32 - 
     (G[{0}, yu^(-1)]*G[{1}, yv^(-1)]*G[{1, 1/(yu*yv), yv^(-1)}, yw])/16 - 
     (G[{0}, yv^(-1)]*G[{1}, yv^(-1)]*G[{1, 1/(yu*yv), yv^(-1)}, yw])/16 + 
     (G[{0}, yw]*G[{1}, yv^(-1)]*G[{1, 1/(yu*yv), yv^(-1)}, yw])/16 + 
     (G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*G[{1, 1/(yu*yv), yv^(-1)}, yw])/16 + 
     (3*G[{1}, yv^(-1)]^2*G[{1, 1/(yu*yv), yv^(-1)}, yw])/32 - 
     (3*G[{0}, yu^(-1)]*G[{1}, yw]*G[{1, 1/(yu*yv), yv^(-1)}, yw])/16 - 
     (3*G[{0}, yv^(-1)]*G[{1}, yw]*G[{1, 1/(yu*yv), yv^(-1)}, yw])/16 + 
     (3*G[{0}, yw]*G[{1}, yw]*G[{1, 1/(yu*yv), yv^(-1)}, yw])/16 + 
     (G[{1}, yu^(-1)]*G[{1}, yw]*G[{1, 1/(yu*yv), yv^(-1)}, yw])/16 + 
     (G[{1}, yv^(-1)]*G[{1}, yw]*G[{1, 1/(yu*yv), yv^(-1)}, yw])/16 - 
     (G[{1}, yw]^2*G[{1, 1/(yu*yv), yv^(-1)}, yw])/8 + 
     (G[{0}, yu^(-1)]*G[{yu}, yv^(-1)]*G[{1, 1/(yu*yv), yv^(-1)}, yw])/4 + 
     (G[{0}, yv^(-1)]*G[{yu}, yv^(-1)]*G[{1, 1/(yu*yv), yv^(-1)}, yw])/4 - 
     (G[{0}, yw]*G[{yu}, yv^(-1)]*G[{1, 1/(yu*yv), yv^(-1)}, yw])/4 - 
     (G[{1}, yu^(-1)]*G[{yu}, yv^(-1)]*G[{1, 1/(yu*yv), yv^(-1)}, yw])/8 + 
     (G[{1}, yw]*G[{yu}, yv^(-1)]*G[{1, 1/(yu*yv), yv^(-1)}, yw])/4 - 
     (3*G[{yu}, yv^(-1)]^2*G[{1, 1/(yu*yv), yv^(-1)}, yw])/16 + 
     (G[{0}, yu^(-1)]*G[{1/(yu*yv)}, yw]*G[{1, 1/(yu*yv), yv^(-1)}, yw])/8 + 
     (G[{0}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{1, 1/(yu*yv), yv^(-1)}, yw])/8 - 
     (G[{0}, yw]*G[{1/(yu*yv)}, yw]*G[{1, 1/(yu*yv), yv^(-1)}, yw])/8 - 
     (G[{1}, yu^(-1)]*G[{1/(yu*yv)}, yw]*G[{1, 1/(yu*yv), yv^(-1)}, yw])/4 - 
     (G[{1}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{1, 1/(yu*yv), yv^(-1)}, yw])/16 - 
     (G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{1, 1/(yu*yv), yv^(-1)}, yw])/16 + 
     (G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{1, 1/(yu*yv), yv^(-1)}, yw])/
      16 + (G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{1, 1/(yu*yv), yv^(-1)}, 
        yw])/16 + (G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*
       G[{1, 1/(yu*yv), yv^(-1)}, yw])/8 - 
     (G[{0, 1}, yv^(-1)]*G[{1, 1/(yu*yv), yv^(-1)}, yw])/8 + 
     (G[{0, 1}, yw]*G[{1, 1/(yu*yv), yv^(-1)}, yw])/16 - 
     (G[{0, yu^(-1)}, yw]*G[{1, 1/(yu*yv), yv^(-1)}, yw])/16 + 
     (G[{0, yu}, yv^(-1)]*G[{1, 1/(yu*yv), yv^(-1)}, yw])/8 - 
     (G[{0, yv^(-1)}, yw]*G[{1, 1/(yu*yv), yv^(-1)}, yw])/16 + 
     (G[{0, 1/(yu*yv)}, yw]*G[{1, 1/(yu*yv), yv^(-1)}, yw])/16 - 
     (G[{1, yu^(-1)}, yw]*G[{1, 1/(yu*yv), yv^(-1)}, yw])/16 - 
     (G[{1, yu}, yv^(-1)]*G[{1, 1/(yu*yv), yv^(-1)}, yw])/8 + 
     (G[{1, yv^(-1)}, yw]*G[{1, 1/(yu*yv), yv^(-1)}, yw])/16 + 
     (G[{1, 1/(yu*yv)}, yw]*G[{1, 1/(yu*yv), yv^(-1)}, yw])/8 - 
     (G[{yu^(-1), 1/(yu*yv)}, yw]*G[{1, 1/(yu*yv), yv^(-1)}, yw])/16 - 
     (G[{yv^(-1), 1/(yu*yv)}, yw]*G[{1, 1/(yu*yv), yv^(-1)}, yw])/8 + 
     (G[{0}, yu^(-1)]^2*G[{1, 1/(yu*yv), 1/(yu*yv)}, yw])/16 + 
     (G[{0}, yu^(-1)]*G[{0}, yv^(-1)]*G[{1, 1/(yu*yv), 1/(yu*yv)}, yw])/8 + 
     (G[{0}, yv^(-1)]^2*G[{1, 1/(yu*yv), 1/(yu*yv)}, yw])/16 - 
     (G[{0}, yu^(-1)]*G[{0}, yw]*G[{1, 1/(yu*yv), 1/(yu*yv)}, yw])/8 - 
     (G[{0}, yv^(-1)]*G[{0}, yw]*G[{1, 1/(yu*yv), 1/(yu*yv)}, yw])/8 + 
     (G[{0}, yw]^2*G[{1, 1/(yu*yv), 1/(yu*yv)}, yw])/16 - 
     (G[{0}, yu^(-1)]*G[{1}, yu^(-1)]*G[{1, 1/(yu*yv), 1/(yu*yv)}, yw])/16 - 
     (G[{0}, yv^(-1)]*G[{1}, yu^(-1)]*G[{1, 1/(yu*yv), 1/(yu*yv)}, yw])/16 + 
     (G[{0}, yw]*G[{1}, yu^(-1)]*G[{1, 1/(yu*yv), 1/(yu*yv)}, yw])/16 - 
     (5*G[{0}, yu^(-1)]*G[{1}, yv^(-1)]*G[{1, 1/(yu*yv), 1/(yu*yv)}, yw])/
      16 - (5*G[{0}, yv^(-1)]*G[{1}, yv^(-1)]*G[{1, 1/(yu*yv), 1/(yu*yv)}, 
        yw])/16 + (5*G[{0}, yw]*G[{1}, yv^(-1)]*G[{1, 1/(yu*yv), 1/(yu*yv)}, 
        yw])/16 + (5*G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*
       G[{1, 1/(yu*yv), 1/(yu*yv)}, yw])/16 + 
     (7*G[{1}, yv^(-1)]^2*G[{1, 1/(yu*yv), 1/(yu*yv)}, yw])/32 - 
     (G[{0}, yu^(-1)]*G[{1}, yw]*G[{1, 1/(yu*yv), 1/(yu*yv)}, yw])/16 - 
     (G[{0}, yv^(-1)]*G[{1}, yw]*G[{1, 1/(yu*yv), 1/(yu*yv)}, yw])/16 + 
     (G[{0}, yw]*G[{1}, yw]*G[{1, 1/(yu*yv), 1/(yu*yv)}, yw])/16 + 
     (G[{1}, yu^(-1)]*G[{1}, yw]*G[{1, 1/(yu*yv), 1/(yu*yv)}, yw])/8 + 
     (G[{1}, yv^(-1)]*G[{1}, yw]*G[{1, 1/(yu*yv), 1/(yu*yv)}, yw])/16 + 
     (G[{1}, yw]^2*G[{1, 1/(yu*yv), 1/(yu*yv)}, yw])/32 + 
     (G[{0}, yu^(-1)]*G[{yu}, yv^(-1)]*G[{1, 1/(yu*yv), 1/(yu*yv)}, yw])/8 + 
     (G[{0}, yv^(-1)]*G[{yu}, yv^(-1)]*G[{1, 1/(yu*yv), 1/(yu*yv)}, yw])/8 - 
     (G[{0}, yw]*G[{yu}, yv^(-1)]*G[{1, 1/(yu*yv), 1/(yu*yv)}, yw])/8 - 
     (3*G[{1}, yu^(-1)]*G[{yu}, yv^(-1)]*G[{1, 1/(yu*yv), 1/(yu*yv)}, yw])/
      16 - (G[{1}, yw]*G[{yu}, yv^(-1)]*G[{1, 1/(yu*yv), 1/(yu*yv)}, yw])/
      16 - (G[{yu}, yv^(-1)]^2*G[{1, 1/(yu*yv), 1/(yu*yv)}, yw])/32 - 
     (G[{0}, yu^(-1)]*G[{1/(yu*yv)}, yw]*G[{1, 1/(yu*yv), 1/(yu*yv)}, yw])/
      16 - (G[{0}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{1, 1/(yu*yv), 1/(yu*yv)}, 
        yw])/16 + (G[{0}, yw]*G[{1/(yu*yv)}, yw]*G[{1, 1/(yu*yv), 1/(yu*yv)}, 
        yw])/16 + (G[{1}, yu^(-1)]*G[{1/(yu*yv)}, yw]*
       G[{1, 1/(yu*yv), 1/(yu*yv)}, yw])/8 - 
     (G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{1, 1/(yu*yv), 1/(yu*yv)}, yw])/
      8 - (G[{0, 1}, yv^(-1)]*G[{1, 1/(yu*yv), 1/(yu*yv)}, yw])/8 + 
     (G[{0, 1}, yw]*G[{1, 1/(yu*yv), 1/(yu*yv)}, yw])/16 - 
     (G[{0, yu^(-1)}, yw]*G[{1, 1/(yu*yv), 1/(yu*yv)}, yw])/16 + 
     (G[{0, yu}, yv^(-1)]*G[{1, 1/(yu*yv), 1/(yu*yv)}, yw])/8 - 
     (G[{0, yv^(-1)}, yw]*G[{1, 1/(yu*yv), 1/(yu*yv)}, yw])/16 + 
     (G[{0, 1/(yu*yv)}, yw]*G[{1, 1/(yu*yv), 1/(yu*yv)}, yw])/16 - 
     (G[{1, yu^(-1)}, yw]*G[{1, 1/(yu*yv), 1/(yu*yv)}, yw])/16 - 
     (G[{1, yu}, yv^(-1)]*G[{1, 1/(yu*yv), 1/(yu*yv)}, yw])/8 + 
     (G[{1, yv^(-1)}, yw]*G[{1, 1/(yu*yv), 1/(yu*yv)}, yw])/16 + 
     (G[{1, 1/(yu*yv)}, yw]*G[{1, 1/(yu*yv), 1/(yu*yv)}, yw])/8 + 
     (G[{yv^(-1), 1/(yu*yv)}, yw]*G[{1, 1/(yu*yv), 1/(yu*yv)}, yw])/8 - 
     (19*Pi^2*G[{yu^(-1), yu^(-1), 1/(yu*yv)}, yw])/256 - 
     (9*G[{0}, yu^(-1)]^2*G[{yu^(-1), yu^(-1), 1/(yu*yv)}, yw])/64 - 
     (9*G[{0}, yu^(-1)]*G[{0}, yv^(-1)]*G[{yu^(-1), yu^(-1), 1/(yu*yv)}, yw])/
      32 - (9*G[{0}, yv^(-1)]^2*G[{yu^(-1), yu^(-1), 1/(yu*yv)}, yw])/64 + 
     (9*G[{0}, yu^(-1)]*G[{0}, yw]*G[{yu^(-1), yu^(-1), 1/(yu*yv)}, yw])/32 + 
     (9*G[{0}, yv^(-1)]*G[{0}, yw]*G[{yu^(-1), yu^(-1), 1/(yu*yv)}, yw])/32 - 
     (9*G[{0}, yw]^2*G[{yu^(-1), yu^(-1), 1/(yu*yv)}, yw])/64 - 
     (3*G[{0}, yu^(-1)]*G[{1}, yu^(-1)]*G[{yu^(-1), yu^(-1), 1/(yu*yv)}, yw])/
      32 - (3*G[{0}, yv^(-1)]*G[{1}, yu^(-1)]*
       G[{yu^(-1), yu^(-1), 1/(yu*yv)}, yw])/32 + 
     (3*G[{0}, yw]*G[{1}, yu^(-1)]*G[{yu^(-1), yu^(-1), 1/(yu*yv)}, yw])/32 + 
     (3*G[{1}, yu^(-1)]^2*G[{yu^(-1), yu^(-1), 1/(yu*yv)}, yw])/16 + 
     (21*G[{0}, yu^(-1)]*G[{1}, yv^(-1)]*G[{yu^(-1), yu^(-1), 1/(yu*yv)}, 
        yw])/32 + (21*G[{0}, yv^(-1)]*G[{1}, yv^(-1)]*
       G[{yu^(-1), yu^(-1), 1/(yu*yv)}, yw])/32 - 
     (21*G[{0}, yw]*G[{1}, yv^(-1)]*G[{yu^(-1), yu^(-1), 1/(yu*yv)}, yw])/
      32 - (3*G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*
       G[{yu^(-1), yu^(-1), 1/(yu*yv)}, yw])/16 - 
     (29*G[{1}, yv^(-1)]^2*G[{yu^(-1), yu^(-1), 1/(yu*yv)}, yw])/64 + 
     (G[{0}, yu^(-1)]*G[{1}, yw]*G[{yu^(-1), yu^(-1), 1/(yu*yv)}, yw])/8 + 
     (G[{0}, yv^(-1)]*G[{1}, yw]*G[{yu^(-1), yu^(-1), 1/(yu*yv)}, yw])/8 - 
     (G[{0}, yw]*G[{1}, yw]*G[{yu^(-1), yu^(-1), 1/(yu*yv)}, yw])/8 - 
     (3*G[{1}, yu^(-1)]*G[{1}, yw]*G[{yu^(-1), yu^(-1), 1/(yu*yv)}, yw])/32 + 
     (G[{1}, yv^(-1)]*G[{1}, yw]*G[{yu^(-1), yu^(-1), 1/(yu*yv)}, yw])/8 + 
     (9*G[{1}, yw]^2*G[{yu^(-1), yu^(-1), 1/(yu*yv)}, yw])/64 - 
     (25*G[{0}, yu^(-1)]*G[{yu^(-1)}, yw]*G[{yu^(-1), yu^(-1), 1/(yu*yv)}, 
        yw])/32 - (25*G[{0}, yv^(-1)]*G[{yu^(-1)}, yw]*
       G[{yu^(-1), yu^(-1), 1/(yu*yv)}, yw])/32 + 
     (25*G[{0}, yw]*G[{yu^(-1)}, yw]*G[{yu^(-1), yu^(-1), 1/(yu*yv)}, yw])/
      32 + (9*G[{1}, yu^(-1)]*G[{yu^(-1)}, yw]*
       G[{yu^(-1), yu^(-1), 1/(yu*yv)}, yw])/32 + 
     (41*G[{1}, yv^(-1)]*G[{yu^(-1)}, yw]*G[{yu^(-1), yu^(-1), 1/(yu*yv)}, 
        yw])/32 - (41*G[{yu^(-1)}, yw]^2*G[{yu^(-1), yu^(-1), 1/(yu*yv)}, 
        yw])/64 - (9*G[{1}, yw]*G[{yu}, yv^(-1)]*
       G[{yu^(-1), yu^(-1), 1/(yu*yv)}, yw])/32 - 
     (17*G[{0}, yu^(-1)]*G[{1/(yu*yv)}, yw]*G[{yu^(-1), yu^(-1), 1/(yu*yv)}, 
        yw])/64 - (17*G[{0}, yv^(-1)]*G[{1/(yu*yv)}, yw]*
       G[{yu^(-1), yu^(-1), 1/(yu*yv)}, yw])/64 + 
     (17*G[{0}, yw]*G[{1/(yu*yv)}, yw]*G[{yu^(-1), yu^(-1), 1/(yu*yv)}, yw])/
      64 - (G[{1}, yu^(-1)]*G[{1/(yu*yv)}, yw]*
       G[{yu^(-1), yu^(-1), 1/(yu*yv)}, yw])/64 + 
     (17*G[{1}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{yu^(-1), yu^(-1), 1/(yu*yv)}, 
        yw])/64 - (9*G[{1}, yw]*G[{1/(yu*yv)}, yw]*
       G[{yu^(-1), yu^(-1), 1/(yu*yv)}, yw])/32 - 
     (17*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{yu^(-1), yu^(-1), 1/(yu*yv)}, 
        yw])/64 + (9*G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw]*
       G[{yu^(-1), yu^(-1), 1/(yu*yv)}, yw])/32 - 
     (5*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{yu^(-1), yu^(-1), 1/(yu*yv)}, 
        yw])/32 + (3*G[{1/(yu*yv)}, yw]^2*G[{yu^(-1), yu^(-1), 1/(yu*yv)}, 
        yw])/64 - (G[{0, 1}, yu^(-1)]*G[{yu^(-1), yu^(-1), 1/(yu*yv)}, yw])/
      32 - (G[{0, 1}, yv^(-1)]*G[{yu^(-1), yu^(-1), 1/(yu*yv)}, yw])/4 + 
     (G[{0, 1}, yw]*G[{yu^(-1), yu^(-1), 1/(yu*yv)}, yw])/8 - 
     (G[{0, yu^(-1)}, yw]*G[{yu^(-1), yu^(-1), 1/(yu*yv)}, yw])/8 + 
     (G[{0, yu}, yv^(-1)]*G[{yu^(-1), yu^(-1), 1/(yu*yv)}, yw])/4 - 
     (G[{0, yv^(-1)}, yw]*G[{yu^(-1), yu^(-1), 1/(yu*yv)}, yw])/8 + 
     (G[{0, 1/(yu*yv)}, yw]*G[{yu^(-1), yu^(-1), 1/(yu*yv)}, yw])/8 - 
     (G[{1, yu^(-1)}, yw]*G[{yu^(-1), yu^(-1), 1/(yu*yv)}, yw])/8 - 
     (7*G[{1, yu}, yv^(-1)]*G[{yu^(-1), yu^(-1), 1/(yu*yv)}, yw])/32 + 
     (3*G[{1, yv^(-1)}, yw]*G[{yu^(-1), yu^(-1), 1/(yu*yv)}, yw])/32 + 
     (9*G[{1, 1/(yu*yv)}, yw]*G[{yu^(-1), yu^(-1), 1/(yu*yv)}, yw])/32 + 
     (5*G[{yu^(-1), 1/(yu*yv)}, yw]*G[{yu^(-1), yu^(-1), 1/(yu*yv)}, yw])/
      16 + (5*G[{yv^(-1), 1/(yu*yv)}, yw]*G[{yu^(-1), yu^(-1), 1/(yu*yv)}, 
        yw])/32 + (3*Pi^2*G[{yu^(-1), 1/(yu*yv), yv^(-1)}, yw])/256 - 
     (3*G[{0}, yu^(-1)]^2*G[{yu^(-1), 1/(yu*yv), yv^(-1)}, yw])/64 - 
     (3*G[{0}, yu^(-1)]*G[{0}, yv^(-1)]*G[{yu^(-1), 1/(yu*yv), yv^(-1)}, yw])/
      32 - (3*G[{0}, yv^(-1)]^2*G[{yu^(-1), 1/(yu*yv), yv^(-1)}, yw])/64 + 
     (3*G[{0}, yu^(-1)]*G[{0}, yw]*G[{yu^(-1), 1/(yu*yv), yv^(-1)}, yw])/32 + 
     (3*G[{0}, yv^(-1)]*G[{0}, yw]*G[{yu^(-1), 1/(yu*yv), yv^(-1)}, yw])/32 - 
     (3*G[{0}, yw]^2*G[{yu^(-1), 1/(yu*yv), yv^(-1)}, yw])/64 + 
     (7*G[{0}, yu^(-1)]*G[{1}, yu^(-1)]*G[{yu^(-1), 1/(yu*yv), yv^(-1)}, yw])/
      32 + (7*G[{0}, yv^(-1)]*G[{1}, yu^(-1)]*
       G[{yu^(-1), 1/(yu*yv), yv^(-1)}, yw])/32 - 
     (7*G[{0}, yw]*G[{1}, yu^(-1)]*G[{yu^(-1), 1/(yu*yv), yv^(-1)}, yw])/32 - 
     (G[{1}, yu^(-1)]^2*G[{yu^(-1), 1/(yu*yv), yv^(-1)}, yw])/8 - 
     (G[{0}, yu^(-1)]*G[{1}, yv^(-1)]*G[{yu^(-1), 1/(yu*yv), yv^(-1)}, yw])/
      32 - (G[{0}, yv^(-1)]*G[{1}, yv^(-1)]*G[{yu^(-1), 1/(yu*yv), yv^(-1)}, 
        yw])/32 + (G[{0}, yw]*G[{1}, yv^(-1)]*
       G[{yu^(-1), 1/(yu*yv), yv^(-1)}, yw])/32 - 
     (3*G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*G[{yu^(-1), 1/(yu*yv), yv^(-1)}, yw])/
      16 + (5*G[{1}, yv^(-1)]^2*G[{yu^(-1), 1/(yu*yv), yv^(-1)}, yw])/64 - 
     (G[{1}, yu^(-1)]*G[{1}, yw]*G[{yu^(-1), 1/(yu*yv), yv^(-1)}, yw])/32 - 
     (G[{1}, yv^(-1)]*G[{1}, yw]*G[{yu^(-1), 1/(yu*yv), yv^(-1)}, yw])/8 - 
     (5*G[{1}, yw]^2*G[{yu^(-1), 1/(yu*yv), yv^(-1)}, yw])/64 + 
     (G[{0}, yu^(-1)]*G[{yu^(-1)}, yw]*G[{yu^(-1), 1/(yu*yv), yv^(-1)}, yw])/
      32 + (G[{0}, yv^(-1)]*G[{yu^(-1)}, yw]*G[{yu^(-1), 1/(yu*yv), yv^(-1)}, 
        yw])/32 - (G[{0}, yw]*G[{yu^(-1)}, yw]*
       G[{yu^(-1), 1/(yu*yv), yv^(-1)}, yw])/32 + 
     (7*G[{1}, yu^(-1)]*G[{yu^(-1)}, yw]*G[{yu^(-1), 1/(yu*yv), yv^(-1)}, 
        yw])/32 - (9*G[{1}, yv^(-1)]*G[{yu^(-1)}, yw]*
       G[{yu^(-1), 1/(yu*yv), yv^(-1)}, yw])/32 + 
     (9*G[{yu^(-1)}, yw]^2*G[{yu^(-1), 1/(yu*yv), yv^(-1)}, yw])/64 + 
     (5*G[{1}, yw]*G[{yu}, yv^(-1)]*G[{yu^(-1), 1/(yu*yv), yv^(-1)}, yw])/
      32 - (11*G[{0}, yu^(-1)]*G[{1/(yu*yv)}, yw]*
       G[{yu^(-1), 1/(yu*yv), yv^(-1)}, yw])/64 - 
     (11*G[{0}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{yu^(-1), 1/(yu*yv), yv^(-1)}, 
        yw])/64 + (11*G[{0}, yw]*G[{1/(yu*yv)}, yw]*
       G[{yu^(-1), 1/(yu*yv), yv^(-1)}, yw])/64 + 
     (17*G[{1}, yu^(-1)]*G[{1/(yu*yv)}, yw]*G[{yu^(-1), 1/(yu*yv), yv^(-1)}, 
        yw])/64 + (7*G[{1}, yv^(-1)]*G[{1/(yu*yv)}, yw]*
       G[{yu^(-1), 1/(yu*yv), yv^(-1)}, yw])/64 + 
     (G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{yu^(-1), 1/(yu*yv), yv^(-1)}, yw])/
      32 - (7*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*
       G[{yu^(-1), 1/(yu*yv), yv^(-1)}, yw])/64 - 
     (G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{yu^(-1), 1/(yu*yv), yv^(-1)}, 
        yw])/32 - (3*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*
       G[{yu^(-1), 1/(yu*yv), yv^(-1)}, yw])/32 - 
     (3*G[{1/(yu*yv)}, yw]^2*G[{yu^(-1), 1/(yu*yv), yv^(-1)}, yw])/64 + 
     (G[{0, 1}, yu^(-1)]*G[{yu^(-1), 1/(yu*yv), yv^(-1)}, yw])/32 + 
     (G[{0, 1}, yv^(-1)]*G[{yu^(-1), 1/(yu*yv), yv^(-1)}, yw])/8 - 
     (G[{0, yu}, yv^(-1)]*G[{yu^(-1), 1/(yu*yv), yv^(-1)}, yw])/8 + 
     (G[{1, yu^(-1)}, yw]*G[{yu^(-1), 1/(yu*yv), yv^(-1)}, yw])/8 + 
     (3*G[{1, yu}, yv^(-1)]*G[{yu^(-1), 1/(yu*yv), yv^(-1)}, yw])/32 + 
     (G[{1, yv^(-1)}, yw]*G[{yu^(-1), 1/(yu*yv), yv^(-1)}, yw])/32 - 
     (5*G[{1, 1/(yu*yv)}, yw]*G[{yu^(-1), 1/(yu*yv), yv^(-1)}, yw])/32 + 
     (G[{yu^(-1), 1/(yu*yv)}, yw]*G[{yu^(-1), 1/(yu*yv), yv^(-1)}, yw])/8 + 
     (3*G[{yv^(-1), 1/(yu*yv)}, yw]*G[{yu^(-1), 1/(yu*yv), yv^(-1)}, yw])/
      32 + (5*Pi^2*G[{yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/768 - 
     (G[{0}, yu^(-1)]*G[{1}, yu^(-1)]*G[{yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/
      16 - (G[{0}, yv^(-1)]*G[{1}, yu^(-1)]*
       G[{yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/16 + 
     (G[{0}, yw]*G[{1}, yu^(-1)]*G[{yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/16 + 
     (5*G[{1}, yu^(-1)]^2*G[{yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/128 + 
     (7*G[{0}, yu^(-1)]*G[{1}, yv^(-1)]*G[{yu^(-1), 1/(yu*yv), 1/(yu*yv)}, 
        yw])/16 + (7*G[{0}, yv^(-1)]*G[{1}, yv^(-1)]*
       G[{yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/16 - 
     (7*G[{0}, yw]*G[{1}, yv^(-1)]*G[{yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/
      16 - (13*G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*
       G[{yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/64 - 
     (13*G[{1}, yv^(-1)]^2*G[{yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/32 + 
     (21*G[{0}, yu^(-1)]*G[{1}, yw]*G[{yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/
      64 + (21*G[{0}, yv^(-1)]*G[{1}, yw]*G[{yu^(-1), 1/(yu*yv), 1/(yu*yv)}, 
        yw])/64 - (21*G[{0}, yw]*G[{1}, yw]*
       G[{yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/64 - 
     (3*G[{1}, yu^(-1)]*G[{1}, yw]*G[{yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/
      16 - (5*G[{1}, yv^(-1)]*G[{1}, yw]*G[{yu^(-1), 1/(yu*yv), 1/(yu*yv)}, 
        yw])/64 + (25*G[{1}, yw]^2*G[{yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/
      128 - (25*G[{0}, yu^(-1)]*G[{yu^(-1)}, yw]*
       G[{yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/64 - 
     (25*G[{0}, yv^(-1)]*G[{yu^(-1)}, yw]*G[{yu^(-1), 1/(yu*yv), 1/(yu*yv)}, 
        yw])/64 + (25*G[{0}, yw]*G[{yu^(-1)}, yw]*
       G[{yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/64 + 
     (9*G[{1}, yu^(-1)]*G[{yu^(-1)}, yw]*G[{yu^(-1), 1/(yu*yv), 1/(yu*yv)}, 
        yw])/64 + (41*G[{1}, yv^(-1)]*G[{yu^(-1)}, yw]*
       G[{yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/64 - 
     (41*G[{yu^(-1)}, yw]^2*G[{yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/128 - 
     (3*G[{0}, yu^(-1)]*G[{yu}, yv^(-1)]*G[{yu^(-1), 1/(yu*yv), 1/(yu*yv)}, 
        yw])/8 - (3*G[{0}, yv^(-1)]*G[{yu}, yv^(-1)]*
       G[{yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/8 + 
     (3*G[{0}, yw]*G[{yu}, yv^(-1)]*G[{yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/
      8 + (G[{1}, yu^(-1)]*G[{yu}, yv^(-1)]*
       G[{yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/4 - 
     (25*G[{1}, yw]*G[{yu}, yv^(-1)]*G[{yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/
      64 + (G[{yu}, yv^(-1)]^2*G[{yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/4 + 
     (G[{0}, yu^(-1)]*G[{1/(yu*yv)}, yw]*G[{yu^(-1), 1/(yu*yv), 1/(yu*yv)}, 
        yw])/16 + (G[{0}, yv^(-1)]*G[{1/(yu*yv)}, yw]*
       G[{yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/16 - 
     (G[{0}, yw]*G[{1/(yu*yv)}, yw]*G[{yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/
      16 - (G[{1}, yu^(-1)]*G[{1/(yu*yv)}, yw]*
       G[{yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/64 - 
     (3*G[{1}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{yu^(-1), 1/(yu*yv), 1/(yu*yv)}, 
        yw])/16 - (5*G[{1}, yw]*G[{1/(yu*yv)}, yw]*
       G[{yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/64 + 
     (3*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*
       G[{yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/16 + 
     (5*G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw]*
       G[{yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/64 - 
     (5*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*
       G[{yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/64 - 
     (G[{0, 1}, yu^(-1)]*G[{yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/64 + 
     (G[{0, 1}, yv^(-1)]*G[{yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/8 - 
     (3*G[{0, 1}, yw]*G[{yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/64 + 
     (3*G[{0, yu^(-1)}, yw]*G[{yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/64 - 
     (G[{0, yu}, yv^(-1)]*G[{yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/8 + 
     (3*G[{0, yv^(-1)}, yw]*G[{yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/64 - 
     (3*G[{0, 1/(yu*yv)}, yw]*G[{yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/64 + 
     (5*G[{1, yu^(-1)}, yw]*G[{yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/64 + 
     (9*G[{1, yu}, yv^(-1)]*G[{yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/64 - 
     (G[{1, yv^(-1)}, yw]*G[{yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/16 - 
     (7*G[{1, 1/(yu*yv)}, yw]*G[{yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/64 + 
     (11*G[{yu^(-1), 1/(yu*yv)}, yw]*G[{yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/
      64 + (5*G[{yv^(-1), 1/(yu*yv)}, yw]*G[{yu^(-1), 1/(yu*yv), 1/(yu*yv)}, 
        yw])/64 + (7*Pi^2*G[{yv^(-1), yv^(-1), 1/(yu*yv)}, yw])/768 + 
     (G[{0}, yu^(-1)]^2*G[{yv^(-1), yv^(-1), 1/(yu*yv)}, yw])/64 + 
     (G[{0}, yu^(-1)]*G[{0}, yv^(-1)]*G[{yv^(-1), yv^(-1), 1/(yu*yv)}, yw])/
      32 + (G[{0}, yv^(-1)]^2*G[{yv^(-1), yv^(-1), 1/(yu*yv)}, yw])/64 - 
     (G[{0}, yu^(-1)]*G[{0}, yw]*G[{yv^(-1), yv^(-1), 1/(yu*yv)}, yw])/32 - 
     (G[{0}, yv^(-1)]*G[{0}, yw]*G[{yv^(-1), yv^(-1), 1/(yu*yv)}, yw])/32 + 
     (G[{0}, yw]^2*G[{yv^(-1), yv^(-1), 1/(yu*yv)}, yw])/64 - 
     (G[{0}, yu^(-1)]*G[{1}, yu^(-1)]*G[{yv^(-1), yv^(-1), 1/(yu*yv)}, yw])/
      32 - (G[{0}, yv^(-1)]*G[{1}, yu^(-1)]*G[{yv^(-1), yv^(-1), 1/(yu*yv)}, 
        yw])/32 + (G[{0}, yw]*G[{1}, yu^(-1)]*
       G[{yv^(-1), yv^(-1), 1/(yu*yv)}, yw])/32 - 
     (G[{1}, yu^(-1)]^2*G[{yv^(-1), yv^(-1), 1/(yu*yv)}, yw])/32 - 
     (G[{0}, yu^(-1)]*G[{1}, yv^(-1)]*G[{yv^(-1), yv^(-1), 1/(yu*yv)}, yw])/
      32 - (G[{0}, yv^(-1)]*G[{1}, yv^(-1)]*G[{yv^(-1), yv^(-1), 1/(yu*yv)}, 
        yw])/32 + (G[{0}, yw]*G[{1}, yv^(-1)]*
       G[{yv^(-1), yv^(-1), 1/(yu*yv)}, yw])/32 + 
     (G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*G[{yv^(-1), yv^(-1), 1/(yu*yv)}, yw])/
      4 + (G[{1}, yv^(-1)]^2*G[{yv^(-1), yv^(-1), 1/(yu*yv)}, yw])/64 - 
     (3*G[{0}, yu^(-1)]*G[{1}, yw]*G[{yv^(-1), yv^(-1), 1/(yu*yv)}, yw])/16 - 
     (3*G[{0}, yv^(-1)]*G[{1}, yw]*G[{yv^(-1), yv^(-1), 1/(yu*yv)}, yw])/16 + 
     (3*G[{0}, yw]*G[{1}, yw]*G[{yv^(-1), yv^(-1), 1/(yu*yv)}, yw])/16 + 
     (3*G[{1}, yu^(-1)]*G[{1}, yw]*G[{yv^(-1), yv^(-1), 1/(yu*yv)}, yw])/32 + 
     (3*G[{1}, yv^(-1)]*G[{1}, yw]*G[{yv^(-1), yv^(-1), 1/(yu*yv)}, yw])/16 - 
     (3*G[{1}, yw]^2*G[{yv^(-1), yv^(-1), 1/(yu*yv)}, yw])/64 + 
     (7*G[{0}, yu^(-1)]*G[{yu^(-1)}, yw]*G[{yv^(-1), yv^(-1), 1/(yu*yv)}, 
        yw])/32 + (7*G[{0}, yv^(-1)]*G[{yu^(-1)}, yw]*
       G[{yv^(-1), yv^(-1), 1/(yu*yv)}, yw])/32 - 
     (7*G[{0}, yw]*G[{yu^(-1)}, yw]*G[{yv^(-1), yv^(-1), 1/(yu*yv)}, yw])/
      32 - (7*G[{1}, yu^(-1)]*G[{yu^(-1)}, yw]*
       G[{yv^(-1), yv^(-1), 1/(yu*yv)}, yw])/32 - 
     (7*G[{1}, yv^(-1)]*G[{yu^(-1)}, yw]*G[{yv^(-1), yv^(-1), 1/(yu*yv)}, 
        yw])/32 + (7*G[{yu^(-1)}, yw]^2*G[{yv^(-1), yv^(-1), 1/(yu*yv)}, yw])/
      64 - (G[{1}, yu^(-1)]*G[{yu}, yv^(-1)]*G[{yv^(-1), yv^(-1), 1/(yu*yv)}, 
        yw])/8 + (3*G[{1}, yw]*G[{yu}, yv^(-1)]*
       G[{yv^(-1), yv^(-1), 1/(yu*yv)}, yw])/32 + 
     (G[{yu}, yv^(-1)]^2*G[{yv^(-1), yv^(-1), 1/(yu*yv)}, yw])/16 + 
     (7*G[{0}, yu^(-1)]*G[{yv^(-1)}, yw]*G[{yv^(-1), yv^(-1), 1/(yu*yv)}, 
        yw])/32 + (7*G[{0}, yv^(-1)]*G[{yv^(-1)}, yw]*
       G[{yv^(-1), yv^(-1), 1/(yu*yv)}, yw])/32 - 
     (7*G[{0}, yw]*G[{yv^(-1)}, yw]*G[{yv^(-1), yv^(-1), 1/(yu*yv)}, yw])/
      32 - (11*G[{1}, yu^(-1)]*G[{yv^(-1)}, yw]*
       G[{yv^(-1), yv^(-1), 1/(yu*yv)}, yw])/32 - 
     (7*G[{1}, yv^(-1)]*G[{yv^(-1)}, yw]*G[{yv^(-1), yv^(-1), 1/(yu*yv)}, 
        yw])/32 - (G[{1}, yw]*G[{yv^(-1)}, yw]*
       G[{yv^(-1), yv^(-1), 1/(yu*yv)}, yw])/8 + 
     (7*G[{yu^(-1)}, yw]*G[{yv^(-1)}, yw]*G[{yv^(-1), yv^(-1), 1/(yu*yv)}, 
        yw])/32 + (G[{yu}, yv^(-1)]*G[{yv^(-1)}, yw]*
       G[{yv^(-1), yv^(-1), 1/(yu*yv)}, yw])/8 + 
     (11*G[{yv^(-1)}, yw]^2*G[{yv^(-1), yv^(-1), 1/(yu*yv)}, yw])/64 + 
     (11*G[{0}, yu^(-1)]*G[{1/(yu*yv)}, yw]*G[{yv^(-1), yv^(-1), 1/(yu*yv)}, 
        yw])/64 + (11*G[{0}, yv^(-1)]*G[{1/(yu*yv)}, yw]*
       G[{yv^(-1), yv^(-1), 1/(yu*yv)}, yw])/64 - 
     (11*G[{0}, yw]*G[{1/(yu*yv)}, yw]*G[{yv^(-1), yv^(-1), 1/(yu*yv)}, yw])/
      64 - (17*G[{1}, yu^(-1)]*G[{1/(yu*yv)}, yw]*
       G[{yv^(-1), yv^(-1), 1/(yu*yv)}, yw])/64 - 
     (11*G[{1}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{yv^(-1), yv^(-1), 1/(yu*yv)}, 
        yw])/64 - (3*G[{1}, yw]*G[{1/(yu*yv)}, yw]*
       G[{yv^(-1), yv^(-1), 1/(yu*yv)}, yw])/32 + 
     (11*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{yv^(-1), yv^(-1), 1/(yu*yv)}, 
        yw])/64 + (3*G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw]*
       G[{yv^(-1), yv^(-1), 1/(yu*yv)}, yw])/32 + 
     (17*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{yv^(-1), yv^(-1), 1/(yu*yv)}, 
        yw])/64 + (3*G[{1/(yu*yv)}, yw]^2*G[{yv^(-1), yv^(-1), 1/(yu*yv)}, 
        yw])/64 + (7*G[{0, 1}, yu^(-1)]*G[{yv^(-1), yv^(-1), 1/(yu*yv)}, yw])/
      32 - (3*G[{0, 1}, yw]*G[{yv^(-1), yv^(-1), 1/(yu*yv)}, yw])/16 + 
     (3*G[{0, yu^(-1)}, yw]*G[{yv^(-1), yv^(-1), 1/(yu*yv)}, yw])/16 + 
     (3*G[{0, yv^(-1)}, yw]*G[{yv^(-1), yv^(-1), 1/(yu*yv)}, yw])/16 - 
     (3*G[{0, 1/(yu*yv)}, yw]*G[{yv^(-1), yv^(-1), 1/(yu*yv)}, yw])/16 - 
     (3*G[{1, yu^(-1)}, yw]*G[{yv^(-1), yv^(-1), 1/(yu*yv)}, yw])/16 - 
     (7*G[{1, yu}, yv^(-1)]*G[{yv^(-1), yv^(-1), 1/(yu*yv)}, yw])/32 + 
     (G[{1, yv^(-1)}, yw]*G[{yv^(-1), yv^(-1), 1/(yu*yv)}, yw])/32 - 
     (7*G[{1, 1/(yu*yv)}, yw]*G[{yv^(-1), yv^(-1), 1/(yu*yv)}, yw])/32 + 
     (3*G[{yu^(-1), 1/(yu*yv)}, yw]*G[{yv^(-1), yv^(-1), 1/(yu*yv)}, yw])/
      16 - (7*G[{yv^(-1), 1/(yu*yv)}, yw]*G[{yv^(-1), yv^(-1), 1/(yu*yv)}, 
        yw])/32 + (7*Pi^2*G[{yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/256 + 
     (G[{0}, yu^(-1)]^2*G[{yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/8 + 
     (G[{0}, yu^(-1)]*G[{0}, yv^(-1)]*G[{yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/
      4 + (G[{0}, yv^(-1)]^2*G[{yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/8 - 
     (G[{0}, yu^(-1)]*G[{0}, yw]*G[{yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/4 - 
     (G[{0}, yv^(-1)]*G[{0}, yw]*G[{yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/4 + 
     (G[{0}, yw]^2*G[{yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/8 - 
     (3*G[{0}, yu^(-1)]*G[{1}, yu^(-1)]*G[{yv^(-1), 1/(yu*yv), 1/(yu*yv)}, 
        yw])/8 - (3*G[{0}, yv^(-1)]*G[{1}, yu^(-1)]*
       G[{yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/8 + 
     (3*G[{0}, yw]*G[{1}, yu^(-1)]*G[{yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/
      8 + (29*G[{1}, yu^(-1)]^2*G[{yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/128 - 
     (G[{0}, yu^(-1)]*G[{1}, yv^(-1)]*G[{yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/
      4 - (G[{0}, yv^(-1)]*G[{1}, yv^(-1)]*G[{yv^(-1), 1/(yu*yv), 1/(yu*yv)}, 
        yw])/4 + (G[{0}, yw]*G[{1}, yv^(-1)]*
       G[{yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/4 + 
     (39*G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*G[{yv^(-1), 1/(yu*yv), 1/(yu*yv)}, 
        yw])/64 + (G[{1}, yv^(-1)]^2*G[{yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/
      16 - (7*G[{0}, yu^(-1)]*G[{1}, yw]*G[{yv^(-1), 1/(yu*yv), 1/(yu*yv)}, 
        yw])/64 - (7*G[{0}, yv^(-1)]*G[{1}, yw]*
       G[{yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/64 + 
     (7*G[{0}, yw]*G[{1}, yw]*G[{yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/64 + 
     (G[{1}, yu^(-1)]*G[{1}, yw]*G[{yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/16 - 
     (G[{1}, yv^(-1)]*G[{1}, yw]*G[{yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/64 - 
     (11*G[{1}, yw]^2*G[{yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/128 + 
     (15*G[{0}, yu^(-1)]*G[{yu^(-1)}, yw]*G[{yv^(-1), 1/(yu*yv), 1/(yu*yv)}, 
        yw])/64 + (15*G[{0}, yv^(-1)]*G[{yu^(-1)}, yw]*
       G[{yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/64 - 
     (15*G[{0}, yw]*G[{yu^(-1)}, yw]*G[{yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/
      64 - (23*G[{1}, yu^(-1)]*G[{yu^(-1)}, yw]*
       G[{yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/64 - 
     (7*G[{1}, yv^(-1)]*G[{yu^(-1)}, yw]*G[{yv^(-1), 1/(yu*yv), 1/(yu*yv)}, 
        yw])/64 + (7*G[{yu^(-1)}, yw]^2*G[{yv^(-1), 1/(yu*yv), 1/(yu*yv)}, 
        yw])/128 + (G[{0}, yu^(-1)]*G[{yu}, yv^(-1)]*
       G[{yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/8 + 
     (G[{0}, yv^(-1)]*G[{yu}, yv^(-1)]*G[{yv^(-1), 1/(yu*yv), 1/(yu*yv)}, 
        yw])/8 - (G[{0}, yw]*G[{yu}, yv^(-1)]*
       G[{yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/8 - 
     (5*G[{1}, yu^(-1)]*G[{yu}, yv^(-1)]*G[{yv^(-1), 1/(yu*yv), 1/(yu*yv)}, 
        yw])/16 + (11*G[{1}, yw]*G[{yu}, yv^(-1)]*
       G[{yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/64 + 
     (G[{yu}, yv^(-1)]^2*G[{yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/32 + 
     (23*G[{0}, yu^(-1)]*G[{yv^(-1)}, yw]*G[{yv^(-1), 1/(yu*yv), 1/(yu*yv)}, 
        yw])/64 + (23*G[{0}, yv^(-1)]*G[{yv^(-1)}, yw]*
       G[{yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/64 - 
     (23*G[{0}, yw]*G[{yv^(-1)}, yw]*G[{yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/
      64 - (43*G[{1}, yu^(-1)]*G[{yv^(-1)}, yw]*
       G[{yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/64 - 
     (23*G[{1}, yv^(-1)]*G[{yv^(-1)}, yw]*G[{yv^(-1), 1/(yu*yv), 1/(yu*yv)}, 
        yw])/64 - (5*G[{1}, yw]*G[{yv^(-1)}, yw]*
       G[{yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/16 + 
     (23*G[{yu^(-1)}, yw]*G[{yv^(-1)}, yw]*G[{yv^(-1), 1/(yu*yv), 1/(yu*yv)}, 
        yw])/64 + (5*G[{yu}, yv^(-1)]*G[{yv^(-1)}, yw]*
       G[{yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/16 + 
     (43*G[{yv^(-1)}, yw]^2*G[{yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/128 + 
     (G[{0}, yu^(-1)]*G[{1/(yu*yv)}, yw]*G[{yv^(-1), 1/(yu*yv), 1/(yu*yv)}, 
        yw])/8 + (G[{0}, yv^(-1)]*G[{1/(yu*yv)}, yw]*
       G[{yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/8 - 
     (G[{0}, yw]*G[{1/(yu*yv)}, yw]*G[{yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/
      8 - (9*G[{1}, yu^(-1)]*G[{1/(yu*yv)}, yw]*
       G[{yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/64 - 
     (G[{1}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{yv^(-1), 1/(yu*yv), 1/(yu*yv)}, 
        yw])/16 + (3*G[{1}, yw]*G[{1/(yu*yv)}, yw]*
       G[{yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/64 + 
     (G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{yv^(-1), 1/(yu*yv), 1/(yu*yv)}, 
        yw])/16 - (3*G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw]*
       G[{yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/64 + 
     (9*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*
       G[{yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/64 + 
     (15*G[{0, 1}, yu^(-1)]*G[{yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/64 + 
     (G[{0, 1}, yw]*G[{yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/64 - 
     (G[{0, yu^(-1)}, yw]*G[{yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/64 - 
     (G[{0, yv^(-1)}, yw]*G[{yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/64 + 
     (G[{0, 1/(yu*yv)}, yw]*G[{yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/64 + 
     (G[{1, yu^(-1)}, yw]*G[{yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/64 - 
     (15*G[{1, yu}, yv^(-1)]*G[{yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/64 + 
     (G[{1, yv^(-1)}, yw]*G[{yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/4 - 
     (15*G[{1, 1/(yu*yv)}, yw]*G[{yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/64 - 
     (G[{yu^(-1), 1/(yu*yv)}, yw]*G[{yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/
      64 + (7*G[{yv^(-1), 1/(yu*yv)}, yw]*G[{yv^(-1), 1/(yu*yv), 1/(yu*yv)}, 
        yw])/32 - (9*G[{0}, yu^(-1)]*G[{0, 0, 0, 1}, yw])/64 - 
     (9*G[{0}, yv^(-1)]*G[{0, 0, 0, 1}, yw])/64 + 
     (9*G[{0}, yw]*G[{0, 0, 0, 1}, yw])/64 + 
     (9*G[{1}, yu^(-1)]*G[{0, 0, 0, 1}, yw])/64 + 
     (9*G[{1}, yv^(-1)]*G[{0, 0, 0, 1}, yw])/64 - 
     (9*G[{1}, yw]*G[{0, 0, 0, 1}, yw])/64 - 
     (9*G[{1/(yu*yv)}, yw]*G[{0, 0, 0, 1}, yw])/64 + 
     (9*G[{0}, yu^(-1)]*G[{0, 0, 0, yu^(-1)}, yw])/64 + 
     (9*G[{0}, yv^(-1)]*G[{0, 0, 0, yu^(-1)}, yw])/64 - 
     (9*G[{0}, yw]*G[{0, 0, 0, yu^(-1)}, yw])/64 - 
     (9*G[{1}, yu^(-1)]*G[{0, 0, 0, yu^(-1)}, yw])/64 - 
     (9*G[{1}, yv^(-1)]*G[{0, 0, 0, yu^(-1)}, yw])/64 + 
     (9*G[{1}, yw]*G[{0, 0, 0, yu^(-1)}, yw])/64 + 
     (9*G[{1/(yu*yv)}, yw]*G[{0, 0, 0, yu^(-1)}, yw])/64 + 
     (9*G[{0}, yu^(-1)]*G[{0, 0, 0, yv^(-1)}, yw])/64 + 
     (9*G[{0}, yv^(-1)]*G[{0, 0, 0, yv^(-1)}, yw])/64 - 
     (9*G[{0}, yw]*G[{0, 0, 0, yv^(-1)}, yw])/64 - 
     (9*G[{1}, yu^(-1)]*G[{0, 0, 0, yv^(-1)}, yw])/64 - 
     (9*G[{1}, yv^(-1)]*G[{0, 0, 0, yv^(-1)}, yw])/64 + 
     (9*G[{1}, yw]*G[{0, 0, 0, yv^(-1)}, yw])/64 + 
     (9*G[{1/(yu*yv)}, yw]*G[{0, 0, 0, yv^(-1)}, yw])/64 - 
     (9*G[{0}, yu^(-1)]*G[{0, 0, 0, 1/(yu*yv)}, yw])/64 - 
     (9*G[{0}, yv^(-1)]*G[{0, 0, 0, 1/(yu*yv)}, yw])/64 + 
     (9*G[{0}, yw]*G[{0, 0, 0, 1/(yu*yv)}, yw])/64 + 
     (9*G[{1}, yu^(-1)]*G[{0, 0, 0, 1/(yu*yv)}, yw])/64 + 
     (9*G[{1}, yv^(-1)]*G[{0, 0, 0, 1/(yu*yv)}, yw])/64 - 
     (9*G[{1}, yw]*G[{0, 0, 0, 1/(yu*yv)}, yw])/64 - 
     (9*G[{1/(yu*yv)}, yw]*G[{0, 0, 0, 1/(yu*yv)}, yw])/64 + 
     (G[{0}, yu^(-1)]*G[{0, 0, 1, 1}, yu^(-1)])/8 + 
     (G[{0}, yv^(-1)]*G[{0, 0, 1, 1}, yu^(-1)])/8 - 
     (G[{0}, yw]*G[{0, 0, 1, 1}, yu^(-1)])/8 - 
     (G[{1}, yv^(-1)]*G[{0, 0, 1, 1}, yu^(-1)])/8 + 
     (G[{1}, yw]*G[{0, 0, 1, 1}, yu^(-1)])/8 - 
     (G[{1}, yv^(-1)]*G[{0, 0, 1, 1}, yv^(-1)])/4 + 
     (G[{1}, yw]*G[{0, 0, 1, 1}, yv^(-1)])/4 - 
     (G[{0}, yu^(-1)]*G[{0, 0, 1, 1}, yw])/16 - 
     (G[{0}, yv^(-1)]*G[{0, 0, 1, 1}, yw])/16 + 
     (G[{0}, yw]*G[{0, 0, 1, 1}, yw])/16 + 
     (G[{1}, yu^(-1)]*G[{0, 0, 1, 1}, yw])/4 + 
     (G[{1}, yv^(-1)]*G[{0, 0, 1, 1}, yw])/16 + 
     (G[{1}, yw]*G[{0, 0, 1, 1}, yw])/32 - 
     (3*G[{yu}, yv^(-1)]*G[{0, 0, 1, 1}, yw])/16 - 
     (7*G[{1/(yu*yv)}, yw]*G[{0, 0, 1, 1}, yw])/32 - 
     (13*G[{0}, yu^(-1)]*G[{0, 0, 1, yu^(-1)}, yw])/64 - 
     (13*G[{0}, yv^(-1)]*G[{0, 0, 1, yu^(-1)}, yw])/64 + 
     (13*G[{0}, yw]*G[{0, 0, 1, yu^(-1)}, yw])/64 + 
     (G[{1}, yu^(-1)]*G[{0, 0, 1, yu^(-1)}, yw])/64 + 
     (25*G[{1}, yv^(-1)]*G[{0, 0, 1, yu^(-1)}, yw])/64 - 
     (11*G[{1}, yw]*G[{0, 0, 1, yu^(-1)}, yw])/64 + 
     (5*G[{1/(yu*yv)}, yw]*G[{0, 0, 1, yu^(-1)}, yw])/64 + 
     (G[{0}, yu^(-1)]*G[{0, 0, 1, yu}, yv^(-1)])/16 + 
     (G[{0}, yv^(-1)]*G[{0, 0, 1, yu}, yv^(-1)])/16 - 
     (G[{0}, yw]*G[{0, 0, 1, yu}, yv^(-1)])/16 + 
     (G[{1}, yv^(-1)]*G[{0, 0, 1, yu}, yv^(-1)])/8 - 
     (G[{1}, yw]*G[{0, 0, 1, yu}, yv^(-1)])/8 + 
     (7*G[{0}, yu^(-1)]*G[{0, 0, 1, yv^(-1)}, yw])/64 + 
     (7*G[{0}, yv^(-1)]*G[{0, 0, 1, yv^(-1)}, yw])/64 - 
     (7*G[{0}, yw]*G[{0, 0, 1, yv^(-1)}, yw])/64 - 
     (7*G[{1}, yu^(-1)]*G[{0, 0, 1, yv^(-1)}, yw])/64 - 
     (7*G[{1}, yv^(-1)]*G[{0, 0, 1, yv^(-1)}, yw])/64 - 
     (11*G[{1}, yw]*G[{0, 0, 1, yv^(-1)}, yw])/64 + 
     (5*G[{1/(yu*yv)}, yw]*G[{0, 0, 1, yv^(-1)}, yw])/64 + 
     (G[{0}, yu^(-1)]*G[{0, 0, 1, 1/(yu*yv)}, yw])/16 + 
     (G[{0}, yv^(-1)]*G[{0, 0, 1, 1/(yu*yv)}, yw])/16 - 
     (G[{0}, yw]*G[{0, 0, 1, 1/(yu*yv)}, yw])/16 - 
     (5*G[{1}, yv^(-1)]*G[{0, 0, 1, 1/(yu*yv)}, yw])/16 + 
     (9*G[{1}, yw]*G[{0, 0, 1, 1/(yu*yv)}, yw])/32 + 
     (3*G[{yu}, yv^(-1)]*G[{0, 0, 1, 1/(yu*yv)}, yw])/16 - 
     (3*G[{1/(yu*yv)}, yw]*G[{0, 0, 1, 1/(yu*yv)}, yw])/32 - 
     (G[{0}, yu^(-1)]*G[{0, 0, yu^(-1), 1}, yw])/4 - 
     (G[{0}, yv^(-1)]*G[{0, 0, yu^(-1), 1}, yw])/4 + 
     (G[{0}, yw]*G[{0, 0, yu^(-1), 1}, yw])/4 + 
     (5*G[{1}, yv^(-1)]*G[{0, 0, yu^(-1), 1}, yw])/16 - 
     (9*G[{1}, yw]*G[{0, 0, yu^(-1), 1}, yw])/32 + 
     (3*G[{yu}, yv^(-1)]*G[{0, 0, yu^(-1), 1}, yw])/16 + 
     (3*G[{1/(yu*yv)}, yw]*G[{0, 0, yu^(-1), 1}, yw])/32 + 
     (25*G[{0}, yu^(-1)]*G[{0, 0, yu^(-1), yu^(-1)}, yw])/64 + 
     (25*G[{0}, yv^(-1)]*G[{0, 0, yu^(-1), yu^(-1)}, yw])/64 - 
     (25*G[{0}, yw]*G[{0, 0, yu^(-1), yu^(-1)}, yw])/64 - 
     (9*G[{1}, yu^(-1)]*G[{0, 0, yu^(-1), yu^(-1)}, yw])/64 - 
     (41*G[{1}, yv^(-1)]*G[{0, 0, yu^(-1), yu^(-1)}, yw])/64 + 
     (19*G[{1}, yw]*G[{0, 0, yu^(-1), yu^(-1)}, yw])/64 + 
     (3*G[{1/(yu*yv)}, yw]*G[{0, 0, yu^(-1), yu^(-1)}, yw])/64 - 
     (7*G[{0}, yu^(-1)]*G[{0, 0, yu^(-1), yv^(-1)}, yw])/64 - 
     (7*G[{0}, yv^(-1)]*G[{0, 0, yu^(-1), yv^(-1)}, yw])/64 + 
     (7*G[{0}, yw]*G[{0, 0, yu^(-1), yv^(-1)}, yw])/64 + 
     (7*G[{1}, yu^(-1)]*G[{0, 0, yu^(-1), yv^(-1)}, yw])/64 + 
     (7*G[{1}, yv^(-1)]*G[{0, 0, yu^(-1), yv^(-1)}, yw])/64 + 
     (3*G[{1}, yw]*G[{0, 0, yu^(-1), yv^(-1)}, yw])/64 - 
     (5*G[{1/(yu*yv)}, yw]*G[{0, 0, yu^(-1), yv^(-1)}, yw])/64 - 
     (G[{0}, yu^(-1)]*G[{0, 0, yu^(-1), 1/(yu*yv)}, yw])/16 - 
     (G[{0}, yv^(-1)]*G[{0, 0, yu^(-1), 1/(yu*yv)}, yw])/16 + 
     (G[{0}, yw]*G[{0, 0, yu^(-1), 1/(yu*yv)}, yw])/16 + 
     (5*G[{1}, yv^(-1)]*G[{0, 0, yu^(-1), 1/(yu*yv)}, yw])/16 - 
     (5*G[{1}, yw]*G[{0, 0, yu^(-1), 1/(yu*yv)}, yw])/32 - 
     (3*G[{yu}, yv^(-1)]*G[{0, 0, yu^(-1), 1/(yu*yv)}, yw])/16 + 
     (3*G[{1/(yu*yv)}, yw]*G[{0, 0, yu^(-1), 1/(yu*yv)}, yw])/32 + 
     (G[{0}, yu^(-1)]*G[{0, 0, yu, 1}, yv^(-1)])/16 + 
     (G[{0}, yv^(-1)]*G[{0, 0, yu, 1}, yv^(-1)])/16 - 
     (G[{0}, yw]*G[{0, 0, yu, 1}, yv^(-1)])/16 + 
     (G[{1}, yv^(-1)]*G[{0, 0, yu, 1}, yv^(-1)])/8 - 
     (G[{1}, yw]*G[{0, 0, yu, 1}, yv^(-1)])/8 - 
     (G[{1}, yv^(-1)]*G[{0, 0, yu, yu}, yv^(-1)])/8 + 
     (G[{1}, yw]*G[{0, 0, yu, yu}, yv^(-1)])/8 + 
     (G[{0}, yu^(-1)]*G[{0, 0, yv^(-1), 1}, yw])/16 + 
     (G[{0}, yv^(-1)]*G[{0, 0, yv^(-1), 1}, yw])/16 - 
     (G[{0}, yw]*G[{0, 0, yv^(-1), 1}, yw])/16 - 
     (G[{1}, yv^(-1)]*G[{0, 0, yv^(-1), 1}, yw])/16 - 
     (9*G[{1}, yw]*G[{0, 0, yv^(-1), 1}, yw])/32 - 
     (G[{yu}, yv^(-1)]*G[{0, 0, yv^(-1), 1}, yw])/16 + 
     (3*G[{1/(yu*yv)}, yw]*G[{0, 0, yv^(-1), 1}, yw])/32 - 
     (7*G[{0}, yu^(-1)]*G[{0, 0, yv^(-1), yu^(-1)}, yw])/64 - 
     (7*G[{0}, yv^(-1)]*G[{0, 0, yv^(-1), yu^(-1)}, yw])/64 + 
     (7*G[{0}, yw]*G[{0, 0, yv^(-1), yu^(-1)}, yw])/64 + 
     (7*G[{1}, yu^(-1)]*G[{0, 0, yv^(-1), yu^(-1)}, yw])/64 + 
     (7*G[{1}, yv^(-1)]*G[{0, 0, yv^(-1), yu^(-1)}, yw])/64 + 
     (3*G[{1}, yw]*G[{0, 0, yv^(-1), yu^(-1)}, yw])/64 - 
     (5*G[{1/(yu*yv)}, yw]*G[{0, 0, yv^(-1), yu^(-1)}, yw])/64 - 
     (7*G[{0}, yu^(-1)]*G[{0, 0, yv^(-1), yv^(-1)}, yw])/64 - 
     (7*G[{0}, yv^(-1)]*G[{0, 0, yv^(-1), yv^(-1)}, yw])/64 + 
     (7*G[{0}, yw]*G[{0, 0, yv^(-1), yv^(-1)}, yw])/64 + 
     (7*G[{1}, yu^(-1)]*G[{0, 0, yv^(-1), yv^(-1)}, yw])/64 + 
     (7*G[{1}, yv^(-1)]*G[{0, 0, yv^(-1), yv^(-1)}, yw])/64 + 
     (11*G[{1}, yw]*G[{0, 0, yv^(-1), yv^(-1)}, yw])/64 + 
     (3*G[{1/(yu*yv)}, yw]*G[{0, 0, yv^(-1), yv^(-1)}, yw])/64 + 
     (G[{0}, yu^(-1)]*G[{0, 0, yv^(-1), 1/(yu*yv)}, yw])/8 + 
     (G[{0}, yv^(-1)]*G[{0, 0, yv^(-1), 1/(yu*yv)}, yw])/8 - 
     (G[{0}, yw]*G[{0, 0, yv^(-1), 1/(yu*yv)}, yw])/8 - 
     (G[{1}, yu^(-1)]*G[{0, 0, yv^(-1), 1/(yu*yv)}, yw])/8 + 
     (G[{1}, yv^(-1)]*G[{0, 0, yv^(-1), 1/(yu*yv)}, yw])/16 - 
     (G[{1}, yw]*G[{0, 0, yv^(-1), 1/(yu*yv)}, yw])/32 - 
     (3*G[{yu}, yv^(-1)]*G[{0, 0, yv^(-1), 1/(yu*yv)}, yw])/16 + 
     (3*G[{1/(yu*yv)}, yw]*G[{0, 0, yv^(-1), 1/(yu*yv)}, yw])/32 + 
     (G[{0}, yu^(-1)]*G[{0, 0, 1/(yu*yv), 1}, yw])/4 + 
     (G[{0}, yv^(-1)]*G[{0, 0, 1/(yu*yv), 1}, yw])/4 - 
     (G[{0}, yw]*G[{0, 0, 1/(yu*yv), 1}, yw])/4 - 
     (G[{1}, yu^(-1)]*G[{0, 0, 1/(yu*yv), 1}, yw])/4 - 
     (5*G[{1}, yv^(-1)]*G[{0, 0, 1/(yu*yv), 1}, yw])/16 + 
     (17*G[{1}, yw]*G[{0, 0, 1/(yu*yv), 1}, yw])/32 + 
     (G[{yu}, yv^(-1)]*G[{0, 0, 1/(yu*yv), 1}, yw])/16 + 
     (G[{1/(yu*yv)}, yw]*G[{0, 0, 1/(yu*yv), 1}, yw])/32 - 
     (13*G[{0}, yu^(-1)]*G[{0, 0, 1/(yu*yv), yu^(-1)}, yw])/64 - 
     (13*G[{0}, yv^(-1)]*G[{0, 0, 1/(yu*yv), yu^(-1)}, yw])/64 + 
     (13*G[{0}, yw]*G[{0, 0, 1/(yu*yv), yu^(-1)}, yw])/64 + 
     (9*G[{1}, yu^(-1)]*G[{0, 0, 1/(yu*yv), yu^(-1)}, yw])/64 + 
     (17*G[{1}, yv^(-1)]*G[{0, 0, 1/(yu*yv), yu^(-1)}, yw])/64 - 
     (19*G[{1}, yw]*G[{0, 0, 1/(yu*yv), yu^(-1)}, yw])/64 - 
     (3*G[{1/(yu*yv)}, yw]*G[{0, 0, 1/(yu*yv), yu^(-1)}, yw])/64 - 
     (G[{0}, yu^(-1)]*G[{0, 0, 1/(yu*yv), yv^(-1)}, yw])/64 - 
     (G[{0}, yv^(-1)]*G[{0, 0, 1/(yu*yv), yv^(-1)}, yw])/64 + 
     (G[{0}, yw]*G[{0, 0, 1/(yu*yv), yv^(-1)}, yw])/64 + 
     (9*G[{1}, yu^(-1)]*G[{0, 0, 1/(yu*yv), yv^(-1)}, yw])/64 + 
     (9*G[{1}, yv^(-1)]*G[{0, 0, 1/(yu*yv), yv^(-1)}, yw])/64 - 
     (11*G[{1}, yw]*G[{0, 0, 1/(yu*yv), yv^(-1)}, yw])/64 - 
     (G[{yu}, yv^(-1)]*G[{0, 0, 1/(yu*yv), yv^(-1)}, yw])/4 - 
     (3*G[{1/(yu*yv)}, yw]*G[{0, 0, 1/(yu*yv), yv^(-1)}, yw])/64 - 
     (G[{0}, yu^(-1)]*G[{0, 0, 1/(yu*yv), 1/(yu*yv)}, yw])/8 - 
     (G[{0}, yv^(-1)]*G[{0, 0, 1/(yu*yv), 1/(yu*yv)}, yw])/8 + 
     (G[{0}, yw]*G[{0, 0, 1/(yu*yv), 1/(yu*yv)}, yw])/8 + 
     (G[{1}, yu^(-1)]*G[{0, 0, 1/(yu*yv), 1/(yu*yv)}, yw])/8 - 
     (G[{1}, yv^(-1)]*G[{0, 0, 1/(yu*yv), 1/(yu*yv)}, yw])/16 - 
     (3*G[{1}, yw]*G[{0, 0, 1/(yu*yv), 1/(yu*yv)}, yw])/32 + 
     (3*G[{yu}, yv^(-1)]*G[{0, 0, 1/(yu*yv), 1/(yu*yv)}, yw])/16 - 
     (3*G[{1/(yu*yv)}, yw]*G[{0, 0, 1/(yu*yv), 1/(yu*yv)}, yw])/32 - 
     (G[{0}, yu^(-1)]*G[{0, 1, 0, yu^(-1)}, yw])/16 - 
     (G[{0}, yv^(-1)]*G[{0, 1, 0, yu^(-1)}, yw])/16 + 
     (G[{0}, yw]*G[{0, 1, 0, yu^(-1)}, yw])/16 + 
     (G[{1}, yu^(-1)]*G[{0, 1, 0, yu^(-1)}, yw])/16 + 
     (G[{1}, yv^(-1)]*G[{0, 1, 0, yu^(-1)}, yw])/16 - 
     (G[{1}, yw]*G[{0, 1, 0, yu^(-1)}, yw])/16 + 
     (G[{0}, yu^(-1)]*G[{0, 1, 0, yu}, yv^(-1)])/16 + 
     (G[{0}, yv^(-1)]*G[{0, 1, 0, yu}, yv^(-1)])/16 - 
     (G[{0}, yw]*G[{0, 1, 0, yu}, yv^(-1)])/16 - 
     (G[{1}, yv^(-1)]*G[{0, 1, 0, yu}, yv^(-1)])/16 + 
     (G[{1}, yw]*G[{0, 1, 0, yu}, yv^(-1)])/16 + 
     (G[{1}, yu^(-1)]*G[{0, 1, 0, yv^(-1)}, yw])/8 - 
     (G[{1}, yw]*G[{0, 1, 0, yv^(-1)}, yw])/8 - 
     (G[{yu}, yv^(-1)]*G[{0, 1, 0, yv^(-1)}, yw])/8 + 
     (G[{0}, yu^(-1)]*G[{0, 1, 0, 1/(yu*yv)}, yw])/16 + 
     (G[{0}, yv^(-1)]*G[{0, 1, 0, 1/(yu*yv)}, yw])/16 - 
     (G[{0}, yw]*G[{0, 1, 0, 1/(yu*yv)}, yw])/16 - 
     (3*G[{1}, yu^(-1)]*G[{0, 1, 0, 1/(yu*yv)}, yw])/16 - 
     (G[{1}, yv^(-1)]*G[{0, 1, 0, 1/(yu*yv)}, yw])/16 + 
     (3*G[{1}, yw]*G[{0, 1, 0, 1/(yu*yv)}, yw])/16 + 
     (G[{yu}, yv^(-1)]*G[{0, 1, 0, 1/(yu*yv)}, yw])/8 + 
     (3*G[{0}, yu^(-1)]*G[{0, 1, 1, 1}, yu^(-1)])/16 + 
     (3*G[{0}, yv^(-1)]*G[{0, 1, 1, 1}, yu^(-1)])/16 - 
     (3*G[{0}, yw]*G[{0, 1, 1, 1}, yu^(-1)])/16 - 
     (3*G[{1}, yv^(-1)]*G[{0, 1, 1, 1}, yu^(-1)])/16 + 
     (3*G[{1}, yw]*G[{0, 1, 1, 1}, yu^(-1)])/16 - 
     (3*G[{1}, yu^(-1)]*G[{0, 1, 1, 1}, yv^(-1)])/16 - 
     (3*G[{1}, yv^(-1)]*G[{0, 1, 1, 1}, yv^(-1)])/8 + 
     (3*G[{1}, yw]*G[{0, 1, 1, 1}, yv^(-1)])/8 - 
     (9*G[{0}, yu^(-1)]*G[{0, 1, 1, 1}, yw])/64 - 
     (9*G[{0}, yv^(-1)]*G[{0, 1, 1, 1}, yw])/64 + 
     (9*G[{0}, yw]*G[{0, 1, 1, 1}, yw])/64 + 
     (17*G[{1}, yu^(-1)]*G[{0, 1, 1, 1}, yw])/64 + 
     (9*G[{1}, yv^(-1)]*G[{0, 1, 1, 1}, yw])/64 - 
     (G[{1}, yw]*G[{0, 1, 1, 1}, yw])/16 - 
     (G[{yu}, yv^(-1)]*G[{0, 1, 1, 1}, yw])/8 - 
     (G[{1/(yu*yv)}, yw]*G[{0, 1, 1, 1}, yw])/8 + 
     (5*G[{0}, yu^(-1)]*G[{0, 1, 1, yu^(-1)}, yw])/64 + 
     (5*G[{0}, yv^(-1)]*G[{0, 1, 1, yu^(-1)}, yw])/64 - 
     (5*G[{0}, yw]*G[{0, 1, 1, yu^(-1)}, yw])/64 - 
     (G[{1}, yu^(-1)]*G[{0, 1, 1, yu^(-1)}, yw])/64 - 
     (9*G[{1}, yv^(-1)]*G[{0, 1, 1, yu^(-1)}, yw])/64 + 
     (5*G[{1}, yw]*G[{0, 1, 1, yu^(-1)}, yw])/32 - 
     (3*G[{1/(yu*yv)}, yw]*G[{0, 1, 1, yu^(-1)}, yw])/32 + 
     (3*G[{0}, yu^(-1)]*G[{0, 1, 1, yu}, yv^(-1)])/16 + 
     (3*G[{0}, yv^(-1)]*G[{0, 1, 1, yu}, yv^(-1)])/16 - 
     (3*G[{0}, yw]*G[{0, 1, 1, yu}, yv^(-1)])/16 - 
     (G[{1}, yu^(-1)]*G[{0, 1, 1, yu}, yv^(-1)])/8 - 
     (3*G[{1}, yv^(-1)]*G[{0, 1, 1, yu}, yv^(-1)])/16 + 
     (3*G[{1}, yw]*G[{0, 1, 1, yu}, yv^(-1)])/16 + 
     (G[{1/(yu*yv)}, yw]*G[{0, 1, 1, yu}, yv^(-1)])/8 + 
     (G[{0}, yu^(-1)]*G[{0, 1, 1, yv^(-1)}, yw])/64 + 
     (G[{0}, yv^(-1)]*G[{0, 1, 1, yv^(-1)}, yw])/64 - 
     (G[{0}, yw]*G[{0, 1, 1, yv^(-1)}, yw])/64 - 
     (9*G[{1}, yu^(-1)]*G[{0, 1, 1, yv^(-1)}, yw])/64 - 
     (G[{1}, yv^(-1)]*G[{0, 1, 1, yv^(-1)}, yw])/64 + 
     (7*G[{1}, yw]*G[{0, 1, 1, yv^(-1)}, yw])/32 + 
     (G[{yu}, yv^(-1)]*G[{0, 1, 1, yv^(-1)}, yw])/8 - 
     (3*G[{1/(yu*yv)}, yw]*G[{0, 1, 1, yv^(-1)}, yw])/32 + 
     (3*G[{0}, yu^(-1)]*G[{0, 1, 1, 1/(yu*yv)}, yw])/64 + 
     (3*G[{0}, yv^(-1)]*G[{0, 1, 1, 1/(yu*yv)}, yw])/64 - 
     (3*G[{0}, yw]*G[{0, 1, 1, 1/(yu*yv)}, yw])/64 + 
     (13*G[{1}, yu^(-1)]*G[{0, 1, 1, 1/(yu*yv)}, yw])/64 + 
     (G[{1}, yv^(-1)]*G[{0, 1, 1, 1/(yu*yv)}, yw])/64 - 
     (5*G[{yu}, yv^(-1)]*G[{0, 1, 1, 1/(yu*yv)}, yw])/16 + 
     (17*G[{0}, yu^(-1)]*G[{0, 1, yu^(-1), 1}, yw])/64 + 
     (17*G[{0}, yv^(-1)]*G[{0, 1, yu^(-1), 1}, yw])/64 - 
     (17*G[{0}, yw]*G[{0, 1, yu^(-1), 1}, yw])/64 - 
     (5*G[{1}, yu^(-1)]*G[{0, 1, yu^(-1), 1}, yw])/64 - 
     (17*G[{1}, yv^(-1)]*G[{0, 1, yu^(-1), 1}, yw])/64 + 
     (9*G[{1}, yw]*G[{0, 1, yu^(-1), 1}, yw])/32 - 
     (3*G[{yu}, yv^(-1)]*G[{0, 1, yu^(-1), 1}, yw])/16 - 
     (3*G[{1/(yu*yv)}, yw]*G[{0, 1, yu^(-1), 1}, yw])/32 - 
     (13*G[{0}, yu^(-1)]*G[{0, 1, yu^(-1), yu^(-1)}, yw])/32 - 
     (13*G[{0}, yv^(-1)]*G[{0, 1, yu^(-1), yu^(-1)}, yw])/32 + 
     (13*G[{0}, yw]*G[{0, 1, yu^(-1), yu^(-1)}, yw])/32 + 
     (G[{1}, yu^(-1)]*G[{0, 1, yu^(-1), yu^(-1)}, yw])/32 + 
     (25*G[{1}, yv^(-1)]*G[{0, 1, yu^(-1), yu^(-1)}, yw])/32 - 
     (21*G[{1}, yw]*G[{0, 1, yu^(-1), yu^(-1)}, yw])/64 + 
     (11*G[{1/(yu*yv)}, yw]*G[{0, 1, yu^(-1), yu^(-1)}, yw])/64 + 
     (3*G[{0}, yu^(-1)]*G[{0, 1, yu^(-1), yv^(-1)}, yw])/32 + 
     (3*G[{0}, yv^(-1)]*G[{0, 1, yu^(-1), yv^(-1)}, yw])/32 - 
     (3*G[{0}, yw]*G[{0, 1, yu^(-1), yv^(-1)}, yw])/32 - 
     (7*G[{1}, yu^(-1)]*G[{0, 1, yu^(-1), yv^(-1)}, yw])/32 + 
     (G[{1}, yv^(-1)]*G[{0, 1, yu^(-1), yv^(-1)}, yw])/32 - 
     (5*G[{1}, yw]*G[{0, 1, yu^(-1), yv^(-1)}, yw])/64 + 
     (11*G[{1/(yu*yv)}, yw]*G[{0, 1, yu^(-1), yv^(-1)}, yw])/64 - 
     (7*G[{0}, yu^(-1)]*G[{0, 1, yu^(-1), 1/(yu*yv)}, yw])/64 - 
     (7*G[{0}, yv^(-1)]*G[{0, 1, yu^(-1), 1/(yu*yv)}, yw])/64 + 
     (7*G[{0}, yw]*G[{0, 1, yu^(-1), 1/(yu*yv)}, yw])/64 + 
     (11*G[{1}, yu^(-1)]*G[{0, 1, yu^(-1), 1/(yu*yv)}, yw])/64 - 
     (9*G[{1}, yv^(-1)]*G[{0, 1, yu^(-1), 1/(yu*yv)}, yw])/64 - 
     (3*G[{1}, yw]*G[{0, 1, yu^(-1), 1/(yu*yv)}, yw])/32 + 
     (3*G[{yu}, yv^(-1)]*G[{0, 1, yu^(-1), 1/(yu*yv)}, yw])/16 - 
     (3*G[{1/(yu*yv)}, yw]*G[{0, 1, yu^(-1), 1/(yu*yv)}, yw])/32 + 
     (G[{0}, yu^(-1)]*G[{0, 1, yu, 1}, yv^(-1)])/8 + 
     (G[{0}, yv^(-1)]*G[{0, 1, yu, 1}, yv^(-1)])/8 - 
     (G[{0}, yw]*G[{0, 1, yu, 1}, yv^(-1)])/8 - 
     (G[{1}, yu^(-1)]*G[{0, 1, yu, 1}, yv^(-1)])/16 - 
     (G[{1}, yv^(-1)]*G[{0, 1, yu, 1}, yv^(-1)])/8 + 
     (G[{1}, yw]*G[{0, 1, yu, 1}, yv^(-1)])/8 + 
     (G[{1/(yu*yv)}, yw]*G[{0, 1, yu, 1}, yv^(-1)])/8 - 
     (G[{0}, yu^(-1)]*G[{0, 1, yu, yu}, yv^(-1)])/4 - 
     (G[{0}, yv^(-1)]*G[{0, 1, yu, yu}, yv^(-1)])/4 + 
     (G[{0}, yw]*G[{0, 1, yu, yu}, yv^(-1)])/4 + 
     (G[{1}, yu^(-1)]*G[{0, 1, yu, yu}, yv^(-1)])/4 + 
     (G[{1}, yv^(-1)]*G[{0, 1, yu, yu}, yv^(-1)])/2 - 
     (G[{1}, yw]*G[{0, 1, yu, yu}, yv^(-1)])/2 - 
     (G[{1/(yu*yv)}, yw]*G[{0, 1, yu, yu}, yv^(-1)])/8 + 
     (G[{0}, yu^(-1)]*G[{0, 1, yv^(-1), 1}, yw])/64 + 
     (G[{0}, yv^(-1)]*G[{0, 1, yv^(-1), 1}, yw])/64 - 
     (G[{0}, yw]*G[{0, 1, yv^(-1), 1}, yw])/64 - 
     (9*G[{1}, yu^(-1)]*G[{0, 1, yv^(-1), 1}, yw])/64 - 
     (G[{1}, yv^(-1)]*G[{0, 1, yv^(-1), 1}, yw])/64 + 
     (9*G[{1}, yw]*G[{0, 1, yv^(-1), 1}, yw])/32 + 
     (G[{yu}, yv^(-1)]*G[{0, 1, yv^(-1), 1}, yw])/8 - 
     (3*G[{1/(yu*yv)}, yw]*G[{0, 1, yv^(-1), 1}, yw])/32 + 
     (3*G[{0}, yu^(-1)]*G[{0, 1, yv^(-1), yu^(-1)}, yw])/32 + 
     (3*G[{0}, yv^(-1)]*G[{0, 1, yv^(-1), yu^(-1)}, yw])/32 - 
     (3*G[{0}, yw]*G[{0, 1, yv^(-1), yu^(-1)}, yw])/32 - 
     (7*G[{1}, yu^(-1)]*G[{0, 1, yv^(-1), yu^(-1)}, yw])/32 + 
     (G[{1}, yv^(-1)]*G[{0, 1, yv^(-1), yu^(-1)}, yw])/32 - 
     (5*G[{1}, yw]*G[{0, 1, yv^(-1), yu^(-1)}, yw])/64 + 
     (11*G[{1/(yu*yv)}, yw]*G[{0, 1, yv^(-1), yu^(-1)}, yw])/64 + 
     (7*G[{0}, yu^(-1)]*G[{0, 1, yv^(-1), yv^(-1)}, yw])/32 + 
     (7*G[{0}, yv^(-1)]*G[{0, 1, yv^(-1), yv^(-1)}, yw])/32 - 
     (7*G[{0}, yw]*G[{0, 1, yv^(-1), yv^(-1)}, yw])/32 - 
     (7*G[{1}, yu^(-1)]*G[{0, 1, yv^(-1), yv^(-1)}, yw])/32 - 
     (7*G[{1}, yv^(-1)]*G[{0, 1, yv^(-1), yv^(-1)}, yw])/32 - 
     (13*G[{1}, yw]*G[{0, 1, yv^(-1), yv^(-1)}, yw])/64 + 
     (11*G[{1/(yu*yv)}, yw]*G[{0, 1, yv^(-1), yv^(-1)}, yw])/64 - 
     (11*G[{0}, yu^(-1)]*G[{0, 1, yv^(-1), 1/(yu*yv)}, yw])/64 - 
     (11*G[{0}, yv^(-1)]*G[{0, 1, yv^(-1), 1/(yu*yv)}, yw])/64 + 
     (11*G[{0}, yw]*G[{0, 1, yv^(-1), 1/(yu*yv)}, yw])/64 + 
     (15*G[{1}, yu^(-1)]*G[{0, 1, yv^(-1), 1/(yu*yv)}, yw])/64 - 
     (G[{1}, yv^(-1)]*G[{0, 1, yv^(-1), 1/(yu*yv)}, yw])/64 - 
     (3*G[{1}, yw]*G[{0, 1, yv^(-1), 1/(yu*yv)}, yw])/32 + 
     (G[{yu}, yv^(-1)]*G[{0, 1, yv^(-1), 1/(yu*yv)}, yw])/8 - 
     (3*G[{1/(yu*yv)}, yw]*G[{0, 1, yv^(-1), 1/(yu*yv)}, yw])/32 - 
     (9*G[{0}, yu^(-1)]*G[{0, 1, 1/(yu*yv), 1}, yw])/64 - 
     (9*G[{0}, yv^(-1)]*G[{0, 1, 1/(yu*yv), 1}, yw])/64 + 
     (9*G[{0}, yw]*G[{0, 1, 1/(yu*yv), 1}, yw])/64 + 
     (17*G[{1}, yu^(-1)]*G[{0, 1, 1/(yu*yv), 1}, yw])/64 + 
     (9*G[{1}, yv^(-1)]*G[{0, 1, 1/(yu*yv), 1}, yw])/64 - 
     (3*G[{1}, yw]*G[{0, 1, 1/(yu*yv), 1}, yw])/16 - 
     (G[{yu}, yv^(-1)]*G[{0, 1, 1/(yu*yv), 1}, yw])/8 + 
     (9*G[{0}, yu^(-1)]*G[{0, 1, 1/(yu*yv), yu^(-1)}, yw])/64 + 
     (9*G[{0}, yv^(-1)]*G[{0, 1, 1/(yu*yv), yu^(-1)}, yw])/64 - 
     (9*G[{0}, yw]*G[{0, 1, 1/(yu*yv), yu^(-1)}, yw])/64 - 
     (G[{1}, yu^(-1)]*G[{0, 1, 1/(yu*yv), yu^(-1)}, yw])/64 - 
     (17*G[{1}, yv^(-1)]*G[{0, 1, 1/(yu*yv), yu^(-1)}, yw])/64 + 
     (5*G[{1}, yw]*G[{0, 1, 1/(yu*yv), yu^(-1)}, yw])/32 - 
     (3*G[{1/(yu*yv)}, yw]*G[{0, 1, 1/(yu*yv), yu^(-1)}, yw])/32 - 
     (7*G[{0}, yu^(-1)]*G[{0, 1, 1/(yu*yv), yv^(-1)}, yw])/64 - 
     (7*G[{0}, yv^(-1)]*G[{0, 1, 1/(yu*yv), yv^(-1)}, yw])/64 + 
     (7*G[{0}, yw]*G[{0, 1, 1/(yu*yv), yv^(-1)}, yw])/64 + 
     (7*G[{1}, yu^(-1)]*G[{0, 1, 1/(yu*yv), yv^(-1)}, yw])/64 - 
     (G[{1}, yv^(-1)]*G[{0, 1, 1/(yu*yv), yv^(-1)}, yw])/64 + 
     (7*G[{1}, yw]*G[{0, 1, 1/(yu*yv), yv^(-1)}, yw])/32 + 
     (G[{yu}, yv^(-1)]*G[{0, 1, 1/(yu*yv), yv^(-1)}, yw])/8 - 
     (3*G[{1/(yu*yv)}, yw]*G[{0, 1, 1/(yu*yv), yv^(-1)}, yw])/32 + 
     (7*G[{0}, yu^(-1)]*G[{0, 1, 1/(yu*yv), 1/(yu*yv)}, yw])/64 + 
     (7*G[{0}, yv^(-1)]*G[{0, 1, 1/(yu*yv), 1/(yu*yv)}, yw])/64 - 
     (7*G[{0}, yw]*G[{0, 1, 1/(yu*yv), 1/(yu*yv)}, yw])/64 - 
     (3*G[{1}, yu^(-1)]*G[{0, 1, 1/(yu*yv), 1/(yu*yv)}, yw])/64 - 
     (15*G[{1}, yv^(-1)]*G[{0, 1, 1/(yu*yv), 1/(yu*yv)}, yw])/64 + 
     (G[{yu}, yv^(-1)]*G[{0, 1, 1/(yu*yv), 1/(yu*yv)}, yw])/16 - 
     (G[{0}, yu^(-1)]*G[{0, yu^(-1), 0, yv^(-1)}, yw])/16 - 
     (G[{0}, yv^(-1)]*G[{0, yu^(-1), 0, yv^(-1)}, yw])/16 + 
     (G[{0}, yw]*G[{0, yu^(-1), 0, yv^(-1)}, yw])/16 + 
     (G[{1}, yv^(-1)]*G[{0, yu^(-1), 0, yv^(-1)}, yw])/8 + 
     (G[{1}, yw]*G[{0, yu^(-1), 0, yv^(-1)}, yw])/16 + 
     (G[{1}, yu^(-1)]*G[{0, yu^(-1), 0, 1/(yu*yv)}, yw])/16 - 
     (G[{1}, yv^(-1)]*G[{0, yu^(-1), 0, 1/(yu*yv)}, yw])/16 - 
     (G[{1}, yw]*G[{0, yu^(-1), 0, 1/(yu*yv)}, yw])/8 + 
     (G[{0}, yu^(-1)]*G[{0, yu^(-1), 1, 1}, yw])/64 + 
     (G[{0}, yv^(-1)]*G[{0, yu^(-1), 1, 1}, yw])/64 - 
     (G[{0}, yw]*G[{0, yu^(-1), 1, 1}, yw])/64 - 
     (5*G[{1}, yu^(-1)]*G[{0, yu^(-1), 1, 1}, yw])/64 - 
     (G[{1}, yv^(-1)]*G[{0, yu^(-1), 1, 1}, yw])/64 - 
     (G[{1}, yw]*G[{0, yu^(-1), 1, 1}, yw])/16 + 
     (G[{yu}, yv^(-1)]*G[{0, yu^(-1), 1, 1}, yw])/16 - 
     (13*G[{0}, yu^(-1)]*G[{0, yu^(-1), 1, yu^(-1)}, yw])/64 - 
     (13*G[{0}, yv^(-1)]*G[{0, yu^(-1), 1, yu^(-1)}, yw])/64 + 
     (13*G[{0}, yw]*G[{0, yu^(-1), 1, yu^(-1)}, yw])/64 + 
     (G[{1}, yu^(-1)]*G[{0, yu^(-1), 1, yu^(-1)}, yw])/64 + 
     (25*G[{1}, yv^(-1)]*G[{0, yu^(-1), 1, yu^(-1)}, yw])/64 - 
     (5*G[{1}, yw]*G[{0, yu^(-1), 1, yu^(-1)}, yw])/32 + 
     (3*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1), 1, yu^(-1)}, yw])/32 - 
     (G[{0}, yu^(-1)]*G[{0, yu^(-1), 1, yv^(-1)}, yw])/64 - 
     (G[{0}, yv^(-1)]*G[{0, yu^(-1), 1, yv^(-1)}, yw])/64 + 
     (G[{0}, yw]*G[{0, yu^(-1), 1, yv^(-1)}, yw])/64 - 
     (7*G[{1}, yu^(-1)]*G[{0, yu^(-1), 1, yv^(-1)}, yw])/64 + 
     (G[{1}, yv^(-1)]*G[{0, yu^(-1), 1, yv^(-1)}, yw])/64 - 
     (7*G[{1}, yw]*G[{0, yu^(-1), 1, yv^(-1)}, yw])/32 + 
     (G[{yu}, yv^(-1)]*G[{0, yu^(-1), 1, yv^(-1)}, yw])/8 + 
     (3*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1), 1, yv^(-1)}, yw])/32 - 
     (3*G[{0}, yu^(-1)]*G[{0, yu^(-1), 1, 1/(yu*yv)}, yw])/64 - 
     (3*G[{0}, yv^(-1)]*G[{0, yu^(-1), 1, 1/(yu*yv)}, yw])/64 + 
     (3*G[{0}, yw]*G[{0, yu^(-1), 1, 1/(yu*yv)}, yw])/64 - 
     (G[{1}, yu^(-1)]*G[{0, yu^(-1), 1, 1/(yu*yv)}, yw])/64 - 
     (G[{1}, yv^(-1)]*G[{0, yu^(-1), 1, 1/(yu*yv)}, yw])/64 + 
     (G[{yu}, yv^(-1)]*G[{0, yu^(-1), 1, 1/(yu*yv)}, yw])/8 - 
     (25*G[{0}, yu^(-1)]*G[{0, yu^(-1), yu^(-1), 1}, yw])/64 - 
     (25*G[{0}, yv^(-1)]*G[{0, yu^(-1), yu^(-1), 1}, yw])/64 + 
     (25*G[{0}, yw]*G[{0, yu^(-1), yu^(-1), 1}, yw])/64 + 
     (9*G[{1}, yu^(-1)]*G[{0, yu^(-1), yu^(-1), 1}, yw])/64 + 
     (25*G[{1}, yv^(-1)]*G[{0, yu^(-1), yu^(-1), 1}, yw])/64 - 
     (9*G[{1}, yw]*G[{0, yu^(-1), yu^(-1), 1}, yw])/32 + 
     (G[{yu}, yv^(-1)]*G[{0, yu^(-1), yu^(-1), 1}, yw])/4 + 
     (3*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1), yu^(-1), 1}, yw])/32 + 
     (25*G[{0}, yu^(-1)]*G[{0, yu^(-1), yu^(-1), yu^(-1)}, yw])/32 + 
     (25*G[{0}, yv^(-1)]*G[{0, yu^(-1), yu^(-1), yu^(-1)}, yw])/32 - 
     (25*G[{0}, yw]*G[{0, yu^(-1), yu^(-1), yu^(-1)}, yw])/32 - 
     (9*G[{1}, yu^(-1)]*G[{0, yu^(-1), yu^(-1), yu^(-1)}, yw])/32 - 
     (41*G[{1}, yv^(-1)]*G[{0, yu^(-1), yu^(-1), yu^(-1)}, yw])/32 + 
     (29*G[{1}, yw]*G[{0, yu^(-1), yu^(-1), yu^(-1)}, yw])/64 - 
     (3*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1), yu^(-1), yu^(-1)}, yw])/64 + 
     (G[{0}, yu^(-1)]*G[{0, yu^(-1), yu^(-1), yv^(-1)}, yw])/32 + 
     (G[{0}, yv^(-1)]*G[{0, yu^(-1), yu^(-1), yv^(-1)}, yw])/32 - 
     (G[{0}, yw]*G[{0, yu^(-1), yu^(-1), yv^(-1)}, yw])/32 + 
     (7*G[{1}, yu^(-1)]*G[{0, yu^(-1), yu^(-1), yv^(-1)}, yw])/32 - 
     (9*G[{1}, yv^(-1)]*G[{0, yu^(-1), yu^(-1), yv^(-1)}, yw])/32 + 
     (5*G[{1}, yw]*G[{0, yu^(-1), yu^(-1), yv^(-1)}, yw])/64 - 
     (11*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1), yu^(-1), yv^(-1)}, yw])/64 - 
     (G[{0}, yu^(-1)]*G[{0, yu^(-1), yu^(-1), 1/(yu*yv)}, yw])/64 - 
     (G[{0}, yv^(-1)]*G[{0, yu^(-1), yu^(-1), 1/(yu*yv)}, yw])/64 + 
     (G[{0}, yw]*G[{0, yu^(-1), yu^(-1), 1/(yu*yv)}, yw])/64 - 
     (7*G[{1}, yu^(-1)]*G[{0, yu^(-1), yu^(-1), 1/(yu*yv)}, yw])/64 + 
     (25*G[{1}, yv^(-1)]*G[{0, yu^(-1), yu^(-1), 1/(yu*yv)}, yw])/64 + 
     (3*G[{1}, yw]*G[{0, yu^(-1), yu^(-1), 1/(yu*yv)}, yw])/32 - 
     (G[{yu}, yv^(-1)]*G[{0, yu^(-1), yu^(-1), 1/(yu*yv)}, yw])/4 + 
     (3*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1), yu^(-1), 1/(yu*yv)}, yw])/32 - 
     (5*G[{0}, yu^(-1)]*G[{0, yu^(-1), yv^(-1), 1}, yw])/64 - 
     (5*G[{0}, yv^(-1)]*G[{0, yu^(-1), yv^(-1), 1}, yw])/64 + 
     (5*G[{0}, yw]*G[{0, yu^(-1), yv^(-1), 1}, yw])/64 + 
     (G[{1}, yu^(-1)]*G[{0, yu^(-1), yv^(-1), 1}, yw])/64 + 
     (G[{1}, yv^(-1)]*G[{0, yu^(-1), yv^(-1), 1}, yw])/64 - 
     (9*G[{1}, yw]*G[{0, yu^(-1), yv^(-1), 1}, yw])/32 + 
     (G[{yu}, yv^(-1)]*G[{0, yu^(-1), yv^(-1), 1}, yw])/8 + 
     (3*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1), yv^(-1), 1}, yw])/32 + 
     (G[{0}, yu^(-1)]*G[{0, yu^(-1), yv^(-1), yu^(-1)}, yw])/32 + 
     (G[{0}, yv^(-1)]*G[{0, yu^(-1), yv^(-1), yu^(-1)}, yw])/32 - 
     (G[{0}, yw]*G[{0, yu^(-1), yv^(-1), yu^(-1)}, yw])/32 + 
     (7*G[{1}, yu^(-1)]*G[{0, yu^(-1), yv^(-1), yu^(-1)}, yw])/32 - 
     (9*G[{1}, yv^(-1)]*G[{0, yu^(-1), yv^(-1), yu^(-1)}, yw])/32 + 
     (5*G[{1}, yw]*G[{0, yu^(-1), yv^(-1), yu^(-1)}, yw])/64 - 
     (11*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1), yv^(-1), yu^(-1)}, yw])/64 - 
     (7*G[{0}, yu^(-1)]*G[{0, yu^(-1), yv^(-1), yv^(-1)}, yw])/32 - 
     (7*G[{0}, yv^(-1)]*G[{0, yu^(-1), yv^(-1), yv^(-1)}, yw])/32 + 
     (7*G[{0}, yw]*G[{0, yu^(-1), yv^(-1), yv^(-1)}, yw])/32 + 
     (7*G[{1}, yu^(-1)]*G[{0, yu^(-1), yv^(-1), yv^(-1)}, yw])/32 + 
     (7*G[{1}, yv^(-1)]*G[{0, yu^(-1), yv^(-1), yv^(-1)}, yw])/32 + 
     (5*G[{1}, yw]*G[{0, yu^(-1), yv^(-1), yv^(-1)}, yw])/64 - 
     (11*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1), yv^(-1), yv^(-1)}, yw])/64 + 
     (11*G[{0}, yu^(-1)]*G[{0, yu^(-1), yv^(-1), 1/(yu*yv)}, yw])/64 + 
     (11*G[{0}, yv^(-1)]*G[{0, yu^(-1), yv^(-1), 1/(yu*yv)}, yw])/64 - 
     (11*G[{0}, yw]*G[{0, yu^(-1), yv^(-1), 1/(yu*yv)}, yw])/64 - 
     (15*G[{1}, yu^(-1)]*G[{0, yu^(-1), yv^(-1), 1/(yu*yv)}, yw])/64 + 
     (G[{1}, yv^(-1)]*G[{0, yu^(-1), yv^(-1), 1/(yu*yv)}, yw])/64 + 
     (3*G[{1}, yw]*G[{0, yu^(-1), yv^(-1), 1/(yu*yv)}, yw])/32 - 
     (G[{yu}, yv^(-1)]*G[{0, yu^(-1), yv^(-1), 1/(yu*yv)}, yw])/8 + 
     (3*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1), yv^(-1), 1/(yu*yv)}, yw])/32 + 
     (9*G[{0}, yu^(-1)]*G[{0, yu^(-1), 1/(yu*yv), 1}, yw])/64 + 
     (9*G[{0}, yv^(-1)]*G[{0, yu^(-1), 1/(yu*yv), 1}, yw])/64 - 
     (9*G[{0}, yw]*G[{0, yu^(-1), 1/(yu*yv), 1}, yw])/64 - 
     (9*G[{1}, yu^(-1)]*G[{0, yu^(-1), 1/(yu*yv), 1}, yw])/64 - 
     (G[{1}, yv^(-1)]*G[{0, yu^(-1), 1/(yu*yv), 1}, yw])/64 + 
     (G[{1}, yw]*G[{0, yu^(-1), 1/(yu*yv), 1}, yw])/16 - 
     (G[{yu}, yv^(-1)]*G[{0, yu^(-1), 1/(yu*yv), 1}, yw])/8 - 
     (13*G[{0}, yu^(-1)]*G[{0, yu^(-1), 1/(yu*yv), yu^(-1)}, yw])/64 - 
     (13*G[{0}, yv^(-1)]*G[{0, yu^(-1), 1/(yu*yv), yu^(-1)}, yw])/64 + 
     (13*G[{0}, yw]*G[{0, yu^(-1), 1/(yu*yv), yu^(-1)}, yw])/64 + 
     (G[{1}, yu^(-1)]*G[{0, yu^(-1), 1/(yu*yv), yu^(-1)}, yw])/64 + 
     (25*G[{1}, yv^(-1)]*G[{0, yu^(-1), 1/(yu*yv), yu^(-1)}, yw])/64 - 
     (G[{1}, yw]*G[{0, yu^(-1), 1/(yu*yv), yu^(-1)}, yw])/32 + 
     (3*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1), 1/(yu*yv), yu^(-1)}, yw])/32 + 
     (7*G[{0}, yu^(-1)]*G[{0, yu^(-1), 1/(yu*yv), yv^(-1)}, yw])/64 + 
     (7*G[{0}, yv^(-1)]*G[{0, yu^(-1), 1/(yu*yv), yv^(-1)}, yw])/64 - 
     (7*G[{0}, yw]*G[{0, yu^(-1), 1/(yu*yv), yv^(-1)}, yw])/64 - 
     (7*G[{1}, yu^(-1)]*G[{0, yu^(-1), 1/(yu*yv), yv^(-1)}, yw])/64 + 
     (G[{1}, yv^(-1)]*G[{0, yu^(-1), 1/(yu*yv), yv^(-1)}, yw])/64 - 
     (3*G[{1}, yw]*G[{0, yu^(-1), 1/(yu*yv), yv^(-1)}, yw])/32 - 
     (G[{yu}, yv^(-1)]*G[{0, yu^(-1), 1/(yu*yv), yv^(-1)}, yw])/8 + 
     (3*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1), 1/(yu*yv), yv^(-1)}, yw])/32 - 
     (7*G[{0}, yu^(-1)]*G[{0, yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/64 - 
     (7*G[{0}, yv^(-1)]*G[{0, yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/64 + 
     (7*G[{0}, yw]*G[{0, yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/64 + 
     (3*G[{1}, yu^(-1)]*G[{0, yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/64 + 
     (15*G[{1}, yv^(-1)]*G[{0, yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/64 - 
     (G[{yu}, yv^(-1)]*G[{0, yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/16 + 
     (G[{0}, yu^(-1)]*G[{0, yu, 1, 1}, yv^(-1)])/16 + 
     (G[{0}, yv^(-1)]*G[{0, yu, 1, 1}, yv^(-1)])/16 - 
     (G[{0}, yw]*G[{0, yu, 1, 1}, yv^(-1)])/16 + 
     (G[{1}, yv^(-1)]*G[{0, yu, 1, 1}, yv^(-1)])/8 - 
     (G[{1}, yw]*G[{0, yu, 1, 1}, yv^(-1)])/8 + 
     (G[{1/(yu*yv)}, yw]*G[{0, yu, 1, 1}, yv^(-1)])/8 - 
     (G[{0}, yu^(-1)]*G[{0, yu, 1, yu}, yv^(-1)])/8 - 
     (G[{0}, yv^(-1)]*G[{0, yu, 1, yu}, yv^(-1)])/8 + 
     (G[{0}, yw]*G[{0, yu, 1, yu}, yv^(-1)])/8 + 
     (G[{1}, yu^(-1)]*G[{0, yu, 1, yu}, yv^(-1)])/8 + 
     (3*G[{1}, yv^(-1)]*G[{0, yu, 1, yu}, yv^(-1)])/16 - 
     (3*G[{1}, yw]*G[{0, yu, 1, yu}, yv^(-1)])/16 - 
     (G[{1/(yu*yv)}, yw]*G[{0, yu, 1, yu}, yv^(-1)])/8 + 
     (G[{1}, yv^(-1)]*G[{0, yu, yu, 1}, yv^(-1)])/8 - 
     (G[{1}, yw]*G[{0, yu, yu, 1}, yv^(-1)])/8 - 
     (G[{1/(yu*yv)}, yw]*G[{0, yu, yu, 1}, yv^(-1)])/8 - 
     (G[{1}, yv^(-1)]*G[{0, yu, yu, yu}, yv^(-1)])/4 + 
     (G[{1}, yw]*G[{0, yu, yu, yu}, yv^(-1)])/4 - 
     (G[{0}, yu^(-1)]*G[{0, yv^(-1), 0, 1/(yu*yv)}, yw])/16 - 
     (G[{0}, yv^(-1)]*G[{0, yv^(-1), 0, 1/(yu*yv)}, yw])/16 + 
     (G[{0}, yw]*G[{0, yv^(-1), 0, 1/(yu*yv)}, yw])/16 + 
     (G[{1}, yu^(-1)]*G[{0, yv^(-1), 0, 1/(yu*yv)}, yw])/8 + 
     (G[{1}, yv^(-1)]*G[{0, yv^(-1), 0, 1/(yu*yv)}, yw])/8 - 
     (G[{1}, yw]*G[{0, yv^(-1), 0, 1/(yu*yv)}, yw])/16 - 
     (G[{yu}, yv^(-1)]*G[{0, yv^(-1), 0, 1/(yu*yv)}, yw])/8 + 
     (9*G[{0}, yu^(-1)]*G[{0, yv^(-1), 1, 1}, yw])/64 + 
     (9*G[{0}, yv^(-1)]*G[{0, yv^(-1), 1, 1}, yw])/64 - 
     (9*G[{0}, yw]*G[{0, yv^(-1), 1, 1}, yw])/64 - 
     (17*G[{1}, yu^(-1)]*G[{0, yv^(-1), 1, 1}, yw])/64 - 
     (9*G[{1}, yv^(-1)]*G[{0, yv^(-1), 1, 1}, yw])/64 + 
     (G[{1}, yw]*G[{0, yv^(-1), 1, 1}, yw])/16 + 
     (G[{yu}, yv^(-1)]*G[{0, yv^(-1), 1, 1}, yw])/8 - 
     (G[{0}, yu^(-1)]*G[{0, yv^(-1), 1, yu^(-1)}, yw])/64 - 
     (G[{0}, yv^(-1)]*G[{0, yv^(-1), 1, yu^(-1)}, yw])/64 + 
     (G[{0}, yw]*G[{0, yv^(-1), 1, yu^(-1)}, yw])/64 + 
     (G[{1}, yu^(-1)]*G[{0, yv^(-1), 1, yu^(-1)}, yw])/64 + 
     (G[{1}, yv^(-1)]*G[{0, yv^(-1), 1, yu^(-1)}, yw])/64 - 
     (5*G[{1}, yw]*G[{0, yv^(-1), 1, yu^(-1)}, yw])/32 + 
     (3*G[{1/(yu*yv)}, yw]*G[{0, yv^(-1), 1, yu^(-1)}, yw])/32 - 
     (G[{0}, yu^(-1)]*G[{0, yv^(-1), 1, yv^(-1)}, yw])/64 - 
     (G[{0}, yv^(-1)]*G[{0, yv^(-1), 1, yv^(-1)}, yw])/64 + 
     (G[{0}, yw]*G[{0, yv^(-1), 1, yv^(-1)}, yw])/64 + 
     (9*G[{1}, yu^(-1)]*G[{0, yv^(-1), 1, yv^(-1)}, yw])/64 + 
     (G[{1}, yv^(-1)]*G[{0, yv^(-1), 1, yv^(-1)}, yw])/64 - 
     (7*G[{1}, yw]*G[{0, yv^(-1), 1, yv^(-1)}, yw])/32 - 
     (G[{yu}, yv^(-1)]*G[{0, yv^(-1), 1, yv^(-1)}, yw])/8 + 
     (3*G[{1/(yu*yv)}, yw]*G[{0, yv^(-1), 1, yv^(-1)}, yw])/32 - 
     (3*G[{0}, yu^(-1)]*G[{0, yv^(-1), 1, 1/(yu*yv)}, yw])/64 - 
     (3*G[{0}, yv^(-1)]*G[{0, yv^(-1), 1, 1/(yu*yv)}, yw])/64 + 
     (3*G[{0}, yw]*G[{0, yv^(-1), 1, 1/(yu*yv)}, yw])/64 - 
     (5*G[{1}, yu^(-1)]*G[{0, yv^(-1), 1, 1/(yu*yv)}, yw])/64 + 
     (7*G[{1}, yv^(-1)]*G[{0, yv^(-1), 1, 1/(yu*yv)}, yw])/64 + 
     (G[{yu}, yv^(-1)]*G[{0, yv^(-1), 1, 1/(yu*yv)}, yw])/16 - 
     (5*G[{0}, yu^(-1)]*G[{0, yv^(-1), yu^(-1), 1}, yw])/64 - 
     (5*G[{0}, yv^(-1)]*G[{0, yv^(-1), yu^(-1), 1}, yw])/64 + 
     (5*G[{0}, yw]*G[{0, yv^(-1), yu^(-1), 1}, yw])/64 + 
     (G[{1}, yu^(-1)]*G[{0, yv^(-1), yu^(-1), 1}, yw])/64 + 
     (G[{1}, yv^(-1)]*G[{0, yv^(-1), yu^(-1), 1}, yw])/64 - 
     (9*G[{1}, yw]*G[{0, yv^(-1), yu^(-1), 1}, yw])/32 + 
     (G[{yu}, yv^(-1)]*G[{0, yv^(-1), yu^(-1), 1}, yw])/8 + 
     (3*G[{1/(yu*yv)}, yw]*G[{0, yv^(-1), yu^(-1), 1}, yw])/32 + 
     (G[{0}, yu^(-1)]*G[{0, yv^(-1), yu^(-1), yu^(-1)}, yw])/32 + 
     (G[{0}, yv^(-1)]*G[{0, yv^(-1), yu^(-1), yu^(-1)}, yw])/32 - 
     (G[{0}, yw]*G[{0, yv^(-1), yu^(-1), yu^(-1)}, yw])/32 + 
     (7*G[{1}, yu^(-1)]*G[{0, yv^(-1), yu^(-1), yu^(-1)}, yw])/32 - 
     (9*G[{1}, yv^(-1)]*G[{0, yv^(-1), yu^(-1), yu^(-1)}, yw])/32 + 
     (5*G[{1}, yw]*G[{0, yv^(-1), yu^(-1), yu^(-1)}, yw])/64 - 
     (11*G[{1/(yu*yv)}, yw]*G[{0, yv^(-1), yu^(-1), yu^(-1)}, yw])/64 - 
     (7*G[{0}, yu^(-1)]*G[{0, yv^(-1), yu^(-1), yv^(-1)}, yw])/32 - 
     (7*G[{0}, yv^(-1)]*G[{0, yv^(-1), yu^(-1), yv^(-1)}, yw])/32 + 
     (7*G[{0}, yw]*G[{0, yv^(-1), yu^(-1), yv^(-1)}, yw])/32 + 
     (7*G[{1}, yu^(-1)]*G[{0, yv^(-1), yu^(-1), yv^(-1)}, yw])/32 + 
     (7*G[{1}, yv^(-1)]*G[{0, yv^(-1), yu^(-1), yv^(-1)}, yw])/32 + 
     (5*G[{1}, yw]*G[{0, yv^(-1), yu^(-1), yv^(-1)}, yw])/64 - 
     (11*G[{1/(yu*yv)}, yw]*G[{0, yv^(-1), yu^(-1), yv^(-1)}, yw])/64 + 
     (11*G[{0}, yu^(-1)]*G[{0, yv^(-1), yu^(-1), 1/(yu*yv)}, yw])/64 + 
     (11*G[{0}, yv^(-1)]*G[{0, yv^(-1), yu^(-1), 1/(yu*yv)}, yw])/64 - 
     (11*G[{0}, yw]*G[{0, yv^(-1), yu^(-1), 1/(yu*yv)}, yw])/64 - 
     (15*G[{1}, yu^(-1)]*G[{0, yv^(-1), yu^(-1), 1/(yu*yv)}, yw])/64 + 
     (G[{1}, yv^(-1)]*G[{0, yv^(-1), yu^(-1), 1/(yu*yv)}, yw])/64 + 
     (3*G[{1}, yw]*G[{0, yv^(-1), yu^(-1), 1/(yu*yv)}, yw])/32 - 
     (G[{yu}, yv^(-1)]*G[{0, yv^(-1), yu^(-1), 1/(yu*yv)}, yw])/8 + 
     (3*G[{1/(yu*yv)}, yw]*G[{0, yv^(-1), yu^(-1), 1/(yu*yv)}, yw])/32 - 
     (G[{0}, yu^(-1)]*G[{0, yv^(-1), yv^(-1), 1}, yw])/64 - 
     (G[{0}, yv^(-1)]*G[{0, yv^(-1), yv^(-1), 1}, yw])/64 + 
     (G[{0}, yw]*G[{0, yv^(-1), yv^(-1), 1}, yw])/64 + 
     (9*G[{1}, yu^(-1)]*G[{0, yv^(-1), yv^(-1), 1}, yw])/64 + 
     (G[{1}, yv^(-1)]*G[{0, yv^(-1), yv^(-1), 1}, yw])/64 - 
     (9*G[{1}, yw]*G[{0, yv^(-1), yv^(-1), 1}, yw])/32 - 
     (G[{yu}, yv^(-1)]*G[{0, yv^(-1), yv^(-1), 1}, yw])/8 + 
     (3*G[{1/(yu*yv)}, yw]*G[{0, yv^(-1), yv^(-1), 1}, yw])/32 - 
     (7*G[{0}, yu^(-1)]*G[{0, yv^(-1), yv^(-1), yu^(-1)}, yw])/32 - 
     (7*G[{0}, yv^(-1)]*G[{0, yv^(-1), yv^(-1), yu^(-1)}, yw])/32 + 
     (7*G[{0}, yw]*G[{0, yv^(-1), yv^(-1), yu^(-1)}, yw])/32 + 
     (7*G[{1}, yu^(-1)]*G[{0, yv^(-1), yv^(-1), yu^(-1)}, yw])/32 + 
     (7*G[{1}, yv^(-1)]*G[{0, yv^(-1), yv^(-1), yu^(-1)}, yw])/32 + 
     (5*G[{1}, yw]*G[{0, yv^(-1), yv^(-1), yu^(-1)}, yw])/64 - 
     (11*G[{1/(yu*yv)}, yw]*G[{0, yv^(-1), yv^(-1), yu^(-1)}, yw])/64 - 
     (7*G[{0}, yu^(-1)]*G[{0, yv^(-1), yv^(-1), yv^(-1)}, yw])/32 - 
     (7*G[{0}, yv^(-1)]*G[{0, yv^(-1), yv^(-1), yv^(-1)}, yw])/32 + 
     (7*G[{0}, yw]*G[{0, yv^(-1), yv^(-1), yv^(-1)}, yw])/32 + 
     (7*G[{1}, yu^(-1)]*G[{0, yv^(-1), yv^(-1), yv^(-1)}, yw])/32 + 
     (7*G[{1}, yv^(-1)]*G[{0, yv^(-1), yv^(-1), yv^(-1)}, yw])/32 + 
     (13*G[{1}, yw]*G[{0, yv^(-1), yv^(-1), yv^(-1)}, yw])/64 - 
     (3*G[{1/(yu*yv)}, yw]*G[{0, yv^(-1), yv^(-1), yv^(-1)}, yw])/64 + 
     (15*G[{0}, yu^(-1)]*G[{0, yv^(-1), yv^(-1), 1/(yu*yv)}, yw])/64 + 
     (15*G[{0}, yv^(-1)]*G[{0, yv^(-1), yv^(-1), 1/(yu*yv)}, yw])/64 - 
     (15*G[{0}, yw]*G[{0, yv^(-1), yv^(-1), 1/(yu*yv)}, yw])/64 - 
     (23*G[{1}, yu^(-1)]*G[{0, yv^(-1), yv^(-1), 1/(yu*yv)}, yw])/64 - 
     (15*G[{1}, yv^(-1)]*G[{0, yv^(-1), yv^(-1), 1/(yu*yv)}, yw])/64 + 
     (3*G[{1}, yw]*G[{0, yv^(-1), yv^(-1), 1/(yu*yv)}, yw])/32 + 
     (G[{yu}, yv^(-1)]*G[{0, yv^(-1), yv^(-1), 1/(yu*yv)}, yw])/8 + 
     (3*G[{1/(yu*yv)}, yw]*G[{0, yv^(-1), yv^(-1), 1/(yu*yv)}, yw])/32 - 
     (3*G[{0}, yu^(-1)]*G[{0, yv^(-1), 1/(yu*yv), 1}, yw])/64 - 
     (3*G[{0}, yv^(-1)]*G[{0, yv^(-1), 1/(yu*yv), 1}, yw])/64 + 
     (3*G[{0}, yw]*G[{0, yv^(-1), 1/(yu*yv), 1}, yw])/64 + 
     (3*G[{1}, yu^(-1)]*G[{0, yv^(-1), 1/(yu*yv), 1}, yw])/64 + 
     (7*G[{1}, yv^(-1)]*G[{0, yv^(-1), 1/(yu*yv), 1}, yw])/64 - 
     (G[{1}, yw]*G[{0, yv^(-1), 1/(yu*yv), 1}, yw])/16 - 
     (G[{yu}, yv^(-1)]*G[{0, yv^(-1), 1/(yu*yv), 1}, yw])/16 + 
     (7*G[{0}, yu^(-1)]*G[{0, yv^(-1), 1/(yu*yv), yu^(-1)}, yw])/64 + 
     (7*G[{0}, yv^(-1)]*G[{0, yv^(-1), 1/(yu*yv), yu^(-1)}, yw])/64 - 
     (7*G[{0}, yw]*G[{0, yv^(-1), 1/(yu*yv), yu^(-1)}, yw])/64 - 
     (15*G[{1}, yu^(-1)]*G[{0, yv^(-1), 1/(yu*yv), yu^(-1)}, yw])/64 + 
     (G[{1}, yv^(-1)]*G[{0, yv^(-1), 1/(yu*yv), yu^(-1)}, yw])/64 + 
     (3*G[{1}, yw]*G[{0, yv^(-1), 1/(yu*yv), yu^(-1)}, yw])/32 + 
     (3*G[{1/(yu*yv)}, yw]*G[{0, yv^(-1), 1/(yu*yv), yu^(-1)}, yw])/32 + 
     (15*G[{0}, yu^(-1)]*G[{0, yv^(-1), 1/(yu*yv), yv^(-1)}, yw])/64 + 
     (15*G[{0}, yv^(-1)]*G[{0, yv^(-1), 1/(yu*yv), yv^(-1)}, yw])/64 - 
     (15*G[{0}, yw]*G[{0, yv^(-1), 1/(yu*yv), yv^(-1)}, yw])/64 - 
     (23*G[{1}, yu^(-1)]*G[{0, yv^(-1), 1/(yu*yv), yv^(-1)}, yw])/64 - 
     (15*G[{1}, yv^(-1)]*G[{0, yv^(-1), 1/(yu*yv), yv^(-1)}, yw])/64 + 
     (G[{1}, yw]*G[{0, yv^(-1), 1/(yu*yv), yv^(-1)}, yw])/32 + 
     (G[{yu}, yv^(-1)]*G[{0, yv^(-1), 1/(yu*yv), yv^(-1)}, yw])/8 + 
     (3*G[{1/(yu*yv)}, yw]*G[{0, yv^(-1), 1/(yu*yv), yv^(-1)}, yw])/32 - 
     (3*G[{0}, yu^(-1)]*G[{0, yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/64 - 
     (3*G[{0}, yv^(-1)]*G[{0, yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/64 + 
     (3*G[{0}, yw]*G[{0, yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/64 + 
     (7*G[{1}, yu^(-1)]*G[{0, yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/64 + 
     (7*G[{1}, yv^(-1)]*G[{0, yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/64 - 
     (G[{yu}, yv^(-1)]*G[{0, yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/8 - 
     (G[{0}, yu^(-1)]*G[{0, 1/(yu*yv), 1, 1}, yw])/64 - 
     (G[{0}, yv^(-1)]*G[{0, 1/(yu*yv), 1, 1}, yw])/64 + 
     (G[{0}, yw]*G[{0, 1/(yu*yv), 1, 1}, yw])/64 + 
     (5*G[{1}, yu^(-1)]*G[{0, 1/(yu*yv), 1, 1}, yw])/64 + 
     (G[{1}, yv^(-1)]*G[{0, 1/(yu*yv), 1, 1}, yw])/64 + 
     (G[{1}, yw]*G[{0, 1/(yu*yv), 1, 1}, yw])/16 - 
     (G[{yu}, yv^(-1)]*G[{0, 1/(yu*yv), 1, 1}, yw])/16 + 
     (G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv), 1, 1}, yw])/8 + 
     (9*G[{0}, yu^(-1)]*G[{0, 1/(yu*yv), 1, yu^(-1)}, yw])/64 + 
     (9*G[{0}, yv^(-1)]*G[{0, 1/(yu*yv), 1, yu^(-1)}, yw])/64 - 
     (9*G[{0}, yw]*G[{0, 1/(yu*yv), 1, yu^(-1)}, yw])/64 - 
     (G[{1}, yu^(-1)]*G[{0, 1/(yu*yv), 1, yu^(-1)}, yw])/64 - 
     (17*G[{1}, yv^(-1)]*G[{0, 1/(yu*yv), 1, yu^(-1)}, yw])/64 + 
     (5*G[{1}, yw]*G[{0, 1/(yu*yv), 1, yu^(-1)}, yw])/32 - 
     (3*G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv), 1, yu^(-1)}, yw])/32 + 
     (G[{0}, yu^(-1)]*G[{0, 1/(yu*yv), 1, yv^(-1)}, yw])/64 + 
     (G[{0}, yv^(-1)]*G[{0, 1/(yu*yv), 1, yv^(-1)}, yw])/64 - 
     (G[{0}, yw]*G[{0, 1/(yu*yv), 1, yv^(-1)}, yw])/64 + 
     (7*G[{1}, yu^(-1)]*G[{0, 1/(yu*yv), 1, yv^(-1)}, yw])/64 - 
     (G[{1}, yv^(-1)]*G[{0, 1/(yu*yv), 1, yv^(-1)}, yw])/64 + 
     (7*G[{1}, yw]*G[{0, 1/(yu*yv), 1, yv^(-1)}, yw])/32 - 
     (G[{yu}, yv^(-1)]*G[{0, 1/(yu*yv), 1, yv^(-1)}, yw])/8 - 
     (3*G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv), 1, yv^(-1)}, yw])/32 + 
     (3*G[{0}, yu^(-1)]*G[{0, 1/(yu*yv), 1, 1/(yu*yv)}, yw])/64 + 
     (3*G[{0}, yv^(-1)]*G[{0, 1/(yu*yv), 1, 1/(yu*yv)}, yw])/64 - 
     (3*G[{0}, yw]*G[{0, 1/(yu*yv), 1, 1/(yu*yv)}, yw])/64 - 
     (7*G[{1}, yu^(-1)]*G[{0, 1/(yu*yv), 1, 1/(yu*yv)}, yw])/64 - 
     (7*G[{1}, yv^(-1)]*G[{0, 1/(yu*yv), 1, 1/(yu*yv)}, yw])/64 + 
     (G[{yu}, yv^(-1)]*G[{0, 1/(yu*yv), 1, 1/(yu*yv)}, yw])/8 + 
     (13*G[{0}, yu^(-1)]*G[{0, 1/(yu*yv), yu^(-1), 1}, yw])/64 + 
     (13*G[{0}, yv^(-1)]*G[{0, 1/(yu*yv), yu^(-1), 1}, yw])/64 - 
     (13*G[{0}, yw]*G[{0, 1/(yu*yv), yu^(-1), 1}, yw])/64 - 
     (5*G[{1}, yu^(-1)]*G[{0, 1/(yu*yv), yu^(-1), 1}, yw])/64 - 
     (9*G[{1}, yv^(-1)]*G[{0, 1/(yu*yv), yu^(-1), 1}, yw])/64 + 
     (9*G[{1}, yw]*G[{0, 1/(yu*yv), yu^(-1), 1}, yw])/32 - 
     (3*G[{yu}, yv^(-1)]*G[{0, 1/(yu*yv), yu^(-1), 1}, yw])/16 - 
     (3*G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv), yu^(-1), 1}, yw])/32 - 
     (13*G[{0}, yu^(-1)]*G[{0, 1/(yu*yv), yu^(-1), yu^(-1)}, yw])/32 - 
     (13*G[{0}, yv^(-1)]*G[{0, 1/(yu*yv), yu^(-1), yu^(-1)}, yw])/32 + 
     (13*G[{0}, yw]*G[{0, 1/(yu*yv), yu^(-1), yu^(-1)}, yw])/32 + 
     (G[{1}, yu^(-1)]*G[{0, 1/(yu*yv), yu^(-1), yu^(-1)}, yw])/32 + 
     (25*G[{1}, yv^(-1)]*G[{0, 1/(yu*yv), yu^(-1), yu^(-1)}, yw])/32 - 
     (13*G[{1}, yw]*G[{0, 1/(yu*yv), yu^(-1), yu^(-1)}, yw])/64 + 
     (3*G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv), yu^(-1), yu^(-1)}, yw])/64 + 
     (3*G[{0}, yu^(-1)]*G[{0, 1/(yu*yv), yu^(-1), yv^(-1)}, yw])/32 + 
     (3*G[{0}, yv^(-1)]*G[{0, 1/(yu*yv), yu^(-1), yv^(-1)}, yw])/32 - 
     (3*G[{0}, yw]*G[{0, 1/(yu*yv), yu^(-1), yv^(-1)}, yw])/32 - 
     (7*G[{1}, yu^(-1)]*G[{0, 1/(yu*yv), yu^(-1), yv^(-1)}, yw])/32 + 
     (G[{1}, yv^(-1)]*G[{0, 1/(yu*yv), yu^(-1), yv^(-1)}, yw])/32 - 
     (5*G[{1}, yw]*G[{0, 1/(yu*yv), yu^(-1), yv^(-1)}, yw])/64 + 
     (11*G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv), yu^(-1), yv^(-1)}, yw])/64 - 
     (3*G[{0}, yu^(-1)]*G[{0, 1/(yu*yv), yu^(-1), 1/(yu*yv)}, yw])/64 - 
     (3*G[{0}, yv^(-1)]*G[{0, 1/(yu*yv), yu^(-1), 1/(yu*yv)}, yw])/64 + 
     (3*G[{0}, yw]*G[{0, 1/(yu*yv), yu^(-1), 1/(yu*yv)}, yw])/64 + 
     (11*G[{1}, yu^(-1)]*G[{0, 1/(yu*yv), yu^(-1), 1/(yu*yv)}, yw])/64 - 
     (17*G[{1}, yv^(-1)]*G[{0, 1/(yu*yv), yu^(-1), 1/(yu*yv)}, yw])/64 - 
     (3*G[{1}, yw]*G[{0, 1/(yu*yv), yu^(-1), 1/(yu*yv)}, yw])/32 + 
     (3*G[{yu}, yv^(-1)]*G[{0, 1/(yu*yv), yu^(-1), 1/(yu*yv)}, yw])/16 - 
     (3*G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv), yu^(-1), 1/(yu*yv)}, yw])/32 + 
     (5*G[{0}, yu^(-1)]*G[{0, 1/(yu*yv), yv^(-1), 1}, yw])/64 + 
     (5*G[{0}, yv^(-1)]*G[{0, 1/(yu*yv), yv^(-1), 1}, yw])/64 - 
     (5*G[{0}, yw]*G[{0, 1/(yu*yv), yv^(-1), 1}, yw])/64 - 
     (G[{1}, yu^(-1)]*G[{0, 1/(yu*yv), yv^(-1), 1}, yw])/64 - 
     (G[{1}, yv^(-1)]*G[{0, 1/(yu*yv), yv^(-1), 1}, yw])/64 + 
     (9*G[{1}, yw]*G[{0, 1/(yu*yv), yv^(-1), 1}, yw])/32 - 
     (G[{yu}, yv^(-1)]*G[{0, 1/(yu*yv), yv^(-1), 1}, yw])/8 - 
     (3*G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv), yv^(-1), 1}, yw])/32 + 
     (3*G[{0}, yu^(-1)]*G[{0, 1/(yu*yv), yv^(-1), yu^(-1)}, yw])/32 + 
     (3*G[{0}, yv^(-1)]*G[{0, 1/(yu*yv), yv^(-1), yu^(-1)}, yw])/32 - 
     (3*G[{0}, yw]*G[{0, 1/(yu*yv), yv^(-1), yu^(-1)}, yw])/32 - 
     (7*G[{1}, yu^(-1)]*G[{0, 1/(yu*yv), yv^(-1), yu^(-1)}, yw])/32 + 
     (G[{1}, yv^(-1)]*G[{0, 1/(yu*yv), yv^(-1), yu^(-1)}, yw])/32 - 
     (5*G[{1}, yw]*G[{0, 1/(yu*yv), yv^(-1), yu^(-1)}, yw])/64 + 
     (11*G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv), yv^(-1), yu^(-1)}, yw])/64 + 
     (7*G[{0}, yu^(-1)]*G[{0, 1/(yu*yv), yv^(-1), yv^(-1)}, yw])/32 + 
     (7*G[{0}, yv^(-1)]*G[{0, 1/(yu*yv), yv^(-1), yv^(-1)}, yw])/32 - 
     (7*G[{0}, yw]*G[{0, 1/(yu*yv), yv^(-1), yv^(-1)}, yw])/32 - 
     (7*G[{1}, yu^(-1)]*G[{0, 1/(yu*yv), yv^(-1), yv^(-1)}, yw])/32 - 
     (7*G[{1}, yv^(-1)]*G[{0, 1/(yu*yv), yv^(-1), yv^(-1)}, yw])/32 - 
     (5*G[{1}, yw]*G[{0, 1/(yu*yv), yv^(-1), yv^(-1)}, yw])/64 + 
     (3*G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv), yv^(-1), yv^(-1)}, yw])/64 - 
     (15*G[{0}, yu^(-1)]*G[{0, 1/(yu*yv), yv^(-1), 1/(yu*yv)}, yw])/64 - 
     (15*G[{0}, yv^(-1)]*G[{0, 1/(yu*yv), yv^(-1), 1/(yu*yv)}, yw])/64 + 
     (15*G[{0}, yw]*G[{0, 1/(yu*yv), yv^(-1), 1/(yu*yv)}, yw])/64 + 
     (23*G[{1}, yu^(-1)]*G[{0, 1/(yu*yv), yv^(-1), 1/(yu*yv)}, yw])/64 + 
     (15*G[{1}, yv^(-1)]*G[{0, 1/(yu*yv), yv^(-1), 1/(yu*yv)}, yw])/64 - 
     (3*G[{1}, yw]*G[{0, 1/(yu*yv), yv^(-1), 1/(yu*yv)}, yw])/32 - 
     (G[{yu}, yv^(-1)]*G[{0, 1/(yu*yv), yv^(-1), 1/(yu*yv)}, yw])/8 - 
     (3*G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv), yv^(-1), 1/(yu*yv)}, yw])/32 + 
     (3*G[{0}, yu^(-1)]*G[{0, 1/(yu*yv), 1/(yu*yv), 1}, yw])/64 + 
     (3*G[{0}, yv^(-1)]*G[{0, 1/(yu*yv), 1/(yu*yv), 1}, yw])/64 - 
     (3*G[{0}, yw]*G[{0, 1/(yu*yv), 1/(yu*yv), 1}, yw])/64 - 
     (11*G[{1}, yu^(-1)]*G[{0, 1/(yu*yv), 1/(yu*yv), 1}, yw])/64 - 
     (15*G[{1}, yv^(-1)]*G[{0, 1/(yu*yv), 1/(yu*yv), 1}, yw])/64 + 
     (3*G[{1}, yw]*G[{0, 1/(yu*yv), 1/(yu*yv), 1}, yw])/16 + 
     (5*G[{yu}, yv^(-1)]*G[{0, 1/(yu*yv), 1/(yu*yv), 1}, yw])/16 - 
     (3*G[{0}, yu^(-1)]*G[{0, 1/(yu*yv), 1/(yu*yv), yu^(-1)}, yw])/64 - 
     (3*G[{0}, yv^(-1)]*G[{0, 1/(yu*yv), 1/(yu*yv), yu^(-1)}, yw])/64 + 
     (3*G[{0}, yw]*G[{0, 1/(yu*yv), 1/(yu*yv), yu^(-1)}, yw])/64 + 
     (15*G[{1}, yu^(-1)]*G[{0, 1/(yu*yv), 1/(yu*yv), yu^(-1)}, yw])/64 - 
     (9*G[{1}, yv^(-1)]*G[{0, 1/(yu*yv), 1/(yu*yv), yu^(-1)}, yw])/64 - 
     (7*G[{1}, yw]*G[{0, 1/(yu*yv), 1/(yu*yv), yu^(-1)}, yw])/32 - 
     (3*G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv), 1/(yu*yv), yu^(-1)}, yw])/32 - 
     (15*G[{0}, yu^(-1)]*G[{0, 1/(yu*yv), 1/(yu*yv), yv^(-1)}, yw])/64 - 
     (15*G[{0}, yv^(-1)]*G[{0, 1/(yu*yv), 1/(yu*yv), yv^(-1)}, yw])/64 + 
     (15*G[{0}, yw]*G[{0, 1/(yu*yv), 1/(yu*yv), yv^(-1)}, yw])/64 + 
     (23*G[{1}, yu^(-1)]*G[{0, 1/(yu*yv), 1/(yu*yv), yv^(-1)}, yw])/64 + 
     (15*G[{1}, yv^(-1)]*G[{0, 1/(yu*yv), 1/(yu*yv), yv^(-1)}, yw])/64 - 
     (5*G[{1}, yw]*G[{0, 1/(yu*yv), 1/(yu*yv), yv^(-1)}, yw])/32 - 
     (G[{yu}, yv^(-1)]*G[{0, 1/(yu*yv), 1/(yu*yv), yv^(-1)}, yw])/8 - 
     (3*G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv), 1/(yu*yv), yv^(-1)}, yw])/32 + 
     (3*G[{0}, yu^(-1)]*G[{0, 1/(yu*yv), 1/(yu*yv), 1/(yu*yv)}, yw])/64 + 
     (3*G[{0}, yv^(-1)]*G[{0, 1/(yu*yv), 1/(yu*yv), 1/(yu*yv)}, yw])/64 - 
     (3*G[{0}, yw]*G[{0, 1/(yu*yv), 1/(yu*yv), 1/(yu*yv)}, yw])/64 - 
     (7*G[{1}, yu^(-1)]*G[{0, 1/(yu*yv), 1/(yu*yv), 1/(yu*yv)}, yw])/64 - 
     (7*G[{1}, yv^(-1)]*G[{0, 1/(yu*yv), 1/(yu*yv), 1/(yu*yv)}, yw])/64 + 
     (G[{yu}, yv^(-1)]*G[{0, 1/(yu*yv), 1/(yu*yv), 1/(yu*yv)}, yw])/8 + 
     (3*G[{0}, yu^(-1)]*G[{1, 1, 1, yu^(-1)}, yw])/64 + 
     (3*G[{0}, yv^(-1)]*G[{1, 1, 1, yu^(-1)}, yw])/64 - 
     (3*G[{0}, yw]*G[{1, 1, 1, yu^(-1)}, yw])/64 + 
     (5*G[{1}, yu^(-1)]*G[{1, 1, 1, yu^(-1)}, yw])/64 + 
     (G[{1}, yv^(-1)]*G[{1, 1, 1, yu^(-1)}, yw])/64 + 
     (3*G[{1}, yw]*G[{1, 1, 1, yu^(-1)}, yw])/16 - 
     (3*G[{yu}, yv^(-1)]*G[{1, 1, 1, yu^(-1)}, yw])/16 - 
     (G[{1/(yu*yv)}, yw]*G[{1, 1, 1, yu^(-1)}, yw])/8 + 
     (G[{0}, yu^(-1)]*G[{1, 1, 1, yu}, yv^(-1)])/16 + 
     (G[{0}, yv^(-1)]*G[{1, 1, 1, yu}, yv^(-1)])/16 - 
     (G[{0}, yw]*G[{1, 1, 1, yu}, yv^(-1)])/16 - 
     (G[{1}, yu^(-1)]*G[{1, 1, 1, yu}, yv^(-1)])/16 + 
     (3*G[{1}, yv^(-1)]*G[{1, 1, 1, yu}, yv^(-1)])/16 + 
     (G[{1}, yw]*G[{1, 1, 1, yu}, yv^(-1)])/4 - 
     (G[{1/(yu*yv)}, yw]*G[{1, 1, 1, yu}, yv^(-1)])/8 - 
     (29*G[{0}, yu^(-1)]*G[{1, 1, 1, yv^(-1)}, yw])/64 - 
     (29*G[{0}, yv^(-1)]*G[{1, 1, 1, yv^(-1)}, yw])/64 + 
     (29*G[{0}, yw]*G[{1, 1, 1, yv^(-1)}, yw])/64 + 
     (41*G[{1}, yu^(-1)]*G[{1, 1, 1, yv^(-1)}, yw])/64 + 
     (29*G[{1}, yv^(-1)]*G[{1, 1, 1, yv^(-1)}, yw])/64 + 
     (3*G[{1}, yw]*G[{1, 1, 1, yv^(-1)}, yw])/16 - 
     (3*G[{yu}, yv^(-1)]*G[{1, 1, 1, yv^(-1)}, yw])/16 - 
     (G[{1/(yu*yv)}, yw]*G[{1, 1, 1, yv^(-1)}, yw])/8 + 
     (G[{0}, yu^(-1)]*G[{1, 1, 1, 1/(yu*yv)}, yw])/8 + 
     (G[{0}, yv^(-1)]*G[{1, 1, 1, 1/(yu*yv)}, yw])/8 - 
     (G[{0}, yw]*G[{1, 1, 1, 1/(yu*yv)}, yw])/8 - 
     (3*G[{1}, yu^(-1)]*G[{1, 1, 1, 1/(yu*yv)}, yw])/16 - 
     (3*G[{1}, yv^(-1)]*G[{1, 1, 1, 1/(yu*yv)}, yw])/16 - 
     (G[{1}, yw]*G[{1, 1, 1, 1/(yu*yv)}, yw])/8 + 
     (G[{yu}, yv^(-1)]*G[{1, 1, 1, 1/(yu*yv)}, yw])/8 - 
     (25*G[{0}, yu^(-1)]*G[{1, 1, yu^(-1), yu^(-1)}, yw])/64 - 
     (25*G[{0}, yv^(-1)]*G[{1, 1, yu^(-1), yu^(-1)}, yw])/64 + 
     (25*G[{0}, yw]*G[{1, 1, yu^(-1), yu^(-1)}, yw])/64 + 
     (9*G[{1}, yu^(-1)]*G[{1, 1, yu^(-1), yu^(-1)}, yw])/64 + 
     (41*G[{1}, yv^(-1)]*G[{1, 1, yu^(-1), yu^(-1)}, yw])/64 - 
     (G[{1/(yu*yv)}, yw]*G[{1, 1, yu^(-1), yu^(-1)}, yw])/32 - 
     (G[{0}, yu^(-1)]*G[{1, 1, yu^(-1), yv^(-1)}, yw])/64 - 
     (G[{0}, yv^(-1)]*G[{1, 1, yu^(-1), yv^(-1)}, yw])/64 + 
     (G[{0}, yw]*G[{1, 1, yu^(-1), yv^(-1)}, yw])/64 + 
     (9*G[{1}, yu^(-1)]*G[{1, 1, yu^(-1), yv^(-1)}, yw])/64 - 
     (7*G[{1}, yv^(-1)]*G[{1, 1, yu^(-1), yv^(-1)}, yw])/64 + 
     (3*G[{1/(yu*yv)}, yw]*G[{1, 1, yu^(-1), yv^(-1)}, yw])/32 + 
     (21*G[{0}, yu^(-1)]*G[{1, 1, yu^(-1), 1/(yu*yv)}, yw])/64 + 
     (21*G[{0}, yv^(-1)]*G[{1, 1, yu^(-1), 1/(yu*yv)}, yw])/64 - 
     (21*G[{0}, yw]*G[{1, 1, yu^(-1), 1/(yu*yv)}, yw])/64 - 
     (21*G[{1}, yu^(-1)]*G[{1, 1, yu^(-1), 1/(yu*yv)}, yw])/64 - 
     (17*G[{1}, yv^(-1)]*G[{1, 1, yu^(-1), 1/(yu*yv)}, yw])/64 + 
     (G[{1}, yw]*G[{1, 1, yu^(-1), 1/(yu*yv)}, yw])/16 - 
     (G[{yu}, yv^(-1)]*G[{1, 1, yu^(-1), 1/(yu*yv)}, yw])/16 - 
     (G[{0}, yu^(-1)]*G[{1, 1, yu, yu}, yv^(-1)])/8 - 
     (G[{0}, yv^(-1)]*G[{1, 1, yu, yu}, yv^(-1)])/8 + 
     (G[{0}, yw]*G[{1, 1, yu, yu}, yv^(-1)])/8 + 
     (3*G[{1}, yu^(-1)]*G[{1, 1, yu, yu}, yv^(-1)])/16 - 
     (G[{1}, yw]*G[{1, 1, yu, yu}, yv^(-1)])/8 - 
     (G[{1/(yu*yv)}, yw]*G[{1, 1, yu, yu}, yv^(-1)])/8 - 
     (G[{0}, yu^(-1)]*G[{1, 1, yv^(-1), yu^(-1)}, yw])/64 - 
     (G[{0}, yv^(-1)]*G[{1, 1, yv^(-1), yu^(-1)}, yw])/64 + 
     (G[{0}, yw]*G[{1, 1, yv^(-1), yu^(-1)}, yw])/64 + 
     (9*G[{1}, yu^(-1)]*G[{1, 1, yv^(-1), yu^(-1)}, yw])/64 - 
     (7*G[{1}, yv^(-1)]*G[{1, 1, yv^(-1), yu^(-1)}, yw])/64 + 
     (3*G[{1/(yu*yv)}, yw]*G[{1, 1, yv^(-1), yu^(-1)}, yw])/32 - 
     (9*G[{0}, yu^(-1)]*G[{1, 1, yv^(-1), yv^(-1)}, yw])/64 - 
     (9*G[{0}, yv^(-1)]*G[{1, 1, yv^(-1), yv^(-1)}, yw])/64 + 
     (9*G[{0}, yw]*G[{1, 1, yv^(-1), yv^(-1)}, yw])/64 + 
     (29*G[{1}, yu^(-1)]*G[{1, 1, yv^(-1), yv^(-1)}, yw])/64 + 
     (9*G[{1}, yv^(-1)]*G[{1, 1, yv^(-1), yv^(-1)}, yw])/64 + 
     (5*G[{1}, yw]*G[{1, 1, yv^(-1), yv^(-1)}, yw])/16 - 
     (5*G[{yu}, yv^(-1)]*G[{1, 1, yv^(-1), yv^(-1)}, yw])/16 - 
     (G[{1/(yu*yv)}, yw]*G[{1, 1, yv^(-1), yv^(-1)}, yw])/32 + 
     (5*G[{0}, yu^(-1)]*G[{1, 1, yv^(-1), 1/(yu*yv)}, yw])/64 + 
     (5*G[{0}, yv^(-1)]*G[{1, 1, yv^(-1), 1/(yu*yv)}, yw])/64 - 
     (5*G[{0}, yw]*G[{1, 1, yv^(-1), 1/(yu*yv)}, yw])/64 + 
     (3*G[{1}, yu^(-1)]*G[{1, 1, yv^(-1), 1/(yu*yv)}, yw])/64 - 
     (5*G[{1}, yv^(-1)]*G[{1, 1, yv^(-1), 1/(yu*yv)}, yw])/64 + 
     (G[{1}, yw]*G[{1, 1, yv^(-1), 1/(yu*yv)}, yw])/8 - 
     (G[{yu}, yv^(-1)]*G[{1, 1, yv^(-1), 1/(yu*yv)}, yw])/8 + 
     (G[{0}, yu^(-1)]*G[{1, 1, 1/(yu*yv), yu^(-1)}, yw])/4 + 
     (G[{0}, yv^(-1)]*G[{1, 1, 1/(yu*yv), yu^(-1)}, yw])/4 - 
     (G[{0}, yw]*G[{1, 1, 1/(yu*yv), yu^(-1)}, yw])/4 - 
     (G[{1}, yu^(-1)]*G[{1, 1, 1/(yu*yv), yu^(-1)}, yw])/4 - 
     (G[{1}, yv^(-1)]*G[{1, 1, 1/(yu*yv), yu^(-1)}, yw])/4 + 
     (G[{1/(yu*yv)}, yw]*G[{1, 1, 1/(yu*yv), yu^(-1)}, yw])/8 + 
     (G[{0}, yu^(-1)]*G[{1, 1, 1/(yu*yv), yv^(-1)}, yw])/4 + 
     (G[{0}, yv^(-1)]*G[{1, 1, 1/(yu*yv), yv^(-1)}, yw])/4 - 
     (G[{0}, yw]*G[{1, 1, 1/(yu*yv), yv^(-1)}, yw])/4 - 
     (G[{1}, yu^(-1)]*G[{1, 1, 1/(yu*yv), yv^(-1)}, yw])/16 - 
     (G[{1}, yv^(-1)]*G[{1, 1, 1/(yu*yv), yv^(-1)}, yw])/4 + 
     (3*G[{1}, yw]*G[{1, 1, 1/(yu*yv), yv^(-1)}, yw])/16 - 
     (3*G[{yu}, yv^(-1)]*G[{1, 1, 1/(yu*yv), yv^(-1)}, yw])/16 + 
     (G[{1/(yu*yv)}, yw]*G[{1, 1, 1/(yu*yv), yv^(-1)}, yw])/8 + 
     (G[{0}, yu^(-1)]*G[{1, 1, 1/(yu*yv), 1/(yu*yv)}, yw])/4 + 
     (G[{0}, yv^(-1)]*G[{1, 1, 1/(yu*yv), 1/(yu*yv)}, yw])/4 - 
     (G[{0}, yw]*G[{1, 1, 1/(yu*yv), 1/(yu*yv)}, yw])/4 - 
     (3*G[{1}, yu^(-1)]*G[{1, 1, 1/(yu*yv), 1/(yu*yv)}, yw])/8 - 
     (3*G[{1}, yv^(-1)]*G[{1, 1, 1/(yu*yv), 1/(yu*yv)}, yw])/16 - 
     (G[{1}, yw]*G[{1, 1, 1/(yu*yv), 1/(yu*yv)}, yw])/16 + 
     (G[{yu}, yv^(-1)]*G[{1, 1, 1/(yu*yv), 1/(yu*yv)}, yw])/16 + 
     (G[{0}, yu^(-1)]*G[{1, yu^(-1), 1, yv^(-1)}, yw])/16 + 
     (G[{0}, yv^(-1)]*G[{1, yu^(-1), 1, yv^(-1)}, yw])/16 - 
     (G[{0}, yw]*G[{1, yu^(-1), 1, yv^(-1)}, yw])/16 + 
     (G[{1}, yu^(-1)]*G[{1, yu^(-1), 1, yv^(-1)}, yw])/8 - 
     (G[{1}, yv^(-1)]*G[{1, yu^(-1), 1, yv^(-1)}, yw])/8 + 
     (G[{1}, yw]*G[{1, yu^(-1), 1, yv^(-1)}, yw])/8 - 
     (G[{yu}, yv^(-1)]*G[{1, yu^(-1), 1, yv^(-1)}, yw])/8 + 
     (5*G[{0}, yu^(-1)]*G[{1, yu^(-1), 1, 1/(yu*yv)}, yw])/16 + 
     (5*G[{0}, yv^(-1)]*G[{1, yu^(-1), 1, 1/(yu*yv)}, yw])/16 - 
     (5*G[{0}, yw]*G[{1, yu^(-1), 1, 1/(yu*yv)}, yw])/16 - 
     (G[{1}, yu^(-1)]*G[{1, yu^(-1), 1, 1/(yu*yv)}, yw])/4 - 
     (G[{1}, yv^(-1)]*G[{1, yu^(-1), 1, 1/(yu*yv)}, yw])/8 + 
     (G[{1}, yw]*G[{1, yu^(-1), 1, 1/(yu*yv)}, yw])/4 - 
     (G[{yu}, yv^(-1)]*G[{1, yu^(-1), 1, 1/(yu*yv)}, yw])/4 - 
     (25*G[{0}, yu^(-1)]*G[{1, yu^(-1), yu^(-1), yu^(-1)}, yw])/32 - 
     (25*G[{0}, yv^(-1)]*G[{1, yu^(-1), yu^(-1), yu^(-1)}, yw])/32 + 
     (25*G[{0}, yw]*G[{1, yu^(-1), yu^(-1), yu^(-1)}, yw])/32 + 
     (9*G[{1}, yu^(-1)]*G[{1, yu^(-1), yu^(-1), yu^(-1)}, yw])/32 + 
     (41*G[{1}, yv^(-1)]*G[{1, yu^(-1), yu^(-1), yu^(-1)}, yw])/32 + 
     (3*G[{1/(yu*yv)}, yw]*G[{1, yu^(-1), yu^(-1), yu^(-1)}, yw])/64 - 
     (G[{0}, yu^(-1)]*G[{1, yu^(-1), yu^(-1), yv^(-1)}, yw])/32 - 
     (G[{0}, yv^(-1)]*G[{1, yu^(-1), yu^(-1), yv^(-1)}, yw])/32 + 
     (G[{0}, yw]*G[{1, yu^(-1), yu^(-1), yv^(-1)}, yw])/32 - 
     (7*G[{1}, yu^(-1)]*G[{1, yu^(-1), yu^(-1), yv^(-1)}, yw])/32 + 
     (9*G[{1}, yv^(-1)]*G[{1, yu^(-1), yu^(-1), yv^(-1)}, yw])/32 + 
     (11*G[{1/(yu*yv)}, yw]*G[{1, yu^(-1), yu^(-1), yv^(-1)}, yw])/64 - 
     (23*G[{0}, yu^(-1)]*G[{1, yu^(-1), yu^(-1), 1/(yu*yv)}, yw])/64 - 
     (23*G[{0}, yv^(-1)]*G[{1, yu^(-1), yu^(-1), 1/(yu*yv)}, yw])/64 + 
     (23*G[{0}, yw]*G[{1, yu^(-1), yu^(-1), 1/(yu*yv)}, yw])/64 + 
     (23*G[{1}, yu^(-1)]*G[{1, yu^(-1), yu^(-1), 1/(yu*yv)}, yw])/64 - 
     (9*G[{1}, yv^(-1)]*G[{1, yu^(-1), yu^(-1), 1/(yu*yv)}, yw])/64 - 
     (G[{1}, yw]*G[{1, yu^(-1), yu^(-1), 1/(yu*yv)}, yw])/2 + 
     (G[{yu}, yv^(-1)]*G[{1, yu^(-1), yu^(-1), 1/(yu*yv)}, yw])/2 - 
     (3*G[{1/(yu*yv)}, yw]*G[{1, yu^(-1), yu^(-1), 1/(yu*yv)}, yw])/32 - 
     (G[{0}, yu^(-1)]*G[{1, yu^(-1), yv^(-1), yu^(-1)}, yw])/32 - 
     (G[{0}, yv^(-1)]*G[{1, yu^(-1), yv^(-1), yu^(-1)}, yw])/32 + 
     (G[{0}, yw]*G[{1, yu^(-1), yv^(-1), yu^(-1)}, yw])/32 - 
     (7*G[{1}, yu^(-1)]*G[{1, yu^(-1), yv^(-1), yu^(-1)}, yw])/32 + 
     (9*G[{1}, yv^(-1)]*G[{1, yu^(-1), yv^(-1), yu^(-1)}, yw])/32 + 
     (11*G[{1/(yu*yv)}, yw]*G[{1, yu^(-1), yv^(-1), yu^(-1)}, yw])/64 + 
     (7*G[{0}, yu^(-1)]*G[{1, yu^(-1), yv^(-1), yv^(-1)}, yw])/32 + 
     (7*G[{0}, yv^(-1)]*G[{1, yu^(-1), yv^(-1), yv^(-1)}, yw])/32 - 
     (7*G[{0}, yw]*G[{1, yu^(-1), yv^(-1), yv^(-1)}, yw])/32 - 
     (7*G[{1}, yu^(-1)]*G[{1, yu^(-1), yv^(-1), yv^(-1)}, yw])/32 - 
     (7*G[{1}, yv^(-1)]*G[{1, yu^(-1), yv^(-1), yv^(-1)}, yw])/32 + 
     (11*G[{1/(yu*yv)}, yw]*G[{1, yu^(-1), yv^(-1), yv^(-1)}, yw])/64 - 
     (11*G[{0}, yu^(-1)]*G[{1, yu^(-1), yv^(-1), 1/(yu*yv)}, yw])/64 - 
     (11*G[{0}, yv^(-1)]*G[{1, yu^(-1), yv^(-1), 1/(yu*yv)}, yw])/64 + 
     (11*G[{0}, yw]*G[{1, yu^(-1), yv^(-1), 1/(yu*yv)}, yw])/64 + 
     (15*G[{1}, yu^(-1)]*G[{1, yu^(-1), yv^(-1), 1/(yu*yv)}, yw])/64 - 
     (G[{1}, yv^(-1)]*G[{1, yu^(-1), yv^(-1), 1/(yu*yv)}, yw])/64 - 
     (G[{1}, yw]*G[{1, yu^(-1), yv^(-1), 1/(yu*yv)}, yw])/8 + 
     (G[{yu}, yv^(-1)]*G[{1, yu^(-1), yv^(-1), 1/(yu*yv)}, yw])/8 - 
     (3*G[{1/(yu*yv)}, yw]*G[{1, yu^(-1), yv^(-1), 1/(yu*yv)}, yw])/32 + 
     (G[{0}, yu^(-1)]*G[{1, yu^(-1), 1/(yu*yv), yu^(-1)}, yw])/64 + 
     (G[{0}, yv^(-1)]*G[{1, yu^(-1), 1/(yu*yv), yu^(-1)}, yw])/64 - 
     (G[{0}, yw]*G[{1, yu^(-1), 1/(yu*yv), yu^(-1)}, yw])/64 + 
     (7*G[{1}, yu^(-1)]*G[{1, yu^(-1), 1/(yu*yv), yu^(-1)}, yw])/64 - 
     (9*G[{1}, yv^(-1)]*G[{1, yu^(-1), 1/(yu*yv), yu^(-1)}, yw])/64 - 
     (3*G[{1/(yu*yv)}, yw]*G[{1, yu^(-1), 1/(yu*yv), yu^(-1)}, yw])/32 - 
     (7*G[{0}, yu^(-1)]*G[{1, yu^(-1), 1/(yu*yv), yv^(-1)}, yw])/64 - 
     (7*G[{0}, yv^(-1)]*G[{1, yu^(-1), 1/(yu*yv), yv^(-1)}, yw])/64 + 
     (7*G[{0}, yw]*G[{1, yu^(-1), 1/(yu*yv), yv^(-1)}, yw])/64 + 
     (7*G[{1}, yu^(-1)]*G[{1, yu^(-1), 1/(yu*yv), yv^(-1)}, yw])/64 + 
     (7*G[{1}, yv^(-1)]*G[{1, yu^(-1), 1/(yu*yv), yv^(-1)}, yw])/64 - 
     (3*G[{1/(yu*yv)}, yw]*G[{1, yu^(-1), 1/(yu*yv), yv^(-1)}, yw])/32 + 
     (7*G[{0}, yu^(-1)]*G[{1, yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/64 + 
     (7*G[{0}, yv^(-1)]*G[{1, yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/64 - 
     (7*G[{0}, yw]*G[{1, yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/64 - 
     (3*G[{1}, yu^(-1)]*G[{1, yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/64 - 
     (7*G[{1}, yv^(-1)]*G[{1, yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/64 + 
     (G[{1}, yw]*G[{1, yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/16 - 
     (G[{yu}, yv^(-1)]*G[{1, yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/16 - 
     (G[{0}, yu^(-1)]*G[{1, yu, yu, yu}, yv^(-1)])/4 - 
     (G[{0}, yv^(-1)]*G[{1, yu, yu, yu}, yv^(-1)])/4 + 
     (G[{0}, yw]*G[{1, yu, yu, yu}, yv^(-1)])/4 + 
     (3*G[{1}, yu^(-1)]*G[{1, yu, yu, yu}, yv^(-1)])/8 - 
     (G[{1}, yw]*G[{1, yu, yu, yu}, yv^(-1)])/2 + 
     (G[{0}, yu^(-1)]*G[{1, yv^(-1), 1, 1/(yu*yv)}, yw])/16 + 
     (G[{0}, yv^(-1)]*G[{1, yv^(-1), 1, 1/(yu*yv)}, yw])/16 - 
     (G[{0}, yw]*G[{1, yv^(-1), 1, 1/(yu*yv)}, yw])/16 + 
     (G[{1}, yu^(-1)]*G[{1, yv^(-1), 1, 1/(yu*yv)}, yw])/8 - 
     (G[{1}, yv^(-1)]*G[{1, yv^(-1), 1, 1/(yu*yv)}, yw])/8 + 
     (G[{1}, yw]*G[{1, yv^(-1), 1, 1/(yu*yv)}, yw])/8 - 
     (G[{yu}, yv^(-1)]*G[{1, yv^(-1), 1, 1/(yu*yv)}, yw])/8 - 
     (G[{0}, yu^(-1)]*G[{1, yv^(-1), yu^(-1), yu^(-1)}, yw])/32 - 
     (G[{0}, yv^(-1)]*G[{1, yv^(-1), yu^(-1), yu^(-1)}, yw])/32 + 
     (G[{0}, yw]*G[{1, yv^(-1), yu^(-1), yu^(-1)}, yw])/32 - 
     (7*G[{1}, yu^(-1)]*G[{1, yv^(-1), yu^(-1), yu^(-1)}, yw])/32 + 
     (9*G[{1}, yv^(-1)]*G[{1, yv^(-1), yu^(-1), yu^(-1)}, yw])/32 + 
     (11*G[{1/(yu*yv)}, yw]*G[{1, yv^(-1), yu^(-1), yu^(-1)}, yw])/64 + 
     (7*G[{0}, yu^(-1)]*G[{1, yv^(-1), yu^(-1), yv^(-1)}, yw])/32 + 
     (7*G[{0}, yv^(-1)]*G[{1, yv^(-1), yu^(-1), yv^(-1)}, yw])/32 - 
     (7*G[{0}, yw]*G[{1, yv^(-1), yu^(-1), yv^(-1)}, yw])/32 - 
     (7*G[{1}, yu^(-1)]*G[{1, yv^(-1), yu^(-1), yv^(-1)}, yw])/32 - 
     (7*G[{1}, yv^(-1)]*G[{1, yv^(-1), yu^(-1), yv^(-1)}, yw])/32 + 
     (11*G[{1/(yu*yv)}, yw]*G[{1, yv^(-1), yu^(-1), yv^(-1)}, yw])/64 - 
     (11*G[{0}, yu^(-1)]*G[{1, yv^(-1), yu^(-1), 1/(yu*yv)}, yw])/64 - 
     (11*G[{0}, yv^(-1)]*G[{1, yv^(-1), yu^(-1), 1/(yu*yv)}, yw])/64 + 
     (11*G[{0}, yw]*G[{1, yv^(-1), yu^(-1), 1/(yu*yv)}, yw])/64 + 
     (15*G[{1}, yu^(-1)]*G[{1, yv^(-1), yu^(-1), 1/(yu*yv)}, yw])/64 - 
     (G[{1}, yv^(-1)]*G[{1, yv^(-1), yu^(-1), 1/(yu*yv)}, yw])/64 - 
     (G[{1}, yw]*G[{1, yv^(-1), yu^(-1), 1/(yu*yv)}, yw])/8 + 
     (G[{yu}, yv^(-1)]*G[{1, yv^(-1), yu^(-1), 1/(yu*yv)}, yw])/8 - 
     (3*G[{1/(yu*yv)}, yw]*G[{1, yv^(-1), yu^(-1), 1/(yu*yv)}, yw])/32 + 
     (7*G[{0}, yu^(-1)]*G[{1, yv^(-1), yv^(-1), yu^(-1)}, yw])/32 + 
     (7*G[{0}, yv^(-1)]*G[{1, yv^(-1), yv^(-1), yu^(-1)}, yw])/32 - 
     (7*G[{0}, yw]*G[{1, yv^(-1), yv^(-1), yu^(-1)}, yw])/32 - 
     (7*G[{1}, yu^(-1)]*G[{1, yv^(-1), yv^(-1), yu^(-1)}, yw])/32 - 
     (7*G[{1}, yv^(-1)]*G[{1, yv^(-1), yv^(-1), yu^(-1)}, yw])/32 + 
     (11*G[{1/(yu*yv)}, yw]*G[{1, yv^(-1), yv^(-1), yu^(-1)}, yw])/64 + 
     (7*G[{0}, yu^(-1)]*G[{1, yv^(-1), yv^(-1), yv^(-1)}, yw])/32 + 
     (7*G[{0}, yv^(-1)]*G[{1, yv^(-1), yv^(-1), yv^(-1)}, yw])/32 - 
     (7*G[{0}, yw]*G[{1, yv^(-1), yv^(-1), yv^(-1)}, yw])/32 - 
     (3*G[{1}, yu^(-1)]*G[{1, yv^(-1), yv^(-1), yv^(-1)}, yw])/32 - 
     (7*G[{1}, yv^(-1)]*G[{1, yv^(-1), yv^(-1), yv^(-1)}, yw])/32 + 
     (G[{1}, yw]*G[{1, yv^(-1), yv^(-1), yv^(-1)}, yw])/8 - 
     (G[{yu}, yv^(-1)]*G[{1, yv^(-1), yv^(-1), yv^(-1)}, yw])/8 + 
     (3*G[{1/(yu*yv)}, yw]*G[{1, yv^(-1), yv^(-1), yv^(-1)}, yw])/64 - 
     (7*G[{0}, yu^(-1)]*G[{1, yv^(-1), yv^(-1), 1/(yu*yv)}, yw])/64 - 
     (7*G[{0}, yv^(-1)]*G[{1, yv^(-1), yv^(-1), 1/(yu*yv)}, yw])/64 + 
     (7*G[{0}, yw]*G[{1, yv^(-1), yv^(-1), 1/(yu*yv)}, yw])/64 + 
     (3*G[{1}, yu^(-1)]*G[{1, yv^(-1), yv^(-1), 1/(yu*yv)}, yw])/64 + 
     (7*G[{1}, yv^(-1)]*G[{1, yv^(-1), yv^(-1), 1/(yu*yv)}, yw])/64 - 
     (G[{1}, yw]*G[{1, yv^(-1), yv^(-1), 1/(yu*yv)}, yw])/16 + 
     (G[{yu}, yv^(-1)]*G[{1, yv^(-1), yv^(-1), 1/(yu*yv)}, yw])/16 - 
     (3*G[{1/(yu*yv)}, yw]*G[{1, yv^(-1), yv^(-1), 1/(yu*yv)}, yw])/32 + 
     (G[{0}, yu^(-1)]*G[{1, yv^(-1), 1/(yu*yv), yu^(-1)}, yw])/64 + 
     (G[{0}, yv^(-1)]*G[{1, yv^(-1), 1/(yu*yv), yu^(-1)}, yw])/64 - 
     (G[{0}, yw]*G[{1, yv^(-1), 1/(yu*yv), yu^(-1)}, yw])/64 + 
     (7*G[{1}, yu^(-1)]*G[{1, yv^(-1), 1/(yu*yv), yu^(-1)}, yw])/64 - 
     (9*G[{1}, yv^(-1)]*G[{1, yv^(-1), 1/(yu*yv), yu^(-1)}, yw])/64 - 
     (3*G[{1/(yu*yv)}, yw]*G[{1, yv^(-1), 1/(yu*yv), yu^(-1)}, yw])/32 - 
     (7*G[{0}, yu^(-1)]*G[{1, yv^(-1), 1/(yu*yv), yv^(-1)}, yw])/64 - 
     (7*G[{0}, yv^(-1)]*G[{1, yv^(-1), 1/(yu*yv), yv^(-1)}, yw])/64 + 
     (7*G[{0}, yw]*G[{1, yv^(-1), 1/(yu*yv), yv^(-1)}, yw])/64 + 
     (3*G[{1}, yu^(-1)]*G[{1, yv^(-1), 1/(yu*yv), yv^(-1)}, yw])/64 + 
     (7*G[{1}, yv^(-1)]*G[{1, yv^(-1), 1/(yu*yv), yv^(-1)}, yw])/64 - 
     (G[{1}, yw]*G[{1, yv^(-1), 1/(yu*yv), yv^(-1)}, yw])/16 + 
     (G[{yu}, yv^(-1)]*G[{1, yv^(-1), 1/(yu*yv), yv^(-1)}, yw])/16 - 
     (3*G[{1/(yu*yv)}, yw]*G[{1, yv^(-1), 1/(yu*yv), yv^(-1)}, yw])/32 - 
     (G[{0}, yu^(-1)]*G[{1, yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/64 - 
     (G[{0}, yv^(-1)]*G[{1, yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/64 + 
     (G[{0}, yw]*G[{1, yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/64 + 
     (9*G[{1}, yu^(-1)]*G[{1, yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/64 - 
     (11*G[{1}, yv^(-1)]*G[{1, yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/64 - 
     (G[{1}, yw]*G[{1, yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/16 + 
     (G[{yu}, yv^(-1)]*G[{1, yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/16 + 
     (G[{1/(yu*yv)}, yw]*G[{1, 1/(yu*yv), yu^(-1), yu^(-1)}, yw])/8 + 
     (5*G[{0}, yu^(-1)]*G[{1, 1/(yu*yv), yu^(-1), 1/(yu*yv)}, yw])/16 + 
     (5*G[{0}, yv^(-1)]*G[{1, 1/(yu*yv), yu^(-1), 1/(yu*yv)}, yw])/16 - 
     (5*G[{0}, yw]*G[{1, 1/(yu*yv), yu^(-1), 1/(yu*yv)}, yw])/16 - 
     (G[{1}, yu^(-1)]*G[{1, 1/(yu*yv), yu^(-1), 1/(yu*yv)}, yw])/4 - 
     (G[{1}, yv^(-1)]*G[{1, 1/(yu*yv), yu^(-1), 1/(yu*yv)}, yw])/8 + 
     (G[{1}, yw]*G[{1, 1/(yu*yv), yu^(-1), 1/(yu*yv)}, yw])/4 - 
     (G[{yu}, yv^(-1)]*G[{1, 1/(yu*yv), yu^(-1), 1/(yu*yv)}, yw])/4 - 
     (G[{1}, yu^(-1)]*G[{1, 1/(yu*yv), yv^(-1), yv^(-1)}, yw])/8 - 
     (G[{1}, yw]*G[{1, 1/(yu*yv), yv^(-1), yv^(-1)}, yw])/8 + 
     (G[{yu}, yv^(-1)]*G[{1, 1/(yu*yv), yv^(-1), yv^(-1)}, yw])/8 + 
     (G[{1/(yu*yv)}, yw]*G[{1, 1/(yu*yv), yv^(-1), yv^(-1)}, yw])/8 - 
     (G[{0}, yu^(-1)]*G[{1, 1/(yu*yv), yv^(-1), 1/(yu*yv)}, yw])/16 - 
     (G[{0}, yv^(-1)]*G[{1, 1/(yu*yv), yv^(-1), 1/(yu*yv)}, yw])/16 + 
     (G[{0}, yw]*G[{1, 1/(yu*yv), yv^(-1), 1/(yu*yv)}, yw])/16 + 
     (3*G[{1}, yu^(-1)]*G[{1, 1/(yu*yv), yv^(-1), 1/(yu*yv)}, yw])/16 - 
     (G[{1}, yv^(-1)]*G[{1, 1/(yu*yv), yv^(-1), 1/(yu*yv)}, yw])/8 - 
     (G[{1}, yw]*G[{1, 1/(yu*yv), yv^(-1), 1/(yu*yv)}, yw])/16 + 
     (G[{yu}, yv^(-1)]*G[{1, 1/(yu*yv), yv^(-1), 1/(yu*yv)}, yw])/16 + 
     (G[{0}, yu^(-1)]*G[{1, 1/(yu*yv), 1/(yu*yv), yu^(-1)}, yw])/4 + 
     (G[{0}, yv^(-1)]*G[{1, 1/(yu*yv), 1/(yu*yv), yu^(-1)}, yw])/4 - 
     (G[{0}, yw]*G[{1, 1/(yu*yv), 1/(yu*yv), yu^(-1)}, yw])/4 - 
     (G[{1}, yu^(-1)]*G[{1, 1/(yu*yv), 1/(yu*yv), yu^(-1)}, yw])/4 - 
     (G[{1}, yv^(-1)]*G[{1, 1/(yu*yv), 1/(yu*yv), yu^(-1)}, yw])/4 + 
     (G[{1}, yu^(-1)]*G[{1, 1/(yu*yv), 1/(yu*yv), yv^(-1)}, yw])/16 - 
     (G[{1}, yv^(-1)]*G[{1, 1/(yu*yv), 1/(yu*yv), yv^(-1)}, yw])/4 - 
     (3*G[{1}, yw]*G[{1, 1/(yu*yv), 1/(yu*yv), yv^(-1)}, yw])/16 + 
     (3*G[{yu}, yv^(-1)]*G[{1, 1/(yu*yv), 1/(yu*yv), yv^(-1)}, yw])/16 + 
     (G[{0}, yu^(-1)]*G[{1, 1/(yu*yv), 1/(yu*yv), 1/(yu*yv)}, yw])/8 + 
     (G[{0}, yv^(-1)]*G[{1, 1/(yu*yv), 1/(yu*yv), 1/(yu*yv)}, yw])/8 - 
     (G[{0}, yw]*G[{1, 1/(yu*yv), 1/(yu*yv), 1/(yu*yv)}, yw])/8 - 
     (3*G[{1}, yu^(-1)]*G[{1, 1/(yu*yv), 1/(yu*yv), 1/(yu*yv)}, yw])/16 - 
     (3*G[{1}, yv^(-1)]*G[{1, 1/(yu*yv), 1/(yu*yv), 1/(yu*yv)}, yw])/16 - 
     (G[{1}, yw]*G[{1, 1/(yu*yv), 1/(yu*yv), 1/(yu*yv)}, yw])/8 + 
     (G[{yu}, yv^(-1)]*G[{1, 1/(yu*yv), 1/(yu*yv), 1/(yu*yv)}, yw])/8 + 
     (25*G[{0}, yu^(-1)]*G[{yu^(-1), yu^(-1), yu^(-1), 1/(yu*yv)}, yw])/32 + 
     (25*G[{0}, yv^(-1)]*G[{yu^(-1), yu^(-1), yu^(-1), 1/(yu*yv)}, yw])/32 - 
     (25*G[{0}, yw]*G[{yu^(-1), yu^(-1), yu^(-1), 1/(yu*yv)}, yw])/32 - 
     (9*G[{1}, yu^(-1)]*G[{yu^(-1), yu^(-1), yu^(-1), 1/(yu*yv)}, yw])/32 - 
     (41*G[{1}, yv^(-1)]*G[{yu^(-1), yu^(-1), yu^(-1), 1/(yu*yv)}, yw])/32 + 
     (41*G[{yu^(-1)}, yw]*G[{yu^(-1), yu^(-1), yu^(-1), 1/(yu*yv)}, yw])/32 - 
     (3*G[{1/(yu*yv)}, yw]*G[{yu^(-1), yu^(-1), yu^(-1), 1/(yu*yv)}, yw])/
      64 - (G[{0}, yu^(-1)]*G[{yu^(-1), yu^(-1), 1/(yu*yv), yv^(-1)}, yw])/
      32 - (G[{0}, yv^(-1)]*G[{yu^(-1), yu^(-1), 1/(yu*yv), yv^(-1)}, yw])/
      32 + (G[{0}, yw]*G[{yu^(-1), yu^(-1), 1/(yu*yv), yv^(-1)}, yw])/32 - 
     (7*G[{1}, yu^(-1)]*G[{yu^(-1), yu^(-1), 1/(yu*yv), yv^(-1)}, yw])/32 + 
     (9*G[{1}, yv^(-1)]*G[{yu^(-1), yu^(-1), 1/(yu*yv), yv^(-1)}, yw])/32 - 
     (9*G[{yu^(-1)}, yw]*G[{yu^(-1), yu^(-1), 1/(yu*yv), yv^(-1)}, yw])/32 + 
     (11*G[{1/(yu*yv)}, yw]*G[{yu^(-1), yu^(-1), 1/(yu*yv), yv^(-1)}, yw])/
      64 + (25*G[{0}, yu^(-1)]*G[{yu^(-1), yu^(-1), 1/(yu*yv), 1/(yu*yv)}, 
        yw])/64 + (25*G[{0}, yv^(-1)]*G[{yu^(-1), yu^(-1), 1/(yu*yv), 
         1/(yu*yv)}, yw])/64 - 
     (25*G[{0}, yw]*G[{yu^(-1), yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/64 - 
     (9*G[{1}, yu^(-1)]*G[{yu^(-1), yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/64 - 
     (41*G[{1}, yv^(-1)]*G[{yu^(-1), yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/
      64 + (41*G[{yu^(-1)}, yw]*G[{yu^(-1), yu^(-1), 1/(yu*yv), 1/(yu*yv)}, 
        yw])/64 - (3*G[{1/(yu*yv)}, yw]*G[{yu^(-1), yu^(-1), 1/(yu*yv), 
         1/(yu*yv)}, yw])/32 - (7*G[{0}, yu^(-1)]*
       G[{yu^(-1), 1/(yu*yv), yv^(-1), yv^(-1)}, yw])/32 - 
     (7*G[{0}, yv^(-1)]*G[{yu^(-1), 1/(yu*yv), yv^(-1), yv^(-1)}, yw])/32 + 
     (7*G[{0}, yw]*G[{yu^(-1), 1/(yu*yv), yv^(-1), yv^(-1)}, yw])/32 + 
     (7*G[{1}, yu^(-1)]*G[{yu^(-1), 1/(yu*yv), yv^(-1), yv^(-1)}, yw])/32 + 
     (7*G[{1}, yv^(-1)]*G[{yu^(-1), 1/(yu*yv), yv^(-1), yv^(-1)}, yw])/32 - 
     (7*G[{yu^(-1)}, yw]*G[{yu^(-1), 1/(yu*yv), yv^(-1), yv^(-1)}, yw])/32 - 
     (11*G[{1/(yu*yv)}, yw]*G[{yu^(-1), 1/(yu*yv), yv^(-1), yv^(-1)}, yw])/
      64 + (11*G[{0}, yu^(-1)]*G[{yu^(-1), 1/(yu*yv), yv^(-1), 1/(yu*yv)}, 
        yw])/64 + (11*G[{0}, yv^(-1)]*G[{yu^(-1), 1/(yu*yv), yv^(-1), 
         1/(yu*yv)}, yw])/64 - 
     (11*G[{0}, yw]*G[{yu^(-1), 1/(yu*yv), yv^(-1), 1/(yu*yv)}, yw])/64 - 
     (15*G[{1}, yu^(-1)]*G[{yu^(-1), 1/(yu*yv), yv^(-1), 1/(yu*yv)}, yw])/
      64 + (G[{1}, yv^(-1)]*G[{yu^(-1), 1/(yu*yv), yv^(-1), 1/(yu*yv)}, yw])/
      64 + (G[{1}, yw]*G[{yu^(-1), 1/(yu*yv), yv^(-1), 1/(yu*yv)}, yw])/8 - 
     (G[{yu^(-1)}, yw]*G[{yu^(-1), 1/(yu*yv), yv^(-1), 1/(yu*yv)}, yw])/64 - 
     (G[{yu}, yv^(-1)]*G[{yu^(-1), 1/(yu*yv), yv^(-1), 1/(yu*yv)}, yw])/8 + 
     (3*G[{1/(yu*yv)}, yw]*G[{yu^(-1), 1/(yu*yv), yv^(-1), 1/(yu*yv)}, yw])/
      32 + (7*G[{0}, yu^(-1)]*G[{yu^(-1), 1/(yu*yv), 1/(yu*yv), yv^(-1)}, 
        yw])/64 + (7*G[{0}, yv^(-1)]*G[{yu^(-1), 1/(yu*yv), 1/(yu*yv), 
         yv^(-1)}, yw])/64 - (7*G[{0}, yw]*G[{yu^(-1), 1/(yu*yv), 1/(yu*yv), 
         yv^(-1)}, yw])/64 - (7*G[{1}, yu^(-1)]*
       G[{yu^(-1), 1/(yu*yv), 1/(yu*yv), yv^(-1)}, yw])/64 + 
     (9*G[{1}, yv^(-1)]*G[{yu^(-1), 1/(yu*yv), 1/(yu*yv), yv^(-1)}, yw])/64 + 
     (G[{1}, yw]*G[{yu^(-1), 1/(yu*yv), 1/(yu*yv), yv^(-1)}, yw])/4 - 
     (9*G[{yu^(-1)}, yw]*G[{yu^(-1), 1/(yu*yv), 1/(yu*yv), yv^(-1)}, yw])/
      64 - (G[{yu}, yv^(-1)]*G[{yu^(-1), 1/(yu*yv), 1/(yu*yv), yv^(-1)}, yw])/
      4 + (3*G[{1/(yu*yv)}, yw]*G[{yu^(-1), 1/(yu*yv), 1/(yu*yv), yv^(-1)}, 
        yw])/32 - (7*G[{0}, yu^(-1)]*G[{yu^(-1), 1/(yu*yv), 1/(yu*yv), 
         1/(yu*yv)}, yw])/64 - (7*G[{0}, yv^(-1)]*
       G[{yu^(-1), 1/(yu*yv), 1/(yu*yv), 1/(yu*yv)}, yw])/64 + 
     (7*G[{0}, yw]*G[{yu^(-1), 1/(yu*yv), 1/(yu*yv), 1/(yu*yv)}, yw])/64 + 
     (3*G[{1}, yu^(-1)]*G[{yu^(-1), 1/(yu*yv), 1/(yu*yv), 1/(yu*yv)}, yw])/
      64 + (23*G[{1}, yv^(-1)]*G[{yu^(-1), 1/(yu*yv), 1/(yu*yv), 1/(yu*yv)}, 
        yw])/64 + (3*G[{1}, yw]*G[{yu^(-1), 1/(yu*yv), 1/(yu*yv), 1/(yu*yv)}, 
        yw])/16 - (23*G[{yu^(-1)}, yw]*G[{yu^(-1), 1/(yu*yv), 1/(yu*yv), 
         1/(yu*yv)}, yw])/64 - (3*G[{yu}, yv^(-1)]*
       G[{yu^(-1), 1/(yu*yv), 1/(yu*yv), 1/(yu*yv)}, yw])/16 - 
     (7*G[{0}, yu^(-1)]*G[{yv^(-1), yv^(-1), yv^(-1), 1/(yu*yv)}, yw])/32 - 
     (7*G[{0}, yv^(-1)]*G[{yv^(-1), yv^(-1), yv^(-1), 1/(yu*yv)}, yw])/32 + 
     (7*G[{0}, yw]*G[{yv^(-1), yv^(-1), yv^(-1), 1/(yu*yv)}, yw])/32 + 
     (11*G[{1}, yu^(-1)]*G[{yv^(-1), yv^(-1), yv^(-1), 1/(yu*yv)}, yw])/32 + 
     (7*G[{1}, yv^(-1)]*G[{yv^(-1), yv^(-1), yv^(-1), 1/(yu*yv)}, yw])/32 + 
     (G[{1}, yw]*G[{yv^(-1), yv^(-1), yv^(-1), 1/(yu*yv)}, yw])/8 - 
     (7*G[{yu^(-1)}, yw]*G[{yv^(-1), yv^(-1), yv^(-1), 1/(yu*yv)}, yw])/32 - 
     (G[{yu}, yv^(-1)]*G[{yv^(-1), yv^(-1), yv^(-1), 1/(yu*yv)}, yw])/8 - 
     (11*G[{yv^(-1)}, yw]*G[{yv^(-1), yv^(-1), yv^(-1), 1/(yu*yv)}, yw])/32 - 
     (3*G[{1/(yu*yv)}, yw]*G[{yv^(-1), yv^(-1), yv^(-1), 1/(yu*yv)}, yw])/
      64 - (23*G[{0}, yu^(-1)]*G[{yv^(-1), yv^(-1), 1/(yu*yv), 1/(yu*yv)}, 
        yw])/64 - (23*G[{0}, yv^(-1)]*G[{yv^(-1), yv^(-1), 1/(yu*yv), 
         1/(yu*yv)}, yw])/64 + 
     (23*G[{0}, yw]*G[{yv^(-1), yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/64 + 
     (43*G[{1}, yu^(-1)]*G[{yv^(-1), yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/
      64 + (23*G[{1}, yv^(-1)]*G[{yv^(-1), yv^(-1), 1/(yu*yv), 1/(yu*yv)}, 
        yw])/64 + (5*G[{1}, yw]*G[{yv^(-1), yv^(-1), 1/(yu*yv), 1/(yu*yv)}, 
        yw])/16 - (23*G[{yu^(-1)}, yw]*G[{yv^(-1), yv^(-1), 1/(yu*yv), 
         1/(yu*yv)}, yw])/64 - (5*G[{yu}, yv^(-1)]*
       G[{yv^(-1), yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/16 - 
     (43*G[{yv^(-1)}, yw]*G[{yv^(-1), yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/
      64 - (3*G[{1/(yu*yv)}, yw]*G[{yv^(-1), yv^(-1), 1/(yu*yv), 1/(yu*yv)}, 
        yw])/32 - (7*G[{0}, yu^(-1)]*G[{yv^(-1), 1/(yu*yv), 1/(yu*yv), 
         1/(yu*yv)}, yw])/64 - (7*G[{0}, yv^(-1)]*
       G[{yv^(-1), 1/(yu*yv), 1/(yu*yv), 1/(yu*yv)}, yw])/64 + 
     (7*G[{0}, yw]*G[{yv^(-1), 1/(yu*yv), 1/(yu*yv), 1/(yu*yv)}, yw])/64 + 
     (23*G[{1}, yu^(-1)]*G[{yv^(-1), 1/(yu*yv), 1/(yu*yv), 1/(yu*yv)}, yw])/
      64 + (3*G[{1}, yv^(-1)]*G[{yv^(-1), 1/(yu*yv), 1/(yu*yv), 1/(yu*yv)}, 
        yw])/64 + (3*G[{1}, yw]*G[{yv^(-1), 1/(yu*yv), 1/(yu*yv), 1/(yu*yv)}, 
        yw])/16 - (3*G[{yu^(-1)}, yw]*G[{yv^(-1), 1/(yu*yv), 1/(yu*yv), 
         1/(yu*yv)}, yw])/64 - (3*G[{yu}, yv^(-1)]*
       G[{yv^(-1), 1/(yu*yv), 1/(yu*yv), 1/(yu*yv)}, yw])/16 - 
     (23*G[{yv^(-1)}, yw]*G[{yv^(-1), 1/(yu*yv), 1/(yu*yv), 1/(yu*yv)}, yw])/
      64 - (3*G[{0, 0, 0, 1, 1}, yu^(-1)])/8 - 
     (3*G[{0, 0, 0, 1, yu^(-1)}, yw])/8 + (9*G[{0, 0, 0, 1, yv^(-1)}, yw])/
      16 - (3*G[{0, 0, 0, 1, 1/(yu*yv)}, yw])/16 - 
     (3*G[{0, 0, 0, yu^(-1), 1}, yw])/8 + 
     (3*G[{0, 0, 0, yu^(-1), yu^(-1)}, yw])/4 - 
     (3*G[{0, 0, 0, yu^(-1), yv^(-1)}, yw])/16 - 
     (3*G[{0, 0, 0, yu^(-1), 1/(yu*yv)}, yw])/16 + 
     (9*G[{0, 0, 0, yv^(-1), 1}, yw])/16 - 
     (3*G[{0, 0, 0, yv^(-1), yu^(-1)}, yw])/16 - 
     (9*G[{0, 0, 0, yv^(-1), yv^(-1)}, yw])/8 + 
     (3*G[{0, 0, 0, yv^(-1), 1/(yu*yv)}, yw])/4 - 
     (3*G[{0, 0, 0, 1/(yu*yv), 1}, yw])/16 - 
     (3*G[{0, 0, 0, 1/(yu*yv), yu^(-1)}, yw])/16 + 
     (3*G[{0, 0, 0, 1/(yu*yv), yv^(-1)}, yw])/4 - 
     (3*G[{0, 0, 0, 1/(yu*yv), 1/(yu*yv)}, yw])/8 - 
     G[{0, 0, 1, 0, 1}, yu^(-1)]/8 - (3*G[{0, 0, 1, 0, 1}, yw])/64 - 
     (5*G[{0, 0, 1, 0, yu^(-1)}, yw])/64 + (15*G[{0, 0, 1, 0, yv^(-1)}, yw])/
      64 - (7*G[{0, 0, 1, 0, 1/(yu*yv)}, yw])/64 - 
     (3*G[{0, 0, 1, 1, 1}, yu^(-1)])/16 + (21*G[{0, 0, 1, 1, 1}, yv^(-1)])/
      16 + (3*G[{0, 0, 1, 1, 1}, yw])/8 - (3*G[{0, 0, 1, 1, yu^(-1)}, yw])/
      32 - (7*G[{0, 0, 1, 1, yu}, yv^(-1)])/16 + 
     (7*G[{0, 0, 1, 1, yv^(-1)}, yw])/32 - (9*G[{0, 0, 1, 1, 1/(yu*yv)}, yw])/
      32 + (11*G[{0, 0, 1, yu^(-1), 1}, yw])/64 - 
     (41*G[{0, 0, 1, yu^(-1), yu^(-1)}, yw])/64 + 
     (5*G[{0, 0, 1, yu^(-1), yv^(-1)}, yw])/64 - 
     (3*G[{0, 0, 1, yu^(-1), 1/(yu*yv)}, yw])/64 - 
     (3*G[{0, 0, 1, yu, 1}, yv^(-1)])/8 - G[{0, 0, 1, yu, yu}, yv^(-1)]/8 + 
     (11*G[{0, 0, 1, yv^(-1), 1}, yw])/64 + 
     (5*G[{0, 0, 1, yv^(-1), yu^(-1)}, yw])/64 + 
     (15*G[{0, 0, 1, yv^(-1), yv^(-1)}, yw])/64 - 
     (11*G[{0, 0, 1, yv^(-1), 1/(yu*yv)}, yw])/64 - 
     (15*G[{0, 0, 1, 1/(yu*yv), 1}, yw])/32 + 
     G[{0, 0, 1, 1/(yu*yv), yu^(-1)}, yw]/16 - 
     G[{0, 0, 1, 1/(yu*yv), yv^(-1)}, yw]/8 + 
     G[{0, 0, 1, 1/(yu*yv), 1/(yu*yv)}, yw]/8 - 
     (5*G[{0, 0, yu^(-1), 0, 1}, yw])/64 + 
     (13*G[{0, 0, yu^(-1), 0, yu^(-1)}, yw])/64 - 
     (7*G[{0, 0, yu^(-1), 0, yv^(-1)}, yw])/64 - 
     G[{0, 0, yu^(-1), 0, 1/(yu*yv)}, yw]/64 + 
     (3*G[{0, 0, yu^(-1), 1, 1}, yw])/32 - 
     (5*G[{0, 0, yu^(-1), 1, yu^(-1)}, yw])/16 - 
     (3*G[{0, 0, yu^(-1), 1, 1/(yu*yv)}, yw])/32 - 
     (21*G[{0, 0, yu^(-1), yu^(-1), 1}, yw])/64 + 
     (17*G[{0, 0, yu^(-1), yu^(-1), yu^(-1)}, yw])/64 - 
     (7*G[{0, 0, yu^(-1), yu^(-1), yv^(-1)}, yw])/64 - 
     (21*G[{0, 0, yu^(-1), yu^(-1), 1/(yu*yv)}, yw])/64 - 
     (3*G[{0, 0, yu^(-1), yv^(-1), 1}, yw])/64 - 
     (7*G[{0, 0, yu^(-1), yv^(-1), yu^(-1)}, yw])/64 - 
     (15*G[{0, 0, yu^(-1), yv^(-1), yv^(-1)}, yw])/64 + 
     (5*G[{0, 0, yu^(-1), yv^(-1), 1/(yu*yv)}, yw])/64 + 
     (11*G[{0, 0, yu^(-1), 1/(yu*yv), 1}, yw])/32 - 
     (5*G[{0, 0, yu^(-1), 1/(yu*yv), yu^(-1)}, yw])/16 + 
     G[{0, 0, yu^(-1), 1/(yu*yv), yv^(-1)}, yw]/32 - 
     G[{0, 0, yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw]/8 - 
     (5*G[{0, 0, yu, 1, 1}, yv^(-1)])/16 + G[{0, 0, yu, 1, yu}, yv^(-1)]/16 + 
     G[{0, 0, yu, yu, 1}, yv^(-1)]/4 + (15*G[{0, 0, yv^(-1), 0, 1}, yw])/64 - 
     (7*G[{0, 0, yv^(-1), 0, yu^(-1)}, yw])/64 - 
     (27*G[{0, 0, yv^(-1), 0, yv^(-1)}, yw])/64 + 
     (19*G[{0, 0, yv^(-1), 0, 1/(yu*yv)}, yw])/64 + 
     (11*G[{0, 0, yv^(-1), 1, 1}, yw])/32 + 
     G[{0, 0, yv^(-1), 1, yu^(-1)}, yw]/16 - 
     (3*G[{0, 0, yv^(-1), 1, 1/(yu*yv)}, yw])/32 - 
     (3*G[{0, 0, yv^(-1), yu^(-1), 1}, yw])/64 - 
     (7*G[{0, 0, yv^(-1), yu^(-1), yu^(-1)}, yw])/64 - 
     (7*G[{0, 0, yv^(-1), yu^(-1), yv^(-1)}, yw])/64 + 
     (5*G[{0, 0, yv^(-1), yu^(-1), 1/(yu*yv)}, yw])/64 - 
     (5*G[{0, 0, yv^(-1), yv^(-1), 1}, yw])/64 + 
     G[{0, 0, yv^(-1), yv^(-1), yu^(-1)}, yw]/64 + 
     (33*G[{0, 0, yv^(-1), yv^(-1), yv^(-1)}, yw])/64 + 
     (27*G[{0, 0, yv^(-1), yv^(-1), 1/(yu*yv)}, yw])/64 + 
     (7*G[{0, 0, yv^(-1), 1/(yu*yv), 1}, yw])/32 - 
     G[{0, 0, yv^(-1), 1/(yu*yv), yu^(-1)}, yw]/16 + 
     G[{0, 0, yv^(-1), 1/(yu*yv), yv^(-1)}, yw]/8 - 
     (7*G[{0, 0, 1/(yu*yv), 0, 1}, yw])/64 - 
     G[{0, 0, 1/(yu*yv), 0, yu^(-1)}, yw]/64 + 
     (19*G[{0, 0, 1/(yu*yv), 0, yv^(-1)}, yw])/64 - 
     (11*G[{0, 0, 1/(yu*yv), 0, 1/(yu*yv)}, yw])/64 - 
     (19*G[{0, 0, 1/(yu*yv), 1, 1}, yw])/32 + 
     (5*G[{0, 0, 1/(yu*yv), 1, yu^(-1)}, yw])/16 + 
     G[{0, 0, 1/(yu*yv), 1, yv^(-1)}, yw]/4 - 
     G[{0, 0, 1/(yu*yv), 1, 1/(yu*yv)}, yw]/32 + 
     (19*G[{0, 0, 1/(yu*yv), yu^(-1), 1}, yw])/64 - 
     (17*G[{0, 0, 1/(yu*yv), yu^(-1), yu^(-1)}, yw])/64 - 
     (9*G[{0, 0, 1/(yu*yv), yu^(-1), yv^(-1)}, yw])/64 + 
     (3*G[{0, 0, 1/(yu*yv), yu^(-1), 1/(yu*yv)}, yw])/64 + 
     (27*G[{0, 0, 1/(yu*yv), yv^(-1), 1}, yw])/64 - 
     (9*G[{0, 0, 1/(yu*yv), yv^(-1), yu^(-1)}, yw])/64 - 
     (9*G[{0, 0, 1/(yu*yv), yv^(-1), yv^(-1)}, yw])/64 + 
     (3*G[{0, 0, 1/(yu*yv), yv^(-1), 1/(yu*yv)}, yw])/64 - 
     G[{0, 0, 1/(yu*yv), 1/(yu*yv), 1}, yw]/4 + 
     G[{0, 0, 1/(yu*yv), 1/(yu*yv), yu^(-1)}, yw]/16 + 
     G[{0, 0, 1/(yu*yv), 1/(yu*yv), yv^(-1)}, yw]/4 + 
     (3*G[{0, 0, 1/(yu*yv), 1/(yu*yv), 1/(yu*yv)}, yw])/16 + 
     (7*G[{0, 1, 0, 1, 1}, yv^(-1)])/16 + (7*G[{0, 1, 0, 1, 1}, yw])/64 - 
     G[{0, 1, 0, 1, yu^(-1)}, yw]/64 - G[{0, 1, 0, 1, yu}, yv^(-1)]/8 + 
     (15*G[{0, 1, 0, 1, yv^(-1)}, yw])/64 - G[{0, 1, 0, 1, 1/(yu*yv)}, yw]/
      4 + G[{0, 1, 0, yu^(-1), 1}, yw]/16 - 
     (3*G[{0, 1, 0, yu^(-1), yu^(-1)}, yw])/16 - 
     G[{0, 1, 0, yu^(-1), yv^(-1)}, yw]/64 + 
     G[{0, 1, 0, yu^(-1), 1/(yu*yv)}, yw]/64 - G[{0, 1, 0, yu, 1}, yv^(-1)]/
      16 - G[{0, 1, 0, yu, yu}, yv^(-1)]/8 + G[{0, 1, 0, yv^(-1), 1}, yw]/4 - 
     G[{0, 1, 0, yv^(-1), yu^(-1)}, yw]/64 - 
     G[{0, 1, 0, yv^(-1), yv^(-1)}, yw]/16 - 
     (3*G[{0, 1, 0, yv^(-1), 1/(yu*yv)}, yw])/64 - 
     (5*G[{0, 1, 0, 1/(yu*yv), 1}, yw])/16 - 
     G[{0, 1, 0, 1/(yu*yv), yu^(-1)}, yw]/16 + 
     G[{0, 1, 0, 1/(yu*yv), yv^(-1)}, yw]/8 + 
     G[{0, 1, 0, 1/(yu*yv), 1/(yu*yv)}, yw]/64 + 
     (3*G[{0, 1, 1, 0, yu^(-1)}, yw])/64 + (3*G[{0, 1, 1, 0, yu}, yv^(-1)])/
      16 + (15*G[{0, 1, 1, 0, yv^(-1)}, yw])/64 - 
     (11*G[{0, 1, 1, 0, 1/(yu*yv)}, yw])/64 - G[{0, 1, 1, 1, 1}, yu^(-1)]/4 + 
     (5*G[{0, 1, 1, 1, 1}, yv^(-1)])/8 + (3*G[{0, 1, 1, 1, 1}, yw])/16 - 
     (9*G[{0, 1, 1, 1, yu^(-1)}, yw])/64 - G[{0, 1, 1, 1, yu}, yv^(-1)]/16 - 
     (17*G[{0, 1, 1, 1, yv^(-1)}, yw])/64 + G[{0, 1, 1, 1, 1/(yu*yv)}, yw]/
      8 - (5*G[{0, 1, 1, yu^(-1), 1}, yw])/32 + 
     (9*G[{0, 1, 1, yu^(-1), yu^(-1)}, yw])/64 + 
     G[{0, 1, 1, yu^(-1), yv^(-1)}, yw]/64 + 
     (3*G[{0, 1, 1, yu^(-1), 1/(yu*yv)}, yw])/32 + 
     (3*G[{0, 1, 1, yu, 1}, yv^(-1)])/16 - G[{0, 1, 1, yu, yu}, yv^(-1)]/4 - 
     (11*G[{0, 1, 1, yv^(-1), 1}, yw])/32 + 
     G[{0, 1, 1, yv^(-1), yu^(-1)}, yw]/64 + 
     (9*G[{0, 1, 1, yv^(-1), yv^(-1)}, yw])/64 + 
     (3*G[{0, 1, 1, yv^(-1), 1/(yu*yv)}, yw])/32 + 
     (5*G[{0, 1, 1, 1/(yu*yv), 1}, yw])/16 - 
     G[{0, 1, 1, 1/(yu*yv), yu^(-1)}, yw]/64 - 
     (13*G[{0, 1, 1, 1/(yu*yv), yv^(-1)}, yw])/64 - 
     G[{0, 1, yu^(-1), 0, yu^(-1)}, yw]/8 + 
     G[{0, 1, yu^(-1), 0, 1/(yu*yv)}, yw]/16 - 
     (3*G[{0, 1, yu^(-1), 1, 1}, yw])/32 + 
     (17*G[{0, 1, yu^(-1), 1, yu^(-1)}, yw])/64 + 
     (5*G[{0, 1, yu^(-1), 1, yv^(-1)}, yw])/64 + 
     (3*G[{0, 1, yu^(-1), 1, 1/(yu*yv)}, yw])/32 + 
     (21*G[{0, 1, yu^(-1), yu^(-1), 1}, yw])/64 - 
     (25*G[{0, 1, yu^(-1), yu^(-1), yu^(-1)}, yw])/32 - 
     G[{0, 1, yu^(-1), yu^(-1), yv^(-1)}, yw]/32 - 
     (11*G[{0, 1, yu^(-1), yu^(-1), 1/(yu*yv)}, yw])/64 + 
     (5*G[{0, 1, yu^(-1), yv^(-1), 1}, yw])/64 - 
     G[{0, 1, yu^(-1), yv^(-1), yu^(-1)}, yw]/32 + 
     (7*G[{0, 1, yu^(-1), yv^(-1), yv^(-1)}, yw])/32 - 
     (11*G[{0, 1, yu^(-1), yv^(-1), 1/(yu*yv)}, yw])/64 - 
     (3*G[{0, 1, yu^(-1), 1/(yu*yv), 1}, yw])/32 + 
     (9*G[{0, 1, yu^(-1), 1/(yu*yv), yu^(-1)}, yw])/64 - 
     (11*G[{0, 1, yu^(-1), 1/(yu*yv), yv^(-1)}, yw])/64 + 
     (3*G[{0, 1, yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/32 - 
     G[{0, 1, yu, 0, yu}, yv^(-1)]/8 + G[{0, 1, yu, 1, 1}, yv^(-1)]/8 - 
     (3*G[{0, 1, yu, 1, yu}, yv^(-1)])/16 - G[{0, 1, yu, yu, 1}, yv^(-1)]/2 + 
     G[{0, 1, yu, yu, yu}, yv^(-1)]/4 - G[{0, 1, yv^(-1), 0, yu^(-1)}, yw]/
      64 + G[{0, 1, yv^(-1), 0, yv^(-1)}, yw]/16 - 
     (13*G[{0, 1, yv^(-1), 1, 1}, yw])/32 + 
     G[{0, 1, yv^(-1), 1, yu^(-1)}, yw]/64 + 
     (9*G[{0, 1, yv^(-1), 1, yv^(-1)}, yw])/64 + 
     (3*G[{0, 1, yv^(-1), 1, 1/(yu*yv)}, yw])/32 + 
     (5*G[{0, 1, yv^(-1), yu^(-1), 1}, yw])/64 - 
     G[{0, 1, yv^(-1), yu^(-1), yu^(-1)}, yw]/32 + 
     (7*G[{0, 1, yv^(-1), yu^(-1), yv^(-1)}, yw])/32 - 
     (11*G[{0, 1, yv^(-1), yu^(-1), 1/(yu*yv)}, yw])/64 + 
     (13*G[{0, 1, yv^(-1), yv^(-1), 1}, yw])/64 + 
     (7*G[{0, 1, yv^(-1), yv^(-1), yu^(-1)}, yw])/32 + 
     (7*G[{0, 1, yv^(-1), yv^(-1), yv^(-1)}, yw])/32 - 
     (11*G[{0, 1, yv^(-1), yv^(-1), 1/(yu*yv)}, yw])/64 - 
     G[{0, 1, yv^(-1), 1/(yu*yv), 1}, yw]/32 + 
     G[{0, 1, yv^(-1), 1/(yu*yv), yu^(-1)}, yw]/64 - 
     (15*G[{0, 1, yv^(-1), 1/(yu*yv), yv^(-1)}, yw])/64 + 
     (3*G[{0, 1, yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/32 - 
     G[{0, 1, 1/(yu*yv), 0, yu^(-1)}, yw]/8 - 
     G[{0, 1, 1/(yu*yv), 0, yv^(-1)}, yw]/16 + 
     G[{0, 1, 1/(yu*yv), 0, 1/(yu*yv)}, yw]/64 + 
     (5*G[{0, 1, 1/(yu*yv), 1, 1}, yw])/16 - 
     (9*G[{0, 1, 1/(yu*yv), 1, yu^(-1)}, yw])/64 - 
     (17*G[{0, 1, 1/(yu*yv), 1, yv^(-1)}, yw])/64 - 
     (5*G[{0, 1, 1/(yu*yv), yu^(-1), 1}, yw])/32 + 
     (17*G[{0, 1, 1/(yu*yv), yu^(-1), yu^(-1)}, yw])/64 + 
     G[{0, 1, 1/(yu*yv), yu^(-1), yv^(-1)}, yw]/64 + 
     (3*G[{0, 1, 1/(yu*yv), yu^(-1), 1/(yu*yv)}, yw])/32 - 
     (11*G[{0, 1, 1/(yu*yv), yv^(-1), 1}, yw])/32 + 
     G[{0, 1, 1/(yu*yv), yv^(-1), yu^(-1)}, yw]/64 - 
     (7*G[{0, 1, 1/(yu*yv), yv^(-1), yv^(-1)}, yw])/64 + 
     (3*G[{0, 1, 1/(yu*yv), yv^(-1), 1/(yu*yv)}, yw])/32 - 
     G[{0, 1, 1/(yu*yv), 1/(yu*yv), 1}, yw]/16 + 
     (15*G[{0, 1, 1/(yu*yv), 1/(yu*yv), yu^(-1)}, yw])/64 + 
     (3*G[{0, 1, 1/(yu*yv), 1/(yu*yv), yv^(-1)}, yw])/64 - 
     G[{0, yu^(-1), 0, yu^(-1), 1}, yw]/64 - 
     (3*G[{0, yu^(-1), 0, yu^(-1), yu^(-1)}, yw])/16 - 
     G[{0, yu^(-1), 0, yu^(-1), yv^(-1)}, yw]/8 - 
     (9*G[{0, yu^(-1), 0, yu^(-1), 1/(yu*yv)}, yw])/64 - 
     G[{0, yu^(-1), 0, yv^(-1), 1}, yw]/16 - 
     G[{0, yu^(-1), 0, yv^(-1), yu^(-1)}, yw]/8 - 
     G[{0, yu^(-1), 0, yv^(-1), yv^(-1)}, yw]/16 + 
     G[{0, yu^(-1), 0, 1/(yu*yv), 1}, yw]/8 + 
     G[{0, yu^(-1), 0, 1/(yu*yv), yu^(-1)}, yw]/16 - 
     (3*G[{0, yu^(-1), 0, 1/(yu*yv), yv^(-1)}, yw])/64 - 
     G[{0, yu^(-1), 0, 1/(yu*yv), 1/(yu*yv)}, yw]/64 - 
     (3*G[{0, yu^(-1), 1, 0, yv^(-1)}, yw])/64 + 
     (3*G[{0, yu^(-1), 1, 0, 1/(yu*yv)}, yw])/64 + 
     G[{0, yu^(-1), 1, 1, yu^(-1)}, yw]/64 + 
     (5*G[{0, yu^(-1), 1, 1, yv^(-1)}, yw])/64 + 
     (5*G[{0, yu^(-1), 1, yu^(-1), 1}, yw])/32 - 
     (25*G[{0, yu^(-1), 1, yu^(-1), yu^(-1)}, yw])/64 - 
     G[{0, yu^(-1), 1, yu^(-1), yv^(-1)}, yw]/64 - 
     (3*G[{0, yu^(-1), 1, yu^(-1), 1/(yu*yv)}, yw])/32 + 
     (3*G[{0, yu^(-1), 1, yv^(-1), 1}, yw])/32 - 
     G[{0, yu^(-1), 1, yv^(-1), yu^(-1)}, yw]/64 + 
     (7*G[{0, yu^(-1), 1, yv^(-1), yv^(-1)}, yw])/64 - 
     (3*G[{0, yu^(-1), 1, yv^(-1), 1/(yu*yv)}, yw])/32 - 
     G[{0, yu^(-1), 1, 1/(yu*yv), 1}, yw]/8 + 
     G[{0, yu^(-1), 1, 1/(yu*yv), yu^(-1)}, yw]/64 + 
     G[{0, yu^(-1), 1, 1/(yu*yv), yv^(-1)}, yw]/64 - 
     G[{0, yu^(-1), yu^(-1), 0, yv^(-1)}, yw]/16 - 
     G[{0, yu^(-1), yu^(-1), 0, 1/(yu*yv)}, yw]/16 + 
     G[{0, yu^(-1), yu^(-1), 1, 1}, yw]/32 - 
     (25*G[{0, yu^(-1), yu^(-1), 1, yu^(-1)}, yw])/64 - 
     (9*G[{0, yu^(-1), yu^(-1), 1, yv^(-1)}, yw])/64 - 
     (3*G[{0, yu^(-1), yu^(-1), 1, 1/(yu*yv)}, yw])/32 - 
     (29*G[{0, yu^(-1), yu^(-1), yu^(-1), 1}, yw])/64 + 
     (41*G[{0, yu^(-1), yu^(-1), yu^(-1), yu^(-1)}, yw])/32 + 
     (9*G[{0, yu^(-1), yu^(-1), yu^(-1), yv^(-1)}, yw])/32 + 
     (3*G[{0, yu^(-1), yu^(-1), yu^(-1), 1/(yu*yv)}, yw])/64 - 
     (5*G[{0, yu^(-1), yu^(-1), yv^(-1), 1}, yw])/64 + 
     (9*G[{0, yu^(-1), yu^(-1), yv^(-1), yu^(-1)}, yw])/32 - 
     (7*G[{0, yu^(-1), yu^(-1), yv^(-1), yv^(-1)}, yw])/32 + 
     (11*G[{0, yu^(-1), yu^(-1), yv^(-1), 1/(yu*yv)}, yw])/64 + 
     (5*G[{0, yu^(-1), yu^(-1), 1/(yu*yv), 1}, yw])/32 - 
     (25*G[{0, yu^(-1), yu^(-1), 1/(yu*yv), yu^(-1)}, yw])/64 + 
     (7*G[{0, yu^(-1), yu^(-1), 1/(yu*yv), yv^(-1)}, yw])/64 - 
     (3*G[{0, yu^(-1), yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/32 - 
     G[{0, yu^(-1), yv^(-1), 0, yv^(-1)}, yw]/16 + 
     (5*G[{0, yu^(-1), yv^(-1), 1, 1}, yw])/32 - 
     G[{0, yu^(-1), yv^(-1), 1, yu^(-1)}, yw]/64 - 
     G[{0, yu^(-1), yv^(-1), 1, yv^(-1)}, yw]/64 - 
     (3*G[{0, yu^(-1), yv^(-1), 1, 1/(yu*yv)}, yw])/32 - 
     (5*G[{0, yu^(-1), yv^(-1), yu^(-1), 1}, yw])/64 + 
     (9*G[{0, yu^(-1), yv^(-1), yu^(-1), yu^(-1)}, yw])/32 - 
     (7*G[{0, yu^(-1), yv^(-1), yu^(-1), yv^(-1)}, yw])/32 + 
     (11*G[{0, yu^(-1), yv^(-1), yu^(-1), 1/(yu*yv)}, yw])/64 - 
     (5*G[{0, yu^(-1), yv^(-1), yv^(-1), 1}, yw])/64 - 
     (7*G[{0, yu^(-1), yv^(-1), yv^(-1), yu^(-1)}, yw])/32 - 
     (7*G[{0, yu^(-1), yv^(-1), yv^(-1), yv^(-1)}, yw])/32 + 
     (11*G[{0, yu^(-1), yv^(-1), yv^(-1), 1/(yu*yv)}, yw])/64 + 
     G[{0, yu^(-1), yv^(-1), 1/(yu*yv), 1}, yw]/32 - 
     G[{0, yu^(-1), yv^(-1), 1/(yu*yv), yu^(-1)}, yw]/64 + 
     (15*G[{0, yu^(-1), yv^(-1), 1/(yu*yv), yv^(-1)}, yw])/64 - 
     (3*G[{0, yu^(-1), yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/32 + 
     G[{0, yu^(-1), 1/(yu*yv), 0, yv^(-1)}, yw]/64 - 
     G[{0, yu^(-1), 1/(yu*yv), 0, 1/(yu*yv)}, yw]/64 + 
     G[{0, yu^(-1), 1/(yu*yv), 1, 1}, yw]/16 + 
     G[{0, yu^(-1), 1/(yu*yv), 1, yu^(-1)}, yw]/64 + 
     (9*G[{0, yu^(-1), 1/(yu*yv), 1, yv^(-1)}, yw])/64 + 
     G[{0, yu^(-1), 1/(yu*yv), yu^(-1), 1}, yw]/32 - 
     (25*G[{0, yu^(-1), 1/(yu*yv), yu^(-1), yu^(-1)}, yw])/64 - 
     G[{0, yu^(-1), 1/(yu*yv), yu^(-1), yv^(-1)}, yw]/64 - 
     (3*G[{0, yu^(-1), 1/(yu*yv), yu^(-1), 1/(yu*yv)}, yw])/32 + 
     (7*G[{0, yu^(-1), 1/(yu*yv), yv^(-1), 1}, yw])/32 - 
     G[{0, yu^(-1), 1/(yu*yv), yv^(-1), yu^(-1)}, yw]/64 + 
     (7*G[{0, yu^(-1), 1/(yu*yv), yv^(-1), yv^(-1)}, yw])/64 - 
     (3*G[{0, yu^(-1), 1/(yu*yv), yv^(-1), 1/(yu*yv)}, yw])/32 + 
     G[{0, yu^(-1), 1/(yu*yv), 1/(yu*yv), 1}, yw]/16 - 
     (15*G[{0, yu^(-1), 1/(yu*yv), 1/(yu*yv), yu^(-1)}, yw])/64 - 
     (3*G[{0, yu^(-1), 1/(yu*yv), 1/(yu*yv), yv^(-1)}, yw])/64 + 
     G[{0, yu, 0, yu, 1}, yv^(-1)]/16 - G[{0, yu, 1, 1, 1}, yv^(-1)]/4 - 
     (3*G[{0, yu, 1, yu, 1}, yv^(-1)])/16 + G[{0, yu, 1, yu, yu}, yv^(-1)]/
      8 - G[{0, yu, yu, 1, 1}, yv^(-1)]/4 + G[{0, yu, yu, 1, yu}, yv^(-1)]/
      8 + G[{0, yu, yu, yu, 1}, yv^(-1)]/4 + 
     (3*G[{0, yv^(-1), 0, yv^(-1), 1}, yw])/64 + 
     G[{0, yv^(-1), 0, yv^(-1), yu^(-1)}, yw]/16 + 
     (5*G[{0, yv^(-1), 0, yv^(-1), yv^(-1)}, yw])/16 + 
     (15*G[{0, yv^(-1), 0, yv^(-1), 1/(yu*yv)}, yw])/64 + 
     (3*G[{0, yv^(-1), 0, 1/(yu*yv), 1}, yw])/16 - 
     G[{0, yv^(-1), 0, 1/(yu*yv), yu^(-1)}, yw]/8 - 
     G[{0, yv^(-1), 0, 1/(yu*yv), yv^(-1)}, yw]/8 + 
     (3*G[{0, yv^(-1), 0, 1/(yu*yv), 1/(yu*yv)}, yw])/64 + 
     (3*G[{0, yv^(-1), 1, 0, 1/(yu*yv)}, yw])/64 - 
     (3*G[{0, yv^(-1), 1, 1, 1}, yw])/16 + 
     (9*G[{0, yv^(-1), 1, 1, yu^(-1)}, yw])/64 + 
     (17*G[{0, yv^(-1), 1, 1, yv^(-1)}, yw])/64 + 
     (5*G[{0, yv^(-1), 1, yu^(-1), 1}, yw])/32 - 
     G[{0, yv^(-1), 1, yu^(-1), yu^(-1)}, yw]/64 - 
     G[{0, yv^(-1), 1, yu^(-1), yv^(-1)}, yw]/64 - 
     (3*G[{0, yv^(-1), 1, yu^(-1), 1/(yu*yv)}, yw])/32 + 
     (11*G[{0, yv^(-1), 1, yv^(-1), 1}, yw])/32 - 
     G[{0, yv^(-1), 1, yv^(-1), yu^(-1)}, yw]/64 - 
     (9*G[{0, yv^(-1), 1, yv^(-1), yv^(-1)}, yw])/64 - 
     (3*G[{0, yv^(-1), 1, yv^(-1), 1/(yu*yv)}, yw])/32 - 
     G[{0, yv^(-1), 1, 1/(yu*yv), 1}, yw]/16 - 
     (7*G[{0, yv^(-1), 1, 1/(yu*yv), yu^(-1)}, yw])/64 + 
     (5*G[{0, yv^(-1), 1, 1/(yu*yv), yv^(-1)}, yw])/64 + 
     (5*G[{0, yv^(-1), yu^(-1), 1, 1}, yw])/32 - 
     G[{0, yv^(-1), yu^(-1), 1, yu^(-1)}, yw]/64 - 
     G[{0, yv^(-1), yu^(-1), 1, yv^(-1)}, yw]/64 - 
     (3*G[{0, yv^(-1), yu^(-1), 1, 1/(yu*yv)}, yw])/32 - 
     (5*G[{0, yv^(-1), yu^(-1), yu^(-1), 1}, yw])/64 + 
     (9*G[{0, yv^(-1), yu^(-1), yu^(-1), yu^(-1)}, yw])/32 - 
     (7*G[{0, yv^(-1), yu^(-1), yu^(-1), yv^(-1)}, yw])/32 + 
     (11*G[{0, yv^(-1), yu^(-1), yu^(-1), 1/(yu*yv)}, yw])/64 - 
     (5*G[{0, yv^(-1), yu^(-1), yv^(-1), 1}, yw])/64 - 
     (7*G[{0, yv^(-1), yu^(-1), yv^(-1), yu^(-1)}, yw])/32 - 
     (7*G[{0, yv^(-1), yu^(-1), yv^(-1), yv^(-1)}, yw])/32 + 
     (11*G[{0, yv^(-1), yu^(-1), yv^(-1), 1/(yu*yv)}, yw])/64 + 
     G[{0, yv^(-1), yu^(-1), 1/(yu*yv), 1}, yw]/32 - 
     G[{0, yv^(-1), yu^(-1), 1/(yu*yv), yu^(-1)}, yw]/64 + 
     (15*G[{0, yv^(-1), yu^(-1), 1/(yu*yv), yv^(-1)}, yw])/64 - 
     (3*G[{0, yv^(-1), yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/32 + 
     (3*G[{0, yv^(-1), yv^(-1), 0, 1/(yu*yv)}, yw])/16 + 
     (13*G[{0, yv^(-1), yv^(-1), 1, 1}, yw])/32 - 
     G[{0, yv^(-1), yv^(-1), 1, yu^(-1)}, yw]/64 - 
     (9*G[{0, yv^(-1), yv^(-1), 1, yv^(-1)}, yw])/64 - 
     (3*G[{0, yv^(-1), yv^(-1), 1, 1/(yu*yv)}, yw])/32 - 
     (5*G[{0, yv^(-1), yv^(-1), yu^(-1), 1}, yw])/64 - 
     (7*G[{0, yv^(-1), yv^(-1), yu^(-1), yu^(-1)}, yw])/32 - 
     (7*G[{0, yv^(-1), yv^(-1), yu^(-1), yv^(-1)}, yw])/32 + 
     (11*G[{0, yv^(-1), yv^(-1), yu^(-1), 1/(yu*yv)}, yw])/64 - 
     (13*G[{0, yv^(-1), yv^(-1), yv^(-1), 1}, yw])/64 - 
     (7*G[{0, yv^(-1), yv^(-1), yv^(-1), yu^(-1)}, yw])/32 - 
     (7*G[{0, yv^(-1), yv^(-1), yv^(-1), yv^(-1)}, yw])/32 + 
     (3*G[{0, yv^(-1), yv^(-1), yv^(-1), 1/(yu*yv)}, yw])/64 - 
     (7*G[{0, yv^(-1), yv^(-1), 1/(yu*yv), 1}, yw])/32 + 
     (15*G[{0, yv^(-1), yv^(-1), 1/(yu*yv), yu^(-1)}, yw])/64 + 
     (23*G[{0, yv^(-1), yv^(-1), 1/(yu*yv), yv^(-1)}, yw])/64 - 
     (3*G[{0, yv^(-1), yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/32 + 
     (3*G[{0, yv^(-1), 1/(yu*yv), 0, 1/(yu*yv)}, yw])/64 + 
     G[{0, yv^(-1), 1/(yu*yv), 1, 1}, yw]/8 - 
     (7*G[{0, yv^(-1), 1/(yu*yv), 1, yu^(-1)}, yw])/64 - 
     (3*G[{0, yv^(-1), 1/(yu*yv), 1, yv^(-1)}, yw])/64 - 
     (3*G[{0, yv^(-1), 1/(yu*yv), yu^(-1), 1}, yw])/32 - 
     G[{0, yv^(-1), 1/(yu*yv), yu^(-1), yu^(-1)}, yw]/64 + 
     (15*G[{0, yv^(-1), 1/(yu*yv), yu^(-1), yv^(-1)}, yw])/64 - 
     (3*G[{0, yv^(-1), 1/(yu*yv), yu^(-1), 1/(yu*yv)}, yw])/32 - 
     (5*G[{0, yv^(-1), 1/(yu*yv), yv^(-1), 1}, yw])/32 + 
     (15*G[{0, yv^(-1), 1/(yu*yv), yv^(-1), yu^(-1)}, yw])/64 + 
     (23*G[{0, yv^(-1), 1/(yu*yv), yv^(-1), yv^(-1)}, yw])/64 - 
     (3*G[{0, yv^(-1), 1/(yu*yv), yv^(-1), 1/(yu*yv)}, yw])/32 + 
     G[{0, yv^(-1), 1/(yu*yv), 1/(yu*yv), 1}, yw]/8 - 
     (7*G[{0, yv^(-1), 1/(yu*yv), 1/(yu*yv), yu^(-1)}, yw])/64 - 
     (7*G[{0, yv^(-1), 1/(yu*yv), 1/(yu*yv), yv^(-1)}, yw])/64 - 
     (5*G[{0, 1/(yu*yv), 0, 1/(yu*yv), 1}, yw])/64 + 
     (3*G[{0, 1/(yu*yv), 0, 1/(yu*yv), yv^(-1)}, yw])/16 + 
     (3*G[{0, 1/(yu*yv), 0, 1/(yu*yv), 1/(yu*yv)}, yw])/64 - 
     G[{0, 1/(yu*yv), 1, 1, yu^(-1)}, yw]/64 - 
     (5*G[{0, 1/(yu*yv), 1, 1, yv^(-1)}, yw])/64 - 
     G[{0, 1/(yu*yv), 1, 1, 1/(yu*yv)}, yw]/8 - 
     (5*G[{0, 1/(yu*yv), 1, yu^(-1), 1}, yw])/32 + 
     (17*G[{0, 1/(yu*yv), 1, yu^(-1), yu^(-1)}, yw])/64 + 
     G[{0, 1/(yu*yv), 1, yu^(-1), yv^(-1)}, yw]/64 + 
     (3*G[{0, 1/(yu*yv), 1, yu^(-1), 1/(yu*yv)}, yw])/32 - 
     (3*G[{0, 1/(yu*yv), 1, yv^(-1), 1}, yw])/32 + 
     G[{0, 1/(yu*yv), 1, yv^(-1), yu^(-1)}, yw]/64 - 
     (7*G[{0, 1/(yu*yv), 1, yv^(-1), yv^(-1)}, yw])/64 + 
     (3*G[{0, 1/(yu*yv), 1, yv^(-1), 1/(yu*yv)}, yw])/32 - 
     G[{0, 1/(yu*yv), 1, 1/(yu*yv), 1}, yw]/8 + 
     (7*G[{0, 1/(yu*yv), 1, 1/(yu*yv), yu^(-1)}, yw])/64 + 
     (7*G[{0, 1/(yu*yv), 1, 1/(yu*yv), yv^(-1)}, yw])/64 - 
     (3*G[{0, 1/(yu*yv), yu^(-1), 1, 1}, yw])/32 + 
     (9*G[{0, 1/(yu*yv), yu^(-1), 1, yu^(-1)}, yw])/64 + 
     (5*G[{0, 1/(yu*yv), yu^(-1), 1, yv^(-1)}, yw])/64 + 
     (3*G[{0, 1/(yu*yv), yu^(-1), 1, 1/(yu*yv)}, yw])/32 + 
     (13*G[{0, 1/(yu*yv), yu^(-1), yu^(-1), 1}, yw])/64 - 
     (25*G[{0, 1/(yu*yv), yu^(-1), yu^(-1), yu^(-1)}, yw])/32 - 
     G[{0, 1/(yu*yv), yu^(-1), yu^(-1), yv^(-1)}, yw]/32 - 
     (3*G[{0, 1/(yu*yv), yu^(-1), yu^(-1), 1/(yu*yv)}, yw])/64 + 
     (5*G[{0, 1/(yu*yv), yu^(-1), yv^(-1), 1}, yw])/64 - 
     G[{0, 1/(yu*yv), yu^(-1), yv^(-1), yu^(-1)}, yw]/32 + 
     (7*G[{0, 1/(yu*yv), yu^(-1), yv^(-1), yv^(-1)}, yw])/32 - 
     (11*G[{0, 1/(yu*yv), yu^(-1), yv^(-1), 1/(yu*yv)}, yw])/64 - 
     (3*G[{0, 1/(yu*yv), yu^(-1), 1/(yu*yv), 1}, yw])/32 + 
     (17*G[{0, 1/(yu*yv), yu^(-1), 1/(yu*yv), yu^(-1)}, yw])/64 - 
     (11*G[{0, 1/(yu*yv), yu^(-1), 1/(yu*yv), yv^(-1)}, yw])/64 + 
     (3*G[{0, 1/(yu*yv), yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/32 - 
     (5*G[{0, 1/(yu*yv), yv^(-1), 1, 1}, yw])/32 + 
     G[{0, 1/(yu*yv), yv^(-1), 1, yu^(-1)}, yw]/64 + 
     G[{0, 1/(yu*yv), yv^(-1), 1, yv^(-1)}, yw]/64 + 
     (3*G[{0, 1/(yu*yv), yv^(-1), 1, 1/(yu*yv)}, yw])/32 + 
     (5*G[{0, 1/(yu*yv), yv^(-1), yu^(-1), 1}, yw])/64 - 
     G[{0, 1/(yu*yv), yv^(-1), yu^(-1), yu^(-1)}, yw]/32 + 
     (7*G[{0, 1/(yu*yv), yv^(-1), yu^(-1), yv^(-1)}, yw])/32 - 
     (11*G[{0, 1/(yu*yv), yv^(-1), yu^(-1), 1/(yu*yv)}, yw])/64 + 
     (5*G[{0, 1/(yu*yv), yv^(-1), yv^(-1), 1}, yw])/64 + 
     (7*G[{0, 1/(yu*yv), yv^(-1), yv^(-1), yu^(-1)}, yw])/32 + 
     (7*G[{0, 1/(yu*yv), yv^(-1), yv^(-1), yv^(-1)}, yw])/32 - 
     (3*G[{0, 1/(yu*yv), yv^(-1), yv^(-1), 1/(yu*yv)}, yw])/64 + 
     (7*G[{0, 1/(yu*yv), yv^(-1), 1/(yu*yv), 1}, yw])/32 - 
     (15*G[{0, 1/(yu*yv), yv^(-1), 1/(yu*yv), yu^(-1)}, yw])/64 - 
     (23*G[{0, 1/(yu*yv), yv^(-1), 1/(yu*yv), yv^(-1)}, yw])/64 + 
     (3*G[{0, 1/(yu*yv), yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/32 - 
     G[{0, 1/(yu*yv), 1/(yu*yv), 1, 1}, yw]/2 + 
     (15*G[{0, 1/(yu*yv), 1/(yu*yv), 1, yu^(-1)}, yw])/64 + 
     (11*G[{0, 1/(yu*yv), 1/(yu*yv), 1, yv^(-1)}, yw])/64 + 
     (7*G[{0, 1/(yu*yv), 1/(yu*yv), yu^(-1), 1}, yw])/32 + 
     (9*G[{0, 1/(yu*yv), 1/(yu*yv), yu^(-1), yu^(-1)}, yw])/64 - 
     (15*G[{0, 1/(yu*yv), 1/(yu*yv), yu^(-1), yv^(-1)}, yw])/64 + 
     (3*G[{0, 1/(yu*yv), 1/(yu*yv), yu^(-1), 1/(yu*yv)}, yw])/32 + 
     (9*G[{0, 1/(yu*yv), 1/(yu*yv), yv^(-1), 1}, yw])/32 - 
     (15*G[{0, 1/(yu*yv), 1/(yu*yv), yv^(-1), yu^(-1)}, yw])/64 - 
     (23*G[{0, 1/(yu*yv), 1/(yu*yv), yv^(-1), yv^(-1)}, yw])/64 + 
     (3*G[{0, 1/(yu*yv), 1/(yu*yv), yv^(-1), 1/(yu*yv)}, yw])/32 - 
     G[{0, 1/(yu*yv), 1/(yu*yv), 1/(yu*yv), 1}, yw]/8 + 
     (7*G[{0, 1/(yu*yv), 1/(yu*yv), 1/(yu*yv), yu^(-1)}, yw])/64 + 
     (7*G[{0, 1/(yu*yv), 1/(yu*yv), 1/(yu*yv), yv^(-1)}, yw])/64 - 
     G[{1, 1, 1, 1, yu^(-1)}, yw]/16 - (7*G[{1, 1, 1, 1, yu}, yv^(-1)])/16 - 
     (7*G[{1, 1, 1, 1, yv^(-1)}, yw])/16 + G[{1, 1, 1, 1, 1/(yu*yv)}, yw]/8 - 
     (25*G[{1, 1, 1, yu^(-1), yu^(-1)}, yw])/16 + 
     G[{1, 1, 1, yu^(-1), yv^(-1)}, yw]/16 + 
     (17*G[{1, 1, 1, yu^(-1), 1/(yu*yv)}, yw])/16 + 
     (7*G[{1, 1, 1, yu, yu}, yv^(-1)])/8 + G[{1, 1, 1, yv^(-1), yu^(-1)}, yw]/
      16 - (5*G[{1, 1, 1, yv^(-1), yv^(-1)}, yw])/4 + 
     G[{1, 1, 1, yv^(-1), 1/(yu*yv)}, yw]/8 + 
     (9*G[{1, 1, 1, 1/(yu*yv), yu^(-1)}, yw])/8 + 
     (3*G[{1, 1, 1, 1/(yu*yv), yv^(-1)}, yw])/16 + 
     (3*G[{1, 1, 1, 1/(yu*yv), 1/(yu*yv)}, yw])/16 - 
     (33*G[{1, 1, yu^(-1), 1, yu^(-1)}, yw])/64 + 
     (3*G[{1, 1, yu^(-1), 1, yv^(-1)}, yw])/64 + 
     (5*G[{1, 1, yu^(-1), 1, 1/(yu*yv)}, yw])/16 - 
     G[{1, 1, yu^(-1), yu^(-1), yu^(-1)}, yw]/64 + 
     (7*G[{1, 1, yu^(-1), yu^(-1), yv^(-1)}, yw])/64 + 
     (3*G[{1, 1, yu^(-1), yu^(-1), 1/(yu*yv)}, yw])/4 + 
     (7*G[{1, 1, yu^(-1), yv^(-1), yu^(-1)}, yw])/64 - 
     (17*G[{1, 1, yu^(-1), yv^(-1), yv^(-1)}, yw])/64 - 
     (3*G[{1, 1, yu^(-1), yv^(-1), 1/(yu*yv)}, yw])/32 + 
     (17*G[{1, 1, yu^(-1), 1/(yu*yv), yu^(-1)}, yw])/64 + 
     (15*G[{1, 1, yu^(-1), 1/(yu*yv), yv^(-1)}, yw])/64 - 
     G[{1, 1, yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw]/8 + 
     (3*G[{1, 1, yu, 1, yu}, yv^(-1)])/8 - 
     (13*G[{1, 1, yu, yu, yu}, yv^(-1)])/16 + 
     (11*G[{1, 1, yv^(-1), 1, yu^(-1)}, yw])/64 - 
     (13*G[{1, 1, yv^(-1), 1, yv^(-1)}, yw])/64 + 
     (7*G[{1, 1, yv^(-1), yu^(-1), yu^(-1)}, yw])/64 - 
     (9*G[{1, 1, yv^(-1), yu^(-1), yv^(-1)}, yw])/64 - 
     (3*G[{1, 1, yv^(-1), yu^(-1), 1/(yu*yv)}, yw])/32 - 
     G[{1, 1, yv^(-1), yv^(-1), yu^(-1)}, yw]/64 - 
     (13*G[{1, 1, yv^(-1), yv^(-1), yv^(-1)}, yw])/64 - 
     G[{1, 1, yv^(-1), yv^(-1), 1/(yu*yv)}, yw]/8 + 
     (5*G[{1, 1, yv^(-1), 1/(yu*yv), yu^(-1)}, yw])/64 - 
     (3*G[{1, 1, yv^(-1), 1/(yu*yv), yv^(-1)}, yw])/64 + 
     G[{1, 1, yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw]/8 + 
     (5*G[{1, 1, 1/(yu*yv), 1, yu^(-1)}, yw])/16 + 
     G[{1, 1, 1/(yu*yv), 1, 1/(yu*yv)}, yw]/16 + 
     G[{1, 1, 1/(yu*yv), yu^(-1), yu^(-1)}, yw]/4 + 
     G[{1, 1, 1/(yu*yv), yu^(-1), yv^(-1)}, yw]/4 - 
     G[{1, 1, 1/(yu*yv), yu^(-1), 1/(yu*yv)}, yw]/8 + 
     G[{1, 1, 1/(yu*yv), yv^(-1), yu^(-1)}, yw]/4 + 
     G[{1, 1, 1/(yu*yv), yv^(-1), yv^(-1)}, yw]/16 - 
     G[{1, 1, 1/(yu*yv), yv^(-1), 1/(yu*yv)}, yw]/8 + 
     (7*G[{1, 1, 1/(yu*yv), 1/(yu*yv), yu^(-1)}, yw])/16 - 
     G[{1, 1, 1/(yu*yv), 1/(yu*yv), 1/(yu*yv)}, yw]/4 + 
     (5*G[{1, yu^(-1), 1, yu^(-1), yu^(-1)}, yw])/16 + 
     G[{1, yu^(-1), 1, yu^(-1), yv^(-1)}, yw]/8 + 
     (23*G[{1, yu^(-1), 1, yu^(-1), 1/(yu*yv)}, yw])/64 + 
     G[{1, yu^(-1), 1, yv^(-1), yu^(-1)}, yw]/8 - 
     (3*G[{1, yu^(-1), 1, yv^(-1), yv^(-1)}, yw])/16 + 
     G[{1, yu^(-1), 1, 1/(yu*yv), yu^(-1)}, yw]/8 + 
     (13*G[{1, yu^(-1), 1, 1/(yu*yv), yv^(-1)}, yw])/64 - 
     G[{1, yu^(-1), 1, 1/(yu*yv), 1/(yu*yv)}, yw]/16 + 
     G[{1, yu^(-1), yu^(-1), 1, yv^(-1)}, yw]/16 + 
     (3*G[{1, yu^(-1), yu^(-1), 1, 1/(yu*yv)}, yw])/8 - 
     (41*G[{1, yu^(-1), yu^(-1), yu^(-1), yu^(-1)}, yw])/32 - 
     (9*G[{1, yu^(-1), yu^(-1), yu^(-1), yv^(-1)}, yw])/32 - 
     (3*G[{1, yu^(-1), yu^(-1), yu^(-1), 1/(yu*yv)}, yw])/64 - 
     (9*G[{1, yu^(-1), yu^(-1), yv^(-1), yu^(-1)}, yw])/32 + 
     (7*G[{1, yu^(-1), yu^(-1), yv^(-1), yv^(-1)}, yw])/32 - 
     (11*G[{1, yu^(-1), yu^(-1), yv^(-1), 1/(yu*yv)}, yw])/64 + 
     (9*G[{1, yu^(-1), yu^(-1), 1/(yu*yv), yu^(-1)}, yw])/64 - 
     (23*G[{1, yu^(-1), yu^(-1), 1/(yu*yv), yv^(-1)}, yw])/64 + 
     (3*G[{1, yu^(-1), yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/32 - 
     G[{1, yu^(-1), yv^(-1), 1, yv^(-1)}, yw]/16 + 
     G[{1, yu^(-1), yv^(-1), 1, 1/(yu*yv)}, yw]/8 - 
     (9*G[{1, yu^(-1), yv^(-1), yu^(-1), yu^(-1)}, yw])/32 + 
     (7*G[{1, yu^(-1), yv^(-1), yu^(-1), yv^(-1)}, yw])/32 - 
     (11*G[{1, yu^(-1), yv^(-1), yu^(-1), 1/(yu*yv)}, yw])/64 + 
     (7*G[{1, yu^(-1), yv^(-1), yv^(-1), yu^(-1)}, yw])/32 + 
     (7*G[{1, yu^(-1), yv^(-1), yv^(-1), yv^(-1)}, yw])/32 - 
     (11*G[{1, yu^(-1), yv^(-1), yv^(-1), 1/(yu*yv)}, yw])/64 + 
     G[{1, yu^(-1), yv^(-1), 1/(yu*yv), yu^(-1)}, yw]/64 - 
     (15*G[{1, yu^(-1), yv^(-1), 1/(yu*yv), yv^(-1)}, yw])/64 + 
     (3*G[{1, yu^(-1), yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/32 - 
     (3*G[{1, yu^(-1), 1/(yu*yv), 1, yv^(-1)}, yw])/64 - 
     G[{1, yu^(-1), 1/(yu*yv), 1, 1/(yu*yv)}, yw]/16 + 
     (9*G[{1, yu^(-1), 1/(yu*yv), yu^(-1), yu^(-1)}, yw])/64 - 
     (7*G[{1, yu^(-1), 1/(yu*yv), yu^(-1), yv^(-1)}, yw])/64 + 
     (3*G[{1, yu^(-1), 1/(yu*yv), yu^(-1), 1/(yu*yv)}, yw])/32 - 
     (7*G[{1, yu^(-1), 1/(yu*yv), yv^(-1), yu^(-1)}, yw])/64 - 
     (7*G[{1, yu^(-1), 1/(yu*yv), yv^(-1), yv^(-1)}, yw])/64 + 
     (3*G[{1, yu^(-1), 1/(yu*yv), yv^(-1), 1/(yu*yv)}, yw])/32 + 
     (7*G[{1, yu^(-1), 1/(yu*yv), 1/(yu*yv), yu^(-1)}, yw])/64 + 
     (3*G[{1, yu^(-1), 1/(yu*yv), 1/(yu*yv), yv^(-1)}, yw])/64 - 
     (7*G[{1, yu, 1, yu, yu}, yv^(-1)])/16 + G[{1, yu, yu, yu, yu}, yv^(-1)]/
      8 + G[{1, yv^(-1), 1, yv^(-1), yu^(-1)}, yw]/16 + 
     G[{1, yv^(-1), 1, yv^(-1), yv^(-1)}, yw]/8 - 
     (5*G[{1, yv^(-1), 1, yv^(-1), 1/(yu*yv)}, yw])/64 + 
     G[{1, yv^(-1), 1, 1/(yu*yv), yu^(-1)}, yw]/8 - 
     G[{1, yv^(-1), 1, 1/(yu*yv), yv^(-1)}, yw]/8 + 
     G[{1, yv^(-1), 1, 1/(yu*yv), 1/(yu*yv)}, yw]/16 + 
     G[{1, yv^(-1), yu^(-1), 1, 1/(yu*yv)}, yw]/8 - 
     (9*G[{1, yv^(-1), yu^(-1), yu^(-1), yu^(-1)}, yw])/32 + 
     (7*G[{1, yv^(-1), yu^(-1), yu^(-1), yv^(-1)}, yw])/32 - 
     (11*G[{1, yv^(-1), yu^(-1), yu^(-1), 1/(yu*yv)}, yw])/64 + 
     (7*G[{1, yv^(-1), yu^(-1), yv^(-1), yu^(-1)}, yw])/32 + 
     (7*G[{1, yv^(-1), yu^(-1), yv^(-1), yv^(-1)}, yw])/32 - 
     (11*G[{1, yv^(-1), yu^(-1), yv^(-1), 1/(yu*yv)}, yw])/64 + 
     G[{1, yv^(-1), yu^(-1), 1/(yu*yv), yu^(-1)}, yw]/64 - 
     (15*G[{1, yv^(-1), yu^(-1), 1/(yu*yv), yv^(-1)}, yw])/64 + 
     (3*G[{1, yv^(-1), yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/32 - 
     G[{1, yv^(-1), yv^(-1), 1, 1/(yu*yv)}, yw]/16 + 
     (7*G[{1, yv^(-1), yv^(-1), yu^(-1), yu^(-1)}, yw])/32 + 
     (7*G[{1, yv^(-1), yv^(-1), yu^(-1), yv^(-1)}, yw])/32 - 
     (11*G[{1, yv^(-1), yv^(-1), yu^(-1), 1/(yu*yv)}, yw])/64 + 
     (7*G[{1, yv^(-1), yv^(-1), yv^(-1), yu^(-1)}, yw])/32 + 
     (3*G[{1, yv^(-1), yv^(-1), yv^(-1), yv^(-1)}, yw])/32 - 
     (3*G[{1, yv^(-1), yv^(-1), yv^(-1), 1/(yu*yv)}, yw])/64 - 
     (7*G[{1, yv^(-1), yv^(-1), 1/(yu*yv), yu^(-1)}, yw])/64 - 
     (3*G[{1, yv^(-1), yv^(-1), 1/(yu*yv), yv^(-1)}, yw])/64 + 
     (3*G[{1, yv^(-1), yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/32 + 
     G[{1, yv^(-1), 1/(yu*yv), 1, 1/(yu*yv)}, yw]/16 + 
     (9*G[{1, yv^(-1), 1/(yu*yv), yu^(-1), yu^(-1)}, yw])/64 - 
     (7*G[{1, yv^(-1), 1/(yu*yv), yu^(-1), yv^(-1)}, yw])/64 + 
     (3*G[{1, yv^(-1), 1/(yu*yv), yu^(-1), 1/(yu*yv)}, yw])/32 - 
     (7*G[{1, yv^(-1), 1/(yu*yv), yv^(-1), yu^(-1)}, yw])/64 - 
     (3*G[{1, yv^(-1), 1/(yu*yv), yv^(-1), yv^(-1)}, yw])/64 + 
     (3*G[{1, yv^(-1), 1/(yu*yv), yv^(-1), 1/(yu*yv)}, yw])/32 + 
     (11*G[{1, yv^(-1), 1/(yu*yv), 1/(yu*yv), yu^(-1)}, yw])/64 - 
     (9*G[{1, yv^(-1), 1/(yu*yv), 1/(yu*yv), yv^(-1)}, yw])/64 + 
     G[{1, 1/(yu*yv), 1, 1/(yu*yv), yu^(-1)}, yw]/8 - 
     (3*G[{1, 1/(yu*yv), 1, 1/(yu*yv), yv^(-1)}, yw])/16 - 
     G[{1, 1/(yu*yv), 1, 1/(yu*yv), 1/(yu*yv)}, yw]/8 - 
     G[{1, 1/(yu*yv), yu^(-1), yu^(-1), 1/(yu*yv)}, yw]/8 + 
     G[{1, 1/(yu*yv), yu^(-1), 1/(yu*yv), yu^(-1)}, yw]/8 + 
     G[{1, 1/(yu*yv), yu^(-1), 1/(yu*yv), yv^(-1)}, yw]/4 + 
     G[{1, 1/(yu*yv), yv^(-1), yv^(-1), yv^(-1)}, yw]/8 - 
     G[{1, 1/(yu*yv), yv^(-1), yv^(-1), 1/(yu*yv)}, yw]/8 + 
     G[{1, 1/(yu*yv), yv^(-1), 1/(yu*yv), yu^(-1)}, yw]/8 - 
     (3*G[{1, 1/(yu*yv), yv^(-1), 1/(yu*yv), yv^(-1)}, yw])/16 + 
     G[{1, 1/(yu*yv), 1/(yu*yv), yu^(-1), yu^(-1)}, yw]/4 + 
     G[{1, 1/(yu*yv), 1/(yu*yv), yu^(-1), yv^(-1)}, yw]/4 + 
     G[{1, 1/(yu*yv), 1/(yu*yv), yv^(-1), yu^(-1)}, yw]/4 - 
     G[{1, 1/(yu*yv), 1/(yu*yv), yv^(-1), yv^(-1)}, yw]/16 + 
     (3*G[{1, 1/(yu*yv), 1/(yu*yv), 1/(yu*yv), yu^(-1)}, yw])/16 + 
     (3*G[{1, 1/(yu*yv), 1/(yu*yv), 1/(yu*yv), yv^(-1)}, yw])/16 - 
     (41*G[{yu^(-1), yu^(-1), yu^(-1), yu^(-1), 1/(yu*yv)}, yw])/32 + 
     (9*G[{yu^(-1), yu^(-1), yu^(-1), 1/(yu*yv), yv^(-1)}, yw])/32 - 
     (129*G[{yu^(-1), yu^(-1), yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/64 - 
     (11*G[{yu^(-1), yu^(-1), 1/(yu*yv), yu^(-1), 1/(yu*yv)}, yw])/16 + 
     (7*G[{yu^(-1), yu^(-1), 1/(yu*yv), yv^(-1), yv^(-1)}, yw])/32 - 
     (11*G[{yu^(-1), yu^(-1), 1/(yu*yv), yv^(-1), 1/(yu*yv)}, yw])/64 - 
     (15*G[{yu^(-1), yu^(-1), 1/(yu*yv), 1/(yu*yv), yv^(-1)}, yw])/64 - 
     (7*G[{yu^(-1), yu^(-1), 1/(yu*yv), 1/(yu*yv), 1/(yu*yv)}, yw])/16 - 
     (3*G[{yu^(-1), 1/(yu*yv), yu^(-1), 1/(yu*yv), yv^(-1)}, yw])/16 - 
     (17*G[{yu^(-1), 1/(yu*yv), yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/64 - 
     (7*G[{yu^(-1), 1/(yu*yv), yv^(-1), yv^(-1), yv^(-1)}, yw])/32 + 
     (11*G[{yu^(-1), 1/(yu*yv), yv^(-1), yv^(-1), 1/(yu*yv)}, yw])/64 + 
     (15*G[{yu^(-1), 1/(yu*yv), yv^(-1), 1/(yu*yv), yv^(-1)}, yw])/64 - 
     (3*G[{yu^(-1), 1/(yu*yv), yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/32 + 
     (7*G[{yu^(-1), 1/(yu*yv), 1/(yu*yv), yv^(-1), yv^(-1)}, yw])/64 - 
     (3*G[{yu^(-1), 1/(yu*yv), 1/(yu*yv), yv^(-1), 1/(yu*yv)}, yw])/32 - 
     (3*G[{yu^(-1), 1/(yu*yv), 1/(yu*yv), 1/(yu*yv), yv^(-1)}, yw])/64 + 
     (11*G[{yv^(-1), yv^(-1), yv^(-1), yv^(-1), 1/(yu*yv)}, yw])/32 + 
     (123*G[{yv^(-1), yv^(-1), yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/64 + 
     (5*G[{yv^(-1), yv^(-1), 1/(yu*yv), yv^(-1), 1/(yu*yv)}, yw])/8 - 
     (7*G[{yv^(-1), yv^(-1), 1/(yu*yv), 1/(yu*yv), 1/(yu*yv)}, yw])/16 - 
     (17*G[{yv^(-1), 1/(yu*yv), yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/64 + 
     (11*Pi^2*Zeta[3])/256 + (3*G[{0}, yu^(-1)]^2*Zeta[3])/16 + 
     (3*G[{0}, yu^(-1)]*G[{0}, yv^(-1)]*Zeta[3])/8 + 
     (3*G[{0}, yv^(-1)]^2*Zeta[3])/16 - (3*G[{0}, yu^(-1)]*G[{0}, yw]*
       Zeta[3])/8 - (3*G[{0}, yv^(-1)]*G[{0}, yw]*Zeta[3])/8 + 
     (3*G[{0}, yw]^2*Zeta[3])/16 - (3*G[{0}, yu^(-1)]*G[{1}, yu^(-1)]*
       Zeta[3])/8 - (3*G[{0}, yv^(-1)]*G[{1}, yu^(-1)]*Zeta[3])/8 + 
     (3*G[{0}, yw]*G[{1}, yu^(-1)]*Zeta[3])/8 + 
     (11*G[{1}, yu^(-1)]^2*Zeta[3])/64 - (G[{0}, yu^(-1)]*G[{1}, yv^(-1)]*
       Zeta[3])/4 - (G[{0}, yv^(-1)]*G[{1}, yv^(-1)]*Zeta[3])/4 + 
     (G[{0}, yw]*G[{1}, yv^(-1)]*Zeta[3])/4 + 
     (9*G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*Zeta[3])/32 + 
     (G[{0}, yu^(-1)]*G[{1}, yw]*Zeta[3])/4 + 
     (G[{0}, yv^(-1)]*G[{1}, yw]*Zeta[3])/4 - (G[{0}, yw]*G[{1}, yw]*Zeta[3])/
      4 - (9*G[{1}, yu^(-1)]*G[{1}, yw]*Zeta[3])/32 - 
     (5*G[{1}, yw]^2*Zeta[3])/32 + (G[{1}, yw]*G[{yu}, yv^(-1)]*Zeta[3])/32 + 
     (3*G[{0}, yu^(-1)]*G[{1/(yu*yv)}, yw]*Zeta[3])/8 + 
     (3*G[{0}, yv^(-1)]*G[{1/(yu*yv)}, yw]*Zeta[3])/8 - 
     (3*G[{0}, yw]*G[{1/(yu*yv)}, yw]*Zeta[3])/8 - 
     (11*G[{1}, yu^(-1)]*G[{1/(yu*yv)}, yw]*Zeta[3])/32 - 
     (G[{1}, yv^(-1)]*G[{1/(yu*yv)}, yw]*Zeta[3])/4 + 
     (G[{1}, yw]*G[{1/(yu*yv)}, yw]*Zeta[3])/8 + 
     (5*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*Zeta[3])/32 - 
     (G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw]*Zeta[3])/32 + 
     (G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*Zeta[3])/4 + 
     (3*G[{1/(yu*yv)}, yw]^2*Zeta[3])/64 + (G[{0, 1}, yu^(-1)]*Zeta[3])/32 + 
     (9*G[{0, 1}, yw]*Zeta[3])/32 - (5*G[{0, yu^(-1)}, yw]*Zeta[3])/32 - 
     (13*G[{0, yv^(-1)}, yw]*Zeta[3])/32 + (9*G[{0, 1/(yu*yv)}, yw]*Zeta[3])/
      32 + (5*G[{1, yu^(-1)}, yw]*Zeta[3])/32 - (G[{1, yu}, yv^(-1)]*Zeta[3])/
      32 + (5*G[{1, yv^(-1)}, yw]*Zeta[3])/16 - 
     (G[{1, 1/(yu*yv)}, yw]*Zeta[3])/32 - 
     (5*G[{yu^(-1), 1/(yu*yv)}, yw]*Zeta[3])/32 - 
     (G[{yv^(-1), 1/(yu*yv)}, yw]*Zeta[3])/4 - (5*Zeta[5])/64
 
QepvwuRegII = (Pi^4*G[{0}, yu^(-1)])/1152 + (Pi^4*G[{0}, yv^(-1)])/1152 - 
     (Pi^4*G[{0}, yw])/1152 + (Pi^2*G[{0}, yu^(-1)]^2*G[{1}, yu^(-1)])/64 + 
     (Pi^2*G[{0}, yu^(-1)]*G[{0}, yv^(-1)]*G[{1}, yu^(-1)])/32 + 
     (Pi^2*G[{0}, yv^(-1)]^2*G[{1}, yu^(-1)])/64 - 
     (Pi^2*G[{0}, yu^(-1)]*G[{0}, yw]*G[{1}, yu^(-1)])/32 - 
     (Pi^2*G[{0}, yv^(-1)]*G[{0}, yw]*G[{1}, yu^(-1)])/32 + 
     (Pi^2*G[{0}, yw]^2*G[{1}, yu^(-1)])/64 - 
     (5*Pi^2*G[{0}, yu^(-1)]*G[{1}, yu^(-1)]^2)/192 - 
     (5*Pi^2*G[{0}, yv^(-1)]*G[{1}, yu^(-1)]^2)/192 + 
     (5*Pi^2*G[{0}, yw]*G[{1}, yu^(-1)]^2)/192 + (5*Pi^2*G[{1}, yu^(-1)]^3)/
      576 - (Pi^4*G[{1}, yv^(-1)])/1152 - 
     (Pi^2*G[{0}, yu^(-1)]*G[{1}, yu^(-1)]*G[{1}, yv^(-1)])/32 - 
     (Pi^2*G[{0}, yv^(-1)]*G[{1}, yu^(-1)]*G[{1}, yv^(-1)])/32 + 
     (Pi^2*G[{0}, yw]*G[{1}, yu^(-1)]*G[{1}, yv^(-1)])/32 + 
     (5*Pi^2*G[{1}, yu^(-1)]^2*G[{1}, yv^(-1)])/192 + 
     (Pi^2*G[{0}, yu^(-1)]*G[{1}, yv^(-1)]^2)/768 - 
     (3*G[{0}, yu^(-1)]^3*G[{1}, yv^(-1)]^2)/256 + 
     (Pi^2*G[{0}, yv^(-1)]*G[{1}, yv^(-1)]^2)/768 - 
     (9*G[{0}, yu^(-1)]^2*G[{0}, yv^(-1)]*G[{1}, yv^(-1)]^2)/256 - 
     (9*G[{0}, yu^(-1)]*G[{0}, yv^(-1)]^2*G[{1}, yv^(-1)]^2)/256 - 
     (3*G[{0}, yv^(-1)]^3*G[{1}, yv^(-1)]^2)/256 - 
     (Pi^2*G[{0}, yw]*G[{1}, yv^(-1)]^2)/768 + 
     (9*G[{0}, yu^(-1)]^2*G[{0}, yw]*G[{1}, yv^(-1)]^2)/256 + 
     (9*G[{0}, yu^(-1)]*G[{0}, yv^(-1)]*G[{0}, yw]*G[{1}, yv^(-1)]^2)/128 + 
     (9*G[{0}, yv^(-1)]^2*G[{0}, yw]*G[{1}, yv^(-1)]^2)/256 - 
     (9*G[{0}, yu^(-1)]*G[{0}, yw]^2*G[{1}, yv^(-1)]^2)/256 - 
     (9*G[{0}, yv^(-1)]*G[{0}, yw]^2*G[{1}, yv^(-1)]^2)/256 + 
     (3*G[{0}, yw]^3*G[{1}, yv^(-1)]^2)/256 + 
     (Pi^2*G[{1}, yu^(-1)]*G[{1}, yv^(-1)]^2)/256 - 
     (3*G[{0}, yu^(-1)]^2*G[{1}, yu^(-1)]*G[{1}, yv^(-1)]^2)/256 - 
     (3*G[{0}, yu^(-1)]*G[{0}, yv^(-1)]*G[{1}, yu^(-1)]*G[{1}, yv^(-1)]^2)/
      128 - (3*G[{0}, yv^(-1)]^2*G[{1}, yu^(-1)]*G[{1}, yv^(-1)]^2)/256 + 
     (3*G[{0}, yu^(-1)]*G[{0}, yw]*G[{1}, yu^(-1)]*G[{1}, yv^(-1)]^2)/128 + 
     (3*G[{0}, yv^(-1)]*G[{0}, yw]*G[{1}, yu^(-1)]*G[{1}, yv^(-1)]^2)/128 - 
     (3*G[{0}, yw]^2*G[{1}, yu^(-1)]*G[{1}, yv^(-1)]^2)/256 + 
     (11*G[{0}, yu^(-1)]*G[{1}, yu^(-1)]^2*G[{1}, yv^(-1)]^2)/256 + 
     (11*G[{0}, yv^(-1)]*G[{1}, yu^(-1)]^2*G[{1}, yv^(-1)]^2)/256 - 
     (11*G[{0}, yw]*G[{1}, yu^(-1)]^2*G[{1}, yv^(-1)]^2)/256 - 
     (5*G[{1}, yu^(-1)]^3*G[{1}, yv^(-1)]^2)/256 + (Pi^2*G[{1}, yv^(-1)]^3)/
      2304 + (9*G[{0}, yu^(-1)]^2*G[{1}, yv^(-1)]^3)/256 + 
     (9*G[{0}, yu^(-1)]*G[{0}, yv^(-1)]*G[{1}, yv^(-1)]^3)/128 + 
     (9*G[{0}, yv^(-1)]^2*G[{1}, yv^(-1)]^3)/256 - 
     (9*G[{0}, yu^(-1)]*G[{0}, yw]*G[{1}, yv^(-1)]^3)/128 - 
     (9*G[{0}, yv^(-1)]*G[{0}, yw]*G[{1}, yv^(-1)]^3)/128 + 
     (9*G[{0}, yw]^2*G[{1}, yv^(-1)]^3)/256 + 
     (G[{0}, yu^(-1)]*G[{1}, yu^(-1)]*G[{1}, yv^(-1)]^3)/384 + 
     (G[{0}, yv^(-1)]*G[{1}, yu^(-1)]*G[{1}, yv^(-1)]^3)/384 - 
     (G[{0}, yw]*G[{1}, yu^(-1)]*G[{1}, yv^(-1)]^3)/384 - 
     (7*G[{1}, yu^(-1)]^2*G[{1}, yv^(-1)]^3)/256 - 
     (9*G[{0}, yu^(-1)]*G[{1}, yv^(-1)]^4)/256 - 
     (9*G[{0}, yv^(-1)]*G[{1}, yv^(-1)]^4)/256 + 
     (9*G[{0}, yw]*G[{1}, yv^(-1)]^4)/256 + 
     (5*G[{1}, yu^(-1)]*G[{1}, yv^(-1)]^4)/768 + (3*G[{1}, yv^(-1)]^5)/256 - 
     (Pi^2*G[{0}, yu^(-1)]^2*G[{1}, yw])/64 - 
     (Pi^2*G[{0}, yu^(-1)]*G[{0}, yv^(-1)]*G[{1}, yw])/32 - 
     (Pi^2*G[{0}, yv^(-1)]^2*G[{1}, yw])/64 + 
     (Pi^2*G[{0}, yu^(-1)]*G[{0}, yw]*G[{1}, yw])/32 + 
     (Pi^2*G[{0}, yv^(-1)]*G[{0}, yw]*G[{1}, yw])/32 - 
     (Pi^2*G[{0}, yw]^2*G[{1}, yw])/64 + 
     (5*Pi^2*G[{0}, yu^(-1)]*G[{1}, yu^(-1)]*G[{1}, yw])/96 + 
     (5*Pi^2*G[{0}, yv^(-1)]*G[{1}, yu^(-1)]*G[{1}, yw])/96 - 
     (5*Pi^2*G[{0}, yw]*G[{1}, yu^(-1)]*G[{1}, yw])/96 - 
     (5*Pi^2*G[{1}, yu^(-1)]^2*G[{1}, yw])/192 + 
     (5*Pi^2*G[{0}, yu^(-1)]*G[{1}, yv^(-1)]*G[{1}, yw])/384 - 
     (3*G[{0}, yu^(-1)]^3*G[{1}, yv^(-1)]*G[{1}, yw])/128 + 
     (5*Pi^2*G[{0}, yv^(-1)]*G[{1}, yv^(-1)]*G[{1}, yw])/384 - 
     (9*G[{0}, yu^(-1)]^2*G[{0}, yv^(-1)]*G[{1}, yv^(-1)]*G[{1}, yw])/128 - 
     (9*G[{0}, yu^(-1)]*G[{0}, yv^(-1)]^2*G[{1}, yv^(-1)]*G[{1}, yw])/128 - 
     (3*G[{0}, yv^(-1)]^3*G[{1}, yv^(-1)]*G[{1}, yw])/128 - 
     (5*Pi^2*G[{0}, yw]*G[{1}, yv^(-1)]*G[{1}, yw])/384 + 
     (9*G[{0}, yu^(-1)]^2*G[{0}, yw]*G[{1}, yv^(-1)]*G[{1}, yw])/128 + 
     (9*G[{0}, yu^(-1)]*G[{0}, yv^(-1)]*G[{0}, yw]*G[{1}, yv^(-1)]*
       G[{1}, yw])/64 + (9*G[{0}, yv^(-1)]^2*G[{0}, yw]*G[{1}, yv^(-1)]*
       G[{1}, yw])/128 - (9*G[{0}, yu^(-1)]*G[{0}, yw]^2*G[{1}, yv^(-1)]*
       G[{1}, yw])/128 - (9*G[{0}, yv^(-1)]*G[{0}, yw]^2*G[{1}, yv^(-1)]*
       G[{1}, yw])/128 + (3*G[{0}, yw]^3*G[{1}, yv^(-1)]*G[{1}, yw])/128 - 
     (7*Pi^2*G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*G[{1}, yw])/128 - 
     (3*G[{0}, yu^(-1)]^2*G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*G[{1}, yw])/128 - 
     (3*G[{0}, yu^(-1)]*G[{0}, yv^(-1)]*G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*
       G[{1}, yw])/64 - (3*G[{0}, yv^(-1)]^2*G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*
       G[{1}, yw])/128 + (3*G[{0}, yu^(-1)]*G[{0}, yw]*G[{1}, yu^(-1)]*
       G[{1}, yv^(-1)]*G[{1}, yw])/64 + (3*G[{0}, yv^(-1)]*G[{0}, yw]*
       G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*G[{1}, yw])/64 - 
     (3*G[{0}, yw]^2*G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*G[{1}, yw])/128 + 
     (11*G[{0}, yu^(-1)]*G[{1}, yu^(-1)]^2*G[{1}, yv^(-1)]*G[{1}, yw])/128 + 
     (11*G[{0}, yv^(-1)]*G[{1}, yu^(-1)]^2*G[{1}, yv^(-1)]*G[{1}, yw])/128 - 
     (11*G[{0}, yw]*G[{1}, yu^(-1)]^2*G[{1}, yv^(-1)]*G[{1}, yw])/128 - 
     (5*G[{1}, yu^(-1)]^3*G[{1}, yv^(-1)]*G[{1}, yw])/128 + 
     (Pi^2*G[{1}, yv^(-1)]^2*G[{1}, yw])/256 + 
     (9*G[{0}, yu^(-1)]^2*G[{1}, yv^(-1)]^2*G[{1}, yw])/256 + 
     (9*G[{0}, yu^(-1)]*G[{0}, yv^(-1)]*G[{1}, yv^(-1)]^2*G[{1}, yw])/128 + 
     (9*G[{0}, yv^(-1)]^2*G[{1}, yv^(-1)]^2*G[{1}, yw])/256 - 
     (9*G[{0}, yu^(-1)]*G[{0}, yw]*G[{1}, yv^(-1)]^2*G[{1}, yw])/128 - 
     (9*G[{0}, yv^(-1)]*G[{0}, yw]*G[{1}, yv^(-1)]^2*G[{1}, yw])/128 + 
     (9*G[{0}, yw]^2*G[{1}, yv^(-1)]^2*G[{1}, yw])/256 - 
     (5*G[{0}, yu^(-1)]*G[{1}, yu^(-1)]*G[{1}, yv^(-1)]^2*G[{1}, yw])/128 - 
     (5*G[{0}, yv^(-1)]*G[{1}, yu^(-1)]*G[{1}, yv^(-1)]^2*G[{1}, yw])/128 + 
     (5*G[{0}, yw]*G[{1}, yu^(-1)]*G[{1}, yv^(-1)]^2*G[{1}, yw])/128 + 
     (G[{1}, yu^(-1)]^2*G[{1}, yv^(-1)]^2*G[{1}, yw])/256 + 
     (G[{1}, yu^(-1)]*G[{1}, yv^(-1)]^3*G[{1}, yw])/32 - 
     (3*G[{1}, yv^(-1)]^4*G[{1}, yw])/256 - 
     (11*Pi^2*G[{0}, yu^(-1)]*G[{1}, yw]^2)/512 - 
     (3*G[{0}, yu^(-1)]^3*G[{1}, yw]^2)/256 - 
     (11*Pi^2*G[{0}, yv^(-1)]*G[{1}, yw]^2)/512 - 
     (9*G[{0}, yu^(-1)]^2*G[{0}, yv^(-1)]*G[{1}, yw]^2)/256 - 
     (9*G[{0}, yu^(-1)]*G[{0}, yv^(-1)]^2*G[{1}, yw]^2)/256 - 
     (3*G[{0}, yv^(-1)]^3*G[{1}, yw]^2)/256 + 
     (11*Pi^2*G[{0}, yw]*G[{1}, yw]^2)/512 + 
     (9*G[{0}, yu^(-1)]^2*G[{0}, yw]*G[{1}, yw]^2)/256 + 
     (9*G[{0}, yu^(-1)]*G[{0}, yv^(-1)]*G[{0}, yw]*G[{1}, yw]^2)/128 + 
     (9*G[{0}, yv^(-1)]^2*G[{0}, yw]*G[{1}, yw]^2)/256 - 
     (9*G[{0}, yu^(-1)]*G[{0}, yw]^2*G[{1}, yw]^2)/256 - 
     (9*G[{0}, yv^(-1)]*G[{0}, yw]^2*G[{1}, yw]^2)/256 + 
     (3*G[{0}, yw]^3*G[{1}, yw]^2)/256 + 
     (11*Pi^2*G[{1}, yu^(-1)]*G[{1}, yw]^2)/512 + 
     (9*G[{0}, yu^(-1)]^2*G[{1}, yu^(-1)]*G[{1}, yw]^2)/256 + 
     (9*G[{0}, yu^(-1)]*G[{0}, yv^(-1)]*G[{1}, yu^(-1)]*G[{1}, yw]^2)/128 + 
     (9*G[{0}, yv^(-1)]^2*G[{1}, yu^(-1)]*G[{1}, yw]^2)/256 - 
     (9*G[{0}, yu^(-1)]*G[{0}, yw]*G[{1}, yu^(-1)]*G[{1}, yw]^2)/128 - 
     (9*G[{0}, yv^(-1)]*G[{0}, yw]*G[{1}, yu^(-1)]*G[{1}, yw]^2)/128 + 
     (9*G[{0}, yw]^2*G[{1}, yu^(-1)]*G[{1}, yw]^2)/256 - 
     (9*G[{0}, yu^(-1)]*G[{1}, yu^(-1)]^2*G[{1}, yw]^2)/256 - 
     (9*G[{0}, yv^(-1)]*G[{1}, yu^(-1)]^2*G[{1}, yw]^2)/256 + 
     (9*G[{0}, yw]*G[{1}, yu^(-1)]^2*G[{1}, yw]^2)/256 + 
     (3*G[{1}, yu^(-1)]^3*G[{1}, yw]^2)/256 + 
     (7*Pi^2*G[{1}, yv^(-1)]*G[{1}, yw]^2)/512 + 
     (3*G[{0}, yu^(-1)]^2*G[{1}, yv^(-1)]*G[{1}, yw]^2)/256 + 
     (3*G[{0}, yu^(-1)]*G[{0}, yv^(-1)]*G[{1}, yv^(-1)]*G[{1}, yw]^2)/128 + 
     (3*G[{0}, yv^(-1)]^2*G[{1}, yv^(-1)]*G[{1}, yw]^2)/256 - 
     (3*G[{0}, yu^(-1)]*G[{0}, yw]*G[{1}, yv^(-1)]*G[{1}, yw]^2)/128 - 
     (3*G[{0}, yv^(-1)]*G[{0}, yw]*G[{1}, yv^(-1)]*G[{1}, yw]^2)/128 + 
     (3*G[{0}, yw]^2*G[{1}, yv^(-1)]*G[{1}, yw]^2)/256 - 
     (15*G[{0}, yu^(-1)]*G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*G[{1}, yw]^2)/128 - 
     (15*G[{0}, yv^(-1)]*G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*G[{1}, yw]^2)/128 + 
     (15*G[{0}, yw]*G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*G[{1}, yw]^2)/128 + 
     (23*G[{1}, yu^(-1)]^2*G[{1}, yv^(-1)]*G[{1}, yw]^2)/256 + 
     (3*G[{1}, yu^(-1)]*G[{1}, yv^(-1)]^2*G[{1}, yw]^2)/64 - 
     (5*Pi^2*G[{1}, yw]^3)/2304 - (G[{0}, yu^(-1)]^2*G[{1}, yw]^3)/256 - 
     (G[{0}, yu^(-1)]*G[{0}, yv^(-1)]*G[{1}, yw]^3)/128 - 
     (G[{0}, yv^(-1)]^2*G[{1}, yw]^3)/256 + 
     (G[{0}, yu^(-1)]*G[{0}, yw]*G[{1}, yw]^3)/128 + 
     (G[{0}, yv^(-1)]*G[{0}, yw]*G[{1}, yw]^3)/128 - 
     (G[{0}, yw]^2*G[{1}, yw]^3)/256 + (G[{0}, yu^(-1)]*G[{1}, yu^(-1)]*
       G[{1}, yw]^3)/128 + (G[{0}, yv^(-1)]*G[{1}, yu^(-1)]*G[{1}, yw]^3)/
      128 - (G[{0}, yw]*G[{1}, yu^(-1)]*G[{1}, yw]^3)/128 - 
     (G[{1}, yu^(-1)]^2*G[{1}, yw]^3)/256 + 
     (G[{0}, yu^(-1)]*G[{1}, yv^(-1)]*G[{1}, yw]^3)/192 + 
     (G[{0}, yv^(-1)]*G[{1}, yv^(-1)]*G[{1}, yw]^3)/192 - 
     (G[{0}, yw]*G[{1}, yv^(-1)]*G[{1}, yw]^3)/192 - 
     (G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*G[{1}, yw]^3)/64 - 
     (G[{1}, yv^(-1)]^2*G[{1}, yw]^3)/768 + (G[{0}, yu^(-1)]*G[{1}, yw]^4)/
      768 + (G[{0}, yv^(-1)]*G[{1}, yw]^4)/768 - (G[{0}, yw]*G[{1}, yw]^4)/
      768 - (G[{1}, yu^(-1)]*G[{1}, yw]^4)/768 - 
     (G[{1}, yv^(-1)]*G[{1}, yw]^4)/768 + 
     (7*Pi^2*G[{0}, yu^(-1)]*G[{1}, yw]*G[{yu}, yv^(-1)])/384 + 
     (3*G[{0}, yu^(-1)]^3*G[{1}, yw]*G[{yu}, yv^(-1)])/128 + 
     (7*Pi^2*G[{0}, yv^(-1)]*G[{1}, yw]*G[{yu}, yv^(-1)])/384 + 
     (9*G[{0}, yu^(-1)]^2*G[{0}, yv^(-1)]*G[{1}, yw]*G[{yu}, yv^(-1)])/128 + 
     (9*G[{0}, yu^(-1)]*G[{0}, yv^(-1)]^2*G[{1}, yw]*G[{yu}, yv^(-1)])/128 + 
     (3*G[{0}, yv^(-1)]^3*G[{1}, yw]*G[{yu}, yv^(-1)])/128 - 
     (7*Pi^2*G[{0}, yw]*G[{1}, yw]*G[{yu}, yv^(-1)])/384 - 
     (9*G[{0}, yu^(-1)]^2*G[{0}, yw]*G[{1}, yw]*G[{yu}, yv^(-1)])/128 - 
     (9*G[{0}, yu^(-1)]*G[{0}, yv^(-1)]*G[{0}, yw]*G[{1}, yw]*
       G[{yu}, yv^(-1)])/64 - (9*G[{0}, yv^(-1)]^2*G[{0}, yw]*G[{1}, yw]*
       G[{yu}, yv^(-1)])/128 + (9*G[{0}, yu^(-1)]*G[{0}, yw]^2*G[{1}, yw]*
       G[{yu}, yv^(-1)])/128 + (9*G[{0}, yv^(-1)]*G[{0}, yw]^2*G[{1}, yw]*
       G[{yu}, yv^(-1)])/128 - (3*G[{0}, yw]^3*G[{1}, yw]*G[{yu}, yv^(-1)])/
      128 + (Pi^2*G[{1}, yu^(-1)]*G[{1}, yw]*G[{yu}, yv^(-1)])/384 + 
     (3*G[{0}, yu^(-1)]^2*G[{1}, yu^(-1)]*G[{1}, yw]*G[{yu}, yv^(-1)])/128 + 
     (3*G[{0}, yu^(-1)]*G[{0}, yv^(-1)]*G[{1}, yu^(-1)]*G[{1}, yw]*
       G[{yu}, yv^(-1)])/64 + (3*G[{0}, yv^(-1)]^2*G[{1}, yu^(-1)]*G[{1}, yw]*
       G[{yu}, yv^(-1)])/128 - (3*G[{0}, yu^(-1)]*G[{0}, yw]*G[{1}, yu^(-1)]*
       G[{1}, yw]*G[{yu}, yv^(-1)])/64 - (3*G[{0}, yv^(-1)]*G[{0}, yw]*
       G[{1}, yu^(-1)]*G[{1}, yw]*G[{yu}, yv^(-1)])/64 + 
     (3*G[{0}, yw]^2*G[{1}, yu^(-1)]*G[{1}, yw]*G[{yu}, yv^(-1)])/128 - 
     (11*G[{0}, yu^(-1)]*G[{1}, yu^(-1)]^2*G[{1}, yw]*G[{yu}, yv^(-1)])/128 - 
     (11*G[{0}, yv^(-1)]*G[{1}, yu^(-1)]^2*G[{1}, yw]*G[{yu}, yv^(-1)])/128 + 
     (11*G[{0}, yw]*G[{1}, yu^(-1)]^2*G[{1}, yw]*G[{yu}, yv^(-1)])/128 + 
     (5*G[{1}, yu^(-1)]^3*G[{1}, yw]*G[{yu}, yv^(-1)])/128 - 
     (7*Pi^2*G[{1}, yv^(-1)]*G[{1}, yw]*G[{yu}, yv^(-1)])/384 - 
     (G[{0}, yu^(-1)]^2*G[{1}, yv^(-1)]*G[{1}, yw]*G[{yu}, yv^(-1)])/128 - 
     (G[{0}, yu^(-1)]*G[{0}, yv^(-1)]*G[{1}, yv^(-1)]*G[{1}, yw]*
       G[{yu}, yv^(-1)])/64 - (G[{0}, yv^(-1)]^2*G[{1}, yv^(-1)]*G[{1}, yw]*
       G[{yu}, yv^(-1)])/128 + (G[{0}, yu^(-1)]*G[{0}, yw]*G[{1}, yv^(-1)]*
       G[{1}, yw]*G[{yu}, yv^(-1)])/64 + 
     (G[{0}, yv^(-1)]*G[{0}, yw]*G[{1}, yv^(-1)]*G[{1}, yw]*G[{yu}, yv^(-1)])/
      64 - (G[{0}, yw]^2*G[{1}, yv^(-1)]*G[{1}, yw]*G[{yu}, yv^(-1)])/128 + 
     (G[{0}, yu^(-1)]*G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*G[{1}, yw]*
       G[{yu}, yv^(-1)])/64 + (G[{0}, yv^(-1)]*G[{1}, yu^(-1)]*
       G[{1}, yv^(-1)]*G[{1}, yw]*G[{yu}, yv^(-1)])/64 - 
     (G[{0}, yw]*G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*G[{1}, yw]*G[{yu}, yv^(-1)])/
      64 + (3*G[{1}, yu^(-1)]^2*G[{1}, yv^(-1)]*G[{1}, yw]*G[{yu}, yv^(-1)])/
      128 - (7*G[{0}, yu^(-1)]*G[{1}, yv^(-1)]^2*G[{1}, yw]*G[{yu}, yv^(-1)])/
      128 - (7*G[{0}, yv^(-1)]*G[{1}, yv^(-1)]^2*G[{1}, yw]*G[{yu}, yv^(-1)])/
      128 + (7*G[{0}, yw]*G[{1}, yv^(-1)]^2*G[{1}, yw]*G[{yu}, yv^(-1)])/
      128 - (G[{1}, yu^(-1)]*G[{1}, yv^(-1)]^2*G[{1}, yw]*G[{yu}, yv^(-1)])/
      128 + (5*G[{1}, yv^(-1)]^3*G[{1}, yw]*G[{yu}, yv^(-1)])/128 + 
     (Pi^2*G[{1}, yw]^2*G[{yu}, yv^(-1)])/128 + 
     (3*G[{0}, yu^(-1)]^2*G[{1}, yw]^2*G[{yu}, yv^(-1)])/128 + 
     (3*G[{0}, yu^(-1)]*G[{0}, yv^(-1)]*G[{1}, yw]^2*G[{yu}, yv^(-1)])/64 + 
     (3*G[{0}, yv^(-1)]^2*G[{1}, yw]^2*G[{yu}, yv^(-1)])/128 - 
     (3*G[{0}, yu^(-1)]*G[{0}, yw]*G[{1}, yw]^2*G[{yu}, yv^(-1)])/64 - 
     (3*G[{0}, yv^(-1)]*G[{0}, yw]*G[{1}, yw]^2*G[{yu}, yv^(-1)])/64 + 
     (3*G[{0}, yw]^2*G[{1}, yw]^2*G[{yu}, yv^(-1)])/128 + 
     (3*G[{0}, yu^(-1)]*G[{1}, yu^(-1)]*G[{1}, yw]^2*G[{yu}, yv^(-1)])/64 + 
     (3*G[{0}, yv^(-1)]*G[{1}, yu^(-1)]*G[{1}, yw]^2*G[{yu}, yv^(-1)])/64 - 
     (3*G[{0}, yw]*G[{1}, yu^(-1)]*G[{1}, yw]^2*G[{yu}, yv^(-1)])/64 - 
     (7*G[{1}, yu^(-1)]^2*G[{1}, yw]^2*G[{yu}, yv^(-1)])/128 + 
     (3*G[{0}, yu^(-1)]*G[{1}, yv^(-1)]*G[{1}, yw]^2*G[{yu}, yv^(-1)])/64 + 
     (3*G[{0}, yv^(-1)]*G[{1}, yv^(-1)]*G[{1}, yw]^2*G[{yu}, yv^(-1)])/64 - 
     (3*G[{0}, yw]*G[{1}, yv^(-1)]*G[{1}, yw]^2*G[{yu}, yv^(-1)])/64 - 
     (3*G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*G[{1}, yw]^2*G[{yu}, yv^(-1)])/64 - 
     (9*G[{1}, yv^(-1)]^2*G[{1}, yw]^2*G[{yu}, yv^(-1)])/128 + 
     (G[{0}, yu^(-1)]*G[{1}, yw]^3*G[{yu}, yv^(-1)])/384 + 
     (G[{0}, yv^(-1)]*G[{1}, yw]^3*G[{yu}, yv^(-1)])/384 - 
     (G[{0}, yw]*G[{1}, yw]^3*G[{yu}, yv^(-1)])/384 + 
     (G[{1}, yu^(-1)]*G[{1}, yw]^3*G[{yu}, yv^(-1)])/128 + 
     (G[{1}, yv^(-1)]*G[{1}, yw]^3*G[{yu}, yv^(-1)])/128 - 
     (Pi^2*G[{1}, yw]*G[{yu}, yv^(-1)]^2)/96 - 
     (5*G[{0}, yu^(-1)]^2*G[{1}, yw]*G[{yu}, yv^(-1)]^2)/64 - 
     (5*G[{0}, yu^(-1)]*G[{0}, yv^(-1)]*G[{1}, yw]*G[{yu}, yv^(-1)]^2)/32 - 
     (5*G[{0}, yv^(-1)]^2*G[{1}, yw]*G[{yu}, yv^(-1)]^2)/64 + 
     (5*G[{0}, yu^(-1)]*G[{0}, yw]*G[{1}, yw]*G[{yu}, yv^(-1)]^2)/32 + 
     (5*G[{0}, yv^(-1)]*G[{0}, yw]*G[{1}, yw]*G[{yu}, yv^(-1)]^2)/32 - 
     (5*G[{0}, yw]^2*G[{1}, yw]*G[{yu}, yv^(-1)]^2)/64 + 
     (G[{0}, yu^(-1)]*G[{1}, yu^(-1)]*G[{1}, yw]*G[{yu}, yv^(-1)]^2)/32 + 
     (G[{0}, yv^(-1)]*G[{1}, yu^(-1)]*G[{1}, yw]*G[{yu}, yv^(-1)]^2)/32 - 
     (G[{0}, yw]*G[{1}, yu^(-1)]*G[{1}, yw]*G[{yu}, yv^(-1)]^2)/32 + 
     (G[{1}, yu^(-1)]^2*G[{1}, yw]*G[{yu}, yv^(-1)]^2)/64 + 
     (5*G[{0}, yu^(-1)]*G[{1}, yv^(-1)]*G[{1}, yw]*G[{yu}, yv^(-1)]^2)/32 + 
     (5*G[{0}, yv^(-1)]*G[{1}, yv^(-1)]*G[{1}, yw]*G[{yu}, yv^(-1)]^2)/32 - 
     (5*G[{0}, yw]*G[{1}, yv^(-1)]*G[{1}, yw]*G[{yu}, yv^(-1)]^2)/32 - 
     (3*G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*G[{1}, yw]*G[{yu}, yv^(-1)]^2)/32 - 
     (5*G[{1}, yv^(-1)]^2*G[{1}, yw]*G[{yu}, yv^(-1)]^2)/64 - 
     (3*G[{0}, yu^(-1)]*G[{1}, yw]^2*G[{yu}, yv^(-1)]^2)/32 - 
     (3*G[{0}, yv^(-1)]*G[{1}, yw]^2*G[{yu}, yv^(-1)]^2)/32 + 
     (3*G[{0}, yw]*G[{1}, yw]^2*G[{yu}, yv^(-1)]^2)/32 + 
     (G[{1}, yu^(-1)]*G[{1}, yw]^2*G[{yu}, yv^(-1)]^2)/32 + 
     (5*G[{1}, yv^(-1)]*G[{1}, yw]^2*G[{yu}, yv^(-1)]^2)/64 - 
     (G[{1}, yw]^3*G[{yu}, yv^(-1)]^2)/96 + 
     (G[{0}, yu^(-1)]*G[{1}, yw]*G[{yu}, yv^(-1)]^3)/24 + 
     (G[{0}, yv^(-1)]*G[{1}, yw]*G[{yu}, yv^(-1)]^3)/24 - 
     (G[{0}, yw]*G[{1}, yw]*G[{yu}, yv^(-1)]^3)/24 - 
     (G[{1}, yv^(-1)]*G[{1}, yw]*G[{yu}, yv^(-1)]^3)/16 + 
     (5*G[{1}, yw]^2*G[{yu}, yv^(-1)]^3)/192 - 
     (G[{1}, yw]*G[{yu}, yv^(-1)]^4)/192 + (Pi^4*G[{1/(yu*yv)}, yw])/1152 + 
     (Pi^2*G[{0}, yu^(-1)]*G[{1}, yu^(-1)]*G[{1/(yu*yv)}, yw])/32 + 
     (Pi^2*G[{0}, yv^(-1)]*G[{1}, yu^(-1)]*G[{1/(yu*yv)}, yw])/32 - 
     (Pi^2*G[{0}, yw]*G[{1}, yu^(-1)]*G[{1/(yu*yv)}, yw])/32 - 
     (5*Pi^2*G[{1}, yu^(-1)]^2*G[{1/(yu*yv)}, yw])/192 - 
     (Pi^2*G[{0}, yu^(-1)]*G[{1}, yv^(-1)]*G[{1/(yu*yv)}, yw])/384 + 
     (3*G[{0}, yu^(-1)]^3*G[{1}, yv^(-1)]*G[{1/(yu*yv)}, yw])/128 - 
     (Pi^2*G[{0}, yv^(-1)]*G[{1}, yv^(-1)]*G[{1/(yu*yv)}, yw])/384 + 
     (9*G[{0}, yu^(-1)]^2*G[{0}, yv^(-1)]*G[{1}, yv^(-1)]*G[{1/(yu*yv)}, yw])/
      128 + (9*G[{0}, yu^(-1)]*G[{0}, yv^(-1)]^2*G[{1}, yv^(-1)]*
       G[{1/(yu*yv)}, yw])/128 + (3*G[{0}, yv^(-1)]^3*G[{1}, yv^(-1)]*
       G[{1/(yu*yv)}, yw])/128 + (Pi^2*G[{0}, yw]*G[{1}, yv^(-1)]*
       G[{1/(yu*yv)}, yw])/384 - (9*G[{0}, yu^(-1)]^2*G[{0}, yw]*
       G[{1}, yv^(-1)]*G[{1/(yu*yv)}, yw])/128 - 
     (9*G[{0}, yu^(-1)]*G[{0}, yv^(-1)]*G[{0}, yw]*G[{1}, yv^(-1)]*
       G[{1/(yu*yv)}, yw])/64 - (9*G[{0}, yv^(-1)]^2*G[{0}, yw]*
       G[{1}, yv^(-1)]*G[{1/(yu*yv)}, yw])/128 + 
     (9*G[{0}, yu^(-1)]*G[{0}, yw]^2*G[{1}, yv^(-1)]*G[{1/(yu*yv)}, yw])/
      128 + (9*G[{0}, yv^(-1)]*G[{0}, yw]^2*G[{1}, yv^(-1)]*
       G[{1/(yu*yv)}, yw])/128 - (3*G[{0}, yw]^3*G[{1}, yv^(-1)]*
       G[{1/(yu*yv)}, yw])/128 - (Pi^2*G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*
       G[{1/(yu*yv)}, yw])/128 + (3*G[{0}, yu^(-1)]^2*G[{1}, yu^(-1)]*
       G[{1}, yv^(-1)]*G[{1/(yu*yv)}, yw])/128 + 
     (3*G[{0}, yu^(-1)]*G[{0}, yv^(-1)]*G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*
       G[{1/(yu*yv)}, yw])/64 + (3*G[{0}, yv^(-1)]^2*G[{1}, yu^(-1)]*
       G[{1}, yv^(-1)]*G[{1/(yu*yv)}, yw])/128 - 
     (3*G[{0}, yu^(-1)]*G[{0}, yw]*G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*
       G[{1/(yu*yv)}, yw])/64 - (3*G[{0}, yv^(-1)]*G[{0}, yw]*G[{1}, yu^(-1)]*
       G[{1}, yv^(-1)]*G[{1/(yu*yv)}, yw])/64 + 
     (3*G[{0}, yw]^2*G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*G[{1/(yu*yv)}, yw])/
      128 - (11*G[{0}, yu^(-1)]*G[{1}, yu^(-1)]^2*G[{1}, yv^(-1)]*
       G[{1/(yu*yv)}, yw])/128 - (11*G[{0}, yv^(-1)]*G[{1}, yu^(-1)]^2*
       G[{1}, yv^(-1)]*G[{1/(yu*yv)}, yw])/128 + 
     (11*G[{0}, yw]*G[{1}, yu^(-1)]^2*G[{1}, yv^(-1)]*G[{1/(yu*yv)}, yw])/
      128 + (5*G[{1}, yu^(-1)]^3*G[{1}, yv^(-1)]*G[{1/(yu*yv)}, yw])/128 - 
     (Pi^2*G[{1}, yv^(-1)]^2*G[{1/(yu*yv)}, yw])/768 - 
     (27*G[{0}, yu^(-1)]^2*G[{1}, yv^(-1)]^2*G[{1/(yu*yv)}, yw])/256 - 
     (27*G[{0}, yu^(-1)]*G[{0}, yv^(-1)]*G[{1}, yv^(-1)]^2*
       G[{1/(yu*yv)}, yw])/128 - (27*G[{0}, yv^(-1)]^2*G[{1}, yv^(-1)]^2*
       G[{1/(yu*yv)}, yw])/256 + (27*G[{0}, yu^(-1)]*G[{0}, yw]*
       G[{1}, yv^(-1)]^2*G[{1/(yu*yv)}, yw])/128 + 
     (27*G[{0}, yv^(-1)]*G[{0}, yw]*G[{1}, yv^(-1)]^2*G[{1/(yu*yv)}, yw])/
      128 - (27*G[{0}, yw]^2*G[{1}, yv^(-1)]^2*G[{1/(yu*yv)}, yw])/256 - 
     (G[{0}, yu^(-1)]*G[{1}, yu^(-1)]*G[{1}, yv^(-1)]^2*G[{1/(yu*yv)}, yw])/
      128 - (G[{0}, yv^(-1)]*G[{1}, yu^(-1)]*G[{1}, yv^(-1)]^2*
       G[{1/(yu*yv)}, yw])/128 + (G[{0}, yw]*G[{1}, yu^(-1)]*
       G[{1}, yv^(-1)]^2*G[{1/(yu*yv)}, yw])/128 + 
     (21*G[{1}, yu^(-1)]^2*G[{1}, yv^(-1)]^2*G[{1/(yu*yv)}, yw])/256 + 
     (9*G[{0}, yu^(-1)]*G[{1}, yv^(-1)]^3*G[{1/(yu*yv)}, yw])/64 + 
     (9*G[{0}, yv^(-1)]*G[{1}, yv^(-1)]^3*G[{1/(yu*yv)}, yw])/64 - 
     (9*G[{0}, yw]*G[{1}, yv^(-1)]^3*G[{1/(yu*yv)}, yw])/64 - 
     (5*G[{1}, yu^(-1)]*G[{1}, yv^(-1)]^3*G[{1/(yu*yv)}, yw])/192 - 
     (15*G[{1}, yv^(-1)]^4*G[{1/(yu*yv)}, yw])/256 + 
     (19*Pi^2*G[{0}, yu^(-1)]*G[{1}, yw]*G[{1/(yu*yv)}, yw])/768 + 
     (3*G[{0}, yu^(-1)]^3*G[{1}, yw]*G[{1/(yu*yv)}, yw])/128 + 
     (19*Pi^2*G[{0}, yv^(-1)]*G[{1}, yw]*G[{1/(yu*yv)}, yw])/768 + 
     (9*G[{0}, yu^(-1)]^2*G[{0}, yv^(-1)]*G[{1}, yw]*G[{1/(yu*yv)}, yw])/
      128 + (9*G[{0}, yu^(-1)]*G[{0}, yv^(-1)]^2*G[{1}, yw]*
       G[{1/(yu*yv)}, yw])/128 + (3*G[{0}, yv^(-1)]^3*G[{1}, yw]*
       G[{1/(yu*yv)}, yw])/128 - (19*Pi^2*G[{0}, yw]*G[{1}, yw]*
       G[{1/(yu*yv)}, yw])/768 - (9*G[{0}, yu^(-1)]^2*G[{0}, yw]*G[{1}, yw]*
       G[{1/(yu*yv)}, yw])/128 - (9*G[{0}, yu^(-1)]*G[{0}, yv^(-1)]*
       G[{0}, yw]*G[{1}, yw]*G[{1/(yu*yv)}, yw])/64 - 
     (9*G[{0}, yv^(-1)]^2*G[{0}, yw]*G[{1}, yw]*G[{1/(yu*yv)}, yw])/128 + 
     (9*G[{0}, yu^(-1)]*G[{0}, yw]^2*G[{1}, yw]*G[{1/(yu*yv)}, yw])/128 + 
     (9*G[{0}, yv^(-1)]*G[{0}, yw]^2*G[{1}, yw]*G[{1/(yu*yv)}, yw])/128 - 
     (3*G[{0}, yw]^3*G[{1}, yw]*G[{1/(yu*yv)}, yw])/128 - 
     (11*Pi^2*G[{1}, yu^(-1)]*G[{1}, yw]*G[{1/(yu*yv)}, yw])/768 - 
     (9*G[{0}, yu^(-1)]^2*G[{1}, yu^(-1)]*G[{1}, yw]*G[{1/(yu*yv)}, yw])/
      128 - (9*G[{0}, yu^(-1)]*G[{0}, yv^(-1)]*G[{1}, yu^(-1)]*G[{1}, yw]*
       G[{1/(yu*yv)}, yw])/64 - (9*G[{0}, yv^(-1)]^2*G[{1}, yu^(-1)]*
       G[{1}, yw]*G[{1/(yu*yv)}, yw])/128 + 
     (9*G[{0}, yu^(-1)]*G[{0}, yw]*G[{1}, yu^(-1)]*G[{1}, yw]*
       G[{1/(yu*yv)}, yw])/64 + (9*G[{0}, yv^(-1)]*G[{0}, yw]*G[{1}, yu^(-1)]*
       G[{1}, yw]*G[{1/(yu*yv)}, yw])/64 - 
     (9*G[{0}, yw]^2*G[{1}, yu^(-1)]*G[{1}, yw]*G[{1/(yu*yv)}, yw])/128 + 
     (9*G[{0}, yu^(-1)]*G[{1}, yu^(-1)]^2*G[{1}, yw]*G[{1/(yu*yv)}, yw])/
      128 + (9*G[{0}, yv^(-1)]*G[{1}, yu^(-1)]^2*G[{1}, yw]*
       G[{1/(yu*yv)}, yw])/128 - (9*G[{0}, yw]*G[{1}, yu^(-1)]^2*G[{1}, yw]*
       G[{1/(yu*yv)}, yw])/128 - (3*G[{1}, yu^(-1)]^3*G[{1}, yw]*
       G[{1/(yu*yv)}, yw])/128 - (11*Pi^2*G[{1}, yv^(-1)]*G[{1}, yw]*
       G[{1/(yu*yv)}, yw])/768 + (3*G[{0}, yu^(-1)]^2*G[{1}, yv^(-1)]*
       G[{1}, yw]*G[{1/(yu*yv)}, yw])/128 + 
     (3*G[{0}, yu^(-1)]*G[{0}, yv^(-1)]*G[{1}, yv^(-1)]*G[{1}, yw]*
       G[{1/(yu*yv)}, yw])/64 + (3*G[{0}, yv^(-1)]^2*G[{1}, yv^(-1)]*
       G[{1}, yw]*G[{1/(yu*yv)}, yw])/128 - 
     (3*G[{0}, yu^(-1)]*G[{0}, yw]*G[{1}, yv^(-1)]*G[{1}, yw]*
       G[{1/(yu*yv)}, yw])/64 - (3*G[{0}, yv^(-1)]*G[{0}, yw]*G[{1}, yv^(-1)]*
       G[{1}, yw]*G[{1/(yu*yv)}, yw])/64 + 
     (3*G[{0}, yw]^2*G[{1}, yv^(-1)]*G[{1}, yw]*G[{1/(yu*yv)}, yw])/128 + 
     (9*G[{0}, yu^(-1)]*G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*G[{1}, yw]*
       G[{1/(yu*yv)}, yw])/64 + (9*G[{0}, yv^(-1)]*G[{1}, yu^(-1)]*
       G[{1}, yv^(-1)]*G[{1}, yw]*G[{1/(yu*yv)}, yw])/64 - 
     (9*G[{0}, yw]*G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*G[{1}, yw]*
       G[{1/(yu*yv)}, yw])/64 - (17*G[{1}, yu^(-1)]^2*G[{1}, yv^(-1)]*
       G[{1}, yw]*G[{1/(yu*yv)}, yw])/128 - 
     (9*G[{0}, yu^(-1)]*G[{1}, yv^(-1)]^2*G[{1}, yw]*G[{1/(yu*yv)}, yw])/64 - 
     (9*G[{0}, yv^(-1)]*G[{1}, yv^(-1)]^2*G[{1}, yw]*G[{1/(yu*yv)}, yw])/64 + 
     (9*G[{0}, yw]*G[{1}, yv^(-1)]^2*G[{1}, yw]*G[{1/(yu*yv)}, yw])/64 - 
     (G[{1}, yu^(-1)]*G[{1}, yv^(-1)]^2*G[{1}, yw]*G[{1/(yu*yv)}, yw])/64 + 
     (3*G[{1}, yv^(-1)]^3*G[{1}, yw]*G[{1/(yu*yv)}, yw])/32 + 
     (7*Pi^2*G[{1}, yw]^2*G[{1/(yu*yv)}, yw])/768 + 
     (9*G[{0}, yu^(-1)]^2*G[{1}, yw]^2*G[{1/(yu*yv)}, yw])/256 + 
     (9*G[{0}, yu^(-1)]*G[{0}, yv^(-1)]*G[{1}, yw]^2*G[{1/(yu*yv)}, yw])/
      128 + (9*G[{0}, yv^(-1)]^2*G[{1}, yw]^2*G[{1/(yu*yv)}, yw])/256 - 
     (9*G[{0}, yu^(-1)]*G[{0}, yw]*G[{1}, yw]^2*G[{1/(yu*yv)}, yw])/128 - 
     (9*G[{0}, yv^(-1)]*G[{0}, yw]*G[{1}, yw]^2*G[{1/(yu*yv)}, yw])/128 + 
     (9*G[{0}, yw]^2*G[{1}, yw]^2*G[{1/(yu*yv)}, yw])/256 - 
     (9*G[{0}, yu^(-1)]*G[{1}, yu^(-1)]*G[{1}, yw]^2*G[{1/(yu*yv)}, yw])/
      128 - (9*G[{0}, yv^(-1)]*G[{1}, yu^(-1)]*G[{1}, yw]^2*
       G[{1/(yu*yv)}, yw])/128 + (9*G[{0}, yw]*G[{1}, yu^(-1)]*G[{1}, yw]^2*
       G[{1/(yu*yv)}, yw])/128 + (9*G[{1}, yu^(-1)]^2*G[{1}, yw]^2*
       G[{1/(yu*yv)}, yw])/256 - (G[{0}, yu^(-1)]*G[{1}, yv^(-1)]*
       G[{1}, yw]^2*G[{1/(yu*yv)}, yw])/32 - 
     (G[{0}, yv^(-1)]*G[{1}, yv^(-1)]*G[{1}, yw]^2*G[{1/(yu*yv)}, yw])/32 + 
     (G[{0}, yw]*G[{1}, yv^(-1)]*G[{1}, yw]^2*G[{1/(yu*yv)}, yw])/32 + 
     (G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*G[{1}, yw]^2*G[{1/(yu*yv)}, yw])/16 - 
     (G[{1}, yv^(-1)]^2*G[{1}, yw]^2*G[{1/(yu*yv)}, yw])/256 + 
     (G[{0}, yu^(-1)]*G[{1}, yw]^3*G[{1/(yu*yv)}, yw])/96 + 
     (G[{0}, yv^(-1)]*G[{1}, yw]^3*G[{1/(yu*yv)}, yw])/96 - 
     (G[{0}, yw]*G[{1}, yw]^3*G[{1/(yu*yv)}, yw])/96 - 
     (G[{1}, yu^(-1)]*G[{1}, yw]^3*G[{1/(yu*yv)}, yw])/96 - 
     (G[{1}, yv^(-1)]*G[{1}, yw]^3*G[{1/(yu*yv)}, yw])/96 - 
     (Pi^2*G[{0}, yu^(-1)]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw])/256 - 
     (3*G[{0}, yu^(-1)]^3*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw])/128 - 
     (Pi^2*G[{0}, yv^(-1)]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw])/256 - 
     (9*G[{0}, yu^(-1)]^2*G[{0}, yv^(-1)]*G[{yu^(-1)}, yw]*
       G[{1/(yu*yv)}, yw])/128 - (9*G[{0}, yu^(-1)]*G[{0}, yv^(-1)]^2*
       G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw])/128 - 
     (3*G[{0}, yv^(-1)]^3*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw])/128 + 
     (Pi^2*G[{0}, yw]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw])/256 + 
     (9*G[{0}, yu^(-1)]^2*G[{0}, yw]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw])/
      128 + (9*G[{0}, yu^(-1)]*G[{0}, yv^(-1)]*G[{0}, yw]*G[{yu^(-1)}, yw]*
       G[{1/(yu*yv)}, yw])/64 + (9*G[{0}, yv^(-1)]^2*G[{0}, yw]*
       G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw])/128 - 
     (9*G[{0}, yu^(-1)]*G[{0}, yw]^2*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw])/
      128 - (9*G[{0}, yv^(-1)]*G[{0}, yw]^2*G[{yu^(-1)}, yw]*
       G[{1/(yu*yv)}, yw])/128 + (3*G[{0}, yw]^3*G[{yu^(-1)}, yw]*
       G[{1/(yu*yv)}, yw])/128 + (19*Pi^2*G[{1}, yu^(-1)]*G[{yu^(-1)}, yw]*
       G[{1/(yu*yv)}, yw])/768 + (9*G[{0}, yu^(-1)]^2*G[{1}, yu^(-1)]*
       G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw])/128 + 
     (9*G[{0}, yu^(-1)]*G[{0}, yv^(-1)]*G[{1}, yu^(-1)]*G[{yu^(-1)}, yw]*
       G[{1/(yu*yv)}, yw])/64 + (9*G[{0}, yv^(-1)]^2*G[{1}, yu^(-1)]*
       G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw])/128 - 
     (9*G[{0}, yu^(-1)]*G[{0}, yw]*G[{1}, yu^(-1)]*G[{yu^(-1)}, yw]*
       G[{1/(yu*yv)}, yw])/64 - (9*G[{0}, yv^(-1)]*G[{0}, yw]*G[{1}, yu^(-1)]*
       G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw])/64 + 
     (9*G[{0}, yw]^2*G[{1}, yu^(-1)]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw])/
      128 - (9*G[{0}, yu^(-1)]*G[{1}, yu^(-1)]^2*G[{yu^(-1)}, yw]*
       G[{1/(yu*yv)}, yw])/128 - (9*G[{0}, yv^(-1)]*G[{1}, yu^(-1)]^2*
       G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw])/128 + 
     (9*G[{0}, yw]*G[{1}, yu^(-1)]^2*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw])/
      128 + (3*G[{1}, yu^(-1)]^3*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw])/128 + 
     (Pi^2*G[{1}, yv^(-1)]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw])/256 + 
     (13*G[{0}, yu^(-1)]^2*G[{1}, yv^(-1)]*G[{yu^(-1)}, yw]*
       G[{1/(yu*yv)}, yw])/128 + (13*G[{0}, yu^(-1)]*G[{0}, yv^(-1)]*
       G[{1}, yv^(-1)]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw])/64 + 
     (13*G[{0}, yv^(-1)]^2*G[{1}, yv^(-1)]*G[{yu^(-1)}, yw]*
       G[{1/(yu*yv)}, yw])/128 - (13*G[{0}, yu^(-1)]*G[{0}, yw]*
       G[{1}, yv^(-1)]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw])/64 - 
     (13*G[{0}, yv^(-1)]*G[{0}, yw]*G[{1}, yv^(-1)]*G[{yu^(-1)}, yw]*
       G[{1/(yu*yv)}, yw])/64 + (13*G[{0}, yw]^2*G[{1}, yv^(-1)]*
       G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw])/128 - 
     (5*G[{0}, yu^(-1)]*G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*G[{yu^(-1)}, yw]*
       G[{1/(yu*yv)}, yw])/64 - (5*G[{0}, yv^(-1)]*G[{1}, yu^(-1)]*
       G[{1}, yv^(-1)]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw])/64 + 
     (5*G[{0}, yw]*G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*G[{yu^(-1)}, yw]*
       G[{1/(yu*yv)}, yw])/64 - (3*G[{1}, yu^(-1)]^2*G[{1}, yv^(-1)]*
       G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw])/128 - 
     (23*G[{0}, yu^(-1)]*G[{1}, yv^(-1)]^2*G[{yu^(-1)}, yw]*
       G[{1/(yu*yv)}, yw])/128 - (23*G[{0}, yv^(-1)]*G[{1}, yv^(-1)]^2*
       G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw])/128 + 
     (23*G[{0}, yw]*G[{1}, yv^(-1)]^2*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw])/
      128 + (7*G[{1}, yu^(-1)]*G[{1}, yv^(-1)]^2*G[{yu^(-1)}, yw]*
       G[{1/(yu*yv)}, yw])/128 + (13*G[{1}, yv^(-1)]^3*G[{yu^(-1)}, yw]*
       G[{1/(yu*yv)}, yw])/128 + (Pi^2*G[{1}, yw]*G[{yu^(-1)}, yw]*
       G[{1/(yu*yv)}, yw])/128 - (11*G[{0}, yu^(-1)]^2*G[{1}, yw]*
       G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw])/128 - 
     (11*G[{0}, yu^(-1)]*G[{0}, yv^(-1)]*G[{1}, yw]*G[{yu^(-1)}, yw]*
       G[{1/(yu*yv)}, yw])/64 - (11*G[{0}, yv^(-1)]^2*G[{1}, yw]*
       G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw])/128 + 
     (11*G[{0}, yu^(-1)]*G[{0}, yw]*G[{1}, yw]*G[{yu^(-1)}, yw]*
       G[{1/(yu*yv)}, yw])/64 + (11*G[{0}, yv^(-1)]*G[{0}, yw]*G[{1}, yw]*
       G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw])/64 - 
     (11*G[{0}, yw]^2*G[{1}, yw]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw])/128 + 
     (11*G[{0}, yu^(-1)]*G[{1}, yu^(-1)]*G[{1}, yw]*G[{yu^(-1)}, yw]*
       G[{1/(yu*yv)}, yw])/64 + (11*G[{0}, yv^(-1)]*G[{1}, yu^(-1)]*
       G[{1}, yw]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw])/64 - 
     (11*G[{0}, yw]*G[{1}, yu^(-1)]*G[{1}, yw]*G[{yu^(-1)}, yw]*
       G[{1/(yu*yv)}, yw])/64 - (11*G[{1}, yu^(-1)]^2*G[{1}, yw]*
       G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw])/128 + 
     (17*G[{0}, yu^(-1)]*G[{1}, yv^(-1)]*G[{1}, yw]*G[{yu^(-1)}, yw]*
       G[{1/(yu*yv)}, yw])/64 + (17*G[{0}, yv^(-1)]*G[{1}, yv^(-1)]*
       G[{1}, yw]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw])/64 - 
     (17*G[{0}, yw]*G[{1}, yv^(-1)]*G[{1}, yw]*G[{yu^(-1)}, yw]*
       G[{1/(yu*yv)}, yw])/64 - (9*G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*G[{1}, yw]*
       G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw])/64 - 
     (23*G[{1}, yv^(-1)]^2*G[{1}, yw]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw])/
      128 - (3*G[{0}, yu^(-1)]*G[{1}, yw]^2*G[{yu^(-1)}, yw]*
       G[{1/(yu*yv)}, yw])/128 - (3*G[{0}, yv^(-1)]*G[{1}, yw]^2*
       G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw])/128 + 
     (3*G[{0}, yw]*G[{1}, yw]^2*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw])/128 + 
     (3*G[{1}, yu^(-1)]*G[{1}, yw]^2*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw])/
      128 + (3*G[{1}, yv^(-1)]*G[{1}, yw]^2*G[{yu^(-1)}, yw]*
       G[{1/(yu*yv)}, yw])/128 + (7*Pi^2*G[{yu^(-1)}, yw]^2*
       G[{1/(yu*yv)}, yw])/1536 + (G[{0}, yu^(-1)]^2*G[{yu^(-1)}, yw]^2*
       G[{1/(yu*yv)}, yw])/128 + (G[{0}, yu^(-1)]*G[{0}, yv^(-1)]*
       G[{yu^(-1)}, yw]^2*G[{1/(yu*yv)}, yw])/64 + 
     (G[{0}, yv^(-1)]^2*G[{yu^(-1)}, yw]^2*G[{1/(yu*yv)}, yw])/128 - 
     (G[{0}, yu^(-1)]*G[{0}, yw]*G[{yu^(-1)}, yw]^2*G[{1/(yu*yv)}, yw])/64 - 
     (G[{0}, yv^(-1)]*G[{0}, yw]*G[{yu^(-1)}, yw]^2*G[{1/(yu*yv)}, yw])/64 + 
     (G[{0}, yw]^2*G[{yu^(-1)}, yw]^2*G[{1/(yu*yv)}, yw])/128 - 
     (G[{0}, yu^(-1)]*G[{1}, yu^(-1)]*G[{yu^(-1)}, yw]^2*G[{1/(yu*yv)}, yw])/
      64 - (G[{0}, yv^(-1)]*G[{1}, yu^(-1)]*G[{yu^(-1)}, yw]^2*
       G[{1/(yu*yv)}, yw])/64 + (G[{0}, yw]*G[{1}, yu^(-1)]*
       G[{yu^(-1)}, yw]^2*G[{1/(yu*yv)}, yw])/64 + 
     (G[{1}, yu^(-1)]^2*G[{yu^(-1)}, yw]^2*G[{1/(yu*yv)}, yw])/128 - 
     (G[{0}, yu^(-1)]*G[{1}, yv^(-1)]*G[{yu^(-1)}, yw]^2*G[{1/(yu*yv)}, yw])/
      64 - (G[{0}, yv^(-1)]*G[{1}, yv^(-1)]*G[{yu^(-1)}, yw]^2*
       G[{1/(yu*yv)}, yw])/64 + (G[{0}, yw]*G[{1}, yv^(-1)]*
       G[{yu^(-1)}, yw]^2*G[{1/(yu*yv)}, yw])/64 + 
     (G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*G[{yu^(-1)}, yw]^2*G[{1/(yu*yv)}, yw])/
      64 - (G[{1}, yv^(-1)]^2*G[{yu^(-1)}, yw]^2*G[{1/(yu*yv)}, yw])/64 - 
     (3*G[{0}, yu^(-1)]*G[{1}, yw]*G[{yu^(-1)}, yw]^2*G[{1/(yu*yv)}, yw])/
      32 - (3*G[{0}, yv^(-1)]*G[{1}, yw]*G[{yu^(-1)}, yw]^2*
       G[{1/(yu*yv)}, yw])/32 + (3*G[{0}, yw]*G[{1}, yw]*G[{yu^(-1)}, yw]^2*
       G[{1/(yu*yv)}, yw])/32 + (3*G[{1}, yu^(-1)]*G[{1}, yw]*
       G[{yu^(-1)}, yw]^2*G[{1/(yu*yv)}, yw])/32 + 
     (3*G[{1}, yv^(-1)]*G[{1}, yw]*G[{yu^(-1)}, yw]^2*G[{1/(yu*yv)}, yw])/
      64 - (3*G[{1}, yw]^2*G[{yu^(-1)}, yw]^2*G[{1/(yu*yv)}, yw])/128 + 
     (7*G[{0}, yu^(-1)]*G[{yu^(-1)}, yw]^3*G[{1/(yu*yv)}, yw])/192 + 
     (7*G[{0}, yv^(-1)]*G[{yu^(-1)}, yw]^3*G[{1/(yu*yv)}, yw])/192 - 
     (7*G[{0}, yw]*G[{yu^(-1)}, yw]^3*G[{1/(yu*yv)}, yw])/192 - 
     (7*G[{1}, yu^(-1)]*G[{yu^(-1)}, yw]^3*G[{1/(yu*yv)}, yw])/192 - 
     (11*G[{1}, yv^(-1)]*G[{yu^(-1)}, yw]^3*G[{1/(yu*yv)}, yw])/192 - 
     (G[{1}, yw]*G[{yu^(-1)}, yw]^3*G[{1/(yu*yv)}, yw])/48 + 
     (11*G[{yu^(-1)}, yw]^4*G[{1/(yu*yv)}, yw])/768 - 
     (7*Pi^2*G[{0}, yu^(-1)]*G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw])/384 - 
     (3*G[{0}, yu^(-1)]^3*G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw])/128 - 
     (7*Pi^2*G[{0}, yv^(-1)]*G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw])/384 - 
     (9*G[{0}, yu^(-1)]^2*G[{0}, yv^(-1)]*G[{yu}, yv^(-1)]*
       G[{1/(yu*yv)}, yw])/128 - (9*G[{0}, yu^(-1)]*G[{0}, yv^(-1)]^2*
       G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw])/128 - 
     (3*G[{0}, yv^(-1)]^3*G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw])/128 + 
     (7*Pi^2*G[{0}, yw]*G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw])/384 + 
     (9*G[{0}, yu^(-1)]^2*G[{0}, yw]*G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw])/
      128 + (9*G[{0}, yu^(-1)]*G[{0}, yv^(-1)]*G[{0}, yw]*G[{yu}, yv^(-1)]*
       G[{1/(yu*yv)}, yw])/64 + (9*G[{0}, yv^(-1)]^2*G[{0}, yw]*
       G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw])/128 - 
     (9*G[{0}, yu^(-1)]*G[{0}, yw]^2*G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw])/
      128 - (9*G[{0}, yv^(-1)]*G[{0}, yw]^2*G[{yu}, yv^(-1)]*
       G[{1/(yu*yv)}, yw])/128 + (3*G[{0}, yw]^3*G[{yu}, yv^(-1)]*
       G[{1/(yu*yv)}, yw])/128 - (Pi^2*G[{1}, yu^(-1)]*G[{yu}, yv^(-1)]*
       G[{1/(yu*yv)}, yw])/384 - (3*G[{0}, yu^(-1)]^2*G[{1}, yu^(-1)]*
       G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw])/128 - 
     (3*G[{0}, yu^(-1)]*G[{0}, yv^(-1)]*G[{1}, yu^(-1)]*G[{yu}, yv^(-1)]*
       G[{1/(yu*yv)}, yw])/64 - (3*G[{0}, yv^(-1)]^2*G[{1}, yu^(-1)]*
       G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw])/128 + 
     (3*G[{0}, yu^(-1)]*G[{0}, yw]*G[{1}, yu^(-1)]*G[{yu}, yv^(-1)]*
       G[{1/(yu*yv)}, yw])/64 + (3*G[{0}, yv^(-1)]*G[{0}, yw]*G[{1}, yu^(-1)]*
       G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw])/64 - 
     (3*G[{0}, yw]^2*G[{1}, yu^(-1)]*G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw])/
      128 + (11*G[{0}, yu^(-1)]*G[{1}, yu^(-1)]^2*G[{yu}, yv^(-1)]*
       G[{1/(yu*yv)}, yw])/128 + (11*G[{0}, yv^(-1)]*G[{1}, yu^(-1)]^2*
       G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw])/128 - 
     (11*G[{0}, yw]*G[{1}, yu^(-1)]^2*G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw])/
      128 - (5*G[{1}, yu^(-1)]^3*G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw])/128 + 
     (7*Pi^2*G[{1}, yv^(-1)]*G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw])/384 + 
     (G[{0}, yu^(-1)]^2*G[{1}, yv^(-1)]*G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw])/
      128 + (G[{0}, yu^(-1)]*G[{0}, yv^(-1)]*G[{1}, yv^(-1)]*G[{yu}, yv^(-1)]*
       G[{1/(yu*yv)}, yw])/64 + (G[{0}, yv^(-1)]^2*G[{1}, yv^(-1)]*
       G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw])/128 - 
     (G[{0}, yu^(-1)]*G[{0}, yw]*G[{1}, yv^(-1)]*G[{yu}, yv^(-1)]*
       G[{1/(yu*yv)}, yw])/64 - (G[{0}, yv^(-1)]*G[{0}, yw]*G[{1}, yv^(-1)]*
       G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw])/64 + 
     (G[{0}, yw]^2*G[{1}, yv^(-1)]*G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw])/128 - 
     (G[{0}, yu^(-1)]*G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*G[{yu}, yv^(-1)]*
       G[{1/(yu*yv)}, yw])/64 - (G[{0}, yv^(-1)]*G[{1}, yu^(-1)]*
       G[{1}, yv^(-1)]*G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw])/64 + 
     (G[{0}, yw]*G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*G[{yu}, yv^(-1)]*
       G[{1/(yu*yv)}, yw])/64 - (3*G[{1}, yu^(-1)]^2*G[{1}, yv^(-1)]*
       G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw])/128 + 
     (7*G[{0}, yu^(-1)]*G[{1}, yv^(-1)]^2*G[{yu}, yv^(-1)]*
       G[{1/(yu*yv)}, yw])/128 + (7*G[{0}, yv^(-1)]*G[{1}, yv^(-1)]^2*
       G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw])/128 - 
     (7*G[{0}, yw]*G[{1}, yv^(-1)]^2*G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw])/
      128 + (G[{1}, yu^(-1)]*G[{1}, yv^(-1)]^2*G[{yu}, yv^(-1)]*
       G[{1/(yu*yv)}, yw])/128 - (5*G[{1}, yv^(-1)]^3*G[{yu}, yv^(-1)]*
       G[{1/(yu*yv)}, yw])/128 - (Pi^2*G[{1}, yw]*G[{yu}, yv^(-1)]*
       G[{1/(yu*yv)}, yw])/48 - (3*G[{0}, yu^(-1)]^2*G[{1}, yw]*
       G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw])/32 - 
     (3*G[{0}, yu^(-1)]*G[{0}, yv^(-1)]*G[{1}, yw]*G[{yu}, yv^(-1)]*
       G[{1/(yu*yv)}, yw])/16 - (3*G[{0}, yv^(-1)]^2*G[{1}, yw]*
       G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw])/32 + 
     (3*G[{0}, yu^(-1)]*G[{0}, yw]*G[{1}, yw]*G[{yu}, yv^(-1)]*
       G[{1/(yu*yv)}, yw])/16 + (3*G[{0}, yv^(-1)]*G[{0}, yw]*G[{1}, yw]*
       G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw])/16 - 
     (3*G[{0}, yw]^2*G[{1}, yw]*G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw])/32 + 
     (G[{1}, yu^(-1)]^2*G[{1}, yw]*G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw])/16 + 
     (G[{0}, yu^(-1)]*G[{1}, yv^(-1)]*G[{1}, yw]*G[{yu}, yv^(-1)]*
       G[{1/(yu*yv)}, yw])/8 + (G[{0}, yv^(-1)]*G[{1}, yv^(-1)]*G[{1}, yw]*
       G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw])/8 - 
     (G[{0}, yw]*G[{1}, yv^(-1)]*G[{1}, yw]*G[{yu}, yv^(-1)]*
       G[{1/(yu*yv)}, yw])/8 - (G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*G[{1}, yw]*
       G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw])/8 - 
     (G[{1}, yv^(-1)]^2*G[{1}, yw]*G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw])/32 - 
     (5*G[{0}, yu^(-1)]*G[{1}, yw]^2*G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw])/
      128 - (5*G[{0}, yv^(-1)]*G[{1}, yw]^2*G[{yu}, yv^(-1)]*
       G[{1/(yu*yv)}, yw])/128 + (5*G[{0}, yw]*G[{1}, yw]^2*G[{yu}, yv^(-1)]*
       G[{1/(yu*yv)}, yw])/128 + (G[{1}, yu^(-1)]*G[{1}, yw]^2*
       G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw])/128 + 
     (G[{1}, yv^(-1)]*G[{1}, yw]^2*G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw])/128 - 
     (Pi^2*G[{yu^(-1)}, yw]*G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw])/48 - 
     (G[{0}, yu^(-1)]^2*G[{yu^(-1)}, yw]*G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw])/
      32 - (G[{0}, yu^(-1)]*G[{0}, yv^(-1)]*G[{yu^(-1)}, yw]*G[{yu}, yv^(-1)]*
       G[{1/(yu*yv)}, yw])/16 - (G[{0}, yv^(-1)]^2*G[{yu^(-1)}, yw]*
       G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw])/32 + 
     (G[{0}, yu^(-1)]*G[{0}, yw]*G[{yu^(-1)}, yw]*G[{yu}, yv^(-1)]*
       G[{1/(yu*yv)}, yw])/16 + (G[{0}, yv^(-1)]*G[{0}, yw]*G[{yu^(-1)}, yw]*
       G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw])/16 - 
     (G[{0}, yw]^2*G[{yu^(-1)}, yw]*G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw])/32 - 
     (G[{0}, yu^(-1)]*G[{1}, yu^(-1)]*G[{yu^(-1)}, yw]*G[{yu}, yv^(-1)]*
       G[{1/(yu*yv)}, yw])/16 - (G[{0}, yv^(-1)]*G[{1}, yu^(-1)]*
       G[{yu^(-1)}, yw]*G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw])/16 + 
     (G[{0}, yw]*G[{1}, yu^(-1)]*G[{yu^(-1)}, yw]*G[{yu}, yv^(-1)]*
       G[{1/(yu*yv)}, yw])/16 + (3*G[{1}, yu^(-1)]^2*G[{yu^(-1)}, yw]*
       G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw])/32 - 
     (G[{0}, yu^(-1)]*G[{1}, yv^(-1)]*G[{yu^(-1)}, yw]*G[{yu}, yv^(-1)]*
       G[{1/(yu*yv)}, yw])/16 - (G[{0}, yv^(-1)]*G[{1}, yv^(-1)]*
       G[{yu^(-1)}, yw]*G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw])/16 + 
     (G[{0}, yw]*G[{1}, yv^(-1)]*G[{yu^(-1)}, yw]*G[{yu}, yv^(-1)]*
       G[{1/(yu*yv)}, yw])/16 - (G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*
       G[{yu^(-1)}, yw]*G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw])/16 + 
     (3*G[{1}, yv^(-1)]^2*G[{yu^(-1)}, yw]*G[{yu}, yv^(-1)]*
       G[{1/(yu*yv)}, yw])/32 - (3*G[{0}, yu^(-1)]*G[{1}, yw]*
       G[{yu^(-1)}, yw]*G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw])/32 - 
     (3*G[{0}, yv^(-1)]*G[{1}, yw]*G[{yu^(-1)}, yw]*G[{yu}, yv^(-1)]*
       G[{1/(yu*yv)}, yw])/32 + (3*G[{0}, yw]*G[{1}, yw]*G[{yu^(-1)}, yw]*
       G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw])/32 - 
     (G[{1}, yu^(-1)]*G[{1}, yw]*G[{yu^(-1)}, yw]*G[{yu}, yv^(-1)]*
       G[{1/(yu*yv)}, yw])/32 - (G[{1}, yv^(-1)]*G[{1}, yw]*G[{yu^(-1)}, yw]*
       G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw])/32 - 
     (G[{1}, yv^(-1)]*G[{yu^(-1)}, yw]^2*G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw])/
      16 + (3*G[{1}, yw]*G[{yu^(-1)}, yw]^2*G[{yu}, yv^(-1)]*
       G[{1/(yu*yv)}, yw])/64 + (G[{yu^(-1)}, yw]^3*G[{yu}, yv^(-1)]*
       G[{1/(yu*yv)}, yw])/48 + (Pi^2*G[{yu}, yv^(-1)]^2*G[{1/(yu*yv)}, yw])/
      96 + (5*G[{0}, yu^(-1)]^2*G[{yu}, yv^(-1)]^2*G[{1/(yu*yv)}, yw])/64 + 
     (5*G[{0}, yu^(-1)]*G[{0}, yv^(-1)]*G[{yu}, yv^(-1)]^2*
       G[{1/(yu*yv)}, yw])/32 + (5*G[{0}, yv^(-1)]^2*G[{yu}, yv^(-1)]^2*
       G[{1/(yu*yv)}, yw])/64 - (5*G[{0}, yu^(-1)]*G[{0}, yw]*
       G[{yu}, yv^(-1)]^2*G[{1/(yu*yv)}, yw])/32 - 
     (5*G[{0}, yv^(-1)]*G[{0}, yw]*G[{yu}, yv^(-1)]^2*G[{1/(yu*yv)}, yw])/
      32 + (5*G[{0}, yw]^2*G[{yu}, yv^(-1)]^2*G[{1/(yu*yv)}, yw])/64 - 
     (G[{0}, yu^(-1)]*G[{1}, yu^(-1)]*G[{yu}, yv^(-1)]^2*G[{1/(yu*yv)}, yw])/
      32 - (G[{0}, yv^(-1)]*G[{1}, yu^(-1)]*G[{yu}, yv^(-1)]^2*
       G[{1/(yu*yv)}, yw])/32 + (G[{0}, yw]*G[{1}, yu^(-1)]*
       G[{yu}, yv^(-1)]^2*G[{1/(yu*yv)}, yw])/32 - 
     (G[{1}, yu^(-1)]^2*G[{yu}, yv^(-1)]^2*G[{1/(yu*yv)}, yw])/64 - 
     (5*G[{0}, yu^(-1)]*G[{1}, yv^(-1)]*G[{yu}, yv^(-1)]^2*
       G[{1/(yu*yv)}, yw])/32 - (5*G[{0}, yv^(-1)]*G[{1}, yv^(-1)]*
       G[{yu}, yv^(-1)]^2*G[{1/(yu*yv)}, yw])/32 + 
     (5*G[{0}, yw]*G[{1}, yv^(-1)]*G[{yu}, yv^(-1)]^2*G[{1/(yu*yv)}, yw])/
      32 + (3*G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*G[{yu}, yv^(-1)]^2*
       G[{1/(yu*yv)}, yw])/32 + (5*G[{1}, yv^(-1)]^2*G[{yu}, yv^(-1)]^2*
       G[{1/(yu*yv)}, yw])/64 + (G[{0}, yu^(-1)]*G[{1}, yw]*
       G[{yu}, yv^(-1)]^2*G[{1/(yu*yv)}, yw])/8 + 
     (G[{0}, yv^(-1)]*G[{1}, yw]*G[{yu}, yv^(-1)]^2*G[{1/(yu*yv)}, yw])/8 - 
     (G[{0}, yw]*G[{1}, yw]*G[{yu}, yv^(-1)]^2*G[{1/(yu*yv)}, yw])/8 - 
     (3*G[{1}, yv^(-1)]*G[{1}, yw]*G[{yu}, yv^(-1)]^2*G[{1/(yu*yv)}, yw])/
      32 + (G[{1}, yw]^2*G[{yu}, yv^(-1)]^2*G[{1/(yu*yv)}, yw])/32 + 
     (G[{0}, yu^(-1)]*G[{yu^(-1)}, yw]*G[{yu}, yv^(-1)]^2*G[{1/(yu*yv)}, yw])/
      8 + (G[{0}, yv^(-1)]*G[{yu^(-1)}, yw]*G[{yu}, yv^(-1)]^2*
       G[{1/(yu*yv)}, yw])/8 - (G[{0}, yw]*G[{yu^(-1)}, yw]*
       G[{yu}, yv^(-1)]^2*G[{1/(yu*yv)}, yw])/8 - 
     (G[{1}, yv^(-1)]*G[{yu^(-1)}, yw]*G[{yu}, yv^(-1)]^2*G[{1/(yu*yv)}, yw])/
      16 + (G[{1}, yw]*G[{yu^(-1)}, yw]*G[{yu}, yv^(-1)]^2*
       G[{1/(yu*yv)}, yw])/8 + (G[{yu^(-1)}, yw]^2*G[{yu}, yv^(-1)]^2*
       G[{1/(yu*yv)}, yw])/32 - (G[{0}, yu^(-1)]*G[{yu}, yv^(-1)]^3*
       G[{1/(yu*yv)}, yw])/24 - (G[{0}, yv^(-1)]*G[{yu}, yv^(-1)]^3*
       G[{1/(yu*yv)}, yw])/24 + (G[{0}, yw]*G[{yu}, yv^(-1)]^3*
       G[{1/(yu*yv)}, yw])/24 + (G[{1}, yv^(-1)]*G[{yu}, yv^(-1)]^3*
       G[{1/(yu*yv)}, yw])/16 - (5*G[{1}, yw]*G[{yu}, yv^(-1)]^3*
       G[{1/(yu*yv)}, yw])/96 - (G[{yu^(-1)}, yw]*G[{yu}, yv^(-1)]^3*
       G[{1/(yu*yv)}, yw])/16 + (G[{yu}, yv^(-1)]^4*G[{1/(yu*yv)}, yw])/192 - 
     (29*Pi^2*G[{0}, yu^(-1)]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw])/768 - 
     (29*Pi^2*G[{0}, yv^(-1)]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw])/768 + 
     (29*Pi^2*G[{0}, yw]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw])/768 + 
     (53*Pi^2*G[{1}, yu^(-1)]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw])/768 + 
     (3*G[{0}, yu^(-1)]^2*G[{1}, yu^(-1)]*G[{yv^(-1)}, yw]*
       G[{1/(yu*yv)}, yw])/32 + (3*G[{0}, yu^(-1)]*G[{0}, yv^(-1)]*
       G[{1}, yu^(-1)]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw])/16 + 
     (3*G[{0}, yv^(-1)]^2*G[{1}, yu^(-1)]*G[{yv^(-1)}, yw]*
       G[{1/(yu*yv)}, yw])/32 - (3*G[{0}, yu^(-1)]*G[{0}, yw]*G[{1}, yu^(-1)]*
       G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw])/16 - 
     (3*G[{0}, yv^(-1)]*G[{0}, yw]*G[{1}, yu^(-1)]*G[{yv^(-1)}, yw]*
       G[{1/(yu*yv)}, yw])/16 + (3*G[{0}, yw]^2*G[{1}, yu^(-1)]*
       G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw])/32 - 
     (5*G[{0}, yu^(-1)]*G[{1}, yu^(-1)]^2*G[{yv^(-1)}, yw]*
       G[{1/(yu*yv)}, yw])/32 - (5*G[{0}, yv^(-1)]*G[{1}, yu^(-1)]^2*
       G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw])/32 + 
     (5*G[{0}, yw]*G[{1}, yu^(-1)]^2*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw])/
      32 + (G[{1}, yu^(-1)]^3*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw])/16 + 
     (5*Pi^2*G[{1}, yv^(-1)]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw])/768 - 
     (3*G[{0}, yu^(-1)]^2*G[{1}, yv^(-1)]*G[{yv^(-1)}, yw]*
       G[{1/(yu*yv)}, yw])/32 - (3*G[{0}, yu^(-1)]*G[{0}, yv^(-1)]*
       G[{1}, yv^(-1)]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw])/16 - 
     (3*G[{0}, yv^(-1)]^2*G[{1}, yv^(-1)]*G[{yv^(-1)}, yw]*
       G[{1/(yu*yv)}, yw])/32 + (3*G[{0}, yu^(-1)]*G[{0}, yw]*G[{1}, yv^(-1)]*
       G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw])/16 + 
     (3*G[{0}, yv^(-1)]*G[{0}, yw]*G[{1}, yv^(-1)]*G[{yv^(-1)}, yw]*
       G[{1/(yu*yv)}, yw])/16 - (3*G[{0}, yw]^2*G[{1}, yv^(-1)]*
       G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw])/32 - 
     (G[{0}, yu^(-1)]*G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*G[{yv^(-1)}, yw]*
       G[{1/(yu*yv)}, yw])/16 - (G[{0}, yv^(-1)]*G[{1}, yu^(-1)]*
       G[{1}, yv^(-1)]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw])/16 + 
     (G[{0}, yw]*G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*G[{yv^(-1)}, yw]*
       G[{1/(yu*yv)}, yw])/16 + (G[{1}, yu^(-1)]^2*G[{1}, yv^(-1)]*
       G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw])/8 + 
     (9*G[{0}, yu^(-1)]*G[{1}, yv^(-1)]^2*G[{yv^(-1)}, yw]*
       G[{1/(yu*yv)}, yw])/64 + (9*G[{0}, yv^(-1)]*G[{1}, yv^(-1)]^2*
       G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw])/64 - 
     (9*G[{0}, yw]*G[{1}, yv^(-1)]^2*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw])/
      64 - (5*G[{1}, yu^(-1)]*G[{1}, yv^(-1)]^2*G[{yv^(-1)}, yw]*
       G[{1/(yu*yv)}, yw])/64 - (3*G[{1}, yv^(-1)]^3*G[{yv^(-1)}, yw]*
       G[{1/(yu*yv)}, yw])/64 + (Pi^2*G[{1}, yw]*G[{yv^(-1)}, yw]*
       G[{1/(yu*yv)}, yw])/192 + (3*G[{0}, yu^(-1)]^2*G[{1}, yw]*
       G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw])/64 + 
     (3*G[{0}, yu^(-1)]*G[{0}, yv^(-1)]*G[{1}, yw]*G[{yv^(-1)}, yw]*
       G[{1/(yu*yv)}, yw])/32 + (3*G[{0}, yv^(-1)]^2*G[{1}, yw]*
       G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw])/64 - 
     (3*G[{0}, yu^(-1)]*G[{0}, yw]*G[{1}, yw]*G[{yv^(-1)}, yw]*
       G[{1/(yu*yv)}, yw])/32 - (3*G[{0}, yv^(-1)]*G[{0}, yw]*G[{1}, yw]*
       G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw])/32 + 
     (3*G[{0}, yw]^2*G[{1}, yw]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw])/64 + 
     (G[{0}, yu^(-1)]*G[{1}, yu^(-1)]*G[{1}, yw]*G[{yv^(-1)}, yw]*
       G[{1/(yu*yv)}, yw])/32 + (G[{0}, yv^(-1)]*G[{1}, yu^(-1)]*G[{1}, yw]*
       G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw])/32 - 
     (G[{0}, yw]*G[{1}, yu^(-1)]*G[{1}, yw]*G[{yv^(-1)}, yw]*
       G[{1/(yu*yv)}, yw])/32 - (3*G[{1}, yu^(-1)]^2*G[{1}, yw]*
       G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw])/64 - 
     (3*G[{1}, yv^(-1)]^2*G[{1}, yw]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw])/
      64 + (G[{0}, yu^(-1)]*G[{1}, yw]^2*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw])/
      8 + (G[{0}, yv^(-1)]*G[{1}, yw]^2*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw])/
      8 - (G[{0}, yw]*G[{1}, yw]^2*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw])/8 - 
     (G[{1}, yu^(-1)]*G[{1}, yw]^2*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw])/16 - 
     (3*G[{1}, yv^(-1)]*G[{1}, yw]^2*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw])/
      32 + (G[{1}, yw]^3*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw])/32 - 
     (3*Pi^2*G[{yu^(-1)}, yw]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw])/256 + 
     (3*G[{0}, yu^(-1)]^2*G[{yu^(-1)}, yw]*G[{yv^(-1)}, yw]*
       G[{1/(yu*yv)}, yw])/64 + (3*G[{0}, yu^(-1)]*G[{0}, yv^(-1)]*
       G[{yu^(-1)}, yw]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw])/32 + 
     (3*G[{0}, yv^(-1)]^2*G[{yu^(-1)}, yw]*G[{yv^(-1)}, yw]*
       G[{1/(yu*yv)}, yw])/64 - (3*G[{0}, yu^(-1)]*G[{0}, yw]*
       G[{yu^(-1)}, yw]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw])/32 - 
     (3*G[{0}, yv^(-1)]*G[{0}, yw]*G[{yu^(-1)}, yw]*G[{yv^(-1)}, yw]*
       G[{1/(yu*yv)}, yw])/32 + (3*G[{0}, yw]^2*G[{yu^(-1)}, yw]*
       G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw])/64 + 
     (G[{0}, yu^(-1)]*G[{1}, yu^(-1)]*G[{yu^(-1)}, yw]*G[{yv^(-1)}, yw]*
       G[{1/(yu*yv)}, yw])/32 + (G[{0}, yv^(-1)]*G[{1}, yu^(-1)]*
       G[{yu^(-1)}, yw]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw])/32 - 
     (G[{0}, yw]*G[{1}, yu^(-1)]*G[{yu^(-1)}, yw]*G[{yv^(-1)}, yw]*
       G[{1/(yu*yv)}, yw])/32 - (5*G[{1}, yu^(-1)]^2*G[{yu^(-1)}, yw]*
       G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw])/64 - 
     (7*G[{0}, yu^(-1)]*G[{1}, yv^(-1)]*G[{yu^(-1)}, yw]*G[{yv^(-1)}, yw]*
       G[{1/(yu*yv)}, yw])/32 - (7*G[{0}, yv^(-1)]*G[{1}, yv^(-1)]*
       G[{yu^(-1)}, yw]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw])/32 + 
     (7*G[{0}, yw]*G[{1}, yv^(-1)]*G[{yu^(-1)}, yw]*G[{yv^(-1)}, yw]*
       G[{1/(yu*yv)}, yw])/32 + (3*G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*
       G[{yu^(-1)}, yw]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw])/32 + 
     (G[{1}, yv^(-1)]^2*G[{yu^(-1)}, yw]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw])/
      8 + (G[{1}, yu^(-1)]*G[{1}, yw]*G[{yu^(-1)}, yw]*G[{yv^(-1)}, yw]*
       G[{1/(yu*yv)}, yw])/8 + (G[{1}, yv^(-1)]*G[{1}, yw]*G[{yu^(-1)}, yw]*
       G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw])/32 + 
     (5*G[{1}, yw]^2*G[{yu^(-1)}, yw]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw])/
      64 + (7*G[{0}, yu^(-1)]*G[{yu^(-1)}, yw]^2*G[{yv^(-1)}, yw]*
       G[{1/(yu*yv)}, yw])/64 + (7*G[{0}, yv^(-1)]*G[{yu^(-1)}, yw]^2*
       G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw])/64 - 
     (7*G[{0}, yw]*G[{yu^(-1)}, yw]^2*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw])/
      64 - (7*G[{1}, yu^(-1)]*G[{yu^(-1)}, yw]^2*G[{yv^(-1)}, yw]*
       G[{1/(yu*yv)}, yw])/64 - (7*G[{1}, yv^(-1)]*G[{yu^(-1)}, yw]^2*
       G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw])/64 + 
     (7*G[{yu^(-1)}, yw]^3*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw])/192 - 
     (7*G[{0}, yu^(-1)]*G[{1}, yw]*G[{yu}, yv^(-1)]*G[{yv^(-1)}, yw]*
       G[{1/(yu*yv)}, yw])/32 - (7*G[{0}, yv^(-1)]*G[{1}, yw]*
       G[{yu}, yv^(-1)]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw])/32 + 
     (7*G[{0}, yw]*G[{1}, yw]*G[{yu}, yv^(-1)]*G[{yv^(-1)}, yw]*
       G[{1/(yu*yv)}, yw])/32 + (G[{1}, yu^(-1)]*G[{1}, yw]*G[{yu}, yv^(-1)]*
       G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw])/32 + 
     (7*G[{1}, yv^(-1)]*G[{1}, yw]*G[{yu}, yv^(-1)]*G[{yv^(-1)}, yw]*
       G[{1/(yu*yv)}, yw])/32 - (3*G[{1}, yw]^2*G[{yu}, yv^(-1)]*
       G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw])/32 - 
     (5*G[{1}, yw]*G[{yu^(-1)}, yw]*G[{yu}, yv^(-1)]*G[{yv^(-1)}, yw]*
       G[{1/(yu*yv)}, yw])/32 + (3*G[{1}, yw]*G[{yu}, yv^(-1)]^2*
       G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw])/32 - 
     (19*Pi^2*G[{yv^(-1)}, yw]^2*G[{1/(yu*yv)}, yw])/512 - 
     (9*G[{0}, yu^(-1)]^2*G[{yv^(-1)}, yw]^2*G[{1/(yu*yv)}, yw])/128 - 
     (9*G[{0}, yu^(-1)]*G[{0}, yv^(-1)]*G[{yv^(-1)}, yw]^2*
       G[{1/(yu*yv)}, yw])/64 - (9*G[{0}, yv^(-1)]^2*G[{yv^(-1)}, yw]^2*
       G[{1/(yu*yv)}, yw])/128 + (9*G[{0}, yu^(-1)]*G[{0}, yw]*
       G[{yv^(-1)}, yw]^2*G[{1/(yu*yv)}, yw])/64 + 
     (9*G[{0}, yv^(-1)]*G[{0}, yw]*G[{yv^(-1)}, yw]^2*G[{1/(yu*yv)}, yw])/
      64 - (9*G[{0}, yw]^2*G[{yv^(-1)}, yw]^2*G[{1/(yu*yv)}, yw])/128 + 
     (21*G[{0}, yu^(-1)]*G[{1}, yu^(-1)]*G[{yv^(-1)}, yw]^2*
       G[{1/(yu*yv)}, yw])/64 + (21*G[{0}, yv^(-1)]*G[{1}, yu^(-1)]*
       G[{yv^(-1)}, yw]^2*G[{1/(yu*yv)}, yw])/64 - 
     (21*G[{0}, yw]*G[{1}, yu^(-1)]*G[{yv^(-1)}, yw]^2*G[{1/(yu*yv)}, yw])/
      64 - (29*G[{1}, yu^(-1)]^2*G[{yv^(-1)}, yw]^2*G[{1/(yu*yv)}, yw])/128 - 
     (3*G[{0}, yu^(-1)]*G[{1}, yv^(-1)]*G[{yv^(-1)}, yw]^2*
       G[{1/(yu*yv)}, yw])/64 - (3*G[{0}, yv^(-1)]*G[{1}, yv^(-1)]*
       G[{yv^(-1)}, yw]^2*G[{1/(yu*yv)}, yw])/64 + 
     (3*G[{0}, yw]*G[{1}, yv^(-1)]*G[{yv^(-1)}, yw]^2*G[{1/(yu*yv)}, yw])/
      64 - (13*G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*G[{yv^(-1)}, yw]^2*
       G[{1/(yu*yv)}, yw])/64 + (3*G[{1}, yv^(-1)]^2*G[{yv^(-1)}, yw]^2*
       G[{1/(yu*yv)}, yw])/32 + (G[{0}, yu^(-1)]*G[{1}, yw]*
       G[{yv^(-1)}, yw]^2*G[{1/(yu*yv)}, yw])/16 + 
     (G[{0}, yv^(-1)]*G[{1}, yw]*G[{yv^(-1)}, yw]^2*G[{1/(yu*yv)}, yw])/16 - 
     (G[{0}, yw]*G[{1}, yw]*G[{yv^(-1)}, yw]^2*G[{1/(yu*yv)}, yw])/16 + 
     (G[{1}, yu^(-1)]*G[{1}, yw]*G[{yv^(-1)}, yw]^2*G[{1/(yu*yv)}, yw])/16 - 
     (3*G[{1}, yv^(-1)]*G[{1}, yw]*G[{yv^(-1)}, yw]^2*G[{1/(yu*yv)}, yw])/
      64 + (9*G[{1}, yw]^2*G[{yv^(-1)}, yw]^2*G[{1/(yu*yv)}, yw])/128 - 
     (G[{0}, yu^(-1)]*G[{yu^(-1)}, yw]*G[{yv^(-1)}, yw]^2*G[{1/(yu*yv)}, yw])/
      64 - (G[{0}, yv^(-1)]*G[{yu^(-1)}, yw]*G[{yv^(-1)}, yw]^2*
       G[{1/(yu*yv)}, yw])/64 + (G[{0}, yw]*G[{yu^(-1)}, yw]*
       G[{yv^(-1)}, yw]^2*G[{1/(yu*yv)}, yw])/64 + 
     (9*G[{1}, yu^(-1)]*G[{yu^(-1)}, yw]*G[{yv^(-1)}, yw]^2*
       G[{1/(yu*yv)}, yw])/64 - (7*G[{1}, yv^(-1)]*G[{yu^(-1)}, yw]*
       G[{yv^(-1)}, yw]^2*G[{1/(yu*yv)}, yw])/64 + 
     (7*G[{yu^(-1)}, yw]^2*G[{yv^(-1)}, yw]^2*G[{1/(yu*yv)}, yw])/128 - 
     (9*G[{1}, yw]*G[{yu}, yv^(-1)]*G[{yv^(-1)}, yw]^2*G[{1/(yu*yv)}, yw])/
      64 - (25*G[{0}, yu^(-1)]*G[{yv^(-1)}, yw]^3*G[{1/(yu*yv)}, yw])/192 - 
     (25*G[{0}, yv^(-1)]*G[{yv^(-1)}, yw]^3*G[{1/(yu*yv)}, yw])/192 + 
     (25*G[{0}, yw]*G[{yv^(-1)}, yw]^3*G[{1/(yu*yv)}, yw])/192 + 
     (41*G[{1}, yu^(-1)]*G[{yv^(-1)}, yw]^3*G[{1/(yu*yv)}, yw])/192 + 
     (3*G[{1}, yv^(-1)]*G[{yv^(-1)}, yw]^3*G[{1/(yu*yv)}, yw])/64 - 
     (3*G[{yu^(-1)}, yw]*G[{yv^(-1)}, yw]^3*G[{1/(yu*yv)}, yw])/64 - 
     (41*G[{yv^(-1)}, yw]^4*G[{1/(yu*yv)}, yw])/768 + 
     (5*Pi^2*G[{0}, yu^(-1)]*G[{1/(yu*yv)}, yw]^2)/1536 + 
     (5*Pi^2*G[{0}, yv^(-1)]*G[{1/(yu*yv)}, yw]^2)/1536 - 
     (5*Pi^2*G[{0}, yw]*G[{1/(yu*yv)}, yw]^2)/1536 - 
     (13*Pi^2*G[{1}, yu^(-1)]*G[{1/(yu*yv)}, yw]^2)/1536 - 
     (3*G[{0}, yu^(-1)]^2*G[{1}, yu^(-1)]*G[{1/(yu*yv)}, yw]^2)/64 - 
     (3*G[{0}, yu^(-1)]*G[{0}, yv^(-1)]*G[{1}, yu^(-1)]*G[{1/(yu*yv)}, yw]^2)/
      32 - (3*G[{0}, yv^(-1)]^2*G[{1}, yu^(-1)]*G[{1/(yu*yv)}, yw]^2)/64 + 
     (3*G[{0}, yu^(-1)]*G[{0}, yw]*G[{1}, yu^(-1)]*G[{1/(yu*yv)}, yw]^2)/32 + 
     (3*G[{0}, yv^(-1)]*G[{0}, yw]*G[{1}, yu^(-1)]*G[{1/(yu*yv)}, yw]^2)/32 - 
     (3*G[{0}, yw]^2*G[{1}, yu^(-1)]*G[{1/(yu*yv)}, yw]^2)/64 + 
     (5*G[{0}, yu^(-1)]*G[{1}, yu^(-1)]^2*G[{1/(yu*yv)}, yw]^2)/64 + 
     (5*G[{0}, yv^(-1)]*G[{1}, yu^(-1)]^2*G[{1/(yu*yv)}, yw]^2)/64 - 
     (5*G[{0}, yw]*G[{1}, yu^(-1)]^2*G[{1/(yu*yv)}, yw]^2)/64 - 
     (G[{1}, yu^(-1)]^3*G[{1/(yu*yv)}, yw]^2)/32 - 
     (Pi^2*G[{1}, yv^(-1)]*G[{1/(yu*yv)}, yw]^2)/1536 + 
     (7*G[{0}, yu^(-1)]^2*G[{1}, yv^(-1)]*G[{1/(yu*yv)}, yw]^2)/128 + 
     (7*G[{0}, yu^(-1)]*G[{0}, yv^(-1)]*G[{1}, yv^(-1)]*G[{1/(yu*yv)}, yw]^2)/
      64 + (7*G[{0}, yv^(-1)]^2*G[{1}, yv^(-1)]*G[{1/(yu*yv)}, yw]^2)/128 - 
     (7*G[{0}, yu^(-1)]*G[{0}, yw]*G[{1}, yv^(-1)]*G[{1/(yu*yv)}, yw]^2)/64 - 
     (7*G[{0}, yv^(-1)]*G[{0}, yw]*G[{1}, yv^(-1)]*G[{1/(yu*yv)}, yw]^2)/64 + 
     (7*G[{0}, yw]^2*G[{1}, yv^(-1)]*G[{1/(yu*yv)}, yw]^2)/128 + 
     (3*G[{0}, yu^(-1)]*G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*G[{1/(yu*yv)}, yw]^2)/
      64 + (3*G[{0}, yv^(-1)]*G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*
       G[{1/(yu*yv)}, yw]^2)/64 - (3*G[{0}, yw]*G[{1}, yu^(-1)]*
       G[{1}, yv^(-1)]*G[{1/(yu*yv)}, yw]^2)/64 - 
     (9*G[{1}, yu^(-1)]^2*G[{1}, yv^(-1)]*G[{1/(yu*yv)}, yw]^2)/128 - 
     (31*G[{0}, yu^(-1)]*G[{1}, yv^(-1)]^2*G[{1/(yu*yv)}, yw]^2)/256 - 
     (31*G[{0}, yv^(-1)]*G[{1}, yv^(-1)]^2*G[{1/(yu*yv)}, yw]^2)/256 + 
     (31*G[{0}, yw]*G[{1}, yv^(-1)]^2*G[{1/(yu*yv)}, yw]^2)/256 + 
     (3*G[{1}, yu^(-1)]*G[{1}, yv^(-1)]^2*G[{1/(yu*yv)}, yw]^2)/256 + 
     (17*G[{1}, yv^(-1)]^3*G[{1/(yu*yv)}, yw]^2)/256 - 
     (Pi^2*G[{1}, yw]*G[{1/(yu*yv)}, yw]^2)/384 + 
     (G[{0}, yu^(-1)]^2*G[{1}, yw]*G[{1/(yu*yv)}, yw]^2)/128 + 
     (G[{0}, yu^(-1)]*G[{0}, yv^(-1)]*G[{1}, yw]*G[{1/(yu*yv)}, yw]^2)/64 + 
     (G[{0}, yv^(-1)]^2*G[{1}, yw]*G[{1/(yu*yv)}, yw]^2)/128 - 
     (G[{0}, yu^(-1)]*G[{0}, yw]*G[{1}, yw]*G[{1/(yu*yv)}, yw]^2)/64 - 
     (G[{0}, yv^(-1)]*G[{0}, yw]*G[{1}, yw]*G[{1/(yu*yv)}, yw]^2)/64 + 
     (G[{0}, yw]^2*G[{1}, yw]*G[{1/(yu*yv)}, yw]^2)/128 - 
     (G[{0}, yu^(-1)]*G[{1}, yu^(-1)]*G[{1}, yw]*G[{1/(yu*yv)}, yw]^2)/64 - 
     (G[{0}, yv^(-1)]*G[{1}, yu^(-1)]*G[{1}, yw]*G[{1/(yu*yv)}, yw]^2)/64 + 
     (G[{0}, yw]*G[{1}, yu^(-1)]*G[{1}, yw]*G[{1/(yu*yv)}, yw]^2)/64 + 
     (3*G[{1}, yu^(-1)]^2*G[{1}, yw]*G[{1/(yu*yv)}, yw]^2)/128 + 
     (9*G[{0}, yu^(-1)]*G[{1}, yv^(-1)]*G[{1}, yw]*G[{1/(yu*yv)}, yw]^2)/
      128 + (9*G[{0}, yv^(-1)]*G[{1}, yv^(-1)]*G[{1}, yw]*
       G[{1/(yu*yv)}, yw]^2)/128 - (9*G[{0}, yw]*G[{1}, yv^(-1)]*G[{1}, yw]*
       G[{1/(yu*yv)}, yw]^2)/128 - (5*G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*
       G[{1}, yw]*G[{1/(yu*yv)}, yw]^2)/128 - 
     (5*G[{1}, yv^(-1)]^2*G[{1}, yw]*G[{1/(yu*yv)}, yw]^2)/64 + 
     (13*G[{0}, yu^(-1)]*G[{1}, yw]^2*G[{1/(yu*yv)}, yw]^2)/256 + 
     (13*G[{0}, yv^(-1)]*G[{1}, yw]^2*G[{1/(yu*yv)}, yw]^2)/256 - 
     (13*G[{0}, yw]*G[{1}, yw]^2*G[{1/(yu*yv)}, yw]^2)/256 - 
     (5*G[{1}, yu^(-1)]*G[{1}, yw]^2*G[{1/(yu*yv)}, yw]^2)/256 - 
     (9*G[{1}, yv^(-1)]*G[{1}, yw]^2*G[{1/(yu*yv)}, yw]^2)/256 + 
     (G[{1}, yw]^3*G[{1/(yu*yv)}, yw]^2)/64 + 
     (Pi^2*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2)/1536 - 
     (7*G[{0}, yu^(-1)]^2*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2)/128 - 
     (7*G[{0}, yu^(-1)]*G[{0}, yv^(-1)]*G[{yu^(-1)}, yw]*
       G[{1/(yu*yv)}, yw]^2)/64 - (7*G[{0}, yv^(-1)]^2*G[{yu^(-1)}, yw]*
       G[{1/(yu*yv)}, yw]^2)/128 + (7*G[{0}, yu^(-1)]*G[{0}, yw]*
       G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2)/64 + 
     (7*G[{0}, yv^(-1)]*G[{0}, yw]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2)/
      64 - (7*G[{0}, yw]^2*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2)/128 - 
     (G[{0}, yu^(-1)]*G[{1}, yu^(-1)]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2)/
      64 - (G[{0}, yv^(-1)]*G[{1}, yu^(-1)]*G[{yu^(-1)}, yw]*
       G[{1/(yu*yv)}, yw]^2)/64 + (G[{0}, yw]*G[{1}, yu^(-1)]*
       G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2)/64 + 
     (5*G[{1}, yu^(-1)]^2*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2)/128 + 
     (13*G[{0}, yu^(-1)]*G[{1}, yv^(-1)]*G[{yu^(-1)}, yw]*
       G[{1/(yu*yv)}, yw]^2)/64 + (13*G[{0}, yv^(-1)]*G[{1}, yv^(-1)]*
       G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2)/64 - 
     (13*G[{0}, yw]*G[{1}, yv^(-1)]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2)/
      64 + (3*G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*G[{yu^(-1)}, yw]*
       G[{1/(yu*yv)}, yw]^2)/64 - (41*G[{1}, yv^(-1)]^2*G[{yu^(-1)}, yw]*
       G[{1/(yu*yv)}, yw]^2)/256 - (13*G[{0}, yu^(-1)]*G[{1}, yw]*
       G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2)/128 - 
     (13*G[{0}, yv^(-1)]*G[{1}, yw]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2)/
      128 + (13*G[{0}, yw]*G[{1}, yw]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2)/
      128 + (21*G[{1}, yu^(-1)]*G[{1}, yw]*G[{yu^(-1)}, yw]*
       G[{1/(yu*yv)}, yw]^2)/128 + (13*G[{1}, yv^(-1)]*G[{1}, yw]*
       G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2)/64 + 
     (21*G[{1}, yw]^2*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2)/256 - 
     (17*G[{0}, yu^(-1)]*G[{yu^(-1)}, yw]^2*G[{1/(yu*yv)}, yw]^2)/256 - 
     (17*G[{0}, yv^(-1)]*G[{yu^(-1)}, yw]^2*G[{1/(yu*yv)}, yw]^2)/256 + 
     (17*G[{0}, yw]*G[{yu^(-1)}, yw]^2*G[{1/(yu*yv)}, yw]^2)/256 - 
     (15*G[{1}, yu^(-1)]*G[{yu^(-1)}, yw]^2*G[{1/(yu*yv)}, yw]^2)/256 + 
     (33*G[{1}, yv^(-1)]*G[{yu^(-1)}, yw]^2*G[{1/(yu*yv)}, yw]^2)/256 - 
     (G[{1}, yw]*G[{yu^(-1)}, yw]^2*G[{1/(yu*yv)}, yw]^2)/16 - 
     (11*G[{yu^(-1)}, yw]^3*G[{1/(yu*yv)}, yw]^2)/256 + 
     (Pi^2*G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw]^2)/384 - 
     (G[{0}, yu^(-1)]^2*G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw]^2)/128 - 
     (G[{0}, yu^(-1)]*G[{0}, yv^(-1)]*G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw]^2)/
      64 - (G[{0}, yv^(-1)]^2*G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw]^2)/128 + 
     (G[{0}, yu^(-1)]*G[{0}, yw]*G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw]^2)/64 + 
     (G[{0}, yv^(-1)]*G[{0}, yw]*G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw]^2)/64 - 
     (G[{0}, yw]^2*G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw]^2)/128 - 
     (G[{0}, yu^(-1)]*G[{1}, yu^(-1)]*G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw]^2)/
      64 - (G[{0}, yv^(-1)]*G[{1}, yu^(-1)]*G[{yu}, yv^(-1)]*
       G[{1/(yu*yv)}, yw]^2)/64 + (G[{0}, yw]*G[{1}, yu^(-1)]*
       G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw]^2)/64 + 
     (G[{1}, yu^(-1)]^2*G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw]^2)/128 - 
     (G[{0}, yu^(-1)]*G[{1}, yv^(-1)]*G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw]^2)/
      64 - (G[{0}, yv^(-1)]*G[{1}, yv^(-1)]*G[{yu}, yv^(-1)]*
       G[{1/(yu*yv)}, yw]^2)/64 + (G[{0}, yw]*G[{1}, yv^(-1)]*
       G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw]^2)/64 + 
     (5*G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*G[{yu}, yv^(-1)]*
       G[{1/(yu*yv)}, yw]^2)/64 + (3*G[{1}, yv^(-1)]^2*G[{yu}, yv^(-1)]*
       G[{1/(yu*yv)}, yw]^2)/128 - (11*G[{0}, yu^(-1)]*G[{1}, yw]*
       G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw]^2)/128 - 
     (11*G[{0}, yv^(-1)]*G[{1}, yw]*G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw]^2)/
      128 + (11*G[{0}, yw]*G[{1}, yw]*G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw]^2)/
      128 + (3*G[{1}, yu^(-1)]*G[{1}, yw]*G[{yu}, yv^(-1)]*
       G[{1/(yu*yv)}, yw]^2)/128 + (15*G[{1}, yv^(-1)]*G[{1}, yw]*
       G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw]^2)/128 - 
     (3*G[{1}, yw]^2*G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw]^2)/64 + 
     (G[{0}, yu^(-1)]*G[{yu^(-1)}, yw]*G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw]^2)/
      32 + (G[{0}, yv^(-1)]*G[{yu^(-1)}, yw]*G[{yu}, yv^(-1)]*
       G[{1/(yu*yv)}, yw]^2)/32 - (G[{0}, yw]*G[{yu^(-1)}, yw]*
       G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw]^2)/32 - 
     (3*G[{1}, yu^(-1)]*G[{yu^(-1)}, yw]*G[{yu}, yv^(-1)]*
       G[{1/(yu*yv)}, yw]^2)/32 - (G[{1}, yv^(-1)]*G[{yu^(-1)}, yw]*
       G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw]^2)/8 - 
     (21*G[{1}, yw]*G[{yu^(-1)}, yw]*G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw]^2)/
      128 + (G[{yu^(-1)}, yw]^2*G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw]^2)/16 + 
     (G[{0}, yu^(-1)]*G[{yu}, yv^(-1)]^2*G[{1/(yu*yv)}, yw]^2)/32 + 
     (G[{0}, yv^(-1)]*G[{yu}, yv^(-1)]^2*G[{1/(yu*yv)}, yw]^2)/32 - 
     (G[{0}, yw]*G[{yu}, yv^(-1)]^2*G[{1/(yu*yv)}, yw]^2)/32 - 
     (G[{1}, yu^(-1)]*G[{yu}, yv^(-1)]^2*G[{1/(yu*yv)}, yw]^2)/32 - 
     (5*G[{1}, yv^(-1)]*G[{yu}, yv^(-1)]^2*G[{1/(yu*yv)}, yw]^2)/64 + 
     (G[{1}, yw]*G[{yu}, yv^(-1)]^2*G[{1/(yu*yv)}, yw]^2)/64 + 
     (5*G[{yu^(-1)}, yw]*G[{yu}, yv^(-1)]^2*G[{1/(yu*yv)}, yw]^2)/64 + 
     (G[{yu}, yv^(-1)]^3*G[{1/(yu*yv)}, yw]^2)/64 + 
     (13*Pi^2*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2)/1536 + 
     (3*G[{0}, yu^(-1)]^2*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2)/64 + 
     (3*G[{0}, yu^(-1)]*G[{0}, yv^(-1)]*G[{yv^(-1)}, yw]*
       G[{1/(yu*yv)}, yw]^2)/32 + (3*G[{0}, yv^(-1)]^2*G[{yv^(-1)}, yw]*
       G[{1/(yu*yv)}, yw]^2)/64 - (3*G[{0}, yu^(-1)]*G[{0}, yw]*
       G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2)/32 - 
     (3*G[{0}, yv^(-1)]*G[{0}, yw]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2)/
      32 + (3*G[{0}, yw]^2*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2)/64 - 
     (G[{0}, yu^(-1)]*G[{1}, yu^(-1)]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2)/
      8 - (G[{0}, yv^(-1)]*G[{1}, yu^(-1)]*G[{yv^(-1)}, yw]*
       G[{1/(yu*yv)}, yw]^2)/8 + (G[{0}, yw]*G[{1}, yu^(-1)]*G[{yv^(-1)}, yw]*
       G[{1/(yu*yv)}, yw]^2)/8 + (G[{1}, yu^(-1)]^2*G[{yv^(-1)}, yw]*
       G[{1/(yu*yv)}, yw]^2)/16 - (3*G[{0}, yu^(-1)]*G[{1}, yv^(-1)]*
       G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2)/32 - 
     (3*G[{0}, yv^(-1)]*G[{1}, yv^(-1)]*G[{yv^(-1)}, yw]*
       G[{1/(yu*yv)}, yw]^2)/32 + (3*G[{0}, yw]*G[{1}, yv^(-1)]*
       G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2)/32 + 
     (5*G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*G[{yv^(-1)}, yw]*
       G[{1/(yu*yv)}, yw]^2)/32 + (9*G[{1}, yv^(-1)]^2*G[{yv^(-1)}, yw]*
       G[{1/(yu*yv)}, yw]^2)/256 - (3*G[{0}, yu^(-1)]*G[{1}, yw]*
       G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2)/128 - 
     (3*G[{0}, yv^(-1)]*G[{1}, yw]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2)/
      128 + (3*G[{0}, yw]*G[{1}, yw]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2)/
      128 + (3*G[{1}, yu^(-1)]*G[{1}, yw]*G[{yv^(-1)}, yw]*
       G[{1/(yu*yv)}, yw]^2)/128 + (G[{1}, yv^(-1)]*G[{1}, yw]*
       G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2)/32 + 
     (G[{1}, yw]^2*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2)/256 + 
     (11*G[{0}, yu^(-1)]*G[{yu^(-1)}, yw]*G[{yv^(-1)}, yw]*
       G[{1/(yu*yv)}, yw]^2)/128 + (11*G[{0}, yv^(-1)]*G[{yu^(-1)}, yw]*
       G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2)/128 - 
     (11*G[{0}, yw]*G[{yu^(-1)}, yw]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2)/
      128 - (19*G[{1}, yu^(-1)]*G[{yu^(-1)}, yw]*G[{yv^(-1)}, yw]*
       G[{1/(yu*yv)}, yw]^2)/128 - (15*G[{1}, yv^(-1)]*G[{yu^(-1)}, yw]*
       G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2)/128 - 
     (3*G[{1}, yw]*G[{yu^(-1)}, yw]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2)/
      32 + (15*G[{yu^(-1)}, yw]^2*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2)/
      256 + (G[{0}, yu^(-1)]*G[{yu}, yv^(-1)]*G[{yv^(-1)}, yw]*
       G[{1/(yu*yv)}, yw]^2)/32 + (G[{0}, yv^(-1)]*G[{yu}, yv^(-1)]*
       G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2)/32 - 
     (G[{0}, yw]*G[{yu}, yv^(-1)]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2)/32 - 
     (G[{1}, yu^(-1)]*G[{yu}, yv^(-1)]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2)/
      32 - (3*G[{1}, yv^(-1)]*G[{yu}, yv^(-1)]*G[{yv^(-1)}, yw]*
       G[{1/(yu*yv)}, yw]^2)/32 - (G[{1}, yw]*G[{yu}, yv^(-1)]*
       G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2)/128 + 
     (3*G[{yu^(-1)}, yw]*G[{yu}, yv^(-1)]*G[{yv^(-1)}, yw]*
       G[{1/(yu*yv)}, yw]^2)/32 + (G[{yu}, yv^(-1)]^2*G[{yv^(-1)}, yw]*
       G[{1/(yu*yv)}, yw]^2)/32 + (15*G[{0}, yu^(-1)]*G[{yv^(-1)}, yw]^2*
       G[{1/(yu*yv)}, yw]^2)/256 + (15*G[{0}, yv^(-1)]*G[{yv^(-1)}, yw]^2*
       G[{1/(yu*yv)}, yw]^2)/256 - (15*G[{0}, yw]*G[{yv^(-1)}, yw]^2*
       G[{1/(yu*yv)}, yw]^2)/256 - (15*G[{1}, yu^(-1)]*G[{yv^(-1)}, yw]^2*
       G[{1/(yu*yv)}, yw]^2)/256 - (19*G[{1}, yv^(-1)]*G[{yv^(-1)}, yw]^2*
       G[{1/(yu*yv)}, yw]^2)/256 - (G[{1}, yw]*G[{yv^(-1)}, yw]^2*
       G[{1/(yu*yv)}, yw]^2)/64 + (19*G[{yu^(-1)}, yw]*G[{yv^(-1)}, yw]^2*
       G[{1/(yu*yv)}, yw]^2)/256 + (G[{yu}, yv^(-1)]*G[{yv^(-1)}, yw]^2*
       G[{1/(yu*yv)}, yw]^2)/64 + (5*G[{yv^(-1)}, yw]^3*G[{1/(yu*yv)}, yw]^2)/
      256 - (G[{0}, yu^(-1)]*G[{1}, yu^(-1)]*G[{1/(yu*yv)}, yw]^3)/96 - 
     (G[{0}, yv^(-1)]*G[{1}, yu^(-1)]*G[{1/(yu*yv)}, yw]^3)/96 + 
     (G[{0}, yw]*G[{1}, yu^(-1)]*G[{1/(yu*yv)}, yw]^3)/96 + 
     (G[{1}, yu^(-1)]^2*G[{1/(yu*yv)}, yw]^3)/96 + 
     (5*G[{0}, yu^(-1)]*G[{1}, yv^(-1)]*G[{1/(yu*yv)}, yw]^3)/384 + 
     (5*G[{0}, yv^(-1)]*G[{1}, yv^(-1)]*G[{1/(yu*yv)}, yw]^3)/384 - 
     (5*G[{0}, yw]*G[{1}, yv^(-1)]*G[{1/(yu*yv)}, yw]^3)/384 - 
     (3*G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*G[{1/(yu*yv)}, yw]^3)/128 - 
     (5*G[{1}, yv^(-1)]^2*G[{1/(yu*yv)}, yw]^3)/384 + 
     (G[{0}, yu^(-1)]*G[{1}, yw]*G[{1/(yu*yv)}, yw]^3)/384 + 
     (G[{0}, yv^(-1)]*G[{1}, yw]*G[{1/(yu*yv)}, yw]^3)/384 - 
     (G[{0}, yw]*G[{1}, yw]*G[{1/(yu*yv)}, yw]^3)/384 - 
     (3*G[{1}, yu^(-1)]*G[{1}, yw]*G[{1/(yu*yv)}, yw]^3)/128 - 
     (3*G[{1}, yv^(-1)]*G[{1}, yw]*G[{1/(yu*yv)}, yw]^3)/128 - 
     (G[{1}, yw]^2*G[{1/(yu*yv)}, yw]^3)/48 - 
     (5*G[{0}, yu^(-1)]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]^3)/384 - 
     (5*G[{0}, yv^(-1)]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]^3)/384 + 
     (5*G[{0}, yw]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]^3)/384 + 
     (3*G[{1}, yu^(-1)]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]^3)/128 + 
     (5*G[{1}, yv^(-1)]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]^3)/192 + 
     (3*G[{1}, yw]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]^3)/128 - 
     (5*G[{yu^(-1)}, yw]^2*G[{1/(yu*yv)}, yw]^3)/384 - 
     (G[{0}, yu^(-1)]*G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw]^3)/384 - 
     (G[{0}, yv^(-1)]*G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw]^3)/384 + 
     (G[{0}, yw]*G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw]^3)/384 + 
     (3*G[{1}, yu^(-1)]*G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw]^3)/128 + 
     (3*G[{1}, yv^(-1)]*G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw]^3)/128 + 
     (G[{1}, yw]*G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw]^3)/24 - 
     (3*G[{yu^(-1)}, yw]*G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw]^3)/128 - 
     (G[{yu}, yv^(-1)]^2*G[{1/(yu*yv)}, yw]^3)/48 + 
     (G[{0}, yu^(-1)]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]^3)/96 + 
     (G[{0}, yv^(-1)]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]^3)/96 - 
     (G[{0}, yw]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]^3)/96 - 
     (G[{1}, yu^(-1)]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]^3)/48 + 
     (3*G[{1}, yv^(-1)]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]^3)/128 + 
     (3*G[{1}, yw]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]^3)/128 - 
     (3*G[{yu^(-1)}, yw]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]^3)/128 - 
     (3*G[{yu}, yv^(-1)]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]^3)/128 + 
     (G[{yv^(-1)}, yw]^2*G[{1/(yu*yv)}, yw]^3)/96 + 
     (Pi^2*G[{1}, yu^(-1)]*G[{0, 1}, yu^(-1)])/32 + 
     (3*G[{0}, yu^(-1)]^2*G[{1}, yu^(-1)]*G[{0, 1}, yu^(-1)])/32 + 
     (3*G[{0}, yu^(-1)]*G[{0}, yv^(-1)]*G[{1}, yu^(-1)]*G[{0, 1}, yu^(-1)])/
      16 + (3*G[{0}, yv^(-1)]^2*G[{1}, yu^(-1)]*G[{0, 1}, yu^(-1)])/32 - 
     (3*G[{0}, yu^(-1)]*G[{0}, yw]*G[{1}, yu^(-1)]*G[{0, 1}, yu^(-1)])/16 - 
     (3*G[{0}, yv^(-1)]*G[{0}, yw]*G[{1}, yu^(-1)]*G[{0, 1}, yu^(-1)])/16 + 
     (3*G[{0}, yw]^2*G[{1}, yu^(-1)]*G[{0, 1}, yu^(-1)])/32 - 
     (5*G[{0}, yu^(-1)]*G[{1}, yu^(-1)]^2*G[{0, 1}, yu^(-1)])/32 - 
     (5*G[{0}, yv^(-1)]*G[{1}, yu^(-1)]^2*G[{0, 1}, yu^(-1)])/32 + 
     (5*G[{0}, yw]*G[{1}, yu^(-1)]^2*G[{0, 1}, yu^(-1)])/32 + 
     (5*G[{1}, yu^(-1)]^3*G[{0, 1}, yu^(-1)])/96 - 
     (3*G[{0}, yu^(-1)]*G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*G[{0, 1}, yu^(-1)])/
      16 - (3*G[{0}, yv^(-1)]*G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*
       G[{0, 1}, yu^(-1)])/16 + (3*G[{0}, yw]*G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*
       G[{0, 1}, yu^(-1)])/16 + (5*G[{1}, yu^(-1)]^2*G[{1}, yv^(-1)]*
       G[{0, 1}, yu^(-1)])/32 + (G[{1}, yu^(-1)]*G[{1}, yv^(-1)]^2*
       G[{0, 1}, yu^(-1)])/16 - (Pi^2*G[{1}, yw]*G[{0, 1}, yu^(-1)])/32 - 
     (3*G[{0}, yu^(-1)]^2*G[{1}, yw]*G[{0, 1}, yu^(-1)])/32 - 
     (3*G[{0}, yu^(-1)]*G[{0}, yv^(-1)]*G[{1}, yw]*G[{0, 1}, yu^(-1)])/16 - 
     (3*G[{0}, yv^(-1)]^2*G[{1}, yw]*G[{0, 1}, yu^(-1)])/32 + 
     (3*G[{0}, yu^(-1)]*G[{0}, yw]*G[{1}, yw]*G[{0, 1}, yu^(-1)])/16 + 
     (3*G[{0}, yv^(-1)]*G[{0}, yw]*G[{1}, yw]*G[{0, 1}, yu^(-1)])/16 - 
     (3*G[{0}, yw]^2*G[{1}, yw]*G[{0, 1}, yu^(-1)])/32 + 
     (5*G[{0}, yu^(-1)]*G[{1}, yu^(-1)]*G[{1}, yw]*G[{0, 1}, yu^(-1)])/16 + 
     (5*G[{0}, yv^(-1)]*G[{1}, yu^(-1)]*G[{1}, yw]*G[{0, 1}, yu^(-1)])/16 - 
     (5*G[{0}, yw]*G[{1}, yu^(-1)]*G[{1}, yw]*G[{0, 1}, yu^(-1)])/16 - 
     (5*G[{1}, yu^(-1)]^2*G[{1}, yw]*G[{0, 1}, yu^(-1)])/32 + 
     (G[{0}, yu^(-1)]*G[{1}, yv^(-1)]*G[{1}, yw]*G[{0, 1}, yu^(-1)])/16 + 
     (G[{0}, yv^(-1)]*G[{1}, yv^(-1)]*G[{1}, yw]*G[{0, 1}, yu^(-1)])/16 - 
     (G[{0}, yw]*G[{1}, yv^(-1)]*G[{1}, yw]*G[{0, 1}, yu^(-1)])/16 - 
     (G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*G[{1}, yw]*G[{0, 1}, yu^(-1)])/4 - 
     (3*G[{0}, yu^(-1)]*G[{1}, yw]^2*G[{0, 1}, yu^(-1)])/32 - 
     (3*G[{0}, yv^(-1)]*G[{1}, yw]^2*G[{0, 1}, yu^(-1)])/32 + 
     (3*G[{0}, yw]*G[{1}, yw]^2*G[{0, 1}, yu^(-1)])/32 + 
     (3*G[{1}, yu^(-1)]*G[{1}, yw]^2*G[{0, 1}, yu^(-1)])/32 + 
     (G[{1}, yv^(-1)]*G[{1}, yw]^2*G[{0, 1}, yu^(-1)])/32 - 
     (G[{1}, yw]^3*G[{0, 1}, yu^(-1)])/96 + 
     (G[{0}, yu^(-1)]*G[{1}, yw]*G[{yu}, yv^(-1)]*G[{0, 1}, yu^(-1)])/8 + 
     (G[{0}, yv^(-1)]*G[{1}, yw]*G[{yu}, yv^(-1)]*G[{0, 1}, yu^(-1)])/8 - 
     (G[{0}, yw]*G[{1}, yw]*G[{yu}, yv^(-1)]*G[{0, 1}, yu^(-1)])/8 - 
     (G[{1}, yu^(-1)]*G[{1}, yw]*G[{yu}, yv^(-1)]*G[{0, 1}, yu^(-1)])/16 - 
     (G[{1}, yv^(-1)]*G[{1}, yw]*G[{yu}, yv^(-1)]*G[{0, 1}, yu^(-1)])/16 + 
     (G[{1}, yw]^2*G[{yu}, yv^(-1)]*G[{0, 1}, yu^(-1)])/16 - 
     (G[{1}, yw]*G[{yu}, yv^(-1)]^2*G[{0, 1}, yu^(-1)])/16 + 
     (3*G[{0}, yu^(-1)]*G[{1}, yu^(-1)]*G[{1/(yu*yv)}, yw]*
       G[{0, 1}, yu^(-1)])/16 + (3*G[{0}, yv^(-1)]*G[{1}, yu^(-1)]*
       G[{1/(yu*yv)}, yw]*G[{0, 1}, yu^(-1)])/16 - 
     (3*G[{0}, yw]*G[{1}, yu^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, 1}, yu^(-1)])/
      16 - (5*G[{1}, yu^(-1)]^2*G[{1/(yu*yv)}, yw]*G[{0, 1}, yu^(-1)])/32 - 
     (G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, 1}, yu^(-1)])/
      8 + (G[{0}, yu^(-1)]*G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1}, yu^(-1)])/
      8 + (G[{0}, yv^(-1)]*G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1}, yu^(-1)])/
      8 - (G[{0}, yw]*G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1}, yu^(-1)])/8 - 
     (G[{1}, yu^(-1)]*G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1}, yu^(-1)])/16 - 
     (G[{1}, yv^(-1)]*G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1}, yu^(-1)])/16 + 
     (G[{1}, yw]^2*G[{1/(yu*yv)}, yw]*G[{0, 1}, yu^(-1)])/32 + 
     (G[{1}, yu^(-1)]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1}, yu^(-1)])/
      8 + (G[{1}, yw]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1}, yu^(-1)])/
      8 - (G[{0}, yu^(-1)]*G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw]*
       G[{0, 1}, yu^(-1)])/8 - (G[{0}, yv^(-1)]*G[{yu}, yv^(-1)]*
       G[{1/(yu*yv)}, yw]*G[{0, 1}, yu^(-1)])/8 + 
     (G[{0}, yw]*G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, 1}, yu^(-1)])/8 + 
     (G[{1}, yu^(-1)]*G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, 1}, yu^(-1)])/
      16 + (G[{1}, yv^(-1)]*G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw]*
       G[{0, 1}, yu^(-1)])/16 - (G[{1}, yw]*G[{yu}, yv^(-1)]*
       G[{1/(yu*yv)}, yw]*G[{0, 1}, yu^(-1)])/8 - 
     (G[{yu^(-1)}, yw]*G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw]*
       G[{0, 1}, yu^(-1)])/8 + (G[{yu}, yv^(-1)]^2*G[{1/(yu*yv)}, yw]*
       G[{0, 1}, yu^(-1)])/16 - (3*G[{0}, yu^(-1)]*G[{yv^(-1)}, yw]*
       G[{1/(yu*yv)}, yw]*G[{0, 1}, yu^(-1)])/16 - 
     (3*G[{0}, yv^(-1)]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*
       G[{0, 1}, yu^(-1)])/16 + (3*G[{0}, yw]*G[{yv^(-1)}, yw]*
       G[{1/(yu*yv)}, yw]*G[{0, 1}, yu^(-1)])/16 + 
     (5*G[{1}, yu^(-1)]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*
       G[{0, 1}, yu^(-1)])/16 + (G[{1}, yv^(-1)]*G[{yv^(-1)}, yw]*
       G[{1/(yu*yv)}, yw]*G[{0, 1}, yu^(-1)])/16 + 
     (G[{1}, yw]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1}, yu^(-1)])/16 - 
     (G[{yu^(-1)}, yw]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*
       G[{0, 1}, yu^(-1)])/8 - (G[{yv^(-1)}, yw]^2*G[{1/(yu*yv)}, yw]*
       G[{0, 1}, yu^(-1)])/8 - (G[{0}, yu^(-1)]*G[{0, 1}, yu^(-1)]^2)/32 - 
     (G[{0}, yv^(-1)]*G[{0, 1}, yu^(-1)]^2)/32 + 
     (G[{0}, yw]*G[{0, 1}, yu^(-1)]^2)/32 + 
     (G[{1}, yu^(-1)]*G[{0, 1}, yu^(-1)]^2)/16 + 
     (G[{1}, yv^(-1)]*G[{0, 1}, yu^(-1)]^2)/32 - 
     (G[{1}, yw]*G[{0, 1}, yu^(-1)]^2)/16 - 
     (G[{1/(yu*yv)}, yw]*G[{0, 1}, yu^(-1)]^2)/32 - 
     (Pi^2*G[{0}, yu^(-1)]*G[{0, 1}, yv^(-1)])/384 + 
     (3*G[{0}, yu^(-1)]^3*G[{0, 1}, yv^(-1)])/128 - 
     (Pi^2*G[{0}, yv^(-1)]*G[{0, 1}, yv^(-1)])/384 + 
     (9*G[{0}, yu^(-1)]^2*G[{0}, yv^(-1)]*G[{0, 1}, yv^(-1)])/128 + 
     (9*G[{0}, yu^(-1)]*G[{0}, yv^(-1)]^2*G[{0, 1}, yv^(-1)])/128 + 
     (3*G[{0}, yv^(-1)]^3*G[{0, 1}, yv^(-1)])/128 + 
     (Pi^2*G[{0}, yw]*G[{0, 1}, yv^(-1)])/384 - 
     (9*G[{0}, yu^(-1)]^2*G[{0}, yw]*G[{0, 1}, yv^(-1)])/128 - 
     (9*G[{0}, yu^(-1)]*G[{0}, yv^(-1)]*G[{0}, yw]*G[{0, 1}, yv^(-1)])/64 - 
     (9*G[{0}, yv^(-1)]^2*G[{0}, yw]*G[{0, 1}, yv^(-1)])/128 + 
     (9*G[{0}, yu^(-1)]*G[{0}, yw]^2*G[{0, 1}, yv^(-1)])/128 + 
     (9*G[{0}, yv^(-1)]*G[{0}, yw]^2*G[{0, 1}, yv^(-1)])/128 - 
     (3*G[{0}, yw]^3*G[{0, 1}, yv^(-1)])/128 + 
     (3*Pi^2*G[{1}, yu^(-1)]*G[{0, 1}, yv^(-1)])/128 + 
     (3*G[{0}, yu^(-1)]^2*G[{1}, yu^(-1)]*G[{0, 1}, yv^(-1)])/128 + 
     (3*G[{0}, yu^(-1)]*G[{0}, yv^(-1)]*G[{1}, yu^(-1)]*G[{0, 1}, yv^(-1)])/
      64 + (3*G[{0}, yv^(-1)]^2*G[{1}, yu^(-1)]*G[{0, 1}, yv^(-1)])/128 - 
     (3*G[{0}, yu^(-1)]*G[{0}, yw]*G[{1}, yu^(-1)]*G[{0, 1}, yv^(-1)])/64 - 
     (3*G[{0}, yv^(-1)]*G[{0}, yw]*G[{1}, yu^(-1)]*G[{0, 1}, yv^(-1)])/64 + 
     (3*G[{0}, yw]^2*G[{1}, yu^(-1)]*G[{0, 1}, yv^(-1)])/128 - 
     (11*G[{0}, yu^(-1)]*G[{1}, yu^(-1)]^2*G[{0, 1}, yv^(-1)])/128 - 
     (11*G[{0}, yv^(-1)]*G[{1}, yu^(-1)]^2*G[{0, 1}, yv^(-1)])/128 + 
     (11*G[{0}, yw]*G[{1}, yu^(-1)]^2*G[{0, 1}, yv^(-1)])/128 + 
     (5*G[{1}, yu^(-1)]^3*G[{0, 1}, yv^(-1)])/128 + 
     (Pi^2*G[{1}, yv^(-1)]*G[{0, 1}, yv^(-1)])/384 - 
     (5*G[{0}, yu^(-1)]^2*G[{1}, yv^(-1)]*G[{0, 1}, yv^(-1)])/128 - 
     (5*G[{0}, yu^(-1)]*G[{0}, yv^(-1)]*G[{1}, yv^(-1)]*G[{0, 1}, yv^(-1)])/
      64 - (5*G[{0}, yv^(-1)]^2*G[{1}, yv^(-1)]*G[{0, 1}, yv^(-1)])/128 + 
     (5*G[{0}, yu^(-1)]*G[{0}, yw]*G[{1}, yv^(-1)]*G[{0, 1}, yv^(-1)])/64 + 
     (5*G[{0}, yv^(-1)]*G[{0}, yw]*G[{1}, yv^(-1)]*G[{0, 1}, yv^(-1)])/64 - 
     (5*G[{0}, yw]^2*G[{1}, yv^(-1)]*G[{0, 1}, yv^(-1)])/128 + 
     (G[{0}, yu^(-1)]*G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*G[{0, 1}, yv^(-1)])/
      64 + (G[{0}, yv^(-1)]*G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*
       G[{0, 1}, yv^(-1)])/64 - (G[{0}, yw]*G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*
       G[{0, 1}, yv^(-1)])/64 - (G[{1}, yu^(-1)]^2*G[{1}, yv^(-1)]*
       G[{0, 1}, yv^(-1)])/128 + (5*G[{0}, yu^(-1)]*G[{1}, yv^(-1)]^2*
       G[{0, 1}, yv^(-1)])/128 + (5*G[{0}, yv^(-1)]*G[{1}, yv^(-1)]^2*
       G[{0, 1}, yv^(-1)])/128 - (5*G[{0}, yw]*G[{1}, yv^(-1)]^2*
       G[{0, 1}, yv^(-1)])/128 - (5*G[{1}, yu^(-1)]*G[{1}, yv^(-1)]^2*
       G[{0, 1}, yv^(-1)])/128 - (5*G[{1}, yv^(-1)]^3*G[{0, 1}, yv^(-1)])/
      384 - (Pi^2*G[{1}, yw]*G[{0, 1}, yv^(-1)])/384 + 
     (G[{0}, yu^(-1)]^2*G[{1}, yw]*G[{0, 1}, yv^(-1)])/128 + 
     (G[{0}, yu^(-1)]*G[{0}, yv^(-1)]*G[{1}, yw]*G[{0, 1}, yv^(-1)])/64 + 
     (G[{0}, yv^(-1)]^2*G[{1}, yw]*G[{0, 1}, yv^(-1)])/128 - 
     (G[{0}, yu^(-1)]*G[{0}, yw]*G[{1}, yw]*G[{0, 1}, yv^(-1)])/64 - 
     (G[{0}, yv^(-1)]*G[{0}, yw]*G[{1}, yw]*G[{0, 1}, yv^(-1)])/64 + 
     (G[{0}, yw]^2*G[{1}, yw]*G[{0, 1}, yv^(-1)])/128 + 
     (7*G[{0}, yu^(-1)]*G[{1}, yu^(-1)]*G[{1}, yw]*G[{0, 1}, yv^(-1)])/64 + 
     (7*G[{0}, yv^(-1)]*G[{1}, yu^(-1)]*G[{1}, yw]*G[{0, 1}, yv^(-1)])/64 - 
     (7*G[{0}, yw]*G[{1}, yu^(-1)]*G[{1}, yw]*G[{0, 1}, yv^(-1)])/64 - 
     (15*G[{1}, yu^(-1)]^2*G[{1}, yw]*G[{0, 1}, yv^(-1)])/128 - 
     (G[{0}, yu^(-1)]*G[{1}, yv^(-1)]*G[{1}, yw]*G[{0, 1}, yv^(-1)])/64 - 
     (G[{0}, yv^(-1)]*G[{1}, yv^(-1)]*G[{1}, yw]*G[{0, 1}, yv^(-1)])/64 + 
     (G[{0}, yw]*G[{1}, yv^(-1)]*G[{1}, yw]*G[{0, 1}, yv^(-1)])/64 - 
     (3*G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*G[{1}, yw]*G[{0, 1}, yv^(-1)])/64 + 
     (5*G[{1}, yv^(-1)]^2*G[{1}, yw]*G[{0, 1}, yv^(-1)])/128 - 
     (9*G[{0}, yu^(-1)]*G[{1}, yw]^2*G[{0, 1}, yv^(-1)])/128 - 
     (9*G[{0}, yv^(-1)]*G[{1}, yw]^2*G[{0, 1}, yv^(-1)])/128 + 
     (9*G[{0}, yw]*G[{1}, yw]^2*G[{0, 1}, yv^(-1)])/128 + 
     (9*G[{1}, yu^(-1)]*G[{1}, yw]^2*G[{0, 1}, yv^(-1)])/128 + 
     (5*G[{1}, yv^(-1)]*G[{1}, yw]^2*G[{0, 1}, yv^(-1)])/128 - 
     (G[{1}, yw]^3*G[{0, 1}, yv^(-1)])/96 - 
     (G[{0}, yu^(-1)]*G[{1}, yw]*G[{yu}, yv^(-1)]*G[{0, 1}, yv^(-1)])/16 - 
     (G[{0}, yv^(-1)]*G[{1}, yw]*G[{yu}, yv^(-1)]*G[{0, 1}, yv^(-1)])/16 + 
     (G[{0}, yw]*G[{1}, yw]*G[{yu}, yv^(-1)]*G[{0, 1}, yv^(-1)])/16 + 
     (G[{1}, yv^(-1)]*G[{1}, yw]*G[{yu}, yv^(-1)]*G[{0, 1}, yv^(-1)])/16 + 
     (G[{1}, yw]*G[{yu}, yv^(-1)]^2*G[{0, 1}, yv^(-1)])/16 - 
     (Pi^2*G[{1/(yu*yv)}, yw]*G[{0, 1}, yv^(-1)])/384 + 
     (5*G[{0}, yu^(-1)]^2*G[{1/(yu*yv)}, yw]*G[{0, 1}, yv^(-1)])/128 + 
     (5*G[{0}, yu^(-1)]*G[{0}, yv^(-1)]*G[{1/(yu*yv)}, yw]*
       G[{0, 1}, yv^(-1)])/64 + (5*G[{0}, yv^(-1)]^2*G[{1/(yu*yv)}, yw]*
       G[{0, 1}, yv^(-1)])/128 - (5*G[{0}, yu^(-1)]*G[{0}, yw]*
       G[{1/(yu*yv)}, yw]*G[{0, 1}, yv^(-1)])/64 - 
     (5*G[{0}, yv^(-1)]*G[{0}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1}, yv^(-1)])/
      64 + (5*G[{0}, yw]^2*G[{1/(yu*yv)}, yw]*G[{0, 1}, yv^(-1)])/128 - 
     (G[{0}, yu^(-1)]*G[{1}, yu^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, 1}, yv^(-1)])/
      64 - (G[{0}, yv^(-1)]*G[{1}, yu^(-1)]*G[{1/(yu*yv)}, yw]*
       G[{0, 1}, yv^(-1)])/64 + (G[{0}, yw]*G[{1}, yu^(-1)]*
       G[{1/(yu*yv)}, yw]*G[{0, 1}, yv^(-1)])/64 + 
     (G[{1}, yu^(-1)]^2*G[{1/(yu*yv)}, yw]*G[{0, 1}, yv^(-1)])/128 - 
     (5*G[{0}, yu^(-1)]*G[{1}, yv^(-1)]*G[{1/(yu*yv)}, yw]*
       G[{0, 1}, yv^(-1)])/64 - (5*G[{0}, yv^(-1)]*G[{1}, yv^(-1)]*
       G[{1/(yu*yv)}, yw]*G[{0, 1}, yv^(-1)])/64 + 
     (5*G[{0}, yw]*G[{1}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, 1}, yv^(-1)])/
      64 + (5*G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*G[{1/(yu*yv)}, yw]*
       G[{0, 1}, yv^(-1)])/64 + (5*G[{1}, yv^(-1)]^2*G[{1/(yu*yv)}, yw]*
       G[{0, 1}, yv^(-1)])/128 + (3*G[{0}, yu^(-1)]*G[{1}, yw]*
       G[{1/(yu*yv)}, yw]*G[{0, 1}, yv^(-1)])/64 + 
     (3*G[{0}, yv^(-1)]*G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1}, yv^(-1)])/
      64 - (3*G[{0}, yw]*G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1}, yv^(-1)])/
      64 + (G[{1}, yu^(-1)]*G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1}, yv^(-1)])/
      64 - (3*G[{1}, yv^(-1)]*G[{1}, yw]*G[{1/(yu*yv)}, yw]*
       G[{0, 1}, yv^(-1)])/64 + (G[{1}, yw]^2*G[{1/(yu*yv)}, yw]*
       G[{0, 1}, yv^(-1)])/32 + (3*G[{0}, yu^(-1)]*G[{yu^(-1)}, yw]*
       G[{1/(yu*yv)}, yw]*G[{0, 1}, yv^(-1)])/32 + 
     (3*G[{0}, yv^(-1)]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*
       G[{0, 1}, yv^(-1)])/32 - (3*G[{0}, yw]*G[{yu^(-1)}, yw]*
       G[{1/(yu*yv)}, yw]*G[{0, 1}, yv^(-1)])/32 + 
     (G[{1}, yu^(-1)]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1}, yv^(-1)])/
      32 - (3*G[{1}, yv^(-1)]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*
       G[{0, 1}, yv^(-1)])/32 + (G[{1}, yw]*G[{yu^(-1)}, yw]*
       G[{1/(yu*yv)}, yw]*G[{0, 1}, yv^(-1)])/8 + 
     (7*G[{yu^(-1)}, yw]^2*G[{1/(yu*yv)}, yw]*G[{0, 1}, yv^(-1)])/64 + 
     (G[{0}, yu^(-1)]*G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, 1}, yv^(-1)])/
      16 + (G[{0}, yv^(-1)]*G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw]*
       G[{0, 1}, yv^(-1)])/16 - (G[{0}, yw]*G[{yu}, yv^(-1)]*
       G[{1/(yu*yv)}, yw]*G[{0, 1}, yv^(-1)])/16 - 
     (G[{1}, yv^(-1)]*G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, 1}, yv^(-1)])/
      16 - (G[{yu}, yv^(-1)]^2*G[{1/(yu*yv)}, yw]*G[{0, 1}, yv^(-1)])/16 - 
     (G[{0}, yu^(-1)]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1}, yv^(-1)])/
      32 - (G[{0}, yv^(-1)]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*
       G[{0, 1}, yv^(-1)])/32 + (G[{0}, yw]*G[{yv^(-1)}, yw]*
       G[{1/(yu*yv)}, yw]*G[{0, 1}, yv^(-1)])/32 + 
     (G[{1}, yu^(-1)]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1}, yv^(-1)])/
      32 - (G[{1}, yv^(-1)]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*
       G[{0, 1}, yv^(-1)])/32 - (G[{1}, yw]*G[{yv^(-1)}, yw]*
       G[{1/(yu*yv)}, yw]*G[{0, 1}, yv^(-1)])/16 - 
     (G[{yu^(-1)}, yw]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*
       G[{0, 1}, yv^(-1)])/32 - (G[{yv^(-1)}, yw]^2*G[{1/(yu*yv)}, yw]*
       G[{0, 1}, yv^(-1)])/64 - (G[{0}, yu^(-1)]*G[{1/(yu*yv)}, yw]^2*
       G[{0, 1}, yv^(-1)])/128 - (G[{0}, yv^(-1)]*G[{1/(yu*yv)}, yw]^2*
       G[{0, 1}, yv^(-1)])/128 + (G[{0}, yw]*G[{1/(yu*yv)}, yw]^2*
       G[{0, 1}, yv^(-1)])/128 - (7*G[{1}, yu^(-1)]*G[{1/(yu*yv)}, yw]^2*
       G[{0, 1}, yv^(-1)])/128 + (G[{1}, yv^(-1)]*G[{1/(yu*yv)}, yw]^2*
       G[{0, 1}, yv^(-1)])/128 - (G[{1}, yw]*G[{1/(yu*yv)}, yw]^2*
       G[{0, 1}, yv^(-1)])/16 - (G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2*
       G[{0, 1}, yv^(-1)])/128 + (G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw]^2*
       G[{0, 1}, yv^(-1)])/16 + (7*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2*
       G[{0, 1}, yv^(-1)])/128 + (G[{1}, yu^(-1)]*G[{0, 1}, yu^(-1)]*
       G[{0, 1}, yv^(-1)])/16 - (G[{0}, yu^(-1)]*G[{0, 1}, yv^(-1)]^2)/32 - 
     (G[{0}, yv^(-1)]*G[{0, 1}, yv^(-1)]^2)/32 + 
     (G[{0}, yw]*G[{0, 1}, yv^(-1)]^2)/32 + 
     (G[{1}, yv^(-1)]*G[{0, 1}, yv^(-1)]^2)/32 - 
     (G[{1}, yw]*G[{0, 1}, yv^(-1)]^2)/16 - 
     (G[{1/(yu*yv)}, yw]*G[{0, 1}, yv^(-1)]^2)/32 - 
     (7*Pi^2*G[{0}, yu^(-1)]*G[{0, 1}, yw])/256 - 
     (7*Pi^2*G[{0}, yv^(-1)]*G[{0, 1}, yw])/256 + 
     (7*Pi^2*G[{0}, yw]*G[{0, 1}, yw])/256 + 
     (29*Pi^2*G[{1}, yu^(-1)]*G[{0, 1}, yw])/768 + 
     (5*Pi^2*G[{1}, yv^(-1)]*G[{0, 1}, yw])/768 - 
     (3*G[{0}, yu^(-1)]^2*G[{1}, yv^(-1)]*G[{0, 1}, yw])/32 - 
     (3*G[{0}, yu^(-1)]*G[{0}, yv^(-1)]*G[{1}, yv^(-1)]*G[{0, 1}, yw])/16 - 
     (3*G[{0}, yv^(-1)]^2*G[{1}, yv^(-1)]*G[{0, 1}, yw])/32 + 
     (3*G[{0}, yu^(-1)]*G[{0}, yw]*G[{1}, yv^(-1)]*G[{0, 1}, yw])/16 + 
     (3*G[{0}, yv^(-1)]*G[{0}, yw]*G[{1}, yv^(-1)]*G[{0, 1}, yw])/16 - 
     (3*G[{0}, yw]^2*G[{1}, yv^(-1)]*G[{0, 1}, yw])/32 + 
     (G[{1}, yu^(-1)]^2*G[{1}, yv^(-1)]*G[{0, 1}, yw])/16 + 
     (9*G[{0}, yu^(-1)]*G[{1}, yv^(-1)]^2*G[{0, 1}, yw])/64 + 
     (9*G[{0}, yv^(-1)]*G[{1}, yv^(-1)]^2*G[{0, 1}, yw])/64 - 
     (9*G[{0}, yw]*G[{1}, yv^(-1)]^2*G[{0, 1}, yw])/64 - 
     (5*G[{1}, yu^(-1)]*G[{1}, yv^(-1)]^2*G[{0, 1}, yw])/64 - 
     (3*G[{1}, yv^(-1)]^3*G[{0, 1}, yw])/64 - 
     (23*Pi^2*G[{1}, yw]*G[{0, 1}, yw])/768 - 
     (3*G[{0}, yu^(-1)]^2*G[{1}, yw]*G[{0, 1}, yw])/64 - 
     (3*G[{0}, yu^(-1)]*G[{0}, yv^(-1)]*G[{1}, yw]*G[{0, 1}, yw])/32 - 
     (3*G[{0}, yv^(-1)]^2*G[{1}, yw]*G[{0, 1}, yw])/64 + 
     (3*G[{0}, yu^(-1)]*G[{0}, yw]*G[{1}, yw]*G[{0, 1}, yw])/32 + 
     (3*G[{0}, yv^(-1)]*G[{0}, yw]*G[{1}, yw]*G[{0, 1}, yw])/32 - 
     (3*G[{0}, yw]^2*G[{1}, yw]*G[{0, 1}, yw])/64 + 
     (3*G[{0}, yu^(-1)]*G[{1}, yu^(-1)]*G[{1}, yw]*G[{0, 1}, yw])/32 + 
     (3*G[{0}, yv^(-1)]*G[{1}, yu^(-1)]*G[{1}, yw]*G[{0, 1}, yw])/32 - 
     (3*G[{0}, yw]*G[{1}, yu^(-1)]*G[{1}, yw]*G[{0, 1}, yw])/32 - 
     (3*G[{1}, yu^(-1)]^2*G[{1}, yw]*G[{0, 1}, yw])/64 - 
     (G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*G[{1}, yw]*G[{0, 1}, yw])/8 + 
     (3*G[{1}, yv^(-1)]^2*G[{1}, yw]*G[{0, 1}, yw])/128 - 
     (7*G[{0}, yu^(-1)]*G[{1}, yw]^2*G[{0, 1}, yw])/128 - 
     (7*G[{0}, yv^(-1)]*G[{1}, yw]^2*G[{0, 1}, yw])/128 + 
     (7*G[{0}, yw]*G[{1}, yw]^2*G[{0, 1}, yw])/128 + 
     (7*G[{1}, yu^(-1)]*G[{1}, yw]^2*G[{0, 1}, yw])/128 + 
     (9*G[{1}, yv^(-1)]*G[{1}, yw]^2*G[{0, 1}, yw])/128 + 
     (G[{1}, yw]^3*G[{0, 1}, yw])/128 + (Pi^2*G[{yu}, yv^(-1)]*G[{0, 1}, yw])/
      48 + (3*G[{0}, yu^(-1)]^2*G[{yu}, yv^(-1)]*G[{0, 1}, yw])/32 + 
     (3*G[{0}, yu^(-1)]*G[{0}, yv^(-1)]*G[{yu}, yv^(-1)]*G[{0, 1}, yw])/16 + 
     (3*G[{0}, yv^(-1)]^2*G[{yu}, yv^(-1)]*G[{0, 1}, yw])/32 - 
     (3*G[{0}, yu^(-1)]*G[{0}, yw]*G[{yu}, yv^(-1)]*G[{0, 1}, yw])/16 - 
     (3*G[{0}, yv^(-1)]*G[{0}, yw]*G[{yu}, yv^(-1)]*G[{0, 1}, yw])/16 + 
     (3*G[{0}, yw]^2*G[{yu}, yv^(-1)]*G[{0, 1}, yw])/32 - 
     (G[{1}, yu^(-1)]^2*G[{yu}, yv^(-1)]*G[{0, 1}, yw])/16 - 
     (G[{0}, yu^(-1)]*G[{1}, yv^(-1)]*G[{yu}, yv^(-1)]*G[{0, 1}, yw])/8 - 
     (G[{0}, yv^(-1)]*G[{1}, yv^(-1)]*G[{yu}, yv^(-1)]*G[{0, 1}, yw])/8 + 
     (G[{0}, yw]*G[{1}, yv^(-1)]*G[{yu}, yv^(-1)]*G[{0, 1}, yw])/8 + 
     (G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*G[{yu}, yv^(-1)]*G[{0, 1}, yw])/8 + 
     (G[{1}, yv^(-1)]^2*G[{yu}, yv^(-1)]*G[{0, 1}, yw])/32 + 
     (3*G[{0}, yu^(-1)]*G[{1}, yw]*G[{yu}, yv^(-1)]*G[{0, 1}, yw])/32 + 
     (3*G[{0}, yv^(-1)]*G[{1}, yw]*G[{yu}, yv^(-1)]*G[{0, 1}, yw])/32 - 
     (3*G[{0}, yw]*G[{1}, yw]*G[{yu}, yv^(-1)]*G[{0, 1}, yw])/32 + 
     (G[{1}, yu^(-1)]*G[{1}, yw]*G[{yu}, yv^(-1)]*G[{0, 1}, yw])/32 + 
     (3*G[{1}, yv^(-1)]*G[{1}, yw]*G[{yu}, yv^(-1)]*G[{0, 1}, yw])/32 - 
     (G[{1}, yw]^2*G[{yu}, yv^(-1)]*G[{0, 1}, yw])/64 - 
     (G[{0}, yu^(-1)]*G[{yu}, yv^(-1)]^2*G[{0, 1}, yw])/8 - 
     (G[{0}, yv^(-1)]*G[{yu}, yv^(-1)]^2*G[{0, 1}, yw])/8 + 
     (G[{0}, yw]*G[{yu}, yv^(-1)]^2*G[{0, 1}, yw])/8 + 
     (G[{1}, yv^(-1)]*G[{yu}, yv^(-1)]^2*G[{0, 1}, yw])/8 - 
     (5*G[{1}, yw]*G[{yu}, yv^(-1)]^2*G[{0, 1}, yw])/32 + 
     (G[{yu}, yv^(-1)]^3*G[{0, 1}, yw])/24 + 
     (3*Pi^2*G[{1/(yu*yv)}, yw]*G[{0, 1}, yw])/256 + 
     (3*G[{0}, yu^(-1)]^2*G[{1/(yu*yv)}, yw]*G[{0, 1}, yw])/64 + 
     (3*G[{0}, yu^(-1)]*G[{0}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, 1}, yw])/
      32 + (3*G[{0}, yv^(-1)]^2*G[{1/(yu*yv)}, yw]*G[{0, 1}, yw])/64 - 
     (3*G[{0}, yu^(-1)]*G[{0}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1}, yw])/32 - 
     (3*G[{0}, yv^(-1)]*G[{0}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1}, yw])/32 + 
     (3*G[{0}, yw]^2*G[{1/(yu*yv)}, yw]*G[{0, 1}, yw])/64 - 
     (5*G[{0}, yu^(-1)]*G[{1}, yu^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, 1}, yw])/
      32 - (5*G[{0}, yv^(-1)]*G[{1}, yu^(-1)]*G[{1/(yu*yv)}, yw]*
       G[{0, 1}, yw])/32 + (5*G[{0}, yw]*G[{1}, yu^(-1)]*G[{1/(yu*yv)}, yw]*
       G[{0, 1}, yw])/32 + (5*G[{1}, yu^(-1)]^2*G[{1/(yu*yv)}, yw]*
       G[{0, 1}, yw])/64 - (G[{0}, yu^(-1)]*G[{1}, yv^(-1)]*
       G[{1/(yu*yv)}, yw]*G[{0, 1}, yw])/8 - 
     (G[{0}, yv^(-1)]*G[{1}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, 1}, yw])/8 + 
     (G[{0}, yw]*G[{1}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, 1}, yw])/8 + 
     (3*G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, 1}, yw])/
      16 + (7*G[{1}, yv^(-1)]^2*G[{1/(yu*yv)}, yw]*G[{0, 1}, yw])/128 + 
     (G[{0}, yu^(-1)]*G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1}, yw])/64 + 
     (G[{0}, yv^(-1)]*G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1}, yw])/64 - 
     (G[{0}, yw]*G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1}, yw])/64 - 
     (5*G[{1}, yu^(-1)]*G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1}, yw])/64 + 
     (3*G[{1}, yv^(-1)]*G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1}, yw])/64 - 
     (G[{1}, yw]^2*G[{1/(yu*yv)}, yw]*G[{0, 1}, yw])/128 - 
     (G[{0}, yu^(-1)]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1}, yw])/32 - 
     (G[{0}, yv^(-1)]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1}, yw])/32 + 
     (G[{0}, yw]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1}, yw])/32 - 
     (3*G[{1}, yu^(-1)]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1}, yw])/
      32 + (3*G[{1}, yv^(-1)]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*
       G[{0, 1}, yw])/32 - (9*G[{1}, yw]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*
       G[{0, 1}, yw])/64 - (3*G[{yu^(-1)}, yw]^2*G[{1/(yu*yv)}, yw]*
       G[{0, 1}, yw])/32 + (3*G[{0}, yu^(-1)]*G[{yu}, yv^(-1)]*
       G[{1/(yu*yv)}, yw]*G[{0, 1}, yw])/32 + 
     (3*G[{0}, yv^(-1)]*G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, 1}, yw])/
      32 - (3*G[{0}, yw]*G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, 1}, yw])/
      32 - (G[{1}, yu^(-1)]*G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw]*
       G[{0, 1}, yw])/32 - (3*G[{1}, yv^(-1)]*G[{yu}, yv^(-1)]*
       G[{1/(yu*yv)}, yw]*G[{0, 1}, yw])/32 + 
     (G[{yu^(-1)}, yw]*G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, 1}, yw])/
      16 - (G[{yu}, yv^(-1)]^2*G[{1/(yu*yv)}, yw]*G[{0, 1}, yw])/32 - 
     (G[{1}, yu^(-1)]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1}, yw])/16 + 
     (G[{1}, yv^(-1)]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1}, yw])/16 + 
     (G[{1}, yw]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1}, yw])/32 + 
     (G[{yv^(-1)}, yw]^2*G[{1/(yu*yv)}, yw]*G[{0, 1}, yw])/16 + 
     (3*G[{0}, yu^(-1)]*G[{1/(yu*yv)}, yw]^2*G[{0, 1}, yw])/128 + 
     (3*G[{0}, yv^(-1)]*G[{1/(yu*yv)}, yw]^2*G[{0, 1}, yw])/128 - 
     (3*G[{0}, yw]*G[{1/(yu*yv)}, yw]^2*G[{0, 1}, yw])/128 - 
     (7*G[{1}, yu^(-1)]*G[{1/(yu*yv)}, yw]^2*G[{0, 1}, yw])/128 + 
     (3*G[{1}, yv^(-1)]*G[{1/(yu*yv)}, yw]^2*G[{0, 1}, yw])/128 + 
     (G[{1}, yw]*G[{1/(yu*yv)}, yw]^2*G[{0, 1}, yw])/64 - 
     (9*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2*G[{0, 1}, yw])/128 - 
     (G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw]^2*G[{0, 1}, yw])/64 + 
     (G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2*G[{0, 1}, yw])/128 - 
     (3*G[{0}, yu^(-1)]*G[{0, 1}, yu^(-1)]*G[{0, 1}, yw])/16 - 
     (3*G[{0}, yv^(-1)]*G[{0, 1}, yu^(-1)]*G[{0, 1}, yw])/16 + 
     (3*G[{0}, yw]*G[{0, 1}, yu^(-1)]*G[{0, 1}, yw])/16 + 
     (G[{1}, yu^(-1)]*G[{0, 1}, yu^(-1)]*G[{0, 1}, yw])/4 + 
     (G[{1}, yv^(-1)]*G[{0, 1}, yu^(-1)]*G[{0, 1}, yw])/16 - 
     (G[{1}, yw]*G[{0, 1}, yu^(-1)]*G[{0, 1}, yw])/8 + 
     (G[{yu}, yv^(-1)]*G[{0, 1}, yu^(-1)]*G[{0, 1}, yw])/8 + 
     (G[{0}, yu^(-1)]*G[{0, 1}, yv^(-1)]*G[{0, 1}, yw])/32 + 
     (G[{0}, yv^(-1)]*G[{0, 1}, yv^(-1)]*G[{0, 1}, yw])/32 - 
     (G[{0}, yw]*G[{0, 1}, yv^(-1)]*G[{0, 1}, yw])/32 + 
     (G[{1}, yu^(-1)]*G[{0, 1}, yv^(-1)]*G[{0, 1}, yw])/32 - 
     (G[{1}, yv^(-1)]*G[{0, 1}, yv^(-1)]*G[{0, 1}, yw])/32 - 
     (9*G[{1}, yw]*G[{0, 1}, yv^(-1)]*G[{0, 1}, yw])/64 - 
     (G[{yu}, yv^(-1)]*G[{0, 1}, yv^(-1)]*G[{0, 1}, yw])/16 + 
     (3*G[{1/(yu*yv)}, yw]*G[{0, 1}, yv^(-1)]*G[{0, 1}, yw])/64 + 
     (G[{0}, yu^(-1)]*G[{0, 1}, yw]^2)/32 + (G[{0}, yv^(-1)]*G[{0, 1}, yw]^2)/
      32 - (G[{0}, yw]*G[{0, 1}, yw]^2)/32 - 
     (G[{1}, yu^(-1)]*G[{0, 1}, yw]^2)/32 + (7*G[{1}, yw]*G[{0, 1}, yw]^2)/
      128 - (G[{yu}, yv^(-1)]*G[{0, 1}, yw]^2)/32 - 
     (G[{1/(yu*yv)}, yw]*G[{0, 1}, yw]^2)/128 - 
     (Pi^2*G[{0}, yu^(-1)]*G[{0, yu^(-1)}, yw])/256 - 
     (Pi^2*G[{0}, yv^(-1)]*G[{0, yu^(-1)}, yw])/256 + 
     (Pi^2*G[{0}, yw]*G[{0, yu^(-1)}, yw])/256 - 
     (13*Pi^2*G[{1}, yu^(-1)]*G[{0, yu^(-1)}, yw])/768 + 
     (Pi^2*G[{1}, yv^(-1)]*G[{0, yu^(-1)}, yw])/256 + 
     (3*G[{0}, yu^(-1)]*G[{1}, yv^(-1)]^2*G[{0, yu^(-1)}, yw])/64 + 
     (3*G[{0}, yv^(-1)]*G[{1}, yv^(-1)]^2*G[{0, yu^(-1)}, yw])/64 - 
     (3*G[{0}, yw]*G[{1}, yv^(-1)]^2*G[{0, yu^(-1)}, yw])/64 + 
     (G[{1}, yu^(-1)]*G[{1}, yv^(-1)]^2*G[{0, yu^(-1)}, yw])/64 - 
     (3*G[{1}, yv^(-1)]^3*G[{0, yu^(-1)}, yw])/64 + 
     (7*Pi^2*G[{1}, yw]*G[{0, yu^(-1)}, yw])/768 + 
     (3*G[{0}, yu^(-1)]^2*G[{1}, yw]*G[{0, yu^(-1)}, yw])/64 + 
     (3*G[{0}, yu^(-1)]*G[{0}, yv^(-1)]*G[{1}, yw]*G[{0, yu^(-1)}, yw])/32 + 
     (3*G[{0}, yv^(-1)]^2*G[{1}, yw]*G[{0, yu^(-1)}, yw])/64 - 
     (3*G[{0}, yu^(-1)]*G[{0}, yw]*G[{1}, yw]*G[{0, yu^(-1)}, yw])/32 - 
     (3*G[{0}, yv^(-1)]*G[{0}, yw]*G[{1}, yw]*G[{0, yu^(-1)}, yw])/32 + 
     (3*G[{0}, yw]^2*G[{1}, yw]*G[{0, yu^(-1)}, yw])/64 - 
     (3*G[{0}, yu^(-1)]*G[{1}, yu^(-1)]*G[{1}, yw]*G[{0, yu^(-1)}, yw])/32 - 
     (3*G[{0}, yv^(-1)]*G[{1}, yu^(-1)]*G[{1}, yw]*G[{0, yu^(-1)}, yw])/32 + 
     (3*G[{0}, yw]*G[{1}, yu^(-1)]*G[{1}, yw]*G[{0, yu^(-1)}, yw])/32 + 
     (3*G[{1}, yu^(-1)]^2*G[{1}, yw]*G[{0, yu^(-1)}, yw])/64 - 
     (G[{0}, yu^(-1)]*G[{1}, yv^(-1)]*G[{1}, yw]*G[{0, yu^(-1)}, yw])/8 - 
     (G[{0}, yv^(-1)]*G[{1}, yv^(-1)]*G[{1}, yw]*G[{0, yu^(-1)}, yw])/8 + 
     (G[{0}, yw]*G[{1}, yv^(-1)]*G[{1}, yw]*G[{0, yu^(-1)}, yw])/8 + 
     (G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*G[{1}, yw]*G[{0, yu^(-1)}, yw])/8 + 
     (13*G[{1}, yv^(-1)]^2*G[{1}, yw]*G[{0, yu^(-1)}, yw])/128 + 
     (7*G[{0}, yu^(-1)]*G[{1}, yw]^2*G[{0, yu^(-1)}, yw])/128 + 
     (7*G[{0}, yv^(-1)]*G[{1}, yw]^2*G[{0, yu^(-1)}, yw])/128 - 
     (7*G[{0}, yw]*G[{1}, yw]^2*G[{0, yu^(-1)}, yw])/128 - 
     (7*G[{1}, yu^(-1)]*G[{1}, yw]^2*G[{0, yu^(-1)}, yw])/128 - 
     (9*G[{1}, yv^(-1)]*G[{1}, yw]^2*G[{0, yu^(-1)}, yw])/128 - 
     (G[{1}, yw]^3*G[{0, yu^(-1)}, yw])/128 + 
     (G[{0}, yu^(-1)]*G[{1}, yw]*G[{yu}, yv^(-1)]*G[{0, yu^(-1)}, yw])/32 + 
     (G[{0}, yv^(-1)]*G[{1}, yw]*G[{yu}, yv^(-1)]*G[{0, yu^(-1)}, yw])/32 - 
     (G[{0}, yw]*G[{1}, yw]*G[{yu}, yv^(-1)]*G[{0, yu^(-1)}, yw])/32 - 
     (G[{1}, yu^(-1)]*G[{1}, yw]*G[{yu}, yv^(-1)]*G[{0, yu^(-1)}, yw])/32 - 
     (3*G[{1}, yv^(-1)]*G[{1}, yw]*G[{yu}, yv^(-1)]*G[{0, yu^(-1)}, yw])/32 + 
     (G[{1}, yw]^2*G[{yu}, yv^(-1)]*G[{0, yu^(-1)}, yw])/64 + 
     (G[{1}, yw]*G[{yu}, yv^(-1)]^2*G[{0, yu^(-1)}, yw])/32 - 
     (3*Pi^2*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1)}, yw])/256 - 
     (3*G[{0}, yu^(-1)]^2*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1)}, yw])/64 - 
     (3*G[{0}, yu^(-1)]*G[{0}, yv^(-1)]*G[{1/(yu*yv)}, yw]*
       G[{0, yu^(-1)}, yw])/32 - (3*G[{0}, yv^(-1)]^2*G[{1/(yu*yv)}, yw]*
       G[{0, yu^(-1)}, yw])/64 + (3*G[{0}, yu^(-1)]*G[{0}, yw]*
       G[{1/(yu*yv)}, yw]*G[{0, yu^(-1)}, yw])/32 + 
     (3*G[{0}, yv^(-1)]*G[{0}, yw]*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1)}, yw])/
      32 - (3*G[{0}, yw]^2*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1)}, yw])/64 + 
     (5*G[{0}, yu^(-1)]*G[{1}, yu^(-1)]*G[{1/(yu*yv)}, yw]*
       G[{0, yu^(-1)}, yw])/32 + (5*G[{0}, yv^(-1)]*G[{1}, yu^(-1)]*
       G[{1/(yu*yv)}, yw]*G[{0, yu^(-1)}, yw])/32 - 
     (5*G[{0}, yw]*G[{1}, yu^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1)}, yw])/
      32 - (5*G[{1}, yu^(-1)]^2*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1)}, yw])/64 + 
     (G[{0}, yu^(-1)]*G[{1}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1)}, yw])/
      16 + (G[{0}, yv^(-1)]*G[{1}, yv^(-1)]*G[{1/(yu*yv)}, yw]*
       G[{0, yu^(-1)}, yw])/16 - (G[{0}, yw]*G[{1}, yv^(-1)]*
       G[{1/(yu*yv)}, yw]*G[{0, yu^(-1)}, yw])/16 - 
     (3*G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*G[{1/(yu*yv)}, yw]*
       G[{0, yu^(-1)}, yw])/16 + (G[{1}, yv^(-1)]^2*G[{1/(yu*yv)}, yw]*
       G[{0, yu^(-1)}, yw])/128 - (G[{0}, yu^(-1)]*G[{1}, yw]*
       G[{1/(yu*yv)}, yw]*G[{0, yu^(-1)}, yw])/64 - 
     (G[{0}, yv^(-1)]*G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1)}, yw])/64 + 
     (G[{0}, yw]*G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1)}, yw])/64 + 
     (5*G[{1}, yu^(-1)]*G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1)}, yw])/
      64 - (3*G[{1}, yv^(-1)]*G[{1}, yw]*G[{1/(yu*yv)}, yw]*
       G[{0, yu^(-1)}, yw])/64 + (G[{1}, yw]^2*G[{1/(yu*yv)}, yw]*
       G[{0, yu^(-1)}, yw])/128 + (G[{0}, yu^(-1)]*G[{yu^(-1)}, yw]*
       G[{1/(yu*yv)}, yw]*G[{0, yu^(-1)}, yw])/32 + 
     (G[{0}, yv^(-1)]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*
       G[{0, yu^(-1)}, yw])/32 - (G[{0}, yw]*G[{yu^(-1)}, yw]*
       G[{1/(yu*yv)}, yw]*G[{0, yu^(-1)}, yw])/32 + 
     (3*G[{1}, yu^(-1)]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*
       G[{0, yu^(-1)}, yw])/32 - (3*G[{1}, yv^(-1)]*G[{yu^(-1)}, yw]*
       G[{1/(yu*yv)}, yw]*G[{0, yu^(-1)}, yw])/32 + 
     (9*G[{1}, yw]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1)}, yw])/
      64 + (3*G[{yu^(-1)}, yw]^2*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1)}, yw])/32 - 
     (G[{0}, yu^(-1)]*G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw]*
       G[{0, yu^(-1)}, yw])/32 - (G[{0}, yv^(-1)]*G[{yu}, yv^(-1)]*
       G[{1/(yu*yv)}, yw]*G[{0, yu^(-1)}, yw])/32 + 
     (G[{0}, yw]*G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1)}, yw])/
      32 + (G[{1}, yu^(-1)]*G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw]*
       G[{0, yu^(-1)}, yw])/32 + (3*G[{1}, yv^(-1)]*G[{yu}, yv^(-1)]*
       G[{1/(yu*yv)}, yw]*G[{0, yu^(-1)}, yw])/32 - 
     (G[{yu^(-1)}, yw]*G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw]*
       G[{0, yu^(-1)}, yw])/16 - (G[{yu}, yv^(-1)]^2*G[{1/(yu*yv)}, yw]*
       G[{0, yu^(-1)}, yw])/32 + (G[{1}, yu^(-1)]*G[{yv^(-1)}, yw]*
       G[{1/(yu*yv)}, yw]*G[{0, yu^(-1)}, yw])/16 - 
     (G[{1}, yv^(-1)]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*
       G[{0, yu^(-1)}, yw])/16 - (G[{1}, yw]*G[{yv^(-1)}, yw]*
       G[{1/(yu*yv)}, yw]*G[{0, yu^(-1)}, yw])/32 - 
     (G[{yv^(-1)}, yw]^2*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1)}, yw])/16 - 
     (3*G[{0}, yu^(-1)]*G[{1/(yu*yv)}, yw]^2*G[{0, yu^(-1)}, yw])/128 - 
     (3*G[{0}, yv^(-1)]*G[{1/(yu*yv)}, yw]^2*G[{0, yu^(-1)}, yw])/128 + 
     (3*G[{0}, yw]*G[{1/(yu*yv)}, yw]^2*G[{0, yu^(-1)}, yw])/128 + 
     (7*G[{1}, yu^(-1)]*G[{1/(yu*yv)}, yw]^2*G[{0, yu^(-1)}, yw])/128 - 
     (3*G[{1}, yv^(-1)]*G[{1/(yu*yv)}, yw]^2*G[{0, yu^(-1)}, yw])/128 - 
     (G[{1}, yw]*G[{1/(yu*yv)}, yw]^2*G[{0, yu^(-1)}, yw])/64 + 
     (9*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2*G[{0, yu^(-1)}, yw])/128 + 
     (G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw]^2*G[{0, yu^(-1)}, yw])/64 - 
     (G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2*G[{0, yu^(-1)}, yw])/128 - 
     (G[{1}, yu^(-1)]*G[{0, 1}, yu^(-1)]*G[{0, yu^(-1)}, yw])/8 - 
     (3*G[{0}, yu^(-1)]*G[{0, 1}, yv^(-1)]*G[{0, yu^(-1)}, yw])/32 - 
     (3*G[{0}, yv^(-1)]*G[{0, 1}, yv^(-1)]*G[{0, yu^(-1)}, yw])/32 + 
     (3*G[{0}, yw]*G[{0, 1}, yv^(-1)]*G[{0, yu^(-1)}, yw])/32 - 
     (G[{1}, yu^(-1)]*G[{0, 1}, yv^(-1)]*G[{0, yu^(-1)}, yw])/32 + 
     (G[{1}, yv^(-1)]*G[{0, 1}, yv^(-1)]*G[{0, yu^(-1)}, yw])/32 + 
     (G[{1}, yw]*G[{0, 1}, yv^(-1)]*G[{0, yu^(-1)}, yw])/64 - 
     (3*G[{1/(yu*yv)}, yw]*G[{0, 1}, yv^(-1)]*G[{0, yu^(-1)}, yw])/64 - 
     (G[{0}, yu^(-1)]*G[{0, 1}, yw]*G[{0, yu^(-1)}, yw])/16 - 
     (G[{0}, yv^(-1)]*G[{0, 1}, yw]*G[{0, yu^(-1)}, yw])/16 + 
     (G[{0}, yw]*G[{0, 1}, yw]*G[{0, yu^(-1)}, yw])/16 + 
     (G[{1}, yu^(-1)]*G[{0, 1}, yw]*G[{0, yu^(-1)}, yw])/16 - 
     (G[{1}, yv^(-1)]*G[{0, 1}, yw]*G[{0, yu^(-1)}, yw])/16 + 
     (G[{1}, yw]*G[{0, 1}, yw]*G[{0, yu^(-1)}, yw])/64 + 
     (G[{yu}, yv^(-1)]*G[{0, 1}, yw]*G[{0, yu^(-1)}, yw])/8 + 
     (G[{1/(yu*yv)}, yw]*G[{0, 1}, yw]*G[{0, yu^(-1)}, yw])/64 + 
     (G[{0}, yu^(-1)]*G[{0, yu^(-1)}, yw]^2)/32 + 
     (G[{0}, yv^(-1)]*G[{0, yu^(-1)}, yw]^2)/32 - 
     (G[{0}, yw]*G[{0, yu^(-1)}, yw]^2)/32 - 
     (G[{1}, yu^(-1)]*G[{0, yu^(-1)}, yw]^2)/32 - 
     (G[{1}, yv^(-1)]*G[{0, yu^(-1)}, yw]^2)/32 - 
     (G[{1}, yw]*G[{0, yu^(-1)}, yw]^2)/128 - 
     (G[{1/(yu*yv)}, yw]*G[{0, yu^(-1)}, yw]^2)/128 - 
     (7*Pi^2*G[{0}, yu^(-1)]*G[{0, yu}, yv^(-1)])/384 - 
     (3*G[{0}, yu^(-1)]^3*G[{0, yu}, yv^(-1)])/128 - 
     (7*Pi^2*G[{0}, yv^(-1)]*G[{0, yu}, yv^(-1)])/384 - 
     (9*G[{0}, yu^(-1)]^2*G[{0}, yv^(-1)]*G[{0, yu}, yv^(-1)])/128 - 
     (9*G[{0}, yu^(-1)]*G[{0}, yv^(-1)]^2*G[{0, yu}, yv^(-1)])/128 - 
     (3*G[{0}, yv^(-1)]^3*G[{0, yu}, yv^(-1)])/128 + 
     (7*Pi^2*G[{0}, yw]*G[{0, yu}, yv^(-1)])/384 + 
     (9*G[{0}, yu^(-1)]^2*G[{0}, yw]*G[{0, yu}, yv^(-1)])/128 + 
     (9*G[{0}, yu^(-1)]*G[{0}, yv^(-1)]*G[{0}, yw]*G[{0, yu}, yv^(-1)])/64 + 
     (9*G[{0}, yv^(-1)]^2*G[{0}, yw]*G[{0, yu}, yv^(-1)])/128 - 
     (9*G[{0}, yu^(-1)]*G[{0}, yw]^2*G[{0, yu}, yv^(-1)])/128 - 
     (9*G[{0}, yv^(-1)]*G[{0}, yw]^2*G[{0, yu}, yv^(-1)])/128 + 
     (3*G[{0}, yw]^3*G[{0, yu}, yv^(-1)])/128 - 
     (Pi^2*G[{1}, yu^(-1)]*G[{0, yu}, yv^(-1)])/384 - 
     (3*G[{0}, yu^(-1)]^2*G[{1}, yu^(-1)]*G[{0, yu}, yv^(-1)])/128 - 
     (3*G[{0}, yu^(-1)]*G[{0}, yv^(-1)]*G[{1}, yu^(-1)]*G[{0, yu}, yv^(-1)])/
      64 - (3*G[{0}, yv^(-1)]^2*G[{1}, yu^(-1)]*G[{0, yu}, yv^(-1)])/128 + 
     (3*G[{0}, yu^(-1)]*G[{0}, yw]*G[{1}, yu^(-1)]*G[{0, yu}, yv^(-1)])/64 + 
     (3*G[{0}, yv^(-1)]*G[{0}, yw]*G[{1}, yu^(-1)]*G[{0, yu}, yv^(-1)])/64 - 
     (3*G[{0}, yw]^2*G[{1}, yu^(-1)]*G[{0, yu}, yv^(-1)])/128 + 
     (11*G[{0}, yu^(-1)]*G[{1}, yu^(-1)]^2*G[{0, yu}, yv^(-1)])/128 + 
     (11*G[{0}, yv^(-1)]*G[{1}, yu^(-1)]^2*G[{0, yu}, yv^(-1)])/128 - 
     (11*G[{0}, yw]*G[{1}, yu^(-1)]^2*G[{0, yu}, yv^(-1)])/128 - 
     (5*G[{1}, yu^(-1)]^3*G[{0, yu}, yv^(-1)])/128 - 
     (Pi^2*G[{1}, yv^(-1)]*G[{0, yu}, yv^(-1)])/384 + 
     (5*G[{0}, yu^(-1)]^2*G[{1}, yv^(-1)]*G[{0, yu}, yv^(-1)])/128 + 
     (5*G[{0}, yu^(-1)]*G[{0}, yv^(-1)]*G[{1}, yv^(-1)]*G[{0, yu}, yv^(-1)])/
      64 + (5*G[{0}, yv^(-1)]^2*G[{1}, yv^(-1)]*G[{0, yu}, yv^(-1)])/128 - 
     (5*G[{0}, yu^(-1)]*G[{0}, yw]*G[{1}, yv^(-1)]*G[{0, yu}, yv^(-1)])/64 - 
     (5*G[{0}, yv^(-1)]*G[{0}, yw]*G[{1}, yv^(-1)]*G[{0, yu}, yv^(-1)])/64 + 
     (5*G[{0}, yw]^2*G[{1}, yv^(-1)]*G[{0, yu}, yv^(-1)])/128 - 
     (G[{0}, yu^(-1)]*G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*G[{0, yu}, yv^(-1)])/
      64 - (G[{0}, yv^(-1)]*G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*
       G[{0, yu}, yv^(-1)])/64 + (G[{0}, yw]*G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*
       G[{0, yu}, yv^(-1)])/64 + (G[{1}, yu^(-1)]^2*G[{1}, yv^(-1)]*
       G[{0, yu}, yv^(-1)])/128 - (5*G[{0}, yu^(-1)]*G[{1}, yv^(-1)]^2*
       G[{0, yu}, yv^(-1)])/128 - (5*G[{0}, yv^(-1)]*G[{1}, yv^(-1)]^2*
       G[{0, yu}, yv^(-1)])/128 + (5*G[{0}, yw]*G[{1}, yv^(-1)]^2*
       G[{0, yu}, yv^(-1)])/128 + (5*G[{1}, yu^(-1)]*G[{1}, yv^(-1)]^2*
       G[{0, yu}, yv^(-1)])/128 + (5*G[{1}, yv^(-1)]^3*G[{0, yu}, yv^(-1)])/
      384 - (7*Pi^2*G[{1}, yw]*G[{0, yu}, yv^(-1)])/384 - 
     (G[{0}, yu^(-1)]^2*G[{1}, yw]*G[{0, yu}, yv^(-1)])/128 - 
     (G[{0}, yu^(-1)]*G[{0}, yv^(-1)]*G[{1}, yw]*G[{0, yu}, yv^(-1)])/64 - 
     (G[{0}, yv^(-1)]^2*G[{1}, yw]*G[{0, yu}, yv^(-1)])/128 + 
     (G[{0}, yu^(-1)]*G[{0}, yw]*G[{1}, yw]*G[{0, yu}, yv^(-1)])/64 + 
     (G[{0}, yv^(-1)]*G[{0}, yw]*G[{1}, yw]*G[{0, yu}, yv^(-1)])/64 - 
     (G[{0}, yw]^2*G[{1}, yw]*G[{0, yu}, yv^(-1)])/128 - 
     (7*G[{0}, yu^(-1)]*G[{1}, yu^(-1)]*G[{1}, yw]*G[{0, yu}, yv^(-1)])/64 - 
     (7*G[{0}, yv^(-1)]*G[{1}, yu^(-1)]*G[{1}, yw]*G[{0, yu}, yv^(-1)])/64 + 
     (7*G[{0}, yw]*G[{1}, yu^(-1)]*G[{1}, yw]*G[{0, yu}, yv^(-1)])/64 + 
     (15*G[{1}, yu^(-1)]^2*G[{1}, yw]*G[{0, yu}, yv^(-1)])/128 + 
     (G[{0}, yu^(-1)]*G[{1}, yv^(-1)]*G[{1}, yw]*G[{0, yu}, yv^(-1)])/64 + 
     (G[{0}, yv^(-1)]*G[{1}, yv^(-1)]*G[{1}, yw]*G[{0, yu}, yv^(-1)])/64 - 
     (G[{0}, yw]*G[{1}, yv^(-1)]*G[{1}, yw]*G[{0, yu}, yv^(-1)])/64 + 
     (3*G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*G[{1}, yw]*G[{0, yu}, yv^(-1)])/64 - 
     (5*G[{1}, yv^(-1)]^2*G[{1}, yw]*G[{0, yu}, yv^(-1)])/128 + 
     (9*G[{0}, yu^(-1)]*G[{1}, yw]^2*G[{0, yu}, yv^(-1)])/128 + 
     (9*G[{0}, yv^(-1)]*G[{1}, yw]^2*G[{0, yu}, yv^(-1)])/128 - 
     (9*G[{0}, yw]*G[{1}, yw]^2*G[{0, yu}, yv^(-1)])/128 - 
     (9*G[{1}, yu^(-1)]*G[{1}, yw]^2*G[{0, yu}, yv^(-1)])/128 - 
     (5*G[{1}, yv^(-1)]*G[{1}, yw]^2*G[{0, yu}, yv^(-1)])/128 + 
     (G[{1}, yw]^3*G[{0, yu}, yv^(-1)])/96 + 
     (G[{0}, yu^(-1)]*G[{1}, yw]*G[{yu}, yv^(-1)]*G[{0, yu}, yv^(-1)])/16 + 
     (G[{0}, yv^(-1)]*G[{1}, yw]*G[{yu}, yv^(-1)]*G[{0, yu}, yv^(-1)])/16 - 
     (G[{0}, yw]*G[{1}, yw]*G[{yu}, yv^(-1)]*G[{0, yu}, yv^(-1)])/16 - 
     (G[{1}, yv^(-1)]*G[{1}, yw]*G[{yu}, yv^(-1)]*G[{0, yu}, yv^(-1)])/16 - 
     (G[{1}, yw]*G[{yu}, yv^(-1)]^2*G[{0, yu}, yv^(-1)])/16 + 
     (Pi^2*G[{1/(yu*yv)}, yw]*G[{0, yu}, yv^(-1)])/384 - 
     (5*G[{0}, yu^(-1)]^2*G[{1/(yu*yv)}, yw]*G[{0, yu}, yv^(-1)])/128 - 
     (5*G[{0}, yu^(-1)]*G[{0}, yv^(-1)]*G[{1/(yu*yv)}, yw]*
       G[{0, yu}, yv^(-1)])/64 - (5*G[{0}, yv^(-1)]^2*G[{1/(yu*yv)}, yw]*
       G[{0, yu}, yv^(-1)])/128 + (5*G[{0}, yu^(-1)]*G[{0}, yw]*
       G[{1/(yu*yv)}, yw]*G[{0, yu}, yv^(-1)])/64 + 
     (5*G[{0}, yv^(-1)]*G[{0}, yw]*G[{1/(yu*yv)}, yw]*G[{0, yu}, yv^(-1)])/
      64 - (5*G[{0}, yw]^2*G[{1/(yu*yv)}, yw]*G[{0, yu}, yv^(-1)])/128 + 
     (G[{0}, yu^(-1)]*G[{1}, yu^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, yu}, yv^(-1)])/
      64 + (G[{0}, yv^(-1)]*G[{1}, yu^(-1)]*G[{1/(yu*yv)}, yw]*
       G[{0, yu}, yv^(-1)])/64 - (G[{0}, yw]*G[{1}, yu^(-1)]*
       G[{1/(yu*yv)}, yw]*G[{0, yu}, yv^(-1)])/64 - 
     (G[{1}, yu^(-1)]^2*G[{1/(yu*yv)}, yw]*G[{0, yu}, yv^(-1)])/128 + 
     (5*G[{0}, yu^(-1)]*G[{1}, yv^(-1)]*G[{1/(yu*yv)}, yw]*
       G[{0, yu}, yv^(-1)])/64 + (5*G[{0}, yv^(-1)]*G[{1}, yv^(-1)]*
       G[{1/(yu*yv)}, yw]*G[{0, yu}, yv^(-1)])/64 - 
     (5*G[{0}, yw]*G[{1}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, yu}, yv^(-1)])/
      64 - (5*G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*G[{1/(yu*yv)}, yw]*
       G[{0, yu}, yv^(-1)])/64 - (5*G[{1}, yv^(-1)]^2*G[{1/(yu*yv)}, yw]*
       G[{0, yu}, yv^(-1)])/128 - (3*G[{0}, yu^(-1)]*G[{1}, yw]*
       G[{1/(yu*yv)}, yw]*G[{0, yu}, yv^(-1)])/64 - 
     (3*G[{0}, yv^(-1)]*G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{0, yu}, yv^(-1)])/
      64 + (3*G[{0}, yw]*G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{0, yu}, yv^(-1)])/
      64 - (G[{1}, yu^(-1)]*G[{1}, yw]*G[{1/(yu*yv)}, yw]*
       G[{0, yu}, yv^(-1)])/64 + (3*G[{1}, yv^(-1)]*G[{1}, yw]*
       G[{1/(yu*yv)}, yw]*G[{0, yu}, yv^(-1)])/64 - 
     (G[{1}, yw]^2*G[{1/(yu*yv)}, yw]*G[{0, yu}, yv^(-1)])/32 - 
     (3*G[{0}, yu^(-1)]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*
       G[{0, yu}, yv^(-1)])/32 - (3*G[{0}, yv^(-1)]*G[{yu^(-1)}, yw]*
       G[{1/(yu*yv)}, yw]*G[{0, yu}, yv^(-1)])/32 + 
     (3*G[{0}, yw]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{0, yu}, yv^(-1)])/
      32 - (G[{1}, yu^(-1)]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*
       G[{0, yu}, yv^(-1)])/32 + (3*G[{1}, yv^(-1)]*G[{yu^(-1)}, yw]*
       G[{1/(yu*yv)}, yw]*G[{0, yu}, yv^(-1)])/32 - 
     (G[{1}, yw]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{0, yu}, yv^(-1)])/8 - 
     (7*G[{yu^(-1)}, yw]^2*G[{1/(yu*yv)}, yw]*G[{0, yu}, yv^(-1)])/64 - 
     (G[{0}, yu^(-1)]*G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw]*
       G[{0, yu}, yv^(-1)])/16 - (G[{0}, yv^(-1)]*G[{yu}, yv^(-1)]*
       G[{1/(yu*yv)}, yw]*G[{0, yu}, yv^(-1)])/16 + 
     (G[{0}, yw]*G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, yu}, yv^(-1)])/
      16 + (G[{1}, yv^(-1)]*G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw]*
       G[{0, yu}, yv^(-1)])/16 + (G[{yu}, yv^(-1)]^2*G[{1/(yu*yv)}, yw]*
       G[{0, yu}, yv^(-1)])/16 + (G[{0}, yu^(-1)]*G[{yv^(-1)}, yw]*
       G[{1/(yu*yv)}, yw]*G[{0, yu}, yv^(-1)])/32 + 
     (G[{0}, yv^(-1)]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*
       G[{0, yu}, yv^(-1)])/32 - (G[{0}, yw]*G[{yv^(-1)}, yw]*
       G[{1/(yu*yv)}, yw]*G[{0, yu}, yv^(-1)])/32 - 
     (G[{1}, yu^(-1)]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*
       G[{0, yu}, yv^(-1)])/32 + (G[{1}, yv^(-1)]*G[{yv^(-1)}, yw]*
       G[{1/(yu*yv)}, yw]*G[{0, yu}, yv^(-1)])/32 + 
     (G[{1}, yw]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{0, yu}, yv^(-1)])/
      16 + (G[{yu^(-1)}, yw]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*
       G[{0, yu}, yv^(-1)])/32 + (G[{yv^(-1)}, yw]^2*G[{1/(yu*yv)}, yw]*
       G[{0, yu}, yv^(-1)])/64 + (G[{0}, yu^(-1)]*G[{1/(yu*yv)}, yw]^2*
       G[{0, yu}, yv^(-1)])/128 + (G[{0}, yv^(-1)]*G[{1/(yu*yv)}, yw]^2*
       G[{0, yu}, yv^(-1)])/128 - (G[{0}, yw]*G[{1/(yu*yv)}, yw]^2*
       G[{0, yu}, yv^(-1)])/128 + (7*G[{1}, yu^(-1)]*G[{1/(yu*yv)}, yw]^2*
       G[{0, yu}, yv^(-1)])/128 - (G[{1}, yv^(-1)]*G[{1/(yu*yv)}, yw]^2*
       G[{0, yu}, yv^(-1)])/128 + (G[{1}, yw]*G[{1/(yu*yv)}, yw]^2*
       G[{0, yu}, yv^(-1)])/16 + (G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2*
       G[{0, yu}, yv^(-1)])/128 - (G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw]^2*
       G[{0, yu}, yv^(-1)])/16 - (7*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2*
       G[{0, yu}, yv^(-1)])/128 - (G[{0}, yu^(-1)]*G[{0, 1}, yu^(-1)]*
       G[{0, yu}, yv^(-1)])/8 - (G[{0}, yv^(-1)]*G[{0, 1}, yu^(-1)]*
       G[{0, yu}, yv^(-1)])/8 + (G[{0}, yw]*G[{0, 1}, yu^(-1)]*
       G[{0, yu}, yv^(-1)])/8 + (G[{1}, yu^(-1)]*G[{0, 1}, yu^(-1)]*
       G[{0, yu}, yv^(-1)])/16 - (G[{1}, yw]*G[{0, 1}, yu^(-1)]*
       G[{0, yu}, yv^(-1)])/8 + (G[{0}, yu^(-1)]*G[{0, 1}, yv^(-1)]*
       G[{0, yu}, yv^(-1)])/16 + (G[{0}, yv^(-1)]*G[{0, 1}, yv^(-1)]*
       G[{0, yu}, yv^(-1)])/16 - (G[{0}, yw]*G[{0, 1}, yv^(-1)]*
       G[{0, yu}, yv^(-1)])/16 - (G[{1}, yv^(-1)]*G[{0, 1}, yv^(-1)]*
       G[{0, yu}, yv^(-1)])/16 + (G[{1/(yu*yv)}, yw]*G[{0, 1}, yv^(-1)]*
       G[{0, yu}, yv^(-1)])/16 - (G[{0}, yu^(-1)]*G[{0, 1}, yw]*
       G[{0, yu}, yv^(-1)])/32 - (G[{0}, yv^(-1)]*G[{0, 1}, yw]*
       G[{0, yu}, yv^(-1)])/32 + (G[{0}, yw]*G[{0, 1}, yw]*
       G[{0, yu}, yv^(-1)])/32 - (G[{1}, yu^(-1)]*G[{0, 1}, yw]*
       G[{0, yu}, yv^(-1)])/32 + (G[{1}, yv^(-1)]*G[{0, 1}, yw]*
       G[{0, yu}, yv^(-1)])/32 + (9*G[{1}, yw]*G[{0, 1}, yw]*
       G[{0, yu}, yv^(-1)])/64 + (G[{yu}, yv^(-1)]*G[{0, 1}, yw]*
       G[{0, yu}, yv^(-1)])/16 - (3*G[{1/(yu*yv)}, yw]*G[{0, 1}, yw]*
       G[{0, yu}, yv^(-1)])/64 + (3*G[{0}, yu^(-1)]*G[{0, yu^(-1)}, yw]*
       G[{0, yu}, yv^(-1)])/32 + (3*G[{0}, yv^(-1)]*G[{0, yu^(-1)}, yw]*
       G[{0, yu}, yv^(-1)])/32 - (3*G[{0}, yw]*G[{0, yu^(-1)}, yw]*
       G[{0, yu}, yv^(-1)])/32 + (G[{1}, yu^(-1)]*G[{0, yu^(-1)}, yw]*
       G[{0, yu}, yv^(-1)])/32 - (G[{1}, yv^(-1)]*G[{0, yu^(-1)}, yw]*
       G[{0, yu}, yv^(-1)])/32 - (G[{1}, yw]*G[{0, yu^(-1)}, yw]*
       G[{0, yu}, yv^(-1)])/64 + (3*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1)}, yw]*
       G[{0, yu}, yv^(-1)])/64 - (G[{0}, yu^(-1)]*G[{0, yu}, yv^(-1)]^2)/32 - 
     (G[{0}, yv^(-1)]*G[{0, yu}, yv^(-1)]^2)/32 + 
     (G[{0}, yw]*G[{0, yu}, yv^(-1)]^2)/32 + 
     (G[{1}, yv^(-1)]*G[{0, yu}, yv^(-1)]^2)/32 - 
     (G[{1/(yu*yv)}, yw]*G[{0, yu}, yv^(-1)]^2)/32 + 
     (29*Pi^2*G[{0}, yu^(-1)]*G[{0, yv^(-1)}, yw])/768 + 
     (29*Pi^2*G[{0}, yv^(-1)]*G[{0, yv^(-1)}, yw])/768 - 
     (29*Pi^2*G[{0}, yw]*G[{0, yv^(-1)}, yw])/768 - 
     (53*Pi^2*G[{1}, yu^(-1)]*G[{0, yv^(-1)}, yw])/768 - 
     (3*G[{0}, yu^(-1)]^2*G[{1}, yu^(-1)]*G[{0, yv^(-1)}, yw])/32 - 
     (3*G[{0}, yu^(-1)]*G[{0}, yv^(-1)]*G[{1}, yu^(-1)]*G[{0, yv^(-1)}, yw])/
      16 - (3*G[{0}, yv^(-1)]^2*G[{1}, yu^(-1)]*G[{0, yv^(-1)}, yw])/32 + 
     (3*G[{0}, yu^(-1)]*G[{0}, yw]*G[{1}, yu^(-1)]*G[{0, yv^(-1)}, yw])/16 + 
     (3*G[{0}, yv^(-1)]*G[{0}, yw]*G[{1}, yu^(-1)]*G[{0, yv^(-1)}, yw])/16 - 
     (3*G[{0}, yw]^2*G[{1}, yu^(-1)]*G[{0, yv^(-1)}, yw])/32 + 
     (5*G[{0}, yu^(-1)]*G[{1}, yu^(-1)]^2*G[{0, yv^(-1)}, yw])/32 + 
     (5*G[{0}, yv^(-1)]*G[{1}, yu^(-1)]^2*G[{0, yv^(-1)}, yw])/32 - 
     (5*G[{0}, yw]*G[{1}, yu^(-1)]^2*G[{0, yv^(-1)}, yw])/32 - 
     (G[{1}, yu^(-1)]^3*G[{0, yv^(-1)}, yw])/16 - 
     (5*Pi^2*G[{1}, yv^(-1)]*G[{0, yv^(-1)}, yw])/768 + 
     (3*G[{0}, yu^(-1)]^2*G[{1}, yv^(-1)]*G[{0, yv^(-1)}, yw])/32 + 
     (3*G[{0}, yu^(-1)]*G[{0}, yv^(-1)]*G[{1}, yv^(-1)]*G[{0, yv^(-1)}, yw])/
      16 + (3*G[{0}, yv^(-1)]^2*G[{1}, yv^(-1)]*G[{0, yv^(-1)}, yw])/32 - 
     (3*G[{0}, yu^(-1)]*G[{0}, yw]*G[{1}, yv^(-1)]*G[{0, yv^(-1)}, yw])/16 - 
     (3*G[{0}, yv^(-1)]*G[{0}, yw]*G[{1}, yv^(-1)]*G[{0, yv^(-1)}, yw])/16 + 
     (3*G[{0}, yw]^2*G[{1}, yv^(-1)]*G[{0, yv^(-1)}, yw])/32 + 
     (G[{0}, yu^(-1)]*G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*G[{0, yv^(-1)}, yw])/
      16 + (G[{0}, yv^(-1)]*G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*
       G[{0, yv^(-1)}, yw])/16 - (G[{0}, yw]*G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*
       G[{0, yv^(-1)}, yw])/16 - (G[{1}, yu^(-1)]^2*G[{1}, yv^(-1)]*
       G[{0, yv^(-1)}, yw])/8 - (9*G[{0}, yu^(-1)]*G[{1}, yv^(-1)]^2*
       G[{0, yv^(-1)}, yw])/64 - (9*G[{0}, yv^(-1)]*G[{1}, yv^(-1)]^2*
       G[{0, yv^(-1)}, yw])/64 + (9*G[{0}, yw]*G[{1}, yv^(-1)]^2*
       G[{0, yv^(-1)}, yw])/64 + (5*G[{1}, yu^(-1)]*G[{1}, yv^(-1)]^2*
       G[{0, yv^(-1)}, yw])/64 + (3*G[{1}, yv^(-1)]^3*G[{0, yv^(-1)}, yw])/
      64 + (5*Pi^2*G[{1}, yw]*G[{0, yv^(-1)}, yw])/256 + 
     (3*G[{0}, yu^(-1)]^2*G[{1}, yw]*G[{0, yv^(-1)}, yw])/64 + 
     (3*G[{0}, yu^(-1)]*G[{0}, yv^(-1)]*G[{1}, yw]*G[{0, yv^(-1)}, yw])/32 + 
     (3*G[{0}, yv^(-1)]^2*G[{1}, yw]*G[{0, yv^(-1)}, yw])/64 - 
     (3*G[{0}, yu^(-1)]*G[{0}, yw]*G[{1}, yw]*G[{0, yv^(-1)}, yw])/32 - 
     (3*G[{0}, yv^(-1)]*G[{0}, yw]*G[{1}, yw]*G[{0, yv^(-1)}, yw])/32 + 
     (3*G[{0}, yw]^2*G[{1}, yw]*G[{0, yv^(-1)}, yw])/64 - 
     (7*G[{0}, yu^(-1)]*G[{1}, yu^(-1)]*G[{1}, yw]*G[{0, yv^(-1)}, yw])/32 - 
     (7*G[{0}, yv^(-1)]*G[{1}, yu^(-1)]*G[{1}, yw]*G[{0, yv^(-1)}, yw])/32 + 
     (7*G[{0}, yw]*G[{1}, yu^(-1)]*G[{1}, yw]*G[{0, yv^(-1)}, yw])/32 + 
     (11*G[{1}, yu^(-1)]^2*G[{1}, yw]*G[{0, yv^(-1)}, yw])/64 + 
     (G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*G[{1}, yw]*G[{0, yv^(-1)}, yw])/8 - 
     (3*G[{1}, yv^(-1)]^2*G[{1}, yw]*G[{0, yv^(-1)}, yw])/128 + 
     (7*G[{0}, yu^(-1)]*G[{1}, yw]^2*G[{0, yv^(-1)}, yw])/128 + 
     (7*G[{0}, yv^(-1)]*G[{1}, yw]^2*G[{0, yv^(-1)}, yw])/128 - 
     (7*G[{0}, yw]*G[{1}, yw]^2*G[{0, yv^(-1)}, yw])/128 - 
     (7*G[{1}, yu^(-1)]*G[{1}, yw]^2*G[{0, yv^(-1)}, yw])/128 - 
     (9*G[{1}, yv^(-1)]*G[{1}, yw]^2*G[{0, yv^(-1)}, yw])/128 - 
     (G[{1}, yw]^3*G[{0, yv^(-1)}, yw])/128 + 
     (G[{0}, yu^(-1)]*G[{1}, yw]*G[{yu}, yv^(-1)]*G[{0, yv^(-1)}, yw])/32 + 
     (G[{0}, yv^(-1)]*G[{1}, yw]*G[{yu}, yv^(-1)]*G[{0, yv^(-1)}, yw])/32 - 
     (G[{0}, yw]*G[{1}, yw]*G[{yu}, yv^(-1)]*G[{0, yv^(-1)}, yw])/32 - 
     (G[{1}, yu^(-1)]*G[{1}, yw]*G[{yu}, yv^(-1)]*G[{0, yv^(-1)}, yw])/32 - 
     (3*G[{1}, yv^(-1)]*G[{1}, yw]*G[{yu}, yv^(-1)]*G[{0, yv^(-1)}, yw])/32 + 
     (G[{1}, yw]^2*G[{yu}, yv^(-1)]*G[{0, yv^(-1)}, yw])/64 + 
     (G[{1}, yw]*G[{yu}, yv^(-1)]^2*G[{0, yv^(-1)}, yw])/32 - 
     (3*Pi^2*G[{1/(yu*yv)}, yw]*G[{0, yv^(-1)}, yw])/256 - 
     (3*G[{0}, yu^(-1)]^2*G[{1/(yu*yv)}, yw]*G[{0, yv^(-1)}, yw])/64 - 
     (3*G[{0}, yu^(-1)]*G[{0}, yv^(-1)]*G[{1/(yu*yv)}, yw]*
       G[{0, yv^(-1)}, yw])/32 - (3*G[{0}, yv^(-1)]^2*G[{1/(yu*yv)}, yw]*
       G[{0, yv^(-1)}, yw])/64 + (3*G[{0}, yu^(-1)]*G[{0}, yw]*
       G[{1/(yu*yv)}, yw]*G[{0, yv^(-1)}, yw])/32 + 
     (3*G[{0}, yv^(-1)]*G[{0}, yw]*G[{1/(yu*yv)}, yw]*G[{0, yv^(-1)}, yw])/
      32 - (3*G[{0}, yw]^2*G[{1/(yu*yv)}, yw]*G[{0, yv^(-1)}, yw])/64 + 
     (3*G[{0}, yu^(-1)]*G[{1}, yu^(-1)]*G[{1/(yu*yv)}, yw]*
       G[{0, yv^(-1)}, yw])/32 + (3*G[{0}, yv^(-1)]*G[{1}, yu^(-1)]*
       G[{1/(yu*yv)}, yw]*G[{0, yv^(-1)}, yw])/32 - 
     (3*G[{0}, yw]*G[{1}, yu^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, yv^(-1)}, yw])/
      32 - (G[{1}, yu^(-1)]^2*G[{1/(yu*yv)}, yw]*G[{0, yv^(-1)}, yw])/64 + 
     (G[{0}, yu^(-1)]*G[{1}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, yv^(-1)}, yw])/
      8 + (G[{0}, yv^(-1)]*G[{1}, yv^(-1)]*G[{1/(yu*yv)}, yw]*
       G[{0, yv^(-1)}, yw])/8 - (G[{0}, yw]*G[{1}, yv^(-1)]*
       G[{1/(yu*yv)}, yw]*G[{0, yv^(-1)}, yw])/8 - 
     (3*G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*G[{1/(yu*yv)}, yw]*
       G[{0, yv^(-1)}, yw])/16 - (7*G[{1}, yv^(-1)]^2*G[{1/(yu*yv)}, yw]*
       G[{0, yv^(-1)}, yw])/128 - (G[{0}, yu^(-1)]*G[{1}, yw]*
       G[{1/(yu*yv)}, yw]*G[{0, yv^(-1)}, yw])/64 - 
     (G[{0}, yv^(-1)]*G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{0, yv^(-1)}, yw])/64 + 
     (G[{0}, yw]*G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{0, yv^(-1)}, yw])/64 + 
     (5*G[{1}, yu^(-1)]*G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{0, yv^(-1)}, yw])/
      64 - (3*G[{1}, yv^(-1)]*G[{1}, yw]*G[{1/(yu*yv)}, yw]*
       G[{0, yv^(-1)}, yw])/64 + (G[{1}, yw]^2*G[{1/(yu*yv)}, yw]*
       G[{0, yv^(-1)}, yw])/128 + (G[{0}, yu^(-1)]*G[{yu^(-1)}, yw]*
       G[{1/(yu*yv)}, yw]*G[{0, yv^(-1)}, yw])/32 + 
     (G[{0}, yv^(-1)]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*
       G[{0, yv^(-1)}, yw])/32 - (G[{0}, yw]*G[{yu^(-1)}, yw]*
       G[{1/(yu*yv)}, yw]*G[{0, yv^(-1)}, yw])/32 + 
     (3*G[{1}, yu^(-1)]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*
       G[{0, yv^(-1)}, yw])/32 - (3*G[{1}, yv^(-1)]*G[{yu^(-1)}, yw]*
       G[{1/(yu*yv)}, yw]*G[{0, yv^(-1)}, yw])/32 + 
     (9*G[{1}, yw]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{0, yv^(-1)}, yw])/
      64 + (3*G[{yu^(-1)}, yw]^2*G[{1/(yu*yv)}, yw]*G[{0, yv^(-1)}, yw])/32 - 
     (G[{0}, yu^(-1)]*G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw]*
       G[{0, yv^(-1)}, yw])/32 - (G[{0}, yv^(-1)]*G[{yu}, yv^(-1)]*
       G[{1/(yu*yv)}, yw]*G[{0, yv^(-1)}, yw])/32 + 
     (G[{0}, yw]*G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, yv^(-1)}, yw])/
      32 + (G[{1}, yu^(-1)]*G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw]*
       G[{0, yv^(-1)}, yw])/32 + (3*G[{1}, yv^(-1)]*G[{yu}, yv^(-1)]*
       G[{1/(yu*yv)}, yw]*G[{0, yv^(-1)}, yw])/32 - 
     (G[{yu^(-1)}, yw]*G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw]*
       G[{0, yv^(-1)}, yw])/16 - (G[{yu}, yv^(-1)]^2*G[{1/(yu*yv)}, yw]*
       G[{0, yv^(-1)}, yw])/32 + (G[{1}, yu^(-1)]*G[{yv^(-1)}, yw]*
       G[{1/(yu*yv)}, yw]*G[{0, yv^(-1)}, yw])/16 - 
     (G[{1}, yv^(-1)]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*
       G[{0, yv^(-1)}, yw])/16 - (G[{1}, yw]*G[{yv^(-1)}, yw]*
       G[{1/(yu*yv)}, yw]*G[{0, yv^(-1)}, yw])/32 - 
     (G[{yv^(-1)}, yw]^2*G[{1/(yu*yv)}, yw]*G[{0, yv^(-1)}, yw])/16 - 
     (3*G[{0}, yu^(-1)]*G[{1/(yu*yv)}, yw]^2*G[{0, yv^(-1)}, yw])/128 - 
     (3*G[{0}, yv^(-1)]*G[{1/(yu*yv)}, yw]^2*G[{0, yv^(-1)}, yw])/128 + 
     (3*G[{0}, yw]*G[{1/(yu*yv)}, yw]^2*G[{0, yv^(-1)}, yw])/128 + 
     (7*G[{1}, yu^(-1)]*G[{1/(yu*yv)}, yw]^2*G[{0, yv^(-1)}, yw])/128 - 
     (3*G[{1}, yv^(-1)]*G[{1/(yu*yv)}, yw]^2*G[{0, yv^(-1)}, yw])/128 - 
     (G[{1}, yw]*G[{1/(yu*yv)}, yw]^2*G[{0, yv^(-1)}, yw])/64 + 
     (9*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2*G[{0, yv^(-1)}, yw])/128 + 
     (G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw]^2*G[{0, yv^(-1)}, yw])/64 - 
     (G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2*G[{0, yv^(-1)}, yw])/128 + 
     (3*G[{0}, yu^(-1)]*G[{0, 1}, yu^(-1)]*G[{0, yv^(-1)}, yw])/16 + 
     (3*G[{0}, yv^(-1)]*G[{0, 1}, yu^(-1)]*G[{0, yv^(-1)}, yw])/16 - 
     (3*G[{0}, yw]*G[{0, 1}, yu^(-1)]*G[{0, yv^(-1)}, yw])/16 - 
     (5*G[{1}, yu^(-1)]*G[{0, 1}, yu^(-1)]*G[{0, yv^(-1)}, yw])/16 - 
     (G[{1}, yv^(-1)]*G[{0, 1}, yu^(-1)]*G[{0, yv^(-1)}, yw])/16 + 
     (G[{1}, yw]*G[{0, 1}, yu^(-1)]*G[{0, yv^(-1)}, yw])/16 + 
     (G[{0}, yu^(-1)]*G[{0, 1}, yv^(-1)]*G[{0, yv^(-1)}, yw])/32 + 
     (G[{0}, yv^(-1)]*G[{0, 1}, yv^(-1)]*G[{0, yv^(-1)}, yw])/32 - 
     (G[{0}, yw]*G[{0, 1}, yv^(-1)]*G[{0, yv^(-1)}, yw])/32 - 
     (G[{1}, yu^(-1)]*G[{0, 1}, yv^(-1)]*G[{0, yv^(-1)}, yw])/32 + 
     (G[{1}, yv^(-1)]*G[{0, 1}, yv^(-1)]*G[{0, yv^(-1)}, yw])/32 + 
     (5*G[{1}, yw]*G[{0, 1}, yv^(-1)]*G[{0, yv^(-1)}, yw])/64 - 
     (3*G[{1/(yu*yv)}, yw]*G[{0, 1}, yv^(-1)]*G[{0, yv^(-1)}, yw])/64 + 
     (G[{1}, yu^(-1)]*G[{0, 1}, yw]*G[{0, yv^(-1)}, yw])/16 - 
     (G[{1}, yv^(-1)]*G[{0, 1}, yw]*G[{0, yv^(-1)}, yw])/16 - 
     (3*G[{1}, yw]*G[{0, 1}, yw]*G[{0, yv^(-1)}, yw])/64 + 
     (G[{1/(yu*yv)}, yw]*G[{0, 1}, yw]*G[{0, yv^(-1)}, yw])/64 - 
     (G[{1}, yu^(-1)]*G[{0, yu^(-1)}, yw]*G[{0, yv^(-1)}, yw])/16 + 
     (G[{1}, yv^(-1)]*G[{0, yu^(-1)}, yw]*G[{0, yv^(-1)}, yw])/16 + 
     (3*G[{1}, yw]*G[{0, yu^(-1)}, yw]*G[{0, yv^(-1)}, yw])/64 - 
     (G[{1/(yu*yv)}, yw]*G[{0, yu^(-1)}, yw]*G[{0, yv^(-1)}, yw])/64 - 
     (G[{0}, yu^(-1)]*G[{0, yu}, yv^(-1)]*G[{0, yv^(-1)}, yw])/32 - 
     (G[{0}, yv^(-1)]*G[{0, yu}, yv^(-1)]*G[{0, yv^(-1)}, yw])/32 + 
     (G[{0}, yw]*G[{0, yu}, yv^(-1)]*G[{0, yv^(-1)}, yw])/32 + 
     (G[{1}, yu^(-1)]*G[{0, yu}, yv^(-1)]*G[{0, yv^(-1)}, yw])/32 - 
     (G[{1}, yv^(-1)]*G[{0, yu}, yv^(-1)]*G[{0, yv^(-1)}, yw])/32 - 
     (5*G[{1}, yw]*G[{0, yu}, yv^(-1)]*G[{0, yv^(-1)}, yw])/64 + 
     (3*G[{1/(yu*yv)}, yw]*G[{0, yu}, yv^(-1)]*G[{0, yv^(-1)}, yw])/64 - 
     (G[{1}, yu^(-1)]*G[{0, yv^(-1)}, yw]^2)/32 + 
     (G[{1}, yv^(-1)]*G[{0, yv^(-1)}, yw]^2)/32 + 
     (3*G[{1}, yw]*G[{0, yv^(-1)}, yw]^2)/128 - 
     (G[{1/(yu*yv)}, yw]*G[{0, yv^(-1)}, yw]^2)/128 - 
     (5*Pi^2*G[{0}, yu^(-1)]*G[{0, 1/(yu*yv)}, yw])/768 - 
     (5*Pi^2*G[{0}, yv^(-1)]*G[{0, 1/(yu*yv)}, yw])/768 + 
     (5*Pi^2*G[{0}, yw]*G[{0, 1/(yu*yv)}, yw])/768 + 
     (37*Pi^2*G[{1}, yu^(-1)]*G[{0, 1/(yu*yv)}, yw])/768 + 
     (3*G[{0}, yu^(-1)]^2*G[{1}, yu^(-1)]*G[{0, 1/(yu*yv)}, yw])/32 + 
     (3*G[{0}, yu^(-1)]*G[{0}, yv^(-1)]*G[{1}, yu^(-1)]*
       G[{0, 1/(yu*yv)}, yw])/16 + (3*G[{0}, yv^(-1)]^2*G[{1}, yu^(-1)]*
       G[{0, 1/(yu*yv)}, yw])/32 - (3*G[{0}, yu^(-1)]*G[{0}, yw]*
       G[{1}, yu^(-1)]*G[{0, 1/(yu*yv)}, yw])/16 - 
     (3*G[{0}, yv^(-1)]*G[{0}, yw]*G[{1}, yu^(-1)]*G[{0, 1/(yu*yv)}, yw])/
      16 + (3*G[{0}, yw]^2*G[{1}, yu^(-1)]*G[{0, 1/(yu*yv)}, yw])/32 - 
     (5*G[{0}, yu^(-1)]*G[{1}, yu^(-1)]^2*G[{0, 1/(yu*yv)}, yw])/32 - 
     (5*G[{0}, yv^(-1)]*G[{1}, yu^(-1)]^2*G[{0, 1/(yu*yv)}, yw])/32 + 
     (5*G[{0}, yw]*G[{1}, yu^(-1)]^2*G[{0, 1/(yu*yv)}, yw])/32 + 
     (G[{1}, yu^(-1)]^3*G[{0, 1/(yu*yv)}, yw])/16 - 
     (Pi^2*G[{1}, yv^(-1)]*G[{0, 1/(yu*yv)}, yw])/256 - 
     (G[{0}, yu^(-1)]*G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*G[{0, 1/(yu*yv)}, yw])/
      16 - (G[{0}, yv^(-1)]*G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*
       G[{0, 1/(yu*yv)}, yw])/16 + (G[{0}, yw]*G[{1}, yu^(-1)]*
       G[{1}, yv^(-1)]*G[{0, 1/(yu*yv)}, yw])/16 + 
     (G[{1}, yu^(-1)]^2*G[{1}, yv^(-1)]*G[{0, 1/(yu*yv)}, yw])/16 - 
     (3*G[{0}, yu^(-1)]*G[{1}, yv^(-1)]^2*G[{0, 1/(yu*yv)}, yw])/64 - 
     (3*G[{0}, yv^(-1)]*G[{1}, yv^(-1)]^2*G[{0, 1/(yu*yv)}, yw])/64 + 
     (3*G[{0}, yw]*G[{1}, yv^(-1)]^2*G[{0, 1/(yu*yv)}, yw])/64 - 
     (G[{1}, yu^(-1)]*G[{1}, yv^(-1)]^2*G[{0, 1/(yu*yv)}, yw])/64 + 
     (3*G[{1}, yv^(-1)]^3*G[{0, 1/(yu*yv)}, yw])/64 + 
     (Pi^2*G[{1}, yw]*G[{0, 1/(yu*yv)}, yw])/768 - 
     (3*G[{0}, yu^(-1)]^2*G[{1}, yw]*G[{0, 1/(yu*yv)}, yw])/64 - 
     (3*G[{0}, yu^(-1)]*G[{0}, yv^(-1)]*G[{1}, yw]*G[{0, 1/(yu*yv)}, yw])/
      32 - (3*G[{0}, yv^(-1)]^2*G[{1}, yw]*G[{0, 1/(yu*yv)}, yw])/64 + 
     (3*G[{0}, yu^(-1)]*G[{0}, yw]*G[{1}, yw]*G[{0, 1/(yu*yv)}, yw])/32 + 
     (3*G[{0}, yv^(-1)]*G[{0}, yw]*G[{1}, yw]*G[{0, 1/(yu*yv)}, yw])/32 - 
     (3*G[{0}, yw]^2*G[{1}, yw]*G[{0, 1/(yu*yv)}, yw])/64 + 
     (7*G[{0}, yu^(-1)]*G[{1}, yu^(-1)]*G[{1}, yw]*G[{0, 1/(yu*yv)}, yw])/
      32 + (7*G[{0}, yv^(-1)]*G[{1}, yu^(-1)]*G[{1}, yw]*
       G[{0, 1/(yu*yv)}, yw])/32 - (7*G[{0}, yw]*G[{1}, yu^(-1)]*G[{1}, yw]*
       G[{0, 1/(yu*yv)}, yw])/32 - (11*G[{1}, yu^(-1)]^2*G[{1}, yw]*
       G[{0, 1/(yu*yv)}, yw])/64 + (G[{0}, yu^(-1)]*G[{1}, yv^(-1)]*
       G[{1}, yw]*G[{0, 1/(yu*yv)}, yw])/8 + 
     (G[{0}, yv^(-1)]*G[{1}, yv^(-1)]*G[{1}, yw]*G[{0, 1/(yu*yv)}, yw])/8 - 
     (G[{0}, yw]*G[{1}, yv^(-1)]*G[{1}, yw]*G[{0, 1/(yu*yv)}, yw])/8 - 
     (G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*G[{1}, yw]*G[{0, 1/(yu*yv)}, yw])/8 - 
     (13*G[{1}, yv^(-1)]^2*G[{1}, yw]*G[{0, 1/(yu*yv)}, yw])/128 - 
     (7*G[{0}, yu^(-1)]*G[{1}, yw]^2*G[{0, 1/(yu*yv)}, yw])/128 - 
     (7*G[{0}, yv^(-1)]*G[{1}, yw]^2*G[{0, 1/(yu*yv)}, yw])/128 + 
     (7*G[{0}, yw]*G[{1}, yw]^2*G[{0, 1/(yu*yv)}, yw])/128 + 
     (7*G[{1}, yu^(-1)]*G[{1}, yw]^2*G[{0, 1/(yu*yv)}, yw])/128 + 
     (9*G[{1}, yv^(-1)]*G[{1}, yw]^2*G[{0, 1/(yu*yv)}, yw])/128 + 
     (G[{1}, yw]^3*G[{0, 1/(yu*yv)}, yw])/128 - 
     (Pi^2*G[{yu}, yv^(-1)]*G[{0, 1/(yu*yv)}, yw])/48 - 
     (3*G[{0}, yu^(-1)]^2*G[{yu}, yv^(-1)]*G[{0, 1/(yu*yv)}, yw])/32 - 
     (3*G[{0}, yu^(-1)]*G[{0}, yv^(-1)]*G[{yu}, yv^(-1)]*
       G[{0, 1/(yu*yv)}, yw])/16 - (3*G[{0}, yv^(-1)]^2*G[{yu}, yv^(-1)]*
       G[{0, 1/(yu*yv)}, yw])/32 + (3*G[{0}, yu^(-1)]*G[{0}, yw]*
       G[{yu}, yv^(-1)]*G[{0, 1/(yu*yv)}, yw])/16 + 
     (3*G[{0}, yv^(-1)]*G[{0}, yw]*G[{yu}, yv^(-1)]*G[{0, 1/(yu*yv)}, yw])/
      16 - (3*G[{0}, yw]^2*G[{yu}, yv^(-1)]*G[{0, 1/(yu*yv)}, yw])/32 + 
     (G[{1}, yu^(-1)]^2*G[{yu}, yv^(-1)]*G[{0, 1/(yu*yv)}, yw])/16 + 
     (G[{0}, yu^(-1)]*G[{1}, yv^(-1)]*G[{yu}, yv^(-1)]*G[{0, 1/(yu*yv)}, yw])/
      8 + (G[{0}, yv^(-1)]*G[{1}, yv^(-1)]*G[{yu}, yv^(-1)]*
       G[{0, 1/(yu*yv)}, yw])/8 - (G[{0}, yw]*G[{1}, yv^(-1)]*
       G[{yu}, yv^(-1)]*G[{0, 1/(yu*yv)}, yw])/8 - 
     (G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*G[{yu}, yv^(-1)]*G[{0, 1/(yu*yv)}, yw])/
      8 - (G[{1}, yv^(-1)]^2*G[{yu}, yv^(-1)]*G[{0, 1/(yu*yv)}, yw])/32 - 
     (5*G[{0}, yu^(-1)]*G[{1}, yw]*G[{yu}, yv^(-1)]*G[{0, 1/(yu*yv)}, yw])/
      32 - (5*G[{0}, yv^(-1)]*G[{1}, yw]*G[{yu}, yv^(-1)]*
       G[{0, 1/(yu*yv)}, yw])/32 + (5*G[{0}, yw]*G[{1}, yw]*G[{yu}, yv^(-1)]*
       G[{0, 1/(yu*yv)}, yw])/32 + (G[{1}, yu^(-1)]*G[{1}, yw]*
       G[{yu}, yv^(-1)]*G[{0, 1/(yu*yv)}, yw])/32 + 
     (3*G[{1}, yv^(-1)]*G[{1}, yw]*G[{yu}, yv^(-1)]*G[{0, 1/(yu*yv)}, yw])/
      32 - (G[{1}, yw]^2*G[{yu}, yv^(-1)]*G[{0, 1/(yu*yv)}, yw])/64 + 
     (G[{0}, yu^(-1)]*G[{yu}, yv^(-1)]^2*G[{0, 1/(yu*yv)}, yw])/8 + 
     (G[{0}, yv^(-1)]*G[{yu}, yv^(-1)]^2*G[{0, 1/(yu*yv)}, yw])/8 - 
     (G[{0}, yw]*G[{yu}, yv^(-1)]^2*G[{0, 1/(yu*yv)}, yw])/8 - 
     (G[{1}, yv^(-1)]*G[{yu}, yv^(-1)]^2*G[{0, 1/(yu*yv)}, yw])/8 + 
     (3*G[{1}, yw]*G[{yu}, yv^(-1)]^2*G[{0, 1/(yu*yv)}, yw])/32 - 
     (G[{yu}, yv^(-1)]^3*G[{0, 1/(yu*yv)}, yw])/24 + 
     (3*Pi^2*G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv)}, yw])/256 + 
     (3*G[{0}, yu^(-1)]^2*G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv)}, yw])/64 + 
     (3*G[{0}, yu^(-1)]*G[{0}, yv^(-1)]*G[{1/(yu*yv)}, yw]*
       G[{0, 1/(yu*yv)}, yw])/32 + (3*G[{0}, yv^(-1)]^2*G[{1/(yu*yv)}, yw]*
       G[{0, 1/(yu*yv)}, yw])/64 - (3*G[{0}, yu^(-1)]*G[{0}, yw]*
       G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv)}, yw])/32 - 
     (3*G[{0}, yv^(-1)]*G[{0}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv)}, yw])/
      32 + (3*G[{0}, yw]^2*G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv)}, yw])/64 - 
     (3*G[{0}, yu^(-1)]*G[{1}, yu^(-1)]*G[{1/(yu*yv)}, yw]*
       G[{0, 1/(yu*yv)}, yw])/32 - (3*G[{0}, yv^(-1)]*G[{1}, yu^(-1)]*
       G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv)}, yw])/32 + 
     (3*G[{0}, yw]*G[{1}, yu^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv)}, yw])/
      32 + (G[{1}, yu^(-1)]^2*G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv)}, yw])/64 - 
     (G[{0}, yu^(-1)]*G[{1}, yv^(-1)]*G[{1/(yu*yv)}, yw]*
       G[{0, 1/(yu*yv)}, yw])/16 - (G[{0}, yv^(-1)]*G[{1}, yv^(-1)]*
       G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv)}, yw])/16 + 
     (G[{0}, yw]*G[{1}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv)}, yw])/
      16 + (3*G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*G[{1/(yu*yv)}, yw]*
       G[{0, 1/(yu*yv)}, yw])/16 - (G[{1}, yv^(-1)]^2*G[{1/(yu*yv)}, yw]*
       G[{0, 1/(yu*yv)}, yw])/128 + (G[{0}, yu^(-1)]*G[{1}, yw]*
       G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv)}, yw])/64 + 
     (G[{0}, yv^(-1)]*G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv)}, yw])/
      64 - (G[{0}, yw]*G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv)}, yw])/
      64 - (5*G[{1}, yu^(-1)]*G[{1}, yw]*G[{1/(yu*yv)}, yw]*
       G[{0, 1/(yu*yv)}, yw])/64 + (3*G[{1}, yv^(-1)]*G[{1}, yw]*
       G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv)}, yw])/64 - 
     (G[{1}, yw]^2*G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv)}, yw])/128 - 
     (G[{0}, yu^(-1)]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*
       G[{0, 1/(yu*yv)}, yw])/32 - (G[{0}, yv^(-1)]*G[{yu^(-1)}, yw]*
       G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv)}, yw])/32 + 
     (G[{0}, yw]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv)}, yw])/
      32 - (3*G[{1}, yu^(-1)]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*
       G[{0, 1/(yu*yv)}, yw])/32 + (3*G[{1}, yv^(-1)]*G[{yu^(-1)}, yw]*
       G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv)}, yw])/32 - 
     (9*G[{1}, yw]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv)}, yw])/
      64 - (3*G[{yu^(-1)}, yw]^2*G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv)}, yw])/
      32 - (G[{0}, yu^(-1)]*G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw]*
       G[{0, 1/(yu*yv)}, yw])/32 - (G[{0}, yv^(-1)]*G[{yu}, yv^(-1)]*
       G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv)}, yw])/32 + 
     (G[{0}, yw]*G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv)}, yw])/
      32 - (G[{1}, yu^(-1)]*G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw]*
       G[{0, 1/(yu*yv)}, yw])/32 - (3*G[{1}, yv^(-1)]*G[{yu}, yv^(-1)]*
       G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv)}, yw])/32 + 
     (G[{yu^(-1)}, yw]*G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw]*
       G[{0, 1/(yu*yv)}, yw])/16 + (3*G[{yu}, yv^(-1)]^2*G[{1/(yu*yv)}, yw]*
       G[{0, 1/(yu*yv)}, yw])/32 - (G[{1}, yu^(-1)]*G[{yv^(-1)}, yw]*
       G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv)}, yw])/16 + 
     (G[{1}, yv^(-1)]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*
       G[{0, 1/(yu*yv)}, yw])/16 + (G[{1}, yw]*G[{yv^(-1)}, yw]*
       G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv)}, yw])/32 + 
     (G[{yv^(-1)}, yw]^2*G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv)}, yw])/16 + 
     (3*G[{0}, yu^(-1)]*G[{1/(yu*yv)}, yw]^2*G[{0, 1/(yu*yv)}, yw])/128 + 
     (3*G[{0}, yv^(-1)]*G[{1/(yu*yv)}, yw]^2*G[{0, 1/(yu*yv)}, yw])/128 - 
     (3*G[{0}, yw]*G[{1/(yu*yv)}, yw]^2*G[{0, 1/(yu*yv)}, yw])/128 - 
     (7*G[{1}, yu^(-1)]*G[{1/(yu*yv)}, yw]^2*G[{0, 1/(yu*yv)}, yw])/128 + 
     (3*G[{1}, yv^(-1)]*G[{1/(yu*yv)}, yw]^2*G[{0, 1/(yu*yv)}, yw])/128 + 
     (G[{1}, yw]*G[{1/(yu*yv)}, yw]^2*G[{0, 1/(yu*yv)}, yw])/64 - 
     (9*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2*G[{0, 1/(yu*yv)}, yw])/128 - 
     (G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw]^2*G[{0, 1/(yu*yv)}, yw])/64 + 
     (G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2*G[{0, 1/(yu*yv)}, yw])/128 + 
     (3*G[{1}, yu^(-1)]*G[{0, 1}, yu^(-1)]*G[{0, 1/(yu*yv)}, yw])/16 + 
     (G[{1}, yw]*G[{0, 1}, yu^(-1)]*G[{0, 1/(yu*yv)}, yw])/16 - 
     (G[{yu}, yv^(-1)]*G[{0, 1}, yu^(-1)]*G[{0, 1/(yu*yv)}, yw])/8 + 
     (G[{0}, yu^(-1)]*G[{0, 1}, yv^(-1)]*G[{0, 1/(yu*yv)}, yw])/32 + 
     (G[{0}, yv^(-1)]*G[{0, 1}, yv^(-1)]*G[{0, 1/(yu*yv)}, yw])/32 - 
     (G[{0}, yw]*G[{0, 1}, yv^(-1)]*G[{0, 1/(yu*yv)}, yw])/32 + 
     (G[{1}, yu^(-1)]*G[{0, 1}, yv^(-1)]*G[{0, 1/(yu*yv)}, yw])/32 - 
     (G[{1}, yv^(-1)]*G[{0, 1}, yv^(-1)]*G[{0, 1/(yu*yv)}, yw])/32 + 
     (3*G[{1}, yw]*G[{0, 1}, yv^(-1)]*G[{0, 1/(yu*yv)}, yw])/64 + 
     (G[{yu}, yv^(-1)]*G[{0, 1}, yv^(-1)]*G[{0, 1/(yu*yv)}, yw])/16 + 
     (3*G[{1/(yu*yv)}, yw]*G[{0, 1}, yv^(-1)]*G[{0, 1/(yu*yv)}, yw])/64 - 
     (G[{1}, yu^(-1)]*G[{0, 1}, yw]*G[{0, 1/(yu*yv)}, yw])/16 + 
     (G[{1}, yv^(-1)]*G[{0, 1}, yw]*G[{0, 1/(yu*yv)}, yw])/8 - 
     (5*G[{1}, yw]*G[{0, 1}, yw]*G[{0, 1/(yu*yv)}, yw])/64 - 
     (G[{yu}, yv^(-1)]*G[{0, 1}, yw]*G[{0, 1/(yu*yv)}, yw])/16 - 
     (G[{1/(yu*yv)}, yw]*G[{0, 1}, yw]*G[{0, 1/(yu*yv)}, yw])/64 + 
     (G[{1}, yu^(-1)]*G[{0, yu^(-1)}, yw]*G[{0, 1/(yu*yv)}, yw])/16 - 
     (G[{1}, yv^(-1)]*G[{0, yu^(-1)}, yw]*G[{0, 1/(yu*yv)}, yw])/16 + 
     (5*G[{1}, yw]*G[{0, yu^(-1)}, yw]*G[{0, 1/(yu*yv)}, yw])/64 + 
     (G[{1/(yu*yv)}, yw]*G[{0, yu^(-1)}, yw]*G[{0, 1/(yu*yv)}, yw])/64 - 
     (G[{0}, yu^(-1)]*G[{0, yu}, yv^(-1)]*G[{0, 1/(yu*yv)}, yw])/32 - 
     (G[{0}, yv^(-1)]*G[{0, yu}, yv^(-1)]*G[{0, 1/(yu*yv)}, yw])/32 + 
     (G[{0}, yw]*G[{0, yu}, yv^(-1)]*G[{0, 1/(yu*yv)}, yw])/32 - 
     (G[{1}, yu^(-1)]*G[{0, yu}, yv^(-1)]*G[{0, 1/(yu*yv)}, yw])/32 + 
     (G[{1}, yv^(-1)]*G[{0, yu}, yv^(-1)]*G[{0, 1/(yu*yv)}, yw])/32 - 
     (3*G[{1}, yw]*G[{0, yu}, yv^(-1)]*G[{0, 1/(yu*yv)}, yw])/64 - 
     (G[{yu}, yv^(-1)]*G[{0, yu}, yv^(-1)]*G[{0, 1/(yu*yv)}, yw])/16 - 
     (3*G[{1/(yu*yv)}, yw]*G[{0, yu}, yv^(-1)]*G[{0, 1/(yu*yv)}, yw])/64 + 
     (G[{1}, yu^(-1)]*G[{0, yv^(-1)}, yw]*G[{0, 1/(yu*yv)}, yw])/8 - 
     (G[{1}, yv^(-1)]*G[{0, yv^(-1)}, yw]*G[{0, 1/(yu*yv)}, yw])/8 + 
     (5*G[{1}, yw]*G[{0, yv^(-1)}, yw]*G[{0, 1/(yu*yv)}, yw])/64 + 
     (G[{1/(yu*yv)}, yw]*G[{0, yv^(-1)}, yw]*G[{0, 1/(yu*yv)}, yw])/64 - 
     (G[{1}, yu^(-1)]*G[{0, 1/(yu*yv)}, yw]^2)/16 + 
     (G[{1}, yv^(-1)]*G[{0, 1/(yu*yv)}, yw]^2)/32 - 
     (5*G[{1}, yw]*G[{0, 1/(yu*yv)}, yw]^2)/128 + 
     (G[{yu}, yv^(-1)]*G[{0, 1/(yu*yv)}, yw]^2)/32 - 
     (G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv)}, yw]^2)/128 - 
     (7*Pi^2*G[{0}, yu^(-1)]*G[{1, yu^(-1)}, yw])/768 + 
     (3*G[{0}, yu^(-1)]^3*G[{1, yu^(-1)}, yw])/128 - 
     (7*Pi^2*G[{0}, yv^(-1)]*G[{1, yu^(-1)}, yw])/768 + 
     (9*G[{0}, yu^(-1)]^2*G[{0}, yv^(-1)]*G[{1, yu^(-1)}, yw])/128 + 
     (9*G[{0}, yu^(-1)]*G[{0}, yv^(-1)]^2*G[{1, yu^(-1)}, yw])/128 + 
     (3*G[{0}, yv^(-1)]^3*G[{1, yu^(-1)}, yw])/128 + 
     (7*Pi^2*G[{0}, yw]*G[{1, yu^(-1)}, yw])/768 - 
     (9*G[{0}, yu^(-1)]^2*G[{0}, yw]*G[{1, yu^(-1)}, yw])/128 - 
     (9*G[{0}, yu^(-1)]*G[{0}, yv^(-1)]*G[{0}, yw]*G[{1, yu^(-1)}, yw])/64 - 
     (9*G[{0}, yv^(-1)]^2*G[{0}, yw]*G[{1, yu^(-1)}, yw])/128 + 
     (9*G[{0}, yu^(-1)]*G[{0}, yw]^2*G[{1, yu^(-1)}, yw])/128 + 
     (9*G[{0}, yv^(-1)]*G[{0}, yw]^2*G[{1, yu^(-1)}, yw])/128 - 
     (3*G[{0}, yw]^3*G[{1, yu^(-1)}, yw])/128 + 
     (7*Pi^2*G[{1}, yu^(-1)]*G[{1, yu^(-1)}, yw])/768 - 
     (9*G[{0}, yu^(-1)]^2*G[{1}, yu^(-1)]*G[{1, yu^(-1)}, yw])/128 - 
     (9*G[{0}, yu^(-1)]*G[{0}, yv^(-1)]*G[{1}, yu^(-1)]*G[{1, yu^(-1)}, yw])/
      64 - (9*G[{0}, yv^(-1)]^2*G[{1}, yu^(-1)]*G[{1, yu^(-1)}, yw])/128 + 
     (9*G[{0}, yu^(-1)]*G[{0}, yw]*G[{1}, yu^(-1)]*G[{1, yu^(-1)}, yw])/64 + 
     (9*G[{0}, yv^(-1)]*G[{0}, yw]*G[{1}, yu^(-1)]*G[{1, yu^(-1)}, yw])/64 - 
     (9*G[{0}, yw]^2*G[{1}, yu^(-1)]*G[{1, yu^(-1)}, yw])/128 + 
     (9*G[{0}, yu^(-1)]*G[{1}, yu^(-1)]^2*G[{1, yu^(-1)}, yw])/128 + 
     (9*G[{0}, yv^(-1)]*G[{1}, yu^(-1)]^2*G[{1, yu^(-1)}, yw])/128 - 
     (9*G[{0}, yw]*G[{1}, yu^(-1)]^2*G[{1, yu^(-1)}, yw])/128 - 
     (3*G[{1}, yu^(-1)]^3*G[{1, yu^(-1)}, yw])/128 - 
     (3*Pi^2*G[{1}, yv^(-1)]*G[{1, yu^(-1)}, yw])/256 - 
     (13*G[{0}, yu^(-1)]^2*G[{1}, yv^(-1)]*G[{1, yu^(-1)}, yw])/128 - 
     (13*G[{0}, yu^(-1)]*G[{0}, yv^(-1)]*G[{1}, yv^(-1)]*G[{1, yu^(-1)}, yw])/
      64 - (13*G[{0}, yv^(-1)]^2*G[{1}, yv^(-1)]*G[{1, yu^(-1)}, yw])/128 + 
     (13*G[{0}, yu^(-1)]*G[{0}, yw]*G[{1}, yv^(-1)]*G[{1, yu^(-1)}, yw])/64 + 
     (13*G[{0}, yv^(-1)]*G[{0}, yw]*G[{1}, yv^(-1)]*G[{1, yu^(-1)}, yw])/64 - 
     (13*G[{0}, yw]^2*G[{1}, yv^(-1)]*G[{1, yu^(-1)}, yw])/128 + 
     (5*G[{0}, yu^(-1)]*G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*G[{1, yu^(-1)}, yw])/
      64 + (5*G[{0}, yv^(-1)]*G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*
       G[{1, yu^(-1)}, yw])/64 - (5*G[{0}, yw]*G[{1}, yu^(-1)]*
       G[{1}, yv^(-1)]*G[{1, yu^(-1)}, yw])/64 + 
     (3*G[{1}, yu^(-1)]^2*G[{1}, yv^(-1)]*G[{1, yu^(-1)}, yw])/128 + 
     (11*G[{0}, yu^(-1)]*G[{1}, yv^(-1)]^2*G[{1, yu^(-1)}, yw])/128 + 
     (11*G[{0}, yv^(-1)]*G[{1}, yv^(-1)]^2*G[{1, yu^(-1)}, yw])/128 - 
     (11*G[{0}, yw]*G[{1}, yv^(-1)]^2*G[{1, yu^(-1)}, yw])/128 - 
     (11*G[{1}, yu^(-1)]*G[{1}, yv^(-1)]^2*G[{1, yu^(-1)}, yw])/128 - 
     (G[{1}, yv^(-1)]^3*G[{1, yu^(-1)}, yw])/128 - 
     (7*Pi^2*G[{1}, yw]*G[{1, yu^(-1)}, yw])/384 - 
     (G[{0}, yu^(-1)]^2*G[{1}, yw]*G[{1, yu^(-1)}, yw])/128 - 
     (G[{0}, yu^(-1)]*G[{0}, yv^(-1)]*G[{1}, yw]*G[{1, yu^(-1)}, yw])/64 - 
     (G[{0}, yv^(-1)]^2*G[{1}, yw]*G[{1, yu^(-1)}, yw])/128 + 
     (G[{0}, yu^(-1)]*G[{0}, yw]*G[{1}, yw]*G[{1, yu^(-1)}, yw])/64 + 
     (G[{0}, yv^(-1)]*G[{0}, yw]*G[{1}, yw]*G[{1, yu^(-1)}, yw])/64 - 
     (G[{0}, yw]^2*G[{1}, yw]*G[{1, yu^(-1)}, yw])/128 + 
     (G[{0}, yu^(-1)]*G[{1}, yu^(-1)]*G[{1}, yw]*G[{1, yu^(-1)}, yw])/64 + 
     (G[{0}, yv^(-1)]*G[{1}, yu^(-1)]*G[{1}, yw]*G[{1, yu^(-1)}, yw])/64 - 
     (G[{0}, yw]*G[{1}, yu^(-1)]*G[{1}, yw]*G[{1, yu^(-1)}, yw])/64 - 
     (G[{1}, yu^(-1)]^2*G[{1}, yw]*G[{1, yu^(-1)}, yw])/128 - 
     (G[{0}, yu^(-1)]*G[{1}, yv^(-1)]*G[{1}, yw]*G[{1, yu^(-1)}, yw])/64 - 
     (G[{0}, yv^(-1)]*G[{1}, yv^(-1)]*G[{1}, yw]*G[{1, yu^(-1)}, yw])/64 + 
     (G[{0}, yw]*G[{1}, yv^(-1)]*G[{1}, yw]*G[{1, yu^(-1)}, yw])/64 - 
     (7*G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*G[{1}, yw]*G[{1, yu^(-1)}, yw])/64 + 
     (3*G[{1}, yv^(-1)]^2*G[{1}, yw]*G[{1, yu^(-1)}, yw])/128 + 
     (3*G[{0}, yu^(-1)]*G[{1}, yw]^2*G[{1, yu^(-1)}, yw])/128 + 
     (3*G[{0}, yv^(-1)]*G[{1}, yw]^2*G[{1, yu^(-1)}, yw])/128 - 
     (3*G[{0}, yw]*G[{1}, yw]^2*G[{1, yu^(-1)}, yw])/128 - 
     (3*G[{1}, yu^(-1)]*G[{1}, yw]^2*G[{1, yu^(-1)}, yw])/128 - 
     (3*G[{1}, yv^(-1)]*G[{1}, yw]^2*G[{1, yu^(-1)}, yw])/128 + 
     (Pi^2*G[{yu}, yv^(-1)]*G[{1, yu^(-1)}, yw])/48 + 
     (G[{0}, yu^(-1)]^2*G[{yu}, yv^(-1)]*G[{1, yu^(-1)}, yw])/32 + 
     (G[{0}, yu^(-1)]*G[{0}, yv^(-1)]*G[{yu}, yv^(-1)]*G[{1, yu^(-1)}, yw])/
      16 + (G[{0}, yv^(-1)]^2*G[{yu}, yv^(-1)]*G[{1, yu^(-1)}, yw])/32 - 
     (G[{0}, yu^(-1)]*G[{0}, yw]*G[{yu}, yv^(-1)]*G[{1, yu^(-1)}, yw])/16 - 
     (G[{0}, yv^(-1)]*G[{0}, yw]*G[{yu}, yv^(-1)]*G[{1, yu^(-1)}, yw])/16 + 
     (G[{0}, yw]^2*G[{yu}, yv^(-1)]*G[{1, yu^(-1)}, yw])/32 + 
     (G[{0}, yu^(-1)]*G[{1}, yu^(-1)]*G[{yu}, yv^(-1)]*G[{1, yu^(-1)}, yw])/
      16 + (G[{0}, yv^(-1)]*G[{1}, yu^(-1)]*G[{yu}, yv^(-1)]*
       G[{1, yu^(-1)}, yw])/16 - (G[{0}, yw]*G[{1}, yu^(-1)]*G[{yu}, yv^(-1)]*
       G[{1, yu^(-1)}, yw])/16 - (3*G[{1}, yu^(-1)]^2*G[{yu}, yv^(-1)]*
       G[{1, yu^(-1)}, yw])/32 + (G[{0}, yu^(-1)]*G[{1}, yv^(-1)]*
       G[{yu}, yv^(-1)]*G[{1, yu^(-1)}, yw])/16 + 
     (G[{0}, yv^(-1)]*G[{1}, yv^(-1)]*G[{yu}, yv^(-1)]*G[{1, yu^(-1)}, yw])/
      16 - (G[{0}, yw]*G[{1}, yv^(-1)]*G[{yu}, yv^(-1)]*G[{1, yu^(-1)}, yw])/
      16 + (G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*G[{yu}, yv^(-1)]*
       G[{1, yu^(-1)}, yw])/16 - (3*G[{1}, yv^(-1)]^2*G[{yu}, yv^(-1)]*
       G[{1, yu^(-1)}, yw])/32 + (G[{0}, yu^(-1)]*G[{1}, yw]*G[{yu}, yv^(-1)]*
       G[{1, yu^(-1)}, yw])/32 + (G[{0}, yv^(-1)]*G[{1}, yw]*G[{yu}, yv^(-1)]*
       G[{1, yu^(-1)}, yw])/32 - (G[{0}, yw]*G[{1}, yw]*G[{yu}, yv^(-1)]*
       G[{1, yu^(-1)}, yw])/32 + (3*G[{1}, yu^(-1)]*G[{1}, yw]*
       G[{yu}, yv^(-1)]*G[{1, yu^(-1)}, yw])/32 - 
     (G[{1}, yv^(-1)]*G[{1}, yw]*G[{yu}, yv^(-1)]*G[{1, yu^(-1)}, yw])/32 - 
     (G[{0}, yu^(-1)]*G[{yu}, yv^(-1)]^2*G[{1, yu^(-1)}, yw])/8 - 
     (G[{0}, yv^(-1)]*G[{yu}, yv^(-1)]^2*G[{1, yu^(-1)}, yw])/8 + 
     (G[{0}, yw]*G[{yu}, yv^(-1)]^2*G[{1, yu^(-1)}, yw])/8 + 
     (G[{1}, yv^(-1)]*G[{yu}, yv^(-1)]^2*G[{1, yu^(-1)}, yw])/16 - 
     (G[{1}, yw]*G[{yu}, yv^(-1)]^2*G[{1, yu^(-1)}, yw])/16 + 
     (G[{yu}, yv^(-1)]^3*G[{1, yu^(-1)}, yw])/16 + 
     (7*Pi^2*G[{1/(yu*yv)}, yw]*G[{1, yu^(-1)}, yw])/768 + 
     (11*G[{0}, yu^(-1)]^2*G[{1/(yu*yv)}, yw]*G[{1, yu^(-1)}, yw])/128 + 
     (11*G[{0}, yu^(-1)]*G[{0}, yv^(-1)]*G[{1/(yu*yv)}, yw]*
       G[{1, yu^(-1)}, yw])/64 + (11*G[{0}, yv^(-1)]^2*G[{1/(yu*yv)}, yw]*
       G[{1, yu^(-1)}, yw])/128 - (11*G[{0}, yu^(-1)]*G[{0}, yw]*
       G[{1/(yu*yv)}, yw]*G[{1, yu^(-1)}, yw])/64 - 
     (11*G[{0}, yv^(-1)]*G[{0}, yw]*G[{1/(yu*yv)}, yw]*G[{1, yu^(-1)}, yw])/
      64 + (11*G[{0}, yw]^2*G[{1/(yu*yv)}, yw]*G[{1, yu^(-1)}, yw])/128 - 
     (11*G[{0}, yu^(-1)]*G[{1}, yu^(-1)]*G[{1/(yu*yv)}, yw]*
       G[{1, yu^(-1)}, yw])/64 - (11*G[{0}, yv^(-1)]*G[{1}, yu^(-1)]*
       G[{1/(yu*yv)}, yw]*G[{1, yu^(-1)}, yw])/64 + 
     (11*G[{0}, yw]*G[{1}, yu^(-1)]*G[{1/(yu*yv)}, yw]*G[{1, yu^(-1)}, yw])/
      64 + (11*G[{1}, yu^(-1)]^2*G[{1/(yu*yv)}, yw]*G[{1, yu^(-1)}, yw])/
      128 - (9*G[{0}, yu^(-1)]*G[{1}, yv^(-1)]*G[{1/(yu*yv)}, yw]*
       G[{1, yu^(-1)}, yw])/64 - (9*G[{0}, yv^(-1)]*G[{1}, yv^(-1)]*
       G[{1/(yu*yv)}, yw]*G[{1, yu^(-1)}, yw])/64 + 
     (9*G[{0}, yw]*G[{1}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{1, yu^(-1)}, yw])/
      64 + (9*G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*G[{1/(yu*yv)}, yw]*
       G[{1, yu^(-1)}, yw])/64 + (G[{1}, yv^(-1)]^2*G[{1/(yu*yv)}, yw]*
       G[{1, yu^(-1)}, yw])/32 + (G[{0}, yu^(-1)]*G[{1}, yw]*
       G[{1/(yu*yv)}, yw]*G[{1, yu^(-1)}, yw])/16 + 
     (G[{0}, yv^(-1)]*G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{1, yu^(-1)}, yw])/16 - 
     (G[{0}, yw]*G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{1, yu^(-1)}, yw])/16 - 
     (G[{1}, yu^(-1)]*G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{1, yu^(-1)}, yw])/16 - 
     (7*G[{1}, yv^(-1)]*G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{1, yu^(-1)}, yw])/
      64 - (3*G[{1}, yw]^2*G[{1/(yu*yv)}, yw]*G[{1, yu^(-1)}, yw])/128 + 
     (G[{0}, yu^(-1)]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*
       G[{1, yu^(-1)}, yw])/16 + (G[{0}, yv^(-1)]*G[{yu^(-1)}, yw]*
       G[{1/(yu*yv)}, yw]*G[{1, yu^(-1)}, yw])/16 - 
     (G[{0}, yw]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{1, yu^(-1)}, yw])/
      16 - (G[{1}, yu^(-1)]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*
       G[{1, yu^(-1)}, yw])/16 + (G[{1}, yw]*G[{yu^(-1)}, yw]*
       G[{1/(yu*yv)}, yw]*G[{1, yu^(-1)}, yw])/16 + 
     (G[{yu^(-1)}, yw]^2*G[{1/(yu*yv)}, yw]*G[{1, yu^(-1)}, yw])/64 - 
     (G[{0}, yu^(-1)]*G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw]*
       G[{1, yu^(-1)}, yw])/32 - (G[{0}, yv^(-1)]*G[{yu}, yv^(-1)]*
       G[{1/(yu*yv)}, yw]*G[{1, yu^(-1)}, yw])/32 + 
     (G[{0}, yw]*G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{1, yu^(-1)}, yw])/
      32 + (G[{1}, yu^(-1)]*G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw]*
       G[{1, yu^(-1)}, yw])/32 + (3*G[{1}, yv^(-1)]*G[{yu}, yv^(-1)]*
       G[{1/(yu*yv)}, yw]*G[{1, yu^(-1)}, yw])/32 + 
     (3*G[{1}, yw]*G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{1, yu^(-1)}, yw])/
      64 - (G[{yu^(-1)}, yw]*G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw]*
       G[{1, yu^(-1)}, yw])/16 - (G[{yu}, yv^(-1)]^2*G[{1/(yu*yv)}, yw]*
       G[{1, yu^(-1)}, yw])/32 - (G[{0}, yu^(-1)]*G[{yv^(-1)}, yw]*
       G[{1/(yu*yv)}, yw]*G[{1, yu^(-1)}, yw])/32 - 
     (G[{0}, yv^(-1)]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*
       G[{1, yu^(-1)}, yw])/32 + (G[{0}, yw]*G[{yv^(-1)}, yw]*
       G[{1/(yu*yv)}, yw]*G[{1, yu^(-1)}, yw])/32 - 
     (G[{1}, yu^(-1)]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*
       G[{1, yu^(-1)}, yw])/32 + (5*G[{1}, yv^(-1)]*G[{yv^(-1)}, yw]*
       G[{1/(yu*yv)}, yw]*G[{1, yu^(-1)}, yw])/32 + 
     (G[{1}, yw]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{1, yu^(-1)}, yw])/
      16 - (G[{yu^(-1)}, yw]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*
       G[{1, yu^(-1)}, yw])/32 - (G[{yu}, yv^(-1)]*G[{yv^(-1)}, yw]*
       G[{1/(yu*yv)}, yw]*G[{1, yu^(-1)}, yw])/16 + 
     (3*G[{yv^(-1)}, yw]^2*G[{1/(yu*yv)}, yw]*G[{1, yu^(-1)}, yw])/64 + 
     (G[{0}, yu^(-1)]*G[{1/(yu*yv)}, yw]^2*G[{1, yu^(-1)}, yw])/64 + 
     (G[{0}, yv^(-1)]*G[{1/(yu*yv)}, yw]^2*G[{1, yu^(-1)}, yw])/64 - 
     (G[{0}, yw]*G[{1/(yu*yv)}, yw]^2*G[{1, yu^(-1)}, yw])/64 - 
     (7*G[{1}, yu^(-1)]*G[{1/(yu*yv)}, yw]^2*G[{1, yu^(-1)}, yw])/64 + 
     (G[{1}, yv^(-1)]*G[{1/(yu*yv)}, yw]^2*G[{1, yu^(-1)}, yw])/32 - 
     (3*G[{1}, yw]*G[{1/(yu*yv)}, yw]^2*G[{1, yu^(-1)}, yw])/64 - 
     (5*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2*G[{1, yu^(-1)}, yw])/64 + 
     (3*G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw]^2*G[{1, yu^(-1)}, yw])/64 + 
     (G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2*G[{1, yu^(-1)}, yw])/16 - 
     (G[{0}, yu^(-1)]*G[{0, 1}, yu^(-1)]*G[{1, yu^(-1)}, yw])/8 - 
     (G[{0}, yv^(-1)]*G[{0, 1}, yu^(-1)]*G[{1, yu^(-1)}, yw])/8 + 
     (G[{0}, yw]*G[{0, 1}, yu^(-1)]*G[{1, yu^(-1)}, yw])/8 + 
     (G[{1}, yu^(-1)]*G[{0, 1}, yu^(-1)]*G[{1, yu^(-1)}, yw])/8 - 
     (G[{1}, yw]*G[{0, 1}, yu^(-1)]*G[{1, yu^(-1)}, yw])/8 + 
     (G[{yu}, yv^(-1)]*G[{0, 1}, yu^(-1)]*G[{1, yu^(-1)}, yw])/8 - 
     (G[{0}, yu^(-1)]*G[{0, 1}, yv^(-1)]*G[{1, yu^(-1)}, yw])/32 - 
     (G[{0}, yv^(-1)]*G[{0, 1}, yv^(-1)]*G[{1, yu^(-1)}, yw])/32 + 
     (G[{0}, yw]*G[{0, 1}, yv^(-1)]*G[{1, yu^(-1)}, yw])/32 + 
     (G[{1}, yu^(-1)]*G[{0, 1}, yv^(-1)]*G[{1, yu^(-1)}, yw])/32 + 
     (G[{1}, yv^(-1)]*G[{0, 1}, yv^(-1)]*G[{1, yu^(-1)}, yw])/32 - 
     (G[{1/(yu*yv)}, yw]*G[{0, 1}, yv^(-1)]*G[{1, yu^(-1)}, yw])/64 + 
     (G[{0}, yu^(-1)]*G[{0, 1}, yw]*G[{1, yu^(-1)}, yw])/32 + 
     (G[{0}, yv^(-1)]*G[{0, 1}, yw]*G[{1, yu^(-1)}, yw])/32 - 
     (G[{0}, yw]*G[{0, 1}, yw]*G[{1, yu^(-1)}, yw])/32 - 
     (G[{1}, yu^(-1)]*G[{0, 1}, yw]*G[{1, yu^(-1)}, yw])/32 + 
     (G[{1}, yv^(-1)]*G[{0, 1}, yw]*G[{1, yu^(-1)}, yw])/32 + 
     (5*G[{1}, yw]*G[{0, 1}, yw]*G[{1, yu^(-1)}, yw])/64 - 
     (G[{yu}, yv^(-1)]*G[{0, 1}, yw]*G[{1, yu^(-1)}, yw])/16 + 
     (G[{1/(yu*yv)}, yw]*G[{0, 1}, yw]*G[{1, yu^(-1)}, yw])/32 - 
     (G[{0}, yu^(-1)]*G[{0, yu^(-1)}, yw]*G[{1, yu^(-1)}, yw])/32 - 
     (G[{0}, yv^(-1)]*G[{0, yu^(-1)}, yw]*G[{1, yu^(-1)}, yw])/32 + 
     (G[{0}, yw]*G[{0, yu^(-1)}, yw]*G[{1, yu^(-1)}, yw])/32 + 
     (G[{1}, yu^(-1)]*G[{0, yu^(-1)}, yw]*G[{1, yu^(-1)}, yw])/32 - 
     (G[{1}, yv^(-1)]*G[{0, yu^(-1)}, yw]*G[{1, yu^(-1)}, yw])/32 - 
     (5*G[{1}, yw]*G[{0, yu^(-1)}, yw]*G[{1, yu^(-1)}, yw])/64 + 
     (G[{yu}, yv^(-1)]*G[{0, yu^(-1)}, yw]*G[{1, yu^(-1)}, yw])/16 - 
     (G[{1/(yu*yv)}, yw]*G[{0, yu^(-1)}, yw]*G[{1, yu^(-1)}, yw])/32 + 
     (G[{0}, yu^(-1)]*G[{0, yu}, yv^(-1)]*G[{1, yu^(-1)}, yw])/32 + 
     (G[{0}, yv^(-1)]*G[{0, yu}, yv^(-1)]*G[{1, yu^(-1)}, yw])/32 - 
     (G[{0}, yw]*G[{0, yu}, yv^(-1)]*G[{1, yu^(-1)}, yw])/32 - 
     (G[{1}, yu^(-1)]*G[{0, yu}, yv^(-1)]*G[{1, yu^(-1)}, yw])/32 - 
     (G[{1}, yv^(-1)]*G[{0, yu}, yv^(-1)]*G[{1, yu^(-1)}, yw])/32 + 
     (G[{1/(yu*yv)}, yw]*G[{0, yu}, yv^(-1)]*G[{1, yu^(-1)}, yw])/64 - 
     (G[{0}, yu^(-1)]*G[{0, yv^(-1)}, yw]*G[{1, yu^(-1)}, yw])/32 - 
     (G[{0}, yv^(-1)]*G[{0, yv^(-1)}, yw]*G[{1, yu^(-1)}, yw])/32 + 
     (G[{0}, yw]*G[{0, yv^(-1)}, yw]*G[{1, yu^(-1)}, yw])/32 + 
     (G[{1}, yu^(-1)]*G[{0, yv^(-1)}, yw]*G[{1, yu^(-1)}, yw])/32 - 
     (G[{1}, yv^(-1)]*G[{0, yv^(-1)}, yw]*G[{1, yu^(-1)}, yw])/32 - 
     (5*G[{1}, yw]*G[{0, yv^(-1)}, yw]*G[{1, yu^(-1)}, yw])/64 + 
     (G[{yu}, yv^(-1)]*G[{0, yv^(-1)}, yw]*G[{1, yu^(-1)}, yw])/16 - 
     (G[{1/(yu*yv)}, yw]*G[{0, yv^(-1)}, yw]*G[{1, yu^(-1)}, yw])/32 + 
     (G[{0}, yu^(-1)]*G[{0, 1/(yu*yv)}, yw]*G[{1, yu^(-1)}, yw])/32 + 
     (G[{0}, yv^(-1)]*G[{0, 1/(yu*yv)}, yw]*G[{1, yu^(-1)}, yw])/32 - 
     (G[{0}, yw]*G[{0, 1/(yu*yv)}, yw]*G[{1, yu^(-1)}, yw])/32 - 
     (G[{1}, yu^(-1)]*G[{0, 1/(yu*yv)}, yw]*G[{1, yu^(-1)}, yw])/32 + 
     (G[{1}, yv^(-1)]*G[{0, 1/(yu*yv)}, yw]*G[{1, yu^(-1)}, yw])/32 + 
     (5*G[{1}, yw]*G[{0, 1/(yu*yv)}, yw]*G[{1, yu^(-1)}, yw])/64 - 
     (G[{yu}, yv^(-1)]*G[{0, 1/(yu*yv)}, yw]*G[{1, yu^(-1)}, yw])/16 + 
     (G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv)}, yw]*G[{1, yu^(-1)}, yw])/32 + 
     (G[{1}, yv^(-1)]*G[{1, yu^(-1)}, yw]^2)/32 + 
     (G[{1}, yw]*G[{1, yu^(-1)}, yw]^2)/32 - 
     (G[{yu}, yv^(-1)]*G[{1, yu^(-1)}, yw]^2)/32 + 
     (G[{1/(yu*yv)}, yw]*G[{1, yu^(-1)}, yw]^2)/128 + 
     (7*Pi^2*G[{0}, yu^(-1)]*G[{1, yu}, yv^(-1)])/384 + 
     (3*G[{0}, yu^(-1)]^3*G[{1, yu}, yv^(-1)])/128 + 
     (7*Pi^2*G[{0}, yv^(-1)]*G[{1, yu}, yv^(-1)])/384 + 
     (9*G[{0}, yu^(-1)]^2*G[{0}, yv^(-1)]*G[{1, yu}, yv^(-1)])/128 + 
     (9*G[{0}, yu^(-1)]*G[{0}, yv^(-1)]^2*G[{1, yu}, yv^(-1)])/128 + 
     (3*G[{0}, yv^(-1)]^3*G[{1, yu}, yv^(-1)])/128 - 
     (7*Pi^2*G[{0}, yw]*G[{1, yu}, yv^(-1)])/384 - 
     (9*G[{0}, yu^(-1)]^2*G[{0}, yw]*G[{1, yu}, yv^(-1)])/128 - 
     (9*G[{0}, yu^(-1)]*G[{0}, yv^(-1)]*G[{0}, yw]*G[{1, yu}, yv^(-1)])/64 - 
     (9*G[{0}, yv^(-1)]^2*G[{0}, yw]*G[{1, yu}, yv^(-1)])/128 + 
     (9*G[{0}, yu^(-1)]*G[{0}, yw]^2*G[{1, yu}, yv^(-1)])/128 + 
     (9*G[{0}, yv^(-1)]*G[{0}, yw]^2*G[{1, yu}, yv^(-1)])/128 - 
     (3*G[{0}, yw]^3*G[{1, yu}, yv^(-1)])/128 + 
     (Pi^2*G[{1}, yu^(-1)]*G[{1, yu}, yv^(-1)])/384 + 
     (3*G[{0}, yu^(-1)]^2*G[{1}, yu^(-1)]*G[{1, yu}, yv^(-1)])/128 + 
     (3*G[{0}, yu^(-1)]*G[{0}, yv^(-1)]*G[{1}, yu^(-1)]*G[{1, yu}, yv^(-1)])/
      64 + (3*G[{0}, yv^(-1)]^2*G[{1}, yu^(-1)]*G[{1, yu}, yv^(-1)])/128 - 
     (3*G[{0}, yu^(-1)]*G[{0}, yw]*G[{1}, yu^(-1)]*G[{1, yu}, yv^(-1)])/64 - 
     (3*G[{0}, yv^(-1)]*G[{0}, yw]*G[{1}, yu^(-1)]*G[{1, yu}, yv^(-1)])/64 + 
     (3*G[{0}, yw]^2*G[{1}, yu^(-1)]*G[{1, yu}, yv^(-1)])/128 - 
     (11*G[{0}, yu^(-1)]*G[{1}, yu^(-1)]^2*G[{1, yu}, yv^(-1)])/128 - 
     (11*G[{0}, yv^(-1)]*G[{1}, yu^(-1)]^2*G[{1, yu}, yv^(-1)])/128 + 
     (11*G[{0}, yw]*G[{1}, yu^(-1)]^2*G[{1, yu}, yv^(-1)])/128 + 
     (5*G[{1}, yu^(-1)]^3*G[{1, yu}, yv^(-1)])/128 - 
     (7*Pi^2*G[{1}, yv^(-1)]*G[{1, yu}, yv^(-1)])/384 - 
     (G[{0}, yu^(-1)]^2*G[{1}, yv^(-1)]*G[{1, yu}, yv^(-1)])/128 - 
     (G[{0}, yu^(-1)]*G[{0}, yv^(-1)]*G[{1}, yv^(-1)]*G[{1, yu}, yv^(-1)])/
      64 - (G[{0}, yv^(-1)]^2*G[{1}, yv^(-1)]*G[{1, yu}, yv^(-1)])/128 + 
     (G[{0}, yu^(-1)]*G[{0}, yw]*G[{1}, yv^(-1)]*G[{1, yu}, yv^(-1)])/64 + 
     (G[{0}, yv^(-1)]*G[{0}, yw]*G[{1}, yv^(-1)]*G[{1, yu}, yv^(-1)])/64 - 
     (G[{0}, yw]^2*G[{1}, yv^(-1)]*G[{1, yu}, yv^(-1)])/128 + 
     (G[{0}, yu^(-1)]*G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*G[{1, yu}, yv^(-1)])/
      64 + (G[{0}, yv^(-1)]*G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*
       G[{1, yu}, yv^(-1)])/64 - (G[{0}, yw]*G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*
       G[{1, yu}, yv^(-1)])/64 + (3*G[{1}, yu^(-1)]^2*G[{1}, yv^(-1)]*
       G[{1, yu}, yv^(-1)])/128 - (7*G[{0}, yu^(-1)]*G[{1}, yv^(-1)]^2*
       G[{1, yu}, yv^(-1)])/128 - (7*G[{0}, yv^(-1)]*G[{1}, yv^(-1)]^2*
       G[{1, yu}, yv^(-1)])/128 + (7*G[{0}, yw]*G[{1}, yv^(-1)]^2*
       G[{1, yu}, yv^(-1)])/128 - (G[{1}, yu^(-1)]*G[{1}, yv^(-1)]^2*
       G[{1, yu}, yv^(-1)])/128 + (5*G[{1}, yv^(-1)]^3*G[{1, yu}, yv^(-1)])/
      128 + (5*Pi^2*G[{1}, yw]*G[{1, yu}, yv^(-1)])/128 + 
     (13*G[{0}, yu^(-1)]^2*G[{1}, yw]*G[{1, yu}, yv^(-1)])/128 + 
     (13*G[{0}, yu^(-1)]*G[{0}, yv^(-1)]*G[{1}, yw]*G[{1, yu}, yv^(-1)])/64 + 
     (13*G[{0}, yv^(-1)]^2*G[{1}, yw]*G[{1, yu}, yv^(-1)])/128 - 
     (13*G[{0}, yu^(-1)]*G[{0}, yw]*G[{1}, yw]*G[{1, yu}, yv^(-1)])/64 - 
     (13*G[{0}, yv^(-1)]*G[{0}, yw]*G[{1}, yw]*G[{1, yu}, yv^(-1)])/64 + 
     (13*G[{0}, yw]^2*G[{1}, yw]*G[{1, yu}, yv^(-1)])/128 - 
     (G[{0}, yu^(-1)]*G[{1}, yu^(-1)]*G[{1}, yw]*G[{1, yu}, yv^(-1)])/64 - 
     (G[{0}, yv^(-1)]*G[{1}, yu^(-1)]*G[{1}, yw]*G[{1, yu}, yv^(-1)])/64 + 
     (G[{0}, yw]*G[{1}, yu^(-1)]*G[{1}, yw]*G[{1, yu}, yv^(-1)])/64 - 
     (11*G[{1}, yu^(-1)]^2*G[{1}, yw]*G[{1, yu}, yv^(-1)])/128 - 
     (G[{0}, yu^(-1)]*G[{1}, yv^(-1)]*G[{1}, yw]*G[{1, yu}, yv^(-1)])/64 - 
     (G[{0}, yv^(-1)]*G[{1}, yv^(-1)]*G[{1}, yw]*G[{1, yu}, yv^(-1)])/64 + 
     (G[{0}, yw]*G[{1}, yv^(-1)]*G[{1}, yw]*G[{1, yu}, yv^(-1)])/64 + 
     (9*G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*G[{1}, yw]*G[{1, yu}, yv^(-1)])/64 - 
     (11*G[{1}, yv^(-1)]^2*G[{1}, yw]*G[{1, yu}, yv^(-1)])/128 + 
     (3*G[{0}, yu^(-1)]*G[{1}, yw]^2*G[{1, yu}, yv^(-1)])/128 + 
     (3*G[{0}, yv^(-1)]*G[{1}, yw]^2*G[{1, yu}, yv^(-1)])/128 - 
     (3*G[{0}, yw]*G[{1}, yw]^2*G[{1, yu}, yv^(-1)])/128 + 
     (G[{1}, yu^(-1)]*G[{1}, yw]^2*G[{1, yu}, yv^(-1)])/128 + 
     (5*G[{1}, yv^(-1)]*G[{1}, yw]^2*G[{1, yu}, yv^(-1)])/128 - 
     (3*G[{0}, yu^(-1)]*G[{1}, yw]*G[{yu}, yv^(-1)]*G[{1, yu}, yv^(-1)])/16 - 
     (3*G[{0}, yv^(-1)]*G[{1}, yw]*G[{yu}, yv^(-1)]*G[{1, yu}, yv^(-1)])/16 + 
     (3*G[{0}, yw]*G[{1}, yw]*G[{yu}, yv^(-1)]*G[{1, yu}, yv^(-1)])/16 + 
     (G[{1}, yu^(-1)]*G[{1}, yw]*G[{yu}, yv^(-1)]*G[{1, yu}, yv^(-1)])/8 + 
     (3*G[{1}, yv^(-1)]*G[{1}, yw]*G[{yu}, yv^(-1)]*G[{1, yu}, yv^(-1)])/16 - 
     (G[{1}, yw]^2*G[{yu}, yv^(-1)]*G[{1, yu}, yv^(-1)])/16 + 
     (G[{1}, yw]*G[{yu}, yv^(-1)]^2*G[{1, yu}, yv^(-1)])/8 - 
     (Pi^2*G[{1/(yu*yv)}, yw]*G[{1, yu}, yv^(-1)])/384 + 
     (5*G[{0}, yu^(-1)]^2*G[{1/(yu*yv)}, yw]*G[{1, yu}, yv^(-1)])/128 + 
     (5*G[{0}, yu^(-1)]*G[{0}, yv^(-1)]*G[{1/(yu*yv)}, yw]*
       G[{1, yu}, yv^(-1)])/64 + (5*G[{0}, yv^(-1)]^2*G[{1/(yu*yv)}, yw]*
       G[{1, yu}, yv^(-1)])/128 - (5*G[{0}, yu^(-1)]*G[{0}, yw]*
       G[{1/(yu*yv)}, yw]*G[{1, yu}, yv^(-1)])/64 - 
     (5*G[{0}, yv^(-1)]*G[{0}, yw]*G[{1/(yu*yv)}, yw]*G[{1, yu}, yv^(-1)])/
      64 + (5*G[{0}, yw]^2*G[{1/(yu*yv)}, yw]*G[{1, yu}, yv^(-1)])/128 + 
     (7*G[{0}, yu^(-1)]*G[{1}, yu^(-1)]*G[{1/(yu*yv)}, yw]*
       G[{1, yu}, yv^(-1)])/64 + (7*G[{0}, yv^(-1)]*G[{1}, yu^(-1)]*
       G[{1/(yu*yv)}, yw]*G[{1, yu}, yv^(-1)])/64 - 
     (7*G[{0}, yw]*G[{1}, yu^(-1)]*G[{1/(yu*yv)}, yw]*G[{1, yu}, yv^(-1)])/
      64 - (11*G[{1}, yu^(-1)]^2*G[{1/(yu*yv)}, yw]*G[{1, yu}, yv^(-1)])/
      128 - (G[{0}, yu^(-1)]*G[{1}, yv^(-1)]*G[{1/(yu*yv)}, yw]*
       G[{1, yu}, yv^(-1)])/64 - (G[{0}, yv^(-1)]*G[{1}, yv^(-1)]*
       G[{1/(yu*yv)}, yw]*G[{1, yu}, yv^(-1)])/64 + 
     (G[{0}, yw]*G[{1}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{1, yu}, yv^(-1)])/64 - 
     (7*G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*G[{1/(yu*yv)}, yw]*
       G[{1, yu}, yv^(-1)])/64 - (3*G[{1}, yv^(-1)]^2*G[{1/(yu*yv)}, yw]*
       G[{1, yu}, yv^(-1)])/128 - (5*G[{0}, yu^(-1)]*G[{1}, yw]*
       G[{1/(yu*yv)}, yw]*G[{1, yu}, yv^(-1)])/64 - 
     (5*G[{0}, yv^(-1)]*G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{1, yu}, yv^(-1)])/
      64 + (5*G[{0}, yw]*G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{1, yu}, yv^(-1)])/
      64 + (9*G[{1}, yu^(-1)]*G[{1}, yw]*G[{1/(yu*yv)}, yw]*
       G[{1, yu}, yv^(-1)])/64 + (5*G[{1}, yv^(-1)]*G[{1}, yw]*
       G[{1/(yu*yv)}, yw]*G[{1, yu}, yv^(-1)])/64 + 
     (3*G[{0}, yu^(-1)]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*
       G[{1, yu}, yv^(-1)])/32 + (3*G[{0}, yv^(-1)]*G[{yu^(-1)}, yw]*
       G[{1/(yu*yv)}, yw]*G[{1, yu}, yv^(-1)])/32 - 
     (3*G[{0}, yw]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{1, yu}, yv^(-1)])/
      32 + (5*G[{1}, yu^(-1)]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*
       G[{1, yu}, yv^(-1)])/32 - (3*G[{1}, yv^(-1)]*G[{yu^(-1)}, yw]*
       G[{1/(yu*yv)}, yw]*G[{1, yu}, yv^(-1)])/32 + 
     (7*G[{yu^(-1)}, yw]^2*G[{1/(yu*yv)}, yw]*G[{1, yu}, yv^(-1)])/64 + 
     (3*G[{0}, yu^(-1)]*G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw]*
       G[{1, yu}, yv^(-1)])/16 + (3*G[{0}, yv^(-1)]*G[{yu}, yv^(-1)]*
       G[{1/(yu*yv)}, yw]*G[{1, yu}, yv^(-1)])/16 - 
     (3*G[{0}, yw]*G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{1, yu}, yv^(-1)])/
      16 - (G[{1}, yu^(-1)]*G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw]*
       G[{1, yu}, yv^(-1)])/8 - (3*G[{1}, yv^(-1)]*G[{yu}, yv^(-1)]*
       G[{1/(yu*yv)}, yw]*G[{1, yu}, yv^(-1)])/16 + 
     (G[{1}, yw]*G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{1, yu}, yv^(-1)])/8 + 
     (G[{yu^(-1)}, yw]*G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw]*
       G[{1, yu}, yv^(-1)])/8 - (G[{yu}, yv^(-1)]^2*G[{1/(yu*yv)}, yw]*
       G[{1, yu}, yv^(-1)])/8 + (5*G[{0}, yu^(-1)]*G[{yv^(-1)}, yw]*
       G[{1/(yu*yv)}, yw]*G[{1, yu}, yv^(-1)])/32 + 
     (5*G[{0}, yv^(-1)]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*
       G[{1, yu}, yv^(-1)])/32 - (5*G[{0}, yw]*G[{yv^(-1)}, yw]*
       G[{1/(yu*yv)}, yw]*G[{1, yu}, yv^(-1)])/32 + 
     (G[{1}, yu^(-1)]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*
       G[{1, yu}, yv^(-1)])/32 - (G[{1}, yv^(-1)]*G[{yv^(-1)}, yw]*
       G[{1/(yu*yv)}, yw]*G[{1, yu}, yv^(-1)])/32 - 
     (G[{1}, yw]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{1, yu}, yv^(-1)])/8 + 
     (3*G[{yu^(-1)}, yw]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*
       G[{1, yu}, yv^(-1)])/32 + (7*G[{yv^(-1)}, yw]^2*G[{1/(yu*yv)}, yw]*
       G[{1, yu}, yv^(-1)])/64 - (G[{0}, yu^(-1)]*G[{1/(yu*yv)}, yw]^2*
       G[{1, yu}, yv^(-1)])/128 - (G[{0}, yv^(-1)]*G[{1/(yu*yv)}, yw]^2*
       G[{1, yu}, yv^(-1)])/128 + (G[{0}, yw]*G[{1/(yu*yv)}, yw]^2*
       G[{1, yu}, yv^(-1)])/128 - (7*G[{1}, yu^(-1)]*G[{1/(yu*yv)}, yw]^2*
       G[{1, yu}, yv^(-1)])/128 + (G[{1}, yv^(-1)]*G[{1/(yu*yv)}, yw]^2*
       G[{1, yu}, yv^(-1)])/128 - (G[{1}, yw]*G[{1/(yu*yv)}, yw]^2*
       G[{1, yu}, yv^(-1)])/16 - (G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2*
       G[{1, yu}, yv^(-1)])/128 + (G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw]^2*
       G[{1, yu}, yv^(-1)])/16 + (7*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2*
       G[{1, yu}, yv^(-1)])/128 + (G[{0}, yu^(-1)]*G[{0, 1}, yu^(-1)]*
       G[{1, yu}, yv^(-1)])/8 + (G[{0}, yv^(-1)]*G[{0, 1}, yu^(-1)]*
       G[{1, yu}, yv^(-1)])/8 - (G[{0}, yw]*G[{0, 1}, yu^(-1)]*
       G[{1, yu}, yv^(-1)])/8 - (G[{1}, yu^(-1)]*G[{0, 1}, yu^(-1)]*
       G[{1, yu}, yv^(-1)])/16 - (G[{1}, yv^(-1)]*G[{0, 1}, yu^(-1)]*
       G[{1, yu}, yv^(-1)])/16 + (3*G[{1}, yw]*G[{0, 1}, yu^(-1)]*
       G[{1, yu}, yv^(-1)])/16 + (G[{1/(yu*yv)}, yw]*G[{0, 1}, yu^(-1)]*
       G[{1, yu}, yv^(-1)])/16 - (G[{0}, yu^(-1)]*G[{0, 1}, yv^(-1)]*
       G[{1, yu}, yv^(-1)])/16 - (G[{0}, yv^(-1)]*G[{0, 1}, yv^(-1)]*
       G[{1, yu}, yv^(-1)])/16 + (G[{0}, yw]*G[{0, 1}, yv^(-1)]*
       G[{1, yu}, yv^(-1)])/16 + (G[{1}, yv^(-1)]*G[{0, 1}, yv^(-1)]*
       G[{1, yu}, yv^(-1)])/16 - (G[{1}, yw]*G[{0, 1}, yv^(-1)]*
       G[{1, yu}, yv^(-1)])/16 - (G[{1/(yu*yv)}, yw]*G[{0, 1}, yv^(-1)]*
       G[{1, yu}, yv^(-1)])/16 + (7*G[{0}, yu^(-1)]*G[{0, 1}, yw]*
       G[{1, yu}, yv^(-1)])/32 + (7*G[{0}, yv^(-1)]*G[{0, 1}, yw]*
       G[{1, yu}, yv^(-1)])/32 - (7*G[{0}, yw]*G[{0, 1}, yw]*
       G[{1, yu}, yv^(-1)])/32 - (3*G[{1}, yu^(-1)]*G[{0, 1}, yw]*
       G[{1, yu}, yv^(-1)])/32 - (3*G[{1}, yv^(-1)]*G[{0, 1}, yw]*
       G[{1, yu}, yv^(-1)])/32 - (G[{1}, yw]*G[{0, 1}, yw]*
       G[{1, yu}, yv^(-1)])/64 - (3*G[{yu}, yv^(-1)]*G[{0, 1}, yw]*
       G[{1, yu}, yv^(-1)])/16 + (3*G[{1/(yu*yv)}, yw]*G[{0, 1}, yw]*
       G[{1, yu}, yv^(-1)])/64 - (3*G[{0}, yu^(-1)]*G[{0, yu^(-1)}, yw]*
       G[{1, yu}, yv^(-1)])/32 - (3*G[{0}, yv^(-1)]*G[{0, yu^(-1)}, yw]*
       G[{1, yu}, yv^(-1)])/32 + (3*G[{0}, yw]*G[{0, yu^(-1)}, yw]*
       G[{1, yu}, yv^(-1)])/32 - (G[{1}, yu^(-1)]*G[{0, yu^(-1)}, yw]*
       G[{1, yu}, yv^(-1)])/32 + (G[{1}, yv^(-1)]*G[{0, yu^(-1)}, yw]*
       G[{1, yu}, yv^(-1)])/32 + (G[{1}, yw]*G[{0, yu^(-1)}, yw]*
       G[{1, yu}, yv^(-1)])/64 - (3*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1)}, yw]*
       G[{1, yu}, yv^(-1)])/64 + (G[{0}, yu^(-1)]*G[{0, yu}, yv^(-1)]*
       G[{1, yu}, yv^(-1)])/16 + (G[{0}, yv^(-1)]*G[{0, yu}, yv^(-1)]*
       G[{1, yu}, yv^(-1)])/16 - (G[{0}, yw]*G[{0, yu}, yv^(-1)]*
       G[{1, yu}, yv^(-1)])/16 - (G[{1}, yv^(-1)]*G[{0, yu}, yv^(-1)]*
       G[{1, yu}, yv^(-1)])/16 + (G[{1}, yw]*G[{0, yu}, yv^(-1)]*
       G[{1, yu}, yv^(-1)])/16 + (G[{1/(yu*yv)}, yw]*G[{0, yu}, yv^(-1)]*
       G[{1, yu}, yv^(-1)])/16 - (5*G[{0}, yu^(-1)]*G[{0, yv^(-1)}, yw]*
       G[{1, yu}, yv^(-1)])/32 - (5*G[{0}, yv^(-1)]*G[{0, yv^(-1)}, yw]*
       G[{1, yu}, yv^(-1)])/32 + (5*G[{0}, yw]*G[{0, yv^(-1)}, yw]*
       G[{1, yu}, yv^(-1)])/32 - (G[{1}, yu^(-1)]*G[{0, yv^(-1)}, yw]*
       G[{1, yu}, yv^(-1)])/32 + (G[{1}, yv^(-1)]*G[{0, yv^(-1)}, yw]*
       G[{1, yu}, yv^(-1)])/32 + (G[{1}, yw]*G[{0, yv^(-1)}, yw]*
       G[{1, yu}, yv^(-1)])/64 - (3*G[{1/(yu*yv)}, yw]*G[{0, yv^(-1)}, yw]*
       G[{1, yu}, yv^(-1)])/64 + (G[{0}, yu^(-1)]*G[{0, 1/(yu*yv)}, yw]*
       G[{1, yu}, yv^(-1)])/32 + (G[{0}, yv^(-1)]*G[{0, 1/(yu*yv)}, yw]*
       G[{1, yu}, yv^(-1)])/32 - (G[{0}, yw]*G[{0, 1/(yu*yv)}, yw]*
       G[{1, yu}, yv^(-1)])/32 + (5*G[{1}, yu^(-1)]*G[{0, 1/(yu*yv)}, yw]*
       G[{1, yu}, yv^(-1)])/32 + (G[{1}, yv^(-1)]*G[{0, 1/(yu*yv)}, yw]*
       G[{1, yu}, yv^(-1)])/32 - (G[{1}, yw]*G[{0, 1/(yu*yv)}, yw]*
       G[{1, yu}, yv^(-1)])/64 + (3*G[{yu}, yv^(-1)]*G[{0, 1/(yu*yv)}, yw]*
       G[{1, yu}, yv^(-1)])/16 + (3*G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv)}, yw]*
       G[{1, yu}, yv^(-1)])/64 + (3*G[{0}, yu^(-1)]*G[{1, yu^(-1)}, yw]*
       G[{1, yu}, yv^(-1)])/32 + (3*G[{0}, yv^(-1)]*G[{1, yu^(-1)}, yw]*
       G[{1, yu}, yv^(-1)])/32 - (3*G[{0}, yw]*G[{1, yu^(-1)}, yw]*
       G[{1, yu}, yv^(-1)])/32 - (3*G[{1}, yu^(-1)]*G[{1, yu^(-1)}, yw]*
       G[{1, yu}, yv^(-1)])/32 + (G[{1}, yv^(-1)]*G[{1, yu^(-1)}, yw]*
       G[{1, yu}, yv^(-1)])/32 + (G[{1}, yw]*G[{1, yu^(-1)}, yw]*
       G[{1, yu}, yv^(-1)])/8 - (G[{yu}, yv^(-1)]*G[{1, yu^(-1)}, yw]*
       G[{1, yu}, yv^(-1)])/8 - (G[{1/(yu*yv)}, yw]*G[{1, yu^(-1)}, yw]*
       G[{1, yu}, yv^(-1)])/64 - (3*G[{0}, yu^(-1)]*G[{1, yu}, yv^(-1)]^2)/
      32 - (3*G[{0}, yv^(-1)]*G[{1, yu}, yv^(-1)]^2)/32 + 
     (3*G[{0}, yw]*G[{1, yu}, yv^(-1)]^2)/32 + 
     (G[{1}, yu^(-1)]*G[{1, yu}, yv^(-1)]^2)/16 + 
     (3*G[{1}, yv^(-1)]*G[{1, yu}, yv^(-1)]^2)/32 - 
     (G[{1}, yw]*G[{1, yu}, yv^(-1)]^2)/8 - 
     (G[{1/(yu*yv)}, yw]*G[{1, yu}, yv^(-1)]^2)/16 - 
     (29*Pi^2*G[{0}, yu^(-1)]*G[{1, yv^(-1)}, yw])/768 - 
     (29*Pi^2*G[{0}, yv^(-1)]*G[{1, yv^(-1)}, yw])/768 + 
     (29*Pi^2*G[{0}, yw]*G[{1, yv^(-1)}, yw])/768 + 
     (53*Pi^2*G[{1}, yu^(-1)]*G[{1, yv^(-1)}, yw])/768 + 
     (3*G[{0}, yu^(-1)]^2*G[{1}, yu^(-1)]*G[{1, yv^(-1)}, yw])/32 + 
     (3*G[{0}, yu^(-1)]*G[{0}, yv^(-1)]*G[{1}, yu^(-1)]*G[{1, yv^(-1)}, yw])/
      16 + (3*G[{0}, yv^(-1)]^2*G[{1}, yu^(-1)]*G[{1, yv^(-1)}, yw])/32 - 
     (3*G[{0}, yu^(-1)]*G[{0}, yw]*G[{1}, yu^(-1)]*G[{1, yv^(-1)}, yw])/16 - 
     (3*G[{0}, yv^(-1)]*G[{0}, yw]*G[{1}, yu^(-1)]*G[{1, yv^(-1)}, yw])/16 + 
     (3*G[{0}, yw]^2*G[{1}, yu^(-1)]*G[{1, yv^(-1)}, yw])/32 - 
     (5*G[{0}, yu^(-1)]*G[{1}, yu^(-1)]^2*G[{1, yv^(-1)}, yw])/32 - 
     (5*G[{0}, yv^(-1)]*G[{1}, yu^(-1)]^2*G[{1, yv^(-1)}, yw])/32 + 
     (5*G[{0}, yw]*G[{1}, yu^(-1)]^2*G[{1, yv^(-1)}, yw])/32 + 
     (G[{1}, yu^(-1)]^3*G[{1, yv^(-1)}, yw])/16 + 
     (5*Pi^2*G[{1}, yv^(-1)]*G[{1, yv^(-1)}, yw])/768 - 
     (3*G[{0}, yu^(-1)]^2*G[{1}, yv^(-1)]*G[{1, yv^(-1)}, yw])/32 - 
     (3*G[{0}, yu^(-1)]*G[{0}, yv^(-1)]*G[{1}, yv^(-1)]*G[{1, yv^(-1)}, yw])/
      16 - (3*G[{0}, yv^(-1)]^2*G[{1}, yv^(-1)]*G[{1, yv^(-1)}, yw])/32 + 
     (3*G[{0}, yu^(-1)]*G[{0}, yw]*G[{1}, yv^(-1)]*G[{1, yv^(-1)}, yw])/16 + 
     (3*G[{0}, yv^(-1)]*G[{0}, yw]*G[{1}, yv^(-1)]*G[{1, yv^(-1)}, yw])/16 - 
     (3*G[{0}, yw]^2*G[{1}, yv^(-1)]*G[{1, yv^(-1)}, yw])/32 - 
     (G[{0}, yu^(-1)]*G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*G[{1, yv^(-1)}, yw])/
      16 - (G[{0}, yv^(-1)]*G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*
       G[{1, yv^(-1)}, yw])/16 + (G[{0}, yw]*G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*
       G[{1, yv^(-1)}, yw])/16 + (G[{1}, yu^(-1)]^2*G[{1}, yv^(-1)]*
       G[{1, yv^(-1)}, yw])/8 + (9*G[{0}, yu^(-1)]*G[{1}, yv^(-1)]^2*
       G[{1, yv^(-1)}, yw])/64 + (9*G[{0}, yv^(-1)]*G[{1}, yv^(-1)]^2*
       G[{1, yv^(-1)}, yw])/64 - (9*G[{0}, yw]*G[{1}, yv^(-1)]^2*
       G[{1, yv^(-1)}, yw])/64 - (5*G[{1}, yu^(-1)]*G[{1}, yv^(-1)]^2*
       G[{1, yv^(-1)}, yw])/64 - (3*G[{1}, yv^(-1)]^3*G[{1, yv^(-1)}, yw])/
      64 + (Pi^2*G[{1}, yw]*G[{1, yv^(-1)}, yw])/192 + 
     (3*G[{0}, yu^(-1)]^2*G[{1}, yw]*G[{1, yv^(-1)}, yw])/64 + 
     (3*G[{0}, yu^(-1)]*G[{0}, yv^(-1)]*G[{1}, yw]*G[{1, yv^(-1)}, yw])/32 + 
     (3*G[{0}, yv^(-1)]^2*G[{1}, yw]*G[{1, yv^(-1)}, yw])/64 - 
     (3*G[{0}, yu^(-1)]*G[{0}, yw]*G[{1}, yw]*G[{1, yv^(-1)}, yw])/32 - 
     (3*G[{0}, yv^(-1)]*G[{0}, yw]*G[{1}, yw]*G[{1, yv^(-1)}, yw])/32 + 
     (3*G[{0}, yw]^2*G[{1}, yw]*G[{1, yv^(-1)}, yw])/64 + 
     (G[{0}, yu^(-1)]*G[{1}, yu^(-1)]*G[{1}, yw]*G[{1, yv^(-1)}, yw])/32 + 
     (G[{0}, yv^(-1)]*G[{1}, yu^(-1)]*G[{1}, yw]*G[{1, yv^(-1)}, yw])/32 - 
     (G[{0}, yw]*G[{1}, yu^(-1)]*G[{1}, yw]*G[{1, yv^(-1)}, yw])/32 - 
     (3*G[{1}, yu^(-1)]^2*G[{1}, yw]*G[{1, yv^(-1)}, yw])/64 - 
     (3*G[{1}, yv^(-1)]^2*G[{1}, yw]*G[{1, yv^(-1)}, yw])/64 + 
     (G[{0}, yu^(-1)]*G[{1}, yw]^2*G[{1, yv^(-1)}, yw])/8 + 
     (G[{0}, yv^(-1)]*G[{1}, yw]^2*G[{1, yv^(-1)}, yw])/8 - 
     (G[{0}, yw]*G[{1}, yw]^2*G[{1, yv^(-1)}, yw])/8 - 
     (G[{1}, yu^(-1)]*G[{1}, yw]^2*G[{1, yv^(-1)}, yw])/16 - 
     (3*G[{1}, yv^(-1)]*G[{1}, yw]^2*G[{1, yv^(-1)}, yw])/32 + 
     (G[{1}, yw]^3*G[{1, yv^(-1)}, yw])/32 - 
     (7*G[{0}, yu^(-1)]*G[{1}, yw]*G[{yu}, yv^(-1)]*G[{1, yv^(-1)}, yw])/32 - 
     (7*G[{0}, yv^(-1)]*G[{1}, yw]*G[{yu}, yv^(-1)]*G[{1, yv^(-1)}, yw])/32 + 
     (7*G[{0}, yw]*G[{1}, yw]*G[{yu}, yv^(-1)]*G[{1, yv^(-1)}, yw])/32 + 
     (G[{1}, yu^(-1)]*G[{1}, yw]*G[{yu}, yv^(-1)]*G[{1, yv^(-1)}, yw])/32 + 
     (7*G[{1}, yv^(-1)]*G[{1}, yw]*G[{yu}, yv^(-1)]*G[{1, yv^(-1)}, yw])/32 - 
     (3*G[{1}, yw]^2*G[{yu}, yv^(-1)]*G[{1, yv^(-1)}, yw])/32 + 
     (3*G[{1}, yw]*G[{yu}, yv^(-1)]^2*G[{1, yv^(-1)}, yw])/32 + 
     (3*Pi^2*G[{1/(yu*yv)}, yw]*G[{1, yv^(-1)}, yw])/256 + 
     (3*G[{0}, yu^(-1)]^2*G[{1/(yu*yv)}, yw]*G[{1, yv^(-1)}, yw])/64 + 
     (3*G[{0}, yu^(-1)]*G[{0}, yv^(-1)]*G[{1/(yu*yv)}, yw]*
       G[{1, yv^(-1)}, yw])/32 + (3*G[{0}, yv^(-1)]^2*G[{1/(yu*yv)}, yw]*
       G[{1, yv^(-1)}, yw])/64 - (3*G[{0}, yu^(-1)]*G[{0}, yw]*
       G[{1/(yu*yv)}, yw]*G[{1, yv^(-1)}, yw])/32 - 
     (3*G[{0}, yv^(-1)]*G[{0}, yw]*G[{1/(yu*yv)}, yw]*G[{1, yv^(-1)}, yw])/
      32 + (3*G[{0}, yw]^2*G[{1/(yu*yv)}, yw]*G[{1, yv^(-1)}, yw])/64 - 
     (9*G[{0}, yu^(-1)]*G[{1}, yu^(-1)]*G[{1/(yu*yv)}, yw]*
       G[{1, yv^(-1)}, yw])/32 - (9*G[{0}, yv^(-1)]*G[{1}, yu^(-1)]*
       G[{1/(yu*yv)}, yw]*G[{1, yv^(-1)}, yw])/32 + 
     (9*G[{0}, yw]*G[{1}, yu^(-1)]*G[{1/(yu*yv)}, yw]*G[{1, yv^(-1)}, yw])/
      32 + (11*G[{1}, yu^(-1)]^2*G[{1/(yu*yv)}, yw]*G[{1, yv^(-1)}, yw])/64 - 
     (G[{0}, yu^(-1)]*G[{1}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{1, yv^(-1)}, yw])/
      8 - (G[{0}, yv^(-1)]*G[{1}, yv^(-1)]*G[{1/(yu*yv)}, yw]*
       G[{1, yv^(-1)}, yw])/8 + (G[{0}, yw]*G[{1}, yv^(-1)]*
       G[{1/(yu*yv)}, yw]*G[{1, yv^(-1)}, yw])/8 + 
     (G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{1, yv^(-1)}, yw])/
      4 + (7*G[{1}, yv^(-1)]^2*G[{1/(yu*yv)}, yw]*G[{1, yv^(-1)}, yw])/128 - 
     (15*G[{0}, yu^(-1)]*G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{1, yv^(-1)}, yw])/
      64 - (15*G[{0}, yv^(-1)]*G[{1}, yw]*G[{1/(yu*yv)}, yw]*
       G[{1, yv^(-1)}, yw])/64 + (15*G[{0}, yw]*G[{1}, yw]*G[{1/(yu*yv)}, yw]*
       G[{1, yv^(-1)}, yw])/64 + (7*G[{1}, yu^(-1)]*G[{1}, yw]*
       G[{1/(yu*yv)}, yw]*G[{1, yv^(-1)}, yw])/64 + 
     (3*G[{1}, yv^(-1)]*G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{1, yv^(-1)}, yw])/
      16 - (11*G[{1}, yw]^2*G[{1/(yu*yv)}, yw]*G[{1, yv^(-1)}, yw])/128 - 
     (G[{0}, yu^(-1)]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*
       G[{1, yv^(-1)}, yw])/32 - (G[{0}, yv^(-1)]*G[{yu^(-1)}, yw]*
       G[{1/(yu*yv)}, yw]*G[{1, yv^(-1)}, yw])/32 + 
     (G[{0}, yw]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{1, yv^(-1)}, yw])/
      32 - (7*G[{1}, yu^(-1)]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*
       G[{1, yv^(-1)}, yw])/32 + (3*G[{1}, yv^(-1)]*G[{yu^(-1)}, yw]*
       G[{1/(yu*yv)}, yw]*G[{1, yv^(-1)}, yw])/32 - 
     (3*G[{1}, yw]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{1, yv^(-1)}, yw])/
      16 - (3*G[{yu^(-1)}, yw]^2*G[{1/(yu*yv)}, yw]*G[{1, yv^(-1)}, yw])/32 + 
     (7*G[{0}, yu^(-1)]*G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw]*
       G[{1, yv^(-1)}, yw])/32 + (7*G[{0}, yv^(-1)]*G[{yu}, yv^(-1)]*
       G[{1/(yu*yv)}, yw]*G[{1, yv^(-1)}, yw])/32 - 
     (7*G[{0}, yw]*G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{1, yv^(-1)}, yw])/
      32 - (G[{1}, yu^(-1)]*G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw]*
       G[{1, yv^(-1)}, yw])/32 - (7*G[{1}, yv^(-1)]*G[{yu}, yv^(-1)]*
       G[{1/(yu*yv)}, yw]*G[{1, yv^(-1)}, yw])/32 + 
     (11*G[{1}, yw]*G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{1, yv^(-1)}, yw])/
      64 + (3*G[{yu^(-1)}, yw]*G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw]*
       G[{1, yv^(-1)}, yw])/16 - (3*G[{yu}, yv^(-1)]^2*G[{1/(yu*yv)}, yw]*
       G[{1, yv^(-1)}, yw])/32 - (3*G[{0}, yu^(-1)]*G[{yv^(-1)}, yw]*
       G[{1/(yu*yv)}, yw]*G[{1, yv^(-1)}, yw])/16 - 
     (3*G[{0}, yv^(-1)]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*
       G[{1, yv^(-1)}, yw])/16 + (3*G[{0}, yw]*G[{yv^(-1)}, yw]*
       G[{1/(yu*yv)}, yw]*G[{1, yv^(-1)}, yw])/16 - 
     (G[{1}, yu^(-1)]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*
       G[{1, yv^(-1)}, yw])/16 + (3*G[{1}, yv^(-1)]*G[{yv^(-1)}, yw]*
       G[{1/(yu*yv)}, yw]*G[{1, yv^(-1)}, yw])/16 - 
     (G[{1}, yw]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{1, yv^(-1)}, yw])/4 - 
     (G[{yu^(-1)}, yw]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*
       G[{1, yv^(-1)}, yw])/8 + (G[{yu}, yv^(-1)]*G[{yv^(-1)}, yw]*
       G[{1/(yu*yv)}, yw]*G[{1, yv^(-1)}, yw])/4 - 
     (G[{yv^(-1)}, yw]^2*G[{1/(yu*yv)}, yw]*G[{1, yv^(-1)}, yw])/16 + 
     (3*G[{0}, yu^(-1)]*G[{1/(yu*yv)}, yw]^2*G[{1, yv^(-1)}, yw])/128 + 
     (3*G[{0}, yv^(-1)]*G[{1/(yu*yv)}, yw]^2*G[{1, yv^(-1)}, yw])/128 - 
     (3*G[{0}, yw]*G[{1/(yu*yv)}, yw]^2*G[{1, yv^(-1)}, yw])/128 - 
     (7*G[{1}, yu^(-1)]*G[{1/(yu*yv)}, yw]^2*G[{1, yv^(-1)}, yw])/128 + 
     (3*G[{1}, yv^(-1)]*G[{1/(yu*yv)}, yw]^2*G[{1, yv^(-1)}, yw])/128 + 
     (G[{1}, yw]*G[{1/(yu*yv)}, yw]^2*G[{1, yv^(-1)}, yw])/64 - 
     (9*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2*G[{1, yv^(-1)}, yw])/128 - 
     (G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw]^2*G[{1, yv^(-1)}, yw])/64 + 
     (G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2*G[{1, yv^(-1)}, yw])/128 - 
     (3*G[{0}, yu^(-1)]*G[{0, 1}, yu^(-1)]*G[{1, yv^(-1)}, yw])/16 - 
     (3*G[{0}, yv^(-1)]*G[{0, 1}, yu^(-1)]*G[{1, yv^(-1)}, yw])/16 + 
     (3*G[{0}, yw]*G[{0, 1}, yu^(-1)]*G[{1, yv^(-1)}, yw])/16 + 
     (5*G[{1}, yu^(-1)]*G[{0, 1}, yu^(-1)]*G[{1, yv^(-1)}, yw])/16 + 
     (G[{1}, yv^(-1)]*G[{0, 1}, yu^(-1)]*G[{1, yv^(-1)}, yw])/16 + 
     (G[{1}, yw]*G[{0, 1}, yu^(-1)]*G[{1, yv^(-1)}, yw])/16 - 
     (G[{1/(yu*yv)}, yw]*G[{0, 1}, yu^(-1)]*G[{1, yv^(-1)}, yw])/16 - 
     (G[{0}, yu^(-1)]*G[{0, 1}, yv^(-1)]*G[{1, yv^(-1)}, yw])/32 - 
     (G[{0}, yv^(-1)]*G[{0, 1}, yv^(-1)]*G[{1, yv^(-1)}, yw])/32 + 
     (G[{0}, yw]*G[{0, 1}, yv^(-1)]*G[{1, yv^(-1)}, yw])/32 + 
     (G[{1}, yu^(-1)]*G[{0, 1}, yv^(-1)]*G[{1, yv^(-1)}, yw])/32 - 
     (G[{1}, yv^(-1)]*G[{0, 1}, yv^(-1)]*G[{1, yv^(-1)}, yw])/32 - 
     (G[{1}, yw]*G[{0, 1}, yv^(-1)]*G[{1, yv^(-1)}, yw])/16 + 
     (3*G[{1/(yu*yv)}, yw]*G[{0, 1}, yv^(-1)]*G[{1, yv^(-1)}, yw])/64 - 
     (G[{1}, yu^(-1)]*G[{0, 1}, yw]*G[{1, yv^(-1)}, yw])/16 + 
     (G[{1}, yv^(-1)]*G[{0, 1}, yw]*G[{1, yv^(-1)}, yw])/16 + 
     (G[{1}, yw]*G[{0, 1}, yw]*G[{1, yv^(-1)}, yw])/32 - 
     (G[{1/(yu*yv)}, yw]*G[{0, 1}, yw]*G[{1, yv^(-1)}, yw])/64 + 
     (G[{1}, yu^(-1)]*G[{0, yu^(-1)}, yw]*G[{1, yv^(-1)}, yw])/16 - 
     (G[{1}, yv^(-1)]*G[{0, yu^(-1)}, yw]*G[{1, yv^(-1)}, yw])/16 - 
     (G[{1}, yw]*G[{0, yu^(-1)}, yw]*G[{1, yv^(-1)}, yw])/32 + 
     (G[{1/(yu*yv)}, yw]*G[{0, yu^(-1)}, yw]*G[{1, yv^(-1)}, yw])/64 + 
     (G[{0}, yu^(-1)]*G[{0, yu}, yv^(-1)]*G[{1, yv^(-1)}, yw])/32 + 
     (G[{0}, yv^(-1)]*G[{0, yu}, yv^(-1)]*G[{1, yv^(-1)}, yw])/32 - 
     (G[{0}, yw]*G[{0, yu}, yv^(-1)]*G[{1, yv^(-1)}, yw])/32 - 
     (G[{1}, yu^(-1)]*G[{0, yu}, yv^(-1)]*G[{1, yv^(-1)}, yw])/32 + 
     (G[{1}, yv^(-1)]*G[{0, yu}, yv^(-1)]*G[{1, yv^(-1)}, yw])/32 + 
     (G[{1}, yw]*G[{0, yu}, yv^(-1)]*G[{1, yv^(-1)}, yw])/16 - 
     (3*G[{1/(yu*yv)}, yw]*G[{0, yu}, yv^(-1)]*G[{1, yv^(-1)}, yw])/64 + 
     (G[{1}, yu^(-1)]*G[{0, yv^(-1)}, yw]*G[{1, yv^(-1)}, yw])/16 - 
     (G[{1}, yv^(-1)]*G[{0, yv^(-1)}, yw]*G[{1, yv^(-1)}, yw])/16 - 
     (G[{1}, yw]*G[{0, yv^(-1)}, yw]*G[{1, yv^(-1)}, yw])/32 + 
     (G[{1/(yu*yv)}, yw]*G[{0, yv^(-1)}, yw]*G[{1, yv^(-1)}, yw])/64 - 
     (G[{1}, yu^(-1)]*G[{0, 1/(yu*yv)}, yw]*G[{1, yv^(-1)}, yw])/16 + 
     (G[{1}, yv^(-1)]*G[{0, 1/(yu*yv)}, yw]*G[{1, yv^(-1)}, yw])/16 + 
     (G[{1}, yw]*G[{0, 1/(yu*yv)}, yw]*G[{1, yv^(-1)}, yw])/32 - 
     (G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv)}, yw]*G[{1, yv^(-1)}, yw])/64 - 
     (G[{0}, yu^(-1)]*G[{1, yu^(-1)}, yw]*G[{1, yv^(-1)}, yw])/32 - 
     (G[{0}, yv^(-1)]*G[{1, yu^(-1)}, yw]*G[{1, yv^(-1)}, yw])/32 + 
     (G[{0}, yw]*G[{1, yu^(-1)}, yw]*G[{1, yv^(-1)}, yw])/32 - 
     (G[{1}, yu^(-1)]*G[{1, yu^(-1)}, yw]*G[{1, yv^(-1)}, yw])/32 + 
     (5*G[{1}, yv^(-1)]*G[{1, yu^(-1)}, yw]*G[{1, yv^(-1)}, yw])/32 + 
     (G[{1}, yw]*G[{1, yu^(-1)}, yw]*G[{1, yv^(-1)}, yw])/16 - 
     (G[{yu}, yv^(-1)]*G[{1, yu^(-1)}, yw]*G[{1, yv^(-1)}, yw])/16 + 
     (G[{1/(yu*yv)}, yw]*G[{1, yu^(-1)}, yw]*G[{1, yv^(-1)}, yw])/32 + 
     (5*G[{0}, yu^(-1)]*G[{1, yu}, yv^(-1)]*G[{1, yv^(-1)}, yw])/32 + 
     (5*G[{0}, yv^(-1)]*G[{1, yu}, yv^(-1)]*G[{1, yv^(-1)}, yw])/32 - 
     (5*G[{0}, yw]*G[{1, yu}, yv^(-1)]*G[{1, yv^(-1)}, yw])/32 + 
     (G[{1}, yu^(-1)]*G[{1, yu}, yv^(-1)]*G[{1, yv^(-1)}, yw])/32 - 
     (G[{1}, yv^(-1)]*G[{1, yu}, yv^(-1)]*G[{1, yv^(-1)}, yw])/32 - 
     (G[{1}, yw]*G[{1, yu}, yv^(-1)]*G[{1, yv^(-1)}, yw])/8 + 
     (7*G[{1/(yu*yv)}, yw]*G[{1, yu}, yv^(-1)]*G[{1, yv^(-1)}, yw])/64 - 
     (3*G[{0}, yu^(-1)]*G[{1, yv^(-1)}, yw]^2)/32 - 
     (3*G[{0}, yv^(-1)]*G[{1, yv^(-1)}, yw]^2)/32 + 
     (3*G[{0}, yw]*G[{1, yv^(-1)}, yw]^2)/32 - 
     (G[{1}, yu^(-1)]*G[{1, yv^(-1)}, yw]^2)/32 + 
     (3*G[{1}, yv^(-1)]*G[{1, yv^(-1)}, yw]^2)/32 - 
     (G[{1}, yw]*G[{1, yv^(-1)}, yw]^2)/8 + 
     (G[{yu}, yv^(-1)]*G[{1, yv^(-1)}, yw]^2)/8 - 
     (5*G[{1/(yu*yv)}, yw]*G[{1, yv^(-1)}, yw]^2)/128 - 
     (7*Pi^2*G[{0}, yu^(-1)]*G[{1, 1/(yu*yv)}, yw])/384 - 
     (3*G[{0}, yu^(-1)]^3*G[{1, 1/(yu*yv)}, yw])/128 - 
     (7*Pi^2*G[{0}, yv^(-1)]*G[{1, 1/(yu*yv)}, yw])/384 - 
     (9*G[{0}, yu^(-1)]^2*G[{0}, yv^(-1)]*G[{1, 1/(yu*yv)}, yw])/128 - 
     (9*G[{0}, yu^(-1)]*G[{0}, yv^(-1)]^2*G[{1, 1/(yu*yv)}, yw])/128 - 
     (3*G[{0}, yv^(-1)]^3*G[{1, 1/(yu*yv)}, yw])/128 + 
     (7*Pi^2*G[{0}, yw]*G[{1, 1/(yu*yv)}, yw])/384 + 
     (9*G[{0}, yu^(-1)]^2*G[{0}, yw]*G[{1, 1/(yu*yv)}, yw])/128 + 
     (9*G[{0}, yu^(-1)]*G[{0}, yv^(-1)]*G[{0}, yw]*G[{1, 1/(yu*yv)}, yw])/
      64 + (9*G[{0}, yv^(-1)]^2*G[{0}, yw]*G[{1, 1/(yu*yv)}, yw])/128 - 
     (9*G[{0}, yu^(-1)]*G[{0}, yw]^2*G[{1, 1/(yu*yv)}, yw])/128 - 
     (9*G[{0}, yv^(-1)]*G[{0}, yw]^2*G[{1, 1/(yu*yv)}, yw])/128 + 
     (3*G[{0}, yw]^3*G[{1, 1/(yu*yv)}, yw])/128 - 
     (Pi^2*G[{1}, yu^(-1)]*G[{1, 1/(yu*yv)}, yw])/384 - 
     (3*G[{0}, yu^(-1)]^2*G[{1}, yu^(-1)]*G[{1, 1/(yu*yv)}, yw])/128 - 
     (3*G[{0}, yu^(-1)]*G[{0}, yv^(-1)]*G[{1}, yu^(-1)]*
       G[{1, 1/(yu*yv)}, yw])/64 - (3*G[{0}, yv^(-1)]^2*G[{1}, yu^(-1)]*
       G[{1, 1/(yu*yv)}, yw])/128 + (3*G[{0}, yu^(-1)]*G[{0}, yw]*
       G[{1}, yu^(-1)]*G[{1, 1/(yu*yv)}, yw])/64 + 
     (3*G[{0}, yv^(-1)]*G[{0}, yw]*G[{1}, yu^(-1)]*G[{1, 1/(yu*yv)}, yw])/
      64 - (3*G[{0}, yw]^2*G[{1}, yu^(-1)]*G[{1, 1/(yu*yv)}, yw])/128 + 
     (11*G[{0}, yu^(-1)]*G[{1}, yu^(-1)]^2*G[{1, 1/(yu*yv)}, yw])/128 + 
     (11*G[{0}, yv^(-1)]*G[{1}, yu^(-1)]^2*G[{1, 1/(yu*yv)}, yw])/128 - 
     (11*G[{0}, yw]*G[{1}, yu^(-1)]^2*G[{1, 1/(yu*yv)}, yw])/128 - 
     (5*G[{1}, yu^(-1)]^3*G[{1, 1/(yu*yv)}, yw])/128 + 
     (7*Pi^2*G[{1}, yv^(-1)]*G[{1, 1/(yu*yv)}, yw])/384 + 
     (G[{0}, yu^(-1)]^2*G[{1}, yv^(-1)]*G[{1, 1/(yu*yv)}, yw])/128 + 
     (G[{0}, yu^(-1)]*G[{0}, yv^(-1)]*G[{1}, yv^(-1)]*G[{1, 1/(yu*yv)}, yw])/
      64 + (G[{0}, yv^(-1)]^2*G[{1}, yv^(-1)]*G[{1, 1/(yu*yv)}, yw])/128 - 
     (G[{0}, yu^(-1)]*G[{0}, yw]*G[{1}, yv^(-1)]*G[{1, 1/(yu*yv)}, yw])/64 - 
     (G[{0}, yv^(-1)]*G[{0}, yw]*G[{1}, yv^(-1)]*G[{1, 1/(yu*yv)}, yw])/64 + 
     (G[{0}, yw]^2*G[{1}, yv^(-1)]*G[{1, 1/(yu*yv)}, yw])/128 - 
     (G[{0}, yu^(-1)]*G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*G[{1, 1/(yu*yv)}, yw])/
      64 - (G[{0}, yv^(-1)]*G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*
       G[{1, 1/(yu*yv)}, yw])/64 + (G[{0}, yw]*G[{1}, yu^(-1)]*
       G[{1}, yv^(-1)]*G[{1, 1/(yu*yv)}, yw])/64 - 
     (3*G[{1}, yu^(-1)]^2*G[{1}, yv^(-1)]*G[{1, 1/(yu*yv)}, yw])/128 + 
     (7*G[{0}, yu^(-1)]*G[{1}, yv^(-1)]^2*G[{1, 1/(yu*yv)}, yw])/128 + 
     (7*G[{0}, yv^(-1)]*G[{1}, yv^(-1)]^2*G[{1, 1/(yu*yv)}, yw])/128 - 
     (7*G[{0}, yw]*G[{1}, yv^(-1)]^2*G[{1, 1/(yu*yv)}, yw])/128 + 
     (G[{1}, yu^(-1)]*G[{1}, yv^(-1)]^2*G[{1, 1/(yu*yv)}, yw])/128 - 
     (5*G[{1}, yv^(-1)]^3*G[{1, 1/(yu*yv)}, yw])/128 - 
     (7*Pi^2*G[{1}, yw]*G[{1, 1/(yu*yv)}, yw])/384 - 
     (17*G[{0}, yu^(-1)]^2*G[{1}, yw]*G[{1, 1/(yu*yv)}, yw])/128 - 
     (17*G[{0}, yu^(-1)]*G[{0}, yv^(-1)]*G[{1}, yw]*G[{1, 1/(yu*yv)}, yw])/
      64 - (17*G[{0}, yv^(-1)]^2*G[{1}, yw]*G[{1, 1/(yu*yv)}, yw])/128 + 
     (17*G[{0}, yu^(-1)]*G[{0}, yw]*G[{1}, yw]*G[{1, 1/(yu*yv)}, yw])/64 + 
     (17*G[{0}, yv^(-1)]*G[{0}, yw]*G[{1}, yw]*G[{1, 1/(yu*yv)}, yw])/64 - 
     (17*G[{0}, yw]^2*G[{1}, yw]*G[{1, 1/(yu*yv)}, yw])/128 + 
     (9*G[{0}, yu^(-1)]*G[{1}, yu^(-1)]*G[{1}, yw]*G[{1, 1/(yu*yv)}, yw])/
      64 + (9*G[{0}, yv^(-1)]*G[{1}, yu^(-1)]*G[{1}, yw]*
       G[{1, 1/(yu*yv)}, yw])/64 - (9*G[{0}, yw]*G[{1}, yu^(-1)]*G[{1}, yw]*
       G[{1, 1/(yu*yv)}, yw])/64 - (5*G[{1}, yu^(-1)]^2*G[{1}, yw]*
       G[{1, 1/(yu*yv)}, yw])/128 + (9*G[{0}, yu^(-1)]*G[{1}, yv^(-1)]*
       G[{1}, yw]*G[{1, 1/(yu*yv)}, yw])/64 + 
     (9*G[{0}, yv^(-1)]*G[{1}, yv^(-1)]*G[{1}, yw]*G[{1, 1/(yu*yv)}, yw])/
      64 - (9*G[{0}, yw]*G[{1}, yv^(-1)]*G[{1}, yw]*G[{1, 1/(yu*yv)}, yw])/
      64 - (9*G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*G[{1}, yw]*
       G[{1, 1/(yu*yv)}, yw])/64 - (G[{1}, yv^(-1)]^2*G[{1}, yw]*
       G[{1, 1/(yu*yv)}, yw])/128 - (19*G[{0}, yu^(-1)]*G[{1}, yw]^2*
       G[{1, 1/(yu*yv)}, yw])/128 - (19*G[{0}, yv^(-1)]*G[{1}, yw]^2*
       G[{1, 1/(yu*yv)}, yw])/128 + (19*G[{0}, yw]*G[{1}, yw]^2*
       G[{1, 1/(yu*yv)}, yw])/128 + (11*G[{1}, yu^(-1)]*G[{1}, yw]^2*
       G[{1, 1/(yu*yv)}, yw])/128 + (15*G[{1}, yv^(-1)]*G[{1}, yw]^2*
       G[{1, 1/(yu*yv)}, yw])/128 - (G[{1}, yw]^3*G[{1, 1/(yu*yv)}, yw])/32 + 
     (Pi^2*G[{yu}, yv^(-1)]*G[{1, 1/(yu*yv)}, yw])/48 + 
     (5*G[{0}, yu^(-1)]^2*G[{yu}, yv^(-1)]*G[{1, 1/(yu*yv)}, yw])/32 + 
     (5*G[{0}, yu^(-1)]*G[{0}, yv^(-1)]*G[{yu}, yv^(-1)]*
       G[{1, 1/(yu*yv)}, yw])/16 + (5*G[{0}, yv^(-1)]^2*G[{yu}, yv^(-1)]*
       G[{1, 1/(yu*yv)}, yw])/32 - (5*G[{0}, yu^(-1)]*G[{0}, yw]*
       G[{yu}, yv^(-1)]*G[{1, 1/(yu*yv)}, yw])/16 - 
     (5*G[{0}, yv^(-1)]*G[{0}, yw]*G[{yu}, yv^(-1)]*G[{1, 1/(yu*yv)}, yw])/
      16 + (5*G[{0}, yw]^2*G[{yu}, yv^(-1)]*G[{1, 1/(yu*yv)}, yw])/32 - 
     (G[{0}, yu^(-1)]*G[{1}, yu^(-1)]*G[{yu}, yv^(-1)]*G[{1, 1/(yu*yv)}, yw])/
      16 - (G[{0}, yv^(-1)]*G[{1}, yu^(-1)]*G[{yu}, yv^(-1)]*
       G[{1, 1/(yu*yv)}, yw])/16 + (G[{0}, yw]*G[{1}, yu^(-1)]*
       G[{yu}, yv^(-1)]*G[{1, 1/(yu*yv)}, yw])/16 - 
     (G[{1}, yu^(-1)]^2*G[{yu}, yv^(-1)]*G[{1, 1/(yu*yv)}, yw])/32 - 
     (5*G[{0}, yu^(-1)]*G[{1}, yv^(-1)]*G[{yu}, yv^(-1)]*
       G[{1, 1/(yu*yv)}, yw])/16 - (5*G[{0}, yv^(-1)]*G[{1}, yv^(-1)]*
       G[{yu}, yv^(-1)]*G[{1, 1/(yu*yv)}, yw])/16 + 
     (5*G[{0}, yw]*G[{1}, yv^(-1)]*G[{yu}, yv^(-1)]*G[{1, 1/(yu*yv)}, yw])/
      16 + (3*G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*G[{yu}, yv^(-1)]*
       G[{1, 1/(yu*yv)}, yw])/16 + (5*G[{1}, yv^(-1)]^2*G[{yu}, yv^(-1)]*
       G[{1, 1/(yu*yv)}, yw])/32 + (G[{0}, yu^(-1)]*G[{1}, yw]*
       G[{yu}, yv^(-1)]*G[{1, 1/(yu*yv)}, yw])/4 + 
     (G[{0}, yv^(-1)]*G[{1}, yw]*G[{yu}, yv^(-1)]*G[{1, 1/(yu*yv)}, yw])/4 - 
     (G[{0}, yw]*G[{1}, yw]*G[{yu}, yv^(-1)]*G[{1, 1/(yu*yv)}, yw])/4 - 
     (G[{1}, yu^(-1)]*G[{1}, yw]*G[{yu}, yv^(-1)]*G[{1, 1/(yu*yv)}, yw])/16 - 
     (G[{1}, yv^(-1)]*G[{1}, yw]*G[{yu}, yv^(-1)]*G[{1, 1/(yu*yv)}, yw])/4 + 
     (3*G[{1}, yw]^2*G[{yu}, yv^(-1)]*G[{1, 1/(yu*yv)}, yw])/32 - 
     (G[{0}, yu^(-1)]*G[{yu}, yv^(-1)]^2*G[{1, 1/(yu*yv)}, yw])/8 - 
     (G[{0}, yv^(-1)]*G[{yu}, yv^(-1)]^2*G[{1, 1/(yu*yv)}, yw])/8 + 
     (G[{0}, yw]*G[{yu}, yv^(-1)]^2*G[{1, 1/(yu*yv)}, yw])/8 + 
     (3*G[{1}, yv^(-1)]*G[{yu}, yv^(-1)]^2*G[{1, 1/(yu*yv)}, yw])/16 - 
     (3*G[{1}, yw]*G[{yu}, yv^(-1)]^2*G[{1, 1/(yu*yv)}, yw])/32 + 
     (G[{yu}, yv^(-1)]^3*G[{1, 1/(yu*yv)}, yw])/48 + 
     (Pi^2*G[{1/(yu*yv)}, yw]*G[{1, 1/(yu*yv)}, yw])/384 - 
     (5*G[{0}, yu^(-1)]^2*G[{1/(yu*yv)}, yw]*G[{1, 1/(yu*yv)}, yw])/128 - 
     (5*G[{0}, yu^(-1)]*G[{0}, yv^(-1)]*G[{1/(yu*yv)}, yw]*
       G[{1, 1/(yu*yv)}, yw])/64 - (5*G[{0}, yv^(-1)]^2*G[{1/(yu*yv)}, yw]*
       G[{1, 1/(yu*yv)}, yw])/128 + (5*G[{0}, yu^(-1)]*G[{0}, yw]*
       G[{1/(yu*yv)}, yw]*G[{1, 1/(yu*yv)}, yw])/64 + 
     (5*G[{0}, yv^(-1)]*G[{0}, yw]*G[{1/(yu*yv)}, yw]*G[{1, 1/(yu*yv)}, yw])/
      64 - (5*G[{0}, yw]^2*G[{1/(yu*yv)}, yw]*G[{1, 1/(yu*yv)}, yw])/128 + 
     (9*G[{0}, yu^(-1)]*G[{1}, yu^(-1)]*G[{1/(yu*yv)}, yw]*
       G[{1, 1/(yu*yv)}, yw])/64 + (9*G[{0}, yv^(-1)]*G[{1}, yu^(-1)]*
       G[{1/(yu*yv)}, yw]*G[{1, 1/(yu*yv)}, yw])/64 - 
     (9*G[{0}, yw]*G[{1}, yu^(-1)]*G[{1/(yu*yv)}, yw]*G[{1, 1/(yu*yv)}, yw])/
      64 - (13*G[{1}, yu^(-1)]^2*G[{1/(yu*yv)}, yw]*G[{1, 1/(yu*yv)}, yw])/
      128 + (G[{0}, yu^(-1)]*G[{1}, yv^(-1)]*G[{1/(yu*yv)}, yw]*
       G[{1, 1/(yu*yv)}, yw])/64 + (G[{0}, yv^(-1)]*G[{1}, yv^(-1)]*
       G[{1/(yu*yv)}, yw]*G[{1, 1/(yu*yv)}, yw])/64 - 
     (G[{0}, yw]*G[{1}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{1, 1/(yu*yv)}, yw])/
      64 - (G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*G[{1/(yu*yv)}, yw]*
       G[{1, 1/(yu*yv)}, yw])/64 + (3*G[{1}, yv^(-1)]^2*G[{1/(yu*yv)}, yw]*
       G[{1, 1/(yu*yv)}, yw])/128 - (3*G[{0}, yu^(-1)]*G[{1}, yw]*
       G[{1/(yu*yv)}, yw]*G[{1, 1/(yu*yv)}, yw])/64 - 
     (3*G[{0}, yv^(-1)]*G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{1, 1/(yu*yv)}, yw])/
      64 + (3*G[{0}, yw]*G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{1, 1/(yu*yv)}, yw])/
      64 + (3*G[{1}, yu^(-1)]*G[{1}, yw]*G[{1/(yu*yv)}, yw]*
       G[{1, 1/(yu*yv)}, yw])/64 + (3*G[{1}, yv^(-1)]*G[{1}, yw]*
       G[{1/(yu*yv)}, yw]*G[{1, 1/(yu*yv)}, yw])/64 - 
     (3*G[{0}, yu^(-1)]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*
       G[{1, 1/(yu*yv)}, yw])/32 - (3*G[{0}, yv^(-1)]*G[{yu^(-1)}, yw]*
       G[{1/(yu*yv)}, yw]*G[{1, 1/(yu*yv)}, yw])/32 + 
     (3*G[{0}, yw]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{1, 1/(yu*yv)}, yw])/
      32 + (3*G[{1}, yu^(-1)]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*
       G[{1, 1/(yu*yv)}, yw])/32 + (3*G[{1}, yv^(-1)]*G[{yu^(-1)}, yw]*
       G[{1/(yu*yv)}, yw]*G[{1, 1/(yu*yv)}, yw])/32 - 
     (7*G[{yu^(-1)}, yw]^2*G[{1/(yu*yv)}, yw]*G[{1, 1/(yu*yv)}, yw])/64 - 
     (G[{1}, yu^(-1)]*G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw]*
       G[{1, 1/(yu*yv)}, yw])/16 - (G[{1}, yv^(-1)]*G[{yu}, yv^(-1)]*
       G[{1/(yu*yv)}, yw]*G[{1, 1/(yu*yv)}, yw])/16 + 
     (G[{yu}, yv^(-1)]^2*G[{1/(yu*yv)}, yw]*G[{1, 1/(yu*yv)}, yw])/16 + 
     (7*G[{0}, yu^(-1)]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*
       G[{1, 1/(yu*yv)}, yw])/32 + (7*G[{0}, yv^(-1)]*G[{yv^(-1)}, yw]*
       G[{1/(yu*yv)}, yw]*G[{1, 1/(yu*yv)}, yw])/32 - 
     (7*G[{0}, yw]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{1, 1/(yu*yv)}, yw])/
      32 - (G[{1}, yu^(-1)]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*
       G[{1, 1/(yu*yv)}, yw])/32 - (7*G[{1}, yv^(-1)]*G[{yv^(-1)}, yw]*
       G[{1/(yu*yv)}, yw]*G[{1, 1/(yu*yv)}, yw])/32 + 
     (3*G[{1}, yw]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{1, 1/(yu*yv)}, yw])/
      16 + (5*G[{yu^(-1)}, yw]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*
       G[{1, 1/(yu*yv)}, yw])/32 - (3*G[{yu}, yv^(-1)]*G[{yv^(-1)}, yw]*
       G[{1/(yu*yv)}, yw]*G[{1, 1/(yu*yv)}, yw])/16 + 
     (9*G[{yv^(-1)}, yw]^2*G[{1/(yu*yv)}, yw]*G[{1, 1/(yu*yv)}, yw])/64 + 
     (G[{0}, yu^(-1)]*G[{1/(yu*yv)}, yw]^2*G[{1, 1/(yu*yv)}, yw])/128 + 
     (G[{0}, yv^(-1)]*G[{1/(yu*yv)}, yw]^2*G[{1, 1/(yu*yv)}, yw])/128 - 
     (G[{0}, yw]*G[{1/(yu*yv)}, yw]^2*G[{1, 1/(yu*yv)}, yw])/128 + 
     (7*G[{1}, yu^(-1)]*G[{1/(yu*yv)}, yw]^2*G[{1, 1/(yu*yv)}, yw])/128 - 
     (G[{1}, yv^(-1)]*G[{1/(yu*yv)}, yw]^2*G[{1, 1/(yu*yv)}, yw])/128 + 
     (G[{1}, yw]*G[{1/(yu*yv)}, yw]^2*G[{1, 1/(yu*yv)}, yw])/16 + 
     (G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2*G[{1, 1/(yu*yv)}, yw])/128 - 
     (G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw]^2*G[{1, 1/(yu*yv)}, yw])/16 - 
     (7*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2*G[{1, 1/(yu*yv)}, yw])/128 - 
     (G[{0}, yu^(-1)]*G[{0, 1}, yu^(-1)]*G[{1, 1/(yu*yv)}, yw])/8 - 
     (G[{0}, yv^(-1)]*G[{0, 1}, yu^(-1)]*G[{1, 1/(yu*yv)}, yw])/8 + 
     (G[{0}, yw]*G[{0, 1}, yu^(-1)]*G[{1, 1/(yu*yv)}, yw])/8 + 
     (G[{1}, yu^(-1)]*G[{0, 1}, yu^(-1)]*G[{1, 1/(yu*yv)}, yw])/16 + 
     (G[{1}, yv^(-1)]*G[{0, 1}, yu^(-1)]*G[{1, 1/(yu*yv)}, yw])/16 - 
     (G[{1}, yw]*G[{0, 1}, yu^(-1)]*G[{1, 1/(yu*yv)}, yw])/16 + 
     (G[{yu}, yv^(-1)]*G[{0, 1}, yu^(-1)]*G[{1, 1/(yu*yv)}, yw])/8 + 
     (G[{1/(yu*yv)}, yw]*G[{0, 1}, yu^(-1)]*G[{1, 1/(yu*yv)}, yw])/16 + 
     (G[{0}, yu^(-1)]*G[{0, 1}, yv^(-1)]*G[{1, 1/(yu*yv)}, yw])/16 + 
     (G[{0}, yv^(-1)]*G[{0, 1}, yv^(-1)]*G[{1, 1/(yu*yv)}, yw])/16 - 
     (G[{0}, yw]*G[{0, 1}, yv^(-1)]*G[{1, 1/(yu*yv)}, yw])/16 - 
     (G[{1}, yv^(-1)]*G[{0, 1}, yv^(-1)]*G[{1, 1/(yu*yv)}, yw])/16 + 
     (G[{1}, yw]*G[{0, 1}, yv^(-1)]*G[{1, 1/(yu*yv)}, yw])/16 - 
     (G[{yu}, yv^(-1)]*G[{0, 1}, yv^(-1)]*G[{1, 1/(yu*yv)}, yw])/8 + 
     (G[{1/(yu*yv)}, yw]*G[{0, 1}, yv^(-1)]*G[{1, 1/(yu*yv)}, yw])/16 + 
     (G[{0}, yu^(-1)]*G[{0, 1}, yw]*G[{1, 1/(yu*yv)}, yw])/32 + 
     (G[{0}, yv^(-1)]*G[{0, 1}, yw]*G[{1, 1/(yu*yv)}, yw])/32 - 
     (G[{0}, yw]*G[{0, 1}, yw]*G[{1, 1/(yu*yv)}, yw])/32 - 
     (G[{1}, yu^(-1)]*G[{0, 1}, yw]*G[{1, 1/(yu*yv)}, yw])/32 - 
     (3*G[{1}, yv^(-1)]*G[{0, 1}, yw]*G[{1, 1/(yu*yv)}, yw])/32 - 
     (3*G[{1}, yw]*G[{0, 1}, yw]*G[{1, 1/(yu*yv)}, yw])/64 + 
     (G[{yu}, yv^(-1)]*G[{0, 1}, yw]*G[{1, 1/(yu*yv)}, yw])/16 - 
     (3*G[{1/(yu*yv)}, yw]*G[{0, 1}, yw]*G[{1, 1/(yu*yv)}, yw])/64 - 
     (G[{0}, yu^(-1)]*G[{0, yu^(-1)}, yw]*G[{1, 1/(yu*yv)}, yw])/32 - 
     (G[{0}, yv^(-1)]*G[{0, yu^(-1)}, yw]*G[{1, 1/(yu*yv)}, yw])/32 + 
     (G[{0}, yw]*G[{0, yu^(-1)}, yw]*G[{1, 1/(yu*yv)}, yw])/32 + 
     (G[{1}, yu^(-1)]*G[{0, yu^(-1)}, yw]*G[{1, 1/(yu*yv)}, yw])/32 + 
     (3*G[{1}, yv^(-1)]*G[{0, yu^(-1)}, yw]*G[{1, 1/(yu*yv)}, yw])/32 + 
     (3*G[{1}, yw]*G[{0, yu^(-1)}, yw]*G[{1, 1/(yu*yv)}, yw])/64 - 
     (G[{yu}, yv^(-1)]*G[{0, yu^(-1)}, yw]*G[{1, 1/(yu*yv)}, yw])/16 + 
     (3*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1)}, yw]*G[{1, 1/(yu*yv)}, yw])/64 - 
     (G[{0}, yu^(-1)]*G[{0, yu}, yv^(-1)]*G[{1, 1/(yu*yv)}, yw])/16 - 
     (G[{0}, yv^(-1)]*G[{0, yu}, yv^(-1)]*G[{1, 1/(yu*yv)}, yw])/16 + 
     (G[{0}, yw]*G[{0, yu}, yv^(-1)]*G[{1, 1/(yu*yv)}, yw])/16 + 
     (G[{1}, yv^(-1)]*G[{0, yu}, yv^(-1)]*G[{1, 1/(yu*yv)}, yw])/16 - 
     (G[{1}, yw]*G[{0, yu}, yv^(-1)]*G[{1, 1/(yu*yv)}, yw])/16 + 
     (G[{yu}, yv^(-1)]*G[{0, yu}, yv^(-1)]*G[{1, 1/(yu*yv)}, yw])/8 - 
     (G[{1/(yu*yv)}, yw]*G[{0, yu}, yv^(-1)]*G[{1, 1/(yu*yv)}, yw])/16 - 
     (G[{0}, yu^(-1)]*G[{0, yv^(-1)}, yw]*G[{1, 1/(yu*yv)}, yw])/32 - 
     (G[{0}, yv^(-1)]*G[{0, yv^(-1)}, yw]*G[{1, 1/(yu*yv)}, yw])/32 + 
     (G[{0}, yw]*G[{0, yv^(-1)}, yw]*G[{1, 1/(yu*yv)}, yw])/32 + 
     (G[{1}, yu^(-1)]*G[{0, yv^(-1)}, yw]*G[{1, 1/(yu*yv)}, yw])/32 + 
     (3*G[{1}, yv^(-1)]*G[{0, yv^(-1)}, yw]*G[{1, 1/(yu*yv)}, yw])/32 + 
     (3*G[{1}, yw]*G[{0, yv^(-1)}, yw]*G[{1, 1/(yu*yv)}, yw])/64 - 
     (G[{yu}, yv^(-1)]*G[{0, yv^(-1)}, yw]*G[{1, 1/(yu*yv)}, yw])/16 + 
     (3*G[{1/(yu*yv)}, yw]*G[{0, yv^(-1)}, yw]*G[{1, 1/(yu*yv)}, yw])/64 + 
     (G[{0}, yu^(-1)]*G[{0, 1/(yu*yv)}, yw]*G[{1, 1/(yu*yv)}, yw])/32 + 
     (G[{0}, yv^(-1)]*G[{0, 1/(yu*yv)}, yw]*G[{1, 1/(yu*yv)}, yw])/32 - 
     (G[{0}, yw]*G[{0, 1/(yu*yv)}, yw]*G[{1, 1/(yu*yv)}, yw])/32 - 
     (G[{1}, yu^(-1)]*G[{0, 1/(yu*yv)}, yw]*G[{1, 1/(yu*yv)}, yw])/32 - 
     (3*G[{1}, yv^(-1)]*G[{0, 1/(yu*yv)}, yw]*G[{1, 1/(yu*yv)}, yw])/32 - 
     (3*G[{1}, yw]*G[{0, 1/(yu*yv)}, yw]*G[{1, 1/(yu*yv)}, yw])/64 + 
     (G[{yu}, yv^(-1)]*G[{0, 1/(yu*yv)}, yw]*G[{1, 1/(yu*yv)}, yw])/16 - 
     (3*G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv)}, yw]*G[{1, 1/(yu*yv)}, yw])/64 + 
     (3*G[{0}, yu^(-1)]*G[{1, yu^(-1)}, yw]*G[{1, 1/(yu*yv)}, yw])/32 + 
     (3*G[{0}, yv^(-1)]*G[{1, yu^(-1)}, yw]*G[{1, 1/(yu*yv)}, yw])/32 - 
     (3*G[{0}, yw]*G[{1, yu^(-1)}, yw]*G[{1, 1/(yu*yv)}, yw])/32 - 
     (G[{1}, yu^(-1)]*G[{1, yu^(-1)}, yw]*G[{1, 1/(yu*yv)}, yw])/32 - 
     (5*G[{1}, yv^(-1)]*G[{1, yu^(-1)}, yw]*G[{1, 1/(yu*yv)}, yw])/32 + 
     (G[{1/(yu*yv)}, yw]*G[{1, yu^(-1)}, yw]*G[{1, 1/(yu*yv)}, yw])/64 + 
     (3*G[{0}, yu^(-1)]*G[{1, yu}, yv^(-1)]*G[{1, 1/(yu*yv)}, yw])/16 + 
     (3*G[{0}, yv^(-1)]*G[{1, yu}, yv^(-1)]*G[{1, 1/(yu*yv)}, yw])/16 - 
     (3*G[{0}, yw]*G[{1, yu}, yv^(-1)]*G[{1, 1/(yu*yv)}, yw])/16 - 
     (G[{1}, yu^(-1)]*G[{1, yu}, yv^(-1)]*G[{1, 1/(yu*yv)}, yw])/8 - 
     (3*G[{1}, yv^(-1)]*G[{1, yu}, yv^(-1)]*G[{1, 1/(yu*yv)}, yw])/16 + 
     (G[{1}, yw]*G[{1, yu}, yv^(-1)]*G[{1, 1/(yu*yv)}, yw])/8 - 
     (G[{yu}, yv^(-1)]*G[{1, yu}, yv^(-1)]*G[{1, 1/(yu*yv)}, yw])/4 - 
     (3*G[{0}, yu^(-1)]*G[{1, yv^(-1)}, yw]*G[{1, 1/(yu*yv)}, yw])/32 - 
     (3*G[{0}, yv^(-1)]*G[{1, yv^(-1)}, yw]*G[{1, 1/(yu*yv)}, yw])/32 + 
     (3*G[{0}, yw]*G[{1, yv^(-1)}, yw]*G[{1, 1/(yu*yv)}, yw])/32 + 
     (3*G[{1}, yu^(-1)]*G[{1, yv^(-1)}, yw]*G[{1, 1/(yu*yv)}, yw])/32 + 
     (G[{1}, yv^(-1)]*G[{1, yv^(-1)}, yw]*G[{1, 1/(yu*yv)}, yw])/32 - 
     (G[{1}, yw]*G[{1, yv^(-1)}, yw]*G[{1, 1/(yu*yv)}, yw])/16 + 
     (G[{yu}, yv^(-1)]*G[{1, yv^(-1)}, yw]*G[{1, 1/(yu*yv)}, yw])/16 + 
     (G[{1/(yu*yv)}, yw]*G[{1, yv^(-1)}, yw]*G[{1, 1/(yu*yv)}, yw])/64 + 
     (G[{0}, yu^(-1)]*G[{1, 1/(yu*yv)}, yw]^2)/32 + 
     (G[{0}, yv^(-1)]*G[{1, 1/(yu*yv)}, yw]^2)/32 - 
     (G[{0}, yw]*G[{1, 1/(yu*yv)}, yw]^2)/32 - 
     (G[{1}, yu^(-1)]*G[{1, 1/(yu*yv)}, yw]^2)/16 - 
     (G[{1}, yv^(-1)]*G[{1, 1/(yu*yv)}, yw]^2)/32 - 
     (G[{1}, yw]*G[{1, 1/(yu*yv)}, yw]^2)/32 + 
     (G[{yu}, yv^(-1)]*G[{1, 1/(yu*yv)}, yw]^2)/32 - 
     (G[{1/(yu*yv)}, yw]*G[{1, 1/(yu*yv)}, yw]^2)/16 + 
     (Pi^2*G[{0}, yu^(-1)]*G[{yu^(-1), 1/(yu*yv)}, yw])/256 + 
     (3*G[{0}, yu^(-1)]^3*G[{yu^(-1), 1/(yu*yv)}, yw])/128 + 
     (Pi^2*G[{0}, yv^(-1)]*G[{yu^(-1), 1/(yu*yv)}, yw])/256 + 
     (9*G[{0}, yu^(-1)]^2*G[{0}, yv^(-1)]*G[{yu^(-1), 1/(yu*yv)}, yw])/128 + 
     (9*G[{0}, yu^(-1)]*G[{0}, yv^(-1)]^2*G[{yu^(-1), 1/(yu*yv)}, yw])/128 + 
     (3*G[{0}, yv^(-1)]^3*G[{yu^(-1), 1/(yu*yv)}, yw])/128 - 
     (Pi^2*G[{0}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw])/256 - 
     (9*G[{0}, yu^(-1)]^2*G[{0}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw])/128 - 
     (9*G[{0}, yu^(-1)]*G[{0}, yv^(-1)]*G[{0}, yw]*G[{yu^(-1), 1/(yu*yv)}, 
        yw])/64 - (9*G[{0}, yv^(-1)]^2*G[{0}, yw]*G[{yu^(-1), 1/(yu*yv)}, 
        yw])/128 + (9*G[{0}, yu^(-1)]*G[{0}, yw]^2*G[{yu^(-1), 1/(yu*yv)}, 
        yw])/128 + (9*G[{0}, yv^(-1)]*G[{0}, yw]^2*G[{yu^(-1), 1/(yu*yv)}, 
        yw])/128 - (3*G[{0}, yw]^3*G[{yu^(-1), 1/(yu*yv)}, yw])/128 - 
     (19*Pi^2*G[{1}, yu^(-1)]*G[{yu^(-1), 1/(yu*yv)}, yw])/768 - 
     (9*G[{0}, yu^(-1)]^2*G[{1}, yu^(-1)]*G[{yu^(-1), 1/(yu*yv)}, yw])/128 - 
     (9*G[{0}, yu^(-1)]*G[{0}, yv^(-1)]*G[{1}, yu^(-1)]*
       G[{yu^(-1), 1/(yu*yv)}, yw])/64 - (9*G[{0}, yv^(-1)]^2*G[{1}, yu^(-1)]*
       G[{yu^(-1), 1/(yu*yv)}, yw])/128 + 
     (9*G[{0}, yu^(-1)]*G[{0}, yw]*G[{1}, yu^(-1)]*G[{yu^(-1), 1/(yu*yv)}, 
        yw])/64 + (9*G[{0}, yv^(-1)]*G[{0}, yw]*G[{1}, yu^(-1)]*
       G[{yu^(-1), 1/(yu*yv)}, yw])/64 - (9*G[{0}, yw]^2*G[{1}, yu^(-1)]*
       G[{yu^(-1), 1/(yu*yv)}, yw])/128 + 
     (9*G[{0}, yu^(-1)]*G[{1}, yu^(-1)]^2*G[{yu^(-1), 1/(yu*yv)}, yw])/128 + 
     (9*G[{0}, yv^(-1)]*G[{1}, yu^(-1)]^2*G[{yu^(-1), 1/(yu*yv)}, yw])/128 - 
     (9*G[{0}, yw]*G[{1}, yu^(-1)]^2*G[{yu^(-1), 1/(yu*yv)}, yw])/128 - 
     (3*G[{1}, yu^(-1)]^3*G[{yu^(-1), 1/(yu*yv)}, yw])/128 - 
     (Pi^2*G[{1}, yv^(-1)]*G[{yu^(-1), 1/(yu*yv)}, yw])/256 - 
     (13*G[{0}, yu^(-1)]^2*G[{1}, yv^(-1)]*G[{yu^(-1), 1/(yu*yv)}, yw])/128 - 
     (13*G[{0}, yu^(-1)]*G[{0}, yv^(-1)]*G[{1}, yv^(-1)]*
       G[{yu^(-1), 1/(yu*yv)}, yw])/64 - 
     (13*G[{0}, yv^(-1)]^2*G[{1}, yv^(-1)]*G[{yu^(-1), 1/(yu*yv)}, yw])/128 + 
     (13*G[{0}, yu^(-1)]*G[{0}, yw]*G[{1}, yv^(-1)]*G[{yu^(-1), 1/(yu*yv)}, 
        yw])/64 + (13*G[{0}, yv^(-1)]*G[{0}, yw]*G[{1}, yv^(-1)]*
       G[{yu^(-1), 1/(yu*yv)}, yw])/64 - (13*G[{0}, yw]^2*G[{1}, yv^(-1)]*
       G[{yu^(-1), 1/(yu*yv)}, yw])/128 + 
     (5*G[{0}, yu^(-1)]*G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*
       G[{yu^(-1), 1/(yu*yv)}, yw])/64 + (5*G[{0}, yv^(-1)]*G[{1}, yu^(-1)]*
       G[{1}, yv^(-1)]*G[{yu^(-1), 1/(yu*yv)}, yw])/64 - 
     (5*G[{0}, yw]*G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*G[{yu^(-1), 1/(yu*yv)}, 
        yw])/64 + (3*G[{1}, yu^(-1)]^2*G[{1}, yv^(-1)]*
       G[{yu^(-1), 1/(yu*yv)}, yw])/128 + 
     (23*G[{0}, yu^(-1)]*G[{1}, yv^(-1)]^2*G[{yu^(-1), 1/(yu*yv)}, yw])/128 + 
     (23*G[{0}, yv^(-1)]*G[{1}, yv^(-1)]^2*G[{yu^(-1), 1/(yu*yv)}, yw])/128 - 
     (23*G[{0}, yw]*G[{1}, yv^(-1)]^2*G[{yu^(-1), 1/(yu*yv)}, yw])/128 - 
     (7*G[{1}, yu^(-1)]*G[{1}, yv^(-1)]^2*G[{yu^(-1), 1/(yu*yv)}, yw])/128 - 
     (13*G[{1}, yv^(-1)]^3*G[{yu^(-1), 1/(yu*yv)}, yw])/128 - 
     (Pi^2*G[{1}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw])/128 + 
     (11*G[{0}, yu^(-1)]^2*G[{1}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw])/128 + 
     (11*G[{0}, yu^(-1)]*G[{0}, yv^(-1)]*G[{1}, yw]*G[{yu^(-1), 1/(yu*yv)}, 
        yw])/64 + (11*G[{0}, yv^(-1)]^2*G[{1}, yw]*G[{yu^(-1), 1/(yu*yv)}, 
        yw])/128 - (11*G[{0}, yu^(-1)]*G[{0}, yw]*G[{1}, yw]*
       G[{yu^(-1), 1/(yu*yv)}, yw])/64 - (11*G[{0}, yv^(-1)]*G[{0}, yw]*
       G[{1}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw])/64 + 
     (11*G[{0}, yw]^2*G[{1}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw])/128 - 
     (11*G[{0}, yu^(-1)]*G[{1}, yu^(-1)]*G[{1}, yw]*G[{yu^(-1), 1/(yu*yv)}, 
        yw])/64 - (11*G[{0}, yv^(-1)]*G[{1}, yu^(-1)]*G[{1}, yw]*
       G[{yu^(-1), 1/(yu*yv)}, yw])/64 + (11*G[{0}, yw]*G[{1}, yu^(-1)]*
       G[{1}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw])/64 + 
     (11*G[{1}, yu^(-1)]^2*G[{1}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw])/128 - 
     (17*G[{0}, yu^(-1)]*G[{1}, yv^(-1)]*G[{1}, yw]*G[{yu^(-1), 1/(yu*yv)}, 
        yw])/64 - (17*G[{0}, yv^(-1)]*G[{1}, yv^(-1)]*G[{1}, yw]*
       G[{yu^(-1), 1/(yu*yv)}, yw])/64 + (17*G[{0}, yw]*G[{1}, yv^(-1)]*
       G[{1}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw])/64 + 
     (9*G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*G[{1}, yw]*G[{yu^(-1), 1/(yu*yv)}, 
        yw])/64 + (23*G[{1}, yv^(-1)]^2*G[{1}, yw]*G[{yu^(-1), 1/(yu*yv)}, 
        yw])/128 + (3*G[{0}, yu^(-1)]*G[{1}, yw]^2*G[{yu^(-1), 1/(yu*yv)}, 
        yw])/128 + (3*G[{0}, yv^(-1)]*G[{1}, yw]^2*G[{yu^(-1), 1/(yu*yv)}, 
        yw])/128 - (3*G[{0}, yw]*G[{1}, yw]^2*G[{yu^(-1), 1/(yu*yv)}, yw])/
      128 - (3*G[{1}, yu^(-1)]*G[{1}, yw]^2*G[{yu^(-1), 1/(yu*yv)}, yw])/
      128 - (3*G[{1}, yv^(-1)]*G[{1}, yw]^2*G[{yu^(-1), 1/(yu*yv)}, yw])/
      128 - (7*Pi^2*G[{yu^(-1)}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw])/768 - 
     (G[{0}, yu^(-1)]^2*G[{yu^(-1)}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw])/64 - 
     (G[{0}, yu^(-1)]*G[{0}, yv^(-1)]*G[{yu^(-1)}, yw]*
       G[{yu^(-1), 1/(yu*yv)}, yw])/32 - (G[{0}, yv^(-1)]^2*G[{yu^(-1)}, yw]*
       G[{yu^(-1), 1/(yu*yv)}, yw])/64 + 
     (G[{0}, yu^(-1)]*G[{0}, yw]*G[{yu^(-1)}, yw]*G[{yu^(-1), 1/(yu*yv)}, 
        yw])/32 + (G[{0}, yv^(-1)]*G[{0}, yw]*G[{yu^(-1)}, yw]*
       G[{yu^(-1), 1/(yu*yv)}, yw])/32 - (G[{0}, yw]^2*G[{yu^(-1)}, yw]*
       G[{yu^(-1), 1/(yu*yv)}, yw])/64 + (G[{0}, yu^(-1)]*G[{1}, yu^(-1)]*
       G[{yu^(-1)}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw])/32 + 
     (G[{0}, yv^(-1)]*G[{1}, yu^(-1)]*G[{yu^(-1)}, yw]*
       G[{yu^(-1), 1/(yu*yv)}, yw])/32 - 
     (G[{0}, yw]*G[{1}, yu^(-1)]*G[{yu^(-1)}, yw]*G[{yu^(-1), 1/(yu*yv)}, 
        yw])/32 - (G[{1}, yu^(-1)]^2*G[{yu^(-1)}, yw]*G[{yu^(-1), 1/(yu*yv)}, 
        yw])/64 + (G[{0}, yu^(-1)]*G[{1}, yv^(-1)]*G[{yu^(-1)}, yw]*
       G[{yu^(-1), 1/(yu*yv)}, yw])/32 + (G[{0}, yv^(-1)]*G[{1}, yv^(-1)]*
       G[{yu^(-1)}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw])/32 - 
     (G[{0}, yw]*G[{1}, yv^(-1)]*G[{yu^(-1)}, yw]*G[{yu^(-1), 1/(yu*yv)}, 
        yw])/32 - (G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*G[{yu^(-1)}, yw]*
       G[{yu^(-1), 1/(yu*yv)}, yw])/32 + (G[{1}, yv^(-1)]^2*G[{yu^(-1)}, yw]*
       G[{yu^(-1), 1/(yu*yv)}, yw])/32 + (3*G[{0}, yu^(-1)]*G[{1}, yw]*
       G[{yu^(-1)}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw])/16 + 
     (3*G[{0}, yv^(-1)]*G[{1}, yw]*G[{yu^(-1)}, yw]*G[{yu^(-1), 1/(yu*yv)}, 
        yw])/16 - (3*G[{0}, yw]*G[{1}, yw]*G[{yu^(-1)}, yw]*
       G[{yu^(-1), 1/(yu*yv)}, yw])/16 - (3*G[{1}, yu^(-1)]*G[{1}, yw]*
       G[{yu^(-1)}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw])/16 - 
     (3*G[{1}, yv^(-1)]*G[{1}, yw]*G[{yu^(-1)}, yw]*G[{yu^(-1), 1/(yu*yv)}, 
        yw])/32 + (3*G[{1}, yw]^2*G[{yu^(-1)}, yw]*G[{yu^(-1), 1/(yu*yv)}, 
        yw])/64 - (7*G[{0}, yu^(-1)]*G[{yu^(-1)}, yw]^2*
       G[{yu^(-1), 1/(yu*yv)}, yw])/64 - 
     (7*G[{0}, yv^(-1)]*G[{yu^(-1)}, yw]^2*G[{yu^(-1), 1/(yu*yv)}, yw])/64 + 
     (7*G[{0}, yw]*G[{yu^(-1)}, yw]^2*G[{yu^(-1), 1/(yu*yv)}, yw])/64 + 
     (7*G[{1}, yu^(-1)]*G[{yu^(-1)}, yw]^2*G[{yu^(-1), 1/(yu*yv)}, yw])/64 + 
     (11*G[{1}, yv^(-1)]*G[{yu^(-1)}, yw]^2*G[{yu^(-1), 1/(yu*yv)}, yw])/64 + 
     (G[{1}, yw]*G[{yu^(-1)}, yw]^2*G[{yu^(-1), 1/(yu*yv)}, yw])/16 - 
     (11*G[{yu^(-1)}, yw]^3*G[{yu^(-1), 1/(yu*yv)}, yw])/192 + 
     (Pi^2*G[{yu}, yv^(-1)]*G[{yu^(-1), 1/(yu*yv)}, yw])/48 + 
     (G[{0}, yu^(-1)]^2*G[{yu}, yv^(-1)]*G[{yu^(-1), 1/(yu*yv)}, yw])/32 + 
     (G[{0}, yu^(-1)]*G[{0}, yv^(-1)]*G[{yu}, yv^(-1)]*
       G[{yu^(-1), 1/(yu*yv)}, yw])/16 + (G[{0}, yv^(-1)]^2*G[{yu}, yv^(-1)]*
       G[{yu^(-1), 1/(yu*yv)}, yw])/32 - 
     (G[{0}, yu^(-1)]*G[{0}, yw]*G[{yu}, yv^(-1)]*G[{yu^(-1), 1/(yu*yv)}, 
        yw])/16 - (G[{0}, yv^(-1)]*G[{0}, yw]*G[{yu}, yv^(-1)]*
       G[{yu^(-1), 1/(yu*yv)}, yw])/16 + (G[{0}, yw]^2*G[{yu}, yv^(-1)]*
       G[{yu^(-1), 1/(yu*yv)}, yw])/32 + (G[{0}, yu^(-1)]*G[{1}, yu^(-1)]*
       G[{yu}, yv^(-1)]*G[{yu^(-1), 1/(yu*yv)}, yw])/16 + 
     (G[{0}, yv^(-1)]*G[{1}, yu^(-1)]*G[{yu}, yv^(-1)]*
       G[{yu^(-1), 1/(yu*yv)}, yw])/16 - 
     (G[{0}, yw]*G[{1}, yu^(-1)]*G[{yu}, yv^(-1)]*G[{yu^(-1), 1/(yu*yv)}, 
        yw])/16 - (3*G[{1}, yu^(-1)]^2*G[{yu}, yv^(-1)]*
       G[{yu^(-1), 1/(yu*yv)}, yw])/32 + (G[{0}, yu^(-1)]*G[{1}, yv^(-1)]*
       G[{yu}, yv^(-1)]*G[{yu^(-1), 1/(yu*yv)}, yw])/16 + 
     (G[{0}, yv^(-1)]*G[{1}, yv^(-1)]*G[{yu}, yv^(-1)]*
       G[{yu^(-1), 1/(yu*yv)}, yw])/16 - 
     (G[{0}, yw]*G[{1}, yv^(-1)]*G[{yu}, yv^(-1)]*G[{yu^(-1), 1/(yu*yv)}, 
        yw])/16 + (G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*G[{yu}, yv^(-1)]*
       G[{yu^(-1), 1/(yu*yv)}, yw])/16 - 
     (3*G[{1}, yv^(-1)]^2*G[{yu}, yv^(-1)]*G[{yu^(-1), 1/(yu*yv)}, yw])/32 + 
     (3*G[{0}, yu^(-1)]*G[{1}, yw]*G[{yu}, yv^(-1)]*G[{yu^(-1), 1/(yu*yv)}, 
        yw])/32 + (3*G[{0}, yv^(-1)]*G[{1}, yw]*G[{yu}, yv^(-1)]*
       G[{yu^(-1), 1/(yu*yv)}, yw])/32 - 
     (3*G[{0}, yw]*G[{1}, yw]*G[{yu}, yv^(-1)]*G[{yu^(-1), 1/(yu*yv)}, yw])/
      32 + (G[{1}, yu^(-1)]*G[{1}, yw]*G[{yu}, yv^(-1)]*
       G[{yu^(-1), 1/(yu*yv)}, yw])/32 + 
     (G[{1}, yv^(-1)]*G[{1}, yw]*G[{yu}, yv^(-1)]*G[{yu^(-1), 1/(yu*yv)}, 
        yw])/32 + (G[{1}, yv^(-1)]*G[{yu^(-1)}, yw]*G[{yu}, yv^(-1)]*
       G[{yu^(-1), 1/(yu*yv)}, yw])/8 - (3*G[{1}, yw]*G[{yu^(-1)}, yw]*
       G[{yu}, yv^(-1)]*G[{yu^(-1), 1/(yu*yv)}, yw])/32 - 
     (G[{yu^(-1)}, yw]^2*G[{yu}, yv^(-1)]*G[{yu^(-1), 1/(yu*yv)}, yw])/16 - 
     (G[{0}, yu^(-1)]*G[{yu}, yv^(-1)]^2*G[{yu^(-1), 1/(yu*yv)}, yw])/8 - 
     (G[{0}, yv^(-1)]*G[{yu}, yv^(-1)]^2*G[{yu^(-1), 1/(yu*yv)}, yw])/8 + 
     (G[{0}, yw]*G[{yu}, yv^(-1)]^2*G[{yu^(-1), 1/(yu*yv)}, yw])/8 + 
     (G[{1}, yv^(-1)]*G[{yu}, yv^(-1)]^2*G[{yu^(-1), 1/(yu*yv)}, yw])/16 - 
     (G[{1}, yw]*G[{yu}, yv^(-1)]^2*G[{yu^(-1), 1/(yu*yv)}, yw])/8 - 
     (G[{yu^(-1)}, yw]*G[{yu}, yv^(-1)]^2*G[{yu^(-1), 1/(yu*yv)}, yw])/16 + 
     (G[{yu}, yv^(-1)]^3*G[{yu^(-1), 1/(yu*yv)}, yw])/16 - 
     (11*Pi^2*G[{1/(yu*yv)}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw])/768 - 
     (G[{0}, yu^(-1)]^2*G[{1/(yu*yv)}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw])/128 - 
     (G[{0}, yu^(-1)]*G[{0}, yv^(-1)]*G[{1/(yu*yv)}, yw]*
       G[{yu^(-1), 1/(yu*yv)}, yw])/64 - 
     (G[{0}, yv^(-1)]^2*G[{1/(yu*yv)}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw])/128 + 
     (G[{0}, yu^(-1)]*G[{0}, yw]*G[{1/(yu*yv)}, yw]*G[{yu^(-1), 1/(yu*yv)}, 
        yw])/64 + (G[{0}, yv^(-1)]*G[{0}, yw]*G[{1/(yu*yv)}, yw]*
       G[{yu^(-1), 1/(yu*yv)}, yw])/64 - (G[{0}, yw]^2*G[{1/(yu*yv)}, yw]*
       G[{yu^(-1), 1/(yu*yv)}, yw])/128 + 
     (9*G[{0}, yu^(-1)]*G[{1}, yu^(-1)]*G[{1/(yu*yv)}, yw]*
       G[{yu^(-1), 1/(yu*yv)}, yw])/64 + (9*G[{0}, yv^(-1)]*G[{1}, yu^(-1)]*
       G[{1/(yu*yv)}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw])/64 - 
     (9*G[{0}, yw]*G[{1}, yu^(-1)]*G[{1/(yu*yv)}, yw]*G[{yu^(-1), 1/(yu*yv)}, 
        yw])/64 - (9*G[{1}, yu^(-1)]^2*G[{1/(yu*yv)}, yw]*
       G[{yu^(-1), 1/(yu*yv)}, yw])/128 - 
     (G[{0}, yu^(-1)]*G[{1}, yv^(-1)]*G[{1/(yu*yv)}, yw]*
       G[{yu^(-1), 1/(yu*yv)}, yw])/64 - (G[{0}, yv^(-1)]*G[{1}, yv^(-1)]*
       G[{1/(yu*yv)}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw])/64 + 
     (G[{0}, yw]*G[{1}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{yu^(-1), 1/(yu*yv)}, 
        yw])/64 - (15*G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*G[{1/(yu*yv)}, yw]*
       G[{yu^(-1), 1/(yu*yv)}, yw])/64 + 
     (3*G[{1}, yv^(-1)]^2*G[{1/(yu*yv)}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw])/
      64 + (5*G[{0}, yu^(-1)]*G[{1}, yw]*G[{1/(yu*yv)}, yw]*
       G[{yu^(-1), 1/(yu*yv)}, yw])/32 + (5*G[{0}, yv^(-1)]*G[{1}, yw]*
       G[{1/(yu*yv)}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw])/32 - 
     (5*G[{0}, yw]*G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw])/
      32 - (5*G[{1}, yu^(-1)]*G[{1}, yw]*G[{1/(yu*yv)}, yw]*
       G[{yu^(-1), 1/(yu*yv)}, yw])/32 - (15*G[{1}, yv^(-1)]*G[{1}, yw]*
       G[{1/(yu*yv)}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw])/64 - 
     (5*G[{1}, yw]^2*G[{1/(yu*yv)}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw])/128 - 
     (3*G[{0}, yu^(-1)]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*
       G[{yu^(-1), 1/(yu*yv)}, yw])/64 - (3*G[{0}, yv^(-1)]*G[{yu^(-1)}, yw]*
       G[{1/(yu*yv)}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw])/64 + 
     (3*G[{0}, yw]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*
       G[{yu^(-1), 1/(yu*yv)}, yw])/64 + (19*G[{1}, yu^(-1)]*G[{yu^(-1)}, yw]*
       G[{1/(yu*yv)}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw])/64 + 
     (5*G[{1}, yv^(-1)]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*
       G[{yu^(-1), 1/(yu*yv)}, yw])/64 + (9*G[{1}, yw]*G[{yu^(-1)}, yw]*
       G[{1/(yu*yv)}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw])/32 - 
     (5*G[{yu^(-1)}, yw]^2*G[{1/(yu*yv)}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw])/
      128 - (3*G[{0}, yu^(-1)]*G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw]*
       G[{yu^(-1), 1/(yu*yv)}, yw])/32 - (3*G[{0}, yv^(-1)]*G[{yu}, yv^(-1)]*
       G[{1/(yu*yv)}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw])/32 + 
     (3*G[{0}, yw]*G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw]*
       G[{yu^(-1), 1/(yu*yv)}, yw])/32 + (3*G[{1}, yu^(-1)]*G[{yu}, yv^(-1)]*
       G[{1/(yu*yv)}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw])/32 + 
     (9*G[{1}, yv^(-1)]*G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw]*
       G[{yu^(-1), 1/(yu*yv)}, yw])/32 + (5*G[{1}, yw]*G[{yu}, yv^(-1)]*
       G[{1/(yu*yv)}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw])/64 - 
     (9*G[{yu^(-1)}, yw]*G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw]*
       G[{yu^(-1), 1/(yu*yv)}, yw])/32 - 
     (3*G[{yu}, yv^(-1)]^2*G[{1/(yu*yv)}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw])/
      32 - (G[{0}, yu^(-1)]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*
       G[{yu^(-1), 1/(yu*yv)}, yw])/32 - (G[{0}, yv^(-1)]*G[{yv^(-1)}, yw]*
       G[{1/(yu*yv)}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw])/32 + 
     (G[{0}, yw]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{yu^(-1), 1/(yu*yv)}, 
        yw])/32 + (3*G[{1}, yu^(-1)]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*
       G[{yu^(-1), 1/(yu*yv)}, yw])/32 + (G[{1}, yv^(-1)]*G[{yv^(-1)}, yw]*
       G[{1/(yu*yv)}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw])/32 + 
     (G[{1}, yw]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{yu^(-1), 1/(yu*yv)}, 
        yw])/16 - (G[{yu^(-1)}, yw]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*
       G[{yu^(-1), 1/(yu*yv)}, yw])/32 - (G[{yu}, yv^(-1)]*G[{yv^(-1)}, yw]*
       G[{1/(yu*yv)}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw])/16 - 
     (5*G[{yv^(-1)}, yw]^2*G[{1/(yu*yv)}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw])/
      64 - (G[{0}, yu^(-1)]*G[{1/(yu*yv)}, yw]^2*G[{yu^(-1), 1/(yu*yv)}, yw])/
      32 - (G[{0}, yv^(-1)]*G[{1/(yu*yv)}, yw]^2*G[{yu^(-1), 1/(yu*yv)}, yw])/
      32 + (G[{0}, yw]*G[{1/(yu*yv)}, yw]^2*G[{yu^(-1), 1/(yu*yv)}, yw])/32 - 
     (G[{1}, yv^(-1)]*G[{1/(yu*yv)}, yw]^2*G[{yu^(-1), 1/(yu*yv)}, yw])/64 - 
     (5*G[{1}, yw]*G[{1/(yu*yv)}, yw]^2*G[{yu^(-1), 1/(yu*yv)}, yw])/64 + 
     (G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2*G[{yu^(-1), 1/(yu*yv)}, yw])/64 + 
     (5*G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw]^2*G[{yu^(-1), 1/(yu*yv)}, yw])/
      64 + (3*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2*G[{yu^(-1), 1/(yu*yv)}, 
        yw])/64 - (G[{1}, yu^(-1)]*G[{0, 1}, yu^(-1)]*G[{yu^(-1), 1/(yu*yv)}, 
        yw])/8 - (G[{1}, yw]*G[{0, 1}, yu^(-1)]*G[{yu^(-1), 1/(yu*yv)}, yw])/
      8 + (G[{yu}, yv^(-1)]*G[{0, 1}, yu^(-1)]*G[{yu^(-1), 1/(yu*yv)}, yw])/
      8 - (3*G[{0}, yu^(-1)]*G[{0, 1}, yv^(-1)]*G[{yu^(-1), 1/(yu*yv)}, yw])/
      32 - (3*G[{0}, yv^(-1)]*G[{0, 1}, yv^(-1)]*G[{yu^(-1), 1/(yu*yv)}, yw])/
      32 + (3*G[{0}, yw]*G[{0, 1}, yv^(-1)]*G[{yu^(-1), 1/(yu*yv)}, yw])/32 - 
     (G[{1}, yu^(-1)]*G[{0, 1}, yv^(-1)]*G[{yu^(-1), 1/(yu*yv)}, yw])/32 + 
     (3*G[{1}, yv^(-1)]*G[{0, 1}, yv^(-1)]*G[{yu^(-1), 1/(yu*yv)}, yw])/32 - 
     (G[{1}, yw]*G[{0, 1}, yv^(-1)]*G[{yu^(-1), 1/(yu*yv)}, yw])/8 - 
     (7*G[{yu^(-1)}, yw]*G[{0, 1}, yv^(-1)]*G[{yu^(-1), 1/(yu*yv)}, yw])/32 - 
     (7*G[{1/(yu*yv)}, yw]*G[{0, 1}, yv^(-1)]*G[{yu^(-1), 1/(yu*yv)}, yw])/
      64 + (G[{0}, yu^(-1)]*G[{0, 1}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw])/32 + 
     (G[{0}, yv^(-1)]*G[{0, 1}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw])/32 - 
     (G[{0}, yw]*G[{0, 1}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw])/32 + 
     (3*G[{1}, yu^(-1)]*G[{0, 1}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw])/32 - 
     (3*G[{1}, yv^(-1)]*G[{0, 1}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw])/32 + 
     (9*G[{1}, yw]*G[{0, 1}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw])/64 + 
     (3*G[{yu^(-1)}, yw]*G[{0, 1}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw])/16 - 
     (G[{yu}, yv^(-1)]*G[{0, 1}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw])/16 + 
     (G[{1/(yu*yv)}, yw]*G[{0, 1}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw])/16 - 
     (G[{0}, yu^(-1)]*G[{0, yu^(-1)}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw])/32 - 
     (G[{0}, yv^(-1)]*G[{0, yu^(-1)}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw])/32 + 
     (G[{0}, yw]*G[{0, yu^(-1)}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw])/32 - 
     (3*G[{1}, yu^(-1)]*G[{0, yu^(-1)}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw])/32 + 
     (3*G[{1}, yv^(-1)]*G[{0, yu^(-1)}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw])/32 - 
     (9*G[{1}, yw]*G[{0, yu^(-1)}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw])/64 - 
     (3*G[{yu^(-1)}, yw]*G[{0, yu^(-1)}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw])/
      16 + (G[{yu}, yv^(-1)]*G[{0, yu^(-1)}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw])/
      16 - (G[{1/(yu*yv)}, yw]*G[{0, yu^(-1)}, yw]*G[{yu^(-1), 1/(yu*yv)}, 
        yw])/16 + (3*G[{0}, yu^(-1)]*G[{0, yu}, yv^(-1)]*
       G[{yu^(-1), 1/(yu*yv)}, yw])/32 + 
     (3*G[{0}, yv^(-1)]*G[{0, yu}, yv^(-1)]*G[{yu^(-1), 1/(yu*yv)}, yw])/32 - 
     (3*G[{0}, yw]*G[{0, yu}, yv^(-1)]*G[{yu^(-1), 1/(yu*yv)}, yw])/32 + 
     (G[{1}, yu^(-1)]*G[{0, yu}, yv^(-1)]*G[{yu^(-1), 1/(yu*yv)}, yw])/32 - 
     (3*G[{1}, yv^(-1)]*G[{0, yu}, yv^(-1)]*G[{yu^(-1), 1/(yu*yv)}, yw])/32 + 
     (G[{1}, yw]*G[{0, yu}, yv^(-1)]*G[{yu^(-1), 1/(yu*yv)}, yw])/8 + 
     (7*G[{yu^(-1)}, yw]*G[{0, yu}, yv^(-1)]*G[{yu^(-1), 1/(yu*yv)}, yw])/
      32 + (7*G[{1/(yu*yv)}, yw]*G[{0, yu}, yv^(-1)]*G[{yu^(-1), 1/(yu*yv)}, 
        yw])/64 - (G[{0}, yu^(-1)]*G[{0, yv^(-1)}, yw]*
       G[{yu^(-1), 1/(yu*yv)}, yw])/32 - (G[{0}, yv^(-1)]*G[{0, yv^(-1)}, yw]*
       G[{yu^(-1), 1/(yu*yv)}, yw])/32 + (G[{0}, yw]*G[{0, yv^(-1)}, yw]*
       G[{yu^(-1), 1/(yu*yv)}, yw])/32 - 
     (3*G[{1}, yu^(-1)]*G[{0, yv^(-1)}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw])/32 + 
     (3*G[{1}, yv^(-1)]*G[{0, yv^(-1)}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw])/32 - 
     (9*G[{1}, yw]*G[{0, yv^(-1)}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw])/64 - 
     (3*G[{yu^(-1)}, yw]*G[{0, yv^(-1)}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw])/
      16 + (G[{yu}, yv^(-1)]*G[{0, yv^(-1)}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw])/
      16 - (G[{1/(yu*yv)}, yw]*G[{0, yv^(-1)}, yw]*G[{yu^(-1), 1/(yu*yv)}, 
        yw])/16 + (G[{0}, yu^(-1)]*G[{0, 1/(yu*yv)}, yw]*
       G[{yu^(-1), 1/(yu*yv)}, yw])/32 + 
     (G[{0}, yv^(-1)]*G[{0, 1/(yu*yv)}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw])/32 - 
     (G[{0}, yw]*G[{0, 1/(yu*yv)}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw])/32 + 
     (3*G[{1}, yu^(-1)]*G[{0, 1/(yu*yv)}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw])/
      32 - (3*G[{1}, yv^(-1)]*G[{0, 1/(yu*yv)}, yw]*G[{yu^(-1), 1/(yu*yv)}, 
        yw])/32 + (9*G[{1}, yw]*G[{0, 1/(yu*yv)}, yw]*G[{yu^(-1), 1/(yu*yv)}, 
        yw])/64 + (3*G[{yu^(-1)}, yw]*G[{0, 1/(yu*yv)}, yw]*
       G[{yu^(-1), 1/(yu*yv)}, yw])/16 - 
     (G[{yu}, yv^(-1)]*G[{0, 1/(yu*yv)}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw])/
      16 + (G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv)}, yw]*G[{yu^(-1), 1/(yu*yv)}, 
        yw])/16 - (G[{0}, yu^(-1)]*G[{1, yu^(-1)}, yw]*
       G[{yu^(-1), 1/(yu*yv)}, yw])/16 - (G[{0}, yv^(-1)]*G[{1, yu^(-1)}, yw]*
       G[{yu^(-1), 1/(yu*yv)}, yw])/16 + (G[{0}, yw]*G[{1, yu^(-1)}, yw]*
       G[{yu^(-1), 1/(yu*yv)}, yw])/16 + (G[{1}, yu^(-1)]*G[{1, yu^(-1)}, yw]*
       G[{yu^(-1), 1/(yu*yv)}, yw])/16 - (G[{1}, yw]*G[{1, yu^(-1)}, yw]*
       G[{yu^(-1), 1/(yu*yv)}, yw])/16 - 
     (G[{yu^(-1)}, yw]*G[{1, yu^(-1)}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw])/32 + 
     (G[{yu}, yv^(-1)]*G[{1, yu^(-1)}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw])/16 - 
     (3*G[{1/(yu*yv)}, yw]*G[{1, yu^(-1)}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw])/
      64 - (3*G[{0}, yu^(-1)]*G[{1, yu}, yv^(-1)]*G[{yu^(-1), 1/(yu*yv)}, 
        yw])/32 - (3*G[{0}, yv^(-1)]*G[{1, yu}, yv^(-1)]*
       G[{yu^(-1), 1/(yu*yv)}, yw])/32 + (3*G[{0}, yw]*G[{1, yu}, yv^(-1)]*
       G[{yu^(-1), 1/(yu*yv)}, yw])/32 - 
     (5*G[{1}, yu^(-1)]*G[{1, yu}, yv^(-1)]*G[{yu^(-1), 1/(yu*yv)}, yw])/32 + 
     (3*G[{1}, yv^(-1)]*G[{1, yu}, yv^(-1)]*G[{yu^(-1), 1/(yu*yv)}, yw])/32 - 
     (7*G[{yu^(-1)}, yw]*G[{1, yu}, yv^(-1)]*G[{yu^(-1), 1/(yu*yv)}, yw])/
      32 - (G[{yu}, yv^(-1)]*G[{1, yu}, yv^(-1)]*G[{yu^(-1), 1/(yu*yv)}, yw])/
      8 - (7*G[{1/(yu*yv)}, yw]*G[{1, yu}, yv^(-1)]*G[{yu^(-1), 1/(yu*yv)}, 
        yw])/64 + (G[{0}, yu^(-1)]*G[{1, yv^(-1)}, yw]*
       G[{yu^(-1), 1/(yu*yv)}, yw])/32 + (G[{0}, yv^(-1)]*G[{1, yv^(-1)}, yw]*
       G[{yu^(-1), 1/(yu*yv)}, yw])/32 - (G[{0}, yw]*G[{1, yv^(-1)}, yw]*
       G[{yu^(-1), 1/(yu*yv)}, yw])/32 + 
     (7*G[{1}, yu^(-1)]*G[{1, yv^(-1)}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw])/32 - 
     (3*G[{1}, yv^(-1)]*G[{1, yv^(-1)}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw])/32 + 
     (3*G[{1}, yw]*G[{1, yv^(-1)}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw])/16 + 
     (3*G[{yu^(-1)}, yw]*G[{1, yv^(-1)}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw])/
      16 - (3*G[{yu}, yv^(-1)]*G[{1, yv^(-1)}, yw]*G[{yu^(-1), 1/(yu*yv)}, 
        yw])/16 + (G[{1/(yu*yv)}, yw]*G[{1, yv^(-1)}, yw]*
       G[{yu^(-1), 1/(yu*yv)}, yw])/16 + 
     (3*G[{0}, yu^(-1)]*G[{1, 1/(yu*yv)}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw])/
      32 + (3*G[{0}, yv^(-1)]*G[{1, 1/(yu*yv)}, yw]*G[{yu^(-1), 1/(yu*yv)}, 
        yw])/32 - (3*G[{0}, yw]*G[{1, 1/(yu*yv)}, yw]*G[{yu^(-1), 1/(yu*yv)}, 
        yw])/32 - (3*G[{1}, yu^(-1)]*G[{1, 1/(yu*yv)}, yw]*
       G[{yu^(-1), 1/(yu*yv)}, yw])/32 - 
     (3*G[{1}, yv^(-1)]*G[{1, 1/(yu*yv)}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw])/
      32 + (7*G[{yu^(-1)}, yw]*G[{1, 1/(yu*yv)}, yw]*G[{yu^(-1), 1/(yu*yv)}, 
        yw])/32 + (7*G[{1/(yu*yv)}, yw]*G[{1, 1/(yu*yv)}, yw]*
       G[{yu^(-1), 1/(yu*yv)}, yw])/64 - 
     (G[{0}, yu^(-1)]*G[{yu^(-1), 1/(yu*yv)}, yw]^2)/16 - 
     (G[{0}, yv^(-1)]*G[{yu^(-1), 1/(yu*yv)}, yw]^2)/16 + 
     (G[{0}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw]^2)/16 - 
     (G[{1}, yu^(-1)]*G[{yu^(-1), 1/(yu*yv)}, yw]^2)/16 + 
     (3*G[{1}, yv^(-1)]*G[{yu^(-1), 1/(yu*yv)}, yw]^2)/32 - 
     (3*G[{1}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw]^2)/32 - 
     (3*G[{yu^(-1)}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw]^2)/32 + 
     (3*G[{yu}, yv^(-1)]*G[{yu^(-1), 1/(yu*yv)}, yw]^2)/32 - 
     (11*G[{1/(yu*yv)}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw]^2)/128 + 
     (29*Pi^2*G[{0}, yu^(-1)]*G[{yv^(-1), 1/(yu*yv)}, yw])/768 + 
     (29*Pi^2*G[{0}, yv^(-1)]*G[{yv^(-1), 1/(yu*yv)}, yw])/768 - 
     (29*Pi^2*G[{0}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw])/768 - 
     (53*Pi^2*G[{1}, yu^(-1)]*G[{yv^(-1), 1/(yu*yv)}, yw])/768 - 
     (3*G[{0}, yu^(-1)]^2*G[{1}, yu^(-1)]*G[{yv^(-1), 1/(yu*yv)}, yw])/32 - 
     (3*G[{0}, yu^(-1)]*G[{0}, yv^(-1)]*G[{1}, yu^(-1)]*
       G[{yv^(-1), 1/(yu*yv)}, yw])/16 - (3*G[{0}, yv^(-1)]^2*G[{1}, yu^(-1)]*
       G[{yv^(-1), 1/(yu*yv)}, yw])/32 + (3*G[{0}, yu^(-1)]*G[{0}, yw]*
       G[{1}, yu^(-1)]*G[{yv^(-1), 1/(yu*yv)}, yw])/16 + 
     (3*G[{0}, yv^(-1)]*G[{0}, yw]*G[{1}, yu^(-1)]*G[{yv^(-1), 1/(yu*yv)}, 
        yw])/16 - (3*G[{0}, yw]^2*G[{1}, yu^(-1)]*G[{yv^(-1), 1/(yu*yv)}, 
        yw])/32 + (5*G[{0}, yu^(-1)]*G[{1}, yu^(-1)]^2*
       G[{yv^(-1), 1/(yu*yv)}, yw])/32 + (5*G[{0}, yv^(-1)]*G[{1}, yu^(-1)]^2*
       G[{yv^(-1), 1/(yu*yv)}, yw])/32 - (5*G[{0}, yw]*G[{1}, yu^(-1)]^2*
       G[{yv^(-1), 1/(yu*yv)}, yw])/32 - 
     (G[{1}, yu^(-1)]^3*G[{yv^(-1), 1/(yu*yv)}, yw])/16 - 
     (5*Pi^2*G[{1}, yv^(-1)]*G[{yv^(-1), 1/(yu*yv)}, yw])/768 + 
     (3*G[{0}, yu^(-1)]^2*G[{1}, yv^(-1)]*G[{yv^(-1), 1/(yu*yv)}, yw])/32 + 
     (3*G[{0}, yu^(-1)]*G[{0}, yv^(-1)]*G[{1}, yv^(-1)]*
       G[{yv^(-1), 1/(yu*yv)}, yw])/16 + (3*G[{0}, yv^(-1)]^2*G[{1}, yv^(-1)]*
       G[{yv^(-1), 1/(yu*yv)}, yw])/32 - (3*G[{0}, yu^(-1)]*G[{0}, yw]*
       G[{1}, yv^(-1)]*G[{yv^(-1), 1/(yu*yv)}, yw])/16 - 
     (3*G[{0}, yv^(-1)]*G[{0}, yw]*G[{1}, yv^(-1)]*G[{yv^(-1), 1/(yu*yv)}, 
        yw])/16 + (3*G[{0}, yw]^2*G[{1}, yv^(-1)]*G[{yv^(-1), 1/(yu*yv)}, 
        yw])/32 + (G[{0}, yu^(-1)]*G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*
       G[{yv^(-1), 1/(yu*yv)}, yw])/16 + (G[{0}, yv^(-1)]*G[{1}, yu^(-1)]*
       G[{1}, yv^(-1)]*G[{yv^(-1), 1/(yu*yv)}, yw])/16 - 
     (G[{0}, yw]*G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*G[{yv^(-1), 1/(yu*yv)}, yw])/
      16 - (G[{1}, yu^(-1)]^2*G[{1}, yv^(-1)]*G[{yv^(-1), 1/(yu*yv)}, yw])/
      8 - (9*G[{0}, yu^(-1)]*G[{1}, yv^(-1)]^2*G[{yv^(-1), 1/(yu*yv)}, yw])/
      64 - (9*G[{0}, yv^(-1)]*G[{1}, yv^(-1)]^2*G[{yv^(-1), 1/(yu*yv)}, yw])/
      64 + (9*G[{0}, yw]*G[{1}, yv^(-1)]^2*G[{yv^(-1), 1/(yu*yv)}, yw])/64 + 
     (5*G[{1}, yu^(-1)]*G[{1}, yv^(-1)]^2*G[{yv^(-1), 1/(yu*yv)}, yw])/64 + 
     (3*G[{1}, yv^(-1)]^3*G[{yv^(-1), 1/(yu*yv)}, yw])/64 - 
     (Pi^2*G[{1}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw])/192 - 
     (3*G[{0}, yu^(-1)]^2*G[{1}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw])/64 - 
     (3*G[{0}, yu^(-1)]*G[{0}, yv^(-1)]*G[{1}, yw]*G[{yv^(-1), 1/(yu*yv)}, 
        yw])/32 - (3*G[{0}, yv^(-1)]^2*G[{1}, yw]*G[{yv^(-1), 1/(yu*yv)}, 
        yw])/64 + (3*G[{0}, yu^(-1)]*G[{0}, yw]*G[{1}, yw]*
       G[{yv^(-1), 1/(yu*yv)}, yw])/32 + (3*G[{0}, yv^(-1)]*G[{0}, yw]*
       G[{1}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw])/32 - 
     (3*G[{0}, yw]^2*G[{1}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw])/64 - 
     (G[{0}, yu^(-1)]*G[{1}, yu^(-1)]*G[{1}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw])/
      32 - (G[{0}, yv^(-1)]*G[{1}, yu^(-1)]*G[{1}, yw]*
       G[{yv^(-1), 1/(yu*yv)}, yw])/32 + 
     (G[{0}, yw]*G[{1}, yu^(-1)]*G[{1}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw])/32 + 
     (3*G[{1}, yu^(-1)]^2*G[{1}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw])/64 + 
     (3*G[{1}, yv^(-1)]^2*G[{1}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw])/64 - 
     (G[{0}, yu^(-1)]*G[{1}, yw]^2*G[{yv^(-1), 1/(yu*yv)}, yw])/8 - 
     (G[{0}, yv^(-1)]*G[{1}, yw]^2*G[{yv^(-1), 1/(yu*yv)}, yw])/8 + 
     (G[{0}, yw]*G[{1}, yw]^2*G[{yv^(-1), 1/(yu*yv)}, yw])/8 + 
     (G[{1}, yu^(-1)]*G[{1}, yw]^2*G[{yv^(-1), 1/(yu*yv)}, yw])/16 + 
     (3*G[{1}, yv^(-1)]*G[{1}, yw]^2*G[{yv^(-1), 1/(yu*yv)}, yw])/32 - 
     (G[{1}, yw]^3*G[{yv^(-1), 1/(yu*yv)}, yw])/32 + 
     (3*Pi^2*G[{yu^(-1)}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw])/256 - 
     (3*G[{0}, yu^(-1)]^2*G[{yu^(-1)}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw])/64 - 
     (3*G[{0}, yu^(-1)]*G[{0}, yv^(-1)]*G[{yu^(-1)}, yw]*
       G[{yv^(-1), 1/(yu*yv)}, yw])/32 - 
     (3*G[{0}, yv^(-1)]^2*G[{yu^(-1)}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw])/64 + 
     (3*G[{0}, yu^(-1)]*G[{0}, yw]*G[{yu^(-1)}, yw]*G[{yv^(-1), 1/(yu*yv)}, 
        yw])/32 + (3*G[{0}, yv^(-1)]*G[{0}, yw]*G[{yu^(-1)}, yw]*
       G[{yv^(-1), 1/(yu*yv)}, yw])/32 - (3*G[{0}, yw]^2*G[{yu^(-1)}, yw]*
       G[{yv^(-1), 1/(yu*yv)}, yw])/64 - (G[{0}, yu^(-1)]*G[{1}, yu^(-1)]*
       G[{yu^(-1)}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw])/32 - 
     (G[{0}, yv^(-1)]*G[{1}, yu^(-1)]*G[{yu^(-1)}, yw]*
       G[{yv^(-1), 1/(yu*yv)}, yw])/32 + 
     (G[{0}, yw]*G[{1}, yu^(-1)]*G[{yu^(-1)}, yw]*G[{yv^(-1), 1/(yu*yv)}, 
        yw])/32 + (5*G[{1}, yu^(-1)]^2*G[{yu^(-1)}, yw]*
       G[{yv^(-1), 1/(yu*yv)}, yw])/64 + (7*G[{0}, yu^(-1)]*G[{1}, yv^(-1)]*
       G[{yu^(-1)}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw])/32 + 
     (7*G[{0}, yv^(-1)]*G[{1}, yv^(-1)]*G[{yu^(-1)}, yw]*
       G[{yv^(-1), 1/(yu*yv)}, yw])/32 - (7*G[{0}, yw]*G[{1}, yv^(-1)]*
       G[{yu^(-1)}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw])/32 - 
     (3*G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*G[{yu^(-1)}, yw]*
       G[{yv^(-1), 1/(yu*yv)}, yw])/32 - (G[{1}, yv^(-1)]^2*G[{yu^(-1)}, yw]*
       G[{yv^(-1), 1/(yu*yv)}, yw])/8 - (G[{1}, yu^(-1)]*G[{1}, yw]*
       G[{yu^(-1)}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw])/8 - 
     (G[{1}, yv^(-1)]*G[{1}, yw]*G[{yu^(-1)}, yw]*G[{yv^(-1), 1/(yu*yv)}, 
        yw])/32 - (5*G[{1}, yw]^2*G[{yu^(-1)}, yw]*G[{yv^(-1), 1/(yu*yv)}, 
        yw])/64 - (7*G[{0}, yu^(-1)]*G[{yu^(-1)}, yw]^2*
       G[{yv^(-1), 1/(yu*yv)}, yw])/64 - 
     (7*G[{0}, yv^(-1)]*G[{yu^(-1)}, yw]^2*G[{yv^(-1), 1/(yu*yv)}, yw])/64 + 
     (7*G[{0}, yw]*G[{yu^(-1)}, yw]^2*G[{yv^(-1), 1/(yu*yv)}, yw])/64 + 
     (7*G[{1}, yu^(-1)]*G[{yu^(-1)}, yw]^2*G[{yv^(-1), 1/(yu*yv)}, yw])/64 + 
     (7*G[{1}, yv^(-1)]*G[{yu^(-1)}, yw]^2*G[{yv^(-1), 1/(yu*yv)}, yw])/64 - 
     (7*G[{yu^(-1)}, yw]^3*G[{yv^(-1), 1/(yu*yv)}, yw])/192 + 
     (7*G[{0}, yu^(-1)]*G[{1}, yw]*G[{yu}, yv^(-1)]*G[{yv^(-1), 1/(yu*yv)}, 
        yw])/32 + (7*G[{0}, yv^(-1)]*G[{1}, yw]*G[{yu}, yv^(-1)]*
       G[{yv^(-1), 1/(yu*yv)}, yw])/32 - 
     (7*G[{0}, yw]*G[{1}, yw]*G[{yu}, yv^(-1)]*G[{yv^(-1), 1/(yu*yv)}, yw])/
      32 - (G[{1}, yu^(-1)]*G[{1}, yw]*G[{yu}, yv^(-1)]*
       G[{yv^(-1), 1/(yu*yv)}, yw])/32 - (7*G[{1}, yv^(-1)]*G[{1}, yw]*
       G[{yu}, yv^(-1)]*G[{yv^(-1), 1/(yu*yv)}, yw])/32 + 
     (3*G[{1}, yw]^2*G[{yu}, yv^(-1)]*G[{yv^(-1), 1/(yu*yv)}, yw])/32 + 
     (5*G[{1}, yw]*G[{yu^(-1)}, yw]*G[{yu}, yv^(-1)]*G[{yv^(-1), 1/(yu*yv)}, 
        yw])/32 - (3*G[{1}, yw]*G[{yu}, yv^(-1)]^2*G[{yv^(-1), 1/(yu*yv)}, 
        yw])/32 + (19*Pi^2*G[{yv^(-1)}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw])/
      256 + (9*G[{0}, yu^(-1)]^2*G[{yv^(-1)}, yw]*G[{yv^(-1), 1/(yu*yv)}, 
        yw])/64 + (9*G[{0}, yu^(-1)]*G[{0}, yv^(-1)]*G[{yv^(-1)}, yw]*
       G[{yv^(-1), 1/(yu*yv)}, yw])/32 + 
     (9*G[{0}, yv^(-1)]^2*G[{yv^(-1)}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw])/64 - 
     (9*G[{0}, yu^(-1)]*G[{0}, yw]*G[{yv^(-1)}, yw]*G[{yv^(-1), 1/(yu*yv)}, 
        yw])/32 - (9*G[{0}, yv^(-1)]*G[{0}, yw]*G[{yv^(-1)}, yw]*
       G[{yv^(-1), 1/(yu*yv)}, yw])/32 + (9*G[{0}, yw]^2*G[{yv^(-1)}, yw]*
       G[{yv^(-1), 1/(yu*yv)}, yw])/64 - (21*G[{0}, yu^(-1)]*G[{1}, yu^(-1)]*
       G[{yv^(-1)}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw])/32 - 
     (21*G[{0}, yv^(-1)]*G[{1}, yu^(-1)]*G[{yv^(-1)}, yw]*
       G[{yv^(-1), 1/(yu*yv)}, yw])/32 + (21*G[{0}, yw]*G[{1}, yu^(-1)]*
       G[{yv^(-1)}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw])/32 + 
     (29*G[{1}, yu^(-1)]^2*G[{yv^(-1)}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw])/64 + 
     (3*G[{0}, yu^(-1)]*G[{1}, yv^(-1)]*G[{yv^(-1)}, yw]*
       G[{yv^(-1), 1/(yu*yv)}, yw])/32 + (3*G[{0}, yv^(-1)]*G[{1}, yv^(-1)]*
       G[{yv^(-1)}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw])/32 - 
     (3*G[{0}, yw]*G[{1}, yv^(-1)]*G[{yv^(-1)}, yw]*G[{yv^(-1), 1/(yu*yv)}, 
        yw])/32 + (13*G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*G[{yv^(-1)}, yw]*
       G[{yv^(-1), 1/(yu*yv)}, yw])/32 - 
     (3*G[{1}, yv^(-1)]^2*G[{yv^(-1)}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw])/16 - 
     (G[{0}, yu^(-1)]*G[{1}, yw]*G[{yv^(-1)}, yw]*G[{yv^(-1), 1/(yu*yv)}, 
        yw])/8 - (G[{0}, yv^(-1)]*G[{1}, yw]*G[{yv^(-1)}, yw]*
       G[{yv^(-1), 1/(yu*yv)}, yw])/8 + 
     (G[{0}, yw]*G[{1}, yw]*G[{yv^(-1)}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw])/8 - 
     (G[{1}, yu^(-1)]*G[{1}, yw]*G[{yv^(-1)}, yw]*G[{yv^(-1), 1/(yu*yv)}, 
        yw])/8 + (3*G[{1}, yv^(-1)]*G[{1}, yw]*G[{yv^(-1)}, yw]*
       G[{yv^(-1), 1/(yu*yv)}, yw])/32 - (9*G[{1}, yw]^2*G[{yv^(-1)}, yw]*
       G[{yv^(-1), 1/(yu*yv)}, yw])/64 + (G[{0}, yu^(-1)]*G[{yu^(-1)}, yw]*
       G[{yv^(-1)}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw])/32 + 
     (G[{0}, yv^(-1)]*G[{yu^(-1)}, yw]*G[{yv^(-1)}, yw]*
       G[{yv^(-1), 1/(yu*yv)}, yw])/32 - 
     (G[{0}, yw]*G[{yu^(-1)}, yw]*G[{yv^(-1)}, yw]*G[{yv^(-1), 1/(yu*yv)}, 
        yw])/32 - (9*G[{1}, yu^(-1)]*G[{yu^(-1)}, yw]*G[{yv^(-1)}, yw]*
       G[{yv^(-1), 1/(yu*yv)}, yw])/32 + (7*G[{1}, yv^(-1)]*G[{yu^(-1)}, yw]*
       G[{yv^(-1)}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw])/32 - 
     (7*G[{yu^(-1)}, yw]^2*G[{yv^(-1)}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw])/64 + 
     (9*G[{1}, yw]*G[{yu}, yv^(-1)]*G[{yv^(-1)}, yw]*G[{yv^(-1), 1/(yu*yv)}, 
        yw])/32 + (25*G[{0}, yu^(-1)]*G[{yv^(-1)}, yw]^2*
       G[{yv^(-1), 1/(yu*yv)}, yw])/64 + 
     (25*G[{0}, yv^(-1)]*G[{yv^(-1)}, yw]^2*G[{yv^(-1), 1/(yu*yv)}, yw])/64 - 
     (25*G[{0}, yw]*G[{yv^(-1)}, yw]^2*G[{yv^(-1), 1/(yu*yv)}, yw])/64 - 
     (41*G[{1}, yu^(-1)]*G[{yv^(-1)}, yw]^2*G[{yv^(-1), 1/(yu*yv)}, yw])/64 - 
     (9*G[{1}, yv^(-1)]*G[{yv^(-1)}, yw]^2*G[{yv^(-1), 1/(yu*yv)}, yw])/64 + 
     (9*G[{yu^(-1)}, yw]*G[{yv^(-1)}, yw]^2*G[{yv^(-1), 1/(yu*yv)}, yw])/64 + 
     (41*G[{yv^(-1)}, yw]^3*G[{yv^(-1), 1/(yu*yv)}, yw])/192 - 
     (3*Pi^2*G[{1/(yu*yv)}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw])/256 - 
     (3*G[{0}, yu^(-1)]^2*G[{1/(yu*yv)}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw])/
      64 - (3*G[{0}, yu^(-1)]*G[{0}, yv^(-1)]*G[{1/(yu*yv)}, yw]*
       G[{yv^(-1), 1/(yu*yv)}, yw])/32 - 
     (3*G[{0}, yv^(-1)]^2*G[{1/(yu*yv)}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw])/
      64 + (3*G[{0}, yu^(-1)]*G[{0}, yw]*G[{1/(yu*yv)}, yw]*
       G[{yv^(-1), 1/(yu*yv)}, yw])/32 + (3*G[{0}, yv^(-1)]*G[{0}, yw]*
       G[{1/(yu*yv)}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw])/32 - 
     (3*G[{0}, yw]^2*G[{1/(yu*yv)}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw])/64 - 
     (3*G[{0}, yu^(-1)]*G[{1}, yu^(-1)]*G[{1/(yu*yv)}, yw]*
       G[{yv^(-1), 1/(yu*yv)}, yw])/32 - (3*G[{0}, yv^(-1)]*G[{1}, yu^(-1)]*
       G[{1/(yu*yv)}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw])/32 + 
     (3*G[{0}, yw]*G[{1}, yu^(-1)]*G[{1/(yu*yv)}, yw]*G[{yv^(-1), 1/(yu*yv)}, 
        yw])/32 + (9*G[{1}, yu^(-1)]^2*G[{1/(yu*yv)}, yw]*
       G[{yv^(-1), 1/(yu*yv)}, yw])/64 + (G[{0}, yu^(-1)]*G[{1}, yv^(-1)]*
       G[{1/(yu*yv)}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw])/8 + 
     (G[{0}, yv^(-1)]*G[{1}, yv^(-1)]*G[{1/(yu*yv)}, yw]*
       G[{yv^(-1), 1/(yu*yv)}, yw])/8 - (G[{0}, yw]*G[{1}, yv^(-1)]*
       G[{1/(yu*yv)}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw])/8 - 
     (G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*G[{1/(yu*yv)}, yw]*
       G[{yv^(-1), 1/(yu*yv)}, yw])/8 - 
     (7*G[{1}, yv^(-1)]^2*G[{1/(yu*yv)}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw])/
      128 - (9*G[{0}, yu^(-1)]*G[{1}, yw]*G[{1/(yu*yv)}, yw]*
       G[{yv^(-1), 1/(yu*yv)}, yw])/64 - (9*G[{0}, yv^(-1)]*G[{1}, yw]*
       G[{1/(yu*yv)}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw])/64 + 
     (9*G[{0}, yw]*G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw])/
      64 + (G[{1}, yu^(-1)]*G[{1}, yw]*G[{1/(yu*yv)}, yw]*
       G[{yv^(-1), 1/(yu*yv)}, yw])/64 + 
     (G[{1}, yv^(-1)]*G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{yv^(-1), 1/(yu*yv)}, 
        yw])/16 - (13*G[{1}, yw]^2*G[{1/(yu*yv)}, yw]*G[{yv^(-1), 1/(yu*yv)}, 
        yw])/128 - (9*G[{0}, yu^(-1)]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*
       G[{yv^(-1), 1/(yu*yv)}, yw])/64 - (9*G[{0}, yv^(-1)]*G[{yu^(-1)}, yw]*
       G[{1/(yu*yv)}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw])/64 + 
     (9*G[{0}, yw]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*
       G[{yv^(-1), 1/(yu*yv)}, yw])/64 + (5*G[{1}, yu^(-1)]*G[{yu^(-1)}, yw]*
       G[{1/(yu*yv)}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw])/64 + 
     (11*G[{1}, yv^(-1)]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*
       G[{yv^(-1), 1/(yu*yv)}, yw])/64 - 
     (G[{1}, yw]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{yv^(-1), 1/(yu*yv)}, 
        yw])/32 - (11*G[{yu^(-1)}, yw]^2*G[{1/(yu*yv)}, yw]*
       G[{yv^(-1), 1/(yu*yv)}, yw])/128 + 
     (5*G[{0}, yu^(-1)]*G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw]*
       G[{yv^(-1), 1/(yu*yv)}, yw])/32 + (5*G[{0}, yv^(-1)]*G[{yu}, yv^(-1)]*
       G[{1/(yu*yv)}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw])/32 - 
     (5*G[{0}, yw]*G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw]*
       G[{yv^(-1), 1/(yu*yv)}, yw])/32 + (G[{1}, yu^(-1)]*G[{yu}, yv^(-1)]*
       G[{1/(yu*yv)}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw])/32 - 
     (G[{1}, yv^(-1)]*G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw]*
       G[{yv^(-1), 1/(yu*yv)}, yw])/32 + (13*G[{1}, yw]*G[{yu}, yv^(-1)]*
       G[{1/(yu*yv)}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw])/64 + 
     (G[{yu^(-1)}, yw]*G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw]*
       G[{yv^(-1), 1/(yu*yv)}, yw])/32 - 
     (5*G[{yu}, yv^(-1)]^2*G[{1/(yu*yv)}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw])/
      32 + (5*G[{0}, yu^(-1)]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*
       G[{yv^(-1), 1/(yu*yv)}, yw])/64 + (5*G[{0}, yv^(-1)]*G[{yv^(-1)}, yw]*
       G[{1/(yu*yv)}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw])/64 - 
     (5*G[{0}, yw]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*
       G[{yv^(-1), 1/(yu*yv)}, yw])/64 - (13*G[{1}, yu^(-1)]*G[{yv^(-1)}, yw]*
       G[{1/(yu*yv)}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw])/64 + 
     (5*G[{1}, yv^(-1)]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*
       G[{yv^(-1), 1/(yu*yv)}, yw])/64 + 
     (G[{1}, yw]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{yv^(-1), 1/(yu*yv)}, 
        yw])/32 - (5*G[{yu^(-1)}, yw]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*
       G[{yv^(-1), 1/(yu*yv)}, yw])/64 - (G[{yu}, yv^(-1)]*G[{yv^(-1)}, yw]*
       G[{1/(yu*yv)}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw])/32 + 
     (13*G[{yv^(-1)}, yw]^2*G[{1/(yu*yv)}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw])/
      128 - (3*G[{0}, yu^(-1)]*G[{1/(yu*yv)}, yw]^2*G[{yv^(-1), 1/(yu*yv)}, 
        yw])/128 - (3*G[{0}, yv^(-1)]*G[{1/(yu*yv)}, yw]^2*
       G[{yv^(-1), 1/(yu*yv)}, yw])/128 + 
     (3*G[{0}, yw]*G[{1/(yu*yv)}, yw]^2*G[{yv^(-1), 1/(yu*yv)}, yw])/128 + 
     (7*G[{1}, yu^(-1)]*G[{1/(yu*yv)}, yw]^2*G[{yv^(-1), 1/(yu*yv)}, yw])/
      128 - (3*G[{1}, yv^(-1)]*G[{1/(yu*yv)}, yw]^2*G[{yv^(-1), 1/(yu*yv)}, 
        yw])/128 - (G[{1}, yw]*G[{1/(yu*yv)}, yw]^2*G[{yv^(-1), 1/(yu*yv)}, 
        yw])/64 + (3*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2*
       G[{yv^(-1), 1/(yu*yv)}, yw])/128 + 
     (G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw]^2*G[{yv^(-1), 1/(yu*yv)}, yw])/64 - 
     (7*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2*G[{yv^(-1), 1/(yu*yv)}, yw])/
      128 + (3*G[{0}, yu^(-1)]*G[{0, 1}, yu^(-1)]*G[{yv^(-1), 1/(yu*yv)}, 
        yw])/16 + (3*G[{0}, yv^(-1)]*G[{0, 1}, yu^(-1)]*
       G[{yv^(-1), 1/(yu*yv)}, yw])/16 - (3*G[{0}, yw]*G[{0, 1}, yu^(-1)]*
       G[{yv^(-1), 1/(yu*yv)}, yw])/16 - 
     (5*G[{1}, yu^(-1)]*G[{0, 1}, yu^(-1)]*G[{yv^(-1), 1/(yu*yv)}, yw])/16 - 
     (G[{1}, yv^(-1)]*G[{0, 1}, yu^(-1)]*G[{yv^(-1), 1/(yu*yv)}, yw])/16 - 
     (G[{1}, yw]*G[{0, 1}, yu^(-1)]*G[{yv^(-1), 1/(yu*yv)}, yw])/16 + 
     (G[{yu^(-1)}, yw]*G[{0, 1}, yu^(-1)]*G[{yv^(-1), 1/(yu*yv)}, yw])/8 + 
     (G[{yv^(-1)}, yw]*G[{0, 1}, yu^(-1)]*G[{yv^(-1), 1/(yu*yv)}, yw])/4 - 
     (G[{1/(yu*yv)}, yw]*G[{0, 1}, yu^(-1)]*G[{yv^(-1), 1/(yu*yv)}, yw])/16 + 
     (G[{0}, yu^(-1)]*G[{0, 1}, yv^(-1)]*G[{yv^(-1), 1/(yu*yv)}, yw])/32 + 
     (G[{0}, yv^(-1)]*G[{0, 1}, yv^(-1)]*G[{yv^(-1), 1/(yu*yv)}, yw])/32 - 
     (G[{0}, yw]*G[{0, 1}, yv^(-1)]*G[{yv^(-1), 1/(yu*yv)}, yw])/32 - 
     (G[{1}, yu^(-1)]*G[{0, 1}, yv^(-1)]*G[{yv^(-1), 1/(yu*yv)}, yw])/32 + 
     (G[{1}, yv^(-1)]*G[{0, 1}, yv^(-1)]*G[{yv^(-1), 1/(yu*yv)}, yw])/32 + 
     (G[{1}, yw]*G[{0, 1}, yv^(-1)]*G[{yv^(-1), 1/(yu*yv)}, yw])/16 + 
     (G[{yu^(-1)}, yw]*G[{0, 1}, yv^(-1)]*G[{yv^(-1), 1/(yu*yv)}, yw])/32 + 
     (G[{yv^(-1)}, yw]*G[{0, 1}, yv^(-1)]*G[{yv^(-1), 1/(yu*yv)}, yw])/32 - 
     (3*G[{1/(yu*yv)}, yw]*G[{0, 1}, yv^(-1)]*G[{yv^(-1), 1/(yu*yv)}, yw])/
      64 + (G[{1}, yu^(-1)]*G[{0, 1}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw])/16 - 
     (G[{1}, yv^(-1)]*G[{0, 1}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw])/16 - 
     (G[{1}, yw]*G[{0, 1}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw])/32 - 
     (G[{yv^(-1)}, yw]*G[{0, 1}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw])/8 + 
     (G[{1/(yu*yv)}, yw]*G[{0, 1}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw])/64 - 
     (G[{1}, yu^(-1)]*G[{0, yu^(-1)}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw])/16 + 
     (G[{1}, yv^(-1)]*G[{0, yu^(-1)}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw])/16 + 
     (G[{1}, yw]*G[{0, yu^(-1)}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw])/32 + 
     (G[{yv^(-1)}, yw]*G[{0, yu^(-1)}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw])/8 - 
     (G[{1/(yu*yv)}, yw]*G[{0, yu^(-1)}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw])/
      64 - (G[{0}, yu^(-1)]*G[{0, yu}, yv^(-1)]*G[{yv^(-1), 1/(yu*yv)}, yw])/
      32 - (G[{0}, yv^(-1)]*G[{0, yu}, yv^(-1)]*G[{yv^(-1), 1/(yu*yv)}, yw])/
      32 + (G[{0}, yw]*G[{0, yu}, yv^(-1)]*G[{yv^(-1), 1/(yu*yv)}, yw])/32 + 
     (G[{1}, yu^(-1)]*G[{0, yu}, yv^(-1)]*G[{yv^(-1), 1/(yu*yv)}, yw])/32 - 
     (G[{1}, yv^(-1)]*G[{0, yu}, yv^(-1)]*G[{yv^(-1), 1/(yu*yv)}, yw])/32 - 
     (G[{1}, yw]*G[{0, yu}, yv^(-1)]*G[{yv^(-1), 1/(yu*yv)}, yw])/16 - 
     (G[{yu^(-1)}, yw]*G[{0, yu}, yv^(-1)]*G[{yv^(-1), 1/(yu*yv)}, yw])/32 - 
     (G[{yv^(-1)}, yw]*G[{0, yu}, yv^(-1)]*G[{yv^(-1), 1/(yu*yv)}, yw])/32 + 
     (3*G[{1/(yu*yv)}, yw]*G[{0, yu}, yv^(-1)]*G[{yv^(-1), 1/(yu*yv)}, yw])/
      64 - (G[{1}, yu^(-1)]*G[{0, yv^(-1)}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw])/
      16 + (G[{1}, yv^(-1)]*G[{0, yv^(-1)}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw])/
      16 + (G[{1}, yw]*G[{0, yv^(-1)}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw])/32 + 
     (G[{yv^(-1)}, yw]*G[{0, yv^(-1)}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw])/8 - 
     (G[{1/(yu*yv)}, yw]*G[{0, yv^(-1)}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw])/
      64 + (G[{1}, yu^(-1)]*G[{0, 1/(yu*yv)}, yw]*G[{yv^(-1), 1/(yu*yv)}, 
        yw])/16 - (G[{1}, yv^(-1)]*G[{0, 1/(yu*yv)}, yw]*
       G[{yv^(-1), 1/(yu*yv)}, yw])/16 - (G[{1}, yw]*G[{0, 1/(yu*yv)}, yw]*
       G[{yv^(-1), 1/(yu*yv)}, yw])/32 - 
     (G[{yv^(-1)}, yw]*G[{0, 1/(yu*yv)}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw])/8 + 
     (G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv)}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw])/
      64 + (G[{0}, yu^(-1)]*G[{1, yu^(-1)}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw])/
      32 + (G[{0}, yv^(-1)]*G[{1, yu^(-1)}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw])/
      32 - (G[{0}, yw]*G[{1, yu^(-1)}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw])/32 + 
     (G[{1}, yu^(-1)]*G[{1, yu^(-1)}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw])/32 - 
     (5*G[{1}, yv^(-1)]*G[{1, yu^(-1)}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw])/32 - 
     (G[{1}, yw]*G[{1, yu^(-1)}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw])/16 + 
     (G[{yu^(-1)}, yw]*G[{1, yu^(-1)}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw])/32 + 
     (G[{yu}, yv^(-1)]*G[{1, yu^(-1)}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw])/16 - 
     (3*G[{yv^(-1)}, yw]*G[{1, yu^(-1)}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw])/
      32 - (G[{1/(yu*yv)}, yw]*G[{1, yu^(-1)}, yw]*G[{yv^(-1), 1/(yu*yv)}, 
        yw])/32 - (5*G[{0}, yu^(-1)]*G[{1, yu}, yv^(-1)]*
       G[{yv^(-1), 1/(yu*yv)}, yw])/32 - 
     (5*G[{0}, yv^(-1)]*G[{1, yu}, yv^(-1)]*G[{yv^(-1), 1/(yu*yv)}, yw])/32 + 
     (5*G[{0}, yw]*G[{1, yu}, yv^(-1)]*G[{yv^(-1), 1/(yu*yv)}, yw])/32 - 
     (G[{1}, yu^(-1)]*G[{1, yu}, yv^(-1)]*G[{yv^(-1), 1/(yu*yv)}, yw])/32 + 
     (G[{1}, yv^(-1)]*G[{1, yu}, yv^(-1)]*G[{yv^(-1), 1/(yu*yv)}, yw])/32 + 
     (G[{1}, yw]*G[{1, yu}, yv^(-1)]*G[{yv^(-1), 1/(yu*yv)}, yw])/8 - 
     (3*G[{yu^(-1)}, yw]*G[{1, yu}, yv^(-1)]*G[{yv^(-1), 1/(yu*yv)}, yw])/
      32 - (7*G[{yv^(-1)}, yw]*G[{1, yu}, yv^(-1)]*G[{yv^(-1), 1/(yu*yv)}, 
        yw])/32 + (G[{1/(yu*yv)}, yw]*G[{1, yu}, yv^(-1)]*
       G[{yv^(-1), 1/(yu*yv)}, yw])/64 + 
     (3*G[{0}, yu^(-1)]*G[{1, yv^(-1)}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw])/16 + 
     (3*G[{0}, yv^(-1)]*G[{1, yv^(-1)}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw])/16 - 
     (3*G[{0}, yw]*G[{1, yv^(-1)}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw])/16 + 
     (G[{1}, yu^(-1)]*G[{1, yv^(-1)}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw])/16 - 
     (3*G[{1}, yv^(-1)]*G[{1, yv^(-1)}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw])/16 + 
     (G[{1}, yw]*G[{1, yv^(-1)}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw])/4 + 
     (G[{yu^(-1)}, yw]*G[{1, yv^(-1)}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw])/8 - 
     (G[{yu}, yv^(-1)]*G[{1, yv^(-1)}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw])/4 + 
     (G[{yv^(-1)}, yw]*G[{1, yv^(-1)}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw])/8 - 
     (3*G[{1/(yu*yv)}, yw]*G[{1, yv^(-1)}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw])/
      64 - (7*G[{0}, yu^(-1)]*G[{1, 1/(yu*yv)}, yw]*G[{yv^(-1), 1/(yu*yv)}, 
        yw])/32 - (7*G[{0}, yv^(-1)]*G[{1, 1/(yu*yv)}, yw]*
       G[{yv^(-1), 1/(yu*yv)}, yw])/32 + (7*G[{0}, yw]*G[{1, 1/(yu*yv)}, yw]*
       G[{yv^(-1), 1/(yu*yv)}, yw])/32 + 
     (G[{1}, yu^(-1)]*G[{1, 1/(yu*yv)}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw])/32 + 
     (7*G[{1}, yv^(-1)]*G[{1, 1/(yu*yv)}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw])/
      32 - (3*G[{1}, yw]*G[{1, 1/(yu*yv)}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw])/
      16 - (5*G[{yu^(-1)}, yw]*G[{1, 1/(yu*yv)}, yw]*G[{yv^(-1), 1/(yu*yv)}, 
        yw])/32 + (3*G[{yu}, yv^(-1)]*G[{1, 1/(yu*yv)}, yw]*
       G[{yv^(-1), 1/(yu*yv)}, yw])/16 - 
     (9*G[{yv^(-1)}, yw]*G[{1, 1/(yu*yv)}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw])/
      32 + (7*G[{1/(yu*yv)}, yw]*G[{1, 1/(yu*yv)}, yw]*
       G[{yv^(-1), 1/(yu*yv)}, yw])/64 + 
     (G[{0}, yu^(-1)]*G[{yu^(-1), 1/(yu*yv)}, yw]*G[{yv^(-1), 1/(yu*yv)}, 
        yw])/32 + (G[{0}, yv^(-1)]*G[{yu^(-1), 1/(yu*yv)}, yw]*
       G[{yv^(-1), 1/(yu*yv)}, yw])/32 - 
     (G[{0}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw])/
      32 - (3*G[{1}, yu^(-1)]*G[{yu^(-1), 1/(yu*yv)}, yw]*
       G[{yv^(-1), 1/(yu*yv)}, yw])/32 - 
     (G[{1}, yv^(-1)]*G[{yu^(-1), 1/(yu*yv)}, yw]*G[{yv^(-1), 1/(yu*yv)}, 
        yw])/32 - (G[{1}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw]*
       G[{yv^(-1), 1/(yu*yv)}, yw])/16 + 
     (G[{yu^(-1)}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw]*G[{yv^(-1), 1/(yu*yv)}, 
        yw])/32 + (G[{yu}, yv^(-1)]*G[{yu^(-1), 1/(yu*yv)}, yw]*
       G[{yv^(-1), 1/(yu*yv)}, yw])/16 + 
     (5*G[{yv^(-1)}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw]*G[{yv^(-1), 1/(yu*yv)}, 
        yw])/32 - (G[{1/(yu*yv)}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw]*
       G[{yv^(-1), 1/(yu*yv)}, yw])/16 + 
     (3*G[{0}, yu^(-1)]*G[{yv^(-1), 1/(yu*yv)}, yw]^2)/32 + 
     (3*G[{0}, yv^(-1)]*G[{yv^(-1), 1/(yu*yv)}, yw]^2)/32 - 
     (3*G[{0}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw]^2)/32 - 
     (G[{1}, yu^(-1)]*G[{yv^(-1), 1/(yu*yv)}, yw]^2)/32 - 
     (G[{1}, yv^(-1)]*G[{yv^(-1), 1/(yu*yv)}, yw]^2)/32 + 
     (G[{1}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw]^2)/8 + 
     (G[{yu^(-1)}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw]^2)/32 - 
     (G[{yu}, yv^(-1)]*G[{yv^(-1), 1/(yu*yv)}, yw]^2)/8 + 
     (G[{yv^(-1)}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw]^2)/32 - 
     (5*G[{1/(yu*yv)}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw]^2)/128 + 
     (G[{0}, yu^(-1)]*G[{1}, yu^(-1)]*G[{0, 0, 1}, yu^(-1)])/16 + 
     (G[{0}, yv^(-1)]*G[{1}, yu^(-1)]*G[{0, 0, 1}, yu^(-1)])/16 - 
     (G[{0}, yw]*G[{1}, yu^(-1)]*G[{0, 0, 1}, yu^(-1)])/16 - 
     (G[{1}, yu^(-1)]^2*G[{0, 0, 1}, yu^(-1)])/32 - 
     (G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*G[{0, 0, 1}, yu^(-1)])/16 - 
     (G[{0}, yu^(-1)]*G[{1}, yw]*G[{0, 0, 1}, yu^(-1)])/16 - 
     (G[{0}, yv^(-1)]*G[{1}, yw]*G[{0, 0, 1}, yu^(-1)])/16 + 
     (G[{0}, yw]*G[{1}, yw]*G[{0, 0, 1}, yu^(-1)])/16 + 
     (G[{1}, yu^(-1)]*G[{1}, yw]*G[{0, 0, 1}, yu^(-1)])/16 - 
     (G[{1}, yw]^2*G[{0, 0, 1}, yu^(-1)])/32 + 
     (G[{1}, yw]*G[{yu}, yv^(-1)]*G[{0, 0, 1}, yu^(-1)])/16 + 
     (G[{1}, yu^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, 0, 1}, yu^(-1)])/16 + 
     (G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 0, 1}, yu^(-1)])/16 - 
     (G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, 0, 1}, yu^(-1)])/16 - 
     (G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 0, 1}, yu^(-1)])/16 - 
     (G[{0, 1}, yw]*G[{0, 0, 1}, yu^(-1)])/16 - 
     (G[{0, yu}, yv^(-1)]*G[{0, 0, 1}, yu^(-1)])/16 + 
     (G[{0, yv^(-1)}, yw]*G[{0, 0, 1}, yu^(-1)])/16 + 
     (G[{1, yu}, yv^(-1)]*G[{0, 0, 1}, yu^(-1)])/16 - 
     (G[{1, yv^(-1)}, yw]*G[{0, 0, 1}, yu^(-1)])/16 - 
     (G[{1, 1/(yu*yv)}, yw]*G[{0, 0, 1}, yu^(-1)])/16 + 
     (G[{yv^(-1), 1/(yu*yv)}, yw]*G[{0, 0, 1}, yu^(-1)])/16 - 
     (G[{0}, yu^(-1)]^2*G[{0, 0, 1}, yv^(-1)])/32 - 
     (G[{0}, yu^(-1)]*G[{0}, yv^(-1)]*G[{0, 0, 1}, yv^(-1)])/16 - 
     (G[{0}, yv^(-1)]^2*G[{0, 0, 1}, yv^(-1)])/32 + 
     (G[{0}, yu^(-1)]*G[{0}, yw]*G[{0, 0, 1}, yv^(-1)])/16 + 
     (G[{0}, yv^(-1)]*G[{0}, yw]*G[{0, 0, 1}, yv^(-1)])/16 - 
     (G[{0}, yw]^2*G[{0, 0, 1}, yv^(-1)])/32 - 
     (G[{0}, yu^(-1)]*G[{1}, yu^(-1)]*G[{0, 0, 1}, yv^(-1)])/16 - 
     (G[{0}, yv^(-1)]*G[{1}, yu^(-1)]*G[{0, 0, 1}, yv^(-1)])/16 + 
     (G[{0}, yw]*G[{1}, yu^(-1)]*G[{0, 0, 1}, yv^(-1)])/16 + 
     (3*G[{1}, yu^(-1)]^2*G[{0, 0, 1}, yv^(-1)])/32 + 
     (G[{0}, yu^(-1)]*G[{1}, yv^(-1)]*G[{0, 0, 1}, yv^(-1)])/16 + 
     (G[{0}, yv^(-1)]*G[{1}, yv^(-1)]*G[{0, 0, 1}, yv^(-1)])/16 - 
     (G[{0}, yw]*G[{1}, yv^(-1)]*G[{0, 0, 1}, yv^(-1)])/16 + 
     (G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*G[{0, 0, 1}, yv^(-1)])/16 - 
     (G[{1}, yv^(-1)]^2*G[{0, 0, 1}, yv^(-1)])/16 + 
     (G[{0}, yu^(-1)]*G[{1}, yw]*G[{0, 0, 1}, yv^(-1)])/16 + 
     (G[{0}, yv^(-1)]*G[{1}, yw]*G[{0, 0, 1}, yv^(-1)])/16 - 
     (G[{0}, yw]*G[{1}, yw]*G[{0, 0, 1}, yv^(-1)])/16 - 
     (G[{1}, yu^(-1)]*G[{1}, yw]*G[{0, 0, 1}, yv^(-1)])/16 + 
     (G[{1}, yw]^2*G[{0, 0, 1}, yv^(-1)])/32 - 
     (G[{1}, yw]*G[{yu}, yv^(-1)]*G[{0, 0, 1}, yv^(-1)])/16 - 
     (G[{0}, yu^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, 0, 1}, yv^(-1)])/16 - 
     (G[{0}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, 0, 1}, yv^(-1)])/16 + 
     (G[{0}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 0, 1}, yv^(-1)])/16 - 
     (G[{1}, yu^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, 0, 1}, yv^(-1)])/16 + 
     (G[{1}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, 0, 1}, yv^(-1)])/8 - 
     (G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 0, 1}, yv^(-1)])/16 - 
     (G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 0, 1}, yv^(-1)])/8 + 
     (G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, 0, 1}, yv^(-1)])/16 + 
     (G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 0, 1}, yv^(-1)])/16 + 
     (G[{0, 1}, yv^(-1)]*G[{0, 0, 1}, yv^(-1)])/16 + 
     (G[{0, 1}, yw]*G[{0, 0, 1}, yv^(-1)])/16 + 
     (G[{0, yu^(-1)}, yw]*G[{0, 0, 1}, yv^(-1)])/16 + 
     (G[{0, yu}, yv^(-1)]*G[{0, 0, 1}, yv^(-1)])/16 - 
     (G[{0, yv^(-1)}, yw]*G[{0, 0, 1}, yv^(-1)])/16 - 
     (G[{0, 1/(yu*yv)}, yw]*G[{0, 0, 1}, yv^(-1)])/16 - 
     (G[{1, yu}, yv^(-1)]*G[{0, 0, 1}, yv^(-1)])/16 + 
     (G[{1, yv^(-1)}, yw]*G[{0, 0, 1}, yv^(-1)])/16 + 
     (G[{1, 1/(yu*yv)}, yw]*G[{0, 0, 1}, yv^(-1)])/16 + 
     (G[{yu^(-1), 1/(yu*yv)}, yw]*G[{0, 0, 1}, yv^(-1)])/8 - 
     (G[{yv^(-1), 1/(yu*yv)}, yw]*G[{0, 0, 1}, yv^(-1)])/16 - 
     (11*Pi^2*G[{0, 0, 1}, yw])/384 - (3*G[{0}, yu^(-1)]^2*G[{0, 0, 1}, yw])/
      64 - (3*G[{0}, yu^(-1)]*G[{0}, yv^(-1)]*G[{0, 0, 1}, yw])/32 - 
     (3*G[{0}, yv^(-1)]^2*G[{0, 0, 1}, yw])/64 + 
     (3*G[{0}, yu^(-1)]*G[{0}, yw]*G[{0, 0, 1}, yw])/32 + 
     (3*G[{0}, yv^(-1)]*G[{0}, yw]*G[{0, 0, 1}, yw])/32 - 
     (3*G[{0}, yw]^2*G[{0, 0, 1}, yw])/64 + 
     (3*G[{0}, yu^(-1)]*G[{1}, yu^(-1)]*G[{0, 0, 1}, yw])/32 + 
     (3*G[{0}, yv^(-1)]*G[{1}, yu^(-1)]*G[{0, 0, 1}, yw])/32 - 
     (3*G[{0}, yw]*G[{1}, yu^(-1)]*G[{0, 0, 1}, yw])/32 - 
     (3*G[{1}, yu^(-1)]^2*G[{0, 0, 1}, yw])/64 - 
     (3*G[{0}, yu^(-1)]*G[{1}, yv^(-1)]*G[{0, 0, 1}, yw])/32 - 
     (3*G[{0}, yv^(-1)]*G[{1}, yv^(-1)]*G[{0, 0, 1}, yw])/32 + 
     (3*G[{0}, yw]*G[{1}, yv^(-1)]*G[{0, 0, 1}, yw])/32 - 
     (3*G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*G[{0, 0, 1}, yw])/32 + 
     (15*G[{1}, yv^(-1)]^2*G[{0, 0, 1}, yw])/128 - 
     (9*G[{0}, yu^(-1)]*G[{1}, yw]*G[{0, 0, 1}, yw])/64 - 
     (9*G[{0}, yv^(-1)]*G[{1}, yw]*G[{0, 0, 1}, yw])/64 + 
     (9*G[{0}, yw]*G[{1}, yw]*G[{0, 0, 1}, yw])/64 + 
     (9*G[{1}, yu^(-1)]*G[{1}, yw]*G[{0, 0, 1}, yw])/64 - 
     (3*G[{1}, yv^(-1)]*G[{1}, yw]*G[{0, 0, 1}, yw])/32 - 
     (17*G[{1}, yw]^2*G[{0, 0, 1}, yw])/128 + 
     (3*G[{0}, yu^(-1)]*G[{yu}, yv^(-1)]*G[{0, 0, 1}, yw])/16 + 
     (3*G[{0}, yv^(-1)]*G[{yu}, yv^(-1)]*G[{0, 0, 1}, yw])/16 - 
     (3*G[{0}, yw]*G[{yu}, yv^(-1)]*G[{0, 0, 1}, yw])/16 - 
     (G[{1}, yv^(-1)]*G[{yu}, yv^(-1)]*G[{0, 0, 1}, yw])/4 + 
     (15*G[{1}, yw]*G[{yu}, yv^(-1)]*G[{0, 0, 1}, yw])/64 - 
     (G[{yu}, yv^(-1)]^2*G[{0, 0, 1}, yw])/16 + 
     (3*G[{0}, yu^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, 0, 1}, yw])/64 + 
     (3*G[{0}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, 0, 1}, yw])/64 - 
     (3*G[{0}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 0, 1}, yw])/64 + 
     (G[{1}, yu^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, 0, 1}, yw])/64 - 
     (G[{1}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, 0, 1}, yw])/4 + 
     (5*G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 0, 1}, yw])/64 + 
     (11*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 0, 1}, yw])/64 + 
     (9*G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, 0, 1}, yw])/64 - 
     (3*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 0, 1}, yw])/32 + 
     (3*G[{1/(yu*yv)}, yw]^2*G[{0, 0, 1}, yw])/64 - 
     (3*G[{0, 1}, yu^(-1)]*G[{0, 0, 1}, yw])/16 + 
     (7*G[{0, 1}, yv^(-1)]*G[{0, 0, 1}, yw])/64 + 
     (G[{0, 1}, yw]*G[{0, 0, 1}, yw])/32 - 
     (7*G[{0, yu^(-1)}, yw]*G[{0, 0, 1}, yw])/32 - 
     (7*G[{0, yu}, yv^(-1)]*G[{0, 0, 1}, yw])/64 + 
     (3*G[{0, yv^(-1)}, yw]*G[{0, 0, 1}, yw])/32 + 
     (3*G[{0, 1/(yu*yv)}, yw]*G[{0, 0, 1}, yw])/32 + 
     (G[{1, yu^(-1)}, yw]*G[{0, 0, 1}, yw])/64 + 
     (19*G[{1, yu}, yv^(-1)]*G[{0, 0, 1}, yw])/64 - 
     (3*G[{1, yv^(-1)}, yw]*G[{0, 0, 1}, yw])/32 + 
     (G[{1, 1/(yu*yv)}, yw]*G[{0, 0, 1}, yw])/64 - 
     (11*G[{yu^(-1), 1/(yu*yv)}, yw]*G[{0, 0, 1}, yw])/64 + 
     (3*G[{yv^(-1), 1/(yu*yv)}, yw]*G[{0, 0, 1}, yw])/32 - 
     (Pi^2*G[{0, 0, yu^(-1)}, yw])/384 + 
     (3*G[{0}, yu^(-1)]^2*G[{0, 0, yu^(-1)}, yw])/64 + 
     (3*G[{0}, yu^(-1)]*G[{0}, yv^(-1)]*G[{0, 0, yu^(-1)}, yw])/32 + 
     (3*G[{0}, yv^(-1)]^2*G[{0, 0, yu^(-1)}, yw])/64 - 
     (3*G[{0}, yu^(-1)]*G[{0}, yw]*G[{0, 0, yu^(-1)}, yw])/32 - 
     (3*G[{0}, yv^(-1)]*G[{0}, yw]*G[{0, 0, yu^(-1)}, yw])/32 + 
     (3*G[{0}, yw]^2*G[{0, 0, yu^(-1)}, yw])/64 - 
     (3*G[{0}, yu^(-1)]*G[{1}, yu^(-1)]*G[{0, 0, yu^(-1)}, yw])/32 - 
     (3*G[{0}, yv^(-1)]*G[{1}, yu^(-1)]*G[{0, 0, yu^(-1)}, yw])/32 + 
     (3*G[{0}, yw]*G[{1}, yu^(-1)]*G[{0, 0, yu^(-1)}, yw])/32 + 
     (3*G[{1}, yu^(-1)]^2*G[{0, 0, yu^(-1)}, yw])/64 - 
     (3*G[{0}, yu^(-1)]*G[{1}, yv^(-1)]*G[{0, 0, yu^(-1)}, yw])/32 - 
     (3*G[{0}, yv^(-1)]*G[{1}, yv^(-1)]*G[{0, 0, yu^(-1)}, yw])/32 + 
     (3*G[{0}, yw]*G[{1}, yv^(-1)]*G[{0, 0, yu^(-1)}, yw])/32 + 
     (3*G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*G[{0, 0, yu^(-1)}, yw])/32 + 
     (9*G[{1}, yv^(-1)]^2*G[{0, 0, yu^(-1)}, yw])/128 + 
     (9*G[{0}, yu^(-1)]*G[{1}, yw]*G[{0, 0, yu^(-1)}, yw])/64 + 
     (9*G[{0}, yv^(-1)]*G[{1}, yw]*G[{0, 0, yu^(-1)}, yw])/64 - 
     (9*G[{0}, yw]*G[{1}, yw]*G[{0, 0, yu^(-1)}, yw])/64 - 
     (9*G[{1}, yu^(-1)]*G[{1}, yw]*G[{0, 0, yu^(-1)}, yw])/64 - 
     (5*G[{1}, yv^(-1)]*G[{1}, yw]*G[{0, 0, yu^(-1)}, yw])/32 + 
     (17*G[{1}, yw]^2*G[{0, 0, yu^(-1)}, yw])/128 + 
     (G[{1}, yw]*G[{yu}, yv^(-1)]*G[{0, 0, yu^(-1)}, yw])/64 - 
     (3*G[{0}, yu^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, 0, yu^(-1)}, yw])/64 - 
     (3*G[{0}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, 0, yu^(-1)}, yw])/64 + 
     (3*G[{0}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 0, yu^(-1)}, yw])/64 - 
     (G[{1}, yu^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, 0, yu^(-1)}, yw])/64 + 
     (G[{1}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, 0, yu^(-1)}, yw])/8 - 
     (5*G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 0, yu^(-1)}, yw])/64 - 
     (11*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 0, yu^(-1)}, yw])/64 - 
     (G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, 0, yu^(-1)}, yw])/64 + 
     (3*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 0, yu^(-1)}, yw])/32 - 
     (3*G[{1/(yu*yv)}, yw]^2*G[{0, 0, yu^(-1)}, yw])/64 - 
     (3*G[{0, 1}, yv^(-1)]*G[{0, 0, yu^(-1)}, yw])/64 - 
     (G[{0, 1}, yw]*G[{0, 0, yu^(-1)}, yw])/32 + 
     (7*G[{0, yu^(-1)}, yw]*G[{0, 0, yu^(-1)}, yw])/32 + 
     (3*G[{0, yu}, yv^(-1)]*G[{0, 0, yu^(-1)}, yw])/64 - 
     (3*G[{0, yv^(-1)}, yw]*G[{0, 0, yu^(-1)}, yw])/32 - 
     (3*G[{0, 1/(yu*yv)}, yw]*G[{0, 0, yu^(-1)}, yw])/32 - 
     (G[{1, yu^(-1)}, yw]*G[{0, 0, yu^(-1)}, yw])/64 - 
     (3*G[{1, yu}, yv^(-1)]*G[{0, 0, yu^(-1)}, yw])/64 + 
     (3*G[{1, yv^(-1)}, yw]*G[{0, 0, yu^(-1)}, yw])/32 - 
     (G[{1, 1/(yu*yv)}, yw]*G[{0, 0, yu^(-1)}, yw])/64 + 
     (11*G[{yu^(-1), 1/(yu*yv)}, yw]*G[{0, 0, yu^(-1)}, yw])/64 - 
     (3*G[{yv^(-1), 1/(yu*yv)}, yw]*G[{0, 0, yu^(-1)}, yw])/32 + 
     (Pi^2*G[{0, 0, yu}, yv^(-1)])/48 + 
     (G[{0}, yu^(-1)]^2*G[{0, 0, yu}, yv^(-1)])/32 + 
     (G[{0}, yu^(-1)]*G[{0}, yv^(-1)]*G[{0, 0, yu}, yv^(-1)])/16 + 
     (G[{0}, yv^(-1)]^2*G[{0, 0, yu}, yv^(-1)])/32 - 
     (G[{0}, yu^(-1)]*G[{0}, yw]*G[{0, 0, yu}, yv^(-1)])/16 - 
     (G[{0}, yv^(-1)]*G[{0}, yw]*G[{0, 0, yu}, yv^(-1)])/16 + 
     (G[{0}, yw]^2*G[{0, 0, yu}, yv^(-1)])/32 + 
     (G[{0}, yu^(-1)]*G[{1}, yu^(-1)]*G[{0, 0, yu}, yv^(-1)])/16 + 
     (G[{0}, yv^(-1)]*G[{1}, yu^(-1)]*G[{0, 0, yu}, yv^(-1)])/16 - 
     (G[{0}, yw]*G[{1}, yu^(-1)]*G[{0, 0, yu}, yv^(-1)])/16 - 
     (3*G[{1}, yu^(-1)]^2*G[{0, 0, yu}, yv^(-1)])/32 - 
     (G[{0}, yu^(-1)]*G[{1}, yv^(-1)]*G[{0, 0, yu}, yv^(-1)])/16 - 
     (G[{0}, yv^(-1)]*G[{1}, yv^(-1)]*G[{0, 0, yu}, yv^(-1)])/16 + 
     (G[{0}, yw]*G[{1}, yv^(-1)]*G[{0, 0, yu}, yv^(-1)])/16 - 
     (G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*G[{0, 0, yu}, yv^(-1)])/16 + 
     (G[{1}, yv^(-1)]^2*G[{0, 0, yu}, yv^(-1)])/16 - 
     (G[{0}, yu^(-1)]*G[{1}, yw]*G[{0, 0, yu}, yv^(-1)])/16 - 
     (G[{0}, yv^(-1)]*G[{1}, yw]*G[{0, 0, yu}, yv^(-1)])/16 + 
     (G[{0}, yw]*G[{1}, yw]*G[{0, 0, yu}, yv^(-1)])/16 + 
     (G[{1}, yu^(-1)]*G[{1}, yw]*G[{0, 0, yu}, yv^(-1)])/16 - 
     (G[{1}, yw]^2*G[{0, 0, yu}, yv^(-1)])/32 + 
     (G[{1}, yw]*G[{yu}, yv^(-1)]*G[{0, 0, yu}, yv^(-1)])/16 + 
     (G[{0}, yu^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, 0, yu}, yv^(-1)])/16 + 
     (G[{0}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, 0, yu}, yv^(-1)])/16 - 
     (G[{0}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 0, yu}, yv^(-1)])/16 + 
     (G[{1}, yu^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, 0, yu}, yv^(-1)])/16 - 
     (G[{1}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, 0, yu}, yv^(-1)])/8 + 
     (G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 0, yu}, yv^(-1)])/16 + 
     (G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 0, yu}, yv^(-1)])/8 - 
     (G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, 0, yu}, yv^(-1)])/16 - 
     (G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 0, yu}, yv^(-1)])/16 + 
     (G[{0, 1}, yu^(-1)]*G[{0, 0, yu}, yv^(-1)])/8 - 
     (G[{0, 1}, yv^(-1)]*G[{0, 0, yu}, yv^(-1)])/16 - 
     (G[{0, 1}, yw]*G[{0, 0, yu}, yv^(-1)])/16 - 
     (G[{0, yu^(-1)}, yw]*G[{0, 0, yu}, yv^(-1)])/16 - 
     (G[{0, yu}, yv^(-1)]*G[{0, 0, yu}, yv^(-1)])/16 + 
     (G[{0, yv^(-1)}, yw]*G[{0, 0, yu}, yv^(-1)])/16 + 
     (G[{0, 1/(yu*yv)}, yw]*G[{0, 0, yu}, yv^(-1)])/16 + 
     (G[{1, yu}, yv^(-1)]*G[{0, 0, yu}, yv^(-1)])/16 - 
     (G[{1, yv^(-1)}, yw]*G[{0, 0, yu}, yv^(-1)])/16 - 
     (G[{1, 1/(yu*yv)}, yw]*G[{0, 0, yu}, yv^(-1)])/16 - 
     (G[{yu^(-1), 1/(yu*yv)}, yw]*G[{0, 0, yu}, yv^(-1)])/8 + 
     (G[{yv^(-1), 1/(yu*yv)}, yw]*G[{0, 0, yu}, yv^(-1)])/16 + 
     (19*Pi^2*G[{0, 0, yv^(-1)}, yw])/384 + 
     (3*G[{0}, yu^(-1)]^2*G[{0, 0, yv^(-1)}, yw])/64 + 
     (3*G[{0}, yu^(-1)]*G[{0}, yv^(-1)]*G[{0, 0, yv^(-1)}, yw])/32 + 
     (3*G[{0}, yv^(-1)]^2*G[{0, 0, yv^(-1)}, yw])/64 - 
     (3*G[{0}, yu^(-1)]*G[{0}, yw]*G[{0, 0, yv^(-1)}, yw])/32 - 
     (3*G[{0}, yv^(-1)]*G[{0}, yw]*G[{0, 0, yv^(-1)}, yw])/32 + 
     (3*G[{0}, yw]^2*G[{0, 0, yv^(-1)}, yw])/64 - 
     (9*G[{0}, yu^(-1)]*G[{1}, yu^(-1)]*G[{0, 0, yv^(-1)}, yw])/32 - 
     (9*G[{0}, yv^(-1)]*G[{1}, yu^(-1)]*G[{0, 0, yv^(-1)}, yw])/32 + 
     (9*G[{0}, yw]*G[{1}, yu^(-1)]*G[{0, 0, yv^(-1)}, yw])/32 + 
     (11*G[{1}, yu^(-1)]^2*G[{0, 0, yv^(-1)}, yw])/64 + 
     (3*G[{0}, yu^(-1)]*G[{1}, yv^(-1)]*G[{0, 0, yv^(-1)}, yw])/32 + 
     (3*G[{0}, yv^(-1)]*G[{1}, yv^(-1)]*G[{0, 0, yv^(-1)}, yw])/32 - 
     (3*G[{0}, yw]*G[{1}, yv^(-1)]*G[{0, 0, yv^(-1)}, yw])/32 + 
     (7*G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*G[{0, 0, yv^(-1)}, yw])/32 - 
     (15*G[{1}, yv^(-1)]^2*G[{0, 0, yv^(-1)}, yw])/128 + 
     (9*G[{0}, yu^(-1)]*G[{1}, yw]*G[{0, 0, yv^(-1)}, yw])/64 + 
     (9*G[{0}, yv^(-1)]*G[{1}, yw]*G[{0, 0, yv^(-1)}, yw])/64 - 
     (9*G[{0}, yw]*G[{1}, yw]*G[{0, 0, yv^(-1)}, yw])/64 - 
     (25*G[{1}, yu^(-1)]*G[{1}, yw]*G[{0, 0, yv^(-1)}, yw])/64 + 
     (3*G[{1}, yv^(-1)]*G[{1}, yw]*G[{0, 0, yv^(-1)}, yw])/32 + 
     (17*G[{1}, yw]^2*G[{0, 0, yv^(-1)}, yw])/128 + 
     (G[{1}, yw]*G[{yu}, yv^(-1)]*G[{0, 0, yv^(-1)}, yw])/64 - 
     (3*G[{0}, yu^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, 0, yv^(-1)}, yw])/64 - 
     (3*G[{0}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, 0, yv^(-1)}, yw])/64 + 
     (3*G[{0}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 0, yv^(-1)}, yw])/64 - 
     (9*G[{1}, yu^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, 0, yv^(-1)}, yw])/64 + 
     (G[{1}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, 0, yv^(-1)}, yw])/4 - 
     (5*G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 0, yv^(-1)}, yw])/64 - 
     (11*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 0, yv^(-1)}, yw])/64 - 
     (G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, 0, yv^(-1)}, yw])/64 + 
     (3*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 0, yv^(-1)}, yw])/32 - 
     (3*G[{1/(yu*yv)}, yw]^2*G[{0, 0, yv^(-1)}, yw])/64 + 
     (3*G[{0, 1}, yu^(-1)]*G[{0, 0, yv^(-1)}, yw])/16 + 
     (G[{0, 1}, yv^(-1)]*G[{0, 0, yv^(-1)}, yw])/64 - 
     (G[{0, 1}, yw]*G[{0, 0, yv^(-1)}, yw])/32 + 
     (7*G[{0, yu^(-1)}, yw]*G[{0, 0, yv^(-1)}, yw])/32 - 
     (G[{0, yu}, yv^(-1)]*G[{0, 0, yv^(-1)}, yw])/64 - 
     (3*G[{0, yv^(-1)}, yw]*G[{0, 0, yv^(-1)}, yw])/32 - 
     (3*G[{0, 1/(yu*yv)}, yw]*G[{0, 0, yv^(-1)}, yw])/32 - 
     (G[{1, yu^(-1)}, yw]*G[{0, 0, yv^(-1)}, yw])/64 - 
     (11*G[{1, yu}, yv^(-1)]*G[{0, 0, yv^(-1)}, yw])/64 + 
     (3*G[{1, yv^(-1)}, yw]*G[{0, 0, yv^(-1)}, yw])/32 - 
     (G[{1, 1/(yu*yv)}, yw]*G[{0, 0, yv^(-1)}, yw])/64 + 
     (11*G[{yu^(-1), 1/(yu*yv)}, yw]*G[{0, 0, yv^(-1)}, yw])/64 - 
     (3*G[{yv^(-1), 1/(yu*yv)}, yw]*G[{0, 0, yv^(-1)}, yw])/32 - 
     (7*Pi^2*G[{0, 0, 1/(yu*yv)}, yw])/384 - 
     (3*G[{0}, yu^(-1)]^2*G[{0, 0, 1/(yu*yv)}, yw])/64 - 
     (3*G[{0}, yu^(-1)]*G[{0}, yv^(-1)]*G[{0, 0, 1/(yu*yv)}, yw])/32 - 
     (3*G[{0}, yv^(-1)]^2*G[{0, 0, 1/(yu*yv)}, yw])/64 + 
     (3*G[{0}, yu^(-1)]*G[{0}, yw]*G[{0, 0, 1/(yu*yv)}, yw])/32 + 
     (3*G[{0}, yv^(-1)]*G[{0}, yw]*G[{0, 0, 1/(yu*yv)}, yw])/32 - 
     (3*G[{0}, yw]^2*G[{0, 0, 1/(yu*yv)}, yw])/64 + 
     (9*G[{0}, yu^(-1)]*G[{1}, yu^(-1)]*G[{0, 0, 1/(yu*yv)}, yw])/32 + 
     (9*G[{0}, yv^(-1)]*G[{1}, yu^(-1)]*G[{0, 0, 1/(yu*yv)}, yw])/32 - 
     (9*G[{0}, yw]*G[{1}, yu^(-1)]*G[{0, 0, 1/(yu*yv)}, yw])/32 - 
     (11*G[{1}, yu^(-1)]^2*G[{0, 0, 1/(yu*yv)}, yw])/64 + 
     (3*G[{0}, yu^(-1)]*G[{1}, yv^(-1)]*G[{0, 0, 1/(yu*yv)}, yw])/32 + 
     (3*G[{0}, yv^(-1)]*G[{1}, yv^(-1)]*G[{0, 0, 1/(yu*yv)}, yw])/32 - 
     (3*G[{0}, yw]*G[{1}, yv^(-1)]*G[{0, 0, 1/(yu*yv)}, yw])/32 - 
     (7*G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*G[{0, 0, 1/(yu*yv)}, yw])/32 - 
     (9*G[{1}, yv^(-1)]^2*G[{0, 0, 1/(yu*yv)}, yw])/128 - 
     (9*G[{0}, yu^(-1)]*G[{1}, yw]*G[{0, 0, 1/(yu*yv)}, yw])/64 - 
     (9*G[{0}, yv^(-1)]*G[{1}, yw]*G[{0, 0, 1/(yu*yv)}, yw])/64 + 
     (9*G[{0}, yw]*G[{1}, yw]*G[{0, 0, 1/(yu*yv)}, yw])/64 + 
     (25*G[{1}, yu^(-1)]*G[{1}, yw]*G[{0, 0, 1/(yu*yv)}, yw])/64 + 
     (5*G[{1}, yv^(-1)]*G[{1}, yw]*G[{0, 0, 1/(yu*yv)}, yw])/32 - 
     (17*G[{1}, yw]^2*G[{0, 0, 1/(yu*yv)}, yw])/128 - 
     (3*G[{0}, yu^(-1)]*G[{yu}, yv^(-1)]*G[{0, 0, 1/(yu*yv)}, yw])/16 - 
     (3*G[{0}, yv^(-1)]*G[{yu}, yv^(-1)]*G[{0, 0, 1/(yu*yv)}, yw])/16 + 
     (3*G[{0}, yw]*G[{yu}, yv^(-1)]*G[{0, 0, 1/(yu*yv)}, yw])/16 + 
     (G[{1}, yv^(-1)]*G[{yu}, yv^(-1)]*G[{0, 0, 1/(yu*yv)}, yw])/4 - 
     (17*G[{1}, yw]*G[{yu}, yv^(-1)]*G[{0, 0, 1/(yu*yv)}, yw])/64 + 
     (G[{yu}, yv^(-1)]^2*G[{0, 0, 1/(yu*yv)}, yw])/16 + 
     (3*G[{0}, yu^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, 0, 1/(yu*yv)}, yw])/64 + 
     (3*G[{0}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, 0, 1/(yu*yv)}, yw])/64 - 
     (3*G[{0}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 0, 1/(yu*yv)}, yw])/64 + 
     (9*G[{1}, yu^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, 0, 1/(yu*yv)}, yw])/64 - 
     (G[{1}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, 0, 1/(yu*yv)}, yw])/8 + 
     (5*G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 0, 1/(yu*yv)}, yw])/64 + 
     (11*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 0, 1/(yu*yv)}, yw])/64 - 
     (7*G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, 0, 1/(yu*yv)}, yw])/64 - 
     (3*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 0, 1/(yu*yv)}, yw])/32 + 
     (3*G[{1/(yu*yv)}, yw]^2*G[{0, 0, 1/(yu*yv)}, yw])/64 - 
     (5*G[{0, 1}, yv^(-1)]*G[{0, 0, 1/(yu*yv)}, yw])/64 + 
     (G[{0, 1}, yw]*G[{0, 0, 1/(yu*yv)}, yw])/32 - 
     (7*G[{0, yu^(-1)}, yw]*G[{0, 0, 1/(yu*yv)}, yw])/32 + 
     (5*G[{0, yu}, yv^(-1)]*G[{0, 0, 1/(yu*yv)}, yw])/64 + 
     (3*G[{0, yv^(-1)}, yw]*G[{0, 0, 1/(yu*yv)}, yw])/32 + 
     (3*G[{0, 1/(yu*yv)}, yw]*G[{0, 0, 1/(yu*yv)}, yw])/32 + 
     (G[{1, yu^(-1)}, yw]*G[{0, 0, 1/(yu*yv)}, yw])/64 - 
     (5*G[{1, yu}, yv^(-1)]*G[{0, 0, 1/(yu*yv)}, yw])/64 - 
     (3*G[{1, yv^(-1)}, yw]*G[{0, 0, 1/(yu*yv)}, yw])/32 + 
     (G[{1, 1/(yu*yv)}, yw]*G[{0, 0, 1/(yu*yv)}, yw])/64 - 
     (11*G[{yu^(-1), 1/(yu*yv)}, yw]*G[{0, 0, 1/(yu*yv)}, yw])/64 + 
     (3*G[{yv^(-1), 1/(yu*yv)}, yw]*G[{0, 0, 1/(yu*yv)}, yw])/32 - 
     (Pi^2*G[{0, 1, 1}, yu^(-1)])/16 - 
     (3*G[{0}, yu^(-1)]^2*G[{0, 1, 1}, yu^(-1)])/16 - 
     (3*G[{0}, yu^(-1)]*G[{0}, yv^(-1)]*G[{0, 1, 1}, yu^(-1)])/8 - 
     (3*G[{0}, yv^(-1)]^2*G[{0, 1, 1}, yu^(-1)])/16 + 
     (3*G[{0}, yu^(-1)]*G[{0}, yw]*G[{0, 1, 1}, yu^(-1)])/8 + 
     (3*G[{0}, yv^(-1)]*G[{0}, yw]*G[{0, 1, 1}, yu^(-1)])/8 - 
     (3*G[{0}, yw]^2*G[{0, 1, 1}, yu^(-1)])/16 + 
     (5*G[{0}, yu^(-1)]*G[{1}, yu^(-1)]*G[{0, 1, 1}, yu^(-1)])/16 + 
     (5*G[{0}, yv^(-1)]*G[{1}, yu^(-1)]*G[{0, 1, 1}, yu^(-1)])/16 - 
     (5*G[{0}, yw]*G[{1}, yu^(-1)]*G[{0, 1, 1}, yu^(-1)])/16 - 
     (G[{1}, yu^(-1)]^2*G[{0, 1, 1}, yu^(-1)])/32 + 
     (3*G[{0}, yu^(-1)]*G[{1}, yv^(-1)]*G[{0, 1, 1}, yu^(-1)])/8 + 
     (3*G[{0}, yv^(-1)]*G[{1}, yv^(-1)]*G[{0, 1, 1}, yu^(-1)])/8 - 
     (3*G[{0}, yw]*G[{1}, yv^(-1)]*G[{0, 1, 1}, yu^(-1)])/8 - 
     (5*G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*G[{0, 1, 1}, yu^(-1)])/16 - 
     (G[{1}, yv^(-1)]^2*G[{0, 1, 1}, yu^(-1)])/8 - 
     (5*G[{0}, yu^(-1)]*G[{1}, yw]*G[{0, 1, 1}, yu^(-1)])/16 - 
     (5*G[{0}, yv^(-1)]*G[{1}, yw]*G[{0, 1, 1}, yu^(-1)])/16 + 
     (5*G[{0}, yw]*G[{1}, yw]*G[{0, 1, 1}, yu^(-1)])/16 + 
     (G[{1}, yu^(-1)]*G[{1}, yw]*G[{0, 1, 1}, yu^(-1)])/16 + 
     (3*G[{1}, yv^(-1)]*G[{1}, yw]*G[{0, 1, 1}, yu^(-1)])/8 - 
     (G[{1}, yw]^2*G[{0, 1, 1}, yu^(-1)])/32 - 
     (G[{1}, yw]*G[{yu}, yv^(-1)]*G[{0, 1, 1}, yu^(-1)])/16 - 
     (3*G[{0}, yu^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, 1, 1}, yu^(-1)])/8 - 
     (3*G[{0}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, 1, 1}, yu^(-1)])/8 + 
     (3*G[{0}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1, 1}, yu^(-1)])/8 + 
     (5*G[{1}, yu^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, 1, 1}, yu^(-1)])/16 + 
     (G[{1}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, 1, 1}, yu^(-1)])/4 - 
     (G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1, 1}, yu^(-1)])/16 - 
     (G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1, 1}, yu^(-1)])/4 + 
     (G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, 1, 1}, yu^(-1)])/16 - 
     (5*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1, 1}, yu^(-1)])/16 - 
     (3*G[{0, 1}, yu^(-1)]*G[{0, 1, 1}, yu^(-1)])/16 - 
     (G[{0, 1}, yv^(-1)]*G[{0, 1, 1}, yu^(-1)])/8 - 
     (3*G[{0, 1}, yw]*G[{0, 1, 1}, yu^(-1)])/16 + 
     (G[{0, yu^(-1)}, yw]*G[{0, 1, 1}, yu^(-1)])/4 + 
     (G[{0, yu}, yv^(-1)]*G[{0, 1, 1}, yu^(-1)])/16 + 
     (5*G[{0, yv^(-1)}, yw]*G[{0, 1, 1}, yu^(-1)])/16 - 
     (3*G[{0, 1/(yu*yv)}, yw]*G[{0, 1, 1}, yu^(-1)])/8 - 
     (G[{1, yu}, yv^(-1)]*G[{0, 1, 1}, yu^(-1)])/16 - 
     (5*G[{1, yv^(-1)}, yw]*G[{0, 1, 1}, yu^(-1)])/16 + 
     (G[{1, 1/(yu*yv)}, yw]*G[{0, 1, 1}, yu^(-1)])/16 + 
     (G[{yu^(-1), 1/(yu*yv)}, yw]*G[{0, 1, 1}, yu^(-1)])/4 + 
     (5*G[{yv^(-1), 1/(yu*yv)}, yw]*G[{0, 1, 1}, yu^(-1)])/16 - 
     (Pi^2*G[{0, 1, 1}, yv^(-1)])/96 - 
     (G[{0}, yu^(-1)]^2*G[{0, 1, 1}, yv^(-1)])/16 - 
     (G[{0}, yu^(-1)]*G[{0}, yv^(-1)]*G[{0, 1, 1}, yv^(-1)])/8 - 
     (G[{0}, yv^(-1)]^2*G[{0, 1, 1}, yv^(-1)])/16 + 
     (G[{0}, yu^(-1)]*G[{0}, yw]*G[{0, 1, 1}, yv^(-1)])/8 + 
     (G[{0}, yv^(-1)]*G[{0}, yw]*G[{0, 1, 1}, yv^(-1)])/8 - 
     (G[{0}, yw]^2*G[{0, 1, 1}, yv^(-1)])/16 + 
     (3*G[{1}, yu^(-1)]^2*G[{0, 1, 1}, yv^(-1)])/32 + 
     (G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*G[{0, 1, 1}, yv^(-1)])/8 - 
     (G[{1}, yv^(-1)]*G[{1}, yw]*G[{0, 1, 1}, yv^(-1)])/8 + 
     (G[{1}, yw]^2*G[{0, 1, 1}, yv^(-1)])/16 - 
     (G[{1}, yu^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, 1, 1}, yv^(-1)])/8 + 
     (G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1, 1}, yv^(-1)])/8 + 
     (G[{0, yu^(-1)}, yw]*G[{0, 1, 1}, yv^(-1)])/8 - 
     (G[{0, yv^(-1)}, yw]*G[{0, 1, 1}, yv^(-1)])/8 + 
     (G[{1, yv^(-1)}, yw]*G[{0, 1, 1}, yv^(-1)])/8 - 
     (G[{yv^(-1), 1/(yu*yv)}, yw]*G[{0, 1, 1}, yv^(-1)])/8 + 
     (11*Pi^2*G[{0, 1, 1}, yw])/768 + (G[{0}, yu^(-1)]*G[{1}, yv^(-1)]*
       G[{0, 1, 1}, yw])/16 + (G[{0}, yv^(-1)]*G[{1}, yv^(-1)]*
       G[{0, 1, 1}, yw])/16 - (G[{0}, yw]*G[{1}, yv^(-1)]*G[{0, 1, 1}, yw])/
      16 - (5*G[{1}, yv^(-1)]^2*G[{0, 1, 1}, yw])/128 + 
     (G[{0}, yu^(-1)]*G[{1}, yw]*G[{0, 1, 1}, yw])/8 + 
     (G[{0}, yv^(-1)]*G[{1}, yw]*G[{0, 1, 1}, yw])/8 - 
     (G[{0}, yw]*G[{1}, yw]*G[{0, 1, 1}, yw])/8 - 
     (G[{1}, yu^(-1)]*G[{1}, yw]*G[{0, 1, 1}, yw])/8 - 
     (13*G[{1}, yv^(-1)]*G[{1}, yw]*G[{0, 1, 1}, yw])/64 - 
     (G[{1}, yw]^2*G[{0, 1, 1}, yw])/128 - 
     (G[{0}, yu^(-1)]*G[{yu}, yv^(-1)]*G[{0, 1, 1}, yw])/16 - 
     (G[{0}, yv^(-1)]*G[{yu}, yv^(-1)]*G[{0, 1, 1}, yw])/16 + 
     (G[{0}, yw]*G[{yu}, yv^(-1)]*G[{0, 1, 1}, yw])/16 - 
     (G[{1}, yv^(-1)]*G[{yu}, yv^(-1)]*G[{0, 1, 1}, yw])/8 + 
     (5*G[{1}, yw]*G[{yu}, yv^(-1)]*G[{0, 1, 1}, yw])/64 + 
     (G[{yu}, yv^(-1)]^2*G[{0, 1, 1}, yw])/8 - 
     (G[{0}, yu^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, 1, 1}, yw])/8 - 
     (G[{0}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, 1, 1}, yw])/8 + 
     (G[{0}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1, 1}, yw])/8 + 
     (G[{1}, yu^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, 1, 1}, yw])/8 + 
     (G[{1}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, 1, 1}, yw])/64 + 
     (G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1, 1}, yw])/64 + 
     (5*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1, 1}, yw])/64 + 
     (7*G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, 1, 1}, yw])/64 - 
     (G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1, 1}, yw])/32 + 
     (G[{0, 1}, yu^(-1)]*G[{0, 1, 1}, yw])/16 + 
     (9*G[{0, 1}, yv^(-1)]*G[{0, 1, 1}, yw])/64 - 
     (5*G[{0, 1}, yw]*G[{0, 1, 1}, yw])/64 - 
     (5*G[{0, yu^(-1)}, yw]*G[{0, 1, 1}, yw])/32 - 
     (9*G[{0, yu}, yv^(-1)]*G[{0, 1, 1}, yw])/64 + 
     (G[{0, yv^(-1)}, yw]*G[{0, 1, 1}, yw])/32 + 
     (3*G[{0, 1/(yu*yv)}, yw]*G[{0, 1, 1}, yw])/32 - 
     (G[{1, yu^(-1)}, yw]*G[{0, 1, 1}, yw])/64 + 
     (5*G[{1, yu}, yv^(-1)]*G[{0, 1, 1}, yw])/64 - 
     (G[{1, yv^(-1)}, yw]*G[{0, 1, 1}, yw])/32 - 
     (G[{1, 1/(yu*yv)}, yw]*G[{0, 1, 1}, yw])/64 - 
     (5*G[{yu^(-1), 1/(yu*yv)}, yw]*G[{0, 1, 1}, yw])/64 + 
     (G[{yv^(-1), 1/(yu*yv)}, yw]*G[{0, 1, 1}, yw])/32 - 
     (3*Pi^2*G[{0, 1, yu^(-1)}, yw])/256 + 
     (3*G[{0}, yu^(-1)]^2*G[{0, 1, yu^(-1)}, yw])/64 + 
     (3*G[{0}, yu^(-1)]*G[{0}, yv^(-1)]*G[{0, 1, yu^(-1)}, yw])/32 + 
     (3*G[{0}, yv^(-1)]^2*G[{0, 1, yu^(-1)}, yw])/64 - 
     (3*G[{0}, yu^(-1)]*G[{0}, yw]*G[{0, 1, yu^(-1)}, yw])/32 - 
     (3*G[{0}, yv^(-1)]*G[{0}, yw]*G[{0, 1, yu^(-1)}, yw])/32 + 
     (3*G[{0}, yw]^2*G[{0, 1, yu^(-1)}, yw])/64 - 
     (3*G[{0}, yu^(-1)]*G[{1}, yu^(-1)]*G[{0, 1, yu^(-1)}, yw])/32 - 
     (3*G[{0}, yv^(-1)]*G[{1}, yu^(-1)]*G[{0, 1, yu^(-1)}, yw])/32 + 
     (3*G[{0}, yw]*G[{1}, yu^(-1)]*G[{0, 1, yu^(-1)}, yw])/32 + 
     (3*G[{1}, yu^(-1)]^2*G[{0, 1, yu^(-1)}, yw])/64 - 
     (7*G[{0}, yu^(-1)]*G[{1}, yv^(-1)]*G[{0, 1, yu^(-1)}, yw])/32 - 
     (7*G[{0}, yv^(-1)]*G[{1}, yv^(-1)]*G[{0, 1, yu^(-1)}, yw])/32 + 
     (7*G[{0}, yw]*G[{1}, yv^(-1)]*G[{0, 1, yu^(-1)}, yw])/32 + 
     (3*G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*G[{0, 1, yu^(-1)}, yw])/32 + 
     (G[{1}, yv^(-1)]^2*G[{0, 1, yu^(-1)}, yw])/8 - 
     (9*G[{0}, yu^(-1)]*G[{1}, yw]*G[{0, 1, yu^(-1)}, yw])/64 - 
     (9*G[{0}, yv^(-1)]*G[{1}, yw]*G[{0, 1, yu^(-1)}, yw])/64 + 
     (9*G[{0}, yw]*G[{1}, yw]*G[{0, 1, yu^(-1)}, yw])/64 + 
     (9*G[{1}, yu^(-1)]*G[{1}, yw]*G[{0, 1, yu^(-1)}, yw])/64 + 
     (11*G[{1}, yv^(-1)]*G[{1}, yw]*G[{0, 1, yu^(-1)}, yw])/64 - 
     (G[{1}, yw]^2*G[{0, 1, yu^(-1)}, yw])/8 + 
     (G[{0}, yu^(-1)]*G[{yu}, yv^(-1)]*G[{0, 1, yu^(-1)}, yw])/8 + 
     (G[{0}, yv^(-1)]*G[{yu}, yv^(-1)]*G[{0, 1, yu^(-1)}, yw])/8 - 
     (G[{0}, yw]*G[{yu}, yv^(-1)]*G[{0, 1, yu^(-1)}, yw])/8 - 
     (G[{1}, yw]*G[{yu}, yv^(-1)]*G[{0, 1, yu^(-1)}, yw])/32 - 
     (G[{yu}, yv^(-1)]^2*G[{0, 1, yu^(-1)}, yw])/8 + 
     (11*G[{0}, yu^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, 1, yu^(-1)}, yw])/64 + 
     (11*G[{0}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, 1, yu^(-1)}, yw])/64 - 
     (11*G[{0}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1, yu^(-1)}, yw])/64 - 
     (7*G[{1}, yu^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, 1, yu^(-1)}, yw])/64 - 
     (17*G[{1}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, 1, yu^(-1)}, yw])/64 + 
     (G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1, yu^(-1)}, yw])/16 + 
     (3*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1, yu^(-1)}, yw])/32 + 
     (G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, 1, yu^(-1)}, yw])/32 - 
     (G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1, yu^(-1)}, yw])/16 + 
     (3*G[{1/(yu*yv)}, yw]^2*G[{0, 1, yu^(-1)}, yw])/64 - 
     (G[{0, 1}, yu^(-1)]*G[{0, 1, yu^(-1)}, yw])/8 - 
     (G[{0, 1}, yv^(-1)]*G[{0, 1, yu^(-1)}, yw])/32 - 
     (G[{0, yu^(-1)}, yw]*G[{0, 1, yu^(-1)}, yw])/16 + 
     (G[{0, yu}, yv^(-1)]*G[{0, 1, yu^(-1)}, yw])/32 + 
     (G[{0, yv^(-1)}, yw]*G[{0, 1, yu^(-1)}, yw])/16 + 
     (G[{1, yu^(-1)}, yw]*G[{0, 1, yu^(-1)}, yw])/32 + 
     (3*G[{1, yu}, yv^(-1)]*G[{0, 1, yu^(-1)}, yw])/32 - 
     (G[{1, yv^(-1)}, yw]*G[{0, 1, yu^(-1)}, yw])/16 + 
     (G[{1, 1/(yu*yv)}, yw]*G[{0, 1, yu^(-1)}, yw])/32 - 
     (3*G[{yu^(-1), 1/(yu*yv)}, yw]*G[{0, 1, yu^(-1)}, yw])/32 + 
     (G[{yv^(-1), 1/(yu*yv)}, yw]*G[{0, 1, yu^(-1)}, yw])/16 - 
     (G[{0}, yu^(-1)]^2*G[{0, 1, yu}, yv^(-1)])/16 - 
     (G[{0}, yu^(-1)]*G[{0}, yv^(-1)]*G[{0, 1, yu}, yv^(-1)])/8 - 
     (G[{0}, yv^(-1)]^2*G[{0, 1, yu}, yv^(-1)])/16 + 
     (G[{0}, yu^(-1)]*G[{0}, yw]*G[{0, 1, yu}, yv^(-1)])/8 + 
     (G[{0}, yv^(-1)]*G[{0}, yw]*G[{0, 1, yu}, yv^(-1)])/8 - 
     (G[{0}, yw]^2*G[{0, 1, yu}, yv^(-1)])/16 + 
     (G[{0}, yu^(-1)]*G[{1}, yu^(-1)]*G[{0, 1, yu}, yv^(-1)])/16 + 
     (G[{0}, yv^(-1)]*G[{1}, yu^(-1)]*G[{0, 1, yu}, yv^(-1)])/16 - 
     (G[{0}, yw]*G[{1}, yu^(-1)]*G[{0, 1, yu}, yv^(-1)])/16 - 
     (G[{1}, yu^(-1)]^2*G[{0, 1, yu}, yv^(-1)])/32 + 
     (G[{0}, yu^(-1)]*G[{1}, yv^(-1)]*G[{0, 1, yu}, yv^(-1)])/8 + 
     (G[{0}, yv^(-1)]*G[{1}, yv^(-1)]*G[{0, 1, yu}, yv^(-1)])/8 - 
     (G[{0}, yw]*G[{1}, yv^(-1)]*G[{0, 1, yu}, yv^(-1)])/8 - 
     (G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*G[{0, 1, yu}, yv^(-1)])/16 - 
     (G[{1}, yv^(-1)]^2*G[{0, 1, yu}, yv^(-1)])/16 - 
     (G[{0}, yu^(-1)]*G[{1}, yw]*G[{0, 1, yu}, yv^(-1)])/16 - 
     (G[{0}, yv^(-1)]*G[{1}, yw]*G[{0, 1, yu}, yv^(-1)])/16 + 
     (G[{0}, yw]*G[{1}, yw]*G[{0, 1, yu}, yv^(-1)])/16 + 
     (G[{1}, yu^(-1)]*G[{1}, yw]*G[{0, 1, yu}, yv^(-1)])/16 + 
     (G[{1}, yv^(-1)]*G[{1}, yw]*G[{0, 1, yu}, yv^(-1)])/8 - 
     (G[{1}, yw]^2*G[{0, 1, yu}, yv^(-1)])/32 - 
     (G[{1}, yw]*G[{yu}, yv^(-1)]*G[{0, 1, yu}, yv^(-1)])/16 - 
     (G[{0}, yu^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, 1, yu}, yv^(-1)])/8 - 
     (G[{0}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, 1, yu}, yv^(-1)])/8 + 
     (G[{0}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1, yu}, yv^(-1)])/8 + 
     (G[{1}, yu^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, 1, yu}, yv^(-1)])/16 + 
     (G[{1}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, 1, yu}, yv^(-1)])/8 - 
     (G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1, yu}, yv^(-1)])/16 - 
     (G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1, yu}, yv^(-1)])/8 + 
     (G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, 1, yu}, yv^(-1)])/16 - 
     (G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1, yu}, yv^(-1)])/16 + 
     (G[{0, 1}, yv^(-1)]*G[{0, 1, yu}, yv^(-1)])/16 + 
     (G[{0, yu^(-1)}, yw]*G[{0, 1, yu}, yv^(-1)])/16 + 
     (G[{0, yu}, yv^(-1)]*G[{0, 1, yu}, yv^(-1)])/16 + 
     (G[{0, yv^(-1)}, yw]*G[{0, 1, yu}, yv^(-1)])/16 - 
     (G[{0, 1/(yu*yv)}, yw]*G[{0, 1, yu}, yv^(-1)])/8 - 
     (G[{1, yu}, yv^(-1)]*G[{0, 1, yu}, yv^(-1)])/16 - 
     (G[{1, yv^(-1)}, yw]*G[{0, 1, yu}, yv^(-1)])/16 + 
     (G[{1, 1/(yu*yv)}, yw]*G[{0, 1, yu}, yv^(-1)])/16 + 
     (G[{yu^(-1), 1/(yu*yv)}, yw]*G[{0, 1, yu}, yv^(-1)])/8 + 
     (G[{yv^(-1), 1/(yu*yv)}, yw]*G[{0, 1, yu}, yv^(-1)])/16 - 
     (11*Pi^2*G[{0, 1, yv^(-1)}, yw])/256 - 
     (3*G[{0}, yu^(-1)]^2*G[{0, 1, yv^(-1)}, yw])/64 - 
     (3*G[{0}, yu^(-1)]*G[{0}, yv^(-1)]*G[{0, 1, yv^(-1)}, yw])/32 - 
     (3*G[{0}, yv^(-1)]^2*G[{0, 1, yv^(-1)}, yw])/64 + 
     (3*G[{0}, yu^(-1)]*G[{0}, yw]*G[{0, 1, yv^(-1)}, yw])/32 + 
     (3*G[{0}, yv^(-1)]*G[{0}, yw]*G[{0, 1, yv^(-1)}, yw])/32 - 
     (3*G[{0}, yw]^2*G[{0, 1, yv^(-1)}, yw])/64 + 
     (11*G[{0}, yu^(-1)]*G[{1}, yu^(-1)]*G[{0, 1, yv^(-1)}, yw])/32 + 
     (11*G[{0}, yv^(-1)]*G[{1}, yu^(-1)]*G[{0, 1, yv^(-1)}, yw])/32 - 
     (11*G[{0}, yw]*G[{1}, yu^(-1)]*G[{0, 1, yv^(-1)}, yw])/32 - 
     (17*G[{1}, yu^(-1)]^2*G[{0, 1, yv^(-1)}, yw])/64 - 
     (5*G[{0}, yu^(-1)]*G[{1}, yv^(-1)]*G[{0, 1, yv^(-1)}, yw])/32 - 
     (5*G[{0}, yv^(-1)]*G[{1}, yv^(-1)]*G[{0, 1, yv^(-1)}, yw])/32 + 
     (5*G[{0}, yw]*G[{1}, yv^(-1)]*G[{0, 1, yv^(-1)}, yw])/32 - 
     (5*G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*G[{0, 1, yv^(-1)}, yw])/32 + 
     (5*G[{1}, yv^(-1)]^2*G[{0, 1, yv^(-1)}, yw])/32 - 
     (13*G[{0}, yu^(-1)]*G[{1}, yw]*G[{0, 1, yv^(-1)}, yw])/64 - 
     (13*G[{0}, yv^(-1)]*G[{1}, yw]*G[{0, 1, yv^(-1)}, yw])/64 + 
     (13*G[{0}, yw]*G[{1}, yw]*G[{0, 1, yv^(-1)}, yw])/64 + 
     (25*G[{1}, yu^(-1)]*G[{1}, yw]*G[{0, 1, yv^(-1)}, yw])/64 + 
     (3*G[{1}, yv^(-1)]*G[{1}, yw]*G[{0, 1, yv^(-1)}, yw])/64 - 
     (G[{1}, yw]^2*G[{0, 1, yv^(-1)}, yw])/8 - 
     (G[{1}, yw]*G[{yu}, yv^(-1)]*G[{0, 1, yv^(-1)}, yw])/32 + 
     (11*G[{0}, yu^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, 1, yv^(-1)}, yw])/64 + 
     (11*G[{0}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, 1, yv^(-1)}, yw])/64 - 
     (11*G[{0}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1, yv^(-1)}, yw])/64 - 
     (7*G[{1}, yu^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, 1, yv^(-1)}, yw])/64 - 
     (17*G[{1}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, 1, yv^(-1)}, yw])/64 + 
     (G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1, yv^(-1)}, yw])/16 + 
     (3*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1, yv^(-1)}, yw])/32 + 
     (G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, 1, yv^(-1)}, yw])/32 - 
     (G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1, yv^(-1)}, yw])/16 + 
     (3*G[{1/(yu*yv)}, yw]^2*G[{0, 1, yv^(-1)}, yw])/64 - 
     (3*G[{0, 1}, yu^(-1)]*G[{0, 1, yv^(-1)}, yw])/16 - 
     (G[{0, 1}, yv^(-1)]*G[{0, 1, yv^(-1)}, yw])/32 + 
     (G[{0, 1}, yw]*G[{0, 1, yv^(-1)}, yw])/16 - 
     (3*G[{0, yu^(-1)}, yw]*G[{0, 1, yv^(-1)}, yw])/64 + 
     (G[{0, yu}, yv^(-1)]*G[{0, 1, yv^(-1)}, yw])/32 + 
     (G[{0, yv^(-1)}, yw]*G[{0, 1, yv^(-1)}, yw])/16 + 
     (G[{1, yu^(-1)}, yw]*G[{0, 1, yv^(-1)}, yw])/32 + 
     (5*G[{1, yu}, yv^(-1)]*G[{0, 1, yv^(-1)}, yw])/32 - 
     (G[{1, yv^(-1)}, yw]*G[{0, 1, yv^(-1)}, yw])/16 + 
     (G[{1, 1/(yu*yv)}, yw]*G[{0, 1, yv^(-1)}, yw])/32 - 
     (3*G[{yu^(-1), 1/(yu*yv)}, yw]*G[{0, 1, yv^(-1)}, yw])/32 + 
     (G[{yv^(-1), 1/(yu*yv)}, yw]*G[{0, 1, yv^(-1)}, yw])/16 - 
     (5*Pi^2*G[{0, 1, 1/(yu*yv)}, yw])/768 - 
     (3*G[{0}, yu^(-1)]*G[{1}, yu^(-1)]*G[{0, 1, 1/(yu*yv)}, yw])/16 - 
     (3*G[{0}, yv^(-1)]*G[{1}, yu^(-1)]*G[{0, 1, 1/(yu*yv)}, yw])/16 + 
     (3*G[{0}, yw]*G[{1}, yu^(-1)]*G[{0, 1, 1/(yu*yv)}, yw])/16 + 
     (3*G[{1}, yu^(-1)]^2*G[{0, 1, 1/(yu*yv)}, yw])/16 + 
     (G[{0}, yu^(-1)]*G[{1}, yv^(-1)]*G[{0, 1, 1/(yu*yv)}, yw])/16 + 
     (G[{0}, yv^(-1)]*G[{1}, yv^(-1)]*G[{0, 1, 1/(yu*yv)}, yw])/16 - 
     (G[{0}, yw]*G[{1}, yv^(-1)]*G[{0, 1, 1/(yu*yv)}, yw])/16 - 
     (5*G[{1}, yv^(-1)]^2*G[{0, 1, 1/(yu*yv)}, yw])/128 + 
     (G[{0}, yu^(-1)]*G[{1}, yw]*G[{0, 1, 1/(yu*yv)}, yw])/16 + 
     (G[{0}, yv^(-1)]*G[{1}, yw]*G[{0, 1, 1/(yu*yv)}, yw])/16 - 
     (G[{0}, yw]*G[{1}, yw]*G[{0, 1, 1/(yu*yv)}, yw])/16 - 
     (G[{1}, yu^(-1)]*G[{1}, yw]*G[{0, 1, 1/(yu*yv)}, yw])/8 - 
     (13*G[{1}, yv^(-1)]*G[{1}, yw]*G[{0, 1, 1/(yu*yv)}, yw])/64 - 
     (G[{1}, yw]^2*G[{0, 1, 1/(yu*yv)}, yw])/128 + 
     (G[{0}, yu^(-1)]*G[{yu}, yv^(-1)]*G[{0, 1, 1/(yu*yv)}, yw])/8 + 
     (G[{0}, yv^(-1)]*G[{yu}, yv^(-1)]*G[{0, 1, 1/(yu*yv)}, yw])/8 - 
     (G[{0}, yw]*G[{yu}, yv^(-1)]*G[{0, 1, 1/(yu*yv)}, yw])/8 - 
     (G[{1}, yv^(-1)]*G[{yu}, yv^(-1)]*G[{0, 1, 1/(yu*yv)}, yw])/8 + 
     (13*G[{1}, yw]*G[{yu}, yv^(-1)]*G[{0, 1, 1/(yu*yv)}, yw])/64 - 
     (G[{yu}, yv^(-1)]^2*G[{0, 1, 1/(yu*yv)}, yw])/16 - 
     (G[{0}, yu^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, 1, 1/(yu*yv)}, yw])/16 - 
     (G[{0}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, 1, 1/(yu*yv)}, yw])/16 + 
     (G[{0}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1, 1/(yu*yv)}, yw])/16 + 
     (G[{1}, yu^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, 1, 1/(yu*yv)}, yw])/8 + 
     (G[{1}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, 1, 1/(yu*yv)}, yw])/64 + 
     (G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1, 1/(yu*yv)}, yw])/64 + 
     (5*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1, 1/(yu*yv)}, yw])/64 - 
     (G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, 1, 1/(yu*yv)}, yw])/64 - 
     (G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1, 1/(yu*yv)}, yw])/32 - 
     (G[{0, 1}, yu^(-1)]*G[{0, 1, 1/(yu*yv)}, yw])/16 + 
     (G[{0, 1}, yv^(-1)]*G[{0, 1, 1/(yu*yv)}, yw])/64 + 
     (3*G[{0, 1}, yw]*G[{0, 1, 1/(yu*yv)}, yw])/64 + 
     (G[{0, yu^(-1)}, yw]*G[{0, 1, 1/(yu*yv)}, yw])/64 - 
     (G[{0, yu}, yv^(-1)]*G[{0, 1, 1/(yu*yv)}, yw])/64 + 
     (5*G[{0, yv^(-1)}, yw]*G[{0, 1, 1/(yu*yv)}, yw])/64 + 
     (G[{0, 1/(yu*yv)}, yw]*G[{0, 1, 1/(yu*yv)}, yw])/32 - 
     (G[{1, yu^(-1)}, yw]*G[{0, 1, 1/(yu*yv)}, yw])/64 + 
     (5*G[{1, yu}, yv^(-1)]*G[{0, 1, 1/(yu*yv)}, yw])/64 - 
     (G[{1, yv^(-1)}, yw]*G[{0, 1, 1/(yu*yv)}, yw])/32 - 
     (G[{1, 1/(yu*yv)}, yw]*G[{0, 1, 1/(yu*yv)}, yw])/64 - 
     (5*G[{yu^(-1), 1/(yu*yv)}, yw]*G[{0, 1, 1/(yu*yv)}, yw])/64 + 
     (G[{yv^(-1), 1/(yu*yv)}, yw]*G[{0, 1, 1/(yu*yv)}, yw])/32 - 
     (Pi^2*G[{0, yu^(-1), 1}, yw])/256 - 
     (3*G[{1}, yv^(-1)]^2*G[{0, yu^(-1), 1}, yw])/128 - 
     (G[{0}, yu^(-1)]*G[{1}, yw]*G[{0, yu^(-1), 1}, yw])/8 - 
     (G[{0}, yv^(-1)]*G[{1}, yw]*G[{0, yu^(-1), 1}, yw])/8 + 
     (G[{0}, yw]*G[{1}, yw]*G[{0, yu^(-1), 1}, yw])/8 + 
     (G[{1}, yu^(-1)]*G[{1}, yw]*G[{0, yu^(-1), 1}, yw])/8 + 
     (13*G[{1}, yv^(-1)]*G[{1}, yw]*G[{0, yu^(-1), 1}, yw])/64 + 
     (G[{1}, yw]^2*G[{0, yu^(-1), 1}, yw])/128 + 
     (G[{1}, yv^(-1)]*G[{yu}, yv^(-1)]*G[{0, yu^(-1), 1}, yw])/8 - 
     (5*G[{1}, yw]*G[{yu}, yv^(-1)]*G[{0, yu^(-1), 1}, yw])/64 - 
     (G[{yu}, yv^(-1)]^2*G[{0, yu^(-1), 1}, yw])/16 + 
     (G[{0}, yu^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1), 1}, yw])/16 + 
     (G[{0}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1), 1}, yw])/16 - 
     (G[{0}, yw]*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1), 1}, yw])/16 - 
     (G[{1}, yu^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1), 1}, yw])/8 - 
     (G[{1}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1), 1}, yw])/64 - 
     (G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1), 1}, yw])/64 - 
     (5*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1), 1}, yw])/64 + 
     (G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1), 1}, yw])/64 + 
     (G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1), 1}, yw])/32 - 
     (5*G[{0, 1}, yv^(-1)]*G[{0, yu^(-1), 1}, yw])/64 + 
     (G[{0, 1}, yw]*G[{0, yu^(-1), 1}, yw])/64 - 
     (G[{0, yu^(-1)}, yw]*G[{0, yu^(-1), 1}, yw])/64 + 
     (5*G[{0, yu}, yv^(-1)]*G[{0, yu^(-1), 1}, yw])/64 - 
     (G[{0, yv^(-1)}, yw]*G[{0, yu^(-1), 1}, yw])/32 - 
     (G[{0, 1/(yu*yv)}, yw]*G[{0, yu^(-1), 1}, yw])/32 + 
     (G[{1, yu^(-1)}, yw]*G[{0, yu^(-1), 1}, yw])/64 - 
     (5*G[{1, yu}, yv^(-1)]*G[{0, yu^(-1), 1}, yw])/64 + 
     (G[{1, yv^(-1)}, yw]*G[{0, yu^(-1), 1}, yw])/32 + 
     (G[{1, 1/(yu*yv)}, yw]*G[{0, yu^(-1), 1}, yw])/64 + 
     (5*G[{yu^(-1), 1/(yu*yv)}, yw]*G[{0, yu^(-1), 1}, yw])/64 - 
     (G[{yv^(-1), 1/(yu*yv)}, yw]*G[{0, yu^(-1), 1}, yw])/32 - 
     (7*Pi^2*G[{0, yu^(-1), yu^(-1)}, yw])/768 - 
     (3*G[{0}, yu^(-1)]^2*G[{0, yu^(-1), yu^(-1)}, yw])/64 - 
     (3*G[{0}, yu^(-1)]*G[{0}, yv^(-1)]*G[{0, yu^(-1), yu^(-1)}, yw])/32 - 
     (3*G[{0}, yv^(-1)]^2*G[{0, yu^(-1), yu^(-1)}, yw])/64 + 
     (3*G[{0}, yu^(-1)]*G[{0}, yw]*G[{0, yu^(-1), yu^(-1)}, yw])/32 + 
     (3*G[{0}, yv^(-1)]*G[{0}, yw]*G[{0, yu^(-1), yu^(-1)}, yw])/32 - 
     (3*G[{0}, yw]^2*G[{0, yu^(-1), yu^(-1)}, yw])/64 + 
     (3*G[{0}, yu^(-1)]*G[{1}, yu^(-1)]*G[{0, yu^(-1), yu^(-1)}, yw])/32 + 
     (3*G[{0}, yv^(-1)]*G[{1}, yu^(-1)]*G[{0, yu^(-1), yu^(-1)}, yw])/32 - 
     (3*G[{0}, yw]*G[{1}, yu^(-1)]*G[{0, yu^(-1), yu^(-1)}, yw])/32 - 
     (3*G[{1}, yu^(-1)]^2*G[{0, yu^(-1), yu^(-1)}, yw])/64 + 
     (3*G[{0}, yu^(-1)]*G[{1}, yv^(-1)]*G[{0, yu^(-1), yu^(-1)}, yw])/32 + 
     (3*G[{0}, yv^(-1)]*G[{1}, yv^(-1)]*G[{0, yu^(-1), yu^(-1)}, yw])/32 - 
     (3*G[{0}, yw]*G[{1}, yv^(-1)]*G[{0, yu^(-1), yu^(-1)}, yw])/32 - 
     (3*G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*G[{0, yu^(-1), yu^(-1)}, yw])/32 + 
     (9*G[{0}, yu^(-1)]*G[{1}, yw]*G[{0, yu^(-1), yu^(-1)}, yw])/64 + 
     (9*G[{0}, yv^(-1)]*G[{1}, yw]*G[{0, yu^(-1), yu^(-1)}, yw])/64 - 
     (9*G[{0}, yw]*G[{1}, yw]*G[{0, yu^(-1), yu^(-1)}, yw])/64 - 
     (9*G[{1}, yu^(-1)]*G[{1}, yw]*G[{0, yu^(-1), yu^(-1)}, yw])/64 - 
     (11*G[{1}, yv^(-1)]*G[{1}, yw]*G[{0, yu^(-1), yu^(-1)}, yw])/64 + 
     (G[{1}, yw]^2*G[{0, yu^(-1), yu^(-1)}, yw])/8 + 
     (G[{1}, yw]*G[{yu}, yv^(-1)]*G[{0, yu^(-1), yu^(-1)}, yw])/32 - 
     (7*G[{0}, yu^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1), yu^(-1)}, yw])/64 - 
     (7*G[{0}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1), yu^(-1)}, yw])/64 + 
     (7*G[{0}, yw]*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1), yu^(-1)}, yw])/64 + 
     (7*G[{1}, yu^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1), yu^(-1)}, yw])/64 + 
     (9*G[{1}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1), yu^(-1)}, yw])/64 - 
     (G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1), yu^(-1)}, yw])/16 - 
     (3*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1), yu^(-1)}, yw])/
      32 - (G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1), yu^(-1)}, yw])/
      32 + (G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1), yu^(-1)}, yw])/
      16 - (3*G[{1/(yu*yv)}, yw]^2*G[{0, yu^(-1), yu^(-1)}, yw])/64 - 
     (3*G[{0, 1}, yv^(-1)]*G[{0, yu^(-1), yu^(-1)}, yw])/32 + 
     (G[{0, 1}, yw]*G[{0, yu^(-1), yu^(-1)}, yw])/8 - 
     (G[{0, yu^(-1)}, yw]*G[{0, yu^(-1), yu^(-1)}, yw])/8 + 
     (3*G[{0, yu}, yv^(-1)]*G[{0, yu^(-1), yu^(-1)}, yw])/32 - 
     (G[{0, yv^(-1)}, yw]*G[{0, yu^(-1), yu^(-1)}, yw])/16 - 
     (G[{0, 1/(yu*yv)}, yw]*G[{0, yu^(-1), yu^(-1)}, yw])/16 - 
     (G[{1, yu^(-1)}, yw]*G[{0, yu^(-1), yu^(-1)}, yw])/32 - 
     (3*G[{1, yu}, yv^(-1)]*G[{0, yu^(-1), yu^(-1)}, yw])/32 + 
     (G[{1, yv^(-1)}, yw]*G[{0, yu^(-1), yu^(-1)}, yw])/16 - 
     (G[{1, 1/(yu*yv)}, yw]*G[{0, yu^(-1), yu^(-1)}, yw])/32 + 
     (3*G[{yu^(-1), 1/(yu*yv)}, yw]*G[{0, yu^(-1), yu^(-1)}, yw])/32 - 
     (G[{yv^(-1), 1/(yu*yv)}, yw]*G[{0, yu^(-1), yu^(-1)}, yw])/16 + 
     (3*Pi^2*G[{0, yu^(-1), yv^(-1)}, yw])/256 - 
     (3*G[{0}, yu^(-1)]^2*G[{0, yu^(-1), yv^(-1)}, yw])/64 - 
     (3*G[{0}, yu^(-1)]*G[{0}, yv^(-1)]*G[{0, yu^(-1), yv^(-1)}, yw])/32 - 
     (3*G[{0}, yv^(-1)]^2*G[{0, yu^(-1), yv^(-1)}, yw])/64 + 
     (3*G[{0}, yu^(-1)]*G[{0}, yw]*G[{0, yu^(-1), yv^(-1)}, yw])/32 + 
     (3*G[{0}, yv^(-1)]*G[{0}, yw]*G[{0, yu^(-1), yv^(-1)}, yw])/32 - 
     (3*G[{0}, yw]^2*G[{0, yu^(-1), yv^(-1)}, yw])/64 - 
     (G[{0}, yu^(-1)]*G[{1}, yu^(-1)]*G[{0, yu^(-1), yv^(-1)}, yw])/32 - 
     (G[{0}, yv^(-1)]*G[{1}, yu^(-1)]*G[{0, yu^(-1), yv^(-1)}, yw])/32 + 
     (G[{0}, yw]*G[{1}, yu^(-1)]*G[{0, yu^(-1), yv^(-1)}, yw])/32 + 
     (5*G[{1}, yu^(-1)]^2*G[{0, yu^(-1), yv^(-1)}, yw])/64 + 
     (7*G[{0}, yu^(-1)]*G[{1}, yv^(-1)]*G[{0, yu^(-1), yv^(-1)}, yw])/32 + 
     (7*G[{0}, yv^(-1)]*G[{1}, yv^(-1)]*G[{0, yu^(-1), yv^(-1)}, yw])/32 - 
     (7*G[{0}, yw]*G[{1}, yv^(-1)]*G[{0, yu^(-1), yv^(-1)}, yw])/32 - 
     (3*G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*G[{0, yu^(-1), yv^(-1)}, yw])/32 - 
     (G[{1}, yv^(-1)]^2*G[{0, yu^(-1), yv^(-1)}, yw])/8 + 
     (5*G[{0}, yu^(-1)]*G[{1}, yw]*G[{0, yu^(-1), yv^(-1)}, yw])/64 + 
     (5*G[{0}, yv^(-1)]*G[{1}, yw]*G[{0, yu^(-1), yv^(-1)}, yw])/64 - 
     (5*G[{0}, yw]*G[{1}, yw]*G[{0, yu^(-1), yv^(-1)}, yw])/64 - 
     (9*G[{1}, yu^(-1)]*G[{1}, yw]*G[{0, yu^(-1), yv^(-1)}, yw])/64 - 
     (3*G[{1}, yv^(-1)]*G[{1}, yw]*G[{0, yu^(-1), yv^(-1)}, yw])/64 + 
     (G[{1}, yw]^2*G[{0, yu^(-1), yv^(-1)}, yw])/8 + 
     (G[{1}, yw]*G[{yu}, yv^(-1)]*G[{0, yu^(-1), yv^(-1)}, yw])/32 - 
     (11*G[{0}, yu^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1), yv^(-1)}, yw])/
      64 - (11*G[{0}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1), yv^(-1)}, 
        yw])/64 + (11*G[{0}, yw]*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1), yv^(-1)}, 
        yw])/64 + (7*G[{1}, yu^(-1)]*G[{1/(yu*yv)}, yw]*
       G[{0, yu^(-1), yv^(-1)}, yw])/64 + 
     (17*G[{1}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1), yv^(-1)}, yw])/
      64 - (G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1), yv^(-1)}, yw])/16 - 
     (3*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1), yv^(-1)}, yw])/
      32 - (G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1), yv^(-1)}, yw])/
      32 + (G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1), yv^(-1)}, yw])/
      16 - (3*G[{1/(yu*yv)}, yw]^2*G[{0, yu^(-1), yv^(-1)}, yw])/64 + 
     (G[{0, 1}, yu^(-1)]*G[{0, yu^(-1), yv^(-1)}, yw])/8 + 
     (G[{0, 1}, yv^(-1)]*G[{0, yu^(-1), yv^(-1)}, yw])/32 - 
     (G[{0, yu}, yv^(-1)]*G[{0, yu^(-1), yv^(-1)}, yw])/32 - 
     (G[{0, yv^(-1)}, yw]*G[{0, yu^(-1), yv^(-1)}, yw])/16 - 
     (G[{1, yu^(-1)}, yw]*G[{0, yu^(-1), yv^(-1)}, yw])/32 - 
     (3*G[{1, yu}, yv^(-1)]*G[{0, yu^(-1), yv^(-1)}, yw])/32 + 
     (G[{1, yv^(-1)}, yw]*G[{0, yu^(-1), yv^(-1)}, yw])/16 - 
     (G[{1, 1/(yu*yv)}, yw]*G[{0, yu^(-1), yv^(-1)}, yw])/32 + 
     (3*G[{yu^(-1), 1/(yu*yv)}, yw]*G[{0, yu^(-1), yv^(-1)}, yw])/32 - 
     (G[{yv^(-1), 1/(yu*yv)}, yw]*G[{0, yu^(-1), yv^(-1)}, yw])/16 + 
     (13*Pi^2*G[{0, yu^(-1), 1/(yu*yv)}, yw])/768 + 
     (3*G[{0}, yu^(-1)]^2*G[{0, yu^(-1), 1/(yu*yv)}, yw])/32 + 
     (3*G[{0}, yu^(-1)]*G[{0}, yv^(-1)]*G[{0, yu^(-1), 1/(yu*yv)}, yw])/16 + 
     (3*G[{0}, yv^(-1)]^2*G[{0, yu^(-1), 1/(yu*yv)}, yw])/32 - 
     (3*G[{0}, yu^(-1)]*G[{0}, yw]*G[{0, yu^(-1), 1/(yu*yv)}, yw])/16 - 
     (3*G[{0}, yv^(-1)]*G[{0}, yw]*G[{0, yu^(-1), 1/(yu*yv)}, yw])/16 + 
     (3*G[{0}, yw]^2*G[{0, yu^(-1), 1/(yu*yv)}, yw])/32 - 
     (G[{0}, yu^(-1)]*G[{1}, yu^(-1)]*G[{0, yu^(-1), 1/(yu*yv)}, yw])/8 - 
     (G[{0}, yv^(-1)]*G[{1}, yu^(-1)]*G[{0, yu^(-1), 1/(yu*yv)}, yw])/8 + 
     (G[{0}, yw]*G[{1}, yu^(-1)]*G[{0, yu^(-1), 1/(yu*yv)}, yw])/8 - 
     (G[{0}, yu^(-1)]*G[{1}, yv^(-1)]*G[{0, yu^(-1), 1/(yu*yv)}, yw])/4 - 
     (G[{0}, yv^(-1)]*G[{1}, yv^(-1)]*G[{0, yu^(-1), 1/(yu*yv)}, yw])/4 + 
     (G[{0}, yw]*G[{1}, yv^(-1)]*G[{0, yu^(-1), 1/(yu*yv)}, yw])/4 + 
     (G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*G[{0, yu^(-1), 1/(yu*yv)}, yw])/4 + 
     (17*G[{1}, yv^(-1)]^2*G[{0, yu^(-1), 1/(yu*yv)}, yw])/128 + 
     (G[{0}, yu^(-1)]*G[{1}, yw]*G[{0, yu^(-1), 1/(yu*yv)}, yw])/16 + 
     (G[{0}, yv^(-1)]*G[{1}, yw]*G[{0, yu^(-1), 1/(yu*yv)}, yw])/16 - 
     (G[{0}, yw]*G[{1}, yw]*G[{0, yu^(-1), 1/(yu*yv)}, yw])/16 - 
     (G[{1}, yu^(-1)]*G[{1}, yw]*G[{0, yu^(-1), 1/(yu*yv)}, yw])/8 - 
     (3*G[{1}, yv^(-1)]*G[{1}, yw]*G[{0, yu^(-1), 1/(yu*yv)}, yw])/64 + 
     (G[{1}, yw]^2*G[{0, yu^(-1), 1/(yu*yv)}, yw])/128 - 
     (G[{1}, yv^(-1)]*G[{yu}, yv^(-1)]*G[{0, yu^(-1), 1/(yu*yv)}, yw])/8 + 
     (3*G[{1}, yw]*G[{yu}, yv^(-1)]*G[{0, yu^(-1), 1/(yu*yv)}, yw])/64 + 
     (G[{yu}, yv^(-1)]^2*G[{0, yu^(-1), 1/(yu*yv)}, yw])/16 + 
     (G[{0}, yu^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1), 1/(yu*yv)}, yw])/16 + 
     (G[{0}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1), 1/(yu*yv)}, yw])/16 - 
     (G[{0}, yw]*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1), 1/(yu*yv)}, yw])/16 - 
     (G[{1}, yu^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1), 1/(yu*yv)}, yw])/8 - 
     (G[{1}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1), 1/(yu*yv)}, yw])/64 - 
     (G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1), 1/(yu*yv)}, yw])/64 - 
     (5*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1), 1/(yu*yv)}, yw])/
      64 + (G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1), 1/(yu*yv)}, 
        yw])/64 + (G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*
       G[{0, yu^(-1), 1/(yu*yv)}, yw])/32 + 
     (7*G[{0, 1}, yv^(-1)]*G[{0, yu^(-1), 1/(yu*yv)}, yw])/64 + 
     (G[{0, 1}, yw]*G[{0, yu^(-1), 1/(yu*yv)}, yw])/64 - 
     (G[{0, yu^(-1)}, yw]*G[{0, yu^(-1), 1/(yu*yv)}, yw])/64 - 
     (7*G[{0, yu}, yv^(-1)]*G[{0, yu^(-1), 1/(yu*yv)}, yw])/64 - 
     (G[{0, yv^(-1)}, yw]*G[{0, yu^(-1), 1/(yu*yv)}, yw])/32 - 
     (G[{0, 1/(yu*yv)}, yw]*G[{0, yu^(-1), 1/(yu*yv)}, yw])/32 + 
     (G[{1, yu^(-1)}, yw]*G[{0, yu^(-1), 1/(yu*yv)}, yw])/64 + 
     (7*G[{1, yu}, yv^(-1)]*G[{0, yu^(-1), 1/(yu*yv)}, yw])/64 + 
     (G[{1, yv^(-1)}, yw]*G[{0, yu^(-1), 1/(yu*yv)}, yw])/32 + 
     (G[{1, 1/(yu*yv)}, yw]*G[{0, yu^(-1), 1/(yu*yv)}, yw])/64 + 
     (5*G[{yu^(-1), 1/(yu*yv)}, yw]*G[{0, yu^(-1), 1/(yu*yv)}, yw])/64 - 
     (G[{yv^(-1), 1/(yu*yv)}, yw]*G[{0, yu^(-1), 1/(yu*yv)}, yw])/32 + 
     (Pi^2*G[{0, yu, 1}, yv^(-1)])/48 - 
     (G[{0}, yu^(-1)]^2*G[{0, yu, 1}, yv^(-1)])/32 - 
     (G[{0}, yu^(-1)]*G[{0}, yv^(-1)]*G[{0, yu, 1}, yv^(-1)])/16 - 
     (G[{0}, yv^(-1)]^2*G[{0, yu, 1}, yv^(-1)])/32 + 
     (G[{0}, yu^(-1)]*G[{0}, yw]*G[{0, yu, 1}, yv^(-1)])/16 + 
     (G[{0}, yv^(-1)]*G[{0}, yw]*G[{0, yu, 1}, yv^(-1)])/16 - 
     (G[{0}, yw]^2*G[{0, yu, 1}, yv^(-1)])/32 - 
     (G[{1}, yu^(-1)]^2*G[{0, yu, 1}, yv^(-1)])/32 + 
     (G[{0}, yu^(-1)]*G[{1}, yv^(-1)]*G[{0, yu, 1}, yv^(-1)])/16 + 
     (G[{0}, yv^(-1)]*G[{1}, yv^(-1)]*G[{0, yu, 1}, yv^(-1)])/16 - 
     (G[{0}, yw]*G[{1}, yv^(-1)]*G[{0, yu, 1}, yv^(-1)])/16 - 
     (G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*G[{0, yu, 1}, yv^(-1)])/8 - 
     (G[{0}, yu^(-1)]*G[{1}, yw]*G[{0, yu, 1}, yv^(-1)])/8 - 
     (G[{0}, yv^(-1)]*G[{1}, yw]*G[{0, yu, 1}, yv^(-1)])/8 + 
     (G[{0}, yw]*G[{1}, yw]*G[{0, yu, 1}, yv^(-1)])/8 + 
     (G[{1}, yv^(-1)]*G[{1}, yw]*G[{0, yu, 1}, yv^(-1)])/8 - 
     (G[{1}, yw]^2*G[{0, yu, 1}, yv^(-1)])/16 - 
     (G[{0}, yu^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, yu, 1}, yv^(-1)])/16 - 
     (G[{0}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, yu, 1}, yv^(-1)])/16 + 
     (G[{0}, yw]*G[{1/(yu*yv)}, yw]*G[{0, yu, 1}, yv^(-1)])/16 + 
     (G[{1}, yu^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, yu, 1}, yv^(-1)])/8 - 
     (G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{0, yu, 1}, yv^(-1)])/8 + 
     (G[{0, 1}, yu^(-1)]*G[{0, yu, 1}, yv^(-1)])/16 - 
     (G[{0, 1}, yw]*G[{0, yu, 1}, yv^(-1)])/16 + 
     (G[{0, yv^(-1)}, yw]*G[{0, yu, 1}, yv^(-1)])/8 - 
     (G[{0, 1/(yu*yv)}, yw]*G[{0, yu, 1}, yv^(-1)])/16 - 
     (G[{1, yv^(-1)}, yw]*G[{0, yu, 1}, yv^(-1)])/8 + 
     (G[{yv^(-1), 1/(yu*yv)}, yw]*G[{0, yu, 1}, yv^(-1)])/8 + 
     (Pi^2*G[{0, yu, yu}, yv^(-1)])/48 + 
     (5*G[{0}, yu^(-1)]^2*G[{0, yu, yu}, yv^(-1)])/32 + 
     (5*G[{0}, yu^(-1)]*G[{0}, yv^(-1)]*G[{0, yu, yu}, yv^(-1)])/16 + 
     (5*G[{0}, yv^(-1)]^2*G[{0, yu, yu}, yv^(-1)])/32 - 
     (5*G[{0}, yu^(-1)]*G[{0}, yw]*G[{0, yu, yu}, yv^(-1)])/16 - 
     (5*G[{0}, yv^(-1)]*G[{0}, yw]*G[{0, yu, yu}, yv^(-1)])/16 + 
     (5*G[{0}, yw]^2*G[{0, yu, yu}, yv^(-1)])/32 - 
     (G[{0}, yu^(-1)]*G[{1}, yu^(-1)]*G[{0, yu, yu}, yv^(-1)])/16 - 
     (G[{0}, yv^(-1)]*G[{1}, yu^(-1)]*G[{0, yu, yu}, yv^(-1)])/16 + 
     (G[{0}, yw]*G[{1}, yu^(-1)]*G[{0, yu, yu}, yv^(-1)])/16 - 
     (G[{1}, yu^(-1)]^2*G[{0, yu, yu}, yv^(-1)])/32 - 
     (3*G[{0}, yu^(-1)]*G[{1}, yv^(-1)]*G[{0, yu, yu}, yv^(-1)])/16 - 
     (3*G[{0}, yv^(-1)]*G[{1}, yv^(-1)]*G[{0, yu, yu}, yv^(-1)])/16 + 
     (3*G[{0}, yw]*G[{1}, yv^(-1)]*G[{0, yu, yu}, yv^(-1)])/16 + 
     (G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*G[{0, yu, yu}, yv^(-1)])/16 + 
     (G[{1}, yv^(-1)]^2*G[{0, yu, yu}, yv^(-1)])/16 + 
     (3*G[{0}, yu^(-1)]*G[{1}, yw]*G[{0, yu, yu}, yv^(-1)])/16 + 
     (3*G[{0}, yv^(-1)]*G[{1}, yw]*G[{0, yu, yu}, yv^(-1)])/16 - 
     (3*G[{0}, yw]*G[{1}, yw]*G[{0, yu, yu}, yv^(-1)])/16 - 
     (G[{1}, yu^(-1)]*G[{1}, yw]*G[{0, yu, yu}, yv^(-1)])/16 - 
     (G[{1}, yv^(-1)]*G[{1}, yw]*G[{0, yu, yu}, yv^(-1)])/8 + 
     (G[{1}, yw]^2*G[{0, yu, yu}, yv^(-1)])/32 + 
     (G[{1}, yw]*G[{yu}, yv^(-1)]*G[{0, yu, yu}, yv^(-1)])/16 + 
     (3*G[{0}, yu^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, yu, yu}, yv^(-1)])/16 + 
     (3*G[{0}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, yu, yu}, yv^(-1)])/16 - 
     (3*G[{0}, yw]*G[{1/(yu*yv)}, yw]*G[{0, yu, yu}, yv^(-1)])/16 - 
     (G[{1}, yu^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, yu, yu}, yv^(-1)])/16 - 
     (G[{1}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, yu, yu}, yv^(-1)])/8 + 
     (G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{0, yu, yu}, yv^(-1)])/16 + 
     (G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{0, yu, yu}, yv^(-1)])/8 - 
     (G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, yu, yu}, yv^(-1)])/16 + 
     (G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{0, yu, yu}, yv^(-1)])/16 + 
     (G[{0, 1}, yu^(-1)]*G[{0, yu, yu}, yv^(-1)])/8 - 
     (G[{0, 1}, yv^(-1)]*G[{0, yu, yu}, yv^(-1)])/8 + 
     (G[{0, 1}, yw]*G[{0, yu, yu}, yv^(-1)])/16 - 
     (3*G[{0, yu^(-1)}, yw]*G[{0, yu, yu}, yv^(-1)])/16 + 
     (G[{0, yu}, yv^(-1)]*G[{0, yu, yu}, yv^(-1)])/8 - 
     (G[{0, yv^(-1)}, yw]*G[{0, yu, yu}, yv^(-1)])/16 + 
     (3*G[{0, 1/(yu*yv)}, yw]*G[{0, yu, yu}, yv^(-1)])/16 + 
     (G[{1, yu}, yv^(-1)]*G[{0, yu, yu}, yv^(-1)])/16 + 
     (G[{1, yv^(-1)}, yw]*G[{0, yu, yu}, yv^(-1)])/16 - 
     (G[{1, 1/(yu*yv)}, yw]*G[{0, yu, yu}, yv^(-1)])/16 - 
     (G[{yu^(-1), 1/(yu*yv)}, yw]*G[{0, yu, yu}, yv^(-1)])/8 - 
     (G[{yv^(-1), 1/(yu*yv)}, yw]*G[{0, yu, yu}, yv^(-1)])/16 - 
     (19*Pi^2*G[{0, yv^(-1), 1}, yw])/768 - 
     (3*G[{0}, yu^(-1)]^2*G[{0, yv^(-1), 1}, yw])/32 - 
     (3*G[{0}, yu^(-1)]*G[{0}, yv^(-1)]*G[{0, yv^(-1), 1}, yw])/16 - 
     (3*G[{0}, yv^(-1)]^2*G[{0, yv^(-1), 1}, yw])/32 + 
     (3*G[{0}, yu^(-1)]*G[{0}, yw]*G[{0, yv^(-1), 1}, yw])/16 + 
     (3*G[{0}, yv^(-1)]*G[{0}, yw]*G[{0, yv^(-1), 1}, yw])/16 - 
     (3*G[{0}, yw]^2*G[{0, yv^(-1), 1}, yw])/32 + 
     (3*G[{0}, yu^(-1)]*G[{1}, yu^(-1)]*G[{0, yv^(-1), 1}, yw])/16 + 
     (3*G[{0}, yv^(-1)]*G[{1}, yu^(-1)]*G[{0, yv^(-1), 1}, yw])/16 - 
     (3*G[{0}, yw]*G[{1}, yu^(-1)]*G[{0, yv^(-1), 1}, yw])/16 - 
     (G[{1}, yu^(-1)]^2*G[{0, yv^(-1), 1}, yw])/8 - 
     (G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*G[{0, yv^(-1), 1}, yw])/8 + 
     (9*G[{1}, yv^(-1)]^2*G[{0, yv^(-1), 1}, yw])/128 - 
     (3*G[{0}, yu^(-1)]*G[{1}, yw]*G[{0, yv^(-1), 1}, yw])/16 - 
     (3*G[{0}, yv^(-1)]*G[{1}, yw]*G[{0, yv^(-1), 1}, yw])/16 + 
     (3*G[{0}, yw]*G[{1}, yw]*G[{0, yv^(-1), 1}, yw])/16 + 
     (G[{1}, yu^(-1)]*G[{1}, yw]*G[{0, yv^(-1), 1}, yw])/8 + 
     (13*G[{1}, yv^(-1)]*G[{1}, yw]*G[{0, yv^(-1), 1}, yw])/64 + 
     (G[{1}, yw]^2*G[{0, yv^(-1), 1}, yw])/128 + 
     (3*G[{0}, yu^(-1)]*G[{yu}, yv^(-1)]*G[{0, yv^(-1), 1}, yw])/16 + 
     (3*G[{0}, yv^(-1)]*G[{yu}, yv^(-1)]*G[{0, yv^(-1), 1}, yw])/16 - 
     (3*G[{0}, yw]*G[{yu}, yv^(-1)]*G[{0, yv^(-1), 1}, yw])/16 - 
     (G[{1}, yv^(-1)]*G[{yu}, yv^(-1)]*G[{0, yv^(-1), 1}, yw])/8 + 
     (3*G[{1}, yw]*G[{yu}, yv^(-1)]*G[{0, yv^(-1), 1}, yw])/64 - 
     (G[{yu}, yv^(-1)]^2*G[{0, yv^(-1), 1}, yw])/8 + 
     (G[{0}, yu^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, yv^(-1), 1}, yw])/16 + 
     (G[{0}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, yv^(-1), 1}, yw])/16 - 
     (G[{0}, yw]*G[{1/(yu*yv)}, yw]*G[{0, yv^(-1), 1}, yw])/16 - 
     (G[{1}, yu^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, yv^(-1), 1}, yw])/8 - 
     (G[{1}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, yv^(-1), 1}, yw])/64 - 
     (G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{0, yv^(-1), 1}, yw])/64 - 
     (5*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{0, yv^(-1), 1}, yw])/64 + 
     (G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, yv^(-1), 1}, yw])/64 + 
     (G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{0, yv^(-1), 1}, yw])/32 - 
     (G[{0, 1}, yu^(-1)]*G[{0, yv^(-1), 1}, yw])/8 - 
     (G[{0, 1}, yv^(-1)]*G[{0, yv^(-1), 1}, yw])/64 + 
     (G[{0, 1}, yw]*G[{0, yv^(-1), 1}, yw])/64 - 
     (G[{0, yu^(-1)}, yw]*G[{0, yv^(-1), 1}, yw])/64 + 
     (G[{0, yu}, yv^(-1)]*G[{0, yv^(-1), 1}, yw])/64 - 
     (G[{0, yv^(-1)}, yw]*G[{0, yv^(-1), 1}, yw])/64 - 
     (G[{0, 1/(yu*yv)}, yw]*G[{0, yv^(-1), 1}, yw])/32 + 
     (G[{1, yu^(-1)}, yw]*G[{0, yv^(-1), 1}, yw])/64 + 
     (7*G[{1, yu}, yv^(-1)]*G[{0, yv^(-1), 1}, yw])/64 + 
     (G[{1, yv^(-1)}, yw]*G[{0, yv^(-1), 1}, yw])/32 + 
     (G[{1, 1/(yu*yv)}, yw]*G[{0, yv^(-1), 1}, yw])/64 + 
     (5*G[{yu^(-1), 1/(yu*yv)}, yw]*G[{0, yv^(-1), 1}, yw])/64 - 
     (G[{yv^(-1), 1/(yu*yv)}, yw]*G[{0, yv^(-1), 1}, yw])/32 + 
     (3*Pi^2*G[{0, yv^(-1), yu^(-1)}, yw])/256 - 
     (3*G[{0}, yu^(-1)]^2*G[{0, yv^(-1), yu^(-1)}, yw])/64 - 
     (3*G[{0}, yu^(-1)]*G[{0}, yv^(-1)]*G[{0, yv^(-1), yu^(-1)}, yw])/32 - 
     (3*G[{0}, yv^(-1)]^2*G[{0, yv^(-1), yu^(-1)}, yw])/64 + 
     (3*G[{0}, yu^(-1)]*G[{0}, yw]*G[{0, yv^(-1), yu^(-1)}, yw])/32 + 
     (3*G[{0}, yv^(-1)]*G[{0}, yw]*G[{0, yv^(-1), yu^(-1)}, yw])/32 - 
     (3*G[{0}, yw]^2*G[{0, yv^(-1), yu^(-1)}, yw])/64 - 
     (G[{0}, yu^(-1)]*G[{1}, yu^(-1)]*G[{0, yv^(-1), yu^(-1)}, yw])/32 - 
     (G[{0}, yv^(-1)]*G[{1}, yu^(-1)]*G[{0, yv^(-1), yu^(-1)}, yw])/32 + 
     (G[{0}, yw]*G[{1}, yu^(-1)]*G[{0, yv^(-1), yu^(-1)}, yw])/32 + 
     (5*G[{1}, yu^(-1)]^2*G[{0, yv^(-1), yu^(-1)}, yw])/64 + 
     (7*G[{0}, yu^(-1)]*G[{1}, yv^(-1)]*G[{0, yv^(-1), yu^(-1)}, yw])/32 + 
     (7*G[{0}, yv^(-1)]*G[{1}, yv^(-1)]*G[{0, yv^(-1), yu^(-1)}, yw])/32 - 
     (7*G[{0}, yw]*G[{1}, yv^(-1)]*G[{0, yv^(-1), yu^(-1)}, yw])/32 - 
     (3*G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*G[{0, yv^(-1), yu^(-1)}, yw])/32 - 
     (G[{1}, yv^(-1)]^2*G[{0, yv^(-1), yu^(-1)}, yw])/8 + 
     (5*G[{0}, yu^(-1)]*G[{1}, yw]*G[{0, yv^(-1), yu^(-1)}, yw])/64 + 
     (5*G[{0}, yv^(-1)]*G[{1}, yw]*G[{0, yv^(-1), yu^(-1)}, yw])/64 - 
     (5*G[{0}, yw]*G[{1}, yw]*G[{0, yv^(-1), yu^(-1)}, yw])/64 - 
     (9*G[{1}, yu^(-1)]*G[{1}, yw]*G[{0, yv^(-1), yu^(-1)}, yw])/64 - 
     (3*G[{1}, yv^(-1)]*G[{1}, yw]*G[{0, yv^(-1), yu^(-1)}, yw])/64 + 
     (G[{1}, yw]^2*G[{0, yv^(-1), yu^(-1)}, yw])/8 + 
     (G[{1}, yw]*G[{yu}, yv^(-1)]*G[{0, yv^(-1), yu^(-1)}, yw])/32 - 
     (11*G[{0}, yu^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, yv^(-1), yu^(-1)}, yw])/
      64 - (11*G[{0}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, yv^(-1), yu^(-1)}, 
        yw])/64 + (11*G[{0}, yw]*G[{1/(yu*yv)}, yw]*G[{0, yv^(-1), yu^(-1)}, 
        yw])/64 + (7*G[{1}, yu^(-1)]*G[{1/(yu*yv)}, yw]*
       G[{0, yv^(-1), yu^(-1)}, yw])/64 + 
     (17*G[{1}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, yv^(-1), yu^(-1)}, yw])/
      64 - (G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{0, yv^(-1), yu^(-1)}, yw])/16 - 
     (3*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{0, yv^(-1), yu^(-1)}, yw])/
      32 - (G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, yv^(-1), yu^(-1)}, yw])/
      32 + (G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{0, yv^(-1), yu^(-1)}, yw])/
      16 - (3*G[{1/(yu*yv)}, yw]^2*G[{0, yv^(-1), yu^(-1)}, yw])/64 + 
     (G[{0, 1}, yu^(-1)]*G[{0, yv^(-1), yu^(-1)}, yw])/8 + 
     (G[{0, 1}, yv^(-1)]*G[{0, yv^(-1), yu^(-1)}, yw])/32 - 
     (G[{0, yu}, yv^(-1)]*G[{0, yv^(-1), yu^(-1)}, yw])/32 - 
     (G[{1, yu^(-1)}, yw]*G[{0, yv^(-1), yu^(-1)}, yw])/32 - 
     (3*G[{1, yu}, yv^(-1)]*G[{0, yv^(-1), yu^(-1)}, yw])/32 + 
     (G[{1, yv^(-1)}, yw]*G[{0, yv^(-1), yu^(-1)}, yw])/16 - 
     (G[{1, 1/(yu*yv)}, yw]*G[{0, yv^(-1), yu^(-1)}, yw])/32 + 
     (3*G[{yu^(-1), 1/(yu*yv)}, yw]*G[{0, yv^(-1), yu^(-1)}, yw])/32 - 
     (G[{yv^(-1), 1/(yu*yv)}, yw]*G[{0, yv^(-1), yu^(-1)}, yw])/16 + 
     (19*Pi^2*G[{0, yv^(-1), yv^(-1)}, yw])/256 + 
     (9*G[{0}, yu^(-1)]^2*G[{0, yv^(-1), yv^(-1)}, yw])/64 + 
     (9*G[{0}, yu^(-1)]*G[{0}, yv^(-1)]*G[{0, yv^(-1), yv^(-1)}, yw])/32 + 
     (9*G[{0}, yv^(-1)]^2*G[{0, yv^(-1), yv^(-1)}, yw])/64 - 
     (9*G[{0}, yu^(-1)]*G[{0}, yw]*G[{0, yv^(-1), yv^(-1)}, yw])/32 - 
     (9*G[{0}, yv^(-1)]*G[{0}, yw]*G[{0, yv^(-1), yv^(-1)}, yw])/32 + 
     (9*G[{0}, yw]^2*G[{0, yv^(-1), yv^(-1)}, yw])/64 - 
     (21*G[{0}, yu^(-1)]*G[{1}, yu^(-1)]*G[{0, yv^(-1), yv^(-1)}, yw])/32 - 
     (21*G[{0}, yv^(-1)]*G[{1}, yu^(-1)]*G[{0, yv^(-1), yv^(-1)}, yw])/32 + 
     (21*G[{0}, yw]*G[{1}, yu^(-1)]*G[{0, yv^(-1), yv^(-1)}, yw])/32 + 
     (29*G[{1}, yu^(-1)]^2*G[{0, yv^(-1), yv^(-1)}, yw])/64 + 
     (3*G[{0}, yu^(-1)]*G[{1}, yv^(-1)]*G[{0, yv^(-1), yv^(-1)}, yw])/32 + 
     (3*G[{0}, yv^(-1)]*G[{1}, yv^(-1)]*G[{0, yv^(-1), yv^(-1)}, yw])/32 - 
     (3*G[{0}, yw]*G[{1}, yv^(-1)]*G[{0, yv^(-1), yv^(-1)}, yw])/32 + 
     (13*G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*G[{0, yv^(-1), yv^(-1)}, yw])/32 - 
     (3*G[{1}, yv^(-1)]^2*G[{0, yv^(-1), yv^(-1)}, yw])/16 + 
     (17*G[{0}, yu^(-1)]*G[{1}, yw]*G[{0, yv^(-1), yv^(-1)}, yw])/64 + 
     (17*G[{0}, yv^(-1)]*G[{1}, yw]*G[{0, yv^(-1), yv^(-1)}, yw])/64 - 
     (17*G[{0}, yw]*G[{1}, yw]*G[{0, yv^(-1), yv^(-1)}, yw])/64 - 
     (33*G[{1}, yu^(-1)]*G[{1}, yw]*G[{0, yv^(-1), yv^(-1)}, yw])/64 - 
     (3*G[{1}, yv^(-1)]*G[{1}, yw]*G[{0, yv^(-1), yv^(-1)}, yw])/64 + 
     (G[{1}, yw]^2*G[{0, yv^(-1), yv^(-1)}, yw])/8 + 
     (G[{1}, yw]*G[{yu}, yv^(-1)]*G[{0, yv^(-1), yv^(-1)}, yw])/32 - 
     (7*G[{0}, yu^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, yv^(-1), yv^(-1)}, yw])/64 - 
     (7*G[{0}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, yv^(-1), yv^(-1)}, yw])/64 + 
     (7*G[{0}, yw]*G[{1/(yu*yv)}, yw]*G[{0, yv^(-1), yv^(-1)}, yw])/64 - 
     (G[{1}, yu^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, yv^(-1), yv^(-1)}, yw])/64 + 
     (17*G[{1}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, yv^(-1), yv^(-1)}, yw])/
      64 - (G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{0, yv^(-1), yv^(-1)}, yw])/16 - 
     (3*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{0, yv^(-1), yv^(-1)}, yw])/
      32 - (G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, yv^(-1), yv^(-1)}, yw])/
      32 + (G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{0, yv^(-1), yv^(-1)}, yw])/
      16 - (3*G[{1/(yu*yv)}, yw]^2*G[{0, yv^(-1), yv^(-1)}, yw])/64 + 
     (G[{0, 1}, yu^(-1)]*G[{0, yv^(-1), yv^(-1)}, yw])/4 + 
     (G[{0, 1}, yv^(-1)]*G[{0, yv^(-1), yv^(-1)}, yw])/32 - 
     (G[{0, 1}, yw]*G[{0, yv^(-1), yv^(-1)}, yw])/8 + 
     (G[{0, yu^(-1)}, yw]*G[{0, yv^(-1), yv^(-1)}, yw])/8 - 
     (G[{0, yu}, yv^(-1)]*G[{0, yv^(-1), yv^(-1)}, yw])/32 + 
     (G[{0, yv^(-1)}, yw]*G[{0, yv^(-1), yv^(-1)}, yw])/8 - 
     (G[{0, 1/(yu*yv)}, yw]*G[{0, yv^(-1), yv^(-1)}, yw])/16 - 
     (G[{1, yu^(-1)}, yw]*G[{0, yv^(-1), yv^(-1)}, yw])/32 - 
     (7*G[{1, yu}, yv^(-1)]*G[{0, yv^(-1), yv^(-1)}, yw])/32 + 
     (G[{1, yv^(-1)}, yw]*G[{0, yv^(-1), yv^(-1)}, yw])/16 - 
     (G[{1, 1/(yu*yv)}, yw]*G[{0, yv^(-1), yv^(-1)}, yw])/32 + 
     (3*G[{yu^(-1), 1/(yu*yv)}, yw]*G[{0, yv^(-1), yv^(-1)}, yw])/32 - 
     (G[{yv^(-1), 1/(yu*yv)}, yw]*G[{0, yv^(-1), yv^(-1)}, yw])/16 + 
     (5*Pi^2*G[{0, yv^(-1), 1/(yu*yv)}, yw])/768 + 
     (G[{0}, yu^(-1)]*G[{1}, yu^(-1)]*G[{0, yv^(-1), 1/(yu*yv)}, yw])/4 + 
     (G[{0}, yv^(-1)]*G[{1}, yu^(-1)]*G[{0, yv^(-1), 1/(yu*yv)}, yw])/4 - 
     (G[{0}, yw]*G[{1}, yu^(-1)]*G[{0, yv^(-1), 1/(yu*yv)}, yw])/4 - 
     (G[{1}, yu^(-1)]^2*G[{0, yv^(-1), 1/(yu*yv)}, yw])/4 - 
     (G[{0}, yu^(-1)]*G[{1}, yv^(-1)]*G[{0, yv^(-1), 1/(yu*yv)}, yw])/16 - 
     (G[{0}, yv^(-1)]*G[{1}, yv^(-1)]*G[{0, yv^(-1), 1/(yu*yv)}, yw])/16 + 
     (G[{0}, yw]*G[{1}, yv^(-1)]*G[{0, yv^(-1), 1/(yu*yv)}, yw])/16 + 
     (5*G[{1}, yv^(-1)]^2*G[{0, yv^(-1), 1/(yu*yv)}, yw])/128 + 
     (5*G[{1}, yv^(-1)]*G[{1}, yw]*G[{0, yv^(-1), 1/(yu*yv)}, yw])/64 + 
     (G[{1}, yw]^2*G[{0, yv^(-1), 1/(yu*yv)}, yw])/128 - 
     (3*G[{0}, yu^(-1)]*G[{yu}, yv^(-1)]*G[{0, yv^(-1), 1/(yu*yv)}, yw])/16 - 
     (3*G[{0}, yv^(-1)]*G[{yu}, yv^(-1)]*G[{0, yv^(-1), 1/(yu*yv)}, yw])/16 + 
     (3*G[{0}, yw]*G[{yu}, yv^(-1)]*G[{0, yv^(-1), 1/(yu*yv)}, yw])/16 + 
     (G[{1}, yv^(-1)]*G[{yu}, yv^(-1)]*G[{0, yv^(-1), 1/(yu*yv)}, yw])/8 - 
     (5*G[{1}, yw]*G[{yu}, yv^(-1)]*G[{0, yv^(-1), 1/(yu*yv)}, yw])/64 + 
     (G[{yu}, yv^(-1)]^2*G[{0, yv^(-1), 1/(yu*yv)}, yw])/8 + 
     (G[{0}, yu^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, yv^(-1), 1/(yu*yv)}, yw])/16 + 
     (G[{0}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, yv^(-1), 1/(yu*yv)}, yw])/16 - 
     (G[{0}, yw]*G[{1/(yu*yv)}, yw]*G[{0, yv^(-1), 1/(yu*yv)}, yw])/16 - 
     (G[{1}, yu^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, yv^(-1), 1/(yu*yv)}, yw])/8 - 
     (G[{1}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, yv^(-1), 1/(yu*yv)}, yw])/64 - 
     (G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{0, yv^(-1), 1/(yu*yv)}, yw])/64 - 
     (5*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{0, yv^(-1), 1/(yu*yv)}, yw])/
      64 + (G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, yv^(-1), 1/(yu*yv)}, 
        yw])/64 + (G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*
       G[{0, yv^(-1), 1/(yu*yv)}, yw])/32 + 
     (G[{0, 1}, yu^(-1)]*G[{0, yv^(-1), 1/(yu*yv)}, yw])/16 - 
     (G[{0, 1}, yv^(-1)]*G[{0, yv^(-1), 1/(yu*yv)}, yw])/64 - 
     (3*G[{0, 1}, yw]*G[{0, yv^(-1), 1/(yu*yv)}, yw])/64 + 
     (3*G[{0, yu^(-1)}, yw]*G[{0, yv^(-1), 1/(yu*yv)}, yw])/64 + 
     (G[{0, yu}, yv^(-1)]*G[{0, yv^(-1), 1/(yu*yv)}, yw])/64 + 
     (3*G[{0, yv^(-1)}, yw]*G[{0, yv^(-1), 1/(yu*yv)}, yw])/64 - 
     (G[{0, 1/(yu*yv)}, yw]*G[{0, yv^(-1), 1/(yu*yv)}, yw])/32 + 
     (G[{1, yu^(-1)}, yw]*G[{0, yv^(-1), 1/(yu*yv)}, yw])/64 - 
     (5*G[{1, yu}, yv^(-1)]*G[{0, yv^(-1), 1/(yu*yv)}, yw])/64 + 
     (G[{1, yv^(-1)}, yw]*G[{0, yv^(-1), 1/(yu*yv)}, yw])/32 + 
     (G[{1, 1/(yu*yv)}, yw]*G[{0, yv^(-1), 1/(yu*yv)}, yw])/64 + 
     (5*G[{yu^(-1), 1/(yu*yv)}, yw]*G[{0, yv^(-1), 1/(yu*yv)}, yw])/64 - 
     (G[{yv^(-1), 1/(yu*yv)}, yw]*G[{0, yv^(-1), 1/(yu*yv)}, yw])/32 + 
     (11*Pi^2*G[{0, 1/(yu*yv), 1}, yw])/768 + 
     (3*G[{0}, yu^(-1)]^2*G[{0, 1/(yu*yv), 1}, yw])/32 + 
     (3*G[{0}, yu^(-1)]*G[{0}, yv^(-1)]*G[{0, 1/(yu*yv), 1}, yw])/16 + 
     (3*G[{0}, yv^(-1)]^2*G[{0, 1/(yu*yv), 1}, yw])/32 - 
     (3*G[{0}, yu^(-1)]*G[{0}, yw]*G[{0, 1/(yu*yv), 1}, yw])/16 - 
     (3*G[{0}, yv^(-1)]*G[{0}, yw]*G[{0, 1/(yu*yv), 1}, yw])/16 + 
     (3*G[{0}, yw]^2*G[{0, 1/(yu*yv), 1}, yw])/32 - 
     (3*G[{0}, yu^(-1)]*G[{1}, yu^(-1)]*G[{0, 1/(yu*yv), 1}, yw])/16 - 
     (3*G[{0}, yv^(-1)]*G[{1}, yu^(-1)]*G[{0, 1/(yu*yv), 1}, yw])/16 + 
     (3*G[{0}, yw]*G[{1}, yu^(-1)]*G[{0, 1/(yu*yv), 1}, yw])/16 + 
     (G[{1}, yu^(-1)]^2*G[{0, 1/(yu*yv), 1}, yw])/8 - 
     (G[{0}, yu^(-1)]*G[{1}, yv^(-1)]*G[{0, 1/(yu*yv), 1}, yw])/16 - 
     (G[{0}, yv^(-1)]*G[{1}, yv^(-1)]*G[{0, 1/(yu*yv), 1}, yw])/16 + 
     (G[{0}, yw]*G[{1}, yv^(-1)]*G[{0, 1/(yu*yv), 1}, yw])/16 + 
     (G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*G[{0, 1/(yu*yv), 1}, yw])/8 - 
     (G[{1}, yv^(-1)]^2*G[{0, 1/(yu*yv), 1}, yw])/128 + 
     (3*G[{0}, yu^(-1)]*G[{1}, yw]*G[{0, 1/(yu*yv), 1}, yw])/16 + 
     (3*G[{0}, yv^(-1)]*G[{1}, yw]*G[{0, 1/(yu*yv), 1}, yw])/16 - 
     (3*G[{0}, yw]*G[{1}, yw]*G[{0, 1/(yu*yv), 1}, yw])/16 - 
     (G[{1}, yu^(-1)]*G[{1}, yw]*G[{0, 1/(yu*yv), 1}, yw])/8 - 
     (13*G[{1}, yv^(-1)]*G[{1}, yw]*G[{0, 1/(yu*yv), 1}, yw])/64 - 
     (G[{1}, yw]^2*G[{0, 1/(yu*yv), 1}, yw])/128 - 
     (G[{0}, yu^(-1)]*G[{yu}, yv^(-1)]*G[{0, 1/(yu*yv), 1}, yw])/8 - 
     (G[{0}, yv^(-1)]*G[{yu}, yv^(-1)]*G[{0, 1/(yu*yv), 1}, yw])/8 + 
     (G[{0}, yw]*G[{yu}, yv^(-1)]*G[{0, 1/(yu*yv), 1}, yw])/8 + 
     (G[{1}, yv^(-1)]*G[{yu}, yv^(-1)]*G[{0, 1/(yu*yv), 1}, yw])/8 - 
     (3*G[{1}, yw]*G[{yu}, yv^(-1)]*G[{0, 1/(yu*yv), 1}, yw])/64 + 
     (G[{yu}, yv^(-1)]^2*G[{0, 1/(yu*yv), 1}, yw])/16 + 
     (G[{1}, yu^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv), 1}, yw])/8 + 
     (G[{1}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv), 1}, yw])/64 + 
     (G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv), 1}, yw])/64 + 
     (5*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv), 1}, yw])/64 - 
     (9*G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv), 1}, yw])/64 - 
     (G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv), 1}, yw])/32 + 
     (G[{0, 1}, yu^(-1)]*G[{0, 1/(yu*yv), 1}, yw])/16 - 
     (3*G[{0, 1}, yv^(-1)]*G[{0, 1/(yu*yv), 1}, yw])/64 + 
     (3*G[{0, 1}, yw]*G[{0, 1/(yu*yv), 1}, yw])/64 - 
     (3*G[{0, yu^(-1)}, yw]*G[{0, 1/(yu*yv), 1}, yw])/64 + 
     (3*G[{0, yu}, yv^(-1)]*G[{0, 1/(yu*yv), 1}, yw])/64 - 
     (3*G[{0, yv^(-1)}, yw]*G[{0, 1/(yu*yv), 1}, yw])/64 + 
     (3*G[{0, 1/(yu*yv)}, yw]*G[{0, 1/(yu*yv), 1}, yw])/64 - 
     (G[{1, yu^(-1)}, yw]*G[{0, 1/(yu*yv), 1}, yw])/64 - 
     (7*G[{1, yu}, yv^(-1)]*G[{0, 1/(yu*yv), 1}, yw])/64 - 
     (G[{1, yv^(-1)}, yw]*G[{0, 1/(yu*yv), 1}, yw])/32 - 
     (G[{1, 1/(yu*yv)}, yw]*G[{0, 1/(yu*yv), 1}, yw])/64 - 
     (5*G[{yu^(-1), 1/(yu*yv)}, yw]*G[{0, 1/(yu*yv), 1}, yw])/64 + 
     (G[{yv^(-1), 1/(yu*yv)}, yw]*G[{0, 1/(yu*yv), 1}, yw])/32 + 
     (7*Pi^2*G[{0, 1/(yu*yv), yu^(-1)}, yw])/768 + 
     (3*G[{0}, yu^(-1)]^2*G[{0, 1/(yu*yv), yu^(-1)}, yw])/64 + 
     (3*G[{0}, yu^(-1)]*G[{0}, yv^(-1)]*G[{0, 1/(yu*yv), yu^(-1)}, yw])/32 + 
     (3*G[{0}, yv^(-1)]^2*G[{0, 1/(yu*yv), yu^(-1)}, yw])/64 - 
     (3*G[{0}, yu^(-1)]*G[{0}, yw]*G[{0, 1/(yu*yv), yu^(-1)}, yw])/32 - 
     (3*G[{0}, yv^(-1)]*G[{0}, yw]*G[{0, 1/(yu*yv), yu^(-1)}, yw])/32 + 
     (3*G[{0}, yw]^2*G[{0, 1/(yu*yv), yu^(-1)}, yw])/64 + 
     (G[{0}, yu^(-1)]*G[{1}, yu^(-1)]*G[{0, 1/(yu*yv), yu^(-1)}, yw])/32 + 
     (G[{0}, yv^(-1)]*G[{1}, yu^(-1)]*G[{0, 1/(yu*yv), yu^(-1)}, yw])/32 - 
     (G[{0}, yw]*G[{1}, yu^(-1)]*G[{0, 1/(yu*yv), yu^(-1)}, yw])/32 - 
     (5*G[{1}, yu^(-1)]^2*G[{0, 1/(yu*yv), yu^(-1)}, yw])/64 - 
     (3*G[{0}, yu^(-1)]*G[{1}, yv^(-1)]*G[{0, 1/(yu*yv), yu^(-1)}, yw])/32 - 
     (3*G[{0}, yv^(-1)]*G[{1}, yv^(-1)]*G[{0, 1/(yu*yv), yu^(-1)}, yw])/32 + 
     (3*G[{0}, yw]*G[{1}, yv^(-1)]*G[{0, 1/(yu*yv), yu^(-1)}, yw])/32 + 
     (3*G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*G[{0, 1/(yu*yv), yu^(-1)}, yw])/32 - 
     (5*G[{0}, yu^(-1)]*G[{1}, yw]*G[{0, 1/(yu*yv), yu^(-1)}, yw])/64 - 
     (5*G[{0}, yv^(-1)]*G[{1}, yw]*G[{0, 1/(yu*yv), yu^(-1)}, yw])/64 + 
     (5*G[{0}, yw]*G[{1}, yw]*G[{0, 1/(yu*yv), yu^(-1)}, yw])/64 + 
     (9*G[{1}, yu^(-1)]*G[{1}, yw]*G[{0, 1/(yu*yv), yu^(-1)}, yw])/64 + 
     (3*G[{1}, yv^(-1)]*G[{1}, yw]*G[{0, 1/(yu*yv), yu^(-1)}, yw])/64 - 
     (G[{1}, yw]^2*G[{0, 1/(yu*yv), yu^(-1)}, yw])/8 - 
     (G[{0}, yu^(-1)]*G[{yu}, yv^(-1)]*G[{0, 1/(yu*yv), yu^(-1)}, yw])/8 - 
     (G[{0}, yv^(-1)]*G[{yu}, yv^(-1)]*G[{0, 1/(yu*yv), yu^(-1)}, yw])/8 + 
     (G[{0}, yw]*G[{yu}, yv^(-1)]*G[{0, 1/(yu*yv), yu^(-1)}, yw])/8 - 
     (G[{1}, yw]*G[{yu}, yv^(-1)]*G[{0, 1/(yu*yv), yu^(-1)}, yw])/32 + 
     (G[{yu}, yv^(-1)]^2*G[{0, 1/(yu*yv), yu^(-1)}, yw])/8 + 
     (7*G[{0}, yu^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv), yu^(-1)}, yw])/
      64 + (7*G[{0}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv), yu^(-1)}, 
        yw])/64 - (7*G[{0}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv), yu^(-1)}, 
        yw])/64 - (7*G[{1}, yu^(-1)]*G[{1/(yu*yv)}, yw]*
       G[{0, 1/(yu*yv), yu^(-1)}, yw])/64 - 
     (9*G[{1}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv), yu^(-1)}, yw])/
      64 + (G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv), yu^(-1)}, yw])/
      16 + (3*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv), yu^(-1)}, 
        yw])/32 + (G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw]*
       G[{0, 1/(yu*yv), yu^(-1)}, yw])/32 - 
     (G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv), yu^(-1)}, yw])/
      16 + (3*G[{1/(yu*yv)}, yw]^2*G[{0, 1/(yu*yv), yu^(-1)}, yw])/64 + 
     (3*G[{0, 1}, yv^(-1)]*G[{0, 1/(yu*yv), yu^(-1)}, yw])/32 - 
     (G[{0, 1}, yw]*G[{0, 1/(yu*yv), yu^(-1)}, yw])/8 + 
     (G[{0, yu^(-1)}, yw]*G[{0, 1/(yu*yv), yu^(-1)}, yw])/8 - 
     (3*G[{0, yu}, yv^(-1)]*G[{0, 1/(yu*yv), yu^(-1)}, yw])/32 + 
     (G[{0, yv^(-1)}, yw]*G[{0, 1/(yu*yv), yu^(-1)}, yw])/8 - 
     (G[{0, 1/(yu*yv)}, yw]*G[{0, 1/(yu*yv), yu^(-1)}, yw])/8 + 
     (G[{1, yu^(-1)}, yw]*G[{0, 1/(yu*yv), yu^(-1)}, yw])/32 + 
     (3*G[{1, yu}, yv^(-1)]*G[{0, 1/(yu*yv), yu^(-1)}, yw])/32 - 
     (G[{1, yv^(-1)}, yw]*G[{0, 1/(yu*yv), yu^(-1)}, yw])/16 + 
     (G[{1, 1/(yu*yv)}, yw]*G[{0, 1/(yu*yv), yu^(-1)}, yw])/32 - 
     (3*G[{yu^(-1), 1/(yu*yv)}, yw]*G[{0, 1/(yu*yv), yu^(-1)}, yw])/32 + 
     (G[{yv^(-1), 1/(yu*yv)}, yw]*G[{0, 1/(yu*yv), yu^(-1)}, yw])/16 - 
     (11*Pi^2*G[{0, 1/(yu*yv), yv^(-1)}, yw])/256 - 
     (3*G[{0}, yu^(-1)]^2*G[{0, 1/(yu*yv), yv^(-1)}, yw])/64 - 
     (3*G[{0}, yu^(-1)]*G[{0}, yv^(-1)]*G[{0, 1/(yu*yv), yv^(-1)}, yw])/32 - 
     (3*G[{0}, yv^(-1)]^2*G[{0, 1/(yu*yv), yv^(-1)}, yw])/64 + 
     (3*G[{0}, yu^(-1)]*G[{0}, yw]*G[{0, 1/(yu*yv), yv^(-1)}, yw])/32 + 
     (3*G[{0}, yv^(-1)]*G[{0}, yw]*G[{0, 1/(yu*yv), yv^(-1)}, yw])/32 - 
     (3*G[{0}, yw]^2*G[{0, 1/(yu*yv), yv^(-1)}, yw])/64 + 
     (11*G[{0}, yu^(-1)]*G[{1}, yu^(-1)]*G[{0, 1/(yu*yv), yv^(-1)}, yw])/32 + 
     (11*G[{0}, yv^(-1)]*G[{1}, yu^(-1)]*G[{0, 1/(yu*yv), yv^(-1)}, yw])/32 - 
     (11*G[{0}, yw]*G[{1}, yu^(-1)]*G[{0, 1/(yu*yv), yv^(-1)}, yw])/32 - 
     (17*G[{1}, yu^(-1)]^2*G[{0, 1/(yu*yv), yv^(-1)}, yw])/64 - 
     (5*G[{0}, yu^(-1)]*G[{1}, yv^(-1)]*G[{0, 1/(yu*yv), yv^(-1)}, yw])/32 - 
     (5*G[{0}, yv^(-1)]*G[{1}, yv^(-1)]*G[{0, 1/(yu*yv), yv^(-1)}, yw])/32 + 
     (5*G[{0}, yw]*G[{1}, yv^(-1)]*G[{0, 1/(yu*yv), yv^(-1)}, yw])/32 - 
     (5*G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*G[{0, 1/(yu*yv), yv^(-1)}, yw])/32 + 
     (5*G[{1}, yv^(-1)]^2*G[{0, 1/(yu*yv), yv^(-1)}, yw])/32 - 
     (9*G[{0}, yu^(-1)]*G[{1}, yw]*G[{0, 1/(yu*yv), yv^(-1)}, yw])/64 - 
     (9*G[{0}, yv^(-1)]*G[{1}, yw]*G[{0, 1/(yu*yv), yv^(-1)}, yw])/64 + 
     (9*G[{0}, yw]*G[{1}, yw]*G[{0, 1/(yu*yv), yv^(-1)}, yw])/64 + 
     (17*G[{1}, yu^(-1)]*G[{1}, yw]*G[{0, 1/(yu*yv), yv^(-1)}, yw])/64 + 
     (3*G[{1}, yv^(-1)]*G[{1}, yw]*G[{0, 1/(yu*yv), yv^(-1)}, yw])/64 - 
     (G[{1}, yw]^2*G[{0, 1/(yu*yv), yv^(-1)}, yw])/8 - 
     (G[{1}, yw]*G[{yu}, yv^(-1)]*G[{0, 1/(yu*yv), yv^(-1)}, yw])/32 + 
     (7*G[{0}, yu^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv), yv^(-1)}, yw])/
      64 + (7*G[{0}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv), yv^(-1)}, 
        yw])/64 - (7*G[{0}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv), yv^(-1)}, 
        yw])/64 + (G[{1}, yu^(-1)]*G[{1/(yu*yv)}, yw]*
       G[{0, 1/(yu*yv), yv^(-1)}, yw])/64 - 
     (17*G[{1}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv), yv^(-1)}, yw])/
      64 + (G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv), yv^(-1)}, yw])/
      16 + (3*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv), yv^(-1)}, 
        yw])/32 + (G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw]*
       G[{0, 1/(yu*yv), yv^(-1)}, yw])/32 - 
     (G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv), yv^(-1)}, yw])/
      16 + (3*G[{1/(yu*yv)}, yw]^2*G[{0, 1/(yu*yv), yv^(-1)}, yw])/64 - 
     (3*G[{0, 1}, yu^(-1)]*G[{0, 1/(yu*yv), yv^(-1)}, yw])/16 - 
     (G[{0, 1}, yv^(-1)]*G[{0, 1/(yu*yv), yv^(-1)}, yw])/32 + 
     (G[{0, 1}, yw]*G[{0, 1/(yu*yv), yv^(-1)}, yw])/16 - 
     (G[{0, yu^(-1)}, yw]*G[{0, 1/(yu*yv), yv^(-1)}, yw])/16 + 
     (G[{0, yu}, yv^(-1)]*G[{0, 1/(yu*yv), yv^(-1)}, yw])/32 - 
     (G[{0, yv^(-1)}, yw]*G[{0, 1/(yu*yv), yv^(-1)}, yw])/16 + 
     (G[{0, 1/(yu*yv)}, yw]*G[{0, 1/(yu*yv), yv^(-1)}, yw])/16 + 
     (G[{1, yu^(-1)}, yw]*G[{0, 1/(yu*yv), yv^(-1)}, yw])/32 + 
     (5*G[{1, yu}, yv^(-1)]*G[{0, 1/(yu*yv), yv^(-1)}, yw])/32 - 
     (G[{1, yv^(-1)}, yw]*G[{0, 1/(yu*yv), yv^(-1)}, yw])/16 + 
     (G[{1, 1/(yu*yv)}, yw]*G[{0, 1/(yu*yv), yv^(-1)}, yw])/32 - 
     (3*G[{yu^(-1), 1/(yu*yv)}, yw]*G[{0, 1/(yu*yv), yv^(-1)}, yw])/32 + 
     (G[{yv^(-1), 1/(yu*yv)}, yw]*G[{0, 1/(yu*yv), yv^(-1)}, yw])/16 - 
     (13*Pi^2*G[{0, 1/(yu*yv), 1/(yu*yv)}, yw])/768 - 
     (3*G[{0}, yu^(-1)]^2*G[{0, 1/(yu*yv), 1/(yu*yv)}, yw])/32 - 
     (3*G[{0}, yu^(-1)]*G[{0}, yv^(-1)]*G[{0, 1/(yu*yv), 1/(yu*yv)}, yw])/
      16 - (3*G[{0}, yv^(-1)]^2*G[{0, 1/(yu*yv), 1/(yu*yv)}, yw])/32 + 
     (3*G[{0}, yu^(-1)]*G[{0}, yw]*G[{0, 1/(yu*yv), 1/(yu*yv)}, yw])/16 + 
     (3*G[{0}, yv^(-1)]*G[{0}, yw]*G[{0, 1/(yu*yv), 1/(yu*yv)}, yw])/16 - 
     (3*G[{0}, yw]^2*G[{0, 1/(yu*yv), 1/(yu*yv)}, yw])/32 + 
     (G[{0}, yu^(-1)]*G[{1}, yu^(-1)]*G[{0, 1/(yu*yv), 1/(yu*yv)}, yw])/16 + 
     (G[{0}, yv^(-1)]*G[{1}, yu^(-1)]*G[{0, 1/(yu*yv), 1/(yu*yv)}, yw])/16 - 
     (G[{0}, yw]*G[{1}, yu^(-1)]*G[{0, 1/(yu*yv), 1/(yu*yv)}, yw])/16 + 
     (G[{1}, yu^(-1)]^2*G[{0, 1/(yu*yv), 1/(yu*yv)}, yw])/16 + 
     (G[{0}, yu^(-1)]*G[{1}, yv^(-1)]*G[{0, 1/(yu*yv), 1/(yu*yv)}, yw])/4 + 
     (G[{0}, yv^(-1)]*G[{1}, yv^(-1)]*G[{0, 1/(yu*yv), 1/(yu*yv)}, yw])/4 - 
     (G[{0}, yw]*G[{1}, yv^(-1)]*G[{0, 1/(yu*yv), 1/(yu*yv)}, yw])/4 - 
     (G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*G[{0, 1/(yu*yv), 1/(yu*yv)}, yw])/4 - 
     (17*G[{1}, yv^(-1)]^2*G[{0, 1/(yu*yv), 1/(yu*yv)}, yw])/128 - 
     (G[{0}, yu^(-1)]*G[{1}, yw]*G[{0, 1/(yu*yv), 1/(yu*yv)}, yw])/8 - 
     (G[{0}, yv^(-1)]*G[{1}, yw]*G[{0, 1/(yu*yv), 1/(yu*yv)}, yw])/8 + 
     (G[{0}, yw]*G[{1}, yw]*G[{0, 1/(yu*yv), 1/(yu*yv)}, yw])/8 + 
     (G[{1}, yu^(-1)]*G[{1}, yw]*G[{0, 1/(yu*yv), 1/(yu*yv)}, yw])/4 + 
     (11*G[{1}, yv^(-1)]*G[{1}, yw]*G[{0, 1/(yu*yv), 1/(yu*yv)}, yw])/64 - 
     (G[{1}, yw]^2*G[{0, 1/(yu*yv), 1/(yu*yv)}, yw])/128 + 
     (G[{0}, yu^(-1)]*G[{yu}, yv^(-1)]*G[{0, 1/(yu*yv), 1/(yu*yv)}, yw])/16 + 
     (G[{0}, yv^(-1)]*G[{yu}, yv^(-1)]*G[{0, 1/(yu*yv), 1/(yu*yv)}, yw])/16 - 
     (G[{0}, yw]*G[{yu}, yv^(-1)]*G[{0, 1/(yu*yv), 1/(yu*yv)}, yw])/16 + 
     (G[{1}, yv^(-1)]*G[{yu}, yv^(-1)]*G[{0, 1/(yu*yv), 1/(yu*yv)}, yw])/8 - 
     (11*G[{1}, yw]*G[{yu}, yv^(-1)]*G[{0, 1/(yu*yv), 1/(yu*yv)}, yw])/64 - 
     (G[{yu}, yv^(-1)]^2*G[{0, 1/(yu*yv), 1/(yu*yv)}, yw])/8 - 
     (G[{0}, yu^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv), 1/(yu*yv)}, yw])/
      16 - (G[{0}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv), 1/(yu*yv)}, 
        yw])/16 + (G[{0}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv), 1/(yu*yv)}, 
        yw])/16 + (G[{1}, yu^(-1)]*G[{1/(yu*yv)}, yw]*
       G[{0, 1/(yu*yv), 1/(yu*yv)}, yw])/8 + 
     (G[{1}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv), 1/(yu*yv)}, yw])/
      64 + (G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv), 1/(yu*yv)}, yw])/
      64 + (5*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*
       G[{0, 1/(yu*yv), 1/(yu*yv)}, yw])/64 - 
     (G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv), 1/(yu*yv)}, yw])/
      64 - (G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv), 1/(yu*yv)}, 
        yw])/32 - (7*G[{0, 1}, yv^(-1)]*G[{0, 1/(yu*yv), 1/(yu*yv)}, yw])/
      64 - (G[{0, 1}, yw]*G[{0, 1/(yu*yv), 1/(yu*yv)}, yw])/64 + 
     (G[{0, yu^(-1)}, yw]*G[{0, 1/(yu*yv), 1/(yu*yv)}, yw])/64 + 
     (7*G[{0, yu}, yv^(-1)]*G[{0, 1/(yu*yv), 1/(yu*yv)}, yw])/64 + 
     (G[{0, yv^(-1)}, yw]*G[{0, 1/(yu*yv), 1/(yu*yv)}, yw])/64 - 
     (G[{0, 1/(yu*yv)}, yw]*G[{0, 1/(yu*yv), 1/(yu*yv)}, yw])/64 - 
     (G[{1, yu^(-1)}, yw]*G[{0, 1/(yu*yv), 1/(yu*yv)}, yw])/64 - 
     (7*G[{1, yu}, yv^(-1)]*G[{0, 1/(yu*yv), 1/(yu*yv)}, yw])/64 - 
     (G[{1, yv^(-1)}, yw]*G[{0, 1/(yu*yv), 1/(yu*yv)}, yw])/32 - 
     (G[{1, 1/(yu*yv)}, yw]*G[{0, 1/(yu*yv), 1/(yu*yv)}, yw])/64 - 
     (5*G[{yu^(-1), 1/(yu*yv)}, yw]*G[{0, 1/(yu*yv), 1/(yu*yv)}, yw])/64 + 
     (G[{yv^(-1), 1/(yu*yv)}, yw]*G[{0, 1/(yu*yv), 1/(yu*yv)}, yw])/32 + 
     (5*Pi^2*G[{1, 1, yu^(-1)}, yw])/768 - 
     (G[{0}, yu^(-1)]^2*G[{1, 1, yu^(-1)}, yw])/32 - 
     (G[{0}, yu^(-1)]*G[{0}, yv^(-1)]*G[{1, 1, yu^(-1)}, yw])/16 - 
     (G[{0}, yv^(-1)]^2*G[{1, 1, yu^(-1)}, yw])/32 + 
     (G[{0}, yu^(-1)]*G[{0}, yw]*G[{1, 1, yu^(-1)}, yw])/16 + 
     (G[{0}, yv^(-1)]*G[{0}, yw]*G[{1, 1, yu^(-1)}, yw])/16 - 
     (G[{0}, yw]^2*G[{1, 1, yu^(-1)}, yw])/32 + 
     (G[{0}, yu^(-1)]*G[{1}, yu^(-1)]*G[{1, 1, yu^(-1)}, yw])/16 + 
     (G[{0}, yv^(-1)]*G[{1}, yu^(-1)]*G[{1, 1, yu^(-1)}, yw])/16 - 
     (G[{0}, yw]*G[{1}, yu^(-1)]*G[{1, 1, yu^(-1)}, yw])/16 - 
     (G[{1}, yu^(-1)]^2*G[{1, 1, yu^(-1)}, yw])/32 + 
     (3*G[{0}, yu^(-1)]*G[{1}, yv^(-1)]*G[{1, 1, yu^(-1)}, yw])/16 + 
     (3*G[{0}, yv^(-1)]*G[{1}, yv^(-1)]*G[{1, 1, yu^(-1)}, yw])/16 - 
     (3*G[{0}, yw]*G[{1}, yv^(-1)]*G[{1, 1, yu^(-1)}, yw])/16 - 
     (G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*G[{1, 1, yu^(-1)}, yw])/16 - 
     (23*G[{1}, yv^(-1)]^2*G[{1, 1, yu^(-1)}, yw])/128 + 
     (5*G[{0}, yu^(-1)]*G[{1}, yw]*G[{1, 1, yu^(-1)}, yw])/64 + 
     (5*G[{0}, yv^(-1)]*G[{1}, yw]*G[{1, 1, yu^(-1)}, yw])/64 - 
     (5*G[{0}, yw]*G[{1}, yw]*G[{1, 1, yu^(-1)}, yw])/64 - 
     (5*G[{1}, yu^(-1)]*G[{1}, yw]*G[{1, 1, yu^(-1)}, yw])/64 - 
     (G[{1}, yv^(-1)]*G[{1}, yw]*G[{1, 1, yu^(-1)}, yw])/8 - 
     (3*G[{1}, yw]^2*G[{1, 1, yu^(-1)}, yw])/128 - 
     (G[{0}, yu^(-1)]*G[{yu}, yv^(-1)]*G[{1, 1, yu^(-1)}, yw])/8 - 
     (G[{0}, yv^(-1)]*G[{yu}, yv^(-1)]*G[{1, 1, yu^(-1)}, yw])/8 + 
     (G[{0}, yw]*G[{yu}, yv^(-1)]*G[{1, 1, yu^(-1)}, yw])/8 + 
     (5*G[{1}, yv^(-1)]*G[{yu}, yv^(-1)]*G[{1, 1, yu^(-1)}, yw])/16 + 
     (3*G[{1}, yw]*G[{yu}, yv^(-1)]*G[{1, 1, yu^(-1)}, yw])/64 - 
     (G[{yu}, yv^(-1)]^2*G[{1, 1, yu^(-1)}, yw])/32 + 
     (7*G[{1}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{1, 1, yu^(-1)}, yw])/64 + 
     (7*G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{1, 1, yu^(-1)}, yw])/64 - 
     (5*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{1, 1, yu^(-1)}, yw])/64 - 
     (7*G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{1, 1, yu^(-1)}, yw])/64 - 
     (3*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{1, 1, yu^(-1)}, yw])/32 + 
     (G[{0, 1}, yu^(-1)]*G[{1, 1, yu^(-1)}, yw])/8 - 
     (9*G[{0, 1}, yv^(-1)]*G[{1, 1, yu^(-1)}, yw])/64 - 
     (3*G[{0, 1}, yw]*G[{1, 1, yu^(-1)}, yw])/64 + 
     (3*G[{0, yu^(-1)}, yw]*G[{1, 1, yu^(-1)}, yw])/64 + 
     (9*G[{0, yu}, yv^(-1)]*G[{1, 1, yu^(-1)}, yw])/64 + 
     (3*G[{0, yv^(-1)}, yw]*G[{1, 1, yu^(-1)}, yw])/64 - 
     (3*G[{0, 1/(yu*yv)}, yw]*G[{1, 1, yu^(-1)}, yw])/64 + 
     (G[{1, yu^(-1)}, yw]*G[{1, 1, yu^(-1)}, yw])/64 - 
     (17*G[{1, yu}, yv^(-1)]*G[{1, 1, yu^(-1)}, yw])/64 - 
     (3*G[{1, yv^(-1)}, yw]*G[{1, 1, yu^(-1)}, yw])/32 + 
     (G[{1, 1/(yu*yv)}, yw]*G[{1, 1, yu^(-1)}, yw])/64 + 
     (5*G[{yu^(-1), 1/(yu*yv)}, yw]*G[{1, 1, yu^(-1)}, yw])/64 + 
     (3*G[{yv^(-1), 1/(yu*yv)}, yw]*G[{1, 1, yu^(-1)}, yw])/32 + 
     (Pi^2*G[{1, 1, yu}, yv^(-1)])/48 - 
     (G[{0}, yu^(-1)]^2*G[{1, 1, yu}, yv^(-1)])/32 - 
     (G[{0}, yu^(-1)]*G[{0}, yv^(-1)]*G[{1, 1, yu}, yv^(-1)])/16 - 
     (G[{0}, yv^(-1)]^2*G[{1, 1, yu}, yv^(-1)])/32 + 
     (G[{0}, yu^(-1)]*G[{0}, yw]*G[{1, 1, yu}, yv^(-1)])/16 + 
     (G[{0}, yv^(-1)]*G[{0}, yw]*G[{1, 1, yu}, yv^(-1)])/16 - 
     (G[{0}, yw]^2*G[{1, 1, yu}, yv^(-1)])/32 - 
     (G[{0}, yu^(-1)]*G[{1}, yu^(-1)]*G[{1, 1, yu}, yv^(-1)])/8 - 
     (G[{0}, yv^(-1)]*G[{1}, yu^(-1)]*G[{1, 1, yu}, yv^(-1)])/8 + 
     (G[{0}, yw]*G[{1}, yu^(-1)]*G[{1, 1, yu}, yv^(-1)])/8 + 
     (G[{1}, yu^(-1)]^2*G[{1, 1, yu}, yv^(-1)])/16 + 
     (G[{0}, yu^(-1)]*G[{1}, yv^(-1)]*G[{1, 1, yu}, yv^(-1)])/8 + 
     (G[{0}, yv^(-1)]*G[{1}, yv^(-1)]*G[{1, 1, yu}, yv^(-1)])/8 - 
     (G[{0}, yw]*G[{1}, yv^(-1)]*G[{1, 1, yu}, yv^(-1)])/8 + 
     (G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*G[{1, 1, yu}, yv^(-1)])/8 - 
     (3*G[{1}, yv^(-1)]^2*G[{1, 1, yu}, yv^(-1)])/32 - 
     (G[{0}, yu^(-1)]*G[{1}, yw]*G[{1, 1, yu}, yv^(-1)])/16 - 
     (G[{0}, yv^(-1)]*G[{1}, yw]*G[{1, 1, yu}, yv^(-1)])/16 + 
     (G[{0}, yw]*G[{1}, yw]*G[{1, 1, yu}, yv^(-1)])/16 - 
     (5*G[{1}, yu^(-1)]*G[{1}, yw]*G[{1, 1, yu}, yv^(-1)])/16 + 
     (G[{1}, yv^(-1)]*G[{1}, yw]*G[{1, 1, yu}, yv^(-1)])/8 - 
     (G[{1}, yw]^2*G[{1, 1, yu}, yv^(-1)])/32 - 
     (G[{1}, yw]*G[{yu}, yv^(-1)]*G[{1, 1, yu}, yv^(-1)])/16 - 
     (G[{0}, yu^(-1)]*G[{1/(yu*yv)}, yw]*G[{1, 1, yu}, yv^(-1)])/16 - 
     (G[{0}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{1, 1, yu}, yv^(-1)])/16 + 
     (G[{0}, yw]*G[{1/(yu*yv)}, yw]*G[{1, 1, yu}, yv^(-1)])/16 + 
     (G[{1}, yu^(-1)]*G[{1/(yu*yv)}, yw]*G[{1, 1, yu}, yv^(-1)])/16 + 
     (G[{1}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{1, 1, yu}, yv^(-1)])/8 - 
     (G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{1, 1, yu}, yv^(-1)])/16 + 
     (G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{1, 1, yu}, yv^(-1)])/16 - 
     (G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{1, 1, yu}, yv^(-1)])/16 + 
     (G[{0, yv^(-1)}, yw]*G[{1, 1, yu}, yv^(-1)])/16 - 
     (G[{0, 1/(yu*yv)}, yw]*G[{1, 1, yu}, yv^(-1)])/16 - 
     (G[{1, yu}, yv^(-1)]*G[{1, 1, yu}, yv^(-1)])/16 - 
     (G[{1, yv^(-1)}, yw]*G[{1, 1, yu}, yv^(-1)])/16 + 
     (G[{1, 1/(yu*yv)}, yw]*G[{1, 1, yu}, yv^(-1)])/16 + 
     (G[{yv^(-1), 1/(yu*yv)}, yw]*G[{1, 1, yu}, yv^(-1)])/16 - 
     (43*Pi^2*G[{1, 1, yv^(-1)}, yw])/768 - 
     (3*G[{0}, yu^(-1)]^2*G[{1, 1, yv^(-1)}, yw])/16 - 
     (3*G[{0}, yu^(-1)]*G[{0}, yv^(-1)]*G[{1, 1, yv^(-1)}, yw])/8 - 
     (3*G[{0}, yv^(-1)]^2*G[{1, 1, yv^(-1)}, yw])/16 + 
     (3*G[{0}, yu^(-1)]*G[{0}, yw]*G[{1, 1, yv^(-1)}, yw])/8 + 
     (3*G[{0}, yv^(-1)]*G[{0}, yw]*G[{1, 1, yv^(-1)}, yw])/8 - 
     (3*G[{0}, yw]^2*G[{1, 1, yv^(-1)}, yw])/16 + 
     (5*G[{0}, yu^(-1)]*G[{1}, yu^(-1)]*G[{1, 1, yv^(-1)}, yw])/16 + 
     (5*G[{0}, yv^(-1)]*G[{1}, yu^(-1)]*G[{1, 1, yv^(-1)}, yw])/16 - 
     (5*G[{0}, yw]*G[{1}, yu^(-1)]*G[{1, 1, yv^(-1)}, yw])/16 - 
     (5*G[{1}, yu^(-1)]^2*G[{1, 1, yv^(-1)}, yw])/32 + 
     (G[{0}, yu^(-1)]*G[{1}, yv^(-1)]*G[{1, 1, yv^(-1)}, yw])/16 + 
     (G[{0}, yv^(-1)]*G[{1}, yv^(-1)]*G[{1, 1, yv^(-1)}, yw])/16 - 
     (G[{0}, yw]*G[{1}, yv^(-1)]*G[{1, 1, yv^(-1)}, yw])/16 - 
     (5*G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*G[{1, 1, yv^(-1)}, yw])/16 + 
     (13*G[{1}, yv^(-1)]^2*G[{1, 1, yv^(-1)}, yw])/128 - 
     (19*G[{0}, yu^(-1)]*G[{1}, yw]*G[{1, 1, yv^(-1)}, yw])/64 - 
     (19*G[{0}, yv^(-1)]*G[{1}, yw]*G[{1, 1, yv^(-1)}, yw])/64 + 
     (19*G[{0}, yw]*G[{1}, yw]*G[{1, 1, yv^(-1)}, yw])/64 + 
     (11*G[{1}, yu^(-1)]*G[{1}, yw]*G[{1, 1, yv^(-1)}, yw])/64 + 
     (3*G[{1}, yv^(-1)]*G[{1}, yw]*G[{1, 1, yv^(-1)}, yw])/16 - 
     (15*G[{1}, yw]^2*G[{1, 1, yv^(-1)}, yw])/128 + 
     (3*G[{0}, yu^(-1)]*G[{yu}, yv^(-1)]*G[{1, 1, yv^(-1)}, yw])/8 + 
     (3*G[{0}, yv^(-1)]*G[{yu}, yv^(-1)]*G[{1, 1, yv^(-1)}, yw])/8 - 
     (3*G[{0}, yw]*G[{yu}, yv^(-1)]*G[{1, 1, yv^(-1)}, yw])/8 - 
     (G[{1}, yv^(-1)]*G[{yu}, yv^(-1)]*G[{1, 1, yv^(-1)}, yw])/4 + 
     (15*G[{1}, yw]*G[{yu}, yv^(-1)]*G[{1, 1, yv^(-1)}, yw])/64 - 
     (G[{yu}, yv^(-1)]^2*G[{1, 1, yv^(-1)}, yw])/4 + 
     (3*G[{0}, yu^(-1)]*G[{1/(yu*yv)}, yw]*G[{1, 1, yv^(-1)}, yw])/8 + 
     (3*G[{0}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{1, 1, yv^(-1)}, yw])/8 - 
     (3*G[{0}, yw]*G[{1/(yu*yv)}, yw]*G[{1, 1, yv^(-1)}, yw])/8 - 
     (5*G[{1}, yu^(-1)]*G[{1/(yu*yv)}, yw]*G[{1, 1, yv^(-1)}, yw])/16 - 
     (17*G[{1}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{1, 1, yv^(-1)}, yw])/64 + 
     (11*G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{1, 1, yv^(-1)}, yw])/64 + 
     (11*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{1, 1, yv^(-1)}, yw])/64 - 
     (11*G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{1, 1, yv^(-1)}, yw])/64 + 
     (11*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{1, 1, yv^(-1)}, yw])/32 - 
     (G[{0, 1}, yu^(-1)]*G[{1, 1, yv^(-1)}, yw])/4 - 
     (G[{0, 1}, yv^(-1)]*G[{1, 1, yv^(-1)}, yw])/64 + 
     (5*G[{0, 1}, yw]*G[{1, 1, yv^(-1)}, yw])/64 - 
     (5*G[{0, yu^(-1)}, yw]*G[{1, 1, yv^(-1)}, yw])/64 + 
     (G[{0, yu}, yv^(-1)]*G[{1, 1, yv^(-1)}, yw])/64 - 
     (5*G[{0, yv^(-1)}, yw]*G[{1, 1, yv^(-1)}, yw])/64 + 
     (5*G[{0, 1/(yu*yv)}, yw]*G[{1, 1, yv^(-1)}, yw])/64 + 
     (G[{1, yu^(-1)}, yw]*G[{1, 1, yv^(-1)}, yw])/64 + 
     (15*G[{1, yu}, yv^(-1)]*G[{1, 1, yv^(-1)}, yw])/64 + 
     (11*G[{1, yv^(-1)}, yw]*G[{1, 1, yv^(-1)}, yw])/32 - 
     (3*G[{1, 1/(yu*yv)}, yw]*G[{1, 1, yv^(-1)}, yw])/64 - 
     (11*G[{yu^(-1), 1/(yu*yv)}, yw]*G[{1, 1, yv^(-1)}, yw])/64 - 
     (11*G[{yv^(-1), 1/(yu*yv)}, yw]*G[{1, 1, yv^(-1)}, yw])/32 + 
     (Pi^2*G[{1, 1, 1/(yu*yv)}, yw])/48 + 
     (7*G[{0}, yu^(-1)]^2*G[{1, 1, 1/(yu*yv)}, yw])/32 + 
     (7*G[{0}, yu^(-1)]*G[{0}, yv^(-1)]*G[{1, 1, 1/(yu*yv)}, yw])/16 + 
     (7*G[{0}, yv^(-1)]^2*G[{1, 1, 1/(yu*yv)}, yw])/32 - 
     (7*G[{0}, yu^(-1)]*G[{0}, yw]*G[{1, 1, 1/(yu*yv)}, yw])/16 - 
     (7*G[{0}, yv^(-1)]*G[{0}, yw]*G[{1, 1, 1/(yu*yv)}, yw])/16 + 
     (7*G[{0}, yw]^2*G[{1, 1, 1/(yu*yv)}, yw])/32 - 
     (3*G[{0}, yu^(-1)]*G[{1}, yu^(-1)]*G[{1, 1, 1/(yu*yv)}, yw])/8 - 
     (3*G[{0}, yv^(-1)]*G[{1}, yu^(-1)]*G[{1, 1, 1/(yu*yv)}, yw])/8 + 
     (3*G[{0}, yw]*G[{1}, yu^(-1)]*G[{1, 1, 1/(yu*yv)}, yw])/8 + 
     (3*G[{1}, yu^(-1)]^2*G[{1, 1, 1/(yu*yv)}, yw])/16 - 
     (3*G[{0}, yu^(-1)]*G[{1}, yv^(-1)]*G[{1, 1, 1/(yu*yv)}, yw])/8 - 
     (3*G[{0}, yv^(-1)]*G[{1}, yv^(-1)]*G[{1, 1, 1/(yu*yv)}, yw])/8 + 
     (3*G[{0}, yw]*G[{1}, yv^(-1)]*G[{1, 1, 1/(yu*yv)}, yw])/8 + 
     (3*G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*G[{1, 1, 1/(yu*yv)}, yw])/8 + 
     (5*G[{1}, yv^(-1)]^2*G[{1, 1, 1/(yu*yv)}, yw])/32 + 
     (G[{0}, yu^(-1)]*G[{1}, yw]*G[{1, 1, 1/(yu*yv)}, yw])/4 + 
     (G[{0}, yv^(-1)]*G[{1}, yw]*G[{1, 1, 1/(yu*yv)}, yw])/4 - 
     (G[{0}, yw]*G[{1}, yw]*G[{1, 1, 1/(yu*yv)}, yw])/4 - 
     (G[{1}, yu^(-1)]*G[{1}, yw]*G[{1, 1, 1/(yu*yv)}, yw])/8 - 
     (3*G[{1}, yv^(-1)]*G[{1}, yw]*G[{1, 1, 1/(yu*yv)}, yw])/16 + 
     (3*G[{1}, yw]^2*G[{1, 1, 1/(yu*yv)}, yw])/32 - 
     (G[{0}, yu^(-1)]*G[{yu}, yv^(-1)]*G[{1, 1, 1/(yu*yv)}, yw])/8 - 
     (G[{0}, yv^(-1)]*G[{yu}, yv^(-1)]*G[{1, 1, 1/(yu*yv)}, yw])/8 + 
     (G[{0}, yw]*G[{yu}, yv^(-1)]*G[{1, 1, 1/(yu*yv)}, yw])/8 + 
     (3*G[{1}, yv^(-1)]*G[{yu}, yv^(-1)]*G[{1, 1, 1/(yu*yv)}, yw])/16 - 
     (3*G[{1}, yw]*G[{yu}, yv^(-1)]*G[{1, 1, 1/(yu*yv)}, yw])/16 + 
     (G[{yu}, yv^(-1)]^2*G[{1, 1, 1/(yu*yv)}, yw])/32 - 
     (G[{0}, yu^(-1)]*G[{1/(yu*yv)}, yw]*G[{1, 1, 1/(yu*yv)}, yw])/8 - 
     (G[{0}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{1, 1, 1/(yu*yv)}, yw])/8 + 
     (G[{0}, yw]*G[{1/(yu*yv)}, yw]*G[{1, 1, 1/(yu*yv)}, yw])/8 + 
     (G[{1}, yu^(-1)]*G[{1/(yu*yv)}, yw]*G[{1, 1, 1/(yu*yv)}, yw])/16 + 
     (G[{1}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{1, 1, 1/(yu*yv)}, yw])/8 - 
     (G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{1, 1, 1/(yu*yv)}, yw])/16 - 
     (G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{1, 1, 1/(yu*yv)}, yw])/4 + 
     (G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{1, 1, 1/(yu*yv)}, yw])/16 - 
     (3*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{1, 1, 1/(yu*yv)}, yw])/16 - 
     (G[{0, 1}, yv^(-1)]*G[{1, 1, 1/(yu*yv)}, yw])/8 + 
     (G[{0, 1}, yw]*G[{1, 1, 1/(yu*yv)}, yw])/8 - 
     (G[{0, yu^(-1)}, yw]*G[{1, 1, 1/(yu*yv)}, yw])/8 + 
     (G[{0, yu}, yv^(-1)]*G[{1, 1, 1/(yu*yv)}, yw])/8 - 
     (G[{0, yv^(-1)}, yw]*G[{1, 1, 1/(yu*yv)}, yw])/8 + 
     (G[{0, 1/(yu*yv)}, yw]*G[{1, 1, 1/(yu*yv)}, yw])/8 - 
     (G[{1, yu}, yv^(-1)]*G[{1, 1, 1/(yu*yv)}, yw])/8 - 
     (3*G[{1, yv^(-1)}, yw]*G[{1, 1, 1/(yu*yv)}, yw])/16 + 
     (G[{1, 1/(yu*yv)}, yw]*G[{1, 1, 1/(yu*yv)}, yw])/16 + 
     (G[{yu^(-1), 1/(yu*yv)}, yw]*G[{1, 1, 1/(yu*yv)}, yw])/4 + 
     (3*G[{yv^(-1), 1/(yu*yv)}, yw]*G[{1, 1, 1/(yu*yv)}, yw])/16 + 
     (7*Pi^2*G[{1, yu^(-1), yu^(-1)}, yw])/768 + 
     (5*G[{0}, yu^(-1)]^2*G[{1, yu^(-1), yu^(-1)}, yw])/64 + 
     (5*G[{0}, yu^(-1)]*G[{0}, yv^(-1)]*G[{1, yu^(-1), yu^(-1)}, yw])/32 + 
     (5*G[{0}, yv^(-1)]^2*G[{1, yu^(-1), yu^(-1)}, yw])/64 - 
     (5*G[{0}, yu^(-1)]*G[{0}, yw]*G[{1, yu^(-1), yu^(-1)}, yw])/32 - 
     (5*G[{0}, yv^(-1)]*G[{0}, yw]*G[{1, yu^(-1), yu^(-1)}, yw])/32 + 
     (5*G[{0}, yw]^2*G[{1, yu^(-1), yu^(-1)}, yw])/64 - 
     (5*G[{0}, yu^(-1)]*G[{1}, yu^(-1)]*G[{1, yu^(-1), yu^(-1)}, yw])/32 - 
     (5*G[{0}, yv^(-1)]*G[{1}, yu^(-1)]*G[{1, yu^(-1), yu^(-1)}, yw])/32 + 
     (5*G[{0}, yw]*G[{1}, yu^(-1)]*G[{1, yu^(-1), yu^(-1)}, yw])/32 + 
     (5*G[{1}, yu^(-1)]^2*G[{1, yu^(-1), yu^(-1)}, yw])/64 - 
     (5*G[{0}, yu^(-1)]*G[{1}, yv^(-1)]*G[{1, yu^(-1), yu^(-1)}, yw])/32 - 
     (5*G[{0}, yv^(-1)]*G[{1}, yv^(-1)]*G[{1, yu^(-1), yu^(-1)}, yw])/32 + 
     (5*G[{0}, yw]*G[{1}, yv^(-1)]*G[{1, yu^(-1), yu^(-1)}, yw])/32 + 
     (5*G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*G[{1, yu^(-1), yu^(-1)}, yw])/32 + 
     (G[{1}, yv^(-1)]^2*G[{1, yu^(-1), yu^(-1)}, yw])/32 - 
     (G[{0}, yu^(-1)]*G[{1}, yw]*G[{1, yu^(-1), yu^(-1)}, yw])/16 - 
     (G[{0}, yv^(-1)]*G[{1}, yw]*G[{1, yu^(-1), yu^(-1)}, yw])/16 + 
     (G[{0}, yw]*G[{1}, yw]*G[{1, yu^(-1), yu^(-1)}, yw])/16 + 
     (G[{1}, yu^(-1)]*G[{1}, yw]*G[{1, yu^(-1), yu^(-1)}, yw])/16 - 
     (G[{1}, yv^(-1)]*G[{1}, yw]*G[{1, yu^(-1), yu^(-1)}, yw])/32 - 
     (3*G[{1}, yw]^2*G[{1, yu^(-1), yu^(-1)}, yw])/64 + 
     (G[{1}, yv^(-1)]*G[{yu}, yv^(-1)]*G[{1, yu^(-1), yu^(-1)}, yw])/8 + 
     (3*G[{1}, yw]*G[{yu}, yv^(-1)]*G[{1, yu^(-1), yu^(-1)}, yw])/32 - 
     (G[{yu}, yv^(-1)]^2*G[{1, yu^(-1), yu^(-1)}, yw])/16 + 
     (3*G[{0}, yu^(-1)]*G[{1/(yu*yv)}, yw]*G[{1, yu^(-1), yu^(-1)}, yw])/64 + 
     (3*G[{0}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{1, yu^(-1), yu^(-1)}, yw])/64 - 
     (3*G[{0}, yw]*G[{1/(yu*yv)}, yw]*G[{1, yu^(-1), yu^(-1)}, yw])/64 - 
     (3*G[{1}, yu^(-1)]*G[{1/(yu*yv)}, yw]*G[{1, yu^(-1), yu^(-1)}, yw])/64 - 
     (G[{1}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{1, yu^(-1), yu^(-1)}, yw])/64 + 
     (G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{1, yu^(-1), yu^(-1)}, yw])/32 - 
     (G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{1, yu^(-1), yu^(-1)}, yw])/32 - 
     (G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{1, yu^(-1), yu^(-1)}, yw])/32 - 
     (G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{1, yu^(-1), yu^(-1)}, yw])/8 + 
     (3*G[{1/(yu*yv)}, yw]^2*G[{1, yu^(-1), yu^(-1)}, yw])/64 - 
     (G[{0, 1}, yv^(-1)]*G[{1, yu^(-1), yu^(-1)}, yw])/32 - 
     (G[{0, 1}, yw]*G[{1, yu^(-1), yu^(-1)}, yw])/16 + 
     (G[{0, yu^(-1)}, yw]*G[{1, yu^(-1), yu^(-1)}, yw])/16 + 
     (G[{0, yu}, yv^(-1)]*G[{1, yu^(-1), yu^(-1)}, yw])/32 + 
     (G[{0, yv^(-1)}, yw]*G[{1, yu^(-1), yu^(-1)}, yw])/16 - 
     (G[{0, 1/(yu*yv)}, yw]*G[{1, yu^(-1), yu^(-1)}, yw])/16 - 
     (3*G[{1, yu^(-1)}, yw]*G[{1, yu^(-1), yu^(-1)}, yw])/32 - 
     (G[{1, yu}, yv^(-1)]*G[{1, yu^(-1), yu^(-1)}, yw])/32 - 
     (G[{1, yv^(-1)}, yw]*G[{1, yu^(-1), yu^(-1)}, yw])/8 + 
     (3*G[{1, 1/(yu*yv)}, yw]*G[{1, yu^(-1), yu^(-1)}, yw])/32 + 
     (G[{yu^(-1), 1/(yu*yv)}, yw]*G[{1, yu^(-1), yu^(-1)}, yw])/32 + 
     (G[{yv^(-1), 1/(yu*yv)}, yw]*G[{1, yu^(-1), yu^(-1)}, yw])/8 - 
     (3*Pi^2*G[{1, yu^(-1), yv^(-1)}, yw])/256 + 
     (3*G[{0}, yu^(-1)]^2*G[{1, yu^(-1), yv^(-1)}, yw])/64 + 
     (3*G[{0}, yu^(-1)]*G[{0}, yv^(-1)]*G[{1, yu^(-1), yv^(-1)}, yw])/32 + 
     (3*G[{0}, yv^(-1)]^2*G[{1, yu^(-1), yv^(-1)}, yw])/64 - 
     (3*G[{0}, yu^(-1)]*G[{0}, yw]*G[{1, yu^(-1), yv^(-1)}, yw])/32 - 
     (3*G[{0}, yv^(-1)]*G[{0}, yw]*G[{1, yu^(-1), yv^(-1)}, yw])/32 + 
     (3*G[{0}, yw]^2*G[{1, yu^(-1), yv^(-1)}, yw])/64 + 
     (G[{0}, yu^(-1)]*G[{1}, yu^(-1)]*G[{1, yu^(-1), yv^(-1)}, yw])/32 + 
     (G[{0}, yv^(-1)]*G[{1}, yu^(-1)]*G[{1, yu^(-1), yv^(-1)}, yw])/32 - 
     (G[{0}, yw]*G[{1}, yu^(-1)]*G[{1, yu^(-1), yv^(-1)}, yw])/32 - 
     (5*G[{1}, yu^(-1)]^2*G[{1, yu^(-1), yv^(-1)}, yw])/64 - 
     (7*G[{0}, yu^(-1)]*G[{1}, yv^(-1)]*G[{1, yu^(-1), yv^(-1)}, yw])/32 - 
     (7*G[{0}, yv^(-1)]*G[{1}, yv^(-1)]*G[{1, yu^(-1), yv^(-1)}, yw])/32 + 
     (7*G[{0}, yw]*G[{1}, yv^(-1)]*G[{1, yu^(-1), yv^(-1)}, yw])/32 + 
     (3*G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*G[{1, yu^(-1), yv^(-1)}, yw])/32 + 
     (G[{1}, yv^(-1)]^2*G[{1, yu^(-1), yv^(-1)}, yw])/8 + 
     (G[{1}, yu^(-1)]*G[{1}, yw]*G[{1, yu^(-1), yv^(-1)}, yw])/8 + 
     (G[{1}, yv^(-1)]*G[{1}, yw]*G[{1, yu^(-1), yv^(-1)}, yw])/32 + 
     (5*G[{1}, yw]^2*G[{1, yu^(-1), yv^(-1)}, yw])/64 - 
     (5*G[{1}, yw]*G[{yu}, yv^(-1)]*G[{1, yu^(-1), yv^(-1)}, yw])/32 + 
     (11*G[{0}, yu^(-1)]*G[{1/(yu*yv)}, yw]*G[{1, yu^(-1), yv^(-1)}, yw])/
      64 + (11*G[{0}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{1, yu^(-1), yv^(-1)}, 
        yw])/64 - (11*G[{0}, yw]*G[{1/(yu*yv)}, yw]*G[{1, yu^(-1), yv^(-1)}, 
        yw])/64 - (7*G[{1}, yu^(-1)]*G[{1/(yu*yv)}, yw]*
       G[{1, yu^(-1), yv^(-1)}, yw])/64 - 
     (17*G[{1}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{1, yu^(-1), yv^(-1)}, yw])/
      64 - (G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{1, yu^(-1), yv^(-1)}, yw])/32 + 
     (3*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{1, yu^(-1), yv^(-1)}, yw])/
      32 + (G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{1, yu^(-1), yv^(-1)}, yw])/
      32 - (G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{1, yu^(-1), yv^(-1)}, yw])/
      16 + (3*G[{1/(yu*yv)}, yw]^2*G[{1, yu^(-1), yv^(-1)}, yw])/64 - 
     (G[{0, 1}, yu^(-1)]*G[{1, yu^(-1), yv^(-1)}, yw])/8 - 
     (G[{0, 1}, yv^(-1)]*G[{1, yu^(-1), yv^(-1)}, yw])/32 + 
     (G[{0, yu}, yv^(-1)]*G[{1, yu^(-1), yv^(-1)}, yw])/32 - 
     (G[{1, yu^(-1)}, yw]*G[{1, yu^(-1), yv^(-1)}, yw])/32 + 
     (3*G[{1, yu}, yv^(-1)]*G[{1, yu^(-1), yv^(-1)}, yw])/32 - 
     (G[{1, yv^(-1)}, yw]*G[{1, yu^(-1), yv^(-1)}, yw])/16 + 
     (G[{1, 1/(yu*yv)}, yw]*G[{1, yu^(-1), yv^(-1)}, yw])/32 - 
     (3*G[{yu^(-1), 1/(yu*yv)}, yw]*G[{1, yu^(-1), yv^(-1)}, yw])/32 + 
     (G[{yv^(-1), 1/(yu*yv)}, yw]*G[{1, yu^(-1), yv^(-1)}, yw])/16 - 
     (5*Pi^2*G[{1, yu^(-1), 1/(yu*yv)}, yw])/768 - 
     (G[{0}, yu^(-1)]^2*G[{1, yu^(-1), 1/(yu*yv)}, yw])/16 - 
     (G[{0}, yu^(-1)]*G[{0}, yv^(-1)]*G[{1, yu^(-1), 1/(yu*yv)}, yw])/8 - 
     (G[{0}, yv^(-1)]^2*G[{1, yu^(-1), 1/(yu*yv)}, yw])/16 + 
     (G[{0}, yu^(-1)]*G[{0}, yw]*G[{1, yu^(-1), 1/(yu*yv)}, yw])/8 + 
     (G[{0}, yv^(-1)]*G[{0}, yw]*G[{1, yu^(-1), 1/(yu*yv)}, yw])/8 - 
     (G[{0}, yw]^2*G[{1, yu^(-1), 1/(yu*yv)}, yw])/16 + 
     (G[{1}, yu^(-1)]^2*G[{1, yu^(-1), 1/(yu*yv)}, yw])/16 + 
     (G[{0}, yu^(-1)]*G[{1}, yv^(-1)]*G[{1, yu^(-1), 1/(yu*yv)}, yw])/8 + 
     (G[{0}, yv^(-1)]*G[{1}, yv^(-1)]*G[{1, yu^(-1), 1/(yu*yv)}, yw])/8 - 
     (G[{0}, yw]*G[{1}, yv^(-1)]*G[{1, yu^(-1), 1/(yu*yv)}, yw])/8 - 
     (G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*G[{1, yu^(-1), 1/(yu*yv)}, yw])/8 - 
     (5*G[{1}, yv^(-1)]^2*G[{1, yu^(-1), 1/(yu*yv)}, yw])/128 - 
     (9*G[{0}, yu^(-1)]*G[{1}, yw]*G[{1, yu^(-1), 1/(yu*yv)}, yw])/64 - 
     (9*G[{0}, yv^(-1)]*G[{1}, yw]*G[{1, yu^(-1), 1/(yu*yv)}, yw])/64 + 
     (9*G[{0}, yw]*G[{1}, yw]*G[{1, yu^(-1), 1/(yu*yv)}, yw])/64 + 
     (G[{1}, yu^(-1)]*G[{1}, yw]*G[{1, yu^(-1), 1/(yu*yv)}, yw])/64 + 
     (G[{1}, yv^(-1)]*G[{1}, yw]*G[{1, yu^(-1), 1/(yu*yv)}, yw])/16 - 
     (13*G[{1}, yw]^2*G[{1, yu^(-1), 1/(yu*yv)}, yw])/128 + 
     (G[{0}, yu^(-1)]*G[{yu}, yv^(-1)]*G[{1, yu^(-1), 1/(yu*yv)}, yw])/8 + 
     (G[{0}, yv^(-1)]*G[{yu}, yv^(-1)]*G[{1, yu^(-1), 1/(yu*yv)}, yw])/8 - 
     (G[{0}, yw]*G[{yu}, yv^(-1)]*G[{1, yu^(-1), 1/(yu*yv)}, yw])/8 - 
     (G[{1}, yv^(-1)]*G[{yu}, yv^(-1)]*G[{1, yu^(-1), 1/(yu*yv)}, yw])/16 + 
     (13*G[{1}, yw]*G[{yu}, yv^(-1)]*G[{1, yu^(-1), 1/(yu*yv)}, yw])/64 - 
     (3*G[{yu}, yv^(-1)]^2*G[{1, yu^(-1), 1/(yu*yv)}, yw])/32 + 
     (3*G[{1}, yu^(-1)]*G[{1/(yu*yv)}, yw]*G[{1, yu^(-1), 1/(yu*yv)}, yw])/
      16 - (7*G[{1}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{1, yu^(-1), 1/(yu*yv)}, 
        yw])/64 + (5*G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{1, yu^(-1), 1/(yu*yv)}, 
        yw])/64 + (13*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*
       G[{1, yu^(-1), 1/(yu*yv)}, yw])/64 - 
     (5*G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{1, yu^(-1), 1/(yu*yv)}, yw])/
      64 - (3*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{1, yu^(-1), 1/(yu*yv)}, 
        yw])/32 + (G[{0, 1}, yv^(-1)]*G[{1, yu^(-1), 1/(yu*yv)}, yw])/64 - 
     (G[{0, 1}, yw]*G[{1, yu^(-1), 1/(yu*yv)}, yw])/64 + 
     (G[{0, yu^(-1)}, yw]*G[{1, yu^(-1), 1/(yu*yv)}, yw])/64 - 
     (G[{0, yu}, yv^(-1)]*G[{1, yu^(-1), 1/(yu*yv)}, yw])/64 + 
     (G[{0, yv^(-1)}, yw]*G[{1, yu^(-1), 1/(yu*yv)}, yw])/64 - 
     (G[{0, 1/(yu*yv)}, yw]*G[{1, yu^(-1), 1/(yu*yv)}, yw])/64 + 
     (G[{1, yu}, yv^(-1)]*G[{1, yu^(-1), 1/(yu*yv)}, yw])/64 + 
     (G[{1, yv^(-1)}, yw]*G[{1, yu^(-1), 1/(yu*yv)}, yw])/32 - 
     (5*G[{1, 1/(yu*yv)}, yw]*G[{1, yu^(-1), 1/(yu*yv)}, yw])/64 - 
     (13*G[{yu^(-1), 1/(yu*yv)}, yw]*G[{1, yu^(-1), 1/(yu*yv)}, yw])/64 + 
     (3*G[{yv^(-1), 1/(yu*yv)}, yw]*G[{1, yu^(-1), 1/(yu*yv)}, yw])/32 - 
     (Pi^2*G[{1, yu, yu}, yv^(-1)])/48 - 
     (5*G[{0}, yu^(-1)]^2*G[{1, yu, yu}, yv^(-1)])/32 - 
     (5*G[{0}, yu^(-1)]*G[{0}, yv^(-1)]*G[{1, yu, yu}, yv^(-1)])/16 - 
     (5*G[{0}, yv^(-1)]^2*G[{1, yu, yu}, yv^(-1)])/32 + 
     (5*G[{0}, yu^(-1)]*G[{0}, yw]*G[{1, yu, yu}, yv^(-1)])/16 + 
     (5*G[{0}, yv^(-1)]*G[{0}, yw]*G[{1, yu, yu}, yv^(-1)])/16 - 
     (5*G[{0}, yw]^2*G[{1, yu, yu}, yv^(-1)])/32 + 
     (G[{0}, yu^(-1)]*G[{1}, yu^(-1)]*G[{1, yu, yu}, yv^(-1)])/16 + 
     (G[{0}, yv^(-1)]*G[{1}, yu^(-1)]*G[{1, yu, yu}, yv^(-1)])/16 - 
     (G[{0}, yw]*G[{1}, yu^(-1)]*G[{1, yu, yu}, yv^(-1)])/16 + 
     (G[{1}, yu^(-1)]^2*G[{1, yu, yu}, yv^(-1)])/32 + 
     (5*G[{0}, yu^(-1)]*G[{1}, yv^(-1)]*G[{1, yu, yu}, yv^(-1)])/16 + 
     (5*G[{0}, yv^(-1)]*G[{1}, yv^(-1)]*G[{1, yu, yu}, yv^(-1)])/16 - 
     (5*G[{0}, yw]*G[{1}, yv^(-1)]*G[{1, yu, yu}, yv^(-1)])/16 - 
     (3*G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*G[{1, yu, yu}, yv^(-1)])/16 - 
     (5*G[{1}, yv^(-1)]^2*G[{1, yu, yu}, yv^(-1)])/32 - 
     (3*G[{0}, yu^(-1)]*G[{1}, yw]*G[{1, yu, yu}, yv^(-1)])/16 - 
     (3*G[{0}, yv^(-1)]*G[{1}, yw]*G[{1, yu, yu}, yv^(-1)])/16 + 
     (3*G[{0}, yw]*G[{1}, yw]*G[{1, yu, yu}, yv^(-1)])/16 - 
     (G[{1}, yu^(-1)]*G[{1}, yw]*G[{1, yu, yu}, yv^(-1)])/16 + 
     (G[{1}, yv^(-1)]*G[{1}, yw]*G[{1, yu, yu}, yv^(-1)])/8 - 
     (G[{1}, yw]^2*G[{1, yu, yu}, yv^(-1)])/32 - 
     (3*G[{1}, yw]*G[{yu}, yv^(-1)]*G[{1, yu, yu}, yv^(-1)])/16 - 
     (7*G[{0}, yu^(-1)]*G[{1/(yu*yv)}, yw]*G[{1, yu, yu}, yv^(-1)])/16 - 
     (7*G[{0}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{1, yu, yu}, yv^(-1)])/16 + 
     (7*G[{0}, yw]*G[{1/(yu*yv)}, yw]*G[{1, yu, yu}, yv^(-1)])/16 + 
     (3*G[{1}, yu^(-1)]*G[{1/(yu*yv)}, yw]*G[{1, yu, yu}, yv^(-1)])/16 + 
     (G[{1}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{1, yu, yu}, yv^(-1)])/2 - 
     (3*G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{1, yu, yu}, yv^(-1)])/16 - 
     (3*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{1, yu, yu}, yv^(-1)])/8 + 
     (3*G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{1, yu, yu}, yv^(-1)])/16 - 
     (5*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{1, yu, yu}, yv^(-1)])/16 - 
     (G[{0, 1}, yu^(-1)]*G[{1, yu, yu}, yv^(-1)])/8 + 
     (G[{0, 1}, yv^(-1)]*G[{1, yu, yu}, yv^(-1)])/8 - 
     (G[{0, 1}, yw]*G[{1, yu, yu}, yv^(-1)])/16 + 
     (3*G[{0, yu^(-1)}, yw]*G[{1, yu, yu}, yv^(-1)])/16 - 
     (G[{0, yu}, yv^(-1)]*G[{1, yu, yu}, yv^(-1)])/8 + 
     (5*G[{0, yv^(-1)}, yw]*G[{1, yu, yu}, yv^(-1)])/16 - 
     (7*G[{0, 1/(yu*yv)}, yw]*G[{1, yu, yu}, yv^(-1)])/16 + 
     (G[{1, yu}, yv^(-1)]*G[{1, yu, yu}, yv^(-1)])/4 - 
     (5*G[{1, yv^(-1)}, yw]*G[{1, yu, yu}, yv^(-1)])/16 + 
     (3*G[{1, 1/(yu*yv)}, yw]*G[{1, yu, yu}, yv^(-1)])/16 + 
     (3*G[{yu^(-1), 1/(yu*yv)}, yw]*G[{1, yu, yu}, yv^(-1)])/8 + 
     (5*G[{yv^(-1), 1/(yu*yv)}, yw]*G[{1, yu, yu}, yv^(-1)])/16 - 
     (3*Pi^2*G[{1, yv^(-1), yu^(-1)}, yw])/256 + 
     (3*G[{0}, yu^(-1)]^2*G[{1, yv^(-1), yu^(-1)}, yw])/64 + 
     (3*G[{0}, yu^(-1)]*G[{0}, yv^(-1)]*G[{1, yv^(-1), yu^(-1)}, yw])/32 + 
     (3*G[{0}, yv^(-1)]^2*G[{1, yv^(-1), yu^(-1)}, yw])/64 - 
     (3*G[{0}, yu^(-1)]*G[{0}, yw]*G[{1, yv^(-1), yu^(-1)}, yw])/32 - 
     (3*G[{0}, yv^(-1)]*G[{0}, yw]*G[{1, yv^(-1), yu^(-1)}, yw])/32 + 
     (3*G[{0}, yw]^2*G[{1, yv^(-1), yu^(-1)}, yw])/64 + 
     (G[{0}, yu^(-1)]*G[{1}, yu^(-1)]*G[{1, yv^(-1), yu^(-1)}, yw])/32 + 
     (G[{0}, yv^(-1)]*G[{1}, yu^(-1)]*G[{1, yv^(-1), yu^(-1)}, yw])/32 - 
     (G[{0}, yw]*G[{1}, yu^(-1)]*G[{1, yv^(-1), yu^(-1)}, yw])/32 - 
     (5*G[{1}, yu^(-1)]^2*G[{1, yv^(-1), yu^(-1)}, yw])/64 - 
     (7*G[{0}, yu^(-1)]*G[{1}, yv^(-1)]*G[{1, yv^(-1), yu^(-1)}, yw])/32 - 
     (7*G[{0}, yv^(-1)]*G[{1}, yv^(-1)]*G[{1, yv^(-1), yu^(-1)}, yw])/32 + 
     (7*G[{0}, yw]*G[{1}, yv^(-1)]*G[{1, yv^(-1), yu^(-1)}, yw])/32 + 
     (3*G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*G[{1, yv^(-1), yu^(-1)}, yw])/32 + 
     (G[{1}, yv^(-1)]^2*G[{1, yv^(-1), yu^(-1)}, yw])/8 + 
     (G[{1}, yu^(-1)]*G[{1}, yw]*G[{1, yv^(-1), yu^(-1)}, yw])/8 + 
     (G[{1}, yv^(-1)]*G[{1}, yw]*G[{1, yv^(-1), yu^(-1)}, yw])/32 + 
     (5*G[{1}, yw]^2*G[{1, yv^(-1), yu^(-1)}, yw])/64 - 
     (5*G[{1}, yw]*G[{yu}, yv^(-1)]*G[{1, yv^(-1), yu^(-1)}, yw])/32 + 
     (11*G[{0}, yu^(-1)]*G[{1/(yu*yv)}, yw]*G[{1, yv^(-1), yu^(-1)}, yw])/
      64 + (11*G[{0}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{1, yv^(-1), yu^(-1)}, 
        yw])/64 - (11*G[{0}, yw]*G[{1/(yu*yv)}, yw]*G[{1, yv^(-1), yu^(-1)}, 
        yw])/64 - (7*G[{1}, yu^(-1)]*G[{1/(yu*yv)}, yw]*
       G[{1, yv^(-1), yu^(-1)}, yw])/64 - 
     (17*G[{1}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{1, yv^(-1), yu^(-1)}, yw])/
      64 - (G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{1, yv^(-1), yu^(-1)}, yw])/32 + 
     (3*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{1, yv^(-1), yu^(-1)}, yw])/
      32 + (G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{1, yv^(-1), yu^(-1)}, yw])/
      32 - (G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{1, yv^(-1), yu^(-1)}, yw])/
      16 + (3*G[{1/(yu*yv)}, yw]^2*G[{1, yv^(-1), yu^(-1)}, yw])/64 - 
     (G[{0, 1}, yu^(-1)]*G[{1, yv^(-1), yu^(-1)}, yw])/8 - 
     (G[{0, 1}, yv^(-1)]*G[{1, yv^(-1), yu^(-1)}, yw])/32 + 
     (G[{0, yu}, yv^(-1)]*G[{1, yv^(-1), yu^(-1)}, yw])/32 - 
     (G[{1, yu^(-1)}, yw]*G[{1, yv^(-1), yu^(-1)}, yw])/32 + 
     (3*G[{1, yu}, yv^(-1)]*G[{1, yv^(-1), yu^(-1)}, yw])/32 - 
     (G[{1, yv^(-1)}, yw]*G[{1, yv^(-1), yu^(-1)}, yw])/8 + 
     (G[{1, 1/(yu*yv)}, yw]*G[{1, yv^(-1), yu^(-1)}, yw])/32 - 
     (3*G[{yu^(-1), 1/(yu*yv)}, yw]*G[{1, yv^(-1), yu^(-1)}, yw])/32 + 
     (G[{yv^(-1), 1/(yu*yv)}, yw]*G[{1, yv^(-1), yu^(-1)}, yw])/16 - 
     (19*Pi^2*G[{1, yv^(-1), yv^(-1)}, yw])/256 - 
     (9*G[{0}, yu^(-1)]^2*G[{1, yv^(-1), yv^(-1)}, yw])/64 - 
     (9*G[{0}, yu^(-1)]*G[{0}, yv^(-1)]*G[{1, yv^(-1), yv^(-1)}, yw])/32 - 
     (9*G[{0}, yv^(-1)]^2*G[{1, yv^(-1), yv^(-1)}, yw])/64 + 
     (9*G[{0}, yu^(-1)]*G[{0}, yw]*G[{1, yv^(-1), yv^(-1)}, yw])/32 + 
     (9*G[{0}, yv^(-1)]*G[{0}, yw]*G[{1, yv^(-1), yv^(-1)}, yw])/32 - 
     (9*G[{0}, yw]^2*G[{1, yv^(-1), yv^(-1)}, yw])/64 + 
     (21*G[{0}, yu^(-1)]*G[{1}, yu^(-1)]*G[{1, yv^(-1), yv^(-1)}, yw])/32 + 
     (21*G[{0}, yv^(-1)]*G[{1}, yu^(-1)]*G[{1, yv^(-1), yv^(-1)}, yw])/32 - 
     (21*G[{0}, yw]*G[{1}, yu^(-1)]*G[{1, yv^(-1), yv^(-1)}, yw])/32 - 
     (29*G[{1}, yu^(-1)]^2*G[{1, yv^(-1), yv^(-1)}, yw])/64 - 
     (3*G[{0}, yu^(-1)]*G[{1}, yv^(-1)]*G[{1, yv^(-1), yv^(-1)}, yw])/32 - 
     (3*G[{0}, yv^(-1)]*G[{1}, yv^(-1)]*G[{1, yv^(-1), yv^(-1)}, yw])/32 + 
     (3*G[{0}, yw]*G[{1}, yv^(-1)]*G[{1, yv^(-1), yv^(-1)}, yw])/32 - 
     (13*G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*G[{1, yv^(-1), yv^(-1)}, yw])/32 + 
     (3*G[{1}, yv^(-1)]^2*G[{1, yv^(-1), yv^(-1)}, yw])/16 + 
     (G[{0}, yu^(-1)]*G[{1}, yw]*G[{1, yv^(-1), yv^(-1)}, yw])/8 + 
     (G[{0}, yv^(-1)]*G[{1}, yw]*G[{1, yv^(-1), yv^(-1)}, yw])/8 - 
     (G[{0}, yw]*G[{1}, yw]*G[{1, yv^(-1), yv^(-1)}, yw])/8 + 
     (G[{1}, yu^(-1)]*G[{1}, yw]*G[{1, yv^(-1), yv^(-1)}, yw])/8 - 
     (3*G[{1}, yv^(-1)]*G[{1}, yw]*G[{1, yv^(-1), yv^(-1)}, yw])/32 + 
     (9*G[{1}, yw]^2*G[{1, yv^(-1), yv^(-1)}, yw])/64 - 
     (9*G[{1}, yw]*G[{yu}, yv^(-1)]*G[{1, yv^(-1), yv^(-1)}, yw])/32 + 
     (31*G[{0}, yu^(-1)]*G[{1/(yu*yv)}, yw]*G[{1, yv^(-1), yv^(-1)}, yw])/
      64 + (31*G[{0}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{1, yv^(-1), yv^(-1)}, 
        yw])/64 - (31*G[{0}, yw]*G[{1/(yu*yv)}, yw]*G[{1, yv^(-1), yv^(-1)}, 
        yw])/64 - (15*G[{1}, yu^(-1)]*G[{1/(yu*yv)}, yw]*
       G[{1, yv^(-1), yv^(-1)}, yw])/64 - 
     (33*G[{1}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{1, yv^(-1), yv^(-1)}, yw])/
      64 + (7*G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{1, yv^(-1), yv^(-1)}, yw])/
      32 + (11*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{1, yv^(-1), yv^(-1)}, 
        yw])/32 - (7*G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw]*
       G[{1, yv^(-1), yv^(-1)}, yw])/32 + 
     (3*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{1, yv^(-1), yv^(-1)}, yw])/
      16 + (3*G[{1/(yu*yv)}, yw]^2*G[{1, yv^(-1), yv^(-1)}, yw])/64 - 
     (G[{0, 1}, yu^(-1)]*G[{1, yv^(-1), yv^(-1)}, yw])/4 - 
     (G[{0, 1}, yv^(-1)]*G[{1, yv^(-1), yv^(-1)}, yw])/32 + 
     (G[{0, 1}, yw]*G[{1, yv^(-1), yv^(-1)}, yw])/8 - 
     (G[{0, yu^(-1)}, yw]*G[{1, yv^(-1), yv^(-1)}, yw])/8 + 
     (G[{0, yu}, yv^(-1)]*G[{1, yv^(-1), yv^(-1)}, yw])/32 - 
     (G[{0, yv^(-1)}, yw]*G[{1, yv^(-1), yv^(-1)}, yw])/8 + 
     (G[{0, 1/(yu*yv)}, yw]*G[{1, yv^(-1), yv^(-1)}, yw])/8 + 
     (3*G[{1, yu^(-1)}, yw]*G[{1, yv^(-1), yv^(-1)}, yw])/32 + 
     (7*G[{1, yu}, yv^(-1)]*G[{1, yv^(-1), yv^(-1)}, yw])/32 - 
     (G[{1, yv^(-1)}, yw]*G[{1, yv^(-1), yv^(-1)}, yw])/8 - 
     (3*G[{1, 1/(yu*yv)}, yw]*G[{1, yv^(-1), yv^(-1)}, yw])/32 - 
     (11*G[{yu^(-1), 1/(yu*yv)}, yw]*G[{1, yv^(-1), yv^(-1)}, yw])/32 - 
     (3*G[{yv^(-1), 1/(yu*yv)}, yw]*G[{1, yv^(-1), yv^(-1)}, yw])/16 - 
     (5*Pi^2*G[{1, yv^(-1), 1/(yu*yv)}, yw])/768 - 
     (G[{0}, yu^(-1)]*G[{1}, yu^(-1)]*G[{1, yv^(-1), 1/(yu*yv)}, yw])/16 - 
     (G[{0}, yv^(-1)]*G[{1}, yu^(-1)]*G[{1, yv^(-1), 1/(yu*yv)}, yw])/16 + 
     (G[{0}, yw]*G[{1}, yu^(-1)]*G[{1, yv^(-1), 1/(yu*yv)}, yw])/16 + 
     (3*G[{1}, yu^(-1)]^2*G[{1, yv^(-1), 1/(yu*yv)}, yw])/32 + 
     (G[{0}, yu^(-1)]*G[{1}, yv^(-1)]*G[{1, yv^(-1), 1/(yu*yv)}, yw])/16 + 
     (G[{0}, yv^(-1)]*G[{1}, yv^(-1)]*G[{1, yv^(-1), 1/(yu*yv)}, yw])/16 - 
     (G[{0}, yw]*G[{1}, yv^(-1)]*G[{1, yv^(-1), 1/(yu*yv)}, yw])/16 - 
     (G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*G[{1, yv^(-1), 1/(yu*yv)}, yw])/16 - 
     (5*G[{1}, yv^(-1)]^2*G[{1, yv^(-1), 1/(yu*yv)}, yw])/128 + 
     (3*G[{0}, yu^(-1)]*G[{1}, yw]*G[{1, yv^(-1), 1/(yu*yv)}, yw])/64 + 
     (3*G[{0}, yv^(-1)]*G[{1}, yw]*G[{1, yv^(-1), 1/(yu*yv)}, yw])/64 - 
     (3*G[{0}, yw]*G[{1}, yw]*G[{1, yv^(-1), 1/(yu*yv)}, yw])/64 - 
     (3*G[{1}, yu^(-1)]*G[{1}, yw]*G[{1, yv^(-1), 1/(yu*yv)}, yw])/64 - 
     (G[{1}, yv^(-1)]*G[{1}, yw]*G[{1, yv^(-1), 1/(yu*yv)}, yw])/16 - 
     (G[{1}, yw]^2*G[{1, yv^(-1), 1/(yu*yv)}, yw])/128 + 
     (G[{1}, yw]*G[{yu}, yv^(-1)]*G[{1, yv^(-1), 1/(yu*yv)}, yw])/64 - 
     (G[{0}, yu^(-1)]*G[{1/(yu*yv)}, yw]*G[{1, yv^(-1), 1/(yu*yv)}, yw])/16 - 
     (G[{0}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{1, yv^(-1), 1/(yu*yv)}, yw])/16 + 
     (G[{0}, yw]*G[{1/(yu*yv)}, yw]*G[{1, yv^(-1), 1/(yu*yv)}, yw])/16 + 
     (G[{1}, yu^(-1)]*G[{1/(yu*yv)}, yw]*G[{1, yv^(-1), 1/(yu*yv)}, yw])/16 + 
     (G[{1}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{1, yv^(-1), 1/(yu*yv)}, yw])/64 - 
     (3*G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{1, yv^(-1), 1/(yu*yv)}, yw])/64 + 
     (5*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{1, yv^(-1), 1/(yu*yv)}, yw])/
      64 + (3*G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{1, yv^(-1), 1/(yu*yv)}, 
        yw])/64 + (G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*
       G[{1, yv^(-1), 1/(yu*yv)}, yw])/32 + 
     (G[{0, 1}, yv^(-1)]*G[{1, yv^(-1), 1/(yu*yv)}, yw])/64 + 
     (3*G[{0, 1}, yw]*G[{1, yv^(-1), 1/(yu*yv)}, yw])/64 - 
     (3*G[{0, yu^(-1)}, yw]*G[{1, yv^(-1), 1/(yu*yv)}, yw])/64 - 
     (G[{0, yu}, yv^(-1)]*G[{1, yv^(-1), 1/(yu*yv)}, yw])/64 - 
     (3*G[{0, yv^(-1)}, yw]*G[{1, yv^(-1), 1/(yu*yv)}, yw])/64 + 
     (3*G[{0, 1/(yu*yv)}, yw]*G[{1, yv^(-1), 1/(yu*yv)}, yw])/64 + 
     (G[{1, yu^(-1)}, yw]*G[{1, yv^(-1), 1/(yu*yv)}, yw])/16 + 
     (G[{1, yu}, yv^(-1)]*G[{1, yv^(-1), 1/(yu*yv)}, yw])/64 + 
     (3*G[{1, yv^(-1)}, yw]*G[{1, yv^(-1), 1/(yu*yv)}, yw])/64 + 
     (3*G[{1, 1/(yu*yv)}, yw]*G[{1, yv^(-1), 1/(yu*yv)}, yw])/64 - 
     (5*G[{yu^(-1), 1/(yu*yv)}, yw]*G[{1, yv^(-1), 1/(yu*yv)}, yw])/64 - 
     (G[{yv^(-1), 1/(yu*yv)}, yw]*G[{1, yv^(-1), 1/(yu*yv)}, yw])/32 - 
     (Pi^2*G[{1, 1/(yu*yv), yu^(-1)}, yw])/48 - 
     (G[{0}, yu^(-1)]^2*G[{1, 1/(yu*yv), yu^(-1)}, yw])/32 - 
     (G[{0}, yu^(-1)]*G[{0}, yv^(-1)]*G[{1, 1/(yu*yv), yu^(-1)}, yw])/16 - 
     (G[{0}, yv^(-1)]^2*G[{1, 1/(yu*yv), yu^(-1)}, yw])/32 + 
     (G[{0}, yu^(-1)]*G[{0}, yw]*G[{1, 1/(yu*yv), yu^(-1)}, yw])/16 + 
     (G[{0}, yv^(-1)]*G[{0}, yw]*G[{1, 1/(yu*yv), yu^(-1)}, yw])/16 - 
     (G[{0}, yw]^2*G[{1, 1/(yu*yv), yu^(-1)}, yw])/32 - 
     (G[{0}, yu^(-1)]*G[{1}, yu^(-1)]*G[{1, 1/(yu*yv), yu^(-1)}, yw])/16 - 
     (G[{0}, yv^(-1)]*G[{1}, yu^(-1)]*G[{1, 1/(yu*yv), yu^(-1)}, yw])/16 + 
     (G[{0}, yw]*G[{1}, yu^(-1)]*G[{1, 1/(yu*yv), yu^(-1)}, yw])/16 + 
     (3*G[{1}, yu^(-1)]^2*G[{1, 1/(yu*yv), yu^(-1)}, yw])/32 - 
     (G[{0}, yu^(-1)]*G[{1}, yv^(-1)]*G[{1, 1/(yu*yv), yu^(-1)}, yw])/16 - 
     (G[{0}, yv^(-1)]*G[{1}, yv^(-1)]*G[{1, 1/(yu*yv), yu^(-1)}, yw])/16 + 
     (G[{0}, yw]*G[{1}, yv^(-1)]*G[{1, 1/(yu*yv), yu^(-1)}, yw])/16 - 
     (G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*G[{1, 1/(yu*yv), yu^(-1)}, yw])/16 + 
     (3*G[{1}, yv^(-1)]^2*G[{1, 1/(yu*yv), yu^(-1)}, yw])/32 - 
     (3*G[{0}, yu^(-1)]*G[{1}, yw]*G[{1, 1/(yu*yv), yu^(-1)}, yw])/16 - 
     (3*G[{0}, yv^(-1)]*G[{1}, yw]*G[{1, 1/(yu*yv), yu^(-1)}, yw])/16 + 
     (3*G[{0}, yw]*G[{1}, yw]*G[{1, 1/(yu*yv), yu^(-1)}, yw])/16 + 
     (G[{1}, yu^(-1)]*G[{1}, yw]*G[{1, 1/(yu*yv), yu^(-1)}, yw])/16 + 
     (G[{1}, yv^(-1)]*G[{1}, yw]*G[{1, 1/(yu*yv), yu^(-1)}, yw])/16 - 
     (G[{1}, yw]^2*G[{1, 1/(yu*yv), yu^(-1)}, yw])/8 + 
     (G[{0}, yu^(-1)]*G[{yu}, yv^(-1)]*G[{1, 1/(yu*yv), yu^(-1)}, yw])/4 + 
     (G[{0}, yv^(-1)]*G[{yu}, yv^(-1)]*G[{1, 1/(yu*yv), yu^(-1)}, yw])/4 - 
     (G[{0}, yw]*G[{yu}, yv^(-1)]*G[{1, 1/(yu*yv), yu^(-1)}, yw])/4 - 
     (G[{1}, yv^(-1)]*G[{yu}, yv^(-1)]*G[{1, 1/(yu*yv), yu^(-1)}, yw])/8 + 
     (G[{1}, yw]*G[{yu}, yv^(-1)]*G[{1, 1/(yu*yv), yu^(-1)}, yw])/4 - 
     (3*G[{yu}, yv^(-1)]^2*G[{1, 1/(yu*yv), yu^(-1)}, yw])/16 + 
     (G[{0}, yu^(-1)]*G[{1/(yu*yv)}, yw]*G[{1, 1/(yu*yv), yu^(-1)}, yw])/8 + 
     (G[{0}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{1, 1/(yu*yv), yu^(-1)}, yw])/8 - 
     (G[{0}, yw]*G[{1/(yu*yv)}, yw]*G[{1, 1/(yu*yv), yu^(-1)}, yw])/8 - 
     (G[{1}, yu^(-1)]*G[{1/(yu*yv)}, yw]*G[{1, 1/(yu*yv), yu^(-1)}, yw])/16 - 
     (G[{1}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{1, 1/(yu*yv), yu^(-1)}, yw])/4 - 
     (G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{1, 1/(yu*yv), yu^(-1)}, yw])/16 + 
     (G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{1, 1/(yu*yv), yu^(-1)}, yw])/8 + 
     (G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{1, 1/(yu*yv), yu^(-1)}, yw])/
      16 + (G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{1, 1/(yu*yv), yu^(-1)}, 
        yw])/16 - (G[{0, 1}, yu^(-1)]*G[{1, 1/(yu*yv), yu^(-1)}, yw])/8 + 
     (G[{0, 1}, yw]*G[{1, 1/(yu*yv), yu^(-1)}, yw])/16 - 
     (G[{0, yu^(-1)}, yw]*G[{1, 1/(yu*yv), yu^(-1)}, yw])/16 - 
     (G[{0, yv^(-1)}, yw]*G[{1, 1/(yu*yv), yu^(-1)}, yw])/16 + 
     (G[{0, 1/(yu*yv)}, yw]*G[{1, 1/(yu*yv), yu^(-1)}, yw])/16 + 
     (G[{1, yu^(-1)}, yw]*G[{1, 1/(yu*yv), yu^(-1)}, yw])/16 + 
     (G[{1, yu}, yv^(-1)]*G[{1, 1/(yu*yv), yu^(-1)}, yw])/8 - 
     (G[{1, yv^(-1)}, yw]*G[{1, 1/(yu*yv), yu^(-1)}, yw])/16 + 
     (G[{1, 1/(yu*yv)}, yw]*G[{1, 1/(yu*yv), yu^(-1)}, yw])/8 - 
     (G[{yu^(-1), 1/(yu*yv)}, yw]*G[{1, 1/(yu*yv), yu^(-1)}, yw])/8 - 
     (G[{yv^(-1), 1/(yu*yv)}, yw]*G[{1, 1/(yu*yv), yu^(-1)}, yw])/16 - 
     (5*G[{0}, yu^(-1)]*G[{1/(yu*yv)}, yw]*G[{1, 1/(yu*yv), yv^(-1)}, yw])/
      16 - (5*G[{0}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{1, 1/(yu*yv), yv^(-1)}, 
        yw])/16 + (5*G[{0}, yw]*G[{1/(yu*yv)}, yw]*G[{1, 1/(yu*yv), yv^(-1)}, 
        yw])/16 + (G[{1}, yu^(-1)]*G[{1/(yu*yv)}, yw]*
       G[{1, 1/(yu*yv), yv^(-1)}, yw])/8 + 
     (G[{1}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{1, 1/(yu*yv), yv^(-1)}, yw])/4 - 
     (G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{1, 1/(yu*yv), yv^(-1)}, yw])/4 - 
     (G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{1, 1/(yu*yv), yv^(-1)}, yw])/4 + 
     (G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{1, 1/(yu*yv), yv^(-1)}, yw])/4 - 
     (G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{1, 1/(yu*yv), yv^(-1)}, yw])/4 + 
     (G[{yu^(-1), 1/(yu*yv)}, yw]*G[{1, 1/(yu*yv), yv^(-1)}, yw])/4 + 
     (G[{yv^(-1), 1/(yu*yv)}, yw]*G[{1, 1/(yu*yv), yv^(-1)}, yw])/4 + 
     (G[{0}, yu^(-1)]^2*G[{1, 1/(yu*yv), 1/(yu*yv)}, yw])/16 + 
     (G[{0}, yu^(-1)]*G[{0}, yv^(-1)]*G[{1, 1/(yu*yv), 1/(yu*yv)}, yw])/8 + 
     (G[{0}, yv^(-1)]^2*G[{1, 1/(yu*yv), 1/(yu*yv)}, yw])/16 - 
     (G[{0}, yu^(-1)]*G[{0}, yw]*G[{1, 1/(yu*yv), 1/(yu*yv)}, yw])/8 - 
     (G[{0}, yv^(-1)]*G[{0}, yw]*G[{1, 1/(yu*yv), 1/(yu*yv)}, yw])/8 + 
     (G[{0}, yw]^2*G[{1, 1/(yu*yv), 1/(yu*yv)}, yw])/16 - 
     (5*G[{0}, yu^(-1)]*G[{1}, yu^(-1)]*G[{1, 1/(yu*yv), 1/(yu*yv)}, yw])/
      16 - (5*G[{0}, yv^(-1)]*G[{1}, yu^(-1)]*G[{1, 1/(yu*yv), 1/(yu*yv)}, 
        yw])/16 + (5*G[{0}, yw]*G[{1}, yu^(-1)]*G[{1, 1/(yu*yv), 1/(yu*yv)}, 
        yw])/16 + (7*G[{1}, yu^(-1)]^2*G[{1, 1/(yu*yv), 1/(yu*yv)}, yw])/32 - 
     (G[{0}, yu^(-1)]*G[{1}, yv^(-1)]*G[{1, 1/(yu*yv), 1/(yu*yv)}, yw])/16 - 
     (G[{0}, yv^(-1)]*G[{1}, yv^(-1)]*G[{1, 1/(yu*yv), 1/(yu*yv)}, yw])/16 + 
     (G[{0}, yw]*G[{1}, yv^(-1)]*G[{1, 1/(yu*yv), 1/(yu*yv)}, yw])/16 + 
     (3*G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*G[{1, 1/(yu*yv), 1/(yu*yv)}, yw])/
      16 - (G[{0}, yu^(-1)]*G[{1}, yw]*G[{1, 1/(yu*yv), 1/(yu*yv)}, yw])/16 - 
     (G[{0}, yv^(-1)]*G[{1}, yw]*G[{1, 1/(yu*yv), 1/(yu*yv)}, yw])/16 + 
     (G[{0}, yw]*G[{1}, yw]*G[{1, 1/(yu*yv), 1/(yu*yv)}, yw])/16 + 
     (G[{1}, yu^(-1)]*G[{1}, yw]*G[{1, 1/(yu*yv), 1/(yu*yv)}, yw])/16 + 
     (G[{1}, yv^(-1)]*G[{1}, yw]*G[{1, 1/(yu*yv), 1/(yu*yv)}, yw])/8 + 
     (G[{1}, yw]^2*G[{1, 1/(yu*yv), 1/(yu*yv)}, yw])/32 + 
     (G[{0}, yu^(-1)]*G[{yu}, yv^(-1)]*G[{1, 1/(yu*yv), 1/(yu*yv)}, yw])/8 + 
     (G[{0}, yv^(-1)]*G[{yu}, yv^(-1)]*G[{1, 1/(yu*yv), 1/(yu*yv)}, yw])/8 - 
     (G[{0}, yw]*G[{yu}, yv^(-1)]*G[{1, 1/(yu*yv), 1/(yu*yv)}, yw])/8 - 
     (3*G[{1}, yv^(-1)]*G[{yu}, yv^(-1)]*G[{1, 1/(yu*yv), 1/(yu*yv)}, yw])/
      16 - (G[{1}, yw]*G[{yu}, yv^(-1)]*G[{1, 1/(yu*yv), 1/(yu*yv)}, yw])/
      16 - (G[{yu}, yv^(-1)]^2*G[{1, 1/(yu*yv), 1/(yu*yv)}, yw])/32 - 
     (G[{0}, yu^(-1)]*G[{1/(yu*yv)}, yw]*G[{1, 1/(yu*yv), 1/(yu*yv)}, yw])/
      16 - (G[{0}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{1, 1/(yu*yv), 1/(yu*yv)}, 
        yw])/16 + (G[{0}, yw]*G[{1/(yu*yv)}, yw]*G[{1, 1/(yu*yv), 1/(yu*yv)}, 
        yw])/16 + (G[{1}, yv^(-1)]*G[{1/(yu*yv)}, yw]*
       G[{1, 1/(yu*yv), 1/(yu*yv)}, yw])/8 - 
     (G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{1, 1/(yu*yv), 1/(yu*yv)}, yw])/
      8 - (G[{0, 1}, yu^(-1)]*G[{1, 1/(yu*yv), 1/(yu*yv)}, yw])/8 + 
     (G[{0, 1}, yw]*G[{1, 1/(yu*yv), 1/(yu*yv)}, yw])/16 - 
     (G[{0, yu^(-1)}, yw]*G[{1, 1/(yu*yv), 1/(yu*yv)}, yw])/16 - 
     (G[{0, yv^(-1)}, yw]*G[{1, 1/(yu*yv), 1/(yu*yv)}, yw])/16 + 
     (G[{0, 1/(yu*yv)}, yw]*G[{1, 1/(yu*yv), 1/(yu*yv)}, yw])/16 + 
     (G[{1, yu^(-1)}, yw]*G[{1, 1/(yu*yv), 1/(yu*yv)}, yw])/16 + 
     (G[{1, yu}, yv^(-1)]*G[{1, 1/(yu*yv), 1/(yu*yv)}, yw])/8 - 
     (G[{1, yv^(-1)}, yw]*G[{1, 1/(yu*yv), 1/(yu*yv)}, yw])/16 + 
     (G[{1, 1/(yu*yv)}, yw]*G[{1, 1/(yu*yv), 1/(yu*yv)}, yw])/8 + 
     (G[{yu^(-1), 1/(yu*yv)}, yw]*G[{1, 1/(yu*yv), 1/(yu*yv)}, yw])/8 + 
     (7*Pi^2*G[{yu^(-1), yu^(-1), 1/(yu*yv)}, yw])/768 + 
     (G[{0}, yu^(-1)]^2*G[{yu^(-1), yu^(-1), 1/(yu*yv)}, yw])/64 + 
     (G[{0}, yu^(-1)]*G[{0}, yv^(-1)]*G[{yu^(-1), yu^(-1), 1/(yu*yv)}, yw])/
      32 + (G[{0}, yv^(-1)]^2*G[{yu^(-1), yu^(-1), 1/(yu*yv)}, yw])/64 - 
     (G[{0}, yu^(-1)]*G[{0}, yw]*G[{yu^(-1), yu^(-1), 1/(yu*yv)}, yw])/32 - 
     (G[{0}, yv^(-1)]*G[{0}, yw]*G[{yu^(-1), yu^(-1), 1/(yu*yv)}, yw])/32 + 
     (G[{0}, yw]^2*G[{yu^(-1), yu^(-1), 1/(yu*yv)}, yw])/64 - 
     (G[{0}, yu^(-1)]*G[{1}, yu^(-1)]*G[{yu^(-1), yu^(-1), 1/(yu*yv)}, yw])/
      32 - (G[{0}, yv^(-1)]*G[{1}, yu^(-1)]*G[{yu^(-1), yu^(-1), 1/(yu*yv)}, 
        yw])/32 + (G[{0}, yw]*G[{1}, yu^(-1)]*
       G[{yu^(-1), yu^(-1), 1/(yu*yv)}, yw])/32 + 
     (G[{1}, yu^(-1)]^2*G[{yu^(-1), yu^(-1), 1/(yu*yv)}, yw])/64 - 
     (G[{0}, yu^(-1)]*G[{1}, yv^(-1)]*G[{yu^(-1), yu^(-1), 1/(yu*yv)}, yw])/
      32 - (G[{0}, yv^(-1)]*G[{1}, yv^(-1)]*G[{yu^(-1), yu^(-1), 1/(yu*yv)}, 
        yw])/32 + (G[{0}, yw]*G[{1}, yv^(-1)]*
       G[{yu^(-1), yu^(-1), 1/(yu*yv)}, yw])/32 + 
     (G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*G[{yu^(-1), yu^(-1), 1/(yu*yv)}, yw])/
      32 - (G[{1}, yv^(-1)]^2*G[{yu^(-1), yu^(-1), 1/(yu*yv)}, yw])/32 - 
     (3*G[{0}, yu^(-1)]*G[{1}, yw]*G[{yu^(-1), yu^(-1), 1/(yu*yv)}, yw])/16 - 
     (3*G[{0}, yv^(-1)]*G[{1}, yw]*G[{yu^(-1), yu^(-1), 1/(yu*yv)}, yw])/16 + 
     (3*G[{0}, yw]*G[{1}, yw]*G[{yu^(-1), yu^(-1), 1/(yu*yv)}, yw])/16 + 
     (3*G[{1}, yu^(-1)]*G[{1}, yw]*G[{yu^(-1), yu^(-1), 1/(yu*yv)}, yw])/16 + 
     (3*G[{1}, yv^(-1)]*G[{1}, yw]*G[{yu^(-1), yu^(-1), 1/(yu*yv)}, yw])/32 - 
     (3*G[{1}, yw]^2*G[{yu^(-1), yu^(-1), 1/(yu*yv)}, yw])/64 + 
     (7*G[{0}, yu^(-1)]*G[{yu^(-1)}, yw]*G[{yu^(-1), yu^(-1), 1/(yu*yv)}, 
        yw])/32 + (7*G[{0}, yv^(-1)]*G[{yu^(-1)}, yw]*
       G[{yu^(-1), yu^(-1), 1/(yu*yv)}, yw])/32 - 
     (7*G[{0}, yw]*G[{yu^(-1)}, yw]*G[{yu^(-1), yu^(-1), 1/(yu*yv)}, yw])/
      32 - (7*G[{1}, yu^(-1)]*G[{yu^(-1)}, yw]*
       G[{yu^(-1), yu^(-1), 1/(yu*yv)}, yw])/32 - 
     (11*G[{1}, yv^(-1)]*G[{yu^(-1)}, yw]*G[{yu^(-1), yu^(-1), 1/(yu*yv)}, 
        yw])/32 - (G[{1}, yw]*G[{yu^(-1)}, yw]*
       G[{yu^(-1), yu^(-1), 1/(yu*yv)}, yw])/8 + 
     (11*G[{yu^(-1)}, yw]^2*G[{yu^(-1), yu^(-1), 1/(yu*yv)}, yw])/64 - 
     (G[{1}, yv^(-1)]*G[{yu}, yv^(-1)]*G[{yu^(-1), yu^(-1), 1/(yu*yv)}, yw])/
      8 + (3*G[{1}, yw]*G[{yu}, yv^(-1)]*G[{yu^(-1), yu^(-1), 1/(yu*yv)}, 
        yw])/32 + (G[{yu^(-1)}, yw]*G[{yu}, yv^(-1)]*
       G[{yu^(-1), yu^(-1), 1/(yu*yv)}, yw])/8 + 
     (G[{yu}, yv^(-1)]^2*G[{yu^(-1), yu^(-1), 1/(yu*yv)}, yw])/16 + 
     (11*G[{0}, yu^(-1)]*G[{1/(yu*yv)}, yw]*G[{yu^(-1), yu^(-1), 1/(yu*yv)}, 
        yw])/64 + (11*G[{0}, yv^(-1)]*G[{1/(yu*yv)}, yw]*
       G[{yu^(-1), yu^(-1), 1/(yu*yv)}, yw])/64 - 
     (11*G[{0}, yw]*G[{1/(yu*yv)}, yw]*G[{yu^(-1), yu^(-1), 1/(yu*yv)}, yw])/
      64 - (11*G[{1}, yu^(-1)]*G[{1/(yu*yv)}, yw]*
       G[{yu^(-1), yu^(-1), 1/(yu*yv)}, yw])/64 - 
     (17*G[{1}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{yu^(-1), yu^(-1), 1/(yu*yv)}, 
        yw])/64 - (3*G[{1}, yw]*G[{1/(yu*yv)}, yw]*
       G[{yu^(-1), yu^(-1), 1/(yu*yv)}, yw])/32 + 
     (17*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{yu^(-1), yu^(-1), 1/(yu*yv)}, 
        yw])/64 + (3*G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw]*
       G[{yu^(-1), yu^(-1), 1/(yu*yv)}, yw])/32 + 
     (3*G[{1/(yu*yv)}, yw]^2*G[{yu^(-1), yu^(-1), 1/(yu*yv)}, yw])/64 + 
     (7*G[{0, 1}, yv^(-1)]*G[{yu^(-1), yu^(-1), 1/(yu*yv)}, yw])/32 - 
     (3*G[{0, 1}, yw]*G[{yu^(-1), yu^(-1), 1/(yu*yv)}, yw])/16 + 
     (3*G[{0, yu^(-1)}, yw]*G[{yu^(-1), yu^(-1), 1/(yu*yv)}, yw])/16 - 
     (7*G[{0, yu}, yv^(-1)]*G[{yu^(-1), yu^(-1), 1/(yu*yv)}, yw])/32 + 
     (3*G[{0, yv^(-1)}, yw]*G[{yu^(-1), yu^(-1), 1/(yu*yv)}, yw])/16 - 
     (3*G[{0, 1/(yu*yv)}, yw]*G[{yu^(-1), yu^(-1), 1/(yu*yv)}, yw])/16 + 
     (G[{1, yu^(-1)}, yw]*G[{yu^(-1), yu^(-1), 1/(yu*yv)}, yw])/32 + 
     (7*G[{1, yu}, yv^(-1)]*G[{yu^(-1), yu^(-1), 1/(yu*yv)}, yw])/32 - 
     (3*G[{1, yv^(-1)}, yw]*G[{yu^(-1), yu^(-1), 1/(yu*yv)}, yw])/16 - 
     (7*G[{1, 1/(yu*yv)}, yw]*G[{yu^(-1), yu^(-1), 1/(yu*yv)}, yw])/32 - 
     (7*G[{yu^(-1), 1/(yu*yv)}, yw]*G[{yu^(-1), yu^(-1), 1/(yu*yv)}, yw])/
      32 + (3*Pi^2*G[{yu^(-1), 1/(yu*yv), yv^(-1)}, yw])/256 - 
     (3*G[{0}, yu^(-1)]^2*G[{yu^(-1), 1/(yu*yv), yv^(-1)}, yw])/64 - 
     (3*G[{0}, yu^(-1)]*G[{0}, yv^(-1)]*G[{yu^(-1), 1/(yu*yv), yv^(-1)}, yw])/
      32 - (3*G[{0}, yv^(-1)]^2*G[{yu^(-1), 1/(yu*yv), yv^(-1)}, yw])/64 + 
     (3*G[{0}, yu^(-1)]*G[{0}, yw]*G[{yu^(-1), 1/(yu*yv), yv^(-1)}, yw])/32 + 
     (3*G[{0}, yv^(-1)]*G[{0}, yw]*G[{yu^(-1), 1/(yu*yv), yv^(-1)}, yw])/32 - 
     (3*G[{0}, yw]^2*G[{yu^(-1), 1/(yu*yv), yv^(-1)}, yw])/64 - 
     (G[{0}, yu^(-1)]*G[{1}, yu^(-1)]*G[{yu^(-1), 1/(yu*yv), yv^(-1)}, yw])/
      32 - (G[{0}, yv^(-1)]*G[{1}, yu^(-1)]*G[{yu^(-1), 1/(yu*yv), yv^(-1)}, 
        yw])/32 + (G[{0}, yw]*G[{1}, yu^(-1)]*
       G[{yu^(-1), 1/(yu*yv), yv^(-1)}, yw])/32 + 
     (5*G[{1}, yu^(-1)]^2*G[{yu^(-1), 1/(yu*yv), yv^(-1)}, yw])/64 + 
     (7*G[{0}, yu^(-1)]*G[{1}, yv^(-1)]*G[{yu^(-1), 1/(yu*yv), yv^(-1)}, yw])/
      32 + (7*G[{0}, yv^(-1)]*G[{1}, yv^(-1)]*
       G[{yu^(-1), 1/(yu*yv), yv^(-1)}, yw])/32 - 
     (7*G[{0}, yw]*G[{1}, yv^(-1)]*G[{yu^(-1), 1/(yu*yv), yv^(-1)}, yw])/32 - 
     (3*G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*G[{yu^(-1), 1/(yu*yv), yv^(-1)}, yw])/
      32 - (G[{1}, yv^(-1)]^2*G[{yu^(-1), 1/(yu*yv), yv^(-1)}, yw])/8 - 
     (G[{1}, yu^(-1)]*G[{1}, yw]*G[{yu^(-1), 1/(yu*yv), yv^(-1)}, yw])/8 - 
     (G[{1}, yv^(-1)]*G[{1}, yw]*G[{yu^(-1), 1/(yu*yv), yv^(-1)}, yw])/32 - 
     (5*G[{1}, yw]^2*G[{yu^(-1), 1/(yu*yv), yv^(-1)}, yw])/64 - 
     (7*G[{0}, yu^(-1)]*G[{yu^(-1)}, yw]*G[{yu^(-1), 1/(yu*yv), yv^(-1)}, 
        yw])/32 - (7*G[{0}, yv^(-1)]*G[{yu^(-1)}, yw]*
       G[{yu^(-1), 1/(yu*yv), yv^(-1)}, yw])/32 + 
     (7*G[{0}, yw]*G[{yu^(-1)}, yw]*G[{yu^(-1), 1/(yu*yv), yv^(-1)}, yw])/
      32 + (7*G[{1}, yu^(-1)]*G[{yu^(-1)}, yw]*
       G[{yu^(-1), 1/(yu*yv), yv^(-1)}, yw])/32 + 
     (7*G[{1}, yv^(-1)]*G[{yu^(-1)}, yw]*G[{yu^(-1), 1/(yu*yv), yv^(-1)}, 
        yw])/32 - (7*G[{yu^(-1)}, yw]^2*G[{yu^(-1), 1/(yu*yv), yv^(-1)}, yw])/
      64 + (5*G[{1}, yw]*G[{yu}, yv^(-1)]*G[{yu^(-1), 1/(yu*yv), yv^(-1)}, 
        yw])/32 - (11*G[{0}, yu^(-1)]*G[{1/(yu*yv)}, yw]*
       G[{yu^(-1), 1/(yu*yv), yv^(-1)}, yw])/64 - 
     (11*G[{0}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{yu^(-1), 1/(yu*yv), yv^(-1)}, 
        yw])/64 + (11*G[{0}, yw]*G[{1/(yu*yv)}, yw]*
       G[{yu^(-1), 1/(yu*yv), yv^(-1)}, yw])/64 + 
     (7*G[{1}, yu^(-1)]*G[{1/(yu*yv)}, yw]*G[{yu^(-1), 1/(yu*yv), yv^(-1)}, 
        yw])/64 + (17*G[{1}, yv^(-1)]*G[{1/(yu*yv)}, yw]*
       G[{yu^(-1), 1/(yu*yv), yv^(-1)}, yw])/64 + 
     (G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{yu^(-1), 1/(yu*yv), yv^(-1)}, yw])/
      32 - (17*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*
       G[{yu^(-1), 1/(yu*yv), yv^(-1)}, yw])/64 - 
     (G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{yu^(-1), 1/(yu*yv), yv^(-1)}, 
        yw])/32 + (G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*
       G[{yu^(-1), 1/(yu*yv), yv^(-1)}, yw])/16 - 
     (3*G[{1/(yu*yv)}, yw]^2*G[{yu^(-1), 1/(yu*yv), yv^(-1)}, yw])/64 + 
     (G[{0, 1}, yu^(-1)]*G[{yu^(-1), 1/(yu*yv), yv^(-1)}, yw])/8 + 
     (G[{0, 1}, yv^(-1)]*G[{yu^(-1), 1/(yu*yv), yv^(-1)}, yw])/32 - 
     (G[{0, yu}, yv^(-1)]*G[{yu^(-1), 1/(yu*yv), yv^(-1)}, yw])/32 + 
     (G[{1, yu^(-1)}, yw]*G[{yu^(-1), 1/(yu*yv), yv^(-1)}, yw])/32 - 
     (3*G[{1, yu}, yv^(-1)]*G[{yu^(-1), 1/(yu*yv), yv^(-1)}, yw])/32 + 
     (G[{1, yv^(-1)}, yw]*G[{yu^(-1), 1/(yu*yv), yv^(-1)}, yw])/8 - 
     (5*G[{1, 1/(yu*yv)}, yw]*G[{yu^(-1), 1/(yu*yv), yv^(-1)}, yw])/32 + 
     (G[{yu^(-1), 1/(yu*yv)}, yw]*G[{yu^(-1), 1/(yu*yv), yv^(-1)}, yw])/32 - 
     (G[{yv^(-1), 1/(yu*yv)}, yw]*G[{yu^(-1), 1/(yu*yv), yv^(-1)}, yw])/16 + 
     (7*Pi^2*G[{yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/256 + 
     (G[{0}, yu^(-1)]^2*G[{yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/8 + 
     (G[{0}, yu^(-1)]*G[{0}, yv^(-1)]*G[{yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/
      4 + (G[{0}, yv^(-1)]^2*G[{yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/8 - 
     (G[{0}, yu^(-1)]*G[{0}, yw]*G[{yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/4 - 
     (G[{0}, yv^(-1)]*G[{0}, yw]*G[{yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/4 + 
     (G[{0}, yw]^2*G[{yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/8 - 
     (G[{0}, yu^(-1)]*G[{1}, yu^(-1)]*G[{yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/
      4 - (G[{0}, yv^(-1)]*G[{1}, yu^(-1)]*G[{yu^(-1), 1/(yu*yv), 1/(yu*yv)}, 
        yw])/4 + (G[{0}, yw]*G[{1}, yu^(-1)]*
       G[{yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/4 + 
     (G[{1}, yu^(-1)]^2*G[{yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/16 - 
     (3*G[{0}, yu^(-1)]*G[{1}, yv^(-1)]*G[{yu^(-1), 1/(yu*yv), 1/(yu*yv)}, 
        yw])/8 - (3*G[{0}, yv^(-1)]*G[{1}, yv^(-1)]*
       G[{yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/8 + 
     (3*G[{0}, yw]*G[{1}, yv^(-1)]*G[{yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/
      8 + (3*G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*
       G[{yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/8 + 
     (29*G[{1}, yv^(-1)]^2*G[{yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/128 - 
     (7*G[{0}, yu^(-1)]*G[{1}, yw]*G[{yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/
      64 - (7*G[{0}, yv^(-1)]*G[{1}, yw]*G[{yu^(-1), 1/(yu*yv), 1/(yu*yv)}, 
        yw])/64 + (7*G[{0}, yw]*G[{1}, yw]*G[{yu^(-1), 1/(yu*yv), 1/(yu*yv)}, 
        yw])/64 - (G[{1}, yu^(-1)]*G[{1}, yw]*
       G[{yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/64 + 
     (G[{1}, yv^(-1)]*G[{1}, yw]*G[{yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/16 - 
     (11*G[{1}, yw]^2*G[{yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/128 + 
     (23*G[{0}, yu^(-1)]*G[{yu^(-1)}, yw]*G[{yu^(-1), 1/(yu*yv), 1/(yu*yv)}, 
        yw])/64 + (23*G[{0}, yv^(-1)]*G[{yu^(-1)}, yw]*
       G[{yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/64 - 
     (23*G[{0}, yw]*G[{yu^(-1)}, yw]*G[{yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/
      64 - (23*G[{1}, yu^(-1)]*G[{yu^(-1)}, yw]*
       G[{yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/64 - 
     (43*G[{1}, yv^(-1)]*G[{yu^(-1)}, yw]*G[{yu^(-1), 1/(yu*yv), 1/(yu*yv)}, 
        yw])/64 - (5*G[{1}, yw]*G[{yu^(-1)}, yw]*
       G[{yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/16 + 
     (43*G[{yu^(-1)}, yw]^2*G[{yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/128 + 
     (G[{0}, yu^(-1)]*G[{yu}, yv^(-1)]*G[{yu^(-1), 1/(yu*yv), 1/(yu*yv)}, 
        yw])/8 + (G[{0}, yv^(-1)]*G[{yu}, yv^(-1)]*
       G[{yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/8 - 
     (G[{0}, yw]*G[{yu}, yv^(-1)]*G[{yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/8 - 
     (5*G[{1}, yv^(-1)]*G[{yu}, yv^(-1)]*G[{yu^(-1), 1/(yu*yv), 1/(yu*yv)}, 
        yw])/16 + (11*G[{1}, yw]*G[{yu}, yv^(-1)]*
       G[{yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/64 + 
     (5*G[{yu^(-1)}, yw]*G[{yu}, yv^(-1)]*G[{yu^(-1), 1/(yu*yv), 1/(yu*yv)}, 
        yw])/16 + (G[{yu}, yv^(-1)]^2*G[{yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/
      32 + (G[{0}, yu^(-1)]*G[{1/(yu*yv)}, yw]*
       G[{yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/8 + 
     (G[{0}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{yu^(-1), 1/(yu*yv), 1/(yu*yv)}, 
        yw])/8 - (G[{0}, yw]*G[{1/(yu*yv)}, yw]*
       G[{yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/8 - 
     (G[{1}, yu^(-1)]*G[{1/(yu*yv)}, yw]*G[{yu^(-1), 1/(yu*yv), 1/(yu*yv)}, 
        yw])/16 - (9*G[{1}, yv^(-1)]*G[{1/(yu*yv)}, yw]*
       G[{yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/64 + 
     (3*G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/
      64 + (9*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*
       G[{yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/64 - 
     (3*G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw]*
       G[{yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/64 - 
     (G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{yu^(-1), 1/(yu*yv), 1/(yu*yv)}, 
        yw])/32 + (15*G[{0, 1}, yv^(-1)]*G[{yu^(-1), 1/(yu*yv), 1/(yu*yv)}, 
        yw])/64 + (G[{0, 1}, yw]*G[{yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/64 - 
     (G[{0, yu^(-1)}, yw]*G[{yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/64 - 
     (15*G[{0, yu}, yv^(-1)]*G[{yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/64 - 
     (G[{0, yv^(-1)}, yw]*G[{yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/64 + 
     (G[{0, 1/(yu*yv)}, yw]*G[{yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/64 + 
     (G[{1, yu^(-1)}, yw]*G[{yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/4 + 
     (15*G[{1, yu}, yv^(-1)]*G[{yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/64 + 
     (G[{1, yv^(-1)}, yw]*G[{yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/64 - 
     (15*G[{1, 1/(yu*yv)}, yw]*G[{yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/64 + 
     (7*G[{yu^(-1), 1/(yu*yv)}, yw]*G[{yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/
      32 + (G[{yv^(-1), 1/(yu*yv)}, yw]*G[{yu^(-1), 1/(yu*yv), 1/(yu*yv)}, 
        yw])/32 - (19*Pi^2*G[{yv^(-1), yv^(-1), 1/(yu*yv)}, yw])/256 - 
     (9*G[{0}, yu^(-1)]^2*G[{yv^(-1), yv^(-1), 1/(yu*yv)}, yw])/64 - 
     (9*G[{0}, yu^(-1)]*G[{0}, yv^(-1)]*G[{yv^(-1), yv^(-1), 1/(yu*yv)}, yw])/
      32 - (9*G[{0}, yv^(-1)]^2*G[{yv^(-1), yv^(-1), 1/(yu*yv)}, yw])/64 + 
     (9*G[{0}, yu^(-1)]*G[{0}, yw]*G[{yv^(-1), yv^(-1), 1/(yu*yv)}, yw])/32 + 
     (9*G[{0}, yv^(-1)]*G[{0}, yw]*G[{yv^(-1), yv^(-1), 1/(yu*yv)}, yw])/32 - 
     (9*G[{0}, yw]^2*G[{yv^(-1), yv^(-1), 1/(yu*yv)}, yw])/64 + 
     (21*G[{0}, yu^(-1)]*G[{1}, yu^(-1)]*G[{yv^(-1), yv^(-1), 1/(yu*yv)}, 
        yw])/32 + (21*G[{0}, yv^(-1)]*G[{1}, yu^(-1)]*
       G[{yv^(-1), yv^(-1), 1/(yu*yv)}, yw])/32 - 
     (21*G[{0}, yw]*G[{1}, yu^(-1)]*G[{yv^(-1), yv^(-1), 1/(yu*yv)}, yw])/
      32 - (29*G[{1}, yu^(-1)]^2*G[{yv^(-1), yv^(-1), 1/(yu*yv)}, yw])/64 - 
     (3*G[{0}, yu^(-1)]*G[{1}, yv^(-1)]*G[{yv^(-1), yv^(-1), 1/(yu*yv)}, yw])/
      32 - (3*G[{0}, yv^(-1)]*G[{1}, yv^(-1)]*
       G[{yv^(-1), yv^(-1), 1/(yu*yv)}, yw])/32 + 
     (3*G[{0}, yw]*G[{1}, yv^(-1)]*G[{yv^(-1), yv^(-1), 1/(yu*yv)}, yw])/32 - 
     (13*G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*G[{yv^(-1), yv^(-1), 1/(yu*yv)}, 
        yw])/32 + (3*G[{1}, yv^(-1)]^2*G[{yv^(-1), yv^(-1), 1/(yu*yv)}, yw])/
      16 + (G[{0}, yu^(-1)]*G[{1}, yw]*G[{yv^(-1), yv^(-1), 1/(yu*yv)}, yw])/
      8 + (G[{0}, yv^(-1)]*G[{1}, yw]*G[{yv^(-1), yv^(-1), 1/(yu*yv)}, yw])/
      8 - (G[{0}, yw]*G[{1}, yw]*G[{yv^(-1), yv^(-1), 1/(yu*yv)}, yw])/8 + 
     (G[{1}, yu^(-1)]*G[{1}, yw]*G[{yv^(-1), yv^(-1), 1/(yu*yv)}, yw])/8 - 
     (3*G[{1}, yv^(-1)]*G[{1}, yw]*G[{yv^(-1), yv^(-1), 1/(yu*yv)}, yw])/32 + 
     (9*G[{1}, yw]^2*G[{yv^(-1), yv^(-1), 1/(yu*yv)}, yw])/64 - 
     (G[{0}, yu^(-1)]*G[{yu^(-1)}, yw]*G[{yv^(-1), yv^(-1), 1/(yu*yv)}, yw])/
      32 - (G[{0}, yv^(-1)]*G[{yu^(-1)}, yw]*G[{yv^(-1), yv^(-1), 1/(yu*yv)}, 
        yw])/32 + (G[{0}, yw]*G[{yu^(-1)}, yw]*
       G[{yv^(-1), yv^(-1), 1/(yu*yv)}, yw])/32 + 
     (9*G[{1}, yu^(-1)]*G[{yu^(-1)}, yw]*G[{yv^(-1), yv^(-1), 1/(yu*yv)}, 
        yw])/32 - (7*G[{1}, yv^(-1)]*G[{yu^(-1)}, yw]*
       G[{yv^(-1), yv^(-1), 1/(yu*yv)}, yw])/32 + 
     (7*G[{yu^(-1)}, yw]^2*G[{yv^(-1), yv^(-1), 1/(yu*yv)}, yw])/64 - 
     (9*G[{1}, yw]*G[{yu}, yv^(-1)]*G[{yv^(-1), yv^(-1), 1/(yu*yv)}, yw])/
      32 - (25*G[{0}, yu^(-1)]*G[{yv^(-1)}, yw]*
       G[{yv^(-1), yv^(-1), 1/(yu*yv)}, yw])/32 - 
     (25*G[{0}, yv^(-1)]*G[{yv^(-1)}, yw]*G[{yv^(-1), yv^(-1), 1/(yu*yv)}, 
        yw])/32 + (25*G[{0}, yw]*G[{yv^(-1)}, yw]*
       G[{yv^(-1), yv^(-1), 1/(yu*yv)}, yw])/32 + 
     (41*G[{1}, yu^(-1)]*G[{yv^(-1)}, yw]*G[{yv^(-1), yv^(-1), 1/(yu*yv)}, 
        yw])/32 + (9*G[{1}, yv^(-1)]*G[{yv^(-1)}, yw]*
       G[{yv^(-1), yv^(-1), 1/(yu*yv)}, yw])/32 - 
     (9*G[{yu^(-1)}, yw]*G[{yv^(-1)}, yw]*G[{yv^(-1), yv^(-1), 1/(yu*yv)}, 
        yw])/32 - (41*G[{yv^(-1)}, yw]^2*G[{yv^(-1), yv^(-1), 1/(yu*yv)}, 
        yw])/64 - (17*G[{0}, yu^(-1)]*G[{1/(yu*yv)}, yw]*
       G[{yv^(-1), yv^(-1), 1/(yu*yv)}, yw])/64 - 
     (17*G[{0}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{yv^(-1), yv^(-1), 1/(yu*yv)}, 
        yw])/64 + (17*G[{0}, yw]*G[{1/(yu*yv)}, yw]*
       G[{yv^(-1), yv^(-1), 1/(yu*yv)}, yw])/64 + 
     (17*G[{1}, yu^(-1)]*G[{1/(yu*yv)}, yw]*G[{yv^(-1), yv^(-1), 1/(yu*yv)}, 
        yw])/64 - (G[{1}, yv^(-1)]*G[{1/(yu*yv)}, yw]*
       G[{yv^(-1), yv^(-1), 1/(yu*yv)}, yw])/64 - 
     (9*G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{yv^(-1), yv^(-1), 1/(yu*yv)}, yw])/
      32 + (G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*
       G[{yv^(-1), yv^(-1), 1/(yu*yv)}, yw])/64 + 
     (9*G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{yv^(-1), yv^(-1), 1/(yu*yv)}, 
        yw])/32 - (17*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*
       G[{yv^(-1), yv^(-1), 1/(yu*yv)}, yw])/64 + 
     (3*G[{1/(yu*yv)}, yw]^2*G[{yv^(-1), yv^(-1), 1/(yu*yv)}, yw])/64 - 
     (G[{0, 1}, yu^(-1)]*G[{yv^(-1), yv^(-1), 1/(yu*yv)}, yw])/4 - 
     (G[{0, 1}, yv^(-1)]*G[{yv^(-1), yv^(-1), 1/(yu*yv)}, yw])/32 + 
     (G[{0, 1}, yw]*G[{yv^(-1), yv^(-1), 1/(yu*yv)}, yw])/8 - 
     (G[{0, yu^(-1)}, yw]*G[{yv^(-1), yv^(-1), 1/(yu*yv)}, yw])/8 + 
     (G[{0, yu}, yv^(-1)]*G[{yv^(-1), yv^(-1), 1/(yu*yv)}, yw])/32 - 
     (G[{0, yv^(-1)}, yw]*G[{yv^(-1), yv^(-1), 1/(yu*yv)}, yw])/8 + 
     (G[{0, 1/(yu*yv)}, yw]*G[{yv^(-1), yv^(-1), 1/(yu*yv)}, yw])/8 + 
     (3*G[{1, yu^(-1)}, yw]*G[{yv^(-1), yv^(-1), 1/(yu*yv)}, yw])/32 + 
     (7*G[{1, yu}, yv^(-1)]*G[{yv^(-1), yv^(-1), 1/(yu*yv)}, yw])/32 - 
     (G[{1, yv^(-1)}, yw]*G[{yv^(-1), yv^(-1), 1/(yu*yv)}, yw])/8 + 
     (9*G[{1, 1/(yu*yv)}, yw]*G[{yv^(-1), yv^(-1), 1/(yu*yv)}, yw])/32 - 
     (5*G[{yu^(-1), 1/(yu*yv)}, yw]*G[{yv^(-1), yv^(-1), 1/(yu*yv)}, yw])/
      32 + (5*G[{yv^(-1), 1/(yu*yv)}, yw]*G[{yv^(-1), yv^(-1), 1/(yu*yv)}, 
        yw])/16 + (5*Pi^2*G[{yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/768 + 
     (7*G[{0}, yu^(-1)]*G[{1}, yu^(-1)]*G[{yv^(-1), 1/(yu*yv), 1/(yu*yv)}, 
        yw])/16 + (7*G[{0}, yv^(-1)]*G[{1}, yu^(-1)]*
       G[{yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/16 - 
     (7*G[{0}, yw]*G[{1}, yu^(-1)]*G[{yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/
      16 - (13*G[{1}, yu^(-1)]^2*G[{yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/32 - 
     (G[{0}, yu^(-1)]*G[{1}, yv^(-1)]*G[{yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/
      16 - (G[{0}, yv^(-1)]*G[{1}, yv^(-1)]*
       G[{yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/16 + 
     (G[{0}, yw]*G[{1}, yv^(-1)]*G[{yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/16 - 
     (G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*G[{yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/
      16 + (5*G[{1}, yv^(-1)]^2*G[{yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/128 + 
     (21*G[{0}, yu^(-1)]*G[{1}, yw]*G[{yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/
      64 + (21*G[{0}, yv^(-1)]*G[{1}, yw]*G[{yv^(-1), 1/(yu*yv), 1/(yu*yv)}, 
        yw])/64 - (21*G[{0}, yw]*G[{1}, yw]*
       G[{yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/64 - 
     (5*G[{1}, yu^(-1)]*G[{1}, yw]*G[{yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/
      64 - (3*G[{1}, yv^(-1)]*G[{1}, yw]*G[{yv^(-1), 1/(yu*yv), 1/(yu*yv)}, 
        yw])/16 + (25*G[{1}, yw]^2*G[{yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/
      128 + (7*G[{0}, yu^(-1)]*G[{yu^(-1)}, yw]*
       G[{yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/64 + 
     (7*G[{0}, yv^(-1)]*G[{yu^(-1)}, yw]*G[{yv^(-1), 1/(yu*yv), 1/(yu*yv)}, 
        yw])/64 - (7*G[{0}, yw]*G[{yu^(-1)}, yw]*
       G[{yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/64 + 
     (9*G[{1}, yu^(-1)]*G[{yu^(-1)}, yw]*G[{yv^(-1), 1/(yu*yv), 1/(yu*yv)}, 
        yw])/64 - (7*G[{1}, yv^(-1)]*G[{yu^(-1)}, yw]*
       G[{yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/64 + 
     (G[{1}, yw]*G[{yu^(-1)}, yw]*G[{yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/4 + 
     (7*G[{yu^(-1)}, yw]^2*G[{yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/128 - 
     (3*G[{0}, yu^(-1)]*G[{yu}, yv^(-1)]*G[{yv^(-1), 1/(yu*yv), 1/(yu*yv)}, 
        yw])/8 - (3*G[{0}, yv^(-1)]*G[{yu}, yv^(-1)]*
       G[{yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/8 + 
     (3*G[{0}, yw]*G[{yu}, yv^(-1)]*G[{yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/
      8 + (G[{1}, yv^(-1)]*G[{yu}, yv^(-1)]*
       G[{yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/4 - 
     (25*G[{1}, yw]*G[{yu}, yv^(-1)]*G[{yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/
      64 - (G[{yu^(-1)}, yw]*G[{yu}, yv^(-1)]*
       G[{yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/4 + 
     (G[{yu}, yv^(-1)]^2*G[{yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/4 - 
     (25*G[{0}, yu^(-1)]*G[{yv^(-1)}, yw]*G[{yv^(-1), 1/(yu*yv), 1/(yu*yv)}, 
        yw])/64 - (25*G[{0}, yv^(-1)]*G[{yv^(-1)}, yw]*
       G[{yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/64 + 
     (25*G[{0}, yw]*G[{yv^(-1)}, yw]*G[{yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/
      64 + (41*G[{1}, yu^(-1)]*G[{yv^(-1)}, yw]*
       G[{yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/64 + 
     (9*G[{1}, yv^(-1)]*G[{yv^(-1)}, yw]*G[{yv^(-1), 1/(yu*yv), 1/(yu*yv)}, 
        yw])/64 - (9*G[{yu^(-1)}, yw]*G[{yv^(-1)}, yw]*
       G[{yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/64 - 
     (41*G[{yv^(-1)}, yw]^2*G[{yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/128 + 
     (G[{0}, yu^(-1)]*G[{1/(yu*yv)}, yw]*G[{yv^(-1), 1/(yu*yv), 1/(yu*yv)}, 
        yw])/16 + (G[{0}, yv^(-1)]*G[{1/(yu*yv)}, yw]*
       G[{yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/16 - 
     (G[{0}, yw]*G[{1/(yu*yv)}, yw]*G[{yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/
      16 - (3*G[{1}, yu^(-1)]*G[{1/(yu*yv)}, yw]*
       G[{yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/16 - 
     (G[{1}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{yv^(-1), 1/(yu*yv), 1/(yu*yv)}, 
        yw])/64 - (5*G[{1}, yw]*G[{1/(yu*yv)}, yw]*
       G[{yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/64 + 
     (G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{yv^(-1), 1/(yu*yv), 1/(yu*yv)}, 
        yw])/64 + (5*G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw]*
       G[{yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/64 + 
     (3*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*
       G[{yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/16 + 
     (G[{0, 1}, yu^(-1)]*G[{yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/8 - 
     (G[{0, 1}, yv^(-1)]*G[{yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/64 - 
     (3*G[{0, 1}, yw]*G[{yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/64 + 
     (3*G[{0, yu^(-1)}, yw]*G[{yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/64 + 
     (G[{0, yu}, yv^(-1)]*G[{yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/64 + 
     (3*G[{0, yv^(-1)}, yw]*G[{yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/64 - 
     (3*G[{0, 1/(yu*yv)}, yw]*G[{yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/64 - 
     (G[{1, yu^(-1)}, yw]*G[{yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/16 - 
     (9*G[{1, yu}, yv^(-1)]*G[{yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/64 + 
     (5*G[{1, yv^(-1)}, yw]*G[{yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/64 - 
     (7*G[{1, 1/(yu*yv)}, yw]*G[{yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/64 + 
     (G[{yu^(-1), 1/(yu*yv)}, yw]*G[{yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/
      32 + (11*G[{yv^(-1), 1/(yu*yv)}, yw]*G[{yv^(-1), 1/(yu*yv), 1/(yu*yv)}, 
        yw])/64 - (9*G[{0}, yu^(-1)]*G[{0, 0, 0, 1}, yw])/64 - 
     (9*G[{0}, yv^(-1)]*G[{0, 0, 0, 1}, yw])/64 + 
     (9*G[{0}, yw]*G[{0, 0, 0, 1}, yw])/64 + 
     (9*G[{1}, yu^(-1)]*G[{0, 0, 0, 1}, yw])/64 + 
     (9*G[{1}, yv^(-1)]*G[{0, 0, 0, 1}, yw])/64 - 
     (9*G[{1}, yw]*G[{0, 0, 0, 1}, yw])/64 - 
     (9*G[{1/(yu*yv)}, yw]*G[{0, 0, 0, 1}, yw])/64 + 
     (9*G[{0}, yu^(-1)]*G[{0, 0, 0, yu^(-1)}, yw])/64 + 
     (9*G[{0}, yv^(-1)]*G[{0, 0, 0, yu^(-1)}, yw])/64 - 
     (9*G[{0}, yw]*G[{0, 0, 0, yu^(-1)}, yw])/64 - 
     (9*G[{1}, yu^(-1)]*G[{0, 0, 0, yu^(-1)}, yw])/64 - 
     (9*G[{1}, yv^(-1)]*G[{0, 0, 0, yu^(-1)}, yw])/64 + 
     (9*G[{1}, yw]*G[{0, 0, 0, yu^(-1)}, yw])/64 + 
     (9*G[{1/(yu*yv)}, yw]*G[{0, 0, 0, yu^(-1)}, yw])/64 + 
     (9*G[{0}, yu^(-1)]*G[{0, 0, 0, yv^(-1)}, yw])/64 + 
     (9*G[{0}, yv^(-1)]*G[{0, 0, 0, yv^(-1)}, yw])/64 - 
     (9*G[{0}, yw]*G[{0, 0, 0, yv^(-1)}, yw])/64 - 
     (9*G[{1}, yu^(-1)]*G[{0, 0, 0, yv^(-1)}, yw])/64 - 
     (9*G[{1}, yv^(-1)]*G[{0, 0, 0, yv^(-1)}, yw])/64 + 
     (9*G[{1}, yw]*G[{0, 0, 0, yv^(-1)}, yw])/64 + 
     (9*G[{1/(yu*yv)}, yw]*G[{0, 0, 0, yv^(-1)}, yw])/64 - 
     (9*G[{0}, yu^(-1)]*G[{0, 0, 0, 1/(yu*yv)}, yw])/64 - 
     (9*G[{0}, yv^(-1)]*G[{0, 0, 0, 1/(yu*yv)}, yw])/64 + 
     (9*G[{0}, yw]*G[{0, 0, 0, 1/(yu*yv)}, yw])/64 + 
     (9*G[{1}, yu^(-1)]*G[{0, 0, 0, 1/(yu*yv)}, yw])/64 + 
     (9*G[{1}, yv^(-1)]*G[{0, 0, 0, 1/(yu*yv)}, yw])/64 - 
     (9*G[{1}, yw]*G[{0, 0, 0, 1/(yu*yv)}, yw])/64 - 
     (9*G[{1/(yu*yv)}, yw]*G[{0, 0, 0, 1/(yu*yv)}, yw])/64 - 
     (G[{1}, yu^(-1)]*G[{0, 0, 1, 1}, yu^(-1)])/4 + 
     (G[{1}, yw]*G[{0, 0, 1, 1}, yu^(-1)])/4 + 
     (G[{0}, yu^(-1)]*G[{0, 0, 1, 1}, yv^(-1)])/8 + 
     (G[{0}, yv^(-1)]*G[{0, 0, 1, 1}, yv^(-1)])/8 - 
     (G[{0}, yw]*G[{0, 0, 1, 1}, yv^(-1)])/8 - 
     (G[{1}, yu^(-1)]*G[{0, 0, 1, 1}, yv^(-1)])/8 + 
     (G[{1}, yw]*G[{0, 0, 1, 1}, yv^(-1)])/8 - 
     (G[{0}, yu^(-1)]*G[{0, 0, 1, 1}, yw])/16 - 
     (G[{0}, yv^(-1)]*G[{0, 0, 1, 1}, yw])/16 + 
     (G[{0}, yw]*G[{0, 0, 1, 1}, yw])/16 + 
     (G[{1}, yu^(-1)]*G[{0, 0, 1, 1}, yw])/16 + 
     (G[{1}, yv^(-1)]*G[{0, 0, 1, 1}, yw])/4 + 
     (G[{1}, yw]*G[{0, 0, 1, 1}, yw])/32 - 
     (3*G[{yu}, yv^(-1)]*G[{0, 0, 1, 1}, yw])/16 - 
     (7*G[{1/(yu*yv)}, yw]*G[{0, 0, 1, 1}, yw])/32 + 
     (7*G[{0}, yu^(-1)]*G[{0, 0, 1, yu^(-1)}, yw])/64 + 
     (7*G[{0}, yv^(-1)]*G[{0, 0, 1, yu^(-1)}, yw])/64 - 
     (7*G[{0}, yw]*G[{0, 0, 1, yu^(-1)}, yw])/64 - 
     (7*G[{1}, yu^(-1)]*G[{0, 0, 1, yu^(-1)}, yw])/64 - 
     (7*G[{1}, yv^(-1)]*G[{0, 0, 1, yu^(-1)}, yw])/64 - 
     (11*G[{1}, yw]*G[{0, 0, 1, yu^(-1)}, yw])/64 + 
     (5*G[{1/(yu*yv)}, yw]*G[{0, 0, 1, yu^(-1)}, yw])/64 + 
     (G[{1}, yw]*G[{0, 0, 1, yu}, yv^(-1)])/8 - 
     (13*G[{0}, yu^(-1)]*G[{0, 0, 1, yv^(-1)}, yw])/64 - 
     (13*G[{0}, yv^(-1)]*G[{0, 0, 1, yv^(-1)}, yw])/64 + 
     (13*G[{0}, yw]*G[{0, 0, 1, yv^(-1)}, yw])/64 + 
     (25*G[{1}, yu^(-1)]*G[{0, 0, 1, yv^(-1)}, yw])/64 + 
     (G[{1}, yv^(-1)]*G[{0, 0, 1, yv^(-1)}, yw])/64 - 
     (11*G[{1}, yw]*G[{0, 0, 1, yv^(-1)}, yw])/64 + 
     (5*G[{1/(yu*yv)}, yw]*G[{0, 0, 1, yv^(-1)}, yw])/64 + 
     (G[{0}, yu^(-1)]*G[{0, 0, 1, 1/(yu*yv)}, yw])/16 + 
     (G[{0}, yv^(-1)]*G[{0, 0, 1, 1/(yu*yv)}, yw])/16 - 
     (G[{0}, yw]*G[{0, 0, 1, 1/(yu*yv)}, yw])/16 - 
     (5*G[{1}, yu^(-1)]*G[{0, 0, 1, 1/(yu*yv)}, yw])/16 + 
     (9*G[{1}, yw]*G[{0, 0, 1, 1/(yu*yv)}, yw])/32 + 
     (3*G[{yu}, yv^(-1)]*G[{0, 0, 1, 1/(yu*yv)}, yw])/16 - 
     (3*G[{1/(yu*yv)}, yw]*G[{0, 0, 1, 1/(yu*yv)}, yw])/32 + 
     (G[{0}, yu^(-1)]*G[{0, 0, yu^(-1), 1}, yw])/16 + 
     (G[{0}, yv^(-1)]*G[{0, 0, yu^(-1), 1}, yw])/16 - 
     (G[{0}, yw]*G[{0, 0, yu^(-1), 1}, yw])/16 - 
     (G[{1}, yu^(-1)]*G[{0, 0, yu^(-1), 1}, yw])/16 - 
     (9*G[{1}, yw]*G[{0, 0, yu^(-1), 1}, yw])/32 - 
     (G[{yu}, yv^(-1)]*G[{0, 0, yu^(-1), 1}, yw])/16 + 
     (3*G[{1/(yu*yv)}, yw]*G[{0, 0, yu^(-1), 1}, yw])/32 - 
     (7*G[{0}, yu^(-1)]*G[{0, 0, yu^(-1), yu^(-1)}, yw])/64 - 
     (7*G[{0}, yv^(-1)]*G[{0, 0, yu^(-1), yu^(-1)}, yw])/64 + 
     (7*G[{0}, yw]*G[{0, 0, yu^(-1), yu^(-1)}, yw])/64 + 
     (7*G[{1}, yu^(-1)]*G[{0, 0, yu^(-1), yu^(-1)}, yw])/64 + 
     (7*G[{1}, yv^(-1)]*G[{0, 0, yu^(-1), yu^(-1)}, yw])/64 + 
     (11*G[{1}, yw]*G[{0, 0, yu^(-1), yu^(-1)}, yw])/64 + 
     (3*G[{1/(yu*yv)}, yw]*G[{0, 0, yu^(-1), yu^(-1)}, yw])/64 + 
     (G[{0}, yu^(-1)]*G[{0, 0, yu^(-1), yv^(-1)}, yw])/64 + 
     (G[{0}, yv^(-1)]*G[{0, 0, yu^(-1), yv^(-1)}, yw])/64 - 
     (G[{0}, yw]*G[{0, 0, yu^(-1), yv^(-1)}, yw])/64 - 
     (9*G[{1}, yu^(-1)]*G[{0, 0, yu^(-1), yv^(-1)}, yw])/64 + 
     (7*G[{1}, yv^(-1)]*G[{0, 0, yu^(-1), yv^(-1)}, yw])/64 - 
     (5*G[{1}, yw]*G[{0, 0, yu^(-1), yv^(-1)}, yw])/64 - 
     (5*G[{1/(yu*yv)}, yw]*G[{0, 0, yu^(-1), yv^(-1)}, yw])/64 + 
     (G[{0}, yu^(-1)]*G[{0, 0, yu^(-1), 1/(yu*yv)}, yw])/8 + 
     (G[{0}, yv^(-1)]*G[{0, 0, yu^(-1), 1/(yu*yv)}, yw])/8 - 
     (G[{0}, yw]*G[{0, 0, yu^(-1), 1/(yu*yv)}, yw])/8 + 
     (G[{1}, yu^(-1)]*G[{0, 0, yu^(-1), 1/(yu*yv)}, yw])/16 - 
     (G[{1}, yv^(-1)]*G[{0, 0, yu^(-1), 1/(yu*yv)}, yw])/8 - 
     (G[{1}, yw]*G[{0, 0, yu^(-1), 1/(yu*yv)}, yw])/32 - 
     (3*G[{yu}, yv^(-1)]*G[{0, 0, yu^(-1), 1/(yu*yv)}, yw])/16 + 
     (3*G[{1/(yu*yv)}, yw]*G[{0, 0, yu^(-1), 1/(yu*yv)}, yw])/32 + 
     (G[{1}, yu^(-1)]*G[{0, 0, yu, 1}, yv^(-1)])/8 + 
     (G[{1}, yw]*G[{0, 0, yu, 1}, yv^(-1)])/8 - 
     (G[{0}, yu^(-1)]*G[{0, 0, yu, yu}, yv^(-1)])/8 - 
     (G[{0}, yv^(-1)]*G[{0, 0, yu, yu}, yv^(-1)])/8 + 
     (G[{0}, yw]*G[{0, 0, yu, yu}, yv^(-1)])/8 - 
     (G[{1}, yw]*G[{0, 0, yu, yu}, yv^(-1)])/8 - 
     (G[{0}, yu^(-1)]*G[{0, 0, yv^(-1), 1}, yw])/4 - 
     (G[{0}, yv^(-1)]*G[{0, 0, yv^(-1), 1}, yw])/4 + 
     (G[{0}, yw]*G[{0, 0, yv^(-1), 1}, yw])/4 + 
     (5*G[{1}, yu^(-1)]*G[{0, 0, yv^(-1), 1}, yw])/16 - 
     (9*G[{1}, yw]*G[{0, 0, yv^(-1), 1}, yw])/32 + 
     (3*G[{yu}, yv^(-1)]*G[{0, 0, yv^(-1), 1}, yw])/16 + 
     (3*G[{1/(yu*yv)}, yw]*G[{0, 0, yv^(-1), 1}, yw])/32 + 
     (G[{0}, yu^(-1)]*G[{0, 0, yv^(-1), yu^(-1)}, yw])/64 + 
     (G[{0}, yv^(-1)]*G[{0, 0, yv^(-1), yu^(-1)}, yw])/64 - 
     (G[{0}, yw]*G[{0, 0, yv^(-1), yu^(-1)}, yw])/64 - 
     (9*G[{1}, yu^(-1)]*G[{0, 0, yv^(-1), yu^(-1)}, yw])/64 + 
     (7*G[{1}, yv^(-1)]*G[{0, 0, yv^(-1), yu^(-1)}, yw])/64 - 
     (5*G[{1}, yw]*G[{0, 0, yv^(-1), yu^(-1)}, yw])/64 - 
     (5*G[{1/(yu*yv)}, yw]*G[{0, 0, yv^(-1), yu^(-1)}, yw])/64 + 
     (25*G[{0}, yu^(-1)]*G[{0, 0, yv^(-1), yv^(-1)}, yw])/64 + 
     (25*G[{0}, yv^(-1)]*G[{0, 0, yv^(-1), yv^(-1)}, yw])/64 - 
     (25*G[{0}, yw]*G[{0, 0, yv^(-1), yv^(-1)}, yw])/64 - 
     (41*G[{1}, yu^(-1)]*G[{0, 0, yv^(-1), yv^(-1)}, yw])/64 - 
     (9*G[{1}, yv^(-1)]*G[{0, 0, yv^(-1), yv^(-1)}, yw])/64 + 
     (19*G[{1}, yw]*G[{0, 0, yv^(-1), yv^(-1)}, yw])/64 + 
     (3*G[{1/(yu*yv)}, yw]*G[{0, 0, yv^(-1), yv^(-1)}, yw])/64 - 
     (G[{0}, yu^(-1)]*G[{0, 0, yv^(-1), 1/(yu*yv)}, yw])/16 - 
     (G[{0}, yv^(-1)]*G[{0, 0, yv^(-1), 1/(yu*yv)}, yw])/16 + 
     (G[{0}, yw]*G[{0, 0, yv^(-1), 1/(yu*yv)}, yw])/16 + 
     (5*G[{1}, yu^(-1)]*G[{0, 0, yv^(-1), 1/(yu*yv)}, yw])/16 - 
     (5*G[{1}, yw]*G[{0, 0, yv^(-1), 1/(yu*yv)}, yw])/32 - 
     (3*G[{yu}, yv^(-1)]*G[{0, 0, yv^(-1), 1/(yu*yv)}, yw])/16 + 
     (3*G[{1/(yu*yv)}, yw]*G[{0, 0, yv^(-1), 1/(yu*yv)}, yw])/32 + 
     (G[{0}, yu^(-1)]*G[{0, 0, 1/(yu*yv), 1}, yw])/4 + 
     (G[{0}, yv^(-1)]*G[{0, 0, 1/(yu*yv), 1}, yw])/4 - 
     (G[{0}, yw]*G[{0, 0, 1/(yu*yv), 1}, yw])/4 - 
     (5*G[{1}, yu^(-1)]*G[{0, 0, 1/(yu*yv), 1}, yw])/16 - 
     (G[{1}, yv^(-1)]*G[{0, 0, 1/(yu*yv), 1}, yw])/4 + 
     (17*G[{1}, yw]*G[{0, 0, 1/(yu*yv), 1}, yw])/32 + 
     (G[{yu}, yv^(-1)]*G[{0, 0, 1/(yu*yv), 1}, yw])/16 + 
     (G[{1/(yu*yv)}, yw]*G[{0, 0, 1/(yu*yv), 1}, yw])/32 - 
     (G[{0}, yu^(-1)]*G[{0, 0, 1/(yu*yv), yu^(-1)}, yw])/64 - 
     (G[{0}, yv^(-1)]*G[{0, 0, 1/(yu*yv), yu^(-1)}, yw])/64 + 
     (G[{0}, yw]*G[{0, 0, 1/(yu*yv), yu^(-1)}, yw])/64 + 
     (9*G[{1}, yu^(-1)]*G[{0, 0, 1/(yu*yv), yu^(-1)}, yw])/64 + 
     (9*G[{1}, yv^(-1)]*G[{0, 0, 1/(yu*yv), yu^(-1)}, yw])/64 - 
     (11*G[{1}, yw]*G[{0, 0, 1/(yu*yv), yu^(-1)}, yw])/64 - 
     (G[{yu}, yv^(-1)]*G[{0, 0, 1/(yu*yv), yu^(-1)}, yw])/4 - 
     (3*G[{1/(yu*yv)}, yw]*G[{0, 0, 1/(yu*yv), yu^(-1)}, yw])/64 - 
     (13*G[{0}, yu^(-1)]*G[{0, 0, 1/(yu*yv), yv^(-1)}, yw])/64 - 
     (13*G[{0}, yv^(-1)]*G[{0, 0, 1/(yu*yv), yv^(-1)}, yw])/64 + 
     (13*G[{0}, yw]*G[{0, 0, 1/(yu*yv), yv^(-1)}, yw])/64 + 
     (17*G[{1}, yu^(-1)]*G[{0, 0, 1/(yu*yv), yv^(-1)}, yw])/64 + 
     (9*G[{1}, yv^(-1)]*G[{0, 0, 1/(yu*yv), yv^(-1)}, yw])/64 - 
     (19*G[{1}, yw]*G[{0, 0, 1/(yu*yv), yv^(-1)}, yw])/64 - 
     (3*G[{1/(yu*yv)}, yw]*G[{0, 0, 1/(yu*yv), yv^(-1)}, yw])/64 - 
     (G[{0}, yu^(-1)]*G[{0, 0, 1/(yu*yv), 1/(yu*yv)}, yw])/8 - 
     (G[{0}, yv^(-1)]*G[{0, 0, 1/(yu*yv), 1/(yu*yv)}, yw])/8 + 
     (G[{0}, yw]*G[{0, 0, 1/(yu*yv), 1/(yu*yv)}, yw])/8 - 
     (G[{1}, yu^(-1)]*G[{0, 0, 1/(yu*yv), 1/(yu*yv)}, yw])/16 + 
     (G[{1}, yv^(-1)]*G[{0, 0, 1/(yu*yv), 1/(yu*yv)}, yw])/8 - 
     (3*G[{1}, yw]*G[{0, 0, 1/(yu*yv), 1/(yu*yv)}, yw])/32 + 
     (3*G[{yu}, yv^(-1)]*G[{0, 0, 1/(yu*yv), 1/(yu*yv)}, yw])/16 - 
     (3*G[{1/(yu*yv)}, yw]*G[{0, 0, 1/(yu*yv), 1/(yu*yv)}, yw])/32 + 
     (G[{1}, yv^(-1)]*G[{0, 1, 0, yu^(-1)}, yw])/8 - 
     (G[{1}, yw]*G[{0, 1, 0, yu^(-1)}, yw])/8 - 
     (G[{yu}, yv^(-1)]*G[{0, 1, 0, yu^(-1)}, yw])/8 + 
     (G[{1}, yw]*G[{0, 1, 0, yu}, yv^(-1)])/8 - 
     (G[{0}, yu^(-1)]*G[{0, 1, 0, yv^(-1)}, yw])/16 - 
     (G[{0}, yv^(-1)]*G[{0, 1, 0, yv^(-1)}, yw])/16 + 
     (G[{0}, yw]*G[{0, 1, 0, yv^(-1)}, yw])/16 + 
     (G[{1}, yu^(-1)]*G[{0, 1, 0, yv^(-1)}, yw])/16 + 
     (G[{1}, yv^(-1)]*G[{0, 1, 0, yv^(-1)}, yw])/16 - 
     (G[{1}, yw]*G[{0, 1, 0, yv^(-1)}, yw])/16 + 
     (G[{0}, yu^(-1)]*G[{0, 1, 0, 1/(yu*yv)}, yw])/16 + 
     (G[{0}, yv^(-1)]*G[{0, 1, 0, 1/(yu*yv)}, yw])/16 - 
     (G[{0}, yw]*G[{0, 1, 0, 1/(yu*yv)}, yw])/16 - 
     (G[{1}, yu^(-1)]*G[{0, 1, 0, 1/(yu*yv)}, yw])/16 - 
     (3*G[{1}, yv^(-1)]*G[{0, 1, 0, 1/(yu*yv)}, yw])/16 + 
     (3*G[{1}, yw]*G[{0, 1, 0, 1/(yu*yv)}, yw])/16 + 
     (G[{yu}, yv^(-1)]*G[{0, 1, 0, 1/(yu*yv)}, yw])/8 - 
     (3*G[{1}, yu^(-1)]*G[{0, 1, 1, 1}, yu^(-1)])/8 + 
     (3*G[{1}, yw]*G[{0, 1, 1, 1}, yu^(-1)])/8 + 
     (3*G[{0}, yu^(-1)]*G[{0, 1, 1, 1}, yv^(-1)])/16 + 
     (3*G[{0}, yv^(-1)]*G[{0, 1, 1, 1}, yv^(-1)])/16 - 
     (3*G[{0}, yw]*G[{0, 1, 1, 1}, yv^(-1)])/16 - 
     (5*G[{1}, yu^(-1)]*G[{0, 1, 1, 1}, yv^(-1)])/16 + 
     (3*G[{1}, yw]*G[{0, 1, 1, 1}, yv^(-1)])/16 - 
     (9*G[{0}, yu^(-1)]*G[{0, 1, 1, 1}, yw])/64 - 
     (9*G[{0}, yv^(-1)]*G[{0, 1, 1, 1}, yw])/64 + 
     (9*G[{0}, yw]*G[{0, 1, 1, 1}, yw])/64 + 
     (9*G[{1}, yu^(-1)]*G[{0, 1, 1, 1}, yw])/64 + 
     (17*G[{1}, yv^(-1)]*G[{0, 1, 1, 1}, yw])/64 - 
     (G[{1}, yw]*G[{0, 1, 1, 1}, yw])/16 - 
     (G[{yu}, yv^(-1)]*G[{0, 1, 1, 1}, yw])/8 - 
     (G[{1/(yu*yv)}, yw]*G[{0, 1, 1, 1}, yw])/8 + 
     (G[{0}, yu^(-1)]*G[{0, 1, 1, yu^(-1)}, yw])/64 + 
     (G[{0}, yv^(-1)]*G[{0, 1, 1, yu^(-1)}, yw])/64 - 
     (G[{0}, yw]*G[{0, 1, 1, yu^(-1)}, yw])/64 - 
     (G[{1}, yu^(-1)]*G[{0, 1, 1, yu^(-1)}, yw])/64 - 
     (9*G[{1}, yv^(-1)]*G[{0, 1, 1, yu^(-1)}, yw])/64 + 
     (7*G[{1}, yw]*G[{0, 1, 1, yu^(-1)}, yw])/32 + 
     (G[{yu}, yv^(-1)]*G[{0, 1, 1, yu^(-1)}, yw])/8 - 
     (3*G[{1/(yu*yv)}, yw]*G[{0, 1, 1, yu^(-1)}, yw])/32 + 
     (G[{0}, yu^(-1)]*G[{0, 1, 1, yu}, yv^(-1)])/16 + 
     (G[{0}, yv^(-1)]*G[{0, 1, 1, yu}, yv^(-1)])/16 - 
     (G[{0}, yw]*G[{0, 1, 1, yu}, yv^(-1)])/16 - 
     (G[{1}, yv^(-1)]*G[{0, 1, 1, yu}, yv^(-1)])/8 - 
     (G[{1}, yw]*G[{0, 1, 1, yu}, yv^(-1)])/16 + 
     (G[{1/(yu*yv)}, yw]*G[{0, 1, 1, yu}, yv^(-1)])/8 + 
     (5*G[{0}, yu^(-1)]*G[{0, 1, 1, yv^(-1)}, yw])/64 + 
     (5*G[{0}, yv^(-1)]*G[{0, 1, 1, yv^(-1)}, yw])/64 - 
     (5*G[{0}, yw]*G[{0, 1, 1, yv^(-1)}, yw])/64 - 
     (9*G[{1}, yu^(-1)]*G[{0, 1, 1, yv^(-1)}, yw])/64 - 
     (G[{1}, yv^(-1)]*G[{0, 1, 1, yv^(-1)}, yw])/64 + 
     (5*G[{1}, yw]*G[{0, 1, 1, yv^(-1)}, yw])/32 - 
     (3*G[{1/(yu*yv)}, yw]*G[{0, 1, 1, yv^(-1)}, yw])/32 + 
     (3*G[{0}, yu^(-1)]*G[{0, 1, 1, 1/(yu*yv)}, yw])/64 + 
     (3*G[{0}, yv^(-1)]*G[{0, 1, 1, 1/(yu*yv)}, yw])/64 - 
     (3*G[{0}, yw]*G[{0, 1, 1, 1/(yu*yv)}, yw])/64 + 
     (G[{1}, yu^(-1)]*G[{0, 1, 1, 1/(yu*yv)}, yw])/64 + 
     (13*G[{1}, yv^(-1)]*G[{0, 1, 1, 1/(yu*yv)}, yw])/64 - 
     (5*G[{yu}, yv^(-1)]*G[{0, 1, 1, 1/(yu*yv)}, yw])/16 + 
     (G[{0}, yu^(-1)]*G[{0, 1, yu^(-1), 1}, yw])/64 + 
     (G[{0}, yv^(-1)]*G[{0, 1, yu^(-1), 1}, yw])/64 - 
     (G[{0}, yw]*G[{0, 1, yu^(-1), 1}, yw])/64 - 
     (G[{1}, yu^(-1)]*G[{0, 1, yu^(-1), 1}, yw])/64 - 
     (9*G[{1}, yv^(-1)]*G[{0, 1, yu^(-1), 1}, yw])/64 + 
     (9*G[{1}, yw]*G[{0, 1, yu^(-1), 1}, yw])/32 + 
     (G[{yu}, yv^(-1)]*G[{0, 1, yu^(-1), 1}, yw])/8 - 
     (3*G[{1/(yu*yv)}, yw]*G[{0, 1, yu^(-1), 1}, yw])/32 + 
     (7*G[{0}, yu^(-1)]*G[{0, 1, yu^(-1), yu^(-1)}, yw])/32 + 
     (7*G[{0}, yv^(-1)]*G[{0, 1, yu^(-1), yu^(-1)}, yw])/32 - 
     (7*G[{0}, yw]*G[{0, 1, yu^(-1), yu^(-1)}, yw])/32 - 
     (7*G[{1}, yu^(-1)]*G[{0, 1, yu^(-1), yu^(-1)}, yw])/32 - 
     (7*G[{1}, yv^(-1)]*G[{0, 1, yu^(-1), yu^(-1)}, yw])/32 - 
     (13*G[{1}, yw]*G[{0, 1, yu^(-1), yu^(-1)}, yw])/64 + 
     (11*G[{1/(yu*yv)}, yw]*G[{0, 1, yu^(-1), yu^(-1)}, yw])/64 + 
     (3*G[{0}, yu^(-1)]*G[{0, 1, yu^(-1), yv^(-1)}, yw])/32 + 
     (3*G[{0}, yv^(-1)]*G[{0, 1, yu^(-1), yv^(-1)}, yw])/32 - 
     (3*G[{0}, yw]*G[{0, 1, yu^(-1), yv^(-1)}, yw])/32 + 
     (G[{1}, yu^(-1)]*G[{0, 1, yu^(-1), yv^(-1)}, yw])/32 - 
     (7*G[{1}, yv^(-1)]*G[{0, 1, yu^(-1), yv^(-1)}, yw])/32 - 
     (5*G[{1}, yw]*G[{0, 1, yu^(-1), yv^(-1)}, yw])/64 + 
     (11*G[{1/(yu*yv)}, yw]*G[{0, 1, yu^(-1), yv^(-1)}, yw])/64 - 
     (11*G[{0}, yu^(-1)]*G[{0, 1, yu^(-1), 1/(yu*yv)}, yw])/64 - 
     (11*G[{0}, yv^(-1)]*G[{0, 1, yu^(-1), 1/(yu*yv)}, yw])/64 + 
     (11*G[{0}, yw]*G[{0, 1, yu^(-1), 1/(yu*yv)}, yw])/64 - 
     (G[{1}, yu^(-1)]*G[{0, 1, yu^(-1), 1/(yu*yv)}, yw])/64 + 
     (15*G[{1}, yv^(-1)]*G[{0, 1, yu^(-1), 1/(yu*yv)}, yw])/64 - 
     (3*G[{1}, yw]*G[{0, 1, yu^(-1), 1/(yu*yv)}, yw])/32 + 
     (G[{yu}, yv^(-1)]*G[{0, 1, yu^(-1), 1/(yu*yv)}, yw])/8 - 
     (3*G[{1/(yu*yv)}, yw]*G[{0, 1, yu^(-1), 1/(yu*yv)}, yw])/32 + 
     (G[{0}, yu^(-1)]*G[{0, 1, yu, 1}, yv^(-1)])/16 + 
     (G[{0}, yv^(-1)]*G[{0, 1, yu, 1}, yv^(-1)])/16 - 
     (G[{0}, yw]*G[{0, 1, yu, 1}, yv^(-1)])/16 - 
     (G[{1}, yv^(-1)]*G[{0, 1, yu, 1}, yv^(-1)])/8 + 
     (G[{1/(yu*yv)}, yw]*G[{0, 1, yu, 1}, yv^(-1)])/8 + 
     (G[{1}, yv^(-1)]*G[{0, 1, yu, yu}, yv^(-1)])/8 - 
     (G[{1/(yu*yv)}, yw]*G[{0, 1, yu, yu}, yv^(-1)])/8 + 
     (17*G[{0}, yu^(-1)]*G[{0, 1, yv^(-1), 1}, yw])/64 + 
     (17*G[{0}, yv^(-1)]*G[{0, 1, yv^(-1), 1}, yw])/64 - 
     (17*G[{0}, yw]*G[{0, 1, yv^(-1), 1}, yw])/64 - 
     (17*G[{1}, yu^(-1)]*G[{0, 1, yv^(-1), 1}, yw])/64 - 
     (5*G[{1}, yv^(-1)]*G[{0, 1, yv^(-1), 1}, yw])/64 + 
     (9*G[{1}, yw]*G[{0, 1, yv^(-1), 1}, yw])/32 - 
     (3*G[{yu}, yv^(-1)]*G[{0, 1, yv^(-1), 1}, yw])/16 - 
     (3*G[{1/(yu*yv)}, yw]*G[{0, 1, yv^(-1), 1}, yw])/32 + 
     (3*G[{0}, yu^(-1)]*G[{0, 1, yv^(-1), yu^(-1)}, yw])/32 + 
     (3*G[{0}, yv^(-1)]*G[{0, 1, yv^(-1), yu^(-1)}, yw])/32 - 
     (3*G[{0}, yw]*G[{0, 1, yv^(-1), yu^(-1)}, yw])/32 + 
     (G[{1}, yu^(-1)]*G[{0, 1, yv^(-1), yu^(-1)}, yw])/32 - 
     (7*G[{1}, yv^(-1)]*G[{0, 1, yv^(-1), yu^(-1)}, yw])/32 - 
     (5*G[{1}, yw]*G[{0, 1, yv^(-1), yu^(-1)}, yw])/64 + 
     (11*G[{1/(yu*yv)}, yw]*G[{0, 1, yv^(-1), yu^(-1)}, yw])/64 - 
     (13*G[{0}, yu^(-1)]*G[{0, 1, yv^(-1), yv^(-1)}, yw])/32 - 
     (13*G[{0}, yv^(-1)]*G[{0, 1, yv^(-1), yv^(-1)}, yw])/32 + 
     (13*G[{0}, yw]*G[{0, 1, yv^(-1), yv^(-1)}, yw])/32 + 
     (25*G[{1}, yu^(-1)]*G[{0, 1, yv^(-1), yv^(-1)}, yw])/32 + 
     (G[{1}, yv^(-1)]*G[{0, 1, yv^(-1), yv^(-1)}, yw])/32 - 
     (21*G[{1}, yw]*G[{0, 1, yv^(-1), yv^(-1)}, yw])/64 + 
     (11*G[{1/(yu*yv)}, yw]*G[{0, 1, yv^(-1), yv^(-1)}, yw])/64 - 
     (7*G[{0}, yu^(-1)]*G[{0, 1, yv^(-1), 1/(yu*yv)}, yw])/64 - 
     (7*G[{0}, yv^(-1)]*G[{0, 1, yv^(-1), 1/(yu*yv)}, yw])/64 + 
     (7*G[{0}, yw]*G[{0, 1, yv^(-1), 1/(yu*yv)}, yw])/64 - 
     (9*G[{1}, yu^(-1)]*G[{0, 1, yv^(-1), 1/(yu*yv)}, yw])/64 + 
     (11*G[{1}, yv^(-1)]*G[{0, 1, yv^(-1), 1/(yu*yv)}, yw])/64 - 
     (3*G[{1}, yw]*G[{0, 1, yv^(-1), 1/(yu*yv)}, yw])/32 + 
     (3*G[{yu}, yv^(-1)]*G[{0, 1, yv^(-1), 1/(yu*yv)}, yw])/16 - 
     (3*G[{1/(yu*yv)}, yw]*G[{0, 1, yv^(-1), 1/(yu*yv)}, yw])/32 - 
     (9*G[{0}, yu^(-1)]*G[{0, 1, 1/(yu*yv), 1}, yw])/64 - 
     (9*G[{0}, yv^(-1)]*G[{0, 1, 1/(yu*yv), 1}, yw])/64 + 
     (9*G[{0}, yw]*G[{0, 1, 1/(yu*yv), 1}, yw])/64 + 
     (9*G[{1}, yu^(-1)]*G[{0, 1, 1/(yu*yv), 1}, yw])/64 + 
     (17*G[{1}, yv^(-1)]*G[{0, 1, 1/(yu*yv), 1}, yw])/64 - 
     (3*G[{1}, yw]*G[{0, 1, 1/(yu*yv), 1}, yw])/16 - 
     (G[{yu}, yv^(-1)]*G[{0, 1, 1/(yu*yv), 1}, yw])/8 - 
     (7*G[{0}, yu^(-1)]*G[{0, 1, 1/(yu*yv), yu^(-1)}, yw])/64 - 
     (7*G[{0}, yv^(-1)]*G[{0, 1, 1/(yu*yv), yu^(-1)}, yw])/64 + 
     (7*G[{0}, yw]*G[{0, 1, 1/(yu*yv), yu^(-1)}, yw])/64 - 
     (G[{1}, yu^(-1)]*G[{0, 1, 1/(yu*yv), yu^(-1)}, yw])/64 + 
     (7*G[{1}, yv^(-1)]*G[{0, 1, 1/(yu*yv), yu^(-1)}, yw])/64 + 
     (7*G[{1}, yw]*G[{0, 1, 1/(yu*yv), yu^(-1)}, yw])/32 + 
     (G[{yu}, yv^(-1)]*G[{0, 1, 1/(yu*yv), yu^(-1)}, yw])/8 - 
     (3*G[{1/(yu*yv)}, yw]*G[{0, 1, 1/(yu*yv), yu^(-1)}, yw])/32 + 
     (9*G[{0}, yu^(-1)]*G[{0, 1, 1/(yu*yv), yv^(-1)}, yw])/64 + 
     (9*G[{0}, yv^(-1)]*G[{0, 1, 1/(yu*yv), yv^(-1)}, yw])/64 - 
     (9*G[{0}, yw]*G[{0, 1, 1/(yu*yv), yv^(-1)}, yw])/64 - 
     (17*G[{1}, yu^(-1)]*G[{0, 1, 1/(yu*yv), yv^(-1)}, yw])/64 - 
     (G[{1}, yv^(-1)]*G[{0, 1, 1/(yu*yv), yv^(-1)}, yw])/64 + 
     (5*G[{1}, yw]*G[{0, 1, 1/(yu*yv), yv^(-1)}, yw])/32 - 
     (3*G[{1/(yu*yv)}, yw]*G[{0, 1, 1/(yu*yv), yv^(-1)}, yw])/32 + 
     (7*G[{0}, yu^(-1)]*G[{0, 1, 1/(yu*yv), 1/(yu*yv)}, yw])/64 + 
     (7*G[{0}, yv^(-1)]*G[{0, 1, 1/(yu*yv), 1/(yu*yv)}, yw])/64 - 
     (7*G[{0}, yw]*G[{0, 1, 1/(yu*yv), 1/(yu*yv)}, yw])/64 - 
     (15*G[{1}, yu^(-1)]*G[{0, 1, 1/(yu*yv), 1/(yu*yv)}, yw])/64 - 
     (3*G[{1}, yv^(-1)]*G[{0, 1, 1/(yu*yv), 1/(yu*yv)}, yw])/64 + 
     (G[{yu}, yv^(-1)]*G[{0, 1, 1/(yu*yv), 1/(yu*yv)}, yw])/16 + 
     (G[{0}, yu^(-1)]*G[{0, yu^(-1), 0, yv^(-1)}, yw])/16 + 
     (G[{0}, yv^(-1)]*G[{0, yu^(-1), 0, yv^(-1)}, yw])/16 - 
     (G[{0}, yw]*G[{0, yu^(-1), 0, yv^(-1)}, yw])/16 - 
     (G[{1}, yu^(-1)]*G[{0, yu^(-1), 0, yv^(-1)}, yw])/8 - 
     (G[{1}, yw]*G[{0, yu^(-1), 0, yv^(-1)}, yw])/16 - 
     (G[{0}, yu^(-1)]*G[{0, yu^(-1), 0, 1/(yu*yv)}, yw])/16 - 
     (G[{0}, yv^(-1)]*G[{0, yu^(-1), 0, 1/(yu*yv)}, yw])/16 + 
     (G[{0}, yw]*G[{0, yu^(-1), 0, 1/(yu*yv)}, yw])/16 + 
     (G[{1}, yu^(-1)]*G[{0, yu^(-1), 0, 1/(yu*yv)}, yw])/8 + 
     (G[{1}, yv^(-1)]*G[{0, yu^(-1), 0, 1/(yu*yv)}, yw])/8 - 
     (G[{1}, yw]*G[{0, yu^(-1), 0, 1/(yu*yv)}, yw])/16 - 
     (G[{yu}, yv^(-1)]*G[{0, yu^(-1), 0, 1/(yu*yv)}, yw])/8 + 
     (9*G[{0}, yu^(-1)]*G[{0, yu^(-1), 1, 1}, yw])/64 + 
     (9*G[{0}, yv^(-1)]*G[{0, yu^(-1), 1, 1}, yw])/64 - 
     (9*G[{0}, yw]*G[{0, yu^(-1), 1, 1}, yw])/64 - 
     (9*G[{1}, yu^(-1)]*G[{0, yu^(-1), 1, 1}, yw])/64 - 
     (17*G[{1}, yv^(-1)]*G[{0, yu^(-1), 1, 1}, yw])/64 + 
     (G[{1}, yw]*G[{0, yu^(-1), 1, 1}, yw])/16 + 
     (G[{yu}, yv^(-1)]*G[{0, yu^(-1), 1, 1}, yw])/8 - 
     (G[{0}, yu^(-1)]*G[{0, yu^(-1), 1, yu^(-1)}, yw])/64 - 
     (G[{0}, yv^(-1)]*G[{0, yu^(-1), 1, yu^(-1)}, yw])/64 + 
     (G[{0}, yw]*G[{0, yu^(-1), 1, yu^(-1)}, yw])/64 + 
     (G[{1}, yu^(-1)]*G[{0, yu^(-1), 1, yu^(-1)}, yw])/64 + 
     (9*G[{1}, yv^(-1)]*G[{0, yu^(-1), 1, yu^(-1)}, yw])/64 - 
     (7*G[{1}, yw]*G[{0, yu^(-1), 1, yu^(-1)}, yw])/32 - 
     (G[{yu}, yv^(-1)]*G[{0, yu^(-1), 1, yu^(-1)}, yw])/8 + 
     (3*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1), 1, yu^(-1)}, yw])/32 - 
     (G[{0}, yu^(-1)]*G[{0, yu^(-1), 1, yv^(-1)}, yw])/64 - 
     (G[{0}, yv^(-1)]*G[{0, yu^(-1), 1, yv^(-1)}, yw])/64 + 
     (G[{0}, yw]*G[{0, yu^(-1), 1, yv^(-1)}, yw])/64 + 
     (G[{1}, yu^(-1)]*G[{0, yu^(-1), 1, yv^(-1)}, yw])/64 + 
     (G[{1}, yv^(-1)]*G[{0, yu^(-1), 1, yv^(-1)}, yw])/64 - 
     (5*G[{1}, yw]*G[{0, yu^(-1), 1, yv^(-1)}, yw])/32 + 
     (3*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1), 1, yv^(-1)}, yw])/32 - 
     (3*G[{0}, yu^(-1)]*G[{0, yu^(-1), 1, 1/(yu*yv)}, yw])/64 - 
     (3*G[{0}, yv^(-1)]*G[{0, yu^(-1), 1, 1/(yu*yv)}, yw])/64 + 
     (3*G[{0}, yw]*G[{0, yu^(-1), 1, 1/(yu*yv)}, yw])/64 + 
     (7*G[{1}, yu^(-1)]*G[{0, yu^(-1), 1, 1/(yu*yv)}, yw])/64 - 
     (5*G[{1}, yv^(-1)]*G[{0, yu^(-1), 1, 1/(yu*yv)}, yw])/64 + 
     (G[{yu}, yv^(-1)]*G[{0, yu^(-1), 1, 1/(yu*yv)}, yw])/16 - 
     (G[{0}, yu^(-1)]*G[{0, yu^(-1), yu^(-1), 1}, yw])/64 - 
     (G[{0}, yv^(-1)]*G[{0, yu^(-1), yu^(-1), 1}, yw])/64 + 
     (G[{0}, yw]*G[{0, yu^(-1), yu^(-1), 1}, yw])/64 + 
     (G[{1}, yu^(-1)]*G[{0, yu^(-1), yu^(-1), 1}, yw])/64 + 
     (9*G[{1}, yv^(-1)]*G[{0, yu^(-1), yu^(-1), 1}, yw])/64 - 
     (9*G[{1}, yw]*G[{0, yu^(-1), yu^(-1), 1}, yw])/32 - 
     (G[{yu}, yv^(-1)]*G[{0, yu^(-1), yu^(-1), 1}, yw])/8 + 
     (3*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1), yu^(-1), 1}, yw])/32 - 
     (7*G[{0}, yu^(-1)]*G[{0, yu^(-1), yu^(-1), yu^(-1)}, yw])/32 - 
     (7*G[{0}, yv^(-1)]*G[{0, yu^(-1), yu^(-1), yu^(-1)}, yw])/32 + 
     (7*G[{0}, yw]*G[{0, yu^(-1), yu^(-1), yu^(-1)}, yw])/32 + 
     (7*G[{1}, yu^(-1)]*G[{0, yu^(-1), yu^(-1), yu^(-1)}, yw])/32 + 
     (7*G[{1}, yv^(-1)]*G[{0, yu^(-1), yu^(-1), yu^(-1)}, yw])/32 + 
     (13*G[{1}, yw]*G[{0, yu^(-1), yu^(-1), yu^(-1)}, yw])/64 - 
     (3*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1), yu^(-1), yu^(-1)}, yw])/64 - 
     (7*G[{0}, yu^(-1)]*G[{0, yu^(-1), yu^(-1), yv^(-1)}, yw])/32 - 
     (7*G[{0}, yv^(-1)]*G[{0, yu^(-1), yu^(-1), yv^(-1)}, yw])/32 + 
     (7*G[{0}, yw]*G[{0, yu^(-1), yu^(-1), yv^(-1)}, yw])/32 + 
     (7*G[{1}, yu^(-1)]*G[{0, yu^(-1), yu^(-1), yv^(-1)}, yw])/32 + 
     (7*G[{1}, yv^(-1)]*G[{0, yu^(-1), yu^(-1), yv^(-1)}, yw])/32 + 
     (5*G[{1}, yw]*G[{0, yu^(-1), yu^(-1), yv^(-1)}, yw])/64 - 
     (11*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1), yu^(-1), yv^(-1)}, yw])/64 + 
     (15*G[{0}, yu^(-1)]*G[{0, yu^(-1), yu^(-1), 1/(yu*yv)}, yw])/64 + 
     (15*G[{0}, yv^(-1)]*G[{0, yu^(-1), yu^(-1), 1/(yu*yv)}, yw])/64 - 
     (15*G[{0}, yw]*G[{0, yu^(-1), yu^(-1), 1/(yu*yv)}, yw])/64 - 
     (15*G[{1}, yu^(-1)]*G[{0, yu^(-1), yu^(-1), 1/(yu*yv)}, yw])/64 - 
     (23*G[{1}, yv^(-1)]*G[{0, yu^(-1), yu^(-1), 1/(yu*yv)}, yw])/64 + 
     (3*G[{1}, yw]*G[{0, yu^(-1), yu^(-1), 1/(yu*yv)}, yw])/32 + 
     (G[{yu}, yv^(-1)]*G[{0, yu^(-1), yu^(-1), 1/(yu*yv)}, yw])/8 + 
     (3*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1), yu^(-1), 1/(yu*yv)}, yw])/32 - 
     (5*G[{0}, yu^(-1)]*G[{0, yu^(-1), yv^(-1), 1}, yw])/64 - 
     (5*G[{0}, yv^(-1)]*G[{0, yu^(-1), yv^(-1), 1}, yw])/64 + 
     (5*G[{0}, yw]*G[{0, yu^(-1), yv^(-1), 1}, yw])/64 + 
     (G[{1}, yu^(-1)]*G[{0, yu^(-1), yv^(-1), 1}, yw])/64 + 
     (G[{1}, yv^(-1)]*G[{0, yu^(-1), yv^(-1), 1}, yw])/64 - 
     (9*G[{1}, yw]*G[{0, yu^(-1), yv^(-1), 1}, yw])/32 + 
     (G[{yu}, yv^(-1)]*G[{0, yu^(-1), yv^(-1), 1}, yw])/8 + 
     (3*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1), yv^(-1), 1}, yw])/32 - 
     (7*G[{0}, yu^(-1)]*G[{0, yu^(-1), yv^(-1), yu^(-1)}, yw])/32 - 
     (7*G[{0}, yv^(-1)]*G[{0, yu^(-1), yv^(-1), yu^(-1)}, yw])/32 + 
     (7*G[{0}, yw]*G[{0, yu^(-1), yv^(-1), yu^(-1)}, yw])/32 + 
     (7*G[{1}, yu^(-1)]*G[{0, yu^(-1), yv^(-1), yu^(-1)}, yw])/32 + 
     (7*G[{1}, yv^(-1)]*G[{0, yu^(-1), yv^(-1), yu^(-1)}, yw])/32 + 
     (5*G[{1}, yw]*G[{0, yu^(-1), yv^(-1), yu^(-1)}, yw])/64 - 
     (11*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1), yv^(-1), yu^(-1)}, yw])/64 + 
     (G[{0}, yu^(-1)]*G[{0, yu^(-1), yv^(-1), yv^(-1)}, yw])/32 + 
     (G[{0}, yv^(-1)]*G[{0, yu^(-1), yv^(-1), yv^(-1)}, yw])/32 - 
     (G[{0}, yw]*G[{0, yu^(-1), yv^(-1), yv^(-1)}, yw])/32 - 
     (9*G[{1}, yu^(-1)]*G[{0, yu^(-1), yv^(-1), yv^(-1)}, yw])/32 + 
     (7*G[{1}, yv^(-1)]*G[{0, yu^(-1), yv^(-1), yv^(-1)}, yw])/32 + 
     (5*G[{1}, yw]*G[{0, yu^(-1), yv^(-1), yv^(-1)}, yw])/64 - 
     (11*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1), yv^(-1), yv^(-1)}, yw])/64 + 
     (11*G[{0}, yu^(-1)]*G[{0, yu^(-1), yv^(-1), 1/(yu*yv)}, yw])/64 + 
     (11*G[{0}, yv^(-1)]*G[{0, yu^(-1), yv^(-1), 1/(yu*yv)}, yw])/64 - 
     (11*G[{0}, yw]*G[{0, yu^(-1), yv^(-1), 1/(yu*yv)}, yw])/64 + 
     (G[{1}, yu^(-1)]*G[{0, yu^(-1), yv^(-1), 1/(yu*yv)}, yw])/64 - 
     (15*G[{1}, yv^(-1)]*G[{0, yu^(-1), yv^(-1), 1/(yu*yv)}, yw])/64 + 
     (3*G[{1}, yw]*G[{0, yu^(-1), yv^(-1), 1/(yu*yv)}, yw])/32 - 
     (G[{yu}, yv^(-1)]*G[{0, yu^(-1), yv^(-1), 1/(yu*yv)}, yw])/8 + 
     (3*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1), yv^(-1), 1/(yu*yv)}, yw])/32 - 
     (3*G[{0}, yu^(-1)]*G[{0, yu^(-1), 1/(yu*yv), 1}, yw])/64 - 
     (3*G[{0}, yv^(-1)]*G[{0, yu^(-1), 1/(yu*yv), 1}, yw])/64 + 
     (3*G[{0}, yw]*G[{0, yu^(-1), 1/(yu*yv), 1}, yw])/64 + 
     (7*G[{1}, yu^(-1)]*G[{0, yu^(-1), 1/(yu*yv), 1}, yw])/64 + 
     (3*G[{1}, yv^(-1)]*G[{0, yu^(-1), 1/(yu*yv), 1}, yw])/64 - 
     (G[{1}, yw]*G[{0, yu^(-1), 1/(yu*yv), 1}, yw])/16 - 
     (G[{yu}, yv^(-1)]*G[{0, yu^(-1), 1/(yu*yv), 1}, yw])/16 + 
     (15*G[{0}, yu^(-1)]*G[{0, yu^(-1), 1/(yu*yv), yu^(-1)}, yw])/64 + 
     (15*G[{0}, yv^(-1)]*G[{0, yu^(-1), 1/(yu*yv), yu^(-1)}, yw])/64 - 
     (15*G[{0}, yw]*G[{0, yu^(-1), 1/(yu*yv), yu^(-1)}, yw])/64 - 
     (15*G[{1}, yu^(-1)]*G[{0, yu^(-1), 1/(yu*yv), yu^(-1)}, yw])/64 - 
     (23*G[{1}, yv^(-1)]*G[{0, yu^(-1), 1/(yu*yv), yu^(-1)}, yw])/64 + 
     (G[{1}, yw]*G[{0, yu^(-1), 1/(yu*yv), yu^(-1)}, yw])/32 + 
     (G[{yu}, yv^(-1)]*G[{0, yu^(-1), 1/(yu*yv), yu^(-1)}, yw])/8 + 
     (3*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1), 1/(yu*yv), yu^(-1)}, yw])/32 + 
     (7*G[{0}, yu^(-1)]*G[{0, yu^(-1), 1/(yu*yv), yv^(-1)}, yw])/64 + 
     (7*G[{0}, yv^(-1)]*G[{0, yu^(-1), 1/(yu*yv), yv^(-1)}, yw])/64 - 
     (7*G[{0}, yw]*G[{0, yu^(-1), 1/(yu*yv), yv^(-1)}, yw])/64 + 
     (G[{1}, yu^(-1)]*G[{0, yu^(-1), 1/(yu*yv), yv^(-1)}, yw])/64 - 
     (15*G[{1}, yv^(-1)]*G[{0, yu^(-1), 1/(yu*yv), yv^(-1)}, yw])/64 + 
     (3*G[{1}, yw]*G[{0, yu^(-1), 1/(yu*yv), yv^(-1)}, yw])/32 + 
     (3*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1), 1/(yu*yv), yv^(-1)}, yw])/32 - 
     (3*G[{0}, yu^(-1)]*G[{0, yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/64 - 
     (3*G[{0}, yv^(-1)]*G[{0, yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/64 + 
     (3*G[{0}, yw]*G[{0, yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/64 + 
     (7*G[{1}, yu^(-1)]*G[{0, yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/64 + 
     (7*G[{1}, yv^(-1)]*G[{0, yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/64 - 
     (G[{yu}, yv^(-1)]*G[{0, yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/8 + 
     (G[{0}, yu^(-1)]*G[{0, yu, 1, 1}, yv^(-1)])/16 + 
     (G[{0}, yv^(-1)]*G[{0, yu, 1, 1}, yv^(-1)])/16 - 
     (G[{0}, yw]*G[{0, yu, 1, 1}, yv^(-1)])/16 + 
     (3*G[{1}, yu^(-1)]*G[{0, yu, 1, 1}, yv^(-1)])/16 - 
     (G[{1}, yv^(-1)]*G[{0, yu, 1, 1}, yv^(-1)])/8 + 
     (G[{1}, yw]*G[{0, yu, 1, 1}, yv^(-1)])/16 + 
     (G[{1/(yu*yv)}, yw]*G[{0, yu, 1, 1}, yv^(-1)])/8 + 
     (G[{1}, yv^(-1)]*G[{0, yu, 1, yu}, yv^(-1)])/8 + 
     (G[{1}, yw]*G[{0, yu, 1, yu}, yv^(-1)])/16 - 
     (G[{1/(yu*yv)}, yw]*G[{0, yu, 1, yu}, yv^(-1)])/8 - 
     (G[{0}, yu^(-1)]*G[{0, yu, yu, 1}, yv^(-1)])/8 - 
     (G[{0}, yv^(-1)]*G[{0, yu, yu, 1}, yv^(-1)])/8 + 
     (G[{0}, yw]*G[{0, yu, yu, 1}, yv^(-1)])/8 + 
     (G[{1}, yu^(-1)]*G[{0, yu, yu, 1}, yv^(-1)])/8 + 
     (G[{1}, yv^(-1)]*G[{0, yu, yu, 1}, yv^(-1)])/8 - 
     (G[{1/(yu*yv)}, yw]*G[{0, yu, yu, 1}, yv^(-1)])/8 - 
     (G[{0}, yu^(-1)]*G[{0, yu, yu, yu}, yv^(-1)])/4 - 
     (G[{0}, yv^(-1)]*G[{0, yu, yu, yu}, yv^(-1)])/4 + 
     (G[{0}, yw]*G[{0, yu, yu, yu}, yv^(-1)])/4 - 
     (G[{1}, yw]*G[{0, yu, yu, yu}, yv^(-1)])/4 - 
     (G[{1}, yu^(-1)]*G[{0, yv^(-1), 0, 1/(yu*yv)}, yw])/16 + 
     (G[{1}, yv^(-1)]*G[{0, yv^(-1), 0, 1/(yu*yv)}, yw])/16 - 
     (G[{1}, yw]*G[{0, yv^(-1), 0, 1/(yu*yv)}, yw])/8 + 
     (G[{0}, yu^(-1)]*G[{0, yv^(-1), 1, 1}, yw])/64 + 
     (G[{0}, yv^(-1)]*G[{0, yv^(-1), 1, 1}, yw])/64 - 
     (G[{0}, yw]*G[{0, yv^(-1), 1, 1}, yw])/64 - 
     (G[{1}, yu^(-1)]*G[{0, yv^(-1), 1, 1}, yw])/64 - 
     (5*G[{1}, yv^(-1)]*G[{0, yv^(-1), 1, 1}, yw])/64 - 
     (G[{1}, yw]*G[{0, yv^(-1), 1, 1}, yw])/16 + 
     (G[{yu}, yv^(-1)]*G[{0, yv^(-1), 1, 1}, yw])/16 - 
     (G[{0}, yu^(-1)]*G[{0, yv^(-1), 1, yu^(-1)}, yw])/64 - 
     (G[{0}, yv^(-1)]*G[{0, yv^(-1), 1, yu^(-1)}, yw])/64 + 
     (G[{0}, yw]*G[{0, yv^(-1), 1, yu^(-1)}, yw])/64 + 
     (G[{1}, yu^(-1)]*G[{0, yv^(-1), 1, yu^(-1)}, yw])/64 - 
     (7*G[{1}, yv^(-1)]*G[{0, yv^(-1), 1, yu^(-1)}, yw])/64 - 
     (7*G[{1}, yw]*G[{0, yv^(-1), 1, yu^(-1)}, yw])/32 + 
     (G[{yu}, yv^(-1)]*G[{0, yv^(-1), 1, yu^(-1)}, yw])/8 + 
     (3*G[{1/(yu*yv)}, yw]*G[{0, yv^(-1), 1, yu^(-1)}, yw])/32 - 
     (13*G[{0}, yu^(-1)]*G[{0, yv^(-1), 1, yv^(-1)}, yw])/64 - 
     (13*G[{0}, yv^(-1)]*G[{0, yv^(-1), 1, yv^(-1)}, yw])/64 + 
     (13*G[{0}, yw]*G[{0, yv^(-1), 1, yv^(-1)}, yw])/64 + 
     (25*G[{1}, yu^(-1)]*G[{0, yv^(-1), 1, yv^(-1)}, yw])/64 + 
     (G[{1}, yv^(-1)]*G[{0, yv^(-1), 1, yv^(-1)}, yw])/64 - 
     (5*G[{1}, yw]*G[{0, yv^(-1), 1, yv^(-1)}, yw])/32 + 
     (3*G[{1/(yu*yv)}, yw]*G[{0, yv^(-1), 1, yv^(-1)}, yw])/32 - 
     (3*G[{0}, yu^(-1)]*G[{0, yv^(-1), 1, 1/(yu*yv)}, yw])/64 - 
     (3*G[{0}, yv^(-1)]*G[{0, yv^(-1), 1, 1/(yu*yv)}, yw])/64 + 
     (3*G[{0}, yw]*G[{0, yv^(-1), 1, 1/(yu*yv)}, yw])/64 - 
     (G[{1}, yu^(-1)]*G[{0, yv^(-1), 1, 1/(yu*yv)}, yw])/64 - 
     (G[{1}, yv^(-1)]*G[{0, yv^(-1), 1, 1/(yu*yv)}, yw])/64 + 
     (G[{yu}, yv^(-1)]*G[{0, yv^(-1), 1, 1/(yu*yv)}, yw])/8 - 
     (5*G[{0}, yu^(-1)]*G[{0, yv^(-1), yu^(-1), 1}, yw])/64 - 
     (5*G[{0}, yv^(-1)]*G[{0, yv^(-1), yu^(-1), 1}, yw])/64 + 
     (5*G[{0}, yw]*G[{0, yv^(-1), yu^(-1), 1}, yw])/64 + 
     (G[{1}, yu^(-1)]*G[{0, yv^(-1), yu^(-1), 1}, yw])/64 + 
     (G[{1}, yv^(-1)]*G[{0, yv^(-1), yu^(-1), 1}, yw])/64 - 
     (9*G[{1}, yw]*G[{0, yv^(-1), yu^(-1), 1}, yw])/32 + 
     (G[{yu}, yv^(-1)]*G[{0, yv^(-1), yu^(-1), 1}, yw])/8 + 
     (3*G[{1/(yu*yv)}, yw]*G[{0, yv^(-1), yu^(-1), 1}, yw])/32 - 
     (7*G[{0}, yu^(-1)]*G[{0, yv^(-1), yu^(-1), yu^(-1)}, yw])/32 - 
     (7*G[{0}, yv^(-1)]*G[{0, yv^(-1), yu^(-1), yu^(-1)}, yw])/32 + 
     (7*G[{0}, yw]*G[{0, yv^(-1), yu^(-1), yu^(-1)}, yw])/32 + 
     (7*G[{1}, yu^(-1)]*G[{0, yv^(-1), yu^(-1), yu^(-1)}, yw])/32 + 
     (7*G[{1}, yv^(-1)]*G[{0, yv^(-1), yu^(-1), yu^(-1)}, yw])/32 + 
     (5*G[{1}, yw]*G[{0, yv^(-1), yu^(-1), yu^(-1)}, yw])/64 - 
     (11*G[{1/(yu*yv)}, yw]*G[{0, yv^(-1), yu^(-1), yu^(-1)}, yw])/64 + 
     (G[{0}, yu^(-1)]*G[{0, yv^(-1), yu^(-1), yv^(-1)}, yw])/32 + 
     (G[{0}, yv^(-1)]*G[{0, yv^(-1), yu^(-1), yv^(-1)}, yw])/32 - 
     (G[{0}, yw]*G[{0, yv^(-1), yu^(-1), yv^(-1)}, yw])/32 - 
     (9*G[{1}, yu^(-1)]*G[{0, yv^(-1), yu^(-1), yv^(-1)}, yw])/32 + 
     (7*G[{1}, yv^(-1)]*G[{0, yv^(-1), yu^(-1), yv^(-1)}, yw])/32 + 
     (5*G[{1}, yw]*G[{0, yv^(-1), yu^(-1), yv^(-1)}, yw])/64 - 
     (11*G[{1/(yu*yv)}, yw]*G[{0, yv^(-1), yu^(-1), yv^(-1)}, yw])/64 + 
     (11*G[{0}, yu^(-1)]*G[{0, yv^(-1), yu^(-1), 1/(yu*yv)}, yw])/64 + 
     (11*G[{0}, yv^(-1)]*G[{0, yv^(-1), yu^(-1), 1/(yu*yv)}, yw])/64 - 
     (11*G[{0}, yw]*G[{0, yv^(-1), yu^(-1), 1/(yu*yv)}, yw])/64 + 
     (G[{1}, yu^(-1)]*G[{0, yv^(-1), yu^(-1), 1/(yu*yv)}, yw])/64 - 
     (15*G[{1}, yv^(-1)]*G[{0, yv^(-1), yu^(-1), 1/(yu*yv)}, yw])/64 + 
     (3*G[{1}, yw]*G[{0, yv^(-1), yu^(-1), 1/(yu*yv)}, yw])/32 - 
     (G[{yu}, yv^(-1)]*G[{0, yv^(-1), yu^(-1), 1/(yu*yv)}, yw])/8 + 
     (3*G[{1/(yu*yv)}, yw]*G[{0, yv^(-1), yu^(-1), 1/(yu*yv)}, yw])/32 - 
     (25*G[{0}, yu^(-1)]*G[{0, yv^(-1), yv^(-1), 1}, yw])/64 - 
     (25*G[{0}, yv^(-1)]*G[{0, yv^(-1), yv^(-1), 1}, yw])/64 + 
     (25*G[{0}, yw]*G[{0, yv^(-1), yv^(-1), 1}, yw])/64 + 
     (25*G[{1}, yu^(-1)]*G[{0, yv^(-1), yv^(-1), 1}, yw])/64 + 
     (9*G[{1}, yv^(-1)]*G[{0, yv^(-1), yv^(-1), 1}, yw])/64 - 
     (9*G[{1}, yw]*G[{0, yv^(-1), yv^(-1), 1}, yw])/32 + 
     (G[{yu}, yv^(-1)]*G[{0, yv^(-1), yv^(-1), 1}, yw])/4 + 
     (3*G[{1/(yu*yv)}, yw]*G[{0, yv^(-1), yv^(-1), 1}, yw])/32 + 
     (G[{0}, yu^(-1)]*G[{0, yv^(-1), yv^(-1), yu^(-1)}, yw])/32 + 
     (G[{0}, yv^(-1)]*G[{0, yv^(-1), yv^(-1), yu^(-1)}, yw])/32 - 
     (G[{0}, yw]*G[{0, yv^(-1), yv^(-1), yu^(-1)}, yw])/32 - 
     (9*G[{1}, yu^(-1)]*G[{0, yv^(-1), yv^(-1), yu^(-1)}, yw])/32 + 
     (7*G[{1}, yv^(-1)]*G[{0, yv^(-1), yv^(-1), yu^(-1)}, yw])/32 + 
     (5*G[{1}, yw]*G[{0, yv^(-1), yv^(-1), yu^(-1)}, yw])/64 - 
     (11*G[{1/(yu*yv)}, yw]*G[{0, yv^(-1), yv^(-1), yu^(-1)}, yw])/64 + 
     (25*G[{0}, yu^(-1)]*G[{0, yv^(-1), yv^(-1), yv^(-1)}, yw])/32 + 
     (25*G[{0}, yv^(-1)]*G[{0, yv^(-1), yv^(-1), yv^(-1)}, yw])/32 - 
     (25*G[{0}, yw]*G[{0, yv^(-1), yv^(-1), yv^(-1)}, yw])/32 - 
     (41*G[{1}, yu^(-1)]*G[{0, yv^(-1), yv^(-1), yv^(-1)}, yw])/32 - 
     (9*G[{1}, yv^(-1)]*G[{0, yv^(-1), yv^(-1), yv^(-1)}, yw])/32 + 
     (29*G[{1}, yw]*G[{0, yv^(-1), yv^(-1), yv^(-1)}, yw])/64 - 
     (3*G[{1/(yu*yv)}, yw]*G[{0, yv^(-1), yv^(-1), yv^(-1)}, yw])/64 - 
     (G[{0}, yu^(-1)]*G[{0, yv^(-1), yv^(-1), 1/(yu*yv)}, yw])/64 - 
     (G[{0}, yv^(-1)]*G[{0, yv^(-1), yv^(-1), 1/(yu*yv)}, yw])/64 + 
     (G[{0}, yw]*G[{0, yv^(-1), yv^(-1), 1/(yu*yv)}, yw])/64 + 
     (25*G[{1}, yu^(-1)]*G[{0, yv^(-1), yv^(-1), 1/(yu*yv)}, yw])/64 - 
     (7*G[{1}, yv^(-1)]*G[{0, yv^(-1), yv^(-1), 1/(yu*yv)}, yw])/64 + 
     (3*G[{1}, yw]*G[{0, yv^(-1), yv^(-1), 1/(yu*yv)}, yw])/32 - 
     (G[{yu}, yv^(-1)]*G[{0, yv^(-1), yv^(-1), 1/(yu*yv)}, yw])/4 + 
     (3*G[{1/(yu*yv)}, yw]*G[{0, yv^(-1), yv^(-1), 1/(yu*yv)}, yw])/32 + 
     (9*G[{0}, yu^(-1)]*G[{0, yv^(-1), 1/(yu*yv), 1}, yw])/64 + 
     (9*G[{0}, yv^(-1)]*G[{0, yv^(-1), 1/(yu*yv), 1}, yw])/64 - 
     (9*G[{0}, yw]*G[{0, yv^(-1), 1/(yu*yv), 1}, yw])/64 - 
     (G[{1}, yu^(-1)]*G[{0, yv^(-1), 1/(yu*yv), 1}, yw])/64 - 
     (9*G[{1}, yv^(-1)]*G[{0, yv^(-1), 1/(yu*yv), 1}, yw])/64 + 
     (G[{1}, yw]*G[{0, yv^(-1), 1/(yu*yv), 1}, yw])/16 - 
     (G[{yu}, yv^(-1)]*G[{0, yv^(-1), 1/(yu*yv), 1}, yw])/8 + 
     (7*G[{0}, yu^(-1)]*G[{0, yv^(-1), 1/(yu*yv), yu^(-1)}, yw])/64 + 
     (7*G[{0}, yv^(-1)]*G[{0, yv^(-1), 1/(yu*yv), yu^(-1)}, yw])/64 - 
     (7*G[{0}, yw]*G[{0, yv^(-1), 1/(yu*yv), yu^(-1)}, yw])/64 + 
     (G[{1}, yu^(-1)]*G[{0, yv^(-1), 1/(yu*yv), yu^(-1)}, yw])/64 - 
     (7*G[{1}, yv^(-1)]*G[{0, yv^(-1), 1/(yu*yv), yu^(-1)}, yw])/64 - 
     (3*G[{1}, yw]*G[{0, yv^(-1), 1/(yu*yv), yu^(-1)}, yw])/32 - 
     (G[{yu}, yv^(-1)]*G[{0, yv^(-1), 1/(yu*yv), yu^(-1)}, yw])/8 + 
     (3*G[{1/(yu*yv)}, yw]*G[{0, yv^(-1), 1/(yu*yv), yu^(-1)}, yw])/32 - 
     (13*G[{0}, yu^(-1)]*G[{0, yv^(-1), 1/(yu*yv), yv^(-1)}, yw])/64 - 
     (13*G[{0}, yv^(-1)]*G[{0, yv^(-1), 1/(yu*yv), yv^(-1)}, yw])/64 + 
     (13*G[{0}, yw]*G[{0, yv^(-1), 1/(yu*yv), yv^(-1)}, yw])/64 + 
     (25*G[{1}, yu^(-1)]*G[{0, yv^(-1), 1/(yu*yv), yv^(-1)}, yw])/64 + 
     (G[{1}, yv^(-1)]*G[{0, yv^(-1), 1/(yu*yv), yv^(-1)}, yw])/64 - 
     (G[{1}, yw]*G[{0, yv^(-1), 1/(yu*yv), yv^(-1)}, yw])/32 + 
     (3*G[{1/(yu*yv)}, yw]*G[{0, yv^(-1), 1/(yu*yv), yv^(-1)}, yw])/32 - 
     (7*G[{0}, yu^(-1)]*G[{0, yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/64 - 
     (7*G[{0}, yv^(-1)]*G[{0, yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/64 + 
     (7*G[{0}, yw]*G[{0, yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/64 + 
     (15*G[{1}, yu^(-1)]*G[{0, yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/64 + 
     (3*G[{1}, yv^(-1)]*G[{0, yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/64 - 
     (G[{yu}, yv^(-1)]*G[{0, yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/16 - 
     (G[{0}, yu^(-1)]*G[{0, 1/(yu*yv), 1, 1}, yw])/64 - 
     (G[{0}, yv^(-1)]*G[{0, 1/(yu*yv), 1, 1}, yw])/64 + 
     (G[{0}, yw]*G[{0, 1/(yu*yv), 1, 1}, yw])/64 + 
     (G[{1}, yu^(-1)]*G[{0, 1/(yu*yv), 1, 1}, yw])/64 + 
     (5*G[{1}, yv^(-1)]*G[{0, 1/(yu*yv), 1, 1}, yw])/64 + 
     (G[{1}, yw]*G[{0, 1/(yu*yv), 1, 1}, yw])/16 - 
     (G[{yu}, yv^(-1)]*G[{0, 1/(yu*yv), 1, 1}, yw])/16 + 
     (G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv), 1, 1}, yw])/8 + 
     (G[{0}, yu^(-1)]*G[{0, 1/(yu*yv), 1, yu^(-1)}, yw])/64 + 
     (G[{0}, yv^(-1)]*G[{0, 1/(yu*yv), 1, yu^(-1)}, yw])/64 - 
     (G[{0}, yw]*G[{0, 1/(yu*yv), 1, yu^(-1)}, yw])/64 - 
     (G[{1}, yu^(-1)]*G[{0, 1/(yu*yv), 1, yu^(-1)}, yw])/64 + 
     (7*G[{1}, yv^(-1)]*G[{0, 1/(yu*yv), 1, yu^(-1)}, yw])/64 + 
     (7*G[{1}, yw]*G[{0, 1/(yu*yv), 1, yu^(-1)}, yw])/32 - 
     (G[{yu}, yv^(-1)]*G[{0, 1/(yu*yv), 1, yu^(-1)}, yw])/8 - 
     (3*G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv), 1, yu^(-1)}, yw])/32 + 
     (9*G[{0}, yu^(-1)]*G[{0, 1/(yu*yv), 1, yv^(-1)}, yw])/64 + 
     (9*G[{0}, yv^(-1)]*G[{0, 1/(yu*yv), 1, yv^(-1)}, yw])/64 - 
     (9*G[{0}, yw]*G[{0, 1/(yu*yv), 1, yv^(-1)}, yw])/64 - 
     (17*G[{1}, yu^(-1)]*G[{0, 1/(yu*yv), 1, yv^(-1)}, yw])/64 - 
     (G[{1}, yv^(-1)]*G[{0, 1/(yu*yv), 1, yv^(-1)}, yw])/64 + 
     (5*G[{1}, yw]*G[{0, 1/(yu*yv), 1, yv^(-1)}, yw])/32 - 
     (3*G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv), 1, yv^(-1)}, yw])/32 + 
     (3*G[{0}, yu^(-1)]*G[{0, 1/(yu*yv), 1, 1/(yu*yv)}, yw])/64 + 
     (3*G[{0}, yv^(-1)]*G[{0, 1/(yu*yv), 1, 1/(yu*yv)}, yw])/64 - 
     (3*G[{0}, yw]*G[{0, 1/(yu*yv), 1, 1/(yu*yv)}, yw])/64 - 
     (7*G[{1}, yu^(-1)]*G[{0, 1/(yu*yv), 1, 1/(yu*yv)}, yw])/64 - 
     (7*G[{1}, yv^(-1)]*G[{0, 1/(yu*yv), 1, 1/(yu*yv)}, yw])/64 + 
     (G[{yu}, yv^(-1)]*G[{0, 1/(yu*yv), 1, 1/(yu*yv)}, yw])/8 + 
     (5*G[{0}, yu^(-1)]*G[{0, 1/(yu*yv), yu^(-1), 1}, yw])/64 + 
     (5*G[{0}, yv^(-1)]*G[{0, 1/(yu*yv), yu^(-1), 1}, yw])/64 - 
     (5*G[{0}, yw]*G[{0, 1/(yu*yv), yu^(-1), 1}, yw])/64 - 
     (G[{1}, yu^(-1)]*G[{0, 1/(yu*yv), yu^(-1), 1}, yw])/64 - 
     (G[{1}, yv^(-1)]*G[{0, 1/(yu*yv), yu^(-1), 1}, yw])/64 + 
     (9*G[{1}, yw]*G[{0, 1/(yu*yv), yu^(-1), 1}, yw])/32 - 
     (G[{yu}, yv^(-1)]*G[{0, 1/(yu*yv), yu^(-1), 1}, yw])/8 - 
     (3*G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv), yu^(-1), 1}, yw])/32 + 
     (7*G[{0}, yu^(-1)]*G[{0, 1/(yu*yv), yu^(-1), yu^(-1)}, yw])/32 + 
     (7*G[{0}, yv^(-1)]*G[{0, 1/(yu*yv), yu^(-1), yu^(-1)}, yw])/32 - 
     (7*G[{0}, yw]*G[{0, 1/(yu*yv), yu^(-1), yu^(-1)}, yw])/32 - 
     (7*G[{1}, yu^(-1)]*G[{0, 1/(yu*yv), yu^(-1), yu^(-1)}, yw])/32 - 
     (7*G[{1}, yv^(-1)]*G[{0, 1/(yu*yv), yu^(-1), yu^(-1)}, yw])/32 - 
     (5*G[{1}, yw]*G[{0, 1/(yu*yv), yu^(-1), yu^(-1)}, yw])/64 + 
     (3*G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv), yu^(-1), yu^(-1)}, yw])/64 + 
     (3*G[{0}, yu^(-1)]*G[{0, 1/(yu*yv), yu^(-1), yv^(-1)}, yw])/32 + 
     (3*G[{0}, yv^(-1)]*G[{0, 1/(yu*yv), yu^(-1), yv^(-1)}, yw])/32 - 
     (3*G[{0}, yw]*G[{0, 1/(yu*yv), yu^(-1), yv^(-1)}, yw])/32 + 
     (G[{1}, yu^(-1)]*G[{0, 1/(yu*yv), yu^(-1), yv^(-1)}, yw])/32 - 
     (7*G[{1}, yv^(-1)]*G[{0, 1/(yu*yv), yu^(-1), yv^(-1)}, yw])/32 - 
     (5*G[{1}, yw]*G[{0, 1/(yu*yv), yu^(-1), yv^(-1)}, yw])/64 + 
     (11*G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv), yu^(-1), yv^(-1)}, yw])/64 - 
     (15*G[{0}, yu^(-1)]*G[{0, 1/(yu*yv), yu^(-1), 1/(yu*yv)}, yw])/64 - 
     (15*G[{0}, yv^(-1)]*G[{0, 1/(yu*yv), yu^(-1), 1/(yu*yv)}, yw])/64 + 
     (15*G[{0}, yw]*G[{0, 1/(yu*yv), yu^(-1), 1/(yu*yv)}, yw])/64 + 
     (15*G[{1}, yu^(-1)]*G[{0, 1/(yu*yv), yu^(-1), 1/(yu*yv)}, yw])/64 + 
     (23*G[{1}, yv^(-1)]*G[{0, 1/(yu*yv), yu^(-1), 1/(yu*yv)}, yw])/64 - 
     (3*G[{1}, yw]*G[{0, 1/(yu*yv), yu^(-1), 1/(yu*yv)}, yw])/32 - 
     (G[{yu}, yv^(-1)]*G[{0, 1/(yu*yv), yu^(-1), 1/(yu*yv)}, yw])/8 - 
     (3*G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv), yu^(-1), 1/(yu*yv)}, yw])/32 + 
     (13*G[{0}, yu^(-1)]*G[{0, 1/(yu*yv), yv^(-1), 1}, yw])/64 + 
     (13*G[{0}, yv^(-1)]*G[{0, 1/(yu*yv), yv^(-1), 1}, yw])/64 - 
     (13*G[{0}, yw]*G[{0, 1/(yu*yv), yv^(-1), 1}, yw])/64 - 
     (9*G[{1}, yu^(-1)]*G[{0, 1/(yu*yv), yv^(-1), 1}, yw])/64 - 
     (5*G[{1}, yv^(-1)]*G[{0, 1/(yu*yv), yv^(-1), 1}, yw])/64 + 
     (9*G[{1}, yw]*G[{0, 1/(yu*yv), yv^(-1), 1}, yw])/32 - 
     (3*G[{yu}, yv^(-1)]*G[{0, 1/(yu*yv), yv^(-1), 1}, yw])/16 - 
     (3*G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv), yv^(-1), 1}, yw])/32 + 
     (3*G[{0}, yu^(-1)]*G[{0, 1/(yu*yv), yv^(-1), yu^(-1)}, yw])/32 + 
     (3*G[{0}, yv^(-1)]*G[{0, 1/(yu*yv), yv^(-1), yu^(-1)}, yw])/32 - 
     (3*G[{0}, yw]*G[{0, 1/(yu*yv), yv^(-1), yu^(-1)}, yw])/32 + 
     (G[{1}, yu^(-1)]*G[{0, 1/(yu*yv), yv^(-1), yu^(-1)}, yw])/32 - 
     (7*G[{1}, yv^(-1)]*G[{0, 1/(yu*yv), yv^(-1), yu^(-1)}, yw])/32 - 
     (5*G[{1}, yw]*G[{0, 1/(yu*yv), yv^(-1), yu^(-1)}, yw])/64 + 
     (11*G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv), yv^(-1), yu^(-1)}, yw])/64 - 
     (13*G[{0}, yu^(-1)]*G[{0, 1/(yu*yv), yv^(-1), yv^(-1)}, yw])/32 - 
     (13*G[{0}, yv^(-1)]*G[{0, 1/(yu*yv), yv^(-1), yv^(-1)}, yw])/32 + 
     (13*G[{0}, yw]*G[{0, 1/(yu*yv), yv^(-1), yv^(-1)}, yw])/32 + 
     (25*G[{1}, yu^(-1)]*G[{0, 1/(yu*yv), yv^(-1), yv^(-1)}, yw])/32 + 
     (G[{1}, yv^(-1)]*G[{0, 1/(yu*yv), yv^(-1), yv^(-1)}, yw])/32 - 
     (13*G[{1}, yw]*G[{0, 1/(yu*yv), yv^(-1), yv^(-1)}, yw])/64 + 
     (3*G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv), yv^(-1), yv^(-1)}, yw])/64 - 
     (3*G[{0}, yu^(-1)]*G[{0, 1/(yu*yv), yv^(-1), 1/(yu*yv)}, yw])/64 - 
     (3*G[{0}, yv^(-1)]*G[{0, 1/(yu*yv), yv^(-1), 1/(yu*yv)}, yw])/64 + 
     (3*G[{0}, yw]*G[{0, 1/(yu*yv), yv^(-1), 1/(yu*yv)}, yw])/64 - 
     (17*G[{1}, yu^(-1)]*G[{0, 1/(yu*yv), yv^(-1), 1/(yu*yv)}, yw])/64 + 
     (11*G[{1}, yv^(-1)]*G[{0, 1/(yu*yv), yv^(-1), 1/(yu*yv)}, yw])/64 - 
     (3*G[{1}, yw]*G[{0, 1/(yu*yv), yv^(-1), 1/(yu*yv)}, yw])/32 + 
     (3*G[{yu}, yv^(-1)]*G[{0, 1/(yu*yv), yv^(-1), 1/(yu*yv)}, yw])/16 - 
     (3*G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv), yv^(-1), 1/(yu*yv)}, yw])/32 + 
     (3*G[{0}, yu^(-1)]*G[{0, 1/(yu*yv), 1/(yu*yv), 1}, yw])/64 + 
     (3*G[{0}, yv^(-1)]*G[{0, 1/(yu*yv), 1/(yu*yv), 1}, yw])/64 - 
     (3*G[{0}, yw]*G[{0, 1/(yu*yv), 1/(yu*yv), 1}, yw])/64 - 
     (15*G[{1}, yu^(-1)]*G[{0, 1/(yu*yv), 1/(yu*yv), 1}, yw])/64 - 
     (11*G[{1}, yv^(-1)]*G[{0, 1/(yu*yv), 1/(yu*yv), 1}, yw])/64 + 
     (3*G[{1}, yw]*G[{0, 1/(yu*yv), 1/(yu*yv), 1}, yw])/16 + 
     (5*G[{yu}, yv^(-1)]*G[{0, 1/(yu*yv), 1/(yu*yv), 1}, yw])/16 - 
     (15*G[{0}, yu^(-1)]*G[{0, 1/(yu*yv), 1/(yu*yv), yu^(-1)}, yw])/64 - 
     (15*G[{0}, yv^(-1)]*G[{0, 1/(yu*yv), 1/(yu*yv), yu^(-1)}, yw])/64 + 
     (15*G[{0}, yw]*G[{0, 1/(yu*yv), 1/(yu*yv), yu^(-1)}, yw])/64 + 
     (15*G[{1}, yu^(-1)]*G[{0, 1/(yu*yv), 1/(yu*yv), yu^(-1)}, yw])/64 + 
     (23*G[{1}, yv^(-1)]*G[{0, 1/(yu*yv), 1/(yu*yv), yu^(-1)}, yw])/64 - 
     (5*G[{1}, yw]*G[{0, 1/(yu*yv), 1/(yu*yv), yu^(-1)}, yw])/32 - 
     (G[{yu}, yv^(-1)]*G[{0, 1/(yu*yv), 1/(yu*yv), yu^(-1)}, yw])/8 - 
     (3*G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv), 1/(yu*yv), yu^(-1)}, yw])/32 - 
     (3*G[{0}, yu^(-1)]*G[{0, 1/(yu*yv), 1/(yu*yv), yv^(-1)}, yw])/64 - 
     (3*G[{0}, yv^(-1)]*G[{0, 1/(yu*yv), 1/(yu*yv), yv^(-1)}, yw])/64 + 
     (3*G[{0}, yw]*G[{0, 1/(yu*yv), 1/(yu*yv), yv^(-1)}, yw])/64 - 
     (9*G[{1}, yu^(-1)]*G[{0, 1/(yu*yv), 1/(yu*yv), yv^(-1)}, yw])/64 + 
     (15*G[{1}, yv^(-1)]*G[{0, 1/(yu*yv), 1/(yu*yv), yv^(-1)}, yw])/64 - 
     (7*G[{1}, yw]*G[{0, 1/(yu*yv), 1/(yu*yv), yv^(-1)}, yw])/32 - 
     (3*G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv), 1/(yu*yv), yv^(-1)}, yw])/32 + 
     (3*G[{0}, yu^(-1)]*G[{0, 1/(yu*yv), 1/(yu*yv), 1/(yu*yv)}, yw])/64 + 
     (3*G[{0}, yv^(-1)]*G[{0, 1/(yu*yv), 1/(yu*yv), 1/(yu*yv)}, yw])/64 - 
     (3*G[{0}, yw]*G[{0, 1/(yu*yv), 1/(yu*yv), 1/(yu*yv)}, yw])/64 - 
     (7*G[{1}, yu^(-1)]*G[{0, 1/(yu*yv), 1/(yu*yv), 1/(yu*yv)}, yw])/64 - 
     (7*G[{1}, yv^(-1)]*G[{0, 1/(yu*yv), 1/(yu*yv), 1/(yu*yv)}, yw])/64 + 
     (G[{yu}, yv^(-1)]*G[{0, 1/(yu*yv), 1/(yu*yv), 1/(yu*yv)}, yw])/8 - 
     (29*G[{0}, yu^(-1)]*G[{1, 1, 1, yu^(-1)}, yw])/64 - 
     (29*G[{0}, yv^(-1)]*G[{1, 1, 1, yu^(-1)}, yw])/64 + 
     (29*G[{0}, yw]*G[{1, 1, 1, yu^(-1)}, yw])/64 + 
     (29*G[{1}, yu^(-1)]*G[{1, 1, 1, yu^(-1)}, yw])/64 + 
     (41*G[{1}, yv^(-1)]*G[{1, 1, 1, yu^(-1)}, yw])/64 + 
     (3*G[{1}, yw]*G[{1, 1, 1, yu^(-1)}, yw])/16 - 
     (3*G[{yu}, yv^(-1)]*G[{1, 1, 1, yu^(-1)}, yw])/16 - 
     (G[{1/(yu*yv)}, yw]*G[{1, 1, 1, yu^(-1)}, yw])/8 - 
     (G[{0}, yu^(-1)]*G[{1, 1, 1, yu}, yv^(-1)])/16 - 
     (G[{0}, yv^(-1)]*G[{1, 1, 1, yu}, yv^(-1)])/16 + 
     (G[{0}, yw]*G[{1, 1, 1, yu}, yv^(-1)])/16 - 
     (3*G[{1}, yu^(-1)]*G[{1, 1, 1, yu}, yv^(-1)])/16 + 
     (G[{1}, yv^(-1)]*G[{1, 1, 1, yu}, yv^(-1)])/16 - 
     (G[{1/(yu*yv)}, yw]*G[{1, 1, 1, yu}, yv^(-1)])/8 + 
     (3*G[{0}, yu^(-1)]*G[{1, 1, 1, yv^(-1)}, yw])/64 + 
     (3*G[{0}, yv^(-1)]*G[{1, 1, 1, yv^(-1)}, yw])/64 - 
     (3*G[{0}, yw]*G[{1, 1, 1, yv^(-1)}, yw])/64 + 
     (G[{1}, yu^(-1)]*G[{1, 1, 1, yv^(-1)}, yw])/64 + 
     (5*G[{1}, yv^(-1)]*G[{1, 1, 1, yv^(-1)}, yw])/64 + 
     (3*G[{1}, yw]*G[{1, 1, 1, yv^(-1)}, yw])/16 - 
     (3*G[{yu}, yv^(-1)]*G[{1, 1, 1, yv^(-1)}, yw])/16 - 
     (G[{1/(yu*yv)}, yw]*G[{1, 1, 1, yv^(-1)}, yw])/8 + 
     (G[{0}, yu^(-1)]*G[{1, 1, 1, 1/(yu*yv)}, yw])/8 + 
     (G[{0}, yv^(-1)]*G[{1, 1, 1, 1/(yu*yv)}, yw])/8 - 
     (G[{0}, yw]*G[{1, 1, 1, 1/(yu*yv)}, yw])/8 - 
     (3*G[{1}, yu^(-1)]*G[{1, 1, 1, 1/(yu*yv)}, yw])/16 - 
     (3*G[{1}, yv^(-1)]*G[{1, 1, 1, 1/(yu*yv)}, yw])/16 - 
     (G[{1}, yw]*G[{1, 1, 1, 1/(yu*yv)}, yw])/8 + 
     (G[{yu}, yv^(-1)]*G[{1, 1, 1, 1/(yu*yv)}, yw])/8 - 
     (9*G[{0}, yu^(-1)]*G[{1, 1, yu^(-1), yu^(-1)}, yw])/64 - 
     (9*G[{0}, yv^(-1)]*G[{1, 1, yu^(-1), yu^(-1)}, yw])/64 + 
     (9*G[{0}, yw]*G[{1, 1, yu^(-1), yu^(-1)}, yw])/64 + 
     (9*G[{1}, yu^(-1)]*G[{1, 1, yu^(-1), yu^(-1)}, yw])/64 + 
     (29*G[{1}, yv^(-1)]*G[{1, 1, yu^(-1), yu^(-1)}, yw])/64 + 
     (5*G[{1}, yw]*G[{1, 1, yu^(-1), yu^(-1)}, yw])/16 - 
     (5*G[{yu}, yv^(-1)]*G[{1, 1, yu^(-1), yu^(-1)}, yw])/16 - 
     (G[{1/(yu*yv)}, yw]*G[{1, 1, yu^(-1), yu^(-1)}, yw])/32 - 
     (9*G[{0}, yu^(-1)]*G[{1, 1, yu^(-1), yv^(-1)}, yw])/64 - 
     (9*G[{0}, yv^(-1)]*G[{1, 1, yu^(-1), yv^(-1)}, yw])/64 + 
     (9*G[{0}, yw]*G[{1, 1, yu^(-1), yv^(-1)}, yw])/64 + 
     (9*G[{1}, yu^(-1)]*G[{1, 1, yu^(-1), yv^(-1)}, yw])/64 - 
     (7*G[{1}, yv^(-1)]*G[{1, 1, yu^(-1), yv^(-1)}, yw])/64 - 
     (G[{1}, yw]*G[{1, 1, yu^(-1), yv^(-1)}, yw])/4 + 
     (G[{yu}, yv^(-1)]*G[{1, 1, yu^(-1), yv^(-1)}, yw])/4 + 
     (3*G[{1/(yu*yv)}, yw]*G[{1, 1, yu^(-1), yv^(-1)}, yw])/32 + 
     (5*G[{0}, yu^(-1)]*G[{1, 1, yu^(-1), 1/(yu*yv)}, yw])/64 + 
     (5*G[{0}, yv^(-1)]*G[{1, 1, yu^(-1), 1/(yu*yv)}, yw])/64 - 
     (5*G[{0}, yw]*G[{1, 1, yu^(-1), 1/(yu*yv)}, yw])/64 - 
     (5*G[{1}, yu^(-1)]*G[{1, 1, yu^(-1), 1/(yu*yv)}, yw])/64 + 
     (3*G[{1}, yv^(-1)]*G[{1, 1, yu^(-1), 1/(yu*yv)}, yw])/64 + 
     (G[{1}, yw]*G[{1, 1, yu^(-1), 1/(yu*yv)}, yw])/8 - 
     (G[{yu}, yv^(-1)]*G[{1, 1, yu^(-1), 1/(yu*yv)}, yw])/8 + 
     (G[{0}, yu^(-1)]*G[{1, 1, yu, yu}, yv^(-1)])/8 + 
     (G[{0}, yv^(-1)]*G[{1, 1, yu, yu}, yv^(-1)])/8 - 
     (G[{0}, yw]*G[{1, 1, yu, yu}, yv^(-1)])/8 - 
     (3*G[{1}, yv^(-1)]*G[{1, 1, yu, yu}, yv^(-1)])/16 + 
     (3*G[{1}, yw]*G[{1, 1, yu, yu}, yv^(-1)])/8 - 
     (G[{1/(yu*yv)}, yw]*G[{1, 1, yu, yu}, yv^(-1)])/8 - 
     (9*G[{0}, yu^(-1)]*G[{1, 1, yv^(-1), yu^(-1)}, yw])/64 - 
     (9*G[{0}, yv^(-1)]*G[{1, 1, yv^(-1), yu^(-1)}, yw])/64 + 
     (9*G[{0}, yw]*G[{1, 1, yv^(-1), yu^(-1)}, yw])/64 + 
     (9*G[{1}, yu^(-1)]*G[{1, 1, yv^(-1), yu^(-1)}, yw])/64 - 
     (7*G[{1}, yv^(-1)]*G[{1, 1, yv^(-1), yu^(-1)}, yw])/64 - 
     (G[{1}, yw]*G[{1, 1, yv^(-1), yu^(-1)}, yw])/4 + 
     (G[{yu}, yv^(-1)]*G[{1, 1, yv^(-1), yu^(-1)}, yw])/4 + 
     (3*G[{1/(yu*yv)}, yw]*G[{1, 1, yv^(-1), yu^(-1)}, yw])/32 - 
     (25*G[{0}, yu^(-1)]*G[{1, 1, yv^(-1), yv^(-1)}, yw])/64 - 
     (25*G[{0}, yv^(-1)]*G[{1, 1, yv^(-1), yv^(-1)}, yw])/64 + 
     (25*G[{0}, yw]*G[{1, 1, yv^(-1), yv^(-1)}, yw])/64 + 
     (41*G[{1}, yu^(-1)]*G[{1, 1, yv^(-1), yv^(-1)}, yw])/64 + 
     (9*G[{1}, yv^(-1)]*G[{1, 1, yv^(-1), yv^(-1)}, yw])/64 - 
     (G[{1/(yu*yv)}, yw]*G[{1, 1, yv^(-1), yv^(-1)}, yw])/32 + 
     (21*G[{0}, yu^(-1)]*G[{1, 1, yv^(-1), 1/(yu*yv)}, yw])/64 + 
     (21*G[{0}, yv^(-1)]*G[{1, 1, yv^(-1), 1/(yu*yv)}, yw])/64 - 
     (21*G[{0}, yw]*G[{1, 1, yv^(-1), 1/(yu*yv)}, yw])/64 - 
     (17*G[{1}, yu^(-1)]*G[{1, 1, yv^(-1), 1/(yu*yv)}, yw])/64 - 
     (21*G[{1}, yv^(-1)]*G[{1, 1, yv^(-1), 1/(yu*yv)}, yw])/64 + 
     (G[{1}, yw]*G[{1, 1, yv^(-1), 1/(yu*yv)}, yw])/16 - 
     (G[{yu}, yv^(-1)]*G[{1, 1, yv^(-1), 1/(yu*yv)}, yw])/16 + 
     (G[{0}, yu^(-1)]*G[{1, 1, 1/(yu*yv), yu^(-1)}, yw])/4 + 
     (G[{0}, yv^(-1)]*G[{1, 1, 1/(yu*yv), yu^(-1)}, yw])/4 - 
     (G[{0}, yw]*G[{1, 1, 1/(yu*yv), yu^(-1)}, yw])/4 - 
     (G[{1}, yu^(-1)]*G[{1, 1, 1/(yu*yv), yu^(-1)}, yw])/4 - 
     (G[{1}, yv^(-1)]*G[{1, 1, 1/(yu*yv), yu^(-1)}, yw])/16 + 
     (3*G[{1}, yw]*G[{1, 1, 1/(yu*yv), yu^(-1)}, yw])/16 - 
     (3*G[{yu}, yv^(-1)]*G[{1, 1, 1/(yu*yv), yu^(-1)}, yw])/16 + 
     (G[{1/(yu*yv)}, yw]*G[{1, 1, 1/(yu*yv), yu^(-1)}, yw])/8 + 
     (G[{0}, yu^(-1)]*G[{1, 1, 1/(yu*yv), yv^(-1)}, yw])/4 + 
     (G[{0}, yv^(-1)]*G[{1, 1, 1/(yu*yv), yv^(-1)}, yw])/4 - 
     (G[{0}, yw]*G[{1, 1, 1/(yu*yv), yv^(-1)}, yw])/4 - 
     (G[{1}, yu^(-1)]*G[{1, 1, 1/(yu*yv), yv^(-1)}, yw])/4 - 
     (G[{1}, yv^(-1)]*G[{1, 1, 1/(yu*yv), yv^(-1)}, yw])/4 + 
     (G[{1/(yu*yv)}, yw]*G[{1, 1, 1/(yu*yv), yv^(-1)}, yw])/8 + 
     (G[{0}, yu^(-1)]*G[{1, 1, 1/(yu*yv), 1/(yu*yv)}, yw])/4 + 
     (G[{0}, yv^(-1)]*G[{1, 1, 1/(yu*yv), 1/(yu*yv)}, yw])/4 - 
     (G[{0}, yw]*G[{1, 1, 1/(yu*yv), 1/(yu*yv)}, yw])/4 - 
     (3*G[{1}, yu^(-1)]*G[{1, 1, 1/(yu*yv), 1/(yu*yv)}, yw])/16 - 
     (3*G[{1}, yv^(-1)]*G[{1, 1, 1/(yu*yv), 1/(yu*yv)}, yw])/8 - 
     (G[{1}, yw]*G[{1, 1, 1/(yu*yv), 1/(yu*yv)}, yw])/16 + 
     (G[{yu}, yv^(-1)]*G[{1, 1, 1/(yu*yv), 1/(yu*yv)}, yw])/16 - 
     (G[{0}, yu^(-1)]*G[{1, yu^(-1), 1, yv^(-1)}, yw])/16 - 
     (G[{0}, yv^(-1)]*G[{1, yu^(-1), 1, yv^(-1)}, yw])/16 + 
     (G[{0}, yw]*G[{1, yu^(-1), 1, yv^(-1)}, yw])/16 + 
     (G[{1}, yu^(-1)]*G[{1, yu^(-1), 1, yv^(-1)}, yw])/8 - 
     (G[{1}, yv^(-1)]*G[{1, yu^(-1), 1, yv^(-1)}, yw])/8 - 
     (G[{1}, yw]*G[{1, yu^(-1), 1, yv^(-1)}, yw])/8 + 
     (G[{yu}, yv^(-1)]*G[{1, yu^(-1), 1, yv^(-1)}, yw])/8 + 
     (G[{0}, yu^(-1)]*G[{1, yu^(-1), 1, 1/(yu*yv)}, yw])/16 + 
     (G[{0}, yv^(-1)]*G[{1, yu^(-1), 1, 1/(yu*yv)}, yw])/16 - 
     (G[{0}, yw]*G[{1, yu^(-1), 1, 1/(yu*yv)}, yw])/16 - 
     (G[{1}, yu^(-1)]*G[{1, yu^(-1), 1, 1/(yu*yv)}, yw])/8 + 
     (G[{1}, yv^(-1)]*G[{1, yu^(-1), 1, 1/(yu*yv)}, yw])/8 + 
     (G[{1}, yw]*G[{1, yu^(-1), 1, 1/(yu*yv)}, yw])/8 - 
     (G[{yu}, yv^(-1)]*G[{1, yu^(-1), 1, 1/(yu*yv)}, yw])/8 + 
     (7*G[{0}, yu^(-1)]*G[{1, yu^(-1), yu^(-1), yu^(-1)}, yw])/32 + 
     (7*G[{0}, yv^(-1)]*G[{1, yu^(-1), yu^(-1), yu^(-1)}, yw])/32 - 
     (7*G[{0}, yw]*G[{1, yu^(-1), yu^(-1), yu^(-1)}, yw])/32 - 
     (7*G[{1}, yu^(-1)]*G[{1, yu^(-1), yu^(-1), yu^(-1)}, yw])/32 - 
     (3*G[{1}, yv^(-1)]*G[{1, yu^(-1), yu^(-1), yu^(-1)}, yw])/32 + 
     (G[{1}, yw]*G[{1, yu^(-1), yu^(-1), yu^(-1)}, yw])/8 - 
     (G[{yu}, yv^(-1)]*G[{1, yu^(-1), yu^(-1), yu^(-1)}, yw])/8 + 
     (3*G[{1/(yu*yv)}, yw]*G[{1, yu^(-1), yu^(-1), yu^(-1)}, yw])/64 + 
     (7*G[{0}, yu^(-1)]*G[{1, yu^(-1), yu^(-1), yv^(-1)}, yw])/32 + 
     (7*G[{0}, yv^(-1)]*G[{1, yu^(-1), yu^(-1), yv^(-1)}, yw])/32 - 
     (7*G[{0}, yw]*G[{1, yu^(-1), yu^(-1), yv^(-1)}, yw])/32 - 
     (7*G[{1}, yu^(-1)]*G[{1, yu^(-1), yu^(-1), yv^(-1)}, yw])/32 - 
     (7*G[{1}, yv^(-1)]*G[{1, yu^(-1), yu^(-1), yv^(-1)}, yw])/32 + 
     (11*G[{1/(yu*yv)}, yw]*G[{1, yu^(-1), yu^(-1), yv^(-1)}, yw])/64 - 
     (7*G[{0}, yu^(-1)]*G[{1, yu^(-1), yu^(-1), 1/(yu*yv)}, yw])/64 - 
     (7*G[{0}, yv^(-1)]*G[{1, yu^(-1), yu^(-1), 1/(yu*yv)}, yw])/64 + 
     (7*G[{0}, yw]*G[{1, yu^(-1), yu^(-1), 1/(yu*yv)}, yw])/64 + 
     (7*G[{1}, yu^(-1)]*G[{1, yu^(-1), yu^(-1), 1/(yu*yv)}, yw])/64 + 
     (3*G[{1}, yv^(-1)]*G[{1, yu^(-1), yu^(-1), 1/(yu*yv)}, yw])/64 - 
     (G[{1}, yw]*G[{1, yu^(-1), yu^(-1), 1/(yu*yv)}, yw])/16 + 
     (G[{yu}, yv^(-1)]*G[{1, yu^(-1), yu^(-1), 1/(yu*yv)}, yw])/16 - 
     (3*G[{1/(yu*yv)}, yw]*G[{1, yu^(-1), yu^(-1), 1/(yu*yv)}, yw])/32 + 
     (7*G[{0}, yu^(-1)]*G[{1, yu^(-1), yv^(-1), yu^(-1)}, yw])/32 + 
     (7*G[{0}, yv^(-1)]*G[{1, yu^(-1), yv^(-1), yu^(-1)}, yw])/32 - 
     (7*G[{0}, yw]*G[{1, yu^(-1), yv^(-1), yu^(-1)}, yw])/32 - 
     (7*G[{1}, yu^(-1)]*G[{1, yu^(-1), yv^(-1), yu^(-1)}, yw])/32 - 
     (7*G[{1}, yv^(-1)]*G[{1, yu^(-1), yv^(-1), yu^(-1)}, yw])/32 + 
     (11*G[{1/(yu*yv)}, yw]*G[{1, yu^(-1), yv^(-1), yu^(-1)}, yw])/64 - 
     (G[{0}, yu^(-1)]*G[{1, yu^(-1), yv^(-1), yv^(-1)}, yw])/32 - 
     (G[{0}, yv^(-1)]*G[{1, yu^(-1), yv^(-1), yv^(-1)}, yw])/32 + 
     (G[{0}, yw]*G[{1, yu^(-1), yv^(-1), yv^(-1)}, yw])/32 + 
     (9*G[{1}, yu^(-1)]*G[{1, yu^(-1), yv^(-1), yv^(-1)}, yw])/32 - 
     (7*G[{1}, yv^(-1)]*G[{1, yu^(-1), yv^(-1), yv^(-1)}, yw])/32 + 
     (11*G[{1/(yu*yv)}, yw]*G[{1, yu^(-1), yv^(-1), yv^(-1)}, yw])/64 - 
     (11*G[{0}, yu^(-1)]*G[{1, yu^(-1), yv^(-1), 1/(yu*yv)}, yw])/64 - 
     (11*G[{0}, yv^(-1)]*G[{1, yu^(-1), yv^(-1), 1/(yu*yv)}, yw])/64 + 
     (11*G[{0}, yw]*G[{1, yu^(-1), yv^(-1), 1/(yu*yv)}, yw])/64 - 
     (G[{1}, yu^(-1)]*G[{1, yu^(-1), yv^(-1), 1/(yu*yv)}, yw])/64 + 
     (15*G[{1}, yv^(-1)]*G[{1, yu^(-1), yv^(-1), 1/(yu*yv)}, yw])/64 - 
     (G[{1}, yw]*G[{1, yu^(-1), yv^(-1), 1/(yu*yv)}, yw])/8 + 
     (G[{yu}, yv^(-1)]*G[{1, yu^(-1), yv^(-1), 1/(yu*yv)}, yw])/8 - 
     (3*G[{1/(yu*yv)}, yw]*G[{1, yu^(-1), yv^(-1), 1/(yu*yv)}, yw])/32 - 
     (7*G[{0}, yu^(-1)]*G[{1, yu^(-1), 1/(yu*yv), yu^(-1)}, yw])/64 - 
     (7*G[{0}, yv^(-1)]*G[{1, yu^(-1), 1/(yu*yv), yu^(-1)}, yw])/64 + 
     (7*G[{0}, yw]*G[{1, yu^(-1), 1/(yu*yv), yu^(-1)}, yw])/64 + 
     (7*G[{1}, yu^(-1)]*G[{1, yu^(-1), 1/(yu*yv), yu^(-1)}, yw])/64 + 
     (3*G[{1}, yv^(-1)]*G[{1, yu^(-1), 1/(yu*yv), yu^(-1)}, yw])/64 - 
     (G[{1}, yw]*G[{1, yu^(-1), 1/(yu*yv), yu^(-1)}, yw])/16 + 
     (G[{yu}, yv^(-1)]*G[{1, yu^(-1), 1/(yu*yv), yu^(-1)}, yw])/16 - 
     (3*G[{1/(yu*yv)}, yw]*G[{1, yu^(-1), 1/(yu*yv), yu^(-1)}, yw])/32 + 
     (G[{0}, yu^(-1)]*G[{1, yu^(-1), 1/(yu*yv), yv^(-1)}, yw])/64 + 
     (G[{0}, yv^(-1)]*G[{1, yu^(-1), 1/(yu*yv), yv^(-1)}, yw])/64 - 
     (G[{0}, yw]*G[{1, yu^(-1), 1/(yu*yv), yv^(-1)}, yw])/64 - 
     (9*G[{1}, yu^(-1)]*G[{1, yu^(-1), 1/(yu*yv), yv^(-1)}, yw])/64 + 
     (7*G[{1}, yv^(-1)]*G[{1, yu^(-1), 1/(yu*yv), yv^(-1)}, yw])/64 - 
     (3*G[{1/(yu*yv)}, yw]*G[{1, yu^(-1), 1/(yu*yv), yv^(-1)}, yw])/32 - 
     (G[{0}, yu^(-1)]*G[{1, yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/64 - 
     (G[{0}, yv^(-1)]*G[{1, yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/64 + 
     (G[{0}, yw]*G[{1, yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/64 - 
     (11*G[{1}, yu^(-1)]*G[{1, yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/64 + 
     (9*G[{1}, yv^(-1)]*G[{1, yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/64 - 
     (G[{1}, yw]*G[{1, yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/16 + 
     (G[{yu}, yv^(-1)]*G[{1, yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/16 + 
     (G[{0}, yu^(-1)]*G[{1, yu, yu, yu}, yv^(-1)])/4 + 
     (G[{0}, yv^(-1)]*G[{1, yu, yu, yu}, yv^(-1)])/4 - 
     (G[{0}, yw]*G[{1, yu, yu, yu}, yv^(-1)])/4 - 
     (3*G[{1}, yv^(-1)]*G[{1, yu, yu, yu}, yv^(-1)])/8 + 
     (G[{1}, yw]*G[{1, yu, yu, yu}, yv^(-1)])/2 + 
     (5*G[{0}, yu^(-1)]*G[{1, yv^(-1), 1, 1/(yu*yv)}, yw])/16 + 
     (5*G[{0}, yv^(-1)]*G[{1, yv^(-1), 1, 1/(yu*yv)}, yw])/16 - 
     (5*G[{0}, yw]*G[{1, yv^(-1), 1, 1/(yu*yv)}, yw])/16 - 
     (G[{1}, yu^(-1)]*G[{1, yv^(-1), 1, 1/(yu*yv)}, yw])/8 - 
     (G[{1}, yv^(-1)]*G[{1, yv^(-1), 1, 1/(yu*yv)}, yw])/4 + 
     (G[{1}, yw]*G[{1, yv^(-1), 1, 1/(yu*yv)}, yw])/4 - 
     (G[{yu}, yv^(-1)]*G[{1, yv^(-1), 1, 1/(yu*yv)}, yw])/4 + 
     (7*G[{0}, yu^(-1)]*G[{1, yv^(-1), yu^(-1), yu^(-1)}, yw])/32 + 
     (7*G[{0}, yv^(-1)]*G[{1, yv^(-1), yu^(-1), yu^(-1)}, yw])/32 - 
     (7*G[{0}, yw]*G[{1, yv^(-1), yu^(-1), yu^(-1)}, yw])/32 - 
     (7*G[{1}, yu^(-1)]*G[{1, yv^(-1), yu^(-1), yu^(-1)}, yw])/32 - 
     (7*G[{1}, yv^(-1)]*G[{1, yv^(-1), yu^(-1), yu^(-1)}, yw])/32 + 
     (11*G[{1/(yu*yv)}, yw]*G[{1, yv^(-1), yu^(-1), yu^(-1)}, yw])/64 - 
     (G[{0}, yu^(-1)]*G[{1, yv^(-1), yu^(-1), yv^(-1)}, yw])/32 - 
     (G[{0}, yv^(-1)]*G[{1, yv^(-1), yu^(-1), yv^(-1)}, yw])/32 + 
     (G[{0}, yw]*G[{1, yv^(-1), yu^(-1), yv^(-1)}, yw])/32 + 
     (9*G[{1}, yu^(-1)]*G[{1, yv^(-1), yu^(-1), yv^(-1)}, yw])/32 - 
     (7*G[{1}, yv^(-1)]*G[{1, yv^(-1), yu^(-1), yv^(-1)}, yw])/32 + 
     (11*G[{1/(yu*yv)}, yw]*G[{1, yv^(-1), yu^(-1), yv^(-1)}, yw])/64 - 
     (11*G[{0}, yu^(-1)]*G[{1, yv^(-1), yu^(-1), 1/(yu*yv)}, yw])/64 - 
     (11*G[{0}, yv^(-1)]*G[{1, yv^(-1), yu^(-1), 1/(yu*yv)}, yw])/64 + 
     (11*G[{0}, yw]*G[{1, yv^(-1), yu^(-1), 1/(yu*yv)}, yw])/64 - 
     (G[{1}, yu^(-1)]*G[{1, yv^(-1), yu^(-1), 1/(yu*yv)}, yw])/64 + 
     (15*G[{1}, yv^(-1)]*G[{1, yv^(-1), yu^(-1), 1/(yu*yv)}, yw])/64 - 
     (G[{1}, yw]*G[{1, yv^(-1), yu^(-1), 1/(yu*yv)}, yw])/8 + 
     (G[{yu}, yv^(-1)]*G[{1, yv^(-1), yu^(-1), 1/(yu*yv)}, yw])/8 - 
     (3*G[{1/(yu*yv)}, yw]*G[{1, yv^(-1), yu^(-1), 1/(yu*yv)}, yw])/32 - 
     (G[{0}, yu^(-1)]*G[{1, yv^(-1), yv^(-1), yu^(-1)}, yw])/32 - 
     (G[{0}, yv^(-1)]*G[{1, yv^(-1), yv^(-1), yu^(-1)}, yw])/32 + 
     (G[{0}, yw]*G[{1, yv^(-1), yv^(-1), yu^(-1)}, yw])/32 + 
     (9*G[{1}, yu^(-1)]*G[{1, yv^(-1), yv^(-1), yu^(-1)}, yw])/32 - 
     (7*G[{1}, yv^(-1)]*G[{1, yv^(-1), yv^(-1), yu^(-1)}, yw])/32 + 
     (11*G[{1/(yu*yv)}, yw]*G[{1, yv^(-1), yv^(-1), yu^(-1)}, yw])/64 - 
     (25*G[{0}, yu^(-1)]*G[{1, yv^(-1), yv^(-1), yv^(-1)}, yw])/32 - 
     (25*G[{0}, yv^(-1)]*G[{1, yv^(-1), yv^(-1), yv^(-1)}, yw])/32 + 
     (25*G[{0}, yw]*G[{1, yv^(-1), yv^(-1), yv^(-1)}, yw])/32 + 
     (41*G[{1}, yu^(-1)]*G[{1, yv^(-1), yv^(-1), yv^(-1)}, yw])/32 + 
     (9*G[{1}, yv^(-1)]*G[{1, yv^(-1), yv^(-1), yv^(-1)}, yw])/32 + 
     (3*G[{1/(yu*yv)}, yw]*G[{1, yv^(-1), yv^(-1), yv^(-1)}, yw])/64 - 
     (23*G[{0}, yu^(-1)]*G[{1, yv^(-1), yv^(-1), 1/(yu*yv)}, yw])/64 - 
     (23*G[{0}, yv^(-1)]*G[{1, yv^(-1), yv^(-1), 1/(yu*yv)}, yw])/64 + 
     (23*G[{0}, yw]*G[{1, yv^(-1), yv^(-1), 1/(yu*yv)}, yw])/64 - 
     (9*G[{1}, yu^(-1)]*G[{1, yv^(-1), yv^(-1), 1/(yu*yv)}, yw])/64 + 
     (23*G[{1}, yv^(-1)]*G[{1, yv^(-1), yv^(-1), 1/(yu*yv)}, yw])/64 - 
     (G[{1}, yw]*G[{1, yv^(-1), yv^(-1), 1/(yu*yv)}, yw])/2 + 
     (G[{yu}, yv^(-1)]*G[{1, yv^(-1), yv^(-1), 1/(yu*yv)}, yw])/2 - 
     (3*G[{1/(yu*yv)}, yw]*G[{1, yv^(-1), yv^(-1), 1/(yu*yv)}, yw])/32 - 
     (7*G[{0}, yu^(-1)]*G[{1, yv^(-1), 1/(yu*yv), yu^(-1)}, yw])/64 - 
     (7*G[{0}, yv^(-1)]*G[{1, yv^(-1), 1/(yu*yv), yu^(-1)}, yw])/64 + 
     (7*G[{0}, yw]*G[{1, yv^(-1), 1/(yu*yv), yu^(-1)}, yw])/64 + 
     (7*G[{1}, yu^(-1)]*G[{1, yv^(-1), 1/(yu*yv), yu^(-1)}, yw])/64 + 
     (7*G[{1}, yv^(-1)]*G[{1, yv^(-1), 1/(yu*yv), yu^(-1)}, yw])/64 - 
     (3*G[{1/(yu*yv)}, yw]*G[{1, yv^(-1), 1/(yu*yv), yu^(-1)}, yw])/32 + 
     (G[{0}, yu^(-1)]*G[{1, yv^(-1), 1/(yu*yv), yv^(-1)}, yw])/64 + 
     (G[{0}, yv^(-1)]*G[{1, yv^(-1), 1/(yu*yv), yv^(-1)}, yw])/64 - 
     (G[{0}, yw]*G[{1, yv^(-1), 1/(yu*yv), yv^(-1)}, yw])/64 - 
     (9*G[{1}, yu^(-1)]*G[{1, yv^(-1), 1/(yu*yv), yv^(-1)}, yw])/64 + 
     (7*G[{1}, yv^(-1)]*G[{1, yv^(-1), 1/(yu*yv), yv^(-1)}, yw])/64 - 
     (3*G[{1/(yu*yv)}, yw]*G[{1, yv^(-1), 1/(yu*yv), yv^(-1)}, yw])/32 + 
     (7*G[{0}, yu^(-1)]*G[{1, yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/64 + 
     (7*G[{0}, yv^(-1)]*G[{1, yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/64 - 
     (7*G[{0}, yw]*G[{1, yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/64 - 
     (7*G[{1}, yu^(-1)]*G[{1, yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/64 - 
     (3*G[{1}, yv^(-1)]*G[{1, yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/64 + 
     (G[{1}, yw]*G[{1, yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/16 - 
     (G[{yu}, yv^(-1)]*G[{1, yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/16 - 
     (G[{1}, yv^(-1)]*G[{1, 1/(yu*yv), yu^(-1), yu^(-1)}, yw])/8 - 
     (G[{1}, yw]*G[{1, 1/(yu*yv), yu^(-1), yu^(-1)}, yw])/8 + 
     (G[{yu}, yv^(-1)]*G[{1, 1/(yu*yv), yu^(-1), yu^(-1)}, yw])/8 + 
     (G[{1/(yu*yv)}, yw]*G[{1, 1/(yu*yv), yu^(-1), yu^(-1)}, yw])/8 - 
     (G[{0}, yu^(-1)]*G[{1, 1/(yu*yv), yu^(-1), 1/(yu*yv)}, yw])/16 - 
     (G[{0}, yv^(-1)]*G[{1, 1/(yu*yv), yu^(-1), 1/(yu*yv)}, yw])/16 + 
     (G[{0}, yw]*G[{1, 1/(yu*yv), yu^(-1), 1/(yu*yv)}, yw])/16 - 
     (G[{1}, yu^(-1)]*G[{1, 1/(yu*yv), yu^(-1), 1/(yu*yv)}, yw])/8 + 
     (3*G[{1}, yv^(-1)]*G[{1, 1/(yu*yv), yu^(-1), 1/(yu*yv)}, yw])/16 - 
     (G[{1}, yw]*G[{1, 1/(yu*yv), yu^(-1), 1/(yu*yv)}, yw])/16 + 
     (G[{yu}, yv^(-1)]*G[{1, 1/(yu*yv), yu^(-1), 1/(yu*yv)}, yw])/16 + 
     (G[{1/(yu*yv)}, yw]*G[{1, 1/(yu*yv), yv^(-1), yv^(-1)}, yw])/8 + 
     (5*G[{0}, yu^(-1)]*G[{1, 1/(yu*yv), yv^(-1), 1/(yu*yv)}, yw])/16 + 
     (5*G[{0}, yv^(-1)]*G[{1, 1/(yu*yv), yv^(-1), 1/(yu*yv)}, yw])/16 - 
     (5*G[{0}, yw]*G[{1, 1/(yu*yv), yv^(-1), 1/(yu*yv)}, yw])/16 - 
     (G[{1}, yu^(-1)]*G[{1, 1/(yu*yv), yv^(-1), 1/(yu*yv)}, yw])/8 - 
     (G[{1}, yv^(-1)]*G[{1, 1/(yu*yv), yv^(-1), 1/(yu*yv)}, yw])/4 + 
     (G[{1}, yw]*G[{1, 1/(yu*yv), yv^(-1), 1/(yu*yv)}, yw])/4 - 
     (G[{yu}, yv^(-1)]*G[{1, 1/(yu*yv), yv^(-1), 1/(yu*yv)}, yw])/4 - 
     (G[{1}, yu^(-1)]*G[{1, 1/(yu*yv), 1/(yu*yv), yu^(-1)}, yw])/4 + 
     (G[{1}, yv^(-1)]*G[{1, 1/(yu*yv), 1/(yu*yv), yu^(-1)}, yw])/16 - 
     (3*G[{1}, yw]*G[{1, 1/(yu*yv), 1/(yu*yv), yu^(-1)}, yw])/16 + 
     (3*G[{yu}, yv^(-1)]*G[{1, 1/(yu*yv), 1/(yu*yv), yu^(-1)}, yw])/16 + 
     (G[{0}, yu^(-1)]*G[{1, 1/(yu*yv), 1/(yu*yv), yv^(-1)}, yw])/4 + 
     (G[{0}, yv^(-1)]*G[{1, 1/(yu*yv), 1/(yu*yv), yv^(-1)}, yw])/4 - 
     (G[{0}, yw]*G[{1, 1/(yu*yv), 1/(yu*yv), yv^(-1)}, yw])/4 - 
     (G[{1}, yu^(-1)]*G[{1, 1/(yu*yv), 1/(yu*yv), yv^(-1)}, yw])/4 - 
     (G[{1}, yv^(-1)]*G[{1, 1/(yu*yv), 1/(yu*yv), yv^(-1)}, yw])/4 + 
     (G[{0}, yu^(-1)]*G[{1, 1/(yu*yv), 1/(yu*yv), 1/(yu*yv)}, yw])/8 + 
     (G[{0}, yv^(-1)]*G[{1, 1/(yu*yv), 1/(yu*yv), 1/(yu*yv)}, yw])/8 - 
     (G[{0}, yw]*G[{1, 1/(yu*yv), 1/(yu*yv), 1/(yu*yv)}, yw])/8 - 
     (3*G[{1}, yu^(-1)]*G[{1, 1/(yu*yv), 1/(yu*yv), 1/(yu*yv)}, yw])/16 - 
     (3*G[{1}, yv^(-1)]*G[{1, 1/(yu*yv), 1/(yu*yv), 1/(yu*yv)}, yw])/16 - 
     (G[{1}, yw]*G[{1, 1/(yu*yv), 1/(yu*yv), 1/(yu*yv)}, yw])/8 + 
     (G[{yu}, yv^(-1)]*G[{1, 1/(yu*yv), 1/(yu*yv), 1/(yu*yv)}, yw])/8 - 
     (7*G[{0}, yu^(-1)]*G[{yu^(-1), yu^(-1), yu^(-1), 1/(yu*yv)}, yw])/32 - 
     (7*G[{0}, yv^(-1)]*G[{yu^(-1), yu^(-1), yu^(-1), 1/(yu*yv)}, yw])/32 + 
     (7*G[{0}, yw]*G[{yu^(-1), yu^(-1), yu^(-1), 1/(yu*yv)}, yw])/32 + 
     (7*G[{1}, yu^(-1)]*G[{yu^(-1), yu^(-1), yu^(-1), 1/(yu*yv)}, yw])/32 + 
     (11*G[{1}, yv^(-1)]*G[{yu^(-1), yu^(-1), yu^(-1), 1/(yu*yv)}, yw])/32 + 
     (G[{1}, yw]*G[{yu^(-1), yu^(-1), yu^(-1), 1/(yu*yv)}, yw])/8 - 
     (11*G[{yu^(-1)}, yw]*G[{yu^(-1), yu^(-1), yu^(-1), 1/(yu*yv)}, yw])/32 - 
     (G[{yu}, yv^(-1)]*G[{yu^(-1), yu^(-1), yu^(-1), 1/(yu*yv)}, yw])/8 - 
     (3*G[{1/(yu*yv)}, yw]*G[{yu^(-1), yu^(-1), yu^(-1), 1/(yu*yv)}, yw])/
      64 + (7*G[{0}, yu^(-1)]*G[{yu^(-1), yu^(-1), 1/(yu*yv), yv^(-1)}, yw])/
      32 + (7*G[{0}, yv^(-1)]*G[{yu^(-1), yu^(-1), 1/(yu*yv), yv^(-1)}, yw])/
      32 - (7*G[{0}, yw]*G[{yu^(-1), yu^(-1), 1/(yu*yv), yv^(-1)}, yw])/32 - 
     (7*G[{1}, yu^(-1)]*G[{yu^(-1), yu^(-1), 1/(yu*yv), yv^(-1)}, yw])/32 - 
     (7*G[{1}, yv^(-1)]*G[{yu^(-1), yu^(-1), 1/(yu*yv), yv^(-1)}, yw])/32 + 
     (7*G[{yu^(-1)}, yw]*G[{yu^(-1), yu^(-1), 1/(yu*yv), yv^(-1)}, yw])/32 + 
     (11*G[{1/(yu*yv)}, yw]*G[{yu^(-1), yu^(-1), 1/(yu*yv), yv^(-1)}, yw])/
      64 - (23*G[{0}, yu^(-1)]*G[{yu^(-1), yu^(-1), 1/(yu*yv), 1/(yu*yv)}, 
        yw])/64 - (23*G[{0}, yv^(-1)]*G[{yu^(-1), yu^(-1), 1/(yu*yv), 
         1/(yu*yv)}, yw])/64 + 
     (23*G[{0}, yw]*G[{yu^(-1), yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/64 + 
     (23*G[{1}, yu^(-1)]*G[{yu^(-1), yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/
      64 + (43*G[{1}, yv^(-1)]*G[{yu^(-1), yu^(-1), 1/(yu*yv), 1/(yu*yv)}, 
        yw])/64 + (5*G[{1}, yw]*G[{yu^(-1), yu^(-1), 1/(yu*yv), 1/(yu*yv)}, 
        yw])/16 - (43*G[{yu^(-1)}, yw]*G[{yu^(-1), yu^(-1), 1/(yu*yv), 
         1/(yu*yv)}, yw])/64 - (5*G[{yu}, yv^(-1)]*
       G[{yu^(-1), yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/16 - 
     (3*G[{1/(yu*yv)}, yw]*G[{yu^(-1), yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/
      32 + (G[{0}, yu^(-1)]*G[{yu^(-1), 1/(yu*yv), yv^(-1), yv^(-1)}, yw])/
      32 + (G[{0}, yv^(-1)]*G[{yu^(-1), 1/(yu*yv), yv^(-1), yv^(-1)}, yw])/
      32 - (G[{0}, yw]*G[{yu^(-1), 1/(yu*yv), yv^(-1), yv^(-1)}, yw])/32 - 
     (9*G[{1}, yu^(-1)]*G[{yu^(-1), 1/(yu*yv), yv^(-1), yv^(-1)}, yw])/32 + 
     (7*G[{1}, yv^(-1)]*G[{yu^(-1), 1/(yu*yv), yv^(-1), yv^(-1)}, yw])/32 - 
     (7*G[{yu^(-1)}, yw]*G[{yu^(-1), 1/(yu*yv), yv^(-1), yv^(-1)}, yw])/32 - 
     (11*G[{1/(yu*yv)}, yw]*G[{yu^(-1), 1/(yu*yv), yv^(-1), yv^(-1)}, yw])/
      64 + (11*G[{0}, yu^(-1)]*G[{yu^(-1), 1/(yu*yv), yv^(-1), 1/(yu*yv)}, 
        yw])/64 + (11*G[{0}, yv^(-1)]*G[{yu^(-1), 1/(yu*yv), yv^(-1), 
         1/(yu*yv)}, yw])/64 - 
     (11*G[{0}, yw]*G[{yu^(-1), 1/(yu*yv), yv^(-1), 1/(yu*yv)}, yw])/64 + 
     (G[{1}, yu^(-1)]*G[{yu^(-1), 1/(yu*yv), yv^(-1), 1/(yu*yv)}, yw])/64 - 
     (15*G[{1}, yv^(-1)]*G[{yu^(-1), 1/(yu*yv), yv^(-1), 1/(yu*yv)}, yw])/
      64 + (G[{1}, yw]*G[{yu^(-1), 1/(yu*yv), yv^(-1), 1/(yu*yv)}, yw])/8 + 
     (15*G[{yu^(-1)}, yw]*G[{yu^(-1), 1/(yu*yv), yv^(-1), 1/(yu*yv)}, yw])/
      64 - (G[{yu}, yv^(-1)]*G[{yu^(-1), 1/(yu*yv), yv^(-1), 1/(yu*yv)}, yw])/
      8 + (3*G[{1/(yu*yv)}, yw]*G[{yu^(-1), 1/(yu*yv), yv^(-1), 1/(yu*yv)}, 
        yw])/32 + (15*G[{0}, yu^(-1)]*G[{yu^(-1), 1/(yu*yv), 1/(yu*yv), 
         yv^(-1)}, yw])/64 + (15*G[{0}, yv^(-1)]*
       G[{yu^(-1), 1/(yu*yv), 1/(yu*yv), yv^(-1)}, yw])/64 - 
     (15*G[{0}, yw]*G[{yu^(-1), 1/(yu*yv), 1/(yu*yv), yv^(-1)}, yw])/64 - 
     (7*G[{1}, yu^(-1)]*G[{yu^(-1), 1/(yu*yv), 1/(yu*yv), yv^(-1)}, yw])/64 - 
     (23*G[{1}, yv^(-1)]*G[{yu^(-1), 1/(yu*yv), 1/(yu*yv), yv^(-1)}, yw])/
      64 + (23*G[{yu^(-1)}, yw]*G[{yu^(-1), 1/(yu*yv), 1/(yu*yv), yv^(-1)}, 
        yw])/64 + (3*G[{1/(yu*yv)}, yw]*G[{yu^(-1), 1/(yu*yv), 1/(yu*yv), 
         yv^(-1)}, yw])/32 - (7*G[{0}, yu^(-1)]*
       G[{yu^(-1), 1/(yu*yv), 1/(yu*yv), 1/(yu*yv)}, yw])/64 - 
     (7*G[{0}, yv^(-1)]*G[{yu^(-1), 1/(yu*yv), 1/(yu*yv), 1/(yu*yv)}, yw])/
      64 + (7*G[{0}, yw]*G[{yu^(-1), 1/(yu*yv), 1/(yu*yv), 1/(yu*yv)}, yw])/
      64 + (3*G[{1}, yu^(-1)]*G[{yu^(-1), 1/(yu*yv), 1/(yu*yv), 1/(yu*yv)}, 
        yw])/64 + (23*G[{1}, yv^(-1)]*G[{yu^(-1), 1/(yu*yv), 1/(yu*yv), 
         1/(yu*yv)}, yw])/64 + 
     (3*G[{1}, yw]*G[{yu^(-1), 1/(yu*yv), 1/(yu*yv), 1/(yu*yv)}, yw])/16 - 
     (23*G[{yu^(-1)}, yw]*G[{yu^(-1), 1/(yu*yv), 1/(yu*yv), 1/(yu*yv)}, yw])/
      64 - (3*G[{yu}, yv^(-1)]*G[{yu^(-1), 1/(yu*yv), 1/(yu*yv), 1/(yu*yv)}, 
        yw])/16 + (25*G[{0}, yu^(-1)]*G[{yv^(-1), yv^(-1), yv^(-1), 
         1/(yu*yv)}, yw])/32 + (25*G[{0}, yv^(-1)]*
       G[{yv^(-1), yv^(-1), yv^(-1), 1/(yu*yv)}, yw])/32 - 
     (25*G[{0}, yw]*G[{yv^(-1), yv^(-1), yv^(-1), 1/(yu*yv)}, yw])/32 - 
     (41*G[{1}, yu^(-1)]*G[{yv^(-1), yv^(-1), yv^(-1), 1/(yu*yv)}, yw])/32 - 
     (9*G[{1}, yv^(-1)]*G[{yv^(-1), yv^(-1), yv^(-1), 1/(yu*yv)}, yw])/32 + 
     (9*G[{yu^(-1)}, yw]*G[{yv^(-1), yv^(-1), yv^(-1), 1/(yu*yv)}, yw])/32 + 
     (41*G[{yv^(-1)}, yw]*G[{yv^(-1), yv^(-1), yv^(-1), 1/(yu*yv)}, yw])/32 - 
     (3*G[{1/(yu*yv)}, yw]*G[{yv^(-1), yv^(-1), yv^(-1), 1/(yu*yv)}, yw])/
      64 + (25*G[{0}, yu^(-1)]*G[{yv^(-1), yv^(-1), 1/(yu*yv), 1/(yu*yv)}, 
        yw])/64 + (25*G[{0}, yv^(-1)]*G[{yv^(-1), yv^(-1), 1/(yu*yv), 
         1/(yu*yv)}, yw])/64 - 
     (25*G[{0}, yw]*G[{yv^(-1), yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/64 - 
     (41*G[{1}, yu^(-1)]*G[{yv^(-1), yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/
      64 - (9*G[{1}, yv^(-1)]*G[{yv^(-1), yv^(-1), 1/(yu*yv), 1/(yu*yv)}, 
        yw])/64 + (9*G[{yu^(-1)}, yw]*G[{yv^(-1), yv^(-1), 1/(yu*yv), 
         1/(yu*yv)}, yw])/64 + (41*G[{yv^(-1)}, yw]*
       G[{yv^(-1), yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/64 - 
     (3*G[{1/(yu*yv)}, yw]*G[{yv^(-1), yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/
      32 - (7*G[{0}, yu^(-1)]*G[{yv^(-1), 1/(yu*yv), 1/(yu*yv), 1/(yu*yv)}, 
        yw])/64 - (7*G[{0}, yv^(-1)]*G[{yv^(-1), 1/(yu*yv), 1/(yu*yv), 
         1/(yu*yv)}, yw])/64 + 
     (7*G[{0}, yw]*G[{yv^(-1), 1/(yu*yv), 1/(yu*yv), 1/(yu*yv)}, yw])/64 + 
     (23*G[{1}, yu^(-1)]*G[{yv^(-1), 1/(yu*yv), 1/(yu*yv), 1/(yu*yv)}, yw])/
      64 + (3*G[{1}, yv^(-1)]*G[{yv^(-1), 1/(yu*yv), 1/(yu*yv), 1/(yu*yv)}, 
        yw])/64 + (3*G[{1}, yw]*G[{yv^(-1), 1/(yu*yv), 1/(yu*yv), 1/(yu*yv)}, 
        yw])/16 - (3*G[{yu^(-1)}, yw]*G[{yv^(-1), 1/(yu*yv), 1/(yu*yv), 
         1/(yu*yv)}, yw])/64 - (3*G[{yu}, yv^(-1)]*
       G[{yv^(-1), 1/(yu*yv), 1/(yu*yv), 1/(yu*yv)}, yw])/16 - 
     (23*G[{yv^(-1)}, yw]*G[{yv^(-1), 1/(yu*yv), 1/(yu*yv), 1/(yu*yv)}, yw])/
      64 - (3*G[{0, 0, 0, 1, 1}, yv^(-1)])/8 + 
     (9*G[{0, 0, 0, 1, yu^(-1)}, yw])/16 - (3*G[{0, 0, 0, 1, yv^(-1)}, yw])/
      8 - (3*G[{0, 0, 0, 1, 1/(yu*yv)}, yw])/16 + 
     (9*G[{0, 0, 0, yu^(-1), 1}, yw])/16 - 
     (9*G[{0, 0, 0, yu^(-1), yu^(-1)}, yw])/8 - 
     (3*G[{0, 0, 0, yu^(-1), yv^(-1)}, yw])/16 + 
     (3*G[{0, 0, 0, yu^(-1), 1/(yu*yv)}, yw])/4 + 
     (3*G[{0, 0, 0, yu, yu}, yv^(-1)])/8 - (3*G[{0, 0, 0, yv^(-1), 1}, yw])/
      8 - (3*G[{0, 0, 0, yv^(-1), yu^(-1)}, yw])/16 + 
     (3*G[{0, 0, 0, yv^(-1), yv^(-1)}, yw])/4 - 
     (3*G[{0, 0, 0, yv^(-1), 1/(yu*yv)}, yw])/16 - 
     (3*G[{0, 0, 0, 1/(yu*yv), 1}, yw])/16 + 
     (3*G[{0, 0, 0, 1/(yu*yv), yu^(-1)}, yw])/4 - 
     (3*G[{0, 0, 0, 1/(yu*yv), yv^(-1)}, yw])/16 - 
     (3*G[{0, 0, 0, 1/(yu*yv), 1/(yu*yv)}, yw])/8 - 
     G[{0, 0, 1, 0, 1}, yv^(-1)]/8 - (3*G[{0, 0, 1, 0, 1}, yw])/64 + 
     (15*G[{0, 0, 1, 0, yu^(-1)}, yw])/64 - (5*G[{0, 0, 1, 0, yv^(-1)}, yw])/
      64 - (7*G[{0, 0, 1, 0, 1/(yu*yv)}, yw])/64 + 
     (21*G[{0, 0, 1, 1, 1}, yu^(-1)])/16 - (3*G[{0, 0, 1, 1, 1}, yv^(-1)])/
      16 + (3*G[{0, 0, 1, 1, 1}, yw])/8 + (7*G[{0, 0, 1, 1, yu^(-1)}, yw])/
      32 - G[{0, 0, 1, 1, yu}, yv^(-1)]/16 - (3*G[{0, 0, 1, 1, yv^(-1)}, yw])/
      32 - (9*G[{0, 0, 1, 1, 1/(yu*yv)}, yw])/32 + 
     (11*G[{0, 0, 1, yu^(-1), 1}, yw])/64 + 
     (15*G[{0, 0, 1, yu^(-1), yu^(-1)}, yw])/64 - 
     (3*G[{0, 0, 1, yu^(-1), yv^(-1)}, yw])/64 - 
     (11*G[{0, 0, 1, yu^(-1), 1/(yu*yv)}, yw])/64 - 
     G[{0, 0, 1, yu, 1}, yv^(-1)]/16 - (3*G[{0, 0, 1, yu, yu}, yv^(-1)])/16 + 
     (11*G[{0, 0, 1, yv^(-1), 1}, yw])/64 - 
     (3*G[{0, 0, 1, yv^(-1), yu^(-1)}, yw])/64 - 
     (41*G[{0, 0, 1, yv^(-1), yv^(-1)}, yw])/64 - 
     (3*G[{0, 0, 1, yv^(-1), 1/(yu*yv)}, yw])/64 - 
     (15*G[{0, 0, 1, 1/(yu*yv), 1}, yw])/32 - 
     G[{0, 0, 1, 1/(yu*yv), yu^(-1)}, yw]/8 + 
     G[{0, 0, 1, 1/(yu*yv), yv^(-1)}, yw]/16 + 
     G[{0, 0, 1, 1/(yu*yv), 1/(yu*yv)}, yw]/8 + 
     (15*G[{0, 0, yu^(-1), 0, 1}, yw])/64 - 
     (27*G[{0, 0, yu^(-1), 0, yu^(-1)}, yw])/64 - 
     (7*G[{0, 0, yu^(-1), 0, yv^(-1)}, yw])/64 + 
     (19*G[{0, 0, yu^(-1), 0, 1/(yu*yv)}, yw])/64 + 
     (11*G[{0, 0, yu^(-1), 1, 1}, yw])/32 + 
     G[{0, 0, yu^(-1), 1, yv^(-1)}, yw]/16 - 
     (3*G[{0, 0, yu^(-1), 1, 1/(yu*yv)}, yw])/32 - 
     (5*G[{0, 0, yu^(-1), yu^(-1), 1}, yw])/64 + 
     (33*G[{0, 0, yu^(-1), yu^(-1), yu^(-1)}, yw])/64 - 
     (7*G[{0, 0, yu^(-1), yu^(-1), yv^(-1)}, yw])/64 + 
     (27*G[{0, 0, yu^(-1), yu^(-1), 1/(yu*yv)}, yw])/64 + 
     (5*G[{0, 0, yu^(-1), yv^(-1), 1}, yw])/64 - 
     (7*G[{0, 0, yu^(-1), yv^(-1), yu^(-1)}, yw])/64 + 
     (17*G[{0, 0, yu^(-1), yv^(-1), yv^(-1)}, yw])/64 + 
     (5*G[{0, 0, yu^(-1), yv^(-1), 1/(yu*yv)}, yw])/64 + 
     (7*G[{0, 0, yu^(-1), 1/(yu*yv), 1}, yw])/32 + 
     G[{0, 0, yu^(-1), 1/(yu*yv), yu^(-1)}, yw]/8 - 
     G[{0, 0, yu^(-1), 1/(yu*yv), yv^(-1)}, yw]/32 + 
     G[{0, 0, yu, 0, yu}, yv^(-1)]/8 - G[{0, 0, yu, 1, 1}, yv^(-1)]/16 - 
     G[{0, 0, yu, 1, yu}, yv^(-1)]/16 + (3*G[{0, 0, yu, yu, 1}, yv^(-1)])/
      16 - (5*G[{0, 0, yu, yu, yu}, yv^(-1)])/16 - 
     (5*G[{0, 0, yv^(-1), 0, 1}, yw])/64 - 
     (7*G[{0, 0, yv^(-1), 0, yu^(-1)}, yw])/64 + 
     (13*G[{0, 0, yv^(-1), 0, yv^(-1)}, yw])/64 - 
     G[{0, 0, yv^(-1), 0, 1/(yu*yv)}, yw]/64 + 
     (3*G[{0, 0, yv^(-1), 1, 1}, yw])/32 - 
     (5*G[{0, 0, yv^(-1), 1, yv^(-1)}, yw])/16 - 
     (3*G[{0, 0, yv^(-1), 1, 1/(yu*yv)}, yw])/32 + 
     (5*G[{0, 0, yv^(-1), yu^(-1), 1}, yw])/64 - 
     (7*G[{0, 0, yv^(-1), yu^(-1), yu^(-1)}, yw])/64 + 
     (9*G[{0, 0, yv^(-1), yu^(-1), yv^(-1)}, yw])/64 + 
     (5*G[{0, 0, yv^(-1), yu^(-1), 1/(yu*yv)}, yw])/64 - 
     (21*G[{0, 0, yv^(-1), yv^(-1), 1}, yw])/64 + 
     G[{0, 0, yv^(-1), yv^(-1), yu^(-1)}, yw]/64 + 
     (17*G[{0, 0, yv^(-1), yv^(-1), yv^(-1)}, yw])/64 - 
     (21*G[{0, 0, yv^(-1), yv^(-1), 1/(yu*yv)}, yw])/64 + 
     (11*G[{0, 0, yv^(-1), 1/(yu*yv), 1}, yw])/32 - 
     (5*G[{0, 0, yv^(-1), 1/(yu*yv), yv^(-1)}, yw])/16 - 
     G[{0, 0, yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw]/8 - 
     (7*G[{0, 0, 1/(yu*yv), 0, 1}, yw])/64 + 
     (19*G[{0, 0, 1/(yu*yv), 0, yu^(-1)}, yw])/64 - 
     G[{0, 0, 1/(yu*yv), 0, yv^(-1)}, yw]/64 - 
     (11*G[{0, 0, 1/(yu*yv), 0, 1/(yu*yv)}, yw])/64 - 
     (19*G[{0, 0, 1/(yu*yv), 1, 1}, yw])/32 + 
     G[{0, 0, 1/(yu*yv), 1, yu^(-1)}, yw]/4 + 
     (5*G[{0, 0, 1/(yu*yv), 1, yv^(-1)}, yw])/16 - 
     G[{0, 0, 1/(yu*yv), 1, 1/(yu*yv)}, yw]/32 + 
     (27*G[{0, 0, 1/(yu*yv), yu^(-1), 1}, yw])/64 - 
     (9*G[{0, 0, 1/(yu*yv), yu^(-1), yu^(-1)}, yw])/64 - 
     (9*G[{0, 0, 1/(yu*yv), yu^(-1), yv^(-1)}, yw])/64 + 
     (3*G[{0, 0, 1/(yu*yv), yu^(-1), 1/(yu*yv)}, yw])/64 + 
     (19*G[{0, 0, 1/(yu*yv), yv^(-1), 1}, yw])/64 - 
     (9*G[{0, 0, 1/(yu*yv), yv^(-1), yu^(-1)}, yw])/64 - 
     (17*G[{0, 0, 1/(yu*yv), yv^(-1), yv^(-1)}, yw])/64 + 
     (3*G[{0, 0, 1/(yu*yv), yv^(-1), 1/(yu*yv)}, yw])/64 - 
     G[{0, 0, 1/(yu*yv), 1/(yu*yv), 1}, yw]/4 + 
     G[{0, 0, 1/(yu*yv), 1/(yu*yv), yu^(-1)}, yw]/4 + 
     G[{0, 0, 1/(yu*yv), 1/(yu*yv), yv^(-1)}, yw]/16 + 
     (3*G[{0, 0, 1/(yu*yv), 1/(yu*yv), 1/(yu*yv)}, yw])/16 + 
     (7*G[{0, 1, 0, 1, 1}, yu^(-1)])/16 + (7*G[{0, 1, 0, 1, 1}, yw])/64 + 
     (15*G[{0, 1, 0, 1, yu^(-1)}, yw])/64 - G[{0, 1, 0, 1, yu}, yv^(-1)]/16 - 
     G[{0, 1, 0, 1, yv^(-1)}, yw]/64 - G[{0, 1, 0, 1, 1/(yu*yv)}, yw]/4 + 
     G[{0, 1, 0, yu^(-1), 1}, yw]/4 - G[{0, 1, 0, yu^(-1), yu^(-1)}, yw]/16 - 
     (5*G[{0, 1, 0, yu^(-1), yv^(-1)}, yw])/64 - 
     (3*G[{0, 1, 0, yu^(-1), 1/(yu*yv)}, yw])/64 - 
     G[{0, 1, 0, yu, 1}, yv^(-1)]/16 - G[{0, 1, 0, yu, yu}, yv^(-1)]/16 + 
     G[{0, 1, 0, yv^(-1), 1}, yw]/16 - (5*G[{0, 1, 0, yv^(-1), yu^(-1)}, yw])/
      64 - (3*G[{0, 1, 0, yv^(-1), yv^(-1)}, yw])/16 + 
     G[{0, 1, 0, yv^(-1), 1/(yu*yv)}, yw]/64 - 
     (5*G[{0, 1, 0, 1/(yu*yv), 1}, yw])/16 + 
     G[{0, 1, 0, 1/(yu*yv), yu^(-1)}, yw]/8 - 
     G[{0, 1, 0, 1/(yu*yv), yv^(-1)}, yw]/16 + 
     G[{0, 1, 0, 1/(yu*yv), 1/(yu*yv)}, yw]/64 + 
     (15*G[{0, 1, 1, 0, yu^(-1)}, yw])/64 + (3*G[{0, 1, 1, 0, yv^(-1)}, yw])/
      64 - (11*G[{0, 1, 1, 0, 1/(yu*yv)}, yw])/64 + 
     (5*G[{0, 1, 1, 1, 1}, yu^(-1)])/8 - G[{0, 1, 1, 1, 1}, yv^(-1)]/4 + 
     (3*G[{0, 1, 1, 1, 1}, yw])/16 - (17*G[{0, 1, 1, 1, yu^(-1)}, yw])/64 + 
     (3*G[{0, 1, 1, 1, yu}, yv^(-1)])/16 - (9*G[{0, 1, 1, 1, yv^(-1)}, yw])/
      64 + G[{0, 1, 1, 1, 1/(yu*yv)}, yw]/8 - 
     (11*G[{0, 1, 1, yu^(-1), 1}, yw])/32 + 
     (9*G[{0, 1, 1, yu^(-1), yu^(-1)}, yw])/64 + 
     G[{0, 1, 1, yu^(-1), yv^(-1)}, yw]/64 + 
     (3*G[{0, 1, 1, yu^(-1), 1/(yu*yv)}, yw])/32 + 
     (3*G[{0, 1, 1, yu, 1}, yv^(-1)])/16 - (3*G[{0, 1, 1, yu, yu}, yv^(-1)])/
      16 - (5*G[{0, 1, 1, yv^(-1), 1}, yw])/32 + 
     G[{0, 1, 1, yv^(-1), yu^(-1)}, yw]/64 + 
     (9*G[{0, 1, 1, yv^(-1), yv^(-1)}, yw])/64 + 
     (3*G[{0, 1, 1, yv^(-1), 1/(yu*yv)}, yw])/32 + 
     (5*G[{0, 1, 1, 1/(yu*yv), 1}, yw])/16 - 
     (13*G[{0, 1, 1, 1/(yu*yv), yu^(-1)}, yw])/64 - 
     G[{0, 1, 1, 1/(yu*yv), yv^(-1)}, yw]/64 + 
     G[{0, 1, yu^(-1), 0, yu^(-1)}, yw]/16 - 
     G[{0, 1, yu^(-1), 0, yv^(-1)}, yw]/16 - 
     (13*G[{0, 1, yu^(-1), 1, 1}, yw])/32 + 
     (9*G[{0, 1, yu^(-1), 1, yu^(-1)}, yw])/64 + 
     G[{0, 1, yu^(-1), 1, yv^(-1)}, yw]/64 + 
     (3*G[{0, 1, yu^(-1), 1, 1/(yu*yv)}, yw])/32 + 
     (13*G[{0, 1, yu^(-1), yu^(-1), 1}, yw])/64 + 
     (7*G[{0, 1, yu^(-1), yu^(-1), yu^(-1)}, yw])/32 + 
     (7*G[{0, 1, yu^(-1), yu^(-1), yv^(-1)}, yw])/32 - 
     (11*G[{0, 1, yu^(-1), yu^(-1), 1/(yu*yv)}, yw])/64 + 
     (5*G[{0, 1, yu^(-1), yv^(-1), 1}, yw])/64 + 
     (7*G[{0, 1, yu^(-1), yv^(-1), yu^(-1)}, yw])/32 - 
     G[{0, 1, yu^(-1), yv^(-1), yv^(-1)}, yw]/32 - 
     (11*G[{0, 1, yu^(-1), yv^(-1), 1/(yu*yv)}, yw])/64 - 
     G[{0, 1, yu^(-1), 1/(yu*yv), 1}, yw]/32 - 
     (15*G[{0, 1, yu^(-1), 1/(yu*yv), yu^(-1)}, yw])/64 + 
     G[{0, 1, yu^(-1), 1/(yu*yv), yv^(-1)}, yw]/64 + 
     (3*G[{0, 1, yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/32 - 
     G[{0, 1, yu, 0, yu}, yv^(-1)]/8 + G[{0, 1, yu, 1, 1}, yv^(-1)]/8 - 
     G[{0, 1, yu, 1, yu}, yv^(-1)]/8 - G[{0, 1, yu, yu, 1}, yv^(-1)]/4 + 
     G[{0, 1, yu, yu, yu}, yv^(-1)]/8 - G[{0, 1, yv^(-1), 0, yu^(-1)}, yw]/
      64 - G[{0, 1, yv^(-1), 0, yv^(-1)}, yw]/8 + 
     G[{0, 1, yv^(-1), 0, 1/(yu*yv)}, yw]/16 - 
     (3*G[{0, 1, yv^(-1), 1, 1}, yw])/32 + 
     (5*G[{0, 1, yv^(-1), 1, yu^(-1)}, yw])/64 + 
     (17*G[{0, 1, yv^(-1), 1, yv^(-1)}, yw])/64 + 
     (3*G[{0, 1, yv^(-1), 1, 1/(yu*yv)}, yw])/32 + 
     (5*G[{0, 1, yv^(-1), yu^(-1), 1}, yw])/64 + 
     (7*G[{0, 1, yv^(-1), yu^(-1), yu^(-1)}, yw])/32 - 
     G[{0, 1, yv^(-1), yu^(-1), yv^(-1)}, yw]/32 - 
     (11*G[{0, 1, yv^(-1), yu^(-1), 1/(yu*yv)}, yw])/64 + 
     (21*G[{0, 1, yv^(-1), yv^(-1), 1}, yw])/64 - 
     G[{0, 1, yv^(-1), yv^(-1), yu^(-1)}, yw]/32 - 
     (25*G[{0, 1, yv^(-1), yv^(-1), yv^(-1)}, yw])/32 - 
     (11*G[{0, 1, yv^(-1), yv^(-1), 1/(yu*yv)}, yw])/64 - 
     (3*G[{0, 1, yv^(-1), 1/(yu*yv), 1}, yw])/32 - 
     (11*G[{0, 1, yv^(-1), 1/(yu*yv), yu^(-1)}, yw])/64 + 
     (9*G[{0, 1, yv^(-1), 1/(yu*yv), yv^(-1)}, yw])/64 + 
     (3*G[{0, 1, yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/32 - 
     G[{0, 1, 1/(yu*yv), 0, yu^(-1)}, yw]/16 - 
     G[{0, 1, 1/(yu*yv), 0, yv^(-1)}, yw]/8 + 
     G[{0, 1, 1/(yu*yv), 0, 1/(yu*yv)}, yw]/64 + 
     (5*G[{0, 1, 1/(yu*yv), 1, 1}, yw])/16 - 
     (17*G[{0, 1, 1/(yu*yv), 1, yu^(-1)}, yw])/64 - 
     (9*G[{0, 1, 1/(yu*yv), 1, yv^(-1)}, yw])/64 - 
     (11*G[{0, 1, 1/(yu*yv), yu^(-1), 1}, yw])/32 - 
     (7*G[{0, 1, 1/(yu*yv), yu^(-1), yu^(-1)}, yw])/64 + 
     G[{0, 1, 1/(yu*yv), yu^(-1), yv^(-1)}, yw]/64 + 
     (3*G[{0, 1, 1/(yu*yv), yu^(-1), 1/(yu*yv)}, yw])/32 - 
     (5*G[{0, 1, 1/(yu*yv), yv^(-1), 1}, yw])/32 + 
     G[{0, 1, 1/(yu*yv), yv^(-1), yu^(-1)}, yw]/64 + 
     (17*G[{0, 1, 1/(yu*yv), yv^(-1), yv^(-1)}, yw])/64 + 
     (3*G[{0, 1, 1/(yu*yv), yv^(-1), 1/(yu*yv)}, yw])/32 - 
     G[{0, 1, 1/(yu*yv), 1/(yu*yv), 1}, yw]/16 + 
     (3*G[{0, 1, 1/(yu*yv), 1/(yu*yv), yu^(-1)}, yw])/64 + 
     (15*G[{0, 1, 1/(yu*yv), 1/(yu*yv), yv^(-1)}, yw])/64 + 
     (3*G[{0, yu^(-1), 0, yu^(-1), 1}, yw])/64 + 
     (5*G[{0, yu^(-1), 0, yu^(-1), yu^(-1)}, yw])/16 + 
     (15*G[{0, yu^(-1), 0, yu^(-1), 1/(yu*yv)}, yw])/64 + 
     G[{0, yu^(-1), 0, yv^(-1), 1}, yw]/16 + 
     (3*G[{0, yu^(-1), 0, yv^(-1), yv^(-1)}, yw])/16 + 
     (3*G[{0, yu^(-1), 0, 1/(yu*yv), 1}, yw])/16 - 
     G[{0, yu^(-1), 0, 1/(yu*yv), yu^(-1)}, yw]/8 - 
     (7*G[{0, yu^(-1), 0, 1/(yu*yv), yv^(-1)}, yw])/64 + 
     (3*G[{0, yu^(-1), 0, 1/(yu*yv), 1/(yu*yv)}, yw])/64 + 
     G[{0, yu^(-1), 1, 0, yv^(-1)}, yw]/64 + 
     (3*G[{0, yu^(-1), 1, 0, 1/(yu*yv)}, yw])/64 - 
     (3*G[{0, yu^(-1), 1, 1, 1}, yw])/16 + 
     (17*G[{0, yu^(-1), 1, 1, yu^(-1)}, yw])/64 + 
     (9*G[{0, yu^(-1), 1, 1, yv^(-1)}, yw])/64 + 
     (11*G[{0, yu^(-1), 1, yu^(-1), 1}, yw])/32 - 
     (9*G[{0, yu^(-1), 1, yu^(-1), yu^(-1)}, yw])/64 - 
     G[{0, yu^(-1), 1, yu^(-1), yv^(-1)}, yw]/64 - 
     (3*G[{0, yu^(-1), 1, yu^(-1), 1/(yu*yv)}, yw])/32 + 
     (5*G[{0, yu^(-1), 1, yv^(-1), 1}, yw])/32 - 
     G[{0, yu^(-1), 1, yv^(-1), yu^(-1)}, yw]/64 - 
     G[{0, yu^(-1), 1, yv^(-1), yv^(-1)}, yw]/64 - 
     (3*G[{0, yu^(-1), 1, yv^(-1), 1/(yu*yv)}, yw])/32 - 
     G[{0, yu^(-1), 1, 1/(yu*yv), 1}, yw]/16 + 
     (5*G[{0, yu^(-1), 1, 1/(yu*yv), yu^(-1)}, yw])/64 - 
     (7*G[{0, yu^(-1), 1, 1/(yu*yv), yv^(-1)}, yw])/64 - 
     G[{0, yu^(-1), yu^(-1), 0, yv^(-1)}, yw]/16 + 
     (3*G[{0, yu^(-1), yu^(-1), 0, 1/(yu*yv)}, yw])/16 + 
     (13*G[{0, yu^(-1), yu^(-1), 1, 1}, yw])/32 - 
     (9*G[{0, yu^(-1), yu^(-1), 1, yu^(-1)}, yw])/64 - 
     G[{0, yu^(-1), yu^(-1), 1, yv^(-1)}, yw]/64 - 
     (3*G[{0, yu^(-1), yu^(-1), 1, 1/(yu*yv)}, yw])/32 - 
     (13*G[{0, yu^(-1), yu^(-1), yu^(-1), 1}, yw])/64 - 
     (7*G[{0, yu^(-1), yu^(-1), yu^(-1), yu^(-1)}, yw])/32 - 
     (7*G[{0, yu^(-1), yu^(-1), yu^(-1), yv^(-1)}, yw])/32 + 
     (3*G[{0, yu^(-1), yu^(-1), yu^(-1), 1/(yu*yv)}, yw])/64 - 
     (5*G[{0, yu^(-1), yu^(-1), yv^(-1), 1}, yw])/64 - 
     (7*G[{0, yu^(-1), yu^(-1), yv^(-1), yu^(-1)}, yw])/32 - 
     (7*G[{0, yu^(-1), yu^(-1), yv^(-1), yv^(-1)}, yw])/32 + 
     (11*G[{0, yu^(-1), yu^(-1), yv^(-1), 1/(yu*yv)}, yw])/64 - 
     (7*G[{0, yu^(-1), yu^(-1), 1/(yu*yv), 1}, yw])/32 + 
     (23*G[{0, yu^(-1), yu^(-1), 1/(yu*yv), yu^(-1)}, yw])/64 + 
     (15*G[{0, yu^(-1), yu^(-1), 1/(yu*yv), yv^(-1)}, yw])/64 - 
     (3*G[{0, yu^(-1), yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/32 + 
     G[{0, yu^(-1), yv^(-1), 0, yv^(-1)}, yw]/16 + 
     (5*G[{0, yu^(-1), yv^(-1), 1, 1}, yw])/32 - 
     G[{0, yu^(-1), yv^(-1), 1, yu^(-1)}, yw]/64 - 
     G[{0, yu^(-1), yv^(-1), 1, yv^(-1)}, yw]/64 - 
     (3*G[{0, yu^(-1), yv^(-1), 1, 1/(yu*yv)}, yw])/32 - 
     (5*G[{0, yu^(-1), yv^(-1), yu^(-1), 1}, yw])/64 - 
     (7*G[{0, yu^(-1), yv^(-1), yu^(-1), yu^(-1)}, yw])/32 - 
     (7*G[{0, yu^(-1), yv^(-1), yu^(-1), yv^(-1)}, yw])/32 + 
     (11*G[{0, yu^(-1), yv^(-1), yu^(-1), 1/(yu*yv)}, yw])/64 - 
     (5*G[{0, yu^(-1), yv^(-1), yv^(-1), 1}, yw])/64 - 
     (7*G[{0, yu^(-1), yv^(-1), yv^(-1), yu^(-1)}, yw])/32 + 
     (9*G[{0, yu^(-1), yv^(-1), yv^(-1), yv^(-1)}, yw])/32 + 
     (11*G[{0, yu^(-1), yv^(-1), yv^(-1), 1/(yu*yv)}, yw])/64 + 
     G[{0, yu^(-1), yv^(-1), 1/(yu*yv), 1}, yw]/32 + 
     (15*G[{0, yu^(-1), yv^(-1), 1/(yu*yv), yu^(-1)}, yw])/64 - 
     G[{0, yu^(-1), yv^(-1), 1/(yu*yv), yv^(-1)}, yw]/64 - 
     (3*G[{0, yu^(-1), yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/32 + 
     G[{0, yu^(-1), 1/(yu*yv), 0, yv^(-1)}, yw]/64 + 
     (3*G[{0, yu^(-1), 1/(yu*yv), 0, 1/(yu*yv)}, yw])/64 + 
     G[{0, yu^(-1), 1/(yu*yv), 1, 1}, yw]/8 - 
     (3*G[{0, yu^(-1), 1/(yu*yv), 1, yu^(-1)}, yw])/64 - 
     (7*G[{0, yu^(-1), 1/(yu*yv), 1, yv^(-1)}, yw])/64 - 
     (5*G[{0, yu^(-1), 1/(yu*yv), yu^(-1), 1}, yw])/32 + 
     (23*G[{0, yu^(-1), 1/(yu*yv), yu^(-1), yu^(-1)}, yw])/64 + 
     (15*G[{0, yu^(-1), 1/(yu*yv), yu^(-1), yv^(-1)}, yw])/64 - 
     (3*G[{0, yu^(-1), 1/(yu*yv), yu^(-1), 1/(yu*yv)}, yw])/32 - 
     (3*G[{0, yu^(-1), 1/(yu*yv), yv^(-1), 1}, yw])/32 + 
     (15*G[{0, yu^(-1), 1/(yu*yv), yv^(-1), yu^(-1)}, yw])/64 - 
     G[{0, yu^(-1), 1/(yu*yv), yv^(-1), yv^(-1)}, yw]/64 - 
     (3*G[{0, yu^(-1), 1/(yu*yv), yv^(-1), 1/(yu*yv)}, yw])/32 + 
     G[{0, yu^(-1), 1/(yu*yv), 1/(yu*yv), 1}, yw]/8 - 
     (7*G[{0, yu^(-1), 1/(yu*yv), 1/(yu*yv), yu^(-1)}, yw])/64 - 
     (7*G[{0, yu^(-1), 1/(yu*yv), 1/(yu*yv), yv^(-1)}, yw])/64 - 
     (3*G[{0, yu, 0, yu, yu}, yv^(-1)])/16 + G[{0, yu, 1, 1, 1}, yv^(-1)]/
      16 - G[{0, yu, 1, 1, yu}, yv^(-1)]/4 - 
     (3*G[{0, yu, 1, yu, 1}, yv^(-1)])/16 + G[{0, yu, 1, yu, yu}, yv^(-1)]/
      16 - G[{0, yu, yu, 1, 1}, yv^(-1)]/16 + G[{0, yu, yu, 1, yu}, yv^(-1)]/
      16 + (3*G[{0, yu, yu, yu, 1}, yv^(-1)])/8 + 
     G[{0, yu, yu, yu, yu}, yv^(-1)]/8 - G[{0, yv^(-1), 0, yv^(-1), 1}, yw]/
      64 - G[{0, yv^(-1), 0, yv^(-1), yu^(-1)}, yw]/16 - 
     (3*G[{0, yv^(-1), 0, yv^(-1), yv^(-1)}, yw])/16 - 
     (9*G[{0, yv^(-1), 0, yv^(-1), 1/(yu*yv)}, yw])/64 + 
     G[{0, yv^(-1), 0, 1/(yu*yv), 1}, yw]/8 - 
     G[{0, yv^(-1), 0, 1/(yu*yv), yu^(-1)}, yw]/16 + 
     G[{0, yv^(-1), 0, 1/(yu*yv), yv^(-1)}, yw]/16 - 
     G[{0, yv^(-1), 0, 1/(yu*yv), 1/(yu*yv)}, yw]/64 + 
     (3*G[{0, yv^(-1), 1, 0, 1/(yu*yv)}, yw])/64 + 
     (5*G[{0, yv^(-1), 1, 1, yu^(-1)}, yw])/64 + 
     G[{0, yv^(-1), 1, 1, yv^(-1)}, yw]/64 + 
     (3*G[{0, yv^(-1), 1, yu^(-1), 1}, yw])/32 + 
     (7*G[{0, yv^(-1), 1, yu^(-1), yu^(-1)}, yw])/64 - 
     G[{0, yv^(-1), 1, yu^(-1), yv^(-1)}, yw]/64 - 
     (3*G[{0, yv^(-1), 1, yu^(-1), 1/(yu*yv)}, yw])/32 + 
     (5*G[{0, yv^(-1), 1, yv^(-1), 1}, yw])/32 - 
     G[{0, yv^(-1), 1, yv^(-1), yu^(-1)}, yw]/64 - 
     (25*G[{0, yv^(-1), 1, yv^(-1), yv^(-1)}, yw])/64 - 
     (3*G[{0, yv^(-1), 1, yv^(-1), 1/(yu*yv)}, yw])/32 - 
     G[{0, yv^(-1), 1, 1/(yu*yv), 1}, yw]/8 + 
     G[{0, yv^(-1), 1, 1/(yu*yv), yu^(-1)}, yw]/64 + 
     G[{0, yv^(-1), 1, 1/(yu*yv), yv^(-1)}, yw]/64 + 
     (5*G[{0, yv^(-1), yu^(-1), 1, 1}, yw])/32 - 
     G[{0, yv^(-1), yu^(-1), 1, yu^(-1)}, yw]/64 - 
     G[{0, yv^(-1), yu^(-1), 1, yv^(-1)}, yw]/64 - 
     (3*G[{0, yv^(-1), yu^(-1), 1, 1/(yu*yv)}, yw])/32 - 
     (5*G[{0, yv^(-1), yu^(-1), yu^(-1), 1}, yw])/64 - 
     (7*G[{0, yv^(-1), yu^(-1), yu^(-1), yu^(-1)}, yw])/32 - 
     (7*G[{0, yv^(-1), yu^(-1), yu^(-1), yv^(-1)}, yw])/32 + 
     (11*G[{0, yv^(-1), yu^(-1), yu^(-1), 1/(yu*yv)}, yw])/64 - 
     (5*G[{0, yv^(-1), yu^(-1), yv^(-1), 1}, yw])/64 - 
     (7*G[{0, yv^(-1), yu^(-1), yv^(-1), yu^(-1)}, yw])/32 + 
     (9*G[{0, yv^(-1), yu^(-1), yv^(-1), yv^(-1)}, yw])/32 + 
     (11*G[{0, yv^(-1), yu^(-1), yv^(-1), 1/(yu*yv)}, yw])/64 + 
     G[{0, yv^(-1), yu^(-1), 1/(yu*yv), 1}, yw]/32 + 
     (15*G[{0, yv^(-1), yu^(-1), 1/(yu*yv), yu^(-1)}, yw])/64 - 
     G[{0, yv^(-1), yu^(-1), 1/(yu*yv), yv^(-1)}, yw]/64 - 
     (3*G[{0, yv^(-1), yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/32 - 
     G[{0, yv^(-1), yv^(-1), 0, 1/(yu*yv)}, yw]/16 + 
     G[{0, yv^(-1), yv^(-1), 1, 1}, yw]/32 - 
     (9*G[{0, yv^(-1), yv^(-1), 1, yu^(-1)}, yw])/64 - 
     (25*G[{0, yv^(-1), yv^(-1), 1, yv^(-1)}, yw])/64 - 
     (3*G[{0, yv^(-1), yv^(-1), 1, 1/(yu*yv)}, yw])/32 - 
     (5*G[{0, yv^(-1), yv^(-1), yu^(-1), 1}, yw])/64 - 
     (7*G[{0, yv^(-1), yv^(-1), yu^(-1), yu^(-1)}, yw])/32 + 
     (9*G[{0, yv^(-1), yv^(-1), yu^(-1), yv^(-1)}, yw])/32 + 
     (11*G[{0, yv^(-1), yv^(-1), yu^(-1), 1/(yu*yv)}, yw])/64 - 
     (29*G[{0, yv^(-1), yv^(-1), yv^(-1), 1}, yw])/64 + 
     (9*G[{0, yv^(-1), yv^(-1), yv^(-1), yu^(-1)}, yw])/32 + 
     (41*G[{0, yv^(-1), yv^(-1), yv^(-1), yv^(-1)}, yw])/32 + 
     (3*G[{0, yv^(-1), yv^(-1), yv^(-1), 1/(yu*yv)}, yw])/64 + 
     (5*G[{0, yv^(-1), yv^(-1), 1/(yu*yv), 1}, yw])/32 + 
     (7*G[{0, yv^(-1), yv^(-1), 1/(yu*yv), yu^(-1)}, yw])/64 - 
     (25*G[{0, yv^(-1), yv^(-1), 1/(yu*yv), yv^(-1)}, yw])/64 - 
     (3*G[{0, yv^(-1), yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/32 - 
     G[{0, yv^(-1), 1/(yu*yv), 0, 1/(yu*yv)}, yw]/64 + 
     G[{0, yv^(-1), 1/(yu*yv), 1, 1}, yw]/16 + 
     (9*G[{0, yv^(-1), 1/(yu*yv), 1, yu^(-1)}, yw])/64 + 
     G[{0, yv^(-1), 1/(yu*yv), 1, yv^(-1)}, yw]/64 + 
     (7*G[{0, yv^(-1), 1/(yu*yv), yu^(-1), 1}, yw])/32 + 
     (7*G[{0, yv^(-1), 1/(yu*yv), yu^(-1), yu^(-1)}, yw])/64 - 
     G[{0, yv^(-1), 1/(yu*yv), yu^(-1), yv^(-1)}, yw]/64 - 
     (3*G[{0, yv^(-1), 1/(yu*yv), yu^(-1), 1/(yu*yv)}, yw])/32 + 
     G[{0, yv^(-1), 1/(yu*yv), yv^(-1), 1}, yw]/32 - 
     G[{0, yv^(-1), 1/(yu*yv), yv^(-1), yu^(-1)}, yw]/64 - 
     (25*G[{0, yv^(-1), 1/(yu*yv), yv^(-1), yv^(-1)}, yw])/64 - 
     (3*G[{0, yv^(-1), 1/(yu*yv), yv^(-1), 1/(yu*yv)}, yw])/32 + 
     G[{0, yv^(-1), 1/(yu*yv), 1/(yu*yv), 1}, yw]/16 - 
     (3*G[{0, yv^(-1), 1/(yu*yv), 1/(yu*yv), yu^(-1)}, yw])/64 - 
     (15*G[{0, yv^(-1), 1/(yu*yv), 1/(yu*yv), yv^(-1)}, yw])/64 - 
     (5*G[{0, 1/(yu*yv), 0, 1/(yu*yv), 1}, yw])/64 + 
     (3*G[{0, 1/(yu*yv), 0, 1/(yu*yv), yu^(-1)}, yw])/16 + 
     (3*G[{0, 1/(yu*yv), 0, 1/(yu*yv), 1/(yu*yv)}, yw])/64 - 
     (5*G[{0, 1/(yu*yv), 1, 1, yu^(-1)}, yw])/64 - 
     G[{0, 1/(yu*yv), 1, 1, yv^(-1)}, yw]/64 - 
     G[{0, 1/(yu*yv), 1, 1, 1/(yu*yv)}, yw]/8 - 
     (3*G[{0, 1/(yu*yv), 1, yu^(-1), 1}, yw])/32 - 
     (7*G[{0, 1/(yu*yv), 1, yu^(-1), yu^(-1)}, yw])/64 + 
     G[{0, 1/(yu*yv), 1, yu^(-1), yv^(-1)}, yw]/64 + 
     (3*G[{0, 1/(yu*yv), 1, yu^(-1), 1/(yu*yv)}, yw])/32 - 
     (5*G[{0, 1/(yu*yv), 1, yv^(-1), 1}, yw])/32 + 
     G[{0, 1/(yu*yv), 1, yv^(-1), yu^(-1)}, yw]/64 + 
     (17*G[{0, 1/(yu*yv), 1, yv^(-1), yv^(-1)}, yw])/64 + 
     (3*G[{0, 1/(yu*yv), 1, yv^(-1), 1/(yu*yv)}, yw])/32 - 
     G[{0, 1/(yu*yv), 1, 1/(yu*yv), 1}, yw]/8 + 
     (7*G[{0, 1/(yu*yv), 1, 1/(yu*yv), yu^(-1)}, yw])/64 + 
     (7*G[{0, 1/(yu*yv), 1, 1/(yu*yv), yv^(-1)}, yw])/64 - 
     (5*G[{0, 1/(yu*yv), yu^(-1), 1, 1}, yw])/32 + 
     G[{0, 1/(yu*yv), yu^(-1), 1, yu^(-1)}, yw]/64 + 
     G[{0, 1/(yu*yv), yu^(-1), 1, yv^(-1)}, yw]/64 + 
     (3*G[{0, 1/(yu*yv), yu^(-1), 1, 1/(yu*yv)}, yw])/32 + 
     (5*G[{0, 1/(yu*yv), yu^(-1), yu^(-1), 1}, yw])/64 + 
     (7*G[{0, 1/(yu*yv), yu^(-1), yu^(-1), yu^(-1)}, yw])/32 + 
     (7*G[{0, 1/(yu*yv), yu^(-1), yu^(-1), yv^(-1)}, yw])/32 - 
     (3*G[{0, 1/(yu*yv), yu^(-1), yu^(-1), 1/(yu*yv)}, yw])/64 + 
     (5*G[{0, 1/(yu*yv), yu^(-1), yv^(-1), 1}, yw])/64 + 
     (7*G[{0, 1/(yu*yv), yu^(-1), yv^(-1), yu^(-1)}, yw])/32 - 
     G[{0, 1/(yu*yv), yu^(-1), yv^(-1), yv^(-1)}, yw]/32 - 
     (11*G[{0, 1/(yu*yv), yu^(-1), yv^(-1), 1/(yu*yv)}, yw])/64 + 
     (7*G[{0, 1/(yu*yv), yu^(-1), 1/(yu*yv), 1}, yw])/32 - 
     (23*G[{0, 1/(yu*yv), yu^(-1), 1/(yu*yv), yu^(-1)}, yw])/64 - 
     (15*G[{0, 1/(yu*yv), yu^(-1), 1/(yu*yv), yv^(-1)}, yw])/64 + 
     (3*G[{0, 1/(yu*yv), yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/32 - 
     (3*G[{0, 1/(yu*yv), yv^(-1), 1, 1}, yw])/32 + 
     (5*G[{0, 1/(yu*yv), yv^(-1), 1, yu^(-1)}, yw])/64 + 
     (9*G[{0, 1/(yu*yv), yv^(-1), 1, yv^(-1)}, yw])/64 + 
     (3*G[{0, 1/(yu*yv), yv^(-1), 1, 1/(yu*yv)}, yw])/32 + 
     (5*G[{0, 1/(yu*yv), yv^(-1), yu^(-1), 1}, yw])/64 + 
     (7*G[{0, 1/(yu*yv), yv^(-1), yu^(-1), yu^(-1)}, yw])/32 - 
     G[{0, 1/(yu*yv), yv^(-1), yu^(-1), yv^(-1)}, yw]/32 - 
     (11*G[{0, 1/(yu*yv), yv^(-1), yu^(-1), 1/(yu*yv)}, yw])/64 + 
     (13*G[{0, 1/(yu*yv), yv^(-1), yv^(-1), 1}, yw])/64 - 
     G[{0, 1/(yu*yv), yv^(-1), yv^(-1), yu^(-1)}, yw]/32 - 
     (25*G[{0, 1/(yu*yv), yv^(-1), yv^(-1), yv^(-1)}, yw])/32 - 
     (3*G[{0, 1/(yu*yv), yv^(-1), yv^(-1), 1/(yu*yv)}, yw])/64 - 
     (3*G[{0, 1/(yu*yv), yv^(-1), 1/(yu*yv), 1}, yw])/32 - 
     (11*G[{0, 1/(yu*yv), yv^(-1), 1/(yu*yv), yu^(-1)}, yw])/64 + 
     (17*G[{0, 1/(yu*yv), yv^(-1), 1/(yu*yv), yv^(-1)}, yw])/64 + 
     (3*G[{0, 1/(yu*yv), yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/32 - 
     G[{0, 1/(yu*yv), 1/(yu*yv), 1, 1}, yw]/2 + 
     (11*G[{0, 1/(yu*yv), 1/(yu*yv), 1, yu^(-1)}, yw])/64 + 
     (15*G[{0, 1/(yu*yv), 1/(yu*yv), 1, yv^(-1)}, yw])/64 + 
     (9*G[{0, 1/(yu*yv), 1/(yu*yv), yu^(-1), 1}, yw])/32 - 
     (23*G[{0, 1/(yu*yv), 1/(yu*yv), yu^(-1), yu^(-1)}, yw])/64 - 
     (15*G[{0, 1/(yu*yv), 1/(yu*yv), yu^(-1), yv^(-1)}, yw])/64 + 
     (3*G[{0, 1/(yu*yv), 1/(yu*yv), yu^(-1), 1/(yu*yv)}, yw])/32 + 
     (7*G[{0, 1/(yu*yv), 1/(yu*yv), yv^(-1), 1}, yw])/32 - 
     (15*G[{0, 1/(yu*yv), 1/(yu*yv), yv^(-1), yu^(-1)}, yw])/64 + 
     (9*G[{0, 1/(yu*yv), 1/(yu*yv), yv^(-1), yv^(-1)}, yw])/64 + 
     (3*G[{0, 1/(yu*yv), 1/(yu*yv), yv^(-1), 1/(yu*yv)}, yw])/32 - 
     G[{0, 1/(yu*yv), 1/(yu*yv), 1/(yu*yv), 1}, yw]/8 + 
     (7*G[{0, 1/(yu*yv), 1/(yu*yv), 1/(yu*yv), yu^(-1)}, yw])/64 + 
     (7*G[{0, 1/(yu*yv), 1/(yu*yv), 1/(yu*yv), yv^(-1)}, yw])/64 - 
     (7*G[{1, 1, 1, 1, yu^(-1)}, yw])/16 + G[{1, 1, 1, 1, yu}, yv^(-1)]/16 - 
     G[{1, 1, 1, 1, yv^(-1)}, yw]/16 + G[{1, 1, 1, 1, 1/(yu*yv)}, yw]/8 - 
     (5*G[{1, 1, 1, yu^(-1), yu^(-1)}, yw])/4 + 
     G[{1, 1, 1, yu^(-1), yv^(-1)}, yw]/16 + 
     G[{1, 1, 1, yu^(-1), 1/(yu*yv)}, yw]/8 + 
     (7*G[{1, 1, 1, yu, yu}, yv^(-1)])/16 + 
     G[{1, 1, 1, yv^(-1), yu^(-1)}, yw]/16 - 
     (25*G[{1, 1, 1, yv^(-1), yv^(-1)}, yw])/16 + 
     (17*G[{1, 1, 1, yv^(-1), 1/(yu*yv)}, yw])/16 + 
     (3*G[{1, 1, 1, 1/(yu*yv), yu^(-1)}, yw])/16 + 
     (9*G[{1, 1, 1, 1/(yu*yv), yv^(-1)}, yw])/8 + 
     (3*G[{1, 1, 1, 1/(yu*yv), 1/(yu*yv)}, yw])/16 - 
     (13*G[{1, 1, yu^(-1), 1, yu^(-1)}, yw])/64 + 
     (11*G[{1, 1, yu^(-1), 1, yv^(-1)}, yw])/64 - 
     (13*G[{1, 1, yu^(-1), yu^(-1), yu^(-1)}, yw])/64 + 
     (7*G[{1, 1, yu^(-1), yu^(-1), yv^(-1)}, yw])/64 - 
     G[{1, 1, yu^(-1), yu^(-1), 1/(yu*yv)}, yw]/8 + 
     (7*G[{1, 1, yu^(-1), yv^(-1), yu^(-1)}, yw])/64 - 
     (17*G[{1, 1, yu^(-1), yv^(-1), yv^(-1)}, yw])/64 - 
     (3*G[{1, 1, yu^(-1), yv^(-1), 1/(yu*yv)}, yw])/32 - 
     (3*G[{1, 1, yu^(-1), 1/(yu*yv), yu^(-1)}, yw])/64 - 
     G[{1, 1, yu^(-1), 1/(yu*yv), yv^(-1)}, yw]/64 + 
     G[{1, 1, yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw]/8 + 
     G[{1, 1, yu, 1, yu}, yv^(-1)]/16 - (15*G[{1, 1, yu, yu, yu}, yv^(-1)])/
      16 + (3*G[{1, 1, yv^(-1), 1, yu^(-1)}, yw])/64 - 
     (33*G[{1, 1, yv^(-1), 1, yv^(-1)}, yw])/64 + 
     (5*G[{1, 1, yv^(-1), 1, 1/(yu*yv)}, yw])/16 + 
     (7*G[{1, 1, yv^(-1), yu^(-1), yu^(-1)}, yw])/64 - 
     (9*G[{1, 1, yv^(-1), yu^(-1), yv^(-1)}, yw])/64 - 
     (3*G[{1, 1, yv^(-1), yu^(-1), 1/(yu*yv)}, yw])/32 - 
     G[{1, 1, yv^(-1), yv^(-1), yu^(-1)}, yw]/64 - 
     G[{1, 1, yv^(-1), yv^(-1), yv^(-1)}, yw]/64 + 
     (3*G[{1, 1, yv^(-1), yv^(-1), 1/(yu*yv)}, yw])/4 + 
     (21*G[{1, 1, yv^(-1), 1/(yu*yv), yu^(-1)}, yw])/64 + 
     (17*G[{1, 1, yv^(-1), 1/(yu*yv), yv^(-1)}, yw])/64 - 
     G[{1, 1, yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw]/8 + 
     (5*G[{1, 1, 1/(yu*yv), 1, yv^(-1)}, yw])/16 + 
     G[{1, 1, 1/(yu*yv), 1, 1/(yu*yv)}, yw]/16 + 
     G[{1, 1, 1/(yu*yv), yu^(-1), yu^(-1)}, yw]/16 + 
     G[{1, 1, 1/(yu*yv), yu^(-1), yv^(-1)}, yw]/4 - 
     G[{1, 1, 1/(yu*yv), yu^(-1), 1/(yu*yv)}, yw]/8 + 
     G[{1, 1, 1/(yu*yv), yv^(-1), yu^(-1)}, yw]/4 + 
     G[{1, 1, 1/(yu*yv), yv^(-1), yv^(-1)}, yw]/4 - 
     G[{1, 1, 1/(yu*yv), yv^(-1), 1/(yu*yv)}, yw]/8 + 
     (7*G[{1, 1, 1/(yu*yv), 1/(yu*yv), yv^(-1)}, yw])/16 - 
     G[{1, 1, 1/(yu*yv), 1/(yu*yv), 1/(yu*yv)}, yw]/4 + 
     G[{1, yu^(-1), 1, yu^(-1), yu^(-1)}, yw]/8 + 
     G[{1, yu^(-1), 1, yu^(-1), yv^(-1)}, yw]/8 - 
     (5*G[{1, yu^(-1), 1, yu^(-1), 1/(yu*yv)}, yw])/64 + 
     G[{1, yu^(-1), 1, yv^(-1), yu^(-1)}, yw]/8 - 
     (3*G[{1, yu^(-1), 1, yv^(-1), yv^(-1)}, yw])/16 - 
     G[{1, yu^(-1), 1, 1/(yu*yv), yu^(-1)}, yw]/8 + 
     (5*G[{1, yu^(-1), 1, 1/(yu*yv), yv^(-1)}, yw])/64 + 
     G[{1, yu^(-1), 1, 1/(yu*yv), 1/(yu*yv)}, yw]/16 + 
     G[{1, yu^(-1), yu^(-1), 1, yv^(-1)}, yw]/16 - 
     G[{1, yu^(-1), yu^(-1), 1, 1/(yu*yv)}, yw]/16 + 
     (3*G[{1, yu^(-1), yu^(-1), yu^(-1), yu^(-1)}, yw])/32 + 
     (7*G[{1, yu^(-1), yu^(-1), yu^(-1), yv^(-1)}, yw])/32 - 
     (3*G[{1, yu^(-1), yu^(-1), yu^(-1), 1/(yu*yv)}, yw])/64 + 
     (7*G[{1, yu^(-1), yu^(-1), yv^(-1), yu^(-1)}, yw])/32 + 
     (7*G[{1, yu^(-1), yu^(-1), yv^(-1), yv^(-1)}, yw])/32 - 
     (11*G[{1, yu^(-1), yu^(-1), yv^(-1), 1/(yu*yv)}, yw])/64 - 
     (3*G[{1, yu^(-1), yu^(-1), 1/(yu*yv), yu^(-1)}, yw])/64 - 
     (7*G[{1, yu^(-1), yu^(-1), 1/(yu*yv), yv^(-1)}, yw])/64 + 
     (3*G[{1, yu^(-1), yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/32 - 
     G[{1, yu^(-1), yv^(-1), 1, yv^(-1)}, yw]/16 + 
     G[{1, yu^(-1), yv^(-1), 1, 1/(yu*yv)}, yw]/8 + 
     (7*G[{1, yu^(-1), yv^(-1), yu^(-1), yu^(-1)}, yw])/32 + 
     (7*G[{1, yu^(-1), yv^(-1), yu^(-1), yv^(-1)}, yw])/32 - 
     (11*G[{1, yu^(-1), yv^(-1), yu^(-1), 1/(yu*yv)}, yw])/64 + 
     (7*G[{1, yu^(-1), yv^(-1), yv^(-1), yu^(-1)}, yw])/32 - 
     (9*G[{1, yu^(-1), yv^(-1), yv^(-1), yv^(-1)}, yw])/32 - 
     (11*G[{1, yu^(-1), yv^(-1), yv^(-1), 1/(yu*yv)}, yw])/64 - 
     (15*G[{1, yu^(-1), yv^(-1), 1/(yu*yv), yu^(-1)}, yw])/64 + 
     G[{1, yu^(-1), yv^(-1), 1/(yu*yv), yv^(-1)}, yw]/64 + 
     (3*G[{1, yu^(-1), yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/32 - 
     (3*G[{1, yu^(-1), 1/(yu*yv), 1, yv^(-1)}, yw])/64 + 
     G[{1, yu^(-1), 1/(yu*yv), 1, 1/(yu*yv)}, yw]/16 - 
     (3*G[{1, yu^(-1), 1/(yu*yv), yu^(-1), yu^(-1)}, yw])/64 - 
     (7*G[{1, yu^(-1), 1/(yu*yv), yu^(-1), yv^(-1)}, yw])/64 + 
     (3*G[{1, yu^(-1), 1/(yu*yv), yu^(-1), 1/(yu*yv)}, yw])/32 - 
     (7*G[{1, yu^(-1), 1/(yu*yv), yv^(-1), yu^(-1)}, yw])/64 + 
     (9*G[{1, yu^(-1), 1/(yu*yv), yv^(-1), yv^(-1)}, yw])/64 + 
     (3*G[{1, yu^(-1), 1/(yu*yv), yv^(-1), 1/(yu*yv)}, yw])/32 - 
     (9*G[{1, yu^(-1), 1/(yu*yv), 1/(yu*yv), yu^(-1)}, yw])/64 + 
     (11*G[{1, yu^(-1), 1/(yu*yv), 1/(yu*yv), yv^(-1)}, yw])/64 - 
     (7*G[{1, yu, 1, yu, yu}, yv^(-1)])/16 - G[{1, yu, yu, yu, yu}, yv^(-1)]/
      8 + G[{1, yv^(-1), 1, yv^(-1), yu^(-1)}, yw]/16 + 
     (5*G[{1, yv^(-1), 1, yv^(-1), yv^(-1)}, yw])/16 + 
     (23*G[{1, yv^(-1), 1, yv^(-1), 1/(yu*yv)}, yw])/64 + 
     G[{1, yv^(-1), 1, 1/(yu*yv), yu^(-1)}, yw]/4 + 
     G[{1, yv^(-1), 1, 1/(yu*yv), yv^(-1)}, yw]/8 - 
     G[{1, yv^(-1), 1, 1/(yu*yv), 1/(yu*yv)}, yw]/16 + 
     G[{1, yv^(-1), yu^(-1), 1, 1/(yu*yv)}, yw]/8 + 
     (7*G[{1, yv^(-1), yu^(-1), yu^(-1), yu^(-1)}, yw])/32 + 
     (7*G[{1, yv^(-1), yu^(-1), yu^(-1), yv^(-1)}, yw])/32 - 
     (11*G[{1, yv^(-1), yu^(-1), yu^(-1), 1/(yu*yv)}, yw])/64 + 
     (7*G[{1, yv^(-1), yu^(-1), yv^(-1), yu^(-1)}, yw])/32 - 
     (9*G[{1, yv^(-1), yu^(-1), yv^(-1), yv^(-1)}, yw])/32 - 
     (11*G[{1, yv^(-1), yu^(-1), yv^(-1), 1/(yu*yv)}, yw])/64 - 
     (15*G[{1, yv^(-1), yu^(-1), 1/(yu*yv), yu^(-1)}, yw])/64 + 
     G[{1, yv^(-1), yu^(-1), 1/(yu*yv), yv^(-1)}, yw]/64 + 
     (3*G[{1, yv^(-1), yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/32 + 
     (3*G[{1, yv^(-1), yv^(-1), 1, 1/(yu*yv)}, yw])/8 + 
     (7*G[{1, yv^(-1), yv^(-1), yu^(-1), yu^(-1)}, yw])/32 - 
     (9*G[{1, yv^(-1), yv^(-1), yu^(-1), yv^(-1)}, yw])/32 - 
     (11*G[{1, yv^(-1), yv^(-1), yu^(-1), 1/(yu*yv)}, yw])/64 - 
     (9*G[{1, yv^(-1), yv^(-1), yv^(-1), yu^(-1)}, yw])/32 - 
     (41*G[{1, yv^(-1), yv^(-1), yv^(-1), yv^(-1)}, yw])/32 - 
     (3*G[{1, yv^(-1), yv^(-1), yv^(-1), 1/(yu*yv)}, yw])/64 - 
     (23*G[{1, yv^(-1), yv^(-1), 1/(yu*yv), yu^(-1)}, yw])/64 + 
     (9*G[{1, yv^(-1), yv^(-1), 1/(yu*yv), yv^(-1)}, yw])/64 + 
     (3*G[{1, yv^(-1), yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/32 - 
     G[{1, yv^(-1), 1/(yu*yv), 1, 1/(yu*yv)}, yw]/16 - 
     (7*G[{1, yv^(-1), 1/(yu*yv), yu^(-1), yu^(-1)}, yw])/64 - 
     (7*G[{1, yv^(-1), 1/(yu*yv), yu^(-1), yv^(-1)}, yw])/64 + 
     (3*G[{1, yv^(-1), 1/(yu*yv), yu^(-1), 1/(yu*yv)}, yw])/32 - 
     (7*G[{1, yv^(-1), 1/(yu*yv), yv^(-1), yu^(-1)}, yw])/64 + 
     (9*G[{1, yv^(-1), 1/(yu*yv), yv^(-1), yv^(-1)}, yw])/64 + 
     (3*G[{1, yv^(-1), 1/(yu*yv), yv^(-1), 1/(yu*yv)}, yw])/32 + 
     (3*G[{1, yv^(-1), 1/(yu*yv), 1/(yu*yv), yu^(-1)}, yw])/64 + 
     (7*G[{1, yv^(-1), 1/(yu*yv), 1/(yu*yv), yv^(-1)}, yw])/64 - 
     (3*G[{1, 1/(yu*yv), 1, 1/(yu*yv), yu^(-1)}, yw])/16 + 
     G[{1, 1/(yu*yv), 1, 1/(yu*yv), yv^(-1)}, yw]/8 - 
     G[{1, 1/(yu*yv), 1, 1/(yu*yv), 1/(yu*yv)}, yw]/8 + 
     G[{1, 1/(yu*yv), yu^(-1), yu^(-1), yu^(-1)}, yw]/8 - 
     G[{1, 1/(yu*yv), yu^(-1), yu^(-1), 1/(yu*yv)}, yw]/8 - 
     (3*G[{1, 1/(yu*yv), yu^(-1), 1/(yu*yv), yu^(-1)}, yw])/16 + 
     G[{1, 1/(yu*yv), yu^(-1), 1/(yu*yv), yv^(-1)}, yw]/8 - 
     G[{1, 1/(yu*yv), yv^(-1), yv^(-1), 1/(yu*yv)}, yw]/8 + 
     G[{1, 1/(yu*yv), yv^(-1), 1/(yu*yv), yu^(-1)}, yw]/4 + 
     G[{1, 1/(yu*yv), yv^(-1), 1/(yu*yv), yv^(-1)}, yw]/8 - 
     G[{1, 1/(yu*yv), 1/(yu*yv), yu^(-1), yu^(-1)}, yw]/16 + 
     G[{1, 1/(yu*yv), 1/(yu*yv), yu^(-1), yv^(-1)}, yw]/4 + 
     G[{1, 1/(yu*yv), 1/(yu*yv), yv^(-1), yu^(-1)}, yw]/4 + 
     G[{1, 1/(yu*yv), 1/(yu*yv), yv^(-1), yv^(-1)}, yw]/4 + 
     (3*G[{1, 1/(yu*yv), 1/(yu*yv), 1/(yu*yv), yu^(-1)}, yw])/16 + 
     (3*G[{1, 1/(yu*yv), 1/(yu*yv), 1/(yu*yv), yv^(-1)}, yw])/16 + 
     (11*G[{yu^(-1), yu^(-1), yu^(-1), yu^(-1), 1/(yu*yv)}, yw])/32 - 
     (7*G[{yu^(-1), yu^(-1), yu^(-1), 1/(yu*yv), yv^(-1)}, yw])/32 + 
     (123*G[{yu^(-1), yu^(-1), yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/64 + 
     (5*G[{yu^(-1), yu^(-1), 1/(yu*yv), yu^(-1), 1/(yu*yv)}, yw])/8 + 
     (7*G[{yu^(-1), yu^(-1), 1/(yu*yv), yv^(-1), yv^(-1)}, yw])/32 - 
     (11*G[{yu^(-1), yu^(-1), 1/(yu*yv), yv^(-1), 1/(yu*yv)}, yw])/64 - 
     (15*G[{yu^(-1), yu^(-1), 1/(yu*yv), 1/(yu*yv), yv^(-1)}, yw])/64 - 
     (7*G[{yu^(-1), yu^(-1), 1/(yu*yv), 1/(yu*yv), 1/(yu*yv)}, yw])/16 + 
     G[{yu^(-1), 1/(yu*yv), yu^(-1), 1/(yu*yv), yv^(-1)}, yw]/16 - 
     (17*G[{yu^(-1), 1/(yu*yv), yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/64 + 
     (9*G[{yu^(-1), 1/(yu*yv), yv^(-1), yv^(-1), yv^(-1)}, yw])/32 + 
     (11*G[{yu^(-1), 1/(yu*yv), yv^(-1), yv^(-1), 1/(yu*yv)}, yw])/64 - 
     G[{yu^(-1), 1/(yu*yv), yv^(-1), 1/(yu*yv), yv^(-1)}, yw]/64 - 
     (3*G[{yu^(-1), 1/(yu*yv), yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/32 + 
     (7*G[{yu^(-1), 1/(yu*yv), 1/(yu*yv), yv^(-1), yv^(-1)}, yw])/64 - 
     (3*G[{yu^(-1), 1/(yu*yv), 1/(yu*yv), yv^(-1), 1/(yu*yv)}, yw])/32 - 
     (3*G[{yu^(-1), 1/(yu*yv), 1/(yu*yv), 1/(yu*yv), yv^(-1)}, yw])/64 - 
     (41*G[{yv^(-1), yv^(-1), yv^(-1), yv^(-1), 1/(yu*yv)}, yw])/32 - 
     (129*G[{yv^(-1), yv^(-1), yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/64 - 
     (11*G[{yv^(-1), yv^(-1), 1/(yu*yv), yv^(-1), 1/(yu*yv)}, yw])/16 - 
     (7*G[{yv^(-1), yv^(-1), 1/(yu*yv), 1/(yu*yv), 1/(yu*yv)}, yw])/16 - 
     (17*G[{yv^(-1), 1/(yu*yv), yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/64 + 
     (11*Pi^2*Zeta[3])/256 + (3*G[{0}, yu^(-1)]^2*Zeta[3])/16 + 
     (3*G[{0}, yu^(-1)]*G[{0}, yv^(-1)]*Zeta[3])/8 + 
     (3*G[{0}, yv^(-1)]^2*Zeta[3])/16 - (3*G[{0}, yu^(-1)]*G[{0}, yw]*
       Zeta[3])/8 - (3*G[{0}, yv^(-1)]*G[{0}, yw]*Zeta[3])/8 + 
     (3*G[{0}, yw]^2*Zeta[3])/16 - (G[{0}, yu^(-1)]*G[{1}, yu^(-1)]*Zeta[3])/
      4 - (G[{0}, yv^(-1)]*G[{1}, yu^(-1)]*Zeta[3])/4 + 
     (G[{0}, yw]*G[{1}, yu^(-1)]*Zeta[3])/4 - 
     (3*G[{0}, yu^(-1)]*G[{1}, yv^(-1)]*Zeta[3])/8 - 
     (3*G[{0}, yv^(-1)]*G[{1}, yv^(-1)]*Zeta[3])/8 + 
     (3*G[{0}, yw]*G[{1}, yv^(-1)]*Zeta[3])/8 + 
     (G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*Zeta[3])/4 + 
     (11*G[{1}, yv^(-1)]^2*Zeta[3])/64 + (G[{0}, yu^(-1)]*G[{1}, yw]*Zeta[3])/
      4 + (G[{0}, yv^(-1)]*G[{1}, yw]*Zeta[3])/4 - 
     (G[{0}, yw]*G[{1}, yw]*Zeta[3])/4 - (9*G[{1}, yv^(-1)]*G[{1}, yw]*
       Zeta[3])/32 - (5*G[{1}, yw]^2*Zeta[3])/32 + 
     (G[{1}, yw]*G[{yu}, yv^(-1)]*Zeta[3])/32 + 
     (3*G[{0}, yu^(-1)]*G[{1/(yu*yv)}, yw]*Zeta[3])/8 + 
     (3*G[{0}, yv^(-1)]*G[{1/(yu*yv)}, yw]*Zeta[3])/8 - 
     (3*G[{0}, yw]*G[{1/(yu*yv)}, yw]*Zeta[3])/8 - 
     (G[{1}, yu^(-1)]*G[{1/(yu*yv)}, yw]*Zeta[3])/4 - 
     (11*G[{1}, yv^(-1)]*G[{1/(yu*yv)}, yw]*Zeta[3])/32 + 
     (G[{1}, yw]*G[{1/(yu*yv)}, yw]*Zeta[3])/8 + 
     (G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*Zeta[3])/4 - 
     (G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw]*Zeta[3])/32 + 
     (5*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*Zeta[3])/32 + 
     (3*G[{1/(yu*yv)}, yw]^2*Zeta[3])/64 + (G[{0, 1}, yv^(-1)]*Zeta[3])/32 + 
     (9*G[{0, 1}, yw]*Zeta[3])/32 - (13*G[{0, yu^(-1)}, yw]*Zeta[3])/32 - 
     (G[{0, yu}, yv^(-1)]*Zeta[3])/32 - (5*G[{0, yv^(-1)}, yw]*Zeta[3])/32 + 
     (9*G[{0, 1/(yu*yv)}, yw]*Zeta[3])/32 + (5*G[{1, yu^(-1)}, yw]*Zeta[3])/
      16 + (G[{1, yu}, yv^(-1)]*Zeta[3])/32 + (5*G[{1, yv^(-1)}, yw]*Zeta[3])/
      32 - (G[{1, 1/(yu*yv)}, yw]*Zeta[3])/32 - 
     (G[{yu^(-1), 1/(yu*yv)}, yw]*Zeta[3])/4 - 
     (5*G[{yv^(-1), 1/(yu*yv)}, yw]*Zeta[3])/32 - (5*Zeta[5])/64
 
QepvuwRegII = (Pi^4*G[{0}, yu^(-1)])/1152 + (Pi^4*G[{0}, yv^(-1)])/1152 - 
     (Pi^4*G[{0}, yw])/1152 - (Pi^4*G[{1}, yu^(-1)])/384 + 
     (Pi^2*G[{0}, yu^(-1)]*G[{1}, yu^(-1)]^2)/192 + 
     (Pi^2*G[{0}, yv^(-1)]*G[{1}, yu^(-1)]^2)/192 - 
     (Pi^2*G[{0}, yw]*G[{1}, yu^(-1)]^2)/192 - (Pi^2*G[{1}, yu^(-1)]^3)/576 - 
     (Pi^4*G[{1}, yv^(-1)])/1152 - (Pi^2*G[{1}, yu^(-1)]^2*G[{1}, yv^(-1)])/
      192 + (Pi^2*G[{0}, yu^(-1)]*G[{1}, yv^(-1)]^2)/96 + 
     (Pi^2*G[{0}, yv^(-1)]*G[{1}, yv^(-1)]^2)/96 - 
     (Pi^2*G[{0}, yw]*G[{1}, yv^(-1)]^2)/96 + 
     (Pi^2*G[{1}, yu^(-1)]*G[{1}, yv^(-1)]^2)/96 - 
     (G[{0}, yu^(-1)]*G[{1}, yu^(-1)]^2*G[{1}, yv^(-1)]^2)/64 - 
     (G[{0}, yv^(-1)]*G[{1}, yu^(-1)]^2*G[{1}, yv^(-1)]^2)/64 + 
     (G[{0}, yw]*G[{1}, yu^(-1)]^2*G[{1}, yv^(-1)]^2)/64 + 
     (G[{1}, yu^(-1)]^3*G[{1}, yv^(-1)]^2)/64 - (5*Pi^2*G[{1}, yv^(-1)]^3)/
      576 + (3*G[{0}, yu^(-1)]^2*G[{1}, yv^(-1)]^3)/256 + 
     (3*G[{0}, yu^(-1)]*G[{0}, yv^(-1)]*G[{1}, yv^(-1)]^3)/128 + 
     (3*G[{0}, yv^(-1)]^2*G[{1}, yv^(-1)]^3)/256 - 
     (3*G[{0}, yu^(-1)]*G[{0}, yw]*G[{1}, yv^(-1)]^3)/128 - 
     (3*G[{0}, yv^(-1)]*G[{0}, yw]*G[{1}, yv^(-1)]^3)/128 + 
     (3*G[{0}, yw]^2*G[{1}, yv^(-1)]^3)/256 + 
     (7*G[{0}, yu^(-1)]*G[{1}, yu^(-1)]*G[{1}, yv^(-1)]^3)/384 + 
     (7*G[{0}, yv^(-1)]*G[{1}, yu^(-1)]*G[{1}, yv^(-1)]^3)/384 - 
     (7*G[{0}, yw]*G[{1}, yu^(-1)]*G[{1}, yv^(-1)]^3)/384 - 
     (5*G[{1}, yu^(-1)]^2*G[{1}, yv^(-1)]^3)/256 - 
     (3*G[{0}, yu^(-1)]*G[{1}, yv^(-1)]^4)/128 - 
     (3*G[{0}, yv^(-1)]*G[{1}, yv^(-1)]^4)/128 + 
     (3*G[{0}, yw]*G[{1}, yv^(-1)]^4)/128 - 
     (G[{1}, yu^(-1)]*G[{1}, yv^(-1)]^4)/192 + (3*G[{1}, yv^(-1)]^5)/256 + 
     (Pi^4*G[{1}, yw])/384 - (Pi^2*G[{0}, yu^(-1)]*G[{1}, yu^(-1)]*
       G[{1}, yw])/96 - (Pi^2*G[{0}, yv^(-1)]*G[{1}, yu^(-1)]*G[{1}, yw])/
      96 + (Pi^2*G[{0}, yw]*G[{1}, yu^(-1)]*G[{1}, yw])/96 + 
     (Pi^2*G[{1}, yu^(-1)]^2*G[{1}, yw])/192 + 
     (Pi^2*G[{0}, yu^(-1)]*G[{1}, yv^(-1)]*G[{1}, yw])/32 + 
     (Pi^2*G[{0}, yv^(-1)]*G[{1}, yv^(-1)]*G[{1}, yw])/32 - 
     (Pi^2*G[{0}, yw]*G[{1}, yv^(-1)]*G[{1}, yw])/32 + 
     (Pi^2*G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*G[{1}, yw])/48 - 
     (G[{0}, yu^(-1)]*G[{1}, yu^(-1)]^2*G[{1}, yv^(-1)]*G[{1}, yw])/32 - 
     (G[{0}, yv^(-1)]*G[{1}, yu^(-1)]^2*G[{1}, yv^(-1)]*G[{1}, yw])/32 + 
     (G[{0}, yw]*G[{1}, yu^(-1)]^2*G[{1}, yv^(-1)]*G[{1}, yw])/32 + 
     (G[{1}, yu^(-1)]^3*G[{1}, yv^(-1)]*G[{1}, yw])/32 - 
     (Pi^2*G[{1}, yv^(-1)]^2*G[{1}, yw])/192 + 
     (9*G[{0}, yu^(-1)]^2*G[{1}, yv^(-1)]^2*G[{1}, yw])/256 + 
     (9*G[{0}, yu^(-1)]*G[{0}, yv^(-1)]*G[{1}, yv^(-1)]^2*G[{1}, yw])/128 + 
     (9*G[{0}, yv^(-1)]^2*G[{1}, yv^(-1)]^2*G[{1}, yw])/256 - 
     (9*G[{0}, yu^(-1)]*G[{0}, yw]*G[{1}, yv^(-1)]^2*G[{1}, yw])/128 - 
     (9*G[{0}, yv^(-1)]*G[{0}, yw]*G[{1}, yv^(-1)]^2*G[{1}, yw])/128 + 
     (9*G[{0}, yw]^2*G[{1}, yv^(-1)]^2*G[{1}, yw])/256 + 
     (7*G[{0}, yu^(-1)]*G[{1}, yu^(-1)]*G[{1}, yv^(-1)]^2*G[{1}, yw])/128 + 
     (7*G[{0}, yv^(-1)]*G[{1}, yu^(-1)]*G[{1}, yv^(-1)]^2*G[{1}, yw])/128 - 
     (7*G[{0}, yw]*G[{1}, yu^(-1)]*G[{1}, yv^(-1)]^2*G[{1}, yw])/128 - 
     (23*G[{1}, yu^(-1)]^2*G[{1}, yv^(-1)]^2*G[{1}, yw])/256 - 
     (3*G[{0}, yu^(-1)]*G[{1}, yv^(-1)]^3*G[{1}, yw])/64 - 
     (3*G[{0}, yv^(-1)]*G[{1}, yv^(-1)]^3*G[{1}, yw])/64 + 
     (3*G[{0}, yw]*G[{1}, yv^(-1)]^3*G[{1}, yw])/64 + 
     (G[{1}, yu^(-1)]*G[{1}, yv^(-1)]^3*G[{1}, yw])/64 + 
     (3*G[{1}, yv^(-1)]^4*G[{1}, yw])/256 + 
     (Pi^2*G[{0}, yu^(-1)]*G[{1}, yw]^2)/48 + 
     (Pi^2*G[{0}, yv^(-1)]*G[{1}, yw]^2)/48 - (Pi^2*G[{0}, yw]*G[{1}, yw]^2)/
      48 - (Pi^2*G[{1}, yu^(-1)]*G[{1}, yw]^2)/48 + 
     (Pi^2*G[{1}, yv^(-1)]*G[{1}, yw]^2)/192 + 
     (9*G[{0}, yu^(-1)]^2*G[{1}, yv^(-1)]*G[{1}, yw]^2)/256 + 
     (9*G[{0}, yu^(-1)]*G[{0}, yv^(-1)]*G[{1}, yv^(-1)]*G[{1}, yw]^2)/128 + 
     (9*G[{0}, yv^(-1)]^2*G[{1}, yv^(-1)]*G[{1}, yw]^2)/256 - 
     (9*G[{0}, yu^(-1)]*G[{0}, yw]*G[{1}, yv^(-1)]*G[{1}, yw]^2)/128 - 
     (9*G[{0}, yv^(-1)]*G[{0}, yw]*G[{1}, yv^(-1)]*G[{1}, yw]^2)/128 + 
     (9*G[{0}, yw]^2*G[{1}, yv^(-1)]*G[{1}, yw]^2)/256 + 
     (3*G[{0}, yu^(-1)]*G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*G[{1}, yw]^2)/128 + 
     (3*G[{0}, yv^(-1)]*G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*G[{1}, yw]^2)/128 - 
     (3*G[{0}, yw]*G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*G[{1}, yw]^2)/128 - 
     (19*G[{1}, yu^(-1)]^2*G[{1}, yv^(-1)]*G[{1}, yw]^2)/256 - 
     (G[{0}, yu^(-1)]*G[{1}, yv^(-1)]^2*G[{1}, yw]^2)/32 - 
     (G[{0}, yv^(-1)]*G[{1}, yv^(-1)]^2*G[{1}, yw]^2)/32 + 
     (G[{0}, yw]*G[{1}, yv^(-1)]^2*G[{1}, yw]^2)/32 + 
     (5*G[{1}, yu^(-1)]*G[{1}, yv^(-1)]^2*G[{1}, yw]^2)/64 - 
     (G[{1}, yv^(-1)]^3*G[{1}, yw]^2)/256 + (Pi^2*G[{1}, yw]^3)/144 + 
     (3*G[{0}, yu^(-1)]^2*G[{1}, yw]^3)/256 + 
     (3*G[{0}, yu^(-1)]*G[{0}, yv^(-1)]*G[{1}, yw]^3)/128 + 
     (3*G[{0}, yv^(-1)]^2*G[{1}, yw]^3)/256 - 
     (3*G[{0}, yu^(-1)]*G[{0}, yw]*G[{1}, yw]^3)/128 - 
     (3*G[{0}, yv^(-1)]*G[{0}, yw]*G[{1}, yw]^3)/128 + 
     (3*G[{0}, yw]^2*G[{1}, yw]^3)/256 - (3*G[{0}, yu^(-1)]*G[{1}, yu^(-1)]*
       G[{1}, yw]^3)/128 - (3*G[{0}, yv^(-1)]*G[{1}, yu^(-1)]*G[{1}, yw]^3)/
      128 + (3*G[{0}, yw]*G[{1}, yu^(-1)]*G[{1}, yw]^3)/128 + 
     (3*G[{1}, yu^(-1)]^2*G[{1}, yw]^3)/256 - 
     (5*G[{0}, yu^(-1)]*G[{1}, yv^(-1)]*G[{1}, yw]^3)/192 - 
     (5*G[{0}, yv^(-1)]*G[{1}, yv^(-1)]*G[{1}, yw]^3)/192 + 
     (5*G[{0}, yw]*G[{1}, yv^(-1)]*G[{1}, yw]^3)/192 + 
     (5*G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*G[{1}, yw]^3)/64 + 
     (11*G[{1}, yv^(-1)]^2*G[{1}, yw]^3)/768 - (G[{0}, yu^(-1)]*G[{1}, yw]^4)/
      96 - (G[{0}, yv^(-1)]*G[{1}, yw]^4)/96 + (G[{0}, yw]*G[{1}, yw]^4)/96 + 
     (G[{1}, yu^(-1)]*G[{1}, yw]^4)/96 + (G[{1}, yv^(-1)]*G[{1}, yw]^4)/96 - 
     (Pi^2*G[{0}, yu^(-1)]*G[{1}, yw]*G[{yu}, yv^(-1)])/32 - 
     (Pi^2*G[{0}, yv^(-1)]*G[{1}, yw]*G[{yu}, yv^(-1)])/32 + 
     (Pi^2*G[{0}, yw]*G[{1}, yw]*G[{yu}, yv^(-1)])/32 - 
     (Pi^2*G[{1}, yu^(-1)]*G[{1}, yw]*G[{yu}, yv^(-1)])/96 + 
     (G[{0}, yu^(-1)]*G[{1}, yu^(-1)]^2*G[{1}, yw]*G[{yu}, yv^(-1)])/32 + 
     (G[{0}, yv^(-1)]*G[{1}, yu^(-1)]^2*G[{1}, yw]*G[{yu}, yv^(-1)])/32 - 
     (G[{0}, yw]*G[{1}, yu^(-1)]^2*G[{1}, yw]*G[{yu}, yv^(-1)])/32 - 
     (G[{1}, yu^(-1)]^3*G[{1}, yw]*G[{yu}, yv^(-1)])/32 - 
     (13*Pi^2*G[{1}, yv^(-1)]*G[{1}, yw]*G[{yu}, yv^(-1)])/768 - 
     (3*G[{0}, yu^(-1)]^2*G[{1}, yv^(-1)]*G[{1}, yw]*G[{yu}, yv^(-1)])/64 - 
     (3*G[{0}, yu^(-1)]*G[{0}, yv^(-1)]*G[{1}, yv^(-1)]*G[{1}, yw]*
       G[{yu}, yv^(-1)])/32 - (3*G[{0}, yv^(-1)]^2*G[{1}, yv^(-1)]*G[{1}, yw]*
       G[{yu}, yv^(-1)])/64 + (3*G[{0}, yu^(-1)]*G[{0}, yw]*G[{1}, yv^(-1)]*
       G[{1}, yw]*G[{yu}, yv^(-1)])/32 + (3*G[{0}, yv^(-1)]*G[{0}, yw]*
       G[{1}, yv^(-1)]*G[{1}, yw]*G[{yu}, yv^(-1)])/32 - 
     (3*G[{0}, yw]^2*G[{1}, yv^(-1)]*G[{1}, yw]*G[{yu}, yv^(-1)])/64 - 
     (3*G[{0}, yu^(-1)]*G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*G[{1}, yw]*
       G[{yu}, yv^(-1)])/32 - (3*G[{0}, yv^(-1)]*G[{1}, yu^(-1)]*
       G[{1}, yv^(-1)]*G[{1}, yw]*G[{yu}, yv^(-1)])/32 + 
     (3*G[{0}, yw]*G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*G[{1}, yw]*
       G[{yu}, yv^(-1)])/32 + (11*G[{1}, yu^(-1)]^2*G[{1}, yv^(-1)]*
       G[{1}, yw]*G[{yu}, yv^(-1)])/64 - (G[{1}, yu^(-1)]*G[{1}, yv^(-1)]^2*
       G[{1}, yw]*G[{yu}, yv^(-1)])/16 + (3*G[{1}, yv^(-1)]^3*G[{1}, yw]*
       G[{yu}, yv^(-1)])/64 - (5*Pi^2*G[{1}, yw]^2*G[{yu}, yv^(-1)])/192 - 
     (9*G[{0}, yu^(-1)]^2*G[{1}, yw]^2*G[{yu}, yv^(-1)])/256 - 
     (9*G[{0}, yu^(-1)]*G[{0}, yv^(-1)]*G[{1}, yw]^2*G[{yu}, yv^(-1)])/128 - 
     (9*G[{0}, yv^(-1)]^2*G[{1}, yw]^2*G[{yu}, yv^(-1)])/256 + 
     (9*G[{0}, yu^(-1)]*G[{0}, yw]*G[{1}, yw]^2*G[{yu}, yv^(-1)])/128 + 
     (9*G[{0}, yv^(-1)]*G[{0}, yw]*G[{1}, yw]^2*G[{yu}, yv^(-1)])/128 - 
     (9*G[{0}, yw]^2*G[{1}, yw]^2*G[{yu}, yv^(-1)])/256 - 
     (3*G[{0}, yu^(-1)]*G[{1}, yu^(-1)]*G[{1}, yw]^2*G[{yu}, yv^(-1)])/128 - 
     (3*G[{0}, yv^(-1)]*G[{1}, yu^(-1)]*G[{1}, yw]^2*G[{yu}, yv^(-1)])/128 + 
     (3*G[{0}, yw]*G[{1}, yu^(-1)]*G[{1}, yw]^2*G[{yu}, yv^(-1)])/128 + 
     (19*G[{1}, yu^(-1)]^2*G[{1}, yw]^2*G[{yu}, yv^(-1)])/256 - 
     (7*G[{0}, yu^(-1)]*G[{1}, yv^(-1)]*G[{1}, yw]^2*G[{yu}, yv^(-1)])/128 - 
     (7*G[{0}, yv^(-1)]*G[{1}, yv^(-1)]*G[{1}, yw]^2*G[{yu}, yv^(-1)])/128 + 
     (7*G[{0}, yw]*G[{1}, yv^(-1)]*G[{1}, yw]^2*G[{yu}, yv^(-1)])/128 - 
     (17*G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*G[{1}, yw]^2*G[{yu}, yv^(-1)])/128 + 
     (17*G[{1}, yv^(-1)]^2*G[{1}, yw]^2*G[{yu}, yv^(-1)])/256 + 
     (G[{0}, yu^(-1)]*G[{1}, yw]^3*G[{yu}, yv^(-1)])/384 + 
     (G[{0}, yv^(-1)]*G[{1}, yw]^3*G[{yu}, yv^(-1)])/384 - 
     (G[{0}, yw]*G[{1}, yw]^3*G[{yu}, yv^(-1)])/384 - 
     (7*G[{1}, yu^(-1)]*G[{1}, yw]^3*G[{yu}, yv^(-1)])/128 - 
     (G[{1}, yv^(-1)]*G[{1}, yw]^3*G[{yu}, yv^(-1)])/32 + 
     (23*Pi^2*G[{1}, yw]*G[{yu}, yv^(-1)]^2)/512 + 
     (3*G[{0}, yu^(-1)]^2*G[{1}, yw]*G[{yu}, yv^(-1)]^2)/128 + 
     (3*G[{0}, yu^(-1)]*G[{0}, yv^(-1)]*G[{1}, yw]*G[{yu}, yv^(-1)]^2)/64 + 
     (3*G[{0}, yv^(-1)]^2*G[{1}, yw]*G[{yu}, yv^(-1)]^2)/128 - 
     (3*G[{0}, yu^(-1)]*G[{0}, yw]*G[{1}, yw]*G[{yu}, yv^(-1)]^2)/64 - 
     (3*G[{0}, yv^(-1)]*G[{0}, yw]*G[{1}, yw]*G[{yu}, yv^(-1)]^2)/64 + 
     (3*G[{0}, yw]^2*G[{1}, yw]*G[{yu}, yv^(-1)]^2)/128 + 
     (G[{0}, yu^(-1)]*G[{1}, yu^(-1)]*G[{1}, yw]*G[{yu}, yv^(-1)]^2)/64 + 
     (G[{0}, yv^(-1)]*G[{1}, yu^(-1)]*G[{1}, yw]*G[{yu}, yv^(-1)]^2)/64 - 
     (G[{0}, yw]*G[{1}, yu^(-1)]*G[{1}, yw]*G[{yu}, yv^(-1)]^2)/64 - 
     (9*G[{1}, yu^(-1)]^2*G[{1}, yw]*G[{yu}, yv^(-1)]^2)/128 + 
     (9*G[{0}, yu^(-1)]*G[{1}, yv^(-1)]*G[{1}, yw]*G[{yu}, yv^(-1)]^2)/64 + 
     (9*G[{0}, yv^(-1)]*G[{1}, yv^(-1)]*G[{1}, yw]*G[{yu}, yv^(-1)]^2)/64 - 
     (9*G[{0}, yw]*G[{1}, yv^(-1)]*G[{1}, yw]*G[{yu}, yv^(-1)]^2)/64 + 
     (7*G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*G[{1}, yw]*G[{yu}, yv^(-1)]^2)/64 - 
     (3*G[{1}, yv^(-1)]^2*G[{1}, yw]*G[{yu}, yv^(-1)]^2)/32 + 
     (7*G[{0}, yu^(-1)]*G[{1}, yw]^2*G[{yu}, yv^(-1)]^2)/64 + 
     (7*G[{0}, yv^(-1)]*G[{1}, yw]^2*G[{yu}, yv^(-1)]^2)/64 - 
     (7*G[{0}, yw]*G[{1}, yw]^2*G[{yu}, yv^(-1)]^2)/64 + 
     (G[{1}, yu^(-1)]*G[{1}, yw]^2*G[{yu}, yv^(-1)]^2)/64 + 
     (7*G[{1}, yv^(-1)]*G[{1}, yw]^2*G[{yu}, yv^(-1)]^2)/256 + 
     (31*G[{1}, yw]^3*G[{yu}, yv^(-1)]^2)/768 - 
     (G[{0}, yu^(-1)]*G[{1}, yw]*G[{yu}, yv^(-1)]^3)/12 - 
     (G[{0}, yv^(-1)]*G[{1}, yw]*G[{yu}, yv^(-1)]^3)/12 + 
     (G[{0}, yw]*G[{1}, yw]*G[{yu}, yv^(-1)]^3)/12 - 
     (3*G[{1}, yv^(-1)]*G[{1}, yw]*G[{yu}, yv^(-1)]^3)/64 - 
     (67*G[{1}, yw]^2*G[{yu}, yv^(-1)]^3)/768 + 
     (41*G[{1}, yw]*G[{yu}, yv^(-1)]^4)/768 + (Pi^4*G[{1/(yu*yv)}, yw])/
      1152 + (Pi^2*G[{1}, yu^(-1)]^2*G[{1/(yu*yv)}, yw])/192 - 
     (Pi^2*G[{0}, yu^(-1)]*G[{1}, yv^(-1)]*G[{1/(yu*yv)}, yw])/48 - 
     (Pi^2*G[{0}, yv^(-1)]*G[{1}, yv^(-1)]*G[{1/(yu*yv)}, yw])/48 + 
     (Pi^2*G[{0}, yw]*G[{1}, yv^(-1)]*G[{1/(yu*yv)}, yw])/48 - 
     (Pi^2*G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*G[{1/(yu*yv)}, yw])/48 + 
     (G[{0}, yu^(-1)]*G[{1}, yu^(-1)]^2*G[{1}, yv^(-1)]*G[{1/(yu*yv)}, yw])/
      32 + (G[{0}, yv^(-1)]*G[{1}, yu^(-1)]^2*G[{1}, yv^(-1)]*
       G[{1/(yu*yv)}, yw])/32 - (G[{0}, yw]*G[{1}, yu^(-1)]^2*G[{1}, yv^(-1)]*
       G[{1/(yu*yv)}, yw])/32 - (G[{1}, yu^(-1)]^3*G[{1}, yv^(-1)]*
       G[{1/(yu*yv)}, yw])/32 + (5*Pi^2*G[{1}, yv^(-1)]^2*G[{1/(yu*yv)}, yw])/
      192 - (9*G[{0}, yu^(-1)]^2*G[{1}, yv^(-1)]^2*G[{1/(yu*yv)}, yw])/256 - 
     (9*G[{0}, yu^(-1)]*G[{0}, yv^(-1)]*G[{1}, yv^(-1)]^2*G[{1/(yu*yv)}, yw])/
      128 - (9*G[{0}, yv^(-1)]^2*G[{1}, yv^(-1)]^2*G[{1/(yu*yv)}, yw])/256 + 
     (9*G[{0}, yu^(-1)]*G[{0}, yw]*G[{1}, yv^(-1)]^2*G[{1/(yu*yv)}, yw])/
      128 + (9*G[{0}, yv^(-1)]*G[{0}, yw]*G[{1}, yv^(-1)]^2*
       G[{1/(yu*yv)}, yw])/128 - (9*G[{0}, yw]^2*G[{1}, yv^(-1)]^2*
       G[{1/(yu*yv)}, yw])/256 - (7*G[{0}, yu^(-1)]*G[{1}, yu^(-1)]*
       G[{1}, yv^(-1)]^2*G[{1/(yu*yv)}, yw])/128 - 
     (7*G[{0}, yv^(-1)]*G[{1}, yu^(-1)]*G[{1}, yv^(-1)]^2*G[{1/(yu*yv)}, yw])/
      128 + (7*G[{0}, yw]*G[{1}, yu^(-1)]*G[{1}, yv^(-1)]^2*
       G[{1/(yu*yv)}, yw])/128 + (15*G[{1}, yu^(-1)]^2*G[{1}, yv^(-1)]^2*
       G[{1/(yu*yv)}, yw])/256 + (3*G[{0}, yu^(-1)]*G[{1}, yv^(-1)]^3*
       G[{1/(yu*yv)}, yw])/32 + (3*G[{0}, yv^(-1)]*G[{1}, yv^(-1)]^3*
       G[{1/(yu*yv)}, yw])/32 - (3*G[{0}, yw]*G[{1}, yv^(-1)]^3*
       G[{1/(yu*yv)}, yw])/32 + (G[{1}, yu^(-1)]*G[{1}, yv^(-1)]^3*
       G[{1/(yu*yv)}, yw])/48 - (15*G[{1}, yv^(-1)]^4*G[{1/(yu*yv)}, yw])/
      256 - (Pi^2*G[{0}, yu^(-1)]*G[{1}, yw]*G[{1/(yu*yv)}, yw])/48 - 
     (Pi^2*G[{0}, yv^(-1)]*G[{1}, yw]*G[{1/(yu*yv)}, yw])/48 + 
     (Pi^2*G[{0}, yw]*G[{1}, yw]*G[{1/(yu*yv)}, yw])/48 - 
     (Pi^2*G[{1}, yv^(-1)]*G[{1}, yw]*G[{1/(yu*yv)}, yw])/32 - 
     (9*G[{0}, yu^(-1)]^2*G[{1}, yv^(-1)]*G[{1}, yw]*G[{1/(yu*yv)}, yw])/
      128 - (9*G[{0}, yu^(-1)]*G[{0}, yv^(-1)]*G[{1}, yv^(-1)]*G[{1}, yw]*
       G[{1/(yu*yv)}, yw])/64 - (9*G[{0}, yv^(-1)]^2*G[{1}, yv^(-1)]*
       G[{1}, yw]*G[{1/(yu*yv)}, yw])/128 + 
     (9*G[{0}, yu^(-1)]*G[{0}, yw]*G[{1}, yv^(-1)]*G[{1}, yw]*
       G[{1/(yu*yv)}, yw])/64 + (9*G[{0}, yv^(-1)]*G[{0}, yw]*G[{1}, yv^(-1)]*
       G[{1}, yw]*G[{1/(yu*yv)}, yw])/64 - 
     (9*G[{0}, yw]^2*G[{1}, yv^(-1)]*G[{1}, yw]*G[{1/(yu*yv)}, yw])/128 - 
     (3*G[{0}, yu^(-1)]*G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*G[{1}, yw]*
       G[{1/(yu*yv)}, yw])/64 - (3*G[{0}, yv^(-1)]*G[{1}, yu^(-1)]*
       G[{1}, yv^(-1)]*G[{1}, yw]*G[{1/(yu*yv)}, yw])/64 + 
     (3*G[{0}, yw]*G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*G[{1}, yw]*
       G[{1/(yu*yv)}, yw])/64 + (19*G[{1}, yu^(-1)]^2*G[{1}, yv^(-1)]*
       G[{1}, yw]*G[{1/(yu*yv)}, yw])/128 + 
     (5*G[{0}, yu^(-1)]*G[{1}, yv^(-1)]^2*G[{1}, yw]*G[{1/(yu*yv)}, yw])/64 + 
     (5*G[{0}, yv^(-1)]*G[{1}, yv^(-1)]^2*G[{1}, yw]*G[{1/(yu*yv)}, yw])/64 - 
     (5*G[{0}, yw]*G[{1}, yv^(-1)]^2*G[{1}, yw]*G[{1/(yu*yv)}, yw])/64 - 
     (3*G[{1}, yu^(-1)]*G[{1}, yv^(-1)]^2*G[{1}, yw]*G[{1/(yu*yv)}, yw])/64 - 
     (G[{1}, yv^(-1)]^3*G[{1}, yw]*G[{1/(yu*yv)}, yw])/128 - 
     (Pi^2*G[{1}, yw]^2*G[{1/(yu*yv)}, yw])/32 - 
     (9*G[{0}, yu^(-1)]^2*G[{1}, yw]^2*G[{1/(yu*yv)}, yw])/256 - 
     (9*G[{0}, yu^(-1)]*G[{0}, yv^(-1)]*G[{1}, yw]^2*G[{1/(yu*yv)}, yw])/
      128 - (9*G[{0}, yv^(-1)]^2*G[{1}, yw]^2*G[{1/(yu*yv)}, yw])/256 + 
     (9*G[{0}, yu^(-1)]*G[{0}, yw]*G[{1}, yw]^2*G[{1/(yu*yv)}, yw])/128 + 
     (9*G[{0}, yv^(-1)]*G[{0}, yw]*G[{1}, yw]^2*G[{1/(yu*yv)}, yw])/128 - 
     (9*G[{0}, yw]^2*G[{1}, yw]^2*G[{1/(yu*yv)}, yw])/256 + 
     (9*G[{0}, yu^(-1)]*G[{1}, yu^(-1)]*G[{1}, yw]^2*G[{1/(yu*yv)}, yw])/
      128 + (9*G[{0}, yv^(-1)]*G[{1}, yu^(-1)]*G[{1}, yw]^2*
       G[{1/(yu*yv)}, yw])/128 - (9*G[{0}, yw]*G[{1}, yu^(-1)]*G[{1}, yw]^2*
       G[{1/(yu*yv)}, yw])/128 - (9*G[{1}, yu^(-1)]^2*G[{1}, yw]^2*
       G[{1/(yu*yv)}, yw])/256 - (3*G[{0}, yu^(-1)]*G[{1}, yv^(-1)]*
       G[{1}, yw]^2*G[{1/(yu*yv)}, yw])/32 - 
     (3*G[{0}, yv^(-1)]*G[{1}, yv^(-1)]*G[{1}, yw]^2*G[{1/(yu*yv)}, yw])/32 + 
     (3*G[{0}, yw]*G[{1}, yv^(-1)]*G[{1}, yw]^2*G[{1/(yu*yv)}, yw])/32 - 
     (G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*G[{1}, yw]^2*G[{1/(yu*yv)}, yw])/16 + 
     (33*G[{1}, yv^(-1)]^2*G[{1}, yw]^2*G[{1/(yu*yv)}, yw])/256 - 
     (7*G[{0}, yu^(-1)]*G[{1}, yw]^3*G[{1/(yu*yv)}, yw])/192 - 
     (7*G[{0}, yv^(-1)]*G[{1}, yw]^3*G[{1/(yu*yv)}, yw])/192 + 
     (7*G[{0}, yw]*G[{1}, yw]^3*G[{1/(yu*yv)}, yw])/192 + 
     (7*G[{1}, yu^(-1)]*G[{1}, yw]^3*G[{1/(yu*yv)}, yw])/192 + 
     (7*G[{1}, yv^(-1)]*G[{1}, yw]^3*G[{1/(yu*yv)}, yw])/192 + 
     (Pi^2*G[{0}, yu^(-1)]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw])/96 + 
     (Pi^2*G[{0}, yv^(-1)]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw])/96 - 
     (Pi^2*G[{0}, yw]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw])/96 + 
     (Pi^2*G[{1}, yu^(-1)]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw])/96 - 
     (19*Pi^2*G[{1}, yv^(-1)]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw])/768 + 
     (3*G[{0}, yu^(-1)]^2*G[{1}, yv^(-1)]*G[{yu^(-1)}, yw]*
       G[{1/(yu*yv)}, yw])/64 + (3*G[{0}, yu^(-1)]*G[{0}, yv^(-1)]*
       G[{1}, yv^(-1)]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw])/32 + 
     (3*G[{0}, yv^(-1)]^2*G[{1}, yv^(-1)]*G[{yu^(-1)}, yw]*
       G[{1/(yu*yv)}, yw])/64 - (3*G[{0}, yu^(-1)]*G[{0}, yw]*G[{1}, yv^(-1)]*
       G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw])/32 - 
     (3*G[{0}, yv^(-1)]*G[{0}, yw]*G[{1}, yv^(-1)]*G[{yu^(-1)}, yw]*
       G[{1/(yu*yv)}, yw])/32 + (3*G[{0}, yw]^2*G[{1}, yv^(-1)]*
       G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw])/64 + 
     (G[{0}, yu^(-1)]*G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*G[{yu^(-1)}, yw]*
       G[{1/(yu*yv)}, yw])/32 + (G[{0}, yv^(-1)]*G[{1}, yu^(-1)]*
       G[{1}, yv^(-1)]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw])/32 - 
     (G[{0}, yw]*G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*G[{yu^(-1)}, yw]*
       G[{1/(yu*yv)}, yw])/32 - (5*G[{1}, yu^(-1)]^2*G[{1}, yv^(-1)]*
       G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw])/64 - 
     (G[{0}, yu^(-1)]*G[{1}, yv^(-1)]^2*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw])/
      8 - (G[{0}, yv^(-1)]*G[{1}, yv^(-1)]^2*G[{yu^(-1)}, yw]*
       G[{1/(yu*yv)}, yw])/8 + (G[{0}, yw]*G[{1}, yv^(-1)]^2*G[{yu^(-1)}, yw]*
       G[{1/(yu*yv)}, yw])/8 + (13*G[{1}, yv^(-1)]^3*G[{yu^(-1)}, yw]*
       G[{1/(yu*yv)}, yw])/128 + (7*Pi^2*G[{1}, yw]*G[{yu^(-1)}, yw]*
       G[{1/(yu*yv)}, yw])/256 + (3*G[{0}, yu^(-1)]^2*G[{1}, yw]*
       G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw])/64 + 
     (3*G[{0}, yu^(-1)]*G[{0}, yv^(-1)]*G[{1}, yw]*G[{yu^(-1)}, yw]*
       G[{1/(yu*yv)}, yw])/32 + (3*G[{0}, yv^(-1)]^2*G[{1}, yw]*
       G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw])/64 - 
     (3*G[{0}, yu^(-1)]*G[{0}, yw]*G[{1}, yw]*G[{yu^(-1)}, yw]*
       G[{1/(yu*yv)}, yw])/32 - (3*G[{0}, yv^(-1)]*G[{0}, yw]*G[{1}, yw]*
       G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw])/32 + 
     (3*G[{0}, yw]^2*G[{1}, yw]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw])/64 - 
     (3*G[{0}, yu^(-1)]*G[{1}, yu^(-1)]*G[{1}, yw]*G[{yu^(-1)}, yw]*
       G[{1/(yu*yv)}, yw])/32 - (3*G[{0}, yv^(-1)]*G[{1}, yu^(-1)]*G[{1}, yw]*
       G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw])/32 + 
     (3*G[{0}, yw]*G[{1}, yu^(-1)]*G[{1}, yw]*G[{yu^(-1)}, yw]*
       G[{1/(yu*yv)}, yw])/32 + (3*G[{1}, yu^(-1)]^2*G[{1}, yw]*
       G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw])/64 + 
     (G[{0}, yu^(-1)]*G[{1}, yv^(-1)]*G[{1}, yw]*G[{yu^(-1)}, yw]*
       G[{1/(yu*yv)}, yw])/16 + (G[{0}, yv^(-1)]*G[{1}, yv^(-1)]*G[{1}, yw]*
       G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw])/16 - 
     (G[{0}, yw]*G[{1}, yv^(-1)]*G[{1}, yw]*G[{yu^(-1)}, yw]*
       G[{1/(yu*yv)}, yw])/16 + (G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*G[{1}, yw]*
       G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw])/16 - 
     (5*G[{1}, yv^(-1)]^2*G[{1}, yw]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw])/
      128 + (G[{0}, yu^(-1)]*G[{1}, yw]^2*G[{yu^(-1)}, yw]*
       G[{1/(yu*yv)}, yw])/8 + (G[{0}, yv^(-1)]*G[{1}, yw]^2*G[{yu^(-1)}, yw]*
       G[{1/(yu*yv)}, yw])/8 - (G[{0}, yw]*G[{1}, yw]^2*G[{yu^(-1)}, yw]*
       G[{1/(yu*yv)}, yw])/8 - (G[{1}, yu^(-1)]*G[{1}, yw]^2*G[{yu^(-1)}, yw]*
       G[{1/(yu*yv)}, yw])/8 - (7*G[{1}, yv^(-1)]*G[{1}, yw]^2*
       G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw])/128 + 
     (3*G[{1}, yw]^3*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw])/128 + 
     (Pi^2*G[{yu^(-1)}, yw]^2*G[{1/(yu*yv)}, yw])/512 - 
     (3*G[{0}, yu^(-1)]^2*G[{yu^(-1)}, yw]^2*G[{1/(yu*yv)}, yw])/128 - 
     (3*G[{0}, yu^(-1)]*G[{0}, yv^(-1)]*G[{yu^(-1)}, yw]^2*
       G[{1/(yu*yv)}, yw])/64 - (3*G[{0}, yv^(-1)]^2*G[{yu^(-1)}, yw]^2*
       G[{1/(yu*yv)}, yw])/128 + (3*G[{0}, yu^(-1)]*G[{0}, yw]*
       G[{yu^(-1)}, yw]^2*G[{1/(yu*yv)}, yw])/64 + 
     (3*G[{0}, yv^(-1)]*G[{0}, yw]*G[{yu^(-1)}, yw]^2*G[{1/(yu*yv)}, yw])/
      64 - (3*G[{0}, yw]^2*G[{yu^(-1)}, yw]^2*G[{1/(yu*yv)}, yw])/128 + 
     (3*G[{0}, yu^(-1)]*G[{1}, yu^(-1)]*G[{yu^(-1)}, yw]^2*
       G[{1/(yu*yv)}, yw])/64 + (3*G[{0}, yv^(-1)]*G[{1}, yu^(-1)]*
       G[{yu^(-1)}, yw]^2*G[{1/(yu*yv)}, yw])/64 - 
     (3*G[{0}, yw]*G[{1}, yu^(-1)]*G[{yu^(-1)}, yw]^2*G[{1/(yu*yv)}, yw])/
      64 - (3*G[{1}, yu^(-1)]^2*G[{yu^(-1)}, yw]^2*G[{1/(yu*yv)}, yw])/128 + 
     (3*G[{0}, yu^(-1)]*G[{1}, yv^(-1)]*G[{yu^(-1)}, yw]^2*
       G[{1/(yu*yv)}, yw])/64 + (3*G[{0}, yv^(-1)]*G[{1}, yv^(-1)]*
       G[{yu^(-1)}, yw]^2*G[{1/(yu*yv)}, yw])/64 - 
     (3*G[{0}, yw]*G[{1}, yv^(-1)]*G[{yu^(-1)}, yw]^2*G[{1/(yu*yv)}, yw])/
      64 - (3*G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*G[{yu^(-1)}, yw]^2*
       G[{1/(yu*yv)}, yw])/64 - (G[{1}, yv^(-1)]^2*G[{yu^(-1)}, yw]^2*
       G[{1/(yu*yv)}, yw])/64 - (7*G[{0}, yu^(-1)]*G[{1}, yw]*
       G[{yu^(-1)}, yw]^2*G[{1/(yu*yv)}, yw])/64 - 
     (7*G[{0}, yv^(-1)]*G[{1}, yw]*G[{yu^(-1)}, yw]^2*G[{1/(yu*yv)}, yw])/
      64 + (7*G[{0}, yw]*G[{1}, yw]*G[{yu^(-1)}, yw]^2*G[{1/(yu*yv)}, yw])/
      64 + (7*G[{1}, yu^(-1)]*G[{1}, yw]*G[{yu^(-1)}, yw]^2*
       G[{1/(yu*yv)}, yw])/64 + (G[{1}, yv^(-1)]*G[{1}, yw]*
       G[{yu^(-1)}, yw]^2*G[{1/(yu*yv)}, yw])/8 + 
     (G[{1}, yw]^2*G[{yu^(-1)}, yw]^2*G[{1/(yu*yv)}, yw])/128 + 
     (G[{0}, yu^(-1)]*G[{yu^(-1)}, yw]^3*G[{1/(yu*yv)}, yw])/48 + 
     (G[{0}, yv^(-1)]*G[{yu^(-1)}, yw]^3*G[{1/(yu*yv)}, yw])/48 - 
     (G[{0}, yw]*G[{yu^(-1)}, yw]^3*G[{1/(yu*yv)}, yw])/48 - 
     (G[{1}, yu^(-1)]*G[{yu^(-1)}, yw]^3*G[{1/(yu*yv)}, yw])/48 - 
     (11*G[{1}, yv^(-1)]*G[{yu^(-1)}, yw]^3*G[{1/(yu*yv)}, yw])/192 - 
     (7*G[{1}, yw]*G[{yu^(-1)}, yw]^3*G[{1/(yu*yv)}, yw])/192 + 
     (11*G[{yu^(-1)}, yw]^4*G[{1/(yu*yv)}, yw])/768 + 
     (Pi^2*G[{0}, yu^(-1)]*G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw])/32 + 
     (Pi^2*G[{0}, yv^(-1)]*G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw])/32 - 
     (Pi^2*G[{0}, yw]*G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw])/32 + 
     (Pi^2*G[{1}, yu^(-1)]*G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw])/96 - 
     (G[{0}, yu^(-1)]*G[{1}, yu^(-1)]^2*G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw])/
      32 - (G[{0}, yv^(-1)]*G[{1}, yu^(-1)]^2*G[{yu}, yv^(-1)]*
       G[{1/(yu*yv)}, yw])/32 + (G[{0}, yw]*G[{1}, yu^(-1)]^2*
       G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw])/32 + 
     (G[{1}, yu^(-1)]^3*G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw])/32 + 
     (13*Pi^2*G[{1}, yv^(-1)]*G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw])/768 + 
     (3*G[{0}, yu^(-1)]^2*G[{1}, yv^(-1)]*G[{yu}, yv^(-1)]*
       G[{1/(yu*yv)}, yw])/64 + (3*G[{0}, yu^(-1)]*G[{0}, yv^(-1)]*
       G[{1}, yv^(-1)]*G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw])/32 + 
     (3*G[{0}, yv^(-1)]^2*G[{1}, yv^(-1)]*G[{yu}, yv^(-1)]*
       G[{1/(yu*yv)}, yw])/64 - (3*G[{0}, yu^(-1)]*G[{0}, yw]*G[{1}, yv^(-1)]*
       G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw])/32 - 
     (3*G[{0}, yv^(-1)]*G[{0}, yw]*G[{1}, yv^(-1)]*G[{yu}, yv^(-1)]*
       G[{1/(yu*yv)}, yw])/32 + (3*G[{0}, yw]^2*G[{1}, yv^(-1)]*
       G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw])/64 + 
     (3*G[{0}, yu^(-1)]*G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*G[{yu}, yv^(-1)]*
       G[{1/(yu*yv)}, yw])/32 + (3*G[{0}, yv^(-1)]*G[{1}, yu^(-1)]*
       G[{1}, yv^(-1)]*G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw])/32 - 
     (3*G[{0}, yw]*G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*G[{yu}, yv^(-1)]*
       G[{1/(yu*yv)}, yw])/32 - (11*G[{1}, yu^(-1)]^2*G[{1}, yv^(-1)]*
       G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw])/64 + 
     (G[{1}, yu^(-1)]*G[{1}, yv^(-1)]^2*G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw])/
      16 - (3*G[{1}, yv^(-1)]^3*G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw])/64 + 
     (7*Pi^2*G[{1}, yw]*G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw])/96 + 
     (9*G[{0}, yu^(-1)]^2*G[{1}, yw]*G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw])/
      128 + (9*G[{0}, yu^(-1)]*G[{0}, yv^(-1)]*G[{1}, yw]*G[{yu}, yv^(-1)]*
       G[{1/(yu*yv)}, yw])/64 + (9*G[{0}, yv^(-1)]^2*G[{1}, yw]*
       G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw])/128 - 
     (9*G[{0}, yu^(-1)]*G[{0}, yw]*G[{1}, yw]*G[{yu}, yv^(-1)]*
       G[{1/(yu*yv)}, yw])/64 - (9*G[{0}, yv^(-1)]*G[{0}, yw]*G[{1}, yw]*
       G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw])/64 + 
     (9*G[{0}, yw]^2*G[{1}, yw]*G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw])/128 + 
     (3*G[{0}, yu^(-1)]*G[{1}, yu^(-1)]*G[{1}, yw]*G[{yu}, yv^(-1)]*
       G[{1/(yu*yv)}, yw])/64 + (3*G[{0}, yv^(-1)]*G[{1}, yu^(-1)]*G[{1}, yw]*
       G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw])/64 - 
     (3*G[{0}, yw]*G[{1}, yu^(-1)]*G[{1}, yw]*G[{yu}, yv^(-1)]*
       G[{1/(yu*yv)}, yw])/64 - (19*G[{1}, yu^(-1)]^2*G[{1}, yw]*
       G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw])/128 + 
     (11*G[{0}, yu^(-1)]*G[{1}, yv^(-1)]*G[{1}, yw]*G[{yu}, yv^(-1)]*
       G[{1/(yu*yv)}, yw])/64 + (11*G[{0}, yv^(-1)]*G[{1}, yv^(-1)]*
       G[{1}, yw]*G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw])/64 - 
     (11*G[{0}, yw]*G[{1}, yv^(-1)]*G[{1}, yw]*G[{yu}, yv^(-1)]*
       G[{1/(yu*yv)}, yw])/64 + (13*G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*
       G[{1}, yw]*G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw])/64 - 
     (25*G[{1}, yv^(-1)]^2*G[{1}, yw]*G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw])/
      128 + (21*G[{0}, yu^(-1)]*G[{1}, yw]^2*G[{yu}, yv^(-1)]*
       G[{1/(yu*yv)}, yw])/128 + (21*G[{0}, yv^(-1)]*G[{1}, yw]^2*
       G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw])/128 - 
     (21*G[{0}, yw]*G[{1}, yw]^2*G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw])/128 - 
     (G[{1}, yu^(-1)]*G[{1}, yw]^2*G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw])/128 - 
     (5*G[{1}, yv^(-1)]*G[{1}, yw]^2*G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw])/
      64 - (5*Pi^2*G[{yu^(-1)}, yw]*G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw])/
      768 - (3*G[{0}, yu^(-1)]^2*G[{yu^(-1)}, yw]*G[{yu}, yv^(-1)]*
       G[{1/(yu*yv)}, yw])/64 - (3*G[{0}, yu^(-1)]*G[{0}, yv^(-1)]*
       G[{yu^(-1)}, yw]*G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw])/32 - 
     (3*G[{0}, yv^(-1)]^2*G[{yu^(-1)}, yw]*G[{yu}, yv^(-1)]*
       G[{1/(yu*yv)}, yw])/64 + (3*G[{0}, yu^(-1)]*G[{0}, yw]*
       G[{yu^(-1)}, yw]*G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw])/32 + 
     (3*G[{0}, yv^(-1)]*G[{0}, yw]*G[{yu^(-1)}, yw]*G[{yu}, yv^(-1)]*
       G[{1/(yu*yv)}, yw])/32 - (3*G[{0}, yw]^2*G[{yu^(-1)}, yw]*
       G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw])/64 - 
     (G[{0}, yu^(-1)]*G[{1}, yu^(-1)]*G[{yu^(-1)}, yw]*G[{yu}, yv^(-1)]*
       G[{1/(yu*yv)}, yw])/32 - (G[{0}, yv^(-1)]*G[{1}, yu^(-1)]*
       G[{yu^(-1)}, yw]*G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw])/32 + 
     (G[{0}, yw]*G[{1}, yu^(-1)]*G[{yu^(-1)}, yw]*G[{yu}, yv^(-1)]*
       G[{1/(yu*yv)}, yw])/32 + (5*G[{1}, yu^(-1)]^2*G[{yu^(-1)}, yw]*
       G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw])/64 - 
     (G[{0}, yu^(-1)]*G[{1}, yv^(-1)]*G[{yu^(-1)}, yw]*G[{yu}, yv^(-1)]*
       G[{1/(yu*yv)}, yw])/32 - (G[{0}, yv^(-1)]*G[{1}, yv^(-1)]*
       G[{yu^(-1)}, yw]*G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw])/32 + 
     (G[{0}, yw]*G[{1}, yv^(-1)]*G[{yu^(-1)}, yw]*G[{yu}, yv^(-1)]*
       G[{1/(yu*yv)}, yw])/32 - (3*G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*
       G[{yu^(-1)}, yw]*G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw])/32 + 
     (G[{1}, yv^(-1)]^2*G[{yu^(-1)}, yw]*G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw])/
      8 - (5*G[{0}, yu^(-1)]*G[{1}, yw]*G[{yu^(-1)}, yw]*G[{yu}, yv^(-1)]*
       G[{1/(yu*yv)}, yw])/32 - (5*G[{0}, yv^(-1)]*G[{1}, yw]*
       G[{yu^(-1)}, yw]*G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw])/32 + 
     (5*G[{0}, yw]*G[{1}, yw]*G[{yu^(-1)}, yw]*G[{yu}, yv^(-1)]*
       G[{1/(yu*yv)}, yw])/32 + (G[{1}, yu^(-1)]*G[{1}, yw]*G[{yu^(-1)}, yw]*
       G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw])/32 + 
     (3*G[{1}, yv^(-1)]*G[{1}, yw]*G[{yu^(-1)}, yw]*G[{yu}, yv^(-1)]*
       G[{1/(yu*yv)}, yw])/32 - (9*G[{1}, yw]^2*G[{yu^(-1)}, yw]*
       G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw])/128 - 
     (7*G[{1}, yv^(-1)]*G[{yu^(-1)}, yw]^2*G[{yu}, yv^(-1)]*
       G[{1/(yu*yv)}, yw])/64 - (G[{1}, yw]*G[{yu^(-1)}, yw]^2*
       G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw])/64 + 
     (7*G[{yu^(-1)}, yw]^3*G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw])/192 - 
     (23*Pi^2*G[{yu}, yv^(-1)]^2*G[{1/(yu*yv)}, yw])/512 - 
     (3*G[{0}, yu^(-1)]^2*G[{yu}, yv^(-1)]^2*G[{1/(yu*yv)}, yw])/128 - 
     (3*G[{0}, yu^(-1)]*G[{0}, yv^(-1)]*G[{yu}, yv^(-1)]^2*
       G[{1/(yu*yv)}, yw])/64 - (3*G[{0}, yv^(-1)]^2*G[{yu}, yv^(-1)]^2*
       G[{1/(yu*yv)}, yw])/128 + (3*G[{0}, yu^(-1)]*G[{0}, yw]*
       G[{yu}, yv^(-1)]^2*G[{1/(yu*yv)}, yw])/64 + 
     (3*G[{0}, yv^(-1)]*G[{0}, yw]*G[{yu}, yv^(-1)]^2*G[{1/(yu*yv)}, yw])/
      64 - (3*G[{0}, yw]^2*G[{yu}, yv^(-1)]^2*G[{1/(yu*yv)}, yw])/128 - 
     (G[{0}, yu^(-1)]*G[{1}, yu^(-1)]*G[{yu}, yv^(-1)]^2*G[{1/(yu*yv)}, yw])/
      64 - (G[{0}, yv^(-1)]*G[{1}, yu^(-1)]*G[{yu}, yv^(-1)]^2*
       G[{1/(yu*yv)}, yw])/64 + (G[{0}, yw]*G[{1}, yu^(-1)]*
       G[{yu}, yv^(-1)]^2*G[{1/(yu*yv)}, yw])/64 + 
     (9*G[{1}, yu^(-1)]^2*G[{yu}, yv^(-1)]^2*G[{1/(yu*yv)}, yw])/128 - 
     (9*G[{0}, yu^(-1)]*G[{1}, yv^(-1)]*G[{yu}, yv^(-1)]^2*
       G[{1/(yu*yv)}, yw])/64 - (9*G[{0}, yv^(-1)]*G[{1}, yv^(-1)]*
       G[{yu}, yv^(-1)]^2*G[{1/(yu*yv)}, yw])/64 + 
     (9*G[{0}, yw]*G[{1}, yv^(-1)]*G[{yu}, yv^(-1)]^2*G[{1/(yu*yv)}, yw])/
      64 - (7*G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*G[{yu}, yv^(-1)]^2*
       G[{1/(yu*yv)}, yw])/64 + (3*G[{1}, yv^(-1)]^2*G[{yu}, yv^(-1)]^2*
       G[{1/(yu*yv)}, yw])/32 - (G[{0}, yu^(-1)]*G[{1}, yw]*
       G[{yu}, yv^(-1)]^2*G[{1/(yu*yv)}, yw])/4 - 
     (G[{0}, yv^(-1)]*G[{1}, yw]*G[{yu}, yv^(-1)]^2*G[{1/(yu*yv)}, yw])/4 + 
     (G[{0}, yw]*G[{1}, yw]*G[{yu}, yv^(-1)]^2*G[{1/(yu*yv)}, yw])/4 - 
     (3*G[{1}, yv^(-1)]*G[{1}, yw]*G[{yu}, yv^(-1)]^2*G[{1/(yu*yv)}, yw])/
      128 - (31*G[{1}, yw]^2*G[{yu}, yv^(-1)]^2*G[{1/(yu*yv)}, yw])/256 + 
     (G[{0}, yu^(-1)]*G[{yu^(-1)}, yw]*G[{yu}, yv^(-1)]^2*G[{1/(yu*yv)}, yw])/
      8 + (G[{0}, yv^(-1)]*G[{yu^(-1)}, yw]*G[{yu}, yv^(-1)]^2*
       G[{1/(yu*yv)}, yw])/8 - (G[{0}, yw]*G[{yu^(-1)}, yw]*
       G[{yu}, yv^(-1)]^2*G[{1/(yu*yv)}, yw])/8 - 
     (7*G[{1}, yv^(-1)]*G[{yu^(-1)}, yw]*G[{yu}, yv^(-1)]^2*
       G[{1/(yu*yv)}, yw])/64 + (3*G[{1}, yw]*G[{yu^(-1)}, yw]*
       G[{yu}, yv^(-1)]^2*G[{1/(yu*yv)}, yw])/32 + 
     (7*G[{yu^(-1)}, yw]^2*G[{yu}, yv^(-1)]^2*G[{1/(yu*yv)}, yw])/128 + 
     (G[{0}, yu^(-1)]*G[{yu}, yv^(-1)]^3*G[{1/(yu*yv)}, yw])/12 + 
     (G[{0}, yv^(-1)]*G[{yu}, yv^(-1)]^3*G[{1/(yu*yv)}, yw])/12 - 
     (G[{0}, yw]*G[{yu}, yv^(-1)]^3*G[{1/(yu*yv)}, yw])/12 + 
     (3*G[{1}, yv^(-1)]*G[{yu}, yv^(-1)]^3*G[{1/(yu*yv)}, yw])/64 + 
     (67*G[{1}, yw]*G[{yu}, yv^(-1)]^3*G[{1/(yu*yv)}, yw])/384 - 
     (3*G[{yu^(-1)}, yw]*G[{yu}, yv^(-1)]^3*G[{1/(yu*yv)}, yw])/64 - 
     (41*G[{yu}, yv^(-1)]^4*G[{1/(yu*yv)}, yw])/768 - 
     (Pi^2*G[{0}, yu^(-1)]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw])/96 - 
     (Pi^2*G[{0}, yv^(-1)]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw])/96 + 
     (Pi^2*G[{0}, yw]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw])/96 - 
     (Pi^2*G[{1}, yu^(-1)]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw])/48 + 
     (G[{0}, yu^(-1)]*G[{1}, yu^(-1)]^2*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw])/
      32 + (G[{0}, yv^(-1)]*G[{1}, yu^(-1)]^2*G[{yv^(-1)}, yw]*
       G[{1/(yu*yv)}, yw])/32 - (G[{0}, yw]*G[{1}, yu^(-1)]^2*
       G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw])/32 - 
     (G[{1}, yu^(-1)]^3*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw])/32 + 
     (Pi^2*G[{1}, yv^(-1)]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw])/24 - 
     (G[{0}, yu^(-1)]*G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*G[{yv^(-1)}, yw]*
       G[{1/(yu*yv)}, yw])/16 - (G[{0}, yv^(-1)]*G[{1}, yu^(-1)]*
       G[{1}, yv^(-1)]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw])/16 + 
     (G[{0}, yw]*G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*G[{yv^(-1)}, yw]*
       G[{1/(yu*yv)}, yw])/16 + (G[{1}, yu^(-1)]^2*G[{1}, yv^(-1)]*
       G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw])/32 + 
     (G[{0}, yu^(-1)]*G[{1}, yv^(-1)]^2*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw])/
      16 + (G[{0}, yv^(-1)]*G[{1}, yv^(-1)]^2*G[{yv^(-1)}, yw]*
       G[{1/(yu*yv)}, yw])/16 - (G[{0}, yw]*G[{1}, yv^(-1)]^2*
       G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw])/16 - 
     (5*G[{1}, yv^(-1)]^3*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw])/128 - 
     (Pi^2*G[{1}, yw]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw])/96 - 
     (G[{0}, yu^(-1)]*G[{1}, yu^(-1)]*G[{1}, yw]*G[{yv^(-1)}, yw]*
       G[{1/(yu*yv)}, yw])/16 - (G[{0}, yv^(-1)]*G[{1}, yu^(-1)]*G[{1}, yw]*
       G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw])/16 + 
     (G[{0}, yw]*G[{1}, yu^(-1)]*G[{1}, yw]*G[{yv^(-1)}, yw]*
       G[{1/(yu*yv)}, yw])/16 + (3*G[{1}, yu^(-1)]^2*G[{1}, yw]*
       G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw])/32 + 
     (G[{0}, yu^(-1)]*G[{1}, yv^(-1)]*G[{1}, yw]*G[{yv^(-1)}, yw]*
       G[{1/(yu*yv)}, yw])/8 + (G[{0}, yv^(-1)]*G[{1}, yv^(-1)]*G[{1}, yw]*
       G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw])/8 - 
     (G[{0}, yw]*G[{1}, yv^(-1)]*G[{1}, yw]*G[{yv^(-1)}, yw]*
       G[{1/(yu*yv)}, yw])/8 - (G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*G[{1}, yw]*
       G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw])/8 - 
     (19*G[{1}, yv^(-1)]^2*G[{1}, yw]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw])/
      128 - (G[{1}, yu^(-1)]*G[{1}, yw]^2*G[{yv^(-1)}, yw]*
       G[{1/(yu*yv)}, yw])/32 - (11*G[{1}, yv^(-1)]*G[{1}, yw]^2*
       G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw])/128 - 
     (5*G[{1}, yw]^3*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw])/128 - 
     (Pi^2*G[{yu^(-1)}, yw]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw])/32 + 
     (G[{0}, yu^(-1)]*G[{1}, yu^(-1)]*G[{yu^(-1)}, yw]*G[{yv^(-1)}, yw]*
       G[{1/(yu*yv)}, yw])/8 + (G[{0}, yv^(-1)]*G[{1}, yu^(-1)]*
       G[{yu^(-1)}, yw]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw])/8 - 
     (G[{0}, yw]*G[{1}, yu^(-1)]*G[{yu^(-1)}, yw]*G[{yv^(-1)}, yw]*
       G[{1/(yu*yv)}, yw])/8 - (G[{1}, yu^(-1)]^2*G[{yu^(-1)}, yw]*
       G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw])/8 - 
     (G[{0}, yu^(-1)]*G[{1}, yv^(-1)]*G[{yu^(-1)}, yw]*G[{yv^(-1)}, yw]*
       G[{1/(yu*yv)}, yw])/8 - (G[{0}, yv^(-1)]*G[{1}, yv^(-1)]*
       G[{yu^(-1)}, yw]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw])/8 + 
     (G[{0}, yw]*G[{1}, yv^(-1)]*G[{yu^(-1)}, yw]*G[{yv^(-1)}, yw]*
       G[{1/(yu*yv)}, yw])/8 + (3*G[{1}, yv^(-1)]^2*G[{yu^(-1)}, yw]*
       G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw])/32 + 
     (G[{1}, yu^(-1)]*G[{1}, yw]*G[{yu^(-1)}, yw]*G[{yv^(-1)}, yw]*
       G[{1/(yu*yv)}, yw])/8 + (G[{1}, yv^(-1)]*G[{1}, yw]*G[{yu^(-1)}, yw]*
       G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw])/16 + 
     (3*G[{1}, yw]^2*G[{yu^(-1)}, yw]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw])/
      32 + (G[{0}, yu^(-1)]*G[{yu^(-1)}, yw]^2*G[{yv^(-1)}, yw]*
       G[{1/(yu*yv)}, yw])/16 + (G[{0}, yv^(-1)]*G[{yu^(-1)}, yw]^2*
       G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw])/16 - 
     (G[{0}, yw]*G[{yu^(-1)}, yw]^2*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw])/16 - 
     (G[{1}, yu^(-1)]*G[{yu^(-1)}, yw]^2*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw])/
      16 - (G[{1}, yv^(-1)]*G[{yu^(-1)}, yw]^2*G[{yv^(-1)}, yw]*
       G[{1/(yu*yv)}, yw])/16 + (G[{yu^(-1)}, yw]^3*G[{yv^(-1)}, yw]*
       G[{1/(yu*yv)}, yw])/48 - (G[{0}, yu^(-1)]*G[{1}, yw]*G[{yu}, yv^(-1)]*
       G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw])/16 - 
     (G[{0}, yv^(-1)]*G[{1}, yw]*G[{yu}, yv^(-1)]*G[{yv^(-1)}, yw]*
       G[{1/(yu*yv)}, yw])/16 + (G[{0}, yw]*G[{1}, yw]*G[{yu}, yv^(-1)]*
       G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw])/16 + 
     (G[{1}, yu^(-1)]*G[{1}, yw]*G[{yu}, yv^(-1)]*G[{yv^(-1)}, yw]*
       G[{1/(yu*yv)}, yw])/16 + (7*G[{1}, yv^(-1)]*G[{1}, yw]*
       G[{yu}, yv^(-1)]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw])/32 + 
     (15*G[{1}, yw]^2*G[{yu}, yv^(-1)]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw])/
      128 - (3*G[{1}, yw]*G[{yu^(-1)}, yw]*G[{yu}, yv^(-1)]*G[{yv^(-1)}, yw]*
       G[{1/(yu*yv)}, yw])/16 - (5*G[{1}, yw]*G[{yu}, yv^(-1)]^2*
       G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw])/64 + 
     (Pi^2*G[{yv^(-1)}, yw]^2*G[{1/(yu*yv)}, yw])/64 + 
     (G[{1}, yu^(-1)]^2*G[{yv^(-1)}, yw]^2*G[{1/(yu*yv)}, yw])/32 - 
     (G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*G[{yv^(-1)}, yw]^2*G[{1/(yu*yv)}, yw])/
      16 + (5*G[{1}, yv^(-1)]^2*G[{yv^(-1)}, yw]^2*G[{1/(yu*yv)}, yw])/64 + 
     (G[{0}, yu^(-1)]*G[{1}, yw]*G[{yv^(-1)}, yw]^2*G[{1/(yu*yv)}, yw])/16 + 
     (G[{0}, yv^(-1)]*G[{1}, yw]*G[{yv^(-1)}, yw]^2*G[{1/(yu*yv)}, yw])/16 - 
     (G[{0}, yw]*G[{1}, yw]*G[{yv^(-1)}, yw]^2*G[{1/(yu*yv)}, yw])/16 - 
     (G[{1}, yu^(-1)]*G[{1}, yw]*G[{yv^(-1)}, yw]^2*G[{1/(yu*yv)}, yw])/8 - 
     (G[{1}, yv^(-1)]*G[{1}, yw]*G[{yv^(-1)}, yw]^2*G[{1/(yu*yv)}, yw])/32 - 
     (G[{1}, yw]^2*G[{yv^(-1)}, yw]^2*G[{1/(yu*yv)}, yw])/64 - 
     (G[{0}, yu^(-1)]*G[{yu^(-1)}, yw]*G[{yv^(-1)}, yw]^2*G[{1/(yu*yv)}, yw])/
      16 - (G[{0}, yv^(-1)]*G[{yu^(-1)}, yw]*G[{yv^(-1)}, yw]^2*
       G[{1/(yu*yv)}, yw])/16 + (G[{0}, yw]*G[{yu^(-1)}, yw]*
       G[{yv^(-1)}, yw]^2*G[{1/(yu*yv)}, yw])/16 + 
     (3*G[{1}, yu^(-1)]*G[{yu^(-1)}, yw]*G[{yv^(-1)}, yw]^2*
       G[{1/(yu*yv)}, yw])/16 - (G[{1}, yv^(-1)]*G[{yu^(-1)}, yw]*
       G[{yv^(-1)}, yw]^2*G[{1/(yu*yv)}, yw])/16 + 
     (G[{yu^(-1)}, yw]^2*G[{yv^(-1)}, yw]^2*G[{1/(yu*yv)}, yw])/32 + 
     (G[{1}, yw]*G[{yu}, yv^(-1)]*G[{yv^(-1)}, yw]^2*G[{1/(yu*yv)}, yw])/32 - 
     (G[{0}, yu^(-1)]*G[{yv^(-1)}, yw]^3*G[{1/(yu*yv)}, yw])/48 - 
     (G[{0}, yv^(-1)]*G[{yv^(-1)}, yw]^3*G[{1/(yu*yv)}, yw])/48 + 
     (G[{0}, yw]*G[{yv^(-1)}, yw]^3*G[{1/(yu*yv)}, yw])/48 - 
     (G[{1}, yu^(-1)]*G[{yv^(-1)}, yw]^3*G[{1/(yu*yv)}, yw])/48 + 
     (G[{1}, yv^(-1)]*G[{yv^(-1)}, yw]^3*G[{1/(yu*yv)}, yw])/16 - 
     (G[{yu^(-1)}, yw]*G[{yv^(-1)}, yw]^3*G[{1/(yu*yv)}, yw])/16 + 
     (G[{yv^(-1)}, yw]^4*G[{1/(yu*yv)}, yw])/192 + 
     (Pi^2*G[{0}, yu^(-1)]*G[{1/(yu*yv)}, yw]^2)/192 + 
     (Pi^2*G[{0}, yv^(-1)]*G[{1/(yu*yv)}, yw]^2)/192 - 
     (Pi^2*G[{0}, yw]*G[{1/(yu*yv)}, yw]^2)/192 + 
     (Pi^2*G[{1}, yu^(-1)]*G[{1/(yu*yv)}, yw]^2)/192 - 
     (G[{0}, yu^(-1)]*G[{1}, yu^(-1)]^2*G[{1/(yu*yv)}, yw]^2)/64 - 
     (G[{0}, yv^(-1)]*G[{1}, yu^(-1)]^2*G[{1/(yu*yv)}, yw]^2)/64 + 
     (G[{0}, yw]*G[{1}, yu^(-1)]^2*G[{1/(yu*yv)}, yw]^2)/64 + 
     (G[{1}, yu^(-1)]^3*G[{1/(yu*yv)}, yw]^2)/64 - 
     (7*Pi^2*G[{1}, yv^(-1)]*G[{1/(yu*yv)}, yw]^2)/512 + 
     (3*G[{0}, yu^(-1)]^2*G[{1}, yv^(-1)]*G[{1/(yu*yv)}, yw]^2)/256 + 
     (3*G[{0}, yu^(-1)]*G[{0}, yv^(-1)]*G[{1}, yv^(-1)]*G[{1/(yu*yv)}, yw]^2)/
      128 + (3*G[{0}, yv^(-1)]^2*G[{1}, yv^(-1)]*G[{1/(yu*yv)}, yw]^2)/256 - 
     (3*G[{0}, yu^(-1)]*G[{0}, yw]*G[{1}, yv^(-1)]*G[{1/(yu*yv)}, yw]^2)/
      128 - (3*G[{0}, yv^(-1)]*G[{0}, yw]*G[{1}, yv^(-1)]*
       G[{1/(yu*yv)}, yw]^2)/128 + (3*G[{0}, yw]^2*G[{1}, yv^(-1)]*
       G[{1/(yu*yv)}, yw]^2)/256 + (5*G[{0}, yu^(-1)]*G[{1}, yu^(-1)]*
       G[{1}, yv^(-1)]*G[{1/(yu*yv)}, yw]^2)/128 + 
     (5*G[{0}, yv^(-1)]*G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*G[{1/(yu*yv)}, yw]^2)/
      128 - (5*G[{0}, yw]*G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*
       G[{1/(yu*yv)}, yw]^2)/128 - (5*G[{1}, yu^(-1)]^2*G[{1}, yv^(-1)]*
       G[{1/(yu*yv)}, yw]^2)/256 - (5*G[{0}, yu^(-1)]*G[{1}, yv^(-1)]^2*
       G[{1/(yu*yv)}, yw]^2)/64 - (5*G[{0}, yv^(-1)]*G[{1}, yv^(-1)]^2*
       G[{1/(yu*yv)}, yw]^2)/64 + (5*G[{0}, yw]*G[{1}, yv^(-1)]^2*
       G[{1/(yu*yv)}, yw]^2)/64 - (G[{1}, yu^(-1)]*G[{1}, yv^(-1)]^2*
       G[{1/(yu*yv)}, yw]^2)/32 + (17*G[{1}, yv^(-1)]^3*G[{1/(yu*yv)}, yw]^2)/
      256 + (Pi^2*G[{1}, yw]*G[{1/(yu*yv)}, yw]^2)/512 + 
     (3*G[{0}, yu^(-1)]^2*G[{1}, yw]*G[{1/(yu*yv)}, yw]^2)/256 + 
     (3*G[{0}, yu^(-1)]*G[{0}, yv^(-1)]*G[{1}, yw]*G[{1/(yu*yv)}, yw]^2)/
      128 + (3*G[{0}, yv^(-1)]^2*G[{1}, yw]*G[{1/(yu*yv)}, yw]^2)/256 - 
     (3*G[{0}, yu^(-1)]*G[{0}, yw]*G[{1}, yw]*G[{1/(yu*yv)}, yw]^2)/128 - 
     (3*G[{0}, yv^(-1)]*G[{0}, yw]*G[{1}, yw]*G[{1/(yu*yv)}, yw]^2)/128 + 
     (3*G[{0}, yw]^2*G[{1}, yw]*G[{1/(yu*yv)}, yw]^2)/256 + 
     (9*G[{0}, yu^(-1)]*G[{1}, yu^(-1)]*G[{1}, yw]*G[{1/(yu*yv)}, yw]^2)/
      128 + (9*G[{0}, yv^(-1)]*G[{1}, yu^(-1)]*G[{1}, yw]*
       G[{1/(yu*yv)}, yw]^2)/128 - (9*G[{0}, yw]*G[{1}, yu^(-1)]*G[{1}, yw]*
       G[{1/(yu*yv)}, yw]^2)/128 - (17*G[{1}, yu^(-1)]^2*G[{1}, yw]*
       G[{1/(yu*yv)}, yw]^2)/256 - (5*G[{0}, yu^(-1)]*G[{1}, yv^(-1)]*
       G[{1}, yw]*G[{1/(yu*yv)}, yw]^2)/64 - 
     (5*G[{0}, yv^(-1)]*G[{1}, yv^(-1)]*G[{1}, yw]*G[{1/(yu*yv)}, yw]^2)/64 + 
     (5*G[{0}, yw]*G[{1}, yv^(-1)]*G[{1}, yw]*G[{1/(yu*yv)}, yw]^2)/64 - 
     (5*G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*G[{1}, yw]*G[{1/(yu*yv)}, yw]^2)/64 + 
     (5*G[{1}, yv^(-1)]^2*G[{1}, yw]*G[{1/(yu*yv)}, yw]^2)/256 + 
     (3*G[{0}, yu^(-1)]*G[{1}, yw]^2*G[{1/(yu*yv)}, yw]^2)/64 + 
     (3*G[{0}, yv^(-1)]*G[{1}, yw]^2*G[{1/(yu*yv)}, yw]^2)/64 - 
     (3*G[{0}, yw]*G[{1}, yw]^2*G[{1/(yu*yv)}, yw]^2)/64 - 
     (G[{1}, yu^(-1)]*G[{1}, yw]^2*G[{1/(yu*yv)}, yw]^2)/16 - 
     (G[{1}, yv^(-1)]*G[{1}, yw]^2*G[{1/(yu*yv)}, yw]^2)/8 - 
     (G[{1}, yw]^3*G[{1/(yu*yv)}, yw]^2)/32 + 
     (7*Pi^2*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2)/512 - 
     (3*G[{0}, yu^(-1)]^2*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2)/256 - 
     (3*G[{0}, yu^(-1)]*G[{0}, yv^(-1)]*G[{yu^(-1)}, yw]*
       G[{1/(yu*yv)}, yw]^2)/128 - (3*G[{0}, yv^(-1)]^2*G[{yu^(-1)}, yw]*
       G[{1/(yu*yv)}, yw]^2)/256 + (3*G[{0}, yu^(-1)]*G[{0}, yw]*
       G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2)/128 + 
     (3*G[{0}, yv^(-1)]*G[{0}, yw]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2)/
      128 - (3*G[{0}, yw]^2*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2)/256 - 
     (13*G[{0}, yu^(-1)]*G[{1}, yu^(-1)]*G[{yu^(-1)}, yw]*
       G[{1/(yu*yv)}, yw]^2)/128 - (13*G[{0}, yv^(-1)]*G[{1}, yu^(-1)]*
       G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2)/128 + 
     (13*G[{0}, yw]*G[{1}, yu^(-1)]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2)/
      128 + (21*G[{1}, yu^(-1)]^2*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2)/
      256 + (15*G[{0}, yu^(-1)]*G[{1}, yv^(-1)]*G[{yu^(-1)}, yw]*
       G[{1/(yu*yv)}, yw]^2)/128 + (15*G[{0}, yv^(-1)]*G[{1}, yv^(-1)]*
       G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2)/128 - 
     (15*G[{0}, yw]*G[{1}, yv^(-1)]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2)/
      128 + (17*G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*G[{yu^(-1)}, yw]*
       G[{1/(yu*yv)}, yw]^2)/128 - (41*G[{1}, yv^(-1)]^2*G[{yu^(-1)}, yw]*
       G[{1/(yu*yv)}, yw]^2)/256 - (3*G[{0}, yu^(-1)]*G[{1}, yw]*
       G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2)/128 - 
     (3*G[{0}, yv^(-1)]*G[{1}, yw]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2)/
      128 + (3*G[{0}, yw]*G[{1}, yw]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2)/
      128 + (11*G[{1}, yu^(-1)]*G[{1}, yw]*G[{yu^(-1)}, yw]*
       G[{1/(yu*yv)}, yw]^2)/128 + (5*G[{1}, yv^(-1)]*G[{1}, yw]*
       G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2)/128 + 
     (5*G[{1}, yw]^2*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2)/128 - 
     (G[{0}, yu^(-1)]*G[{yu^(-1)}, yw]^2*G[{1/(yu*yv)}, yw]^2)/16 - 
     (G[{0}, yv^(-1)]*G[{yu^(-1)}, yw]^2*G[{1/(yu*yv)}, yw]^2)/16 + 
     (G[{0}, yw]*G[{yu^(-1)}, yw]^2*G[{1/(yu*yv)}, yw]^2)/16 - 
     (G[{1}, yu^(-1)]*G[{yu^(-1)}, yw]^2*G[{1/(yu*yv)}, yw]^2)/16 + 
     (33*G[{1}, yv^(-1)]*G[{yu^(-1)}, yw]^2*G[{1/(yu*yv)}, yw]^2)/256 - 
     (15*G[{1}, yw]*G[{yu^(-1)}, yw]^2*G[{1/(yu*yv)}, yw]^2)/256 - 
     (11*G[{yu^(-1)}, yw]^3*G[{1/(yu*yv)}, yw]^2)/256 - 
     (Pi^2*G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw]^2)/512 - 
     (3*G[{0}, yu^(-1)]^2*G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw]^2)/256 - 
     (3*G[{0}, yu^(-1)]*G[{0}, yv^(-1)]*G[{yu}, yv^(-1)]*
       G[{1/(yu*yv)}, yw]^2)/128 - (3*G[{0}, yv^(-1)]^2*G[{yu}, yv^(-1)]*
       G[{1/(yu*yv)}, yw]^2)/256 + (3*G[{0}, yu^(-1)]*G[{0}, yw]*
       G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw]^2)/128 + 
     (3*G[{0}, yv^(-1)]*G[{0}, yw]*G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw]^2)/
      128 - (3*G[{0}, yw]^2*G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw]^2)/256 - 
     (G[{0}, yu^(-1)]*G[{1}, yu^(-1)]*G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw]^2)/
      128 - (G[{0}, yv^(-1)]*G[{1}, yu^(-1)]*G[{yu}, yv^(-1)]*
       G[{1/(yu*yv)}, yw]^2)/128 + (G[{0}, yw]*G[{1}, yu^(-1)]*
       G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw]^2)/128 + 
     (G[{1}, yu^(-1)]^2*G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw]^2)/256 + 
     (3*G[{0}, yu^(-1)]*G[{1}, yv^(-1)]*G[{yu}, yv^(-1)]*
       G[{1/(yu*yv)}, yw]^2)/128 + (3*G[{0}, yv^(-1)]*G[{1}, yv^(-1)]*
       G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw]^2)/128 - 
     (3*G[{0}, yw]*G[{1}, yv^(-1)]*G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw]^2)/
      128 + (5*G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*G[{yu}, yv^(-1)]*
       G[{1/(yu*yv)}, yw]^2)/128 + (9*G[{1}, yv^(-1)]^2*G[{yu}, yv^(-1)]*
       G[{1/(yu*yv)}, yw]^2)/256 - (5*G[{0}, yu^(-1)]*G[{1}, yw]*
       G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw]^2)/128 - 
     (5*G[{0}, yv^(-1)]*G[{1}, yw]*G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw]^2)/
      128 + (5*G[{0}, yw]*G[{1}, yw]*G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw]^2)/
      128 + (9*G[{1}, yu^(-1)]*G[{1}, yw]*G[{yu}, yv^(-1)]*
       G[{1/(yu*yv)}, yw]^2)/128 + (3*G[{1}, yv^(-1)]*G[{1}, yw]*
       G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw]^2)/16 + 
     (3*G[{1}, yw]^2*G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw]^2)/32 + 
     (G[{0}, yu^(-1)]*G[{yu^(-1)}, yw]*G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw]^2)/
      32 + (G[{0}, yv^(-1)]*G[{yu^(-1)}, yw]*G[{yu}, yv^(-1)]*
       G[{1/(yu*yv)}, yw]^2)/32 - (G[{0}, yw]*G[{yu^(-1)}, yw]*
       G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw]^2)/32 - 
     (3*G[{1}, yu^(-1)]*G[{yu^(-1)}, yw]*G[{yu}, yv^(-1)]*
       G[{1/(yu*yv)}, yw]^2)/32 - (15*G[{1}, yv^(-1)]*G[{yu^(-1)}, yw]*
       G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw]^2)/128 - 
     (5*G[{1}, yw]*G[{yu^(-1)}, yw]*G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw]^2)/
      64 + (15*G[{yu^(-1)}, yw]^2*G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw]^2)/
      256 + (G[{0}, yu^(-1)]*G[{yu}, yv^(-1)]^2*G[{1/(yu*yv)}, yw]^2)/64 + 
     (G[{0}, yv^(-1)]*G[{yu}, yv^(-1)]^2*G[{1/(yu*yv)}, yw]^2)/64 - 
     (G[{0}, yw]*G[{yu}, yv^(-1)]^2*G[{1/(yu*yv)}, yw]^2)/64 - 
     (G[{1}, yu^(-1)]*G[{yu}, yv^(-1)]^2*G[{1/(yu*yv)}, yw]^2)/64 - 
     (19*G[{1}, yv^(-1)]*G[{yu}, yv^(-1)]^2*G[{1/(yu*yv)}, yw]^2)/256 - 
     (23*G[{1}, yw]*G[{yu}, yv^(-1)]^2*G[{1/(yu*yv)}, yw]^2)/256 + 
     (19*G[{yu^(-1)}, yw]*G[{yu}, yv^(-1)]^2*G[{1/(yu*yv)}, yw]^2)/256 + 
     (5*G[{yu}, yv^(-1)]^3*G[{1/(yu*yv)}, yw]^2)/256 - 
     (Pi^2*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2)/192 - 
     (G[{0}, yu^(-1)]*G[{1}, yu^(-1)]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2)/
      32 - (G[{0}, yv^(-1)]*G[{1}, yu^(-1)]*G[{yv^(-1)}, yw]*
       G[{1/(yu*yv)}, yw]^2)/32 + (G[{0}, yw]*G[{1}, yu^(-1)]*
       G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2)/32 + 
     (G[{1}, yu^(-1)]^2*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2)/64 - 
     (G[{0}, yu^(-1)]*G[{1}, yv^(-1)]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2)/
      32 - (G[{0}, yv^(-1)]*G[{1}, yv^(-1)]*G[{yv^(-1)}, yw]*
       G[{1/(yu*yv)}, yw]^2)/32 + (G[{0}, yw]*G[{1}, yv^(-1)]*
       G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2)/32 + 
     (3*G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*G[{yv^(-1)}, yw]*
       G[{1/(yu*yv)}, yw]^2)/32 + (3*G[{1}, yv^(-1)]^2*G[{yv^(-1)}, yw]*
       G[{1/(yu*yv)}, yw]^2)/128 - (G[{0}, yu^(-1)]*G[{1}, yw]*
       G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2)/8 - 
     (G[{0}, yv^(-1)]*G[{1}, yw]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2)/8 + 
     (G[{0}, yw]*G[{1}, yw]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2)/8 + 
     (G[{1}, yu^(-1)]*G[{1}, yw]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2)/8 + 
     (9*G[{1}, yv^(-1)]*G[{1}, yw]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2)/
      64 + (G[{1}, yw]^2*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2)/128 + 
     (3*G[{0}, yu^(-1)]*G[{yu^(-1)}, yw]*G[{yv^(-1)}, yw]*
       G[{1/(yu*yv)}, yw]^2)/32 + (3*G[{0}, yv^(-1)]*G[{yu^(-1)}, yw]*
       G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2)/32 - 
     (3*G[{0}, yw]*G[{yu^(-1)}, yw]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2)/
      32 - (5*G[{1}, yu^(-1)]*G[{yu^(-1)}, yw]*G[{yv^(-1)}, yw]*
       G[{1/(yu*yv)}, yw]^2)/32 - (G[{1}, yv^(-1)]*G[{yu^(-1)}, yw]*
       G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2)/8 - 
     (3*G[{1}, yw]*G[{yu^(-1)}, yw]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2)/
      32 + (G[{yu^(-1)}, yw]^2*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2)/16 + 
     (G[{0}, yu^(-1)]*G[{yu}, yv^(-1)]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2)/
      16 + (G[{0}, yv^(-1)]*G[{yu}, yv^(-1)]*G[{yv^(-1)}, yw]*
       G[{1/(yu*yv)}, yw]^2)/16 - (G[{0}, yw]*G[{yu}, yv^(-1)]*
       G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2)/16 - 
     (G[{1}, yu^(-1)]*G[{yu}, yv^(-1)]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2)/
      16 - (3*G[{1}, yv^(-1)]*G[{yu}, yv^(-1)]*G[{yv^(-1)}, yw]*
       G[{1/(yu*yv)}, yw]^2)/32 - (G[{1}, yw]*G[{yu}, yv^(-1)]*
       G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2)/64 + 
     (3*G[{yu^(-1)}, yw]*G[{yu}, yv^(-1)]*G[{yv^(-1)}, yw]*
       G[{1/(yu*yv)}, yw]^2)/32 + (G[{yu}, yv^(-1)]^2*G[{yv^(-1)}, yw]*
       G[{1/(yu*yv)}, yw]^2)/64 + (3*G[{0}, yu^(-1)]*G[{yv^(-1)}, yw]^2*
       G[{1/(yu*yv)}, yw]^2)/64 + (3*G[{0}, yv^(-1)]*G[{yv^(-1)}, yw]^2*
       G[{1/(yu*yv)}, yw]^2)/64 - (3*G[{0}, yw]*G[{yv^(-1)}, yw]^2*
       G[{1/(yu*yv)}, yw]^2)/64 - (3*G[{1}, yu^(-1)]*G[{yv^(-1)}, yw]^2*
       G[{1/(yu*yv)}, yw]^2)/64 - (5*G[{1}, yv^(-1)]*G[{yv^(-1)}, yw]^2*
       G[{1/(yu*yv)}, yw]^2)/64 - (G[{1}, yw]*G[{yv^(-1)}, yw]^2*
       G[{1/(yu*yv)}, yw]^2)/32 + (5*G[{yu^(-1)}, yw]*G[{yv^(-1)}, yw]^2*
       G[{1/(yu*yv)}, yw]^2)/64 + (G[{yu}, yv^(-1)]*G[{yv^(-1)}, yw]^2*
       G[{1/(yu*yv)}, yw]^2)/32 + (G[{yv^(-1)}, yw]^3*G[{1/(yu*yv)}, yw]^2)/
      64 + (G[{0}, yu^(-1)]*G[{1}, yu^(-1)]*G[{1/(yu*yv)}, yw]^3)/48 + 
     (G[{0}, yv^(-1)]*G[{1}, yu^(-1)]*G[{1/(yu*yv)}, yw]^3)/48 - 
     (G[{0}, yw]*G[{1}, yu^(-1)]*G[{1/(yu*yv)}, yw]^3)/48 - 
     (G[{1}, yu^(-1)]^2*G[{1/(yu*yv)}, yw]^3)/48 + 
     (5*G[{0}, yu^(-1)]*G[{1}, yv^(-1)]*G[{1/(yu*yv)}, yw]^3)/384 + 
     (5*G[{0}, yv^(-1)]*G[{1}, yv^(-1)]*G[{1/(yu*yv)}, yw]^3)/384 - 
     (5*G[{0}, yw]*G[{1}, yv^(-1)]*G[{1/(yu*yv)}, yw]^3)/384 - 
     (3*G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*G[{1/(yu*yv)}, yw]^3)/128 - 
     (5*G[{1}, yv^(-1)]^2*G[{1/(yu*yv)}, yw]^3)/384 + 
     (13*G[{0}, yu^(-1)]*G[{1}, yw]*G[{1/(yu*yv)}, yw]^3)/384 + 
     (13*G[{0}, yv^(-1)]*G[{1}, yw]*G[{1/(yu*yv)}, yw]^3)/384 - 
     (13*G[{0}, yw]*G[{1}, yw]*G[{1/(yu*yv)}, yw]^3)/384 - 
     (3*G[{1}, yu^(-1)]*G[{1}, yw]*G[{1/(yu*yv)}, yw]^3)/128 - 
     (3*G[{1}, yv^(-1)]*G[{1}, yw]*G[{1/(yu*yv)}, yw]^3)/128 + 
     (G[{1}, yw]^2*G[{1/(yu*yv)}, yw]^3)/96 - 
     (5*G[{0}, yu^(-1)]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]^3)/384 - 
     (5*G[{0}, yv^(-1)]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]^3)/384 + 
     (5*G[{0}, yw]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]^3)/384 + 
     (3*G[{1}, yu^(-1)]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]^3)/128 + 
     (5*G[{1}, yv^(-1)]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]^3)/192 + 
     (3*G[{1}, yw]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]^3)/128 - 
     (5*G[{yu^(-1)}, yw]^2*G[{1/(yu*yv)}, yw]^3)/384 - 
     (13*G[{0}, yu^(-1)]*G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw]^3)/384 - 
     (13*G[{0}, yv^(-1)]*G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw]^3)/384 + 
     (13*G[{0}, yw]*G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw]^3)/384 + 
     (3*G[{1}, yu^(-1)]*G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw]^3)/128 + 
     (3*G[{1}, yv^(-1)]*G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw]^3)/128 - 
     (G[{1}, yw]*G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw]^3)/48 - 
     (3*G[{yu^(-1)}, yw]*G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw]^3)/128 + 
     (G[{yu}, yv^(-1)]^2*G[{1/(yu*yv)}, yw]^3)/96 - 
     (G[{0}, yu^(-1)]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]^3)/48 - 
     (G[{0}, yv^(-1)]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]^3)/48 + 
     (G[{0}, yw]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]^3)/48 + 
     (G[{1}, yu^(-1)]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]^3)/24 + 
     (3*G[{1}, yv^(-1)]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]^3)/128 + 
     (3*G[{1}, yw]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]^3)/128 - 
     (3*G[{yu^(-1)}, yw]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]^3)/128 - 
     (3*G[{yu}, yv^(-1)]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]^3)/128 - 
     (G[{yv^(-1)}, yw]^2*G[{1/(yu*yv)}, yw]^3)/48 - 
     (Pi^2*G[{1}, yu^(-1)]*G[{0, 1}, yu^(-1)])/32 + 
     (G[{0}, yu^(-1)]*G[{1}, yu^(-1)]^2*G[{0, 1}, yu^(-1)])/32 + 
     (G[{0}, yv^(-1)]*G[{1}, yu^(-1)]^2*G[{0, 1}, yu^(-1)])/32 - 
     (G[{0}, yw]*G[{1}, yu^(-1)]^2*G[{0, 1}, yu^(-1)])/32 - 
     (G[{1}, yu^(-1)]^3*G[{0, 1}, yu^(-1)])/96 - 
     (G[{1}, yu^(-1)]^2*G[{1}, yv^(-1)]*G[{0, 1}, yu^(-1)])/32 + 
     (G[{1}, yu^(-1)]*G[{1}, yv^(-1)]^2*G[{0, 1}, yu^(-1)])/16 + 
     (Pi^2*G[{1}, yw]*G[{0, 1}, yu^(-1)])/32 - 
     (G[{0}, yu^(-1)]*G[{1}, yu^(-1)]*G[{1}, yw]*G[{0, 1}, yu^(-1)])/16 - 
     (G[{0}, yv^(-1)]*G[{1}, yu^(-1)]*G[{1}, yw]*G[{0, 1}, yu^(-1)])/16 + 
     (G[{0}, yw]*G[{1}, yu^(-1)]*G[{1}, yw]*G[{0, 1}, yu^(-1)])/16 + 
     (G[{1}, yu^(-1)]^2*G[{1}, yw]*G[{0, 1}, yu^(-1)])/32 + 
     (G[{0}, yu^(-1)]*G[{1}, yv^(-1)]*G[{1}, yw]*G[{0, 1}, yu^(-1)])/16 + 
     (G[{0}, yv^(-1)]*G[{1}, yv^(-1)]*G[{1}, yw]*G[{0, 1}, yu^(-1)])/16 - 
     (G[{0}, yw]*G[{1}, yv^(-1)]*G[{1}, yw]*G[{0, 1}, yu^(-1)])/16 + 
     (G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*G[{1}, yw]*G[{0, 1}, yu^(-1)])/8 + 
     (3*G[{0}, yu^(-1)]*G[{1}, yw]^2*G[{0, 1}, yu^(-1)])/32 + 
     (3*G[{0}, yv^(-1)]*G[{1}, yw]^2*G[{0, 1}, yu^(-1)])/32 - 
     (3*G[{0}, yw]*G[{1}, yw]^2*G[{0, 1}, yu^(-1)])/32 - 
     (3*G[{1}, yu^(-1)]*G[{1}, yw]^2*G[{0, 1}, yu^(-1)])/32 + 
     (G[{1}, yv^(-1)]*G[{1}, yw]^2*G[{0, 1}, yu^(-1)])/32 + 
     (5*G[{1}, yw]^3*G[{0, 1}, yu^(-1)])/96 - 
     (G[{0}, yu^(-1)]*G[{1}, yw]*G[{yu}, yv^(-1)]*G[{0, 1}, yu^(-1)])/16 - 
     (G[{0}, yv^(-1)]*G[{1}, yw]*G[{yu}, yv^(-1)]*G[{0, 1}, yu^(-1)])/16 + 
     (G[{0}, yw]*G[{1}, yw]*G[{yu}, yv^(-1)]*G[{0, 1}, yu^(-1)])/16 - 
     (G[{1}, yu^(-1)]*G[{1}, yw]*G[{yu}, yv^(-1)]*G[{0, 1}, yu^(-1)])/16 - 
     (G[{1}, yv^(-1)]*G[{1}, yw]*G[{yu}, yv^(-1)]*G[{0, 1}, yu^(-1)])/16 - 
     (G[{1}, yw]^2*G[{yu}, yv^(-1)]*G[{0, 1}, yu^(-1)])/8 + 
     (G[{1}, yw]*G[{yu}, yv^(-1)]^2*G[{0, 1}, yu^(-1)])/8 + 
     (G[{1}, yu^(-1)]^2*G[{1/(yu*yv)}, yw]*G[{0, 1}, yu^(-1)])/32 - 
     (G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, 1}, yu^(-1)])/
      8 - (G[{0}, yu^(-1)]*G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1}, yu^(-1)])/
      16 - (G[{0}, yv^(-1)]*G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1}, yu^(-1)])/
      16 + (G[{0}, yw]*G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1}, yu^(-1)])/16 - 
     (G[{1}, yu^(-1)]*G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1}, yu^(-1)])/16 - 
     (G[{1}, yv^(-1)]*G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1}, yu^(-1)])/16 - 
     (5*G[{1}, yw]^2*G[{1/(yu*yv)}, yw]*G[{0, 1}, yu^(-1)])/32 + 
     (G[{1}, yu^(-1)]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1}, yu^(-1)])/
      8 + (G[{1}, yw]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1}, yu^(-1)])/
      8 + (G[{0}, yu^(-1)]*G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw]*
       G[{0, 1}, yu^(-1)])/16 + (G[{0}, yv^(-1)]*G[{yu}, yv^(-1)]*
       G[{1/(yu*yv)}, yw]*G[{0, 1}, yu^(-1)])/16 - 
     (G[{0}, yw]*G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, 1}, yu^(-1)])/16 + 
     (G[{1}, yu^(-1)]*G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, 1}, yu^(-1)])/
      16 + (G[{1}, yv^(-1)]*G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw]*
       G[{0, 1}, yu^(-1)])/16 + (G[{1}, yw]*G[{yu}, yv^(-1)]*
       G[{1/(yu*yv)}, yw]*G[{0, 1}, yu^(-1)])/4 - 
     (G[{yu^(-1)}, yw]*G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw]*
       G[{0, 1}, yu^(-1)])/8 - (G[{yu}, yv^(-1)]^2*G[{1/(yu*yv)}, yw]*
       G[{0, 1}, yu^(-1)])/8 - (G[{1}, yu^(-1)]*G[{yv^(-1)}, yw]*
       G[{1/(yu*yv)}, yw]*G[{0, 1}, yu^(-1)])/16 + 
     (G[{1}, yv^(-1)]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1}, yu^(-1)])/
      16 + (G[{1}, yw]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*
       G[{0, 1}, yu^(-1)])/16 - (G[{yu^(-1)}, yw]*G[{yv^(-1)}, yw]*
       G[{1/(yu*yv)}, yw]*G[{0, 1}, yu^(-1)])/8 + 
     (G[{yv^(-1)}, yw]^2*G[{1/(yu*yv)}, yw]*G[{0, 1}, yu^(-1)])/16 - 
     (G[{0}, yu^(-1)]*G[{0, 1}, yu^(-1)]^2)/32 - 
     (G[{0}, yv^(-1)]*G[{0, 1}, yu^(-1)]^2)/32 + 
     (G[{0}, yw]*G[{0, 1}, yu^(-1)]^2)/32 - 
     (G[{1}, yu^(-1)]*G[{0, 1}, yu^(-1)]^2)/32 + 
     (G[{1}, yv^(-1)]*G[{0, 1}, yu^(-1)]^2)/32 + 
     (G[{1}, yw]*G[{0, 1}, yu^(-1)]^2)/32 - 
     (G[{1/(yu*yv)}, yw]*G[{0, 1}, yu^(-1)]^2)/32 - 
     (Pi^2*G[{0}, yu^(-1)]*G[{0, 1}, yv^(-1)])/48 - 
     (Pi^2*G[{0}, yv^(-1)]*G[{0, 1}, yv^(-1)])/48 + 
     (Pi^2*G[{0}, yw]*G[{0, 1}, yv^(-1)])/48 - 
     (Pi^2*G[{1}, yu^(-1)]*G[{0, 1}, yv^(-1)])/48 + 
     (G[{0}, yu^(-1)]*G[{1}, yu^(-1)]^2*G[{0, 1}, yv^(-1)])/32 + 
     (G[{0}, yv^(-1)]*G[{1}, yu^(-1)]^2*G[{0, 1}, yv^(-1)])/32 - 
     (G[{0}, yw]*G[{1}, yu^(-1)]^2*G[{0, 1}, yv^(-1)])/32 - 
     (G[{1}, yu^(-1)]^3*G[{0, 1}, yv^(-1)])/32 + 
     (5*Pi^2*G[{1}, yv^(-1)]*G[{0, 1}, yv^(-1)])/768 - 
     (3*G[{0}, yu^(-1)]^2*G[{1}, yv^(-1)]*G[{0, 1}, yv^(-1)])/128 - 
     (3*G[{0}, yu^(-1)]*G[{0}, yv^(-1)]*G[{1}, yv^(-1)]*G[{0, 1}, yv^(-1)])/
      64 - (3*G[{0}, yv^(-1)]^2*G[{1}, yv^(-1)]*G[{0, 1}, yv^(-1)])/128 + 
     (3*G[{0}, yu^(-1)]*G[{0}, yw]*G[{1}, yv^(-1)]*G[{0, 1}, yv^(-1)])/64 + 
     (3*G[{0}, yv^(-1)]*G[{0}, yw]*G[{1}, yv^(-1)]*G[{0, 1}, yv^(-1)])/64 - 
     (3*G[{0}, yw]^2*G[{1}, yv^(-1)]*G[{0, 1}, yv^(-1)])/128 - 
     (G[{0}, yu^(-1)]*G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*G[{0, 1}, yv^(-1)])/
      64 - (G[{0}, yv^(-1)]*G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*
       G[{0, 1}, yv^(-1)])/64 + (G[{0}, yw]*G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*
       G[{0, 1}, yv^(-1)])/64 + (G[{1}, yu^(-1)]^2*G[{1}, yv^(-1)]*
       G[{0, 1}, yv^(-1)])/128 + (5*G[{0}, yu^(-1)]*G[{1}, yv^(-1)]^2*
       G[{0, 1}, yv^(-1)])/64 + (5*G[{0}, yv^(-1)]*G[{1}, yv^(-1)]^2*
       G[{0, 1}, yv^(-1)])/64 - (5*G[{0}, yw]*G[{1}, yv^(-1)]^2*
       G[{0, 1}, yv^(-1)])/64 + (G[{1}, yu^(-1)]*G[{1}, yv^(-1)]^2*
       G[{0, 1}, yv^(-1)])/64 - (13*G[{1}, yv^(-1)]^3*G[{0, 1}, yv^(-1)])/
      192 - (Pi^2*G[{1}, yw]*G[{0, 1}, yv^(-1)])/256 - 
     (3*G[{0}, yu^(-1)]^2*G[{1}, yw]*G[{0, 1}, yv^(-1)])/128 - 
     (3*G[{0}, yu^(-1)]*G[{0}, yv^(-1)]*G[{1}, yw]*G[{0, 1}, yv^(-1)])/64 - 
     (3*G[{0}, yv^(-1)]^2*G[{1}, yw]*G[{0, 1}, yv^(-1)])/128 + 
     (3*G[{0}, yu^(-1)]*G[{0}, yw]*G[{1}, yw]*G[{0, 1}, yv^(-1)])/64 + 
     (3*G[{0}, yv^(-1)]*G[{0}, yw]*G[{1}, yw]*G[{0, 1}, yv^(-1)])/64 - 
     (3*G[{0}, yw]^2*G[{1}, yw]*G[{0, 1}, yv^(-1)])/128 - 
     (G[{0}, yu^(-1)]*G[{1}, yu^(-1)]*G[{1}, yw]*G[{0, 1}, yv^(-1)])/64 - 
     (G[{0}, yv^(-1)]*G[{1}, yu^(-1)]*G[{1}, yw]*G[{0, 1}, yv^(-1)])/64 + 
     (G[{0}, yw]*G[{1}, yu^(-1)]*G[{1}, yw]*G[{0, 1}, yv^(-1)])/64 + 
     (5*G[{1}, yu^(-1)]^2*G[{1}, yw]*G[{0, 1}, yv^(-1)])/128 + 
     (G[{0}, yu^(-1)]*G[{1}, yv^(-1)]*G[{1}, yw]*G[{0, 1}, yv^(-1)])/8 + 
     (G[{0}, yv^(-1)]*G[{1}, yv^(-1)]*G[{1}, yw]*G[{0, 1}, yv^(-1)])/8 - 
     (G[{0}, yw]*G[{1}, yv^(-1)]*G[{1}, yw]*G[{0, 1}, yv^(-1)])/8 - 
     (3*G[{1}, yv^(-1)]^2*G[{1}, yw]*G[{0, 1}, yv^(-1)])/64 + 
     (3*G[{0}, yu^(-1)]*G[{1}, yw]^2*G[{0, 1}, yv^(-1)])/64 + 
     (3*G[{0}, yv^(-1)]*G[{1}, yw]^2*G[{0, 1}, yv^(-1)])/64 - 
     (3*G[{0}, yw]*G[{1}, yw]^2*G[{0, 1}, yv^(-1)])/64 - 
     (3*G[{1}, yu^(-1)]*G[{1}, yw]^2*G[{0, 1}, yv^(-1)])/64 + 
     (5*G[{1}, yv^(-1)]*G[{1}, yw]^2*G[{0, 1}, yv^(-1)])/128 + 
     (11*G[{1}, yw]^3*G[{0, 1}, yv^(-1)])/384 - 
     (G[{0}, yu^(-1)]*G[{1}, yw]*G[{yu}, yv^(-1)]*G[{0, 1}, yv^(-1)])/16 - 
     (G[{0}, yv^(-1)]*G[{1}, yw]*G[{yu}, yv^(-1)]*G[{0, 1}, yv^(-1)])/16 + 
     (G[{0}, yw]*G[{1}, yw]*G[{yu}, yv^(-1)]*G[{0, 1}, yv^(-1)])/16 - 
     (G[{1}, yv^(-1)]*G[{1}, yw]*G[{yu}, yv^(-1)]*G[{0, 1}, yv^(-1)])/32 - 
     (9*G[{1}, yw]^2*G[{yu}, yv^(-1)]*G[{0, 1}, yv^(-1)])/128 + 
     (G[{1}, yw]*G[{yu}, yv^(-1)]^2*G[{0, 1}, yv^(-1)])/16 - 
     (5*Pi^2*G[{1/(yu*yv)}, yw]*G[{0, 1}, yv^(-1)])/768 + 
     (3*G[{0}, yu^(-1)]^2*G[{1/(yu*yv)}, yw]*G[{0, 1}, yv^(-1)])/128 + 
     (3*G[{0}, yu^(-1)]*G[{0}, yv^(-1)]*G[{1/(yu*yv)}, yw]*
       G[{0, 1}, yv^(-1)])/64 + (3*G[{0}, yv^(-1)]^2*G[{1/(yu*yv)}, yw]*
       G[{0, 1}, yv^(-1)])/128 - (3*G[{0}, yu^(-1)]*G[{0}, yw]*
       G[{1/(yu*yv)}, yw]*G[{0, 1}, yv^(-1)])/64 - 
     (3*G[{0}, yv^(-1)]*G[{0}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1}, yv^(-1)])/
      64 + (3*G[{0}, yw]^2*G[{1/(yu*yv)}, yw]*G[{0, 1}, yv^(-1)])/128 + 
     (G[{0}, yu^(-1)]*G[{1}, yu^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, 1}, yv^(-1)])/
      64 + (G[{0}, yv^(-1)]*G[{1}, yu^(-1)]*G[{1/(yu*yv)}, yw]*
       G[{0, 1}, yv^(-1)])/64 - (G[{0}, yw]*G[{1}, yu^(-1)]*
       G[{1/(yu*yv)}, yw]*G[{0, 1}, yv^(-1)])/64 - 
     (G[{1}, yu^(-1)]^2*G[{1/(yu*yv)}, yw]*G[{0, 1}, yv^(-1)])/128 - 
     (5*G[{0}, yu^(-1)]*G[{1}, yv^(-1)]*G[{1/(yu*yv)}, yw]*
       G[{0, 1}, yv^(-1)])/32 - (5*G[{0}, yv^(-1)]*G[{1}, yv^(-1)]*
       G[{1/(yu*yv)}, yw]*G[{0, 1}, yv^(-1)])/32 + 
     (5*G[{0}, yw]*G[{1}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, 1}, yv^(-1)])/
      32 - (G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*G[{1/(yu*yv)}, yw]*
       G[{0, 1}, yv^(-1)])/32 + (13*G[{1}, yv^(-1)]^2*G[{1/(yu*yv)}, yw]*
       G[{0, 1}, yv^(-1)])/64 - (G[{0}, yu^(-1)]*G[{1}, yw]*
       G[{1/(yu*yv)}, yw]*G[{0, 1}, yv^(-1)])/16 - 
     (G[{0}, yv^(-1)]*G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1}, yv^(-1)])/16 + 
     (G[{0}, yw]*G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1}, yv^(-1)])/16 - 
     (G[{1}, yu^(-1)]*G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1}, yv^(-1)])/16 + 
     (G[{1}, yv^(-1)]*G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1}, yv^(-1)])/64 - 
     (11*G[{1}, yw]^2*G[{1/(yu*yv)}, yw]*G[{0, 1}, yv^(-1)])/128 + 
     (G[{0}, yu^(-1)]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1}, yv^(-1)])/
      16 + (G[{0}, yv^(-1)]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*
       G[{0, 1}, yv^(-1)])/16 - (G[{0}, yw]*G[{yu^(-1)}, yw]*
       G[{1/(yu*yv)}, yw]*G[{0, 1}, yv^(-1)])/16 + 
     (G[{1}, yu^(-1)]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1}, yv^(-1)])/
      16 - (17*G[{1}, yv^(-1)]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*
       G[{0, 1}, yv^(-1)])/64 - (5*G[{1}, yw]*G[{yu^(-1)}, yw]*
       G[{1/(yu*yv)}, yw]*G[{0, 1}, yv^(-1)])/64 + 
     (3*G[{yu^(-1)}, yw]^2*G[{1/(yu*yv)}, yw]*G[{0, 1}, yv^(-1)])/32 + 
     (G[{0}, yu^(-1)]*G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, 1}, yv^(-1)])/
      16 + (G[{0}, yv^(-1)]*G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw]*
       G[{0, 1}, yv^(-1)])/16 - (G[{0}, yw]*G[{yu}, yv^(-1)]*
       G[{1/(yu*yv)}, yw]*G[{0, 1}, yv^(-1)])/16 + 
     (G[{1}, yv^(-1)]*G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, 1}, yv^(-1)])/
      32 + (9*G[{1}, yw]*G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw]*
       G[{0, 1}, yv^(-1)])/64 - (G[{yu}, yv^(-1)]^2*G[{1/(yu*yv)}, yw]*
       G[{0, 1}, yv^(-1)])/16 - (G[{0}, yu^(-1)]*G[{yv^(-1)}, yw]*
       G[{1/(yu*yv)}, yw]*G[{0, 1}, yv^(-1)])/16 - 
     (G[{0}, yv^(-1)]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1}, yv^(-1)])/
      16 + (G[{0}, yw]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*
       G[{0, 1}, yv^(-1)])/16 + (G[{1}, yu^(-1)]*G[{yv^(-1)}, yw]*
       G[{1/(yu*yv)}, yw]*G[{0, 1}, yv^(-1)])/16 + 
     (5*G[{1}, yv^(-1)]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*
       G[{0, 1}, yv^(-1)])/64 + (G[{1}, yw]*G[{yv^(-1)}, yw]*
       G[{1/(yu*yv)}, yw]*G[{0, 1}, yv^(-1)])/64 - 
     (G[{yu^(-1)}, yw]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*
       G[{0, 1}, yv^(-1)])/16 - (G[{yv^(-1)}, yw]^2*G[{1/(yu*yv)}, yw]*
       G[{0, 1}, yv^(-1)])/32 + (3*G[{0}, yu^(-1)]*G[{1/(yu*yv)}, yw]^2*
       G[{0, 1}, yv^(-1)])/64 + (3*G[{0}, yv^(-1)]*G[{1/(yu*yv)}, yw]^2*
       G[{0, 1}, yv^(-1)])/64 - (3*G[{0}, yw]*G[{1/(yu*yv)}, yw]^2*
       G[{0, 1}, yv^(-1)])/64 - (G[{1}, yu^(-1)]*G[{1/(yu*yv)}, yw]^2*
       G[{0, 1}, yv^(-1)])/64 - (9*G[{1}, yv^(-1)]*G[{1/(yu*yv)}, yw]^2*
       G[{0, 1}, yv^(-1)])/128 + (G[{1}, yw]*G[{1/(yu*yv)}, yw]^2*
       G[{0, 1}, yv^(-1)])/128 + (9*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2*
       G[{0, 1}, yv^(-1)])/128 - (G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw]^2*
       G[{0, 1}, yv^(-1)])/128 + (G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2*
       G[{0, 1}, yv^(-1)])/64 - (G[{1}, yu^(-1)]*G[{0, 1}, yu^(-1)]*
       G[{0, 1}, yv^(-1)])/8 - (G[{0}, yu^(-1)]*G[{0, 1}, yv^(-1)]^2)/32 - 
     (G[{0}, yv^(-1)]*G[{0, 1}, yv^(-1)]^2)/32 + 
     (G[{0}, yw]*G[{0, 1}, yv^(-1)]^2)/32 + 
     (G[{1}, yv^(-1)]*G[{0, 1}, yv^(-1)]^2)/128 + 
     (G[{1}, yw]*G[{0, 1}, yv^(-1)]^2)/128 - 
     (G[{1/(yu*yv)}, yw]*G[{0, 1}, yv^(-1)]^2)/128 + 
     (Pi^2*G[{1}, yu^(-1)]*G[{0, 1}, yw])/96 + 
     (Pi^2*G[{1}, yv^(-1)]*G[{0, 1}, yw])/24 - 
     (G[{1}, yu^(-1)]^2*G[{1}, yv^(-1)]*G[{0, 1}, yw])/32 + 
     (G[{0}, yu^(-1)]*G[{1}, yv^(-1)]^2*G[{0, 1}, yw])/16 + 
     (G[{0}, yv^(-1)]*G[{1}, yv^(-1)]^2*G[{0, 1}, yw])/16 - 
     (G[{0}, yw]*G[{1}, yv^(-1)]^2*G[{0, 1}, yw])/16 - 
     (5*G[{1}, yv^(-1)]^3*G[{0, 1}, yw])/128 + 
     (Pi^2*G[{1}, yw]*G[{0, 1}, yw])/48 + 
     (G[{0}, yu^(-1)]*G[{1}, yv^(-1)]*G[{1}, yw]*G[{0, 1}, yw])/8 + 
     (G[{0}, yv^(-1)]*G[{1}, yv^(-1)]*G[{1}, yw]*G[{0, 1}, yw])/8 - 
     (G[{0}, yw]*G[{1}, yv^(-1)]*G[{1}, yw]*G[{0, 1}, yw])/8 - 
     (G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*G[{1}, yw]*G[{0, 1}, yw])/16 - 
     (15*G[{1}, yv^(-1)]^2*G[{1}, yw]*G[{0, 1}, yw])/128 + 
     (G[{0}, yu^(-1)]*G[{1}, yw]^2*G[{0, 1}, yw])/32 + 
     (G[{0}, yv^(-1)]*G[{1}, yw]^2*G[{0, 1}, yw])/32 - 
     (G[{0}, yw]*G[{1}, yw]^2*G[{0, 1}, yw])/32 - 
     (G[{1}, yu^(-1)]*G[{1}, yw]^2*G[{0, 1}, yw])/32 - 
     (15*G[{1}, yv^(-1)]*G[{1}, yw]^2*G[{0, 1}, yw])/128 - 
     (5*G[{1}, yw]^3*G[{0, 1}, yw])/128 - 
     (Pi^2*G[{yu}, yv^(-1)]*G[{0, 1}, yw])/24 + 
     (G[{1}, yu^(-1)]^2*G[{yu}, yv^(-1)]*G[{0, 1}, yw])/32 - 
     (G[{0}, yu^(-1)]*G[{1}, yv^(-1)]*G[{yu}, yv^(-1)]*G[{0, 1}, yw])/8 - 
     (G[{0}, yv^(-1)]*G[{1}, yv^(-1)]*G[{yu}, yv^(-1)]*G[{0, 1}, yw])/8 + 
     (G[{0}, yw]*G[{1}, yv^(-1)]*G[{yu}, yv^(-1)]*G[{0, 1}, yw])/8 - 
     (G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*G[{yu}, yv^(-1)]*G[{0, 1}, yw])/16 + 
     (G[{1}, yv^(-1)]^2*G[{yu}, yv^(-1)]*G[{0, 1}, yw])/32 - 
     (G[{0}, yu^(-1)]*G[{1}, yw]*G[{yu}, yv^(-1)]*G[{0, 1}, yw])/8 - 
     (G[{0}, yv^(-1)]*G[{1}, yw]*G[{yu}, yv^(-1)]*G[{0, 1}, yw])/8 + 
     (G[{0}, yw]*G[{1}, yw]*G[{yu}, yv^(-1)]*G[{0, 1}, yw])/8 + 
     (G[{1}, yu^(-1)]*G[{1}, yw]*G[{yu}, yv^(-1)]*G[{0, 1}, yw])/16 + 
     (3*G[{1}, yv^(-1)]*G[{1}, yw]*G[{yu}, yv^(-1)]*G[{0, 1}, yw])/32 + 
     (11*G[{1}, yw]^2*G[{yu}, yv^(-1)]*G[{0, 1}, yw])/128 + 
     (G[{0}, yu^(-1)]*G[{yu}, yv^(-1)]^2*G[{0, 1}, yw])/16 + 
     (G[{0}, yv^(-1)]*G[{yu}, yv^(-1)]^2*G[{0, 1}, yw])/16 - 
     (G[{0}, yw]*G[{yu}, yv^(-1)]^2*G[{0, 1}, yw])/16 + 
     (G[{1}, yv^(-1)]*G[{yu}, yv^(-1)]^2*G[{0, 1}, yw])/8 + 
     (3*G[{1}, yw]*G[{yu}, yv^(-1)]^2*G[{0, 1}, yw])/64 - 
     (G[{yu}, yv^(-1)]^3*G[{0, 1}, yw])/12 - 
     (G[{0}, yu^(-1)]*G[{1}, yu^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, 1}, yw])/16 - 
     (G[{0}, yv^(-1)]*G[{1}, yu^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, 1}, yw])/16 + 
     (G[{0}, yw]*G[{1}, yu^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, 1}, yw])/16 + 
     (G[{1}, yu^(-1)]^2*G[{1/(yu*yv)}, yw]*G[{0, 1}, yw])/32 - 
     (G[{0}, yu^(-1)]*G[{1}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, 1}, yw])/16 - 
     (G[{0}, yv^(-1)]*G[{1}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, 1}, yw])/16 + 
     (G[{0}, yw]*G[{1}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, 1}, yw])/16 + 
     (G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, 1}, yw])/8 + 
     (3*G[{1}, yv^(-1)]^2*G[{1/(yu*yv)}, yw]*G[{0, 1}, yw])/128 - 
     (G[{0}, yu^(-1)]*G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1}, yw])/16 - 
     (G[{0}, yv^(-1)]*G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1}, yw])/16 + 
     (G[{0}, yw]*G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1}, yw])/16 + 
     (3*G[{1}, yu^(-1)]*G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1}, yw])/16 - 
     (G[{1}, yv^(-1)]*G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1}, yw])/64 + 
     (7*G[{1}, yw]^2*G[{1/(yu*yv)}, yw]*G[{0, 1}, yw])/128 - 
     (G[{1}, yu^(-1)]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1}, yw])/8 + 
     (3*G[{1}, yv^(-1)]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1}, yw])/
      32 + (3*G[{1}, yw]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1}, yw])/
      32 - (7*G[{yu^(-1)}, yw]^2*G[{1/(yu*yv)}, yw]*G[{0, 1}, yw])/64 + 
     (G[{0}, yu^(-1)]*G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, 1}, yw])/8 + 
     (G[{0}, yv^(-1)]*G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, 1}, yw])/8 - 
     (G[{0}, yw]*G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, 1}, yw])/8 - 
     (G[{1}, yu^(-1)]*G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, 1}, yw])/16 - 
     (3*G[{1}, yv^(-1)]*G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, 1}, yw])/
      32 - (3*G[{1}, yw]*G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, 1}, yw])/
      64 + (G[{yu^(-1)}, yw]*G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw]*
       G[{0, 1}, yw])/32 - (3*G[{yu}, yv^(-1)]^2*G[{1/(yu*yv)}, yw]*
       G[{0, 1}, yw])/64 - (G[{1}, yu^(-1)]*G[{yv^(-1)}, yw]*
       G[{1/(yu*yv)}, yw]*G[{0, 1}, yw])/16 + 
     (G[{1}, yv^(-1)]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1}, yw])/16 - 
     (G[{1}, yw]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1}, yw])/16 + 
     (G[{yv^(-1)}, yw]^2*G[{1/(yu*yv)}, yw]*G[{0, 1}, yw])/16 + 
     (G[{1}, yu^(-1)]*G[{1/(yu*yv)}, yw]^2*G[{0, 1}, yw])/16 - 
     (G[{1}, yv^(-1)]*G[{1/(yu*yv)}, yw]^2*G[{0, 1}, yw])/128 + 
     (7*G[{1}, yw]*G[{1/(yu*yv)}, yw]^2*G[{0, 1}, yw])/128 + 
     (G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2*G[{0, 1}, yw])/128 - 
     (7*G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw]^2*G[{0, 1}, yw])/128 - 
     (G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2*G[{0, 1}, yw])/16 + 
     (G[{1}, yu^(-1)]*G[{0, 1}, yu^(-1)]*G[{0, 1}, yw])/16 + 
     (G[{1}, yv^(-1)]*G[{0, 1}, yu^(-1)]*G[{0, 1}, yw])/16 + 
     (G[{1}, yw]*G[{0, 1}, yu^(-1)]*G[{0, 1}, yw])/16 - 
     (G[{yu}, yv^(-1)]*G[{0, 1}, yu^(-1)]*G[{0, 1}, yw])/16 + 
     (G[{1}, yu^(-1)]*G[{0, 1}, yv^(-1)]*G[{0, 1}, yw])/16 + 
     (5*G[{1}, yv^(-1)]*G[{0, 1}, yv^(-1)]*G[{0, 1}, yw])/64 + 
     (G[{1}, yw]*G[{0, 1}, yv^(-1)]*G[{0, 1}, yw])/64 - 
     (G[{yu}, yv^(-1)]*G[{0, 1}, yv^(-1)]*G[{0, 1}, yw])/16 + 
     (3*G[{1/(yu*yv)}, yw]*G[{0, 1}, yv^(-1)]*G[{0, 1}, yw])/64 + 
     (G[{0}, yu^(-1)]*G[{0, 1}, yw]^2)/32 + (G[{0}, yv^(-1)]*G[{0, 1}, yw]^2)/
      32 - (G[{0}, yw]*G[{0, 1}, yw]^2)/32 - 
     (G[{1}, yu^(-1)]*G[{0, 1}, yw]^2)/32 + (G[{1}, yw]*G[{0, 1}, yw]^2)/32 - 
     (G[{yu}, yv^(-1)]*G[{0, 1}, yw]^2)/32 - 
     (G[{1/(yu*yv)}, yw]*G[{0, 1}, yw]^2)/32 - 
     (Pi^2*G[{1}, yu^(-1)]*G[{0, yu^(-1)}, yw])/48 + 
     (G[{0}, yu^(-1)]*G[{1}, yv^(-1)]^2*G[{0, yu^(-1)}, yw])/32 + 
     (G[{0}, yv^(-1)]*G[{1}, yv^(-1)]^2*G[{0, yu^(-1)}, yw])/32 - 
     (G[{0}, yw]*G[{1}, yv^(-1)]^2*G[{0, yu^(-1)}, yw])/32 + 
     (G[{1}, yu^(-1)]*G[{1}, yv^(-1)]^2*G[{0, yu^(-1)}, yw])/32 - 
     (7*G[{1}, yv^(-1)]^3*G[{0, yu^(-1)}, yw])/128 - 
     (Pi^2*G[{1}, yw]*G[{0, yu^(-1)}, yw])/96 - 
     (G[{0}, yu^(-1)]*G[{1}, yv^(-1)]*G[{1}, yw]*G[{0, yu^(-1)}, yw])/16 - 
     (G[{0}, yv^(-1)]*G[{1}, yv^(-1)]*G[{1}, yw]*G[{0, yu^(-1)}, yw])/16 + 
     (G[{0}, yw]*G[{1}, yv^(-1)]*G[{1}, yw]*G[{0, yu^(-1)}, yw])/16 + 
     (G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*G[{1}, yw]*G[{0, yu^(-1)}, yw])/16 + 
     (7*G[{1}, yv^(-1)]^2*G[{1}, yw]*G[{0, yu^(-1)}, yw])/128 - 
     (G[{0}, yu^(-1)]*G[{1}, yw]^2*G[{0, yu^(-1)}, yw])/32 - 
     (G[{0}, yv^(-1)]*G[{1}, yw]^2*G[{0, yu^(-1)}, yw])/32 + 
     (G[{0}, yw]*G[{1}, yw]^2*G[{0, yu^(-1)}, yw])/32 + 
     (G[{1}, yu^(-1)]*G[{1}, yw]^2*G[{0, yu^(-1)}, yw])/32 + 
     (15*G[{1}, yv^(-1)]*G[{1}, yw]^2*G[{0, yu^(-1)}, yw])/128 + 
     (5*G[{1}, yw]^3*G[{0, yu^(-1)}, yw])/128 + 
     (G[{0}, yu^(-1)]*G[{1}, yw]*G[{yu}, yv^(-1)]*G[{0, yu^(-1)}, yw])/16 + 
     (G[{0}, yv^(-1)]*G[{1}, yw]*G[{yu}, yv^(-1)]*G[{0, yu^(-1)}, yw])/16 - 
     (G[{0}, yw]*G[{1}, yw]*G[{yu}, yv^(-1)]*G[{0, yu^(-1)}, yw])/16 - 
     (G[{1}, yu^(-1)]*G[{1}, yw]*G[{yu}, yv^(-1)]*G[{0, yu^(-1)}, yw])/16 - 
     (3*G[{1}, yv^(-1)]*G[{1}, yw]*G[{yu}, yv^(-1)]*G[{0, yu^(-1)}, yw])/32 - 
     (11*G[{1}, yw]^2*G[{yu}, yv^(-1)]*G[{0, yu^(-1)}, yw])/128 + 
     (G[{1}, yw]*G[{yu}, yv^(-1)]^2*G[{0, yu^(-1)}, yw])/64 + 
     (G[{0}, yu^(-1)]*G[{1}, yu^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1)}, yw])/
      16 + (G[{0}, yv^(-1)]*G[{1}, yu^(-1)]*G[{1/(yu*yv)}, yw]*
       G[{0, yu^(-1)}, yw])/16 - (G[{0}, yw]*G[{1}, yu^(-1)]*
       G[{1/(yu*yv)}, yw]*G[{0, yu^(-1)}, yw])/16 - 
     (G[{1}, yu^(-1)]^2*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1)}, yw])/32 - 
     (G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1)}, yw])/
      8 + (5*G[{1}, yv^(-1)]^2*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1)}, yw])/128 + 
     (G[{0}, yu^(-1)]*G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1)}, yw])/16 + 
     (G[{0}, yv^(-1)]*G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1)}, yw])/16 - 
     (G[{0}, yw]*G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1)}, yw])/16 - 
     (3*G[{1}, yu^(-1)]*G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1)}, yw])/
      16 + (G[{1}, yv^(-1)]*G[{1}, yw]*G[{1/(yu*yv)}, yw]*
       G[{0, yu^(-1)}, yw])/64 - (7*G[{1}, yw]^2*G[{1/(yu*yv)}, yw]*
       G[{0, yu^(-1)}, yw])/128 + (G[{1}, yu^(-1)]*G[{yu^(-1)}, yw]*
       G[{1/(yu*yv)}, yw]*G[{0, yu^(-1)}, yw])/8 - 
     (3*G[{1}, yv^(-1)]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*
       G[{0, yu^(-1)}, yw])/32 - (3*G[{1}, yw]*G[{yu^(-1)}, yw]*
       G[{1/(yu*yv)}, yw]*G[{0, yu^(-1)}, yw])/32 + 
     (7*G[{yu^(-1)}, yw]^2*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1)}, yw])/64 - 
     (G[{0}, yu^(-1)]*G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw]*
       G[{0, yu^(-1)}, yw])/16 - (G[{0}, yv^(-1)]*G[{yu}, yv^(-1)]*
       G[{1/(yu*yv)}, yw]*G[{0, yu^(-1)}, yw])/16 + 
     (G[{0}, yw]*G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1)}, yw])/
      16 + (G[{1}, yu^(-1)]*G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw]*
       G[{0, yu^(-1)}, yw])/16 + (3*G[{1}, yv^(-1)]*G[{yu}, yv^(-1)]*
       G[{1/(yu*yv)}, yw]*G[{0, yu^(-1)}, yw])/32 + 
     (3*G[{1}, yw]*G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1)}, yw])/
      64 - (G[{yu^(-1)}, yw]*G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw]*
       G[{0, yu^(-1)}, yw])/32 - (G[{yu}, yv^(-1)]^2*G[{1/(yu*yv)}, yw]*
       G[{0, yu^(-1)}, yw])/64 + (G[{1}, yu^(-1)]*G[{yv^(-1)}, yw]*
       G[{1/(yu*yv)}, yw]*G[{0, yu^(-1)}, yw])/16 - 
     (G[{1}, yv^(-1)]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*
       G[{0, yu^(-1)}, yw])/16 + (G[{1}, yw]*G[{yv^(-1)}, yw]*
       G[{1/(yu*yv)}, yw]*G[{0, yu^(-1)}, yw])/16 - 
     (G[{yv^(-1)}, yw]^2*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1)}, yw])/16 - 
     (G[{1}, yu^(-1)]*G[{1/(yu*yv)}, yw]^2*G[{0, yu^(-1)}, yw])/16 + 
     (G[{1}, yv^(-1)]*G[{1/(yu*yv)}, yw]^2*G[{0, yu^(-1)}, yw])/128 - 
     (7*G[{1}, yw]*G[{1/(yu*yv)}, yw]^2*G[{0, yu^(-1)}, yw])/128 - 
     (G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2*G[{0, yu^(-1)}, yw])/128 + 
     (7*G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw]^2*G[{0, yu^(-1)}, yw])/128 + 
     (G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2*G[{0, yu^(-1)}, yw])/16 - 
     (G[{1}, yu^(-1)]*G[{0, 1}, yu^(-1)]*G[{0, yu^(-1)}, yw])/8 - 
     (G[{0}, yu^(-1)]*G[{0, 1}, yv^(-1)]*G[{0, yu^(-1)}, yw])/16 - 
     (G[{0}, yv^(-1)]*G[{0, 1}, yv^(-1)]*G[{0, yu^(-1)}, yw])/16 + 
     (G[{0}, yw]*G[{0, 1}, yv^(-1)]*G[{0, yu^(-1)}, yw])/16 - 
     (G[{1}, yu^(-1)]*G[{0, 1}, yv^(-1)]*G[{0, yu^(-1)}, yw])/16 + 
     (7*G[{1}, yv^(-1)]*G[{0, 1}, yv^(-1)]*G[{0, yu^(-1)}, yw])/64 + 
     (3*G[{1}, yw]*G[{0, 1}, yv^(-1)]*G[{0, yu^(-1)}, yw])/64 - 
     (3*G[{1/(yu*yv)}, yw]*G[{0, 1}, yv^(-1)]*G[{0, yu^(-1)}, yw])/64 - 
     (G[{0}, yu^(-1)]*G[{0, 1}, yw]*G[{0, yu^(-1)}, yw])/16 - 
     (G[{0}, yv^(-1)]*G[{0, 1}, yw]*G[{0, yu^(-1)}, yw])/16 + 
     (G[{0}, yw]*G[{0, 1}, yw]*G[{0, yu^(-1)}, yw])/16 + 
     (G[{1}, yu^(-1)]*G[{0, 1}, yw]*G[{0, yu^(-1)}, yw])/16 - 
     (G[{1}, yv^(-1)]*G[{0, 1}, yw]*G[{0, yu^(-1)}, yw])/16 - 
     (G[{1}, yw]*G[{0, 1}, yw]*G[{0, yu^(-1)}, yw])/8 + 
     (G[{yu}, yv^(-1)]*G[{0, 1}, yw]*G[{0, yu^(-1)}, yw])/8 + 
     (G[{1/(yu*yv)}, yw]*G[{0, 1}, yw]*G[{0, yu^(-1)}, yw])/16 + 
     (G[{0}, yu^(-1)]*G[{0, yu^(-1)}, yw]^2)/32 + 
     (G[{0}, yv^(-1)]*G[{0, yu^(-1)}, yw]^2)/32 - 
     (G[{0}, yw]*G[{0, yu^(-1)}, yw]^2)/32 - 
     (G[{1}, yu^(-1)]*G[{0, yu^(-1)}, yw]^2)/32 - 
     (G[{1}, yv^(-1)]*G[{0, yu^(-1)}, yw]^2)/32 + 
     (G[{1}, yw]*G[{0, yu^(-1)}, yw]^2)/16 - 
     (G[{1/(yu*yv)}, yw]*G[{0, yu^(-1)}, yw]^2)/32 + 
     (Pi^2*G[{0}, yu^(-1)]*G[{0, yu}, yv^(-1)])/32 + 
     (Pi^2*G[{0}, yv^(-1)]*G[{0, yu}, yv^(-1)])/32 - 
     (Pi^2*G[{0}, yw]*G[{0, yu}, yv^(-1)])/32 + 
     (Pi^2*G[{1}, yu^(-1)]*G[{0, yu}, yv^(-1)])/96 - 
     (G[{0}, yu^(-1)]*G[{1}, yu^(-1)]^2*G[{0, yu}, yv^(-1)])/32 - 
     (G[{0}, yv^(-1)]*G[{1}, yu^(-1)]^2*G[{0, yu}, yv^(-1)])/32 + 
     (G[{0}, yw]*G[{1}, yu^(-1)]^2*G[{0, yu}, yv^(-1)])/32 + 
     (G[{1}, yu^(-1)]^3*G[{0, yu}, yv^(-1)])/32 - 
     (5*Pi^2*G[{1}, yv^(-1)]*G[{0, yu}, yv^(-1)])/768 + 
     (3*G[{0}, yu^(-1)]^2*G[{1}, yv^(-1)]*G[{0, yu}, yv^(-1)])/128 + 
     (3*G[{0}, yu^(-1)]*G[{0}, yv^(-1)]*G[{1}, yv^(-1)]*G[{0, yu}, yv^(-1)])/
      64 + (3*G[{0}, yv^(-1)]^2*G[{1}, yv^(-1)]*G[{0, yu}, yv^(-1)])/128 - 
     (3*G[{0}, yu^(-1)]*G[{0}, yw]*G[{1}, yv^(-1)]*G[{0, yu}, yv^(-1)])/64 - 
     (3*G[{0}, yv^(-1)]*G[{0}, yw]*G[{1}, yv^(-1)]*G[{0, yu}, yv^(-1)])/64 + 
     (3*G[{0}, yw]^2*G[{1}, yv^(-1)]*G[{0, yu}, yv^(-1)])/128 + 
     (G[{0}, yu^(-1)]*G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*G[{0, yu}, yv^(-1)])/
      64 + (G[{0}, yv^(-1)]*G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*
       G[{0, yu}, yv^(-1)])/64 - (G[{0}, yw]*G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*
       G[{0, yu}, yv^(-1)])/64 - (G[{1}, yu^(-1)]^2*G[{1}, yv^(-1)]*
       G[{0, yu}, yv^(-1)])/128 - (5*G[{0}, yu^(-1)]*G[{1}, yv^(-1)]^2*
       G[{0, yu}, yv^(-1)])/64 - (5*G[{0}, yv^(-1)]*G[{1}, yv^(-1)]^2*
       G[{0, yu}, yv^(-1)])/64 + (5*G[{0}, yw]*G[{1}, yv^(-1)]^2*
       G[{0, yu}, yv^(-1)])/64 - (G[{1}, yu^(-1)]*G[{1}, yv^(-1)]^2*
       G[{0, yu}, yv^(-1)])/64 + (13*G[{1}, yv^(-1)]^3*G[{0, yu}, yv^(-1)])/
      192 + (11*Pi^2*G[{1}, yw]*G[{0, yu}, yv^(-1)])/768 + 
     (3*G[{0}, yu^(-1)]^2*G[{1}, yw]*G[{0, yu}, yv^(-1)])/128 + 
     (3*G[{0}, yu^(-1)]*G[{0}, yv^(-1)]*G[{1}, yw]*G[{0, yu}, yv^(-1)])/64 + 
     (3*G[{0}, yv^(-1)]^2*G[{1}, yw]*G[{0, yu}, yv^(-1)])/128 - 
     (3*G[{0}, yu^(-1)]*G[{0}, yw]*G[{1}, yw]*G[{0, yu}, yv^(-1)])/64 - 
     (3*G[{0}, yv^(-1)]*G[{0}, yw]*G[{1}, yw]*G[{0, yu}, yv^(-1)])/64 + 
     (3*G[{0}, yw]^2*G[{1}, yw]*G[{0, yu}, yv^(-1)])/128 + 
     (G[{0}, yu^(-1)]*G[{1}, yu^(-1)]*G[{1}, yw]*G[{0, yu}, yv^(-1)])/64 + 
     (G[{0}, yv^(-1)]*G[{1}, yu^(-1)]*G[{1}, yw]*G[{0, yu}, yv^(-1)])/64 - 
     (G[{0}, yw]*G[{1}, yu^(-1)]*G[{1}, yw]*G[{0, yu}, yv^(-1)])/64 - 
     (5*G[{1}, yu^(-1)]^2*G[{1}, yw]*G[{0, yu}, yv^(-1)])/128 - 
     (G[{0}, yu^(-1)]*G[{1}, yv^(-1)]*G[{1}, yw]*G[{0, yu}, yv^(-1)])/8 - 
     (G[{0}, yv^(-1)]*G[{1}, yv^(-1)]*G[{1}, yw]*G[{0, yu}, yv^(-1)])/8 + 
     (G[{0}, yw]*G[{1}, yv^(-1)]*G[{1}, yw]*G[{0, yu}, yv^(-1)])/8 + 
     (3*G[{1}, yv^(-1)]^2*G[{1}, yw]*G[{0, yu}, yv^(-1)])/64 - 
     (3*G[{0}, yu^(-1)]*G[{1}, yw]^2*G[{0, yu}, yv^(-1)])/64 - 
     (3*G[{0}, yv^(-1)]*G[{1}, yw]^2*G[{0, yu}, yv^(-1)])/64 + 
     (3*G[{0}, yw]*G[{1}, yw]^2*G[{0, yu}, yv^(-1)])/64 + 
     (3*G[{1}, yu^(-1)]*G[{1}, yw]^2*G[{0, yu}, yv^(-1)])/64 - 
     (5*G[{1}, yv^(-1)]*G[{1}, yw]^2*G[{0, yu}, yv^(-1)])/128 - 
     (11*G[{1}, yw]^3*G[{0, yu}, yv^(-1)])/384 + 
     (G[{0}, yu^(-1)]*G[{1}, yw]*G[{yu}, yv^(-1)]*G[{0, yu}, yv^(-1)])/16 + 
     (G[{0}, yv^(-1)]*G[{1}, yw]*G[{yu}, yv^(-1)]*G[{0, yu}, yv^(-1)])/16 - 
     (G[{0}, yw]*G[{1}, yw]*G[{yu}, yv^(-1)]*G[{0, yu}, yv^(-1)])/16 + 
     (G[{1}, yv^(-1)]*G[{1}, yw]*G[{yu}, yv^(-1)]*G[{0, yu}, yv^(-1)])/32 + 
     (9*G[{1}, yw]^2*G[{yu}, yv^(-1)]*G[{0, yu}, yv^(-1)])/128 - 
     (G[{1}, yw]*G[{yu}, yv^(-1)]^2*G[{0, yu}, yv^(-1)])/16 + 
     (5*Pi^2*G[{1/(yu*yv)}, yw]*G[{0, yu}, yv^(-1)])/768 - 
     (3*G[{0}, yu^(-1)]^2*G[{1/(yu*yv)}, yw]*G[{0, yu}, yv^(-1)])/128 - 
     (3*G[{0}, yu^(-1)]*G[{0}, yv^(-1)]*G[{1/(yu*yv)}, yw]*
       G[{0, yu}, yv^(-1)])/64 - (3*G[{0}, yv^(-1)]^2*G[{1/(yu*yv)}, yw]*
       G[{0, yu}, yv^(-1)])/128 + (3*G[{0}, yu^(-1)]*G[{0}, yw]*
       G[{1/(yu*yv)}, yw]*G[{0, yu}, yv^(-1)])/64 + 
     (3*G[{0}, yv^(-1)]*G[{0}, yw]*G[{1/(yu*yv)}, yw]*G[{0, yu}, yv^(-1)])/
      64 - (3*G[{0}, yw]^2*G[{1/(yu*yv)}, yw]*G[{0, yu}, yv^(-1)])/128 - 
     (G[{0}, yu^(-1)]*G[{1}, yu^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, yu}, yv^(-1)])/
      64 - (G[{0}, yv^(-1)]*G[{1}, yu^(-1)]*G[{1/(yu*yv)}, yw]*
       G[{0, yu}, yv^(-1)])/64 + (G[{0}, yw]*G[{1}, yu^(-1)]*
       G[{1/(yu*yv)}, yw]*G[{0, yu}, yv^(-1)])/64 + 
     (G[{1}, yu^(-1)]^2*G[{1/(yu*yv)}, yw]*G[{0, yu}, yv^(-1)])/128 + 
     (5*G[{0}, yu^(-1)]*G[{1}, yv^(-1)]*G[{1/(yu*yv)}, yw]*
       G[{0, yu}, yv^(-1)])/32 + (5*G[{0}, yv^(-1)]*G[{1}, yv^(-1)]*
       G[{1/(yu*yv)}, yw]*G[{0, yu}, yv^(-1)])/32 - 
     (5*G[{0}, yw]*G[{1}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, yu}, yv^(-1)])/
      32 + (G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*G[{1/(yu*yv)}, yw]*
       G[{0, yu}, yv^(-1)])/32 - (13*G[{1}, yv^(-1)]^2*G[{1/(yu*yv)}, yw]*
       G[{0, yu}, yv^(-1)])/64 + (G[{0}, yu^(-1)]*G[{1}, yw]*
       G[{1/(yu*yv)}, yw]*G[{0, yu}, yv^(-1)])/16 + 
     (G[{0}, yv^(-1)]*G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{0, yu}, yv^(-1)])/16 - 
     (G[{0}, yw]*G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{0, yu}, yv^(-1)])/16 + 
     (G[{1}, yu^(-1)]*G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{0, yu}, yv^(-1)])/16 - 
     (G[{1}, yv^(-1)]*G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{0, yu}, yv^(-1)])/64 + 
     (11*G[{1}, yw]^2*G[{1/(yu*yv)}, yw]*G[{0, yu}, yv^(-1)])/128 - 
     (G[{0}, yu^(-1)]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*
       G[{0, yu}, yv^(-1)])/16 - (G[{0}, yv^(-1)]*G[{yu^(-1)}, yw]*
       G[{1/(yu*yv)}, yw]*G[{0, yu}, yv^(-1)])/16 + 
     (G[{0}, yw]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{0, yu}, yv^(-1)])/
      16 - (G[{1}, yu^(-1)]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*
       G[{0, yu}, yv^(-1)])/16 + (17*G[{1}, yv^(-1)]*G[{yu^(-1)}, yw]*
       G[{1/(yu*yv)}, yw]*G[{0, yu}, yv^(-1)])/64 + 
     (5*G[{1}, yw]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{0, yu}, yv^(-1)])/
      64 - (3*G[{yu^(-1)}, yw]^2*G[{1/(yu*yv)}, yw]*G[{0, yu}, yv^(-1)])/32 - 
     (G[{0}, yu^(-1)]*G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw]*
       G[{0, yu}, yv^(-1)])/16 - (G[{0}, yv^(-1)]*G[{yu}, yv^(-1)]*
       G[{1/(yu*yv)}, yw]*G[{0, yu}, yv^(-1)])/16 + 
     (G[{0}, yw]*G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, yu}, yv^(-1)])/
      16 - (G[{1}, yv^(-1)]*G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw]*
       G[{0, yu}, yv^(-1)])/32 - (9*G[{1}, yw]*G[{yu}, yv^(-1)]*
       G[{1/(yu*yv)}, yw]*G[{0, yu}, yv^(-1)])/64 + 
     (G[{yu}, yv^(-1)]^2*G[{1/(yu*yv)}, yw]*G[{0, yu}, yv^(-1)])/16 + 
     (G[{0}, yu^(-1)]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*
       G[{0, yu}, yv^(-1)])/16 + (G[{0}, yv^(-1)]*G[{yv^(-1)}, yw]*
       G[{1/(yu*yv)}, yw]*G[{0, yu}, yv^(-1)])/16 - 
     (G[{0}, yw]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{0, yu}, yv^(-1)])/
      16 - (G[{1}, yu^(-1)]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*
       G[{0, yu}, yv^(-1)])/16 - (5*G[{1}, yv^(-1)]*G[{yv^(-1)}, yw]*
       G[{1/(yu*yv)}, yw]*G[{0, yu}, yv^(-1)])/64 - 
     (G[{1}, yw]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{0, yu}, yv^(-1)])/
      64 + (G[{yu^(-1)}, yw]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*
       G[{0, yu}, yv^(-1)])/16 + (G[{yv^(-1)}, yw]^2*G[{1/(yu*yv)}, yw]*
       G[{0, yu}, yv^(-1)])/32 - (3*G[{0}, yu^(-1)]*G[{1/(yu*yv)}, yw]^2*
       G[{0, yu}, yv^(-1)])/64 - (3*G[{0}, yv^(-1)]*G[{1/(yu*yv)}, yw]^2*
       G[{0, yu}, yv^(-1)])/64 + (3*G[{0}, yw]*G[{1/(yu*yv)}, yw]^2*
       G[{0, yu}, yv^(-1)])/64 + (G[{1}, yu^(-1)]*G[{1/(yu*yv)}, yw]^2*
       G[{0, yu}, yv^(-1)])/64 + (9*G[{1}, yv^(-1)]*G[{1/(yu*yv)}, yw]^2*
       G[{0, yu}, yv^(-1)])/128 - (G[{1}, yw]*G[{1/(yu*yv)}, yw]^2*
       G[{0, yu}, yv^(-1)])/128 - (9*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2*
       G[{0, yu}, yv^(-1)])/128 + (G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw]^2*
       G[{0, yu}, yv^(-1)])/128 - (G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2*
       G[{0, yu}, yv^(-1)])/64 + (G[{0}, yu^(-1)]*G[{0, 1}, yu^(-1)]*
       G[{0, yu}, yv^(-1)])/16 + (G[{0}, yv^(-1)]*G[{0, 1}, yu^(-1)]*
       G[{0, yu}, yv^(-1)])/16 - (G[{0}, yw]*G[{0, 1}, yu^(-1)]*
       G[{0, yu}, yv^(-1)])/16 + (G[{1}, yu^(-1)]*G[{0, 1}, yu^(-1)]*
       G[{0, yu}, yv^(-1)])/16 + (G[{1}, yw]*G[{0, 1}, yu^(-1)]*
       G[{0, yu}, yv^(-1)])/16 + (G[{0}, yu^(-1)]*G[{0, 1}, yv^(-1)]*
       G[{0, yu}, yv^(-1)])/16 + (G[{0}, yv^(-1)]*G[{0, 1}, yv^(-1)]*
       G[{0, yu}, yv^(-1)])/16 - (G[{0}, yw]*G[{0, 1}, yv^(-1)]*
       G[{0, yu}, yv^(-1)])/16 - (G[{1}, yv^(-1)]*G[{0, 1}, yv^(-1)]*
       G[{0, yu}, yv^(-1)])/64 + (3*G[{1}, yw]*G[{0, 1}, yv^(-1)]*
       G[{0, yu}, yv^(-1)])/64 + (G[{1/(yu*yv)}, yw]*G[{0, 1}, yv^(-1)]*
       G[{0, yu}, yv^(-1)])/64 - (G[{1}, yu^(-1)]*G[{0, 1}, yw]*
       G[{0, yu}, yv^(-1)])/16 - (5*G[{1}, yv^(-1)]*G[{0, 1}, yw]*
       G[{0, yu}, yv^(-1)])/64 - (G[{1}, yw]*G[{0, 1}, yw]*
       G[{0, yu}, yv^(-1)])/64 + (G[{yu}, yv^(-1)]*G[{0, 1}, yw]*
       G[{0, yu}, yv^(-1)])/16 - (3*G[{1/(yu*yv)}, yw]*G[{0, 1}, yw]*
       G[{0, yu}, yv^(-1)])/64 + (G[{0}, yu^(-1)]*G[{0, yu^(-1)}, yw]*
       G[{0, yu}, yv^(-1)])/16 + (G[{0}, yv^(-1)]*G[{0, yu^(-1)}, yw]*
       G[{0, yu}, yv^(-1)])/16 - (G[{0}, yw]*G[{0, yu^(-1)}, yw]*
       G[{0, yu}, yv^(-1)])/16 + (G[{1}, yu^(-1)]*G[{0, yu^(-1)}, yw]*
       G[{0, yu}, yv^(-1)])/16 - (7*G[{1}, yv^(-1)]*G[{0, yu^(-1)}, yw]*
       G[{0, yu}, yv^(-1)])/64 - (3*G[{1}, yw]*G[{0, yu^(-1)}, yw]*
       G[{0, yu}, yv^(-1)])/64 + (3*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1)}, yw]*
       G[{0, yu}, yv^(-1)])/64 - (G[{0}, yu^(-1)]*G[{0, yu}, yv^(-1)]^2)/32 - 
     (G[{0}, yv^(-1)]*G[{0, yu}, yv^(-1)]^2)/32 + 
     (G[{0}, yw]*G[{0, yu}, yv^(-1)]^2)/32 + 
     (G[{1}, yv^(-1)]*G[{0, yu}, yv^(-1)]^2)/128 - 
     (3*G[{1}, yw]*G[{0, yu}, yv^(-1)]^2)/128 - 
     (G[{1/(yu*yv)}, yw]*G[{0, yu}, yv^(-1)]^2)/128 + 
     (Pi^2*G[{0}, yu^(-1)]*G[{0, yv^(-1)}, yw])/96 + 
     (Pi^2*G[{0}, yv^(-1)]*G[{0, yv^(-1)}, yw])/96 - 
     (Pi^2*G[{0}, yw]*G[{0, yv^(-1)}, yw])/96 + 
     (Pi^2*G[{1}, yu^(-1)]*G[{0, yv^(-1)}, yw])/48 - 
     (G[{0}, yu^(-1)]*G[{1}, yu^(-1)]^2*G[{0, yv^(-1)}, yw])/32 - 
     (G[{0}, yv^(-1)]*G[{1}, yu^(-1)]^2*G[{0, yv^(-1)}, yw])/32 + 
     (G[{0}, yw]*G[{1}, yu^(-1)]^2*G[{0, yv^(-1)}, yw])/32 + 
     (G[{1}, yu^(-1)]^3*G[{0, yv^(-1)}, yw])/32 - 
     (Pi^2*G[{1}, yv^(-1)]*G[{0, yv^(-1)}, yw])/24 + 
     (G[{0}, yu^(-1)]*G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*G[{0, yv^(-1)}, yw])/
      16 + (G[{0}, yv^(-1)]*G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*
       G[{0, yv^(-1)}, yw])/16 - (G[{0}, yw]*G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*
       G[{0, yv^(-1)}, yw])/16 - (G[{1}, yu^(-1)]^2*G[{1}, yv^(-1)]*
       G[{0, yv^(-1)}, yw])/32 - (G[{0}, yu^(-1)]*G[{1}, yv^(-1)]^2*
       G[{0, yv^(-1)}, yw])/16 - (G[{0}, yv^(-1)]*G[{1}, yv^(-1)]^2*
       G[{0, yv^(-1)}, yw])/16 + (G[{0}, yw]*G[{1}, yv^(-1)]^2*
       G[{0, yv^(-1)}, yw])/16 + (5*G[{1}, yv^(-1)]^3*G[{0, yv^(-1)}, yw])/
      128 - (Pi^2*G[{1}, yw]*G[{0, yv^(-1)}, yw])/32 + 
     (G[{0}, yu^(-1)]*G[{1}, yu^(-1)]*G[{1}, yw]*G[{0, yv^(-1)}, yw])/16 + 
     (G[{0}, yv^(-1)]*G[{1}, yu^(-1)]*G[{1}, yw]*G[{0, yv^(-1)}, yw])/16 - 
     (G[{0}, yw]*G[{1}, yu^(-1)]*G[{1}, yw]*G[{0, yv^(-1)}, yw])/16 - 
     (G[{1}, yu^(-1)]^2*G[{1}, yw]*G[{0, yv^(-1)}, yw])/16 - 
     (G[{0}, yu^(-1)]*G[{1}, yv^(-1)]*G[{1}, yw]*G[{0, yv^(-1)}, yw])/8 - 
     (G[{0}, yv^(-1)]*G[{1}, yv^(-1)]*G[{1}, yw]*G[{0, yv^(-1)}, yw])/8 + 
     (G[{0}, yw]*G[{1}, yv^(-1)]*G[{1}, yw]*G[{0, yv^(-1)}, yw])/8 + 
     (G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*G[{1}, yw]*G[{0, yv^(-1)}, yw])/16 + 
     (15*G[{1}, yv^(-1)]^2*G[{1}, yw]*G[{0, yv^(-1)}, yw])/128 - 
     (G[{0}, yu^(-1)]*G[{1}, yw]^2*G[{0, yv^(-1)}, yw])/32 - 
     (G[{0}, yv^(-1)]*G[{1}, yw]^2*G[{0, yv^(-1)}, yw])/32 + 
     (G[{0}, yw]*G[{1}, yw]^2*G[{0, yv^(-1)}, yw])/32 + 
     (G[{1}, yu^(-1)]*G[{1}, yw]^2*G[{0, yv^(-1)}, yw])/32 + 
     (15*G[{1}, yv^(-1)]*G[{1}, yw]^2*G[{0, yv^(-1)}, yw])/128 + 
     (5*G[{1}, yw]^3*G[{0, yv^(-1)}, yw])/128 + 
     (G[{0}, yu^(-1)]*G[{1}, yw]*G[{yu}, yv^(-1)]*G[{0, yv^(-1)}, yw])/16 + 
     (G[{0}, yv^(-1)]*G[{1}, yw]*G[{yu}, yv^(-1)]*G[{0, yv^(-1)}, yw])/16 - 
     (G[{0}, yw]*G[{1}, yw]*G[{yu}, yv^(-1)]*G[{0, yv^(-1)}, yw])/16 - 
     (G[{1}, yu^(-1)]*G[{1}, yw]*G[{yu}, yv^(-1)]*G[{0, yv^(-1)}, yw])/16 - 
     (3*G[{1}, yv^(-1)]*G[{1}, yw]*G[{yu}, yv^(-1)]*G[{0, yv^(-1)}, yw])/32 - 
     (11*G[{1}, yw]^2*G[{yu}, yv^(-1)]*G[{0, yv^(-1)}, yw])/128 + 
     (G[{1}, yw]*G[{yu}, yv^(-1)]^2*G[{0, yv^(-1)}, yw])/64 + 
     (G[{1}, yu^(-1)]^2*G[{1/(yu*yv)}, yw]*G[{0, yv^(-1)}, yw])/32 + 
     (G[{0}, yu^(-1)]*G[{1}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, yv^(-1)}, yw])/
      16 + (G[{0}, yv^(-1)]*G[{1}, yv^(-1)]*G[{1/(yu*yv)}, yw]*
       G[{0, yv^(-1)}, yw])/16 - (G[{0}, yw]*G[{1}, yv^(-1)]*
       G[{1/(yu*yv)}, yw]*G[{0, yv^(-1)}, yw])/16 - 
     (G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, yv^(-1)}, yw])/
      8 - (3*G[{1}, yv^(-1)]^2*G[{1/(yu*yv)}, yw]*G[{0, yv^(-1)}, yw])/128 + 
     (G[{0}, yu^(-1)]*G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{0, yv^(-1)}, yw])/16 + 
     (G[{0}, yv^(-1)]*G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{0, yv^(-1)}, yw])/16 - 
     (G[{0}, yw]*G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{0, yv^(-1)}, yw])/16 - 
     (3*G[{1}, yu^(-1)]*G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{0, yv^(-1)}, yw])/
      16 + (G[{1}, yv^(-1)]*G[{1}, yw]*G[{1/(yu*yv)}, yw]*
       G[{0, yv^(-1)}, yw])/64 - (7*G[{1}, yw]^2*G[{1/(yu*yv)}, yw]*
       G[{0, yv^(-1)}, yw])/128 + (G[{1}, yu^(-1)]*G[{yu^(-1)}, yw]*
       G[{1/(yu*yv)}, yw]*G[{0, yv^(-1)}, yw])/8 - 
     (3*G[{1}, yv^(-1)]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*
       G[{0, yv^(-1)}, yw])/32 - (3*G[{1}, yw]*G[{yu^(-1)}, yw]*
       G[{1/(yu*yv)}, yw]*G[{0, yv^(-1)}, yw])/32 + 
     (7*G[{yu^(-1)}, yw]^2*G[{1/(yu*yv)}, yw]*G[{0, yv^(-1)}, yw])/64 - 
     (G[{0}, yu^(-1)]*G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw]*
       G[{0, yv^(-1)}, yw])/16 - (G[{0}, yv^(-1)]*G[{yu}, yv^(-1)]*
       G[{1/(yu*yv)}, yw]*G[{0, yv^(-1)}, yw])/16 + 
     (G[{0}, yw]*G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, yv^(-1)}, yw])/
      16 + (G[{1}, yu^(-1)]*G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw]*
       G[{0, yv^(-1)}, yw])/16 + (3*G[{1}, yv^(-1)]*G[{yu}, yv^(-1)]*
       G[{1/(yu*yv)}, yw]*G[{0, yv^(-1)}, yw])/32 + 
     (3*G[{1}, yw]*G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, yv^(-1)}, yw])/
      64 - (G[{yu^(-1)}, yw]*G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw]*
       G[{0, yv^(-1)}, yw])/32 - (G[{yu}, yv^(-1)]^2*G[{1/(yu*yv)}, yw]*
       G[{0, yv^(-1)}, yw])/64 + (G[{1}, yu^(-1)]*G[{yv^(-1)}, yw]*
       G[{1/(yu*yv)}, yw]*G[{0, yv^(-1)}, yw])/16 - 
     (G[{1}, yv^(-1)]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*
       G[{0, yv^(-1)}, yw])/16 + (G[{1}, yw]*G[{yv^(-1)}, yw]*
       G[{1/(yu*yv)}, yw]*G[{0, yv^(-1)}, yw])/16 - 
     (G[{yv^(-1)}, yw]^2*G[{1/(yu*yv)}, yw]*G[{0, yv^(-1)}, yw])/16 - 
     (G[{1}, yu^(-1)]*G[{1/(yu*yv)}, yw]^2*G[{0, yv^(-1)}, yw])/16 + 
     (G[{1}, yv^(-1)]*G[{1/(yu*yv)}, yw]^2*G[{0, yv^(-1)}, yw])/128 - 
     (7*G[{1}, yw]*G[{1/(yu*yv)}, yw]^2*G[{0, yv^(-1)}, yw])/128 - 
     (G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2*G[{0, yv^(-1)}, yw])/128 + 
     (7*G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw]^2*G[{0, yv^(-1)}, yw])/128 + 
     (G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2*G[{0, yv^(-1)}, yw])/16 + 
     (G[{1}, yu^(-1)]*G[{0, 1}, yu^(-1)]*G[{0, yv^(-1)}, yw])/16 - 
     (G[{1}, yv^(-1)]*G[{0, 1}, yu^(-1)]*G[{0, yv^(-1)}, yw])/16 - 
     (G[{1}, yw]*G[{0, 1}, yu^(-1)]*G[{0, yv^(-1)}, yw])/8 + 
     (G[{0}, yu^(-1)]*G[{0, 1}, yv^(-1)]*G[{0, yv^(-1)}, yw])/16 + 
     (G[{0}, yv^(-1)]*G[{0, 1}, yv^(-1)]*G[{0, yv^(-1)}, yw])/16 - 
     (G[{0}, yw]*G[{0, 1}, yv^(-1)]*G[{0, yv^(-1)}, yw])/16 - 
     (G[{1}, yu^(-1)]*G[{0, 1}, yv^(-1)]*G[{0, yv^(-1)}, yw])/16 - 
     (5*G[{1}, yv^(-1)]*G[{0, 1}, yv^(-1)]*G[{0, yv^(-1)}, yw])/64 - 
     (5*G[{1}, yw]*G[{0, 1}, yv^(-1)]*G[{0, yv^(-1)}, yw])/64 - 
     (3*G[{1/(yu*yv)}, yw]*G[{0, 1}, yv^(-1)]*G[{0, yv^(-1)}, yw])/64 + 
     (G[{1}, yu^(-1)]*G[{0, 1}, yw]*G[{0, yv^(-1)}, yw])/16 - 
     (G[{1}, yv^(-1)]*G[{0, 1}, yw]*G[{0, yv^(-1)}, yw])/16 + 
     (G[{1/(yu*yv)}, yw]*G[{0, 1}, yw]*G[{0, yv^(-1)}, yw])/16 - 
     (G[{1}, yu^(-1)]*G[{0, yu^(-1)}, yw]*G[{0, yv^(-1)}, yw])/16 + 
     (G[{1}, yv^(-1)]*G[{0, yu^(-1)}, yw]*G[{0, yv^(-1)}, yw])/16 - 
     (G[{1/(yu*yv)}, yw]*G[{0, yu^(-1)}, yw]*G[{0, yv^(-1)}, yw])/16 - 
     (G[{0}, yu^(-1)]*G[{0, yu}, yv^(-1)]*G[{0, yv^(-1)}, yw])/16 - 
     (G[{0}, yv^(-1)]*G[{0, yu}, yv^(-1)]*G[{0, yv^(-1)}, yw])/16 + 
     (G[{0}, yw]*G[{0, yu}, yv^(-1)]*G[{0, yv^(-1)}, yw])/16 + 
     (G[{1}, yu^(-1)]*G[{0, yu}, yv^(-1)]*G[{0, yv^(-1)}, yw])/16 + 
     (5*G[{1}, yv^(-1)]*G[{0, yu}, yv^(-1)]*G[{0, yv^(-1)}, yw])/64 + 
     (5*G[{1}, yw]*G[{0, yu}, yv^(-1)]*G[{0, yv^(-1)}, yw])/64 + 
     (3*G[{1/(yu*yv)}, yw]*G[{0, yu}, yv^(-1)]*G[{0, yv^(-1)}, yw])/64 - 
     (G[{1}, yu^(-1)]*G[{0, yv^(-1)}, yw]^2)/32 + 
     (G[{1}, yv^(-1)]*G[{0, yv^(-1)}, yw]^2)/32 - 
     (G[{1/(yu*yv)}, yw]*G[{0, yv^(-1)}, yw]^2)/32 - 
     (Pi^2*G[{0}, yu^(-1)]*G[{0, 1/(yu*yv)}, yw])/96 - 
     (Pi^2*G[{0}, yv^(-1)]*G[{0, 1/(yu*yv)}, yw])/96 + 
     (Pi^2*G[{0}, yw]*G[{0, 1/(yu*yv)}, yw])/96 - 
     (Pi^2*G[{1}, yu^(-1)]*G[{0, 1/(yu*yv)}, yw])/96 + 
     (G[{0}, yu^(-1)]*G[{1}, yu^(-1)]^2*G[{0, 1/(yu*yv)}, yw])/32 + 
     (G[{0}, yv^(-1)]*G[{1}, yu^(-1)]^2*G[{0, 1/(yu*yv)}, yw])/32 - 
     (G[{0}, yw]*G[{1}, yu^(-1)]^2*G[{0, 1/(yu*yv)}, yw])/32 - 
     (G[{1}, yu^(-1)]^3*G[{0, 1/(yu*yv)}, yw])/32 - 
     (G[{0}, yu^(-1)]*G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*G[{0, 1/(yu*yv)}, yw])/
      16 - (G[{0}, yv^(-1)]*G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*
       G[{0, 1/(yu*yv)}, yw])/16 + (G[{0}, yw]*G[{1}, yu^(-1)]*
       G[{1}, yv^(-1)]*G[{0, 1/(yu*yv)}, yw])/16 + 
     (G[{1}, yu^(-1)]^2*G[{1}, yv^(-1)]*G[{0, 1/(yu*yv)}, yw])/16 - 
     (G[{0}, yu^(-1)]*G[{1}, yv^(-1)]^2*G[{0, 1/(yu*yv)}, yw])/32 - 
     (G[{0}, yv^(-1)]*G[{1}, yv^(-1)]^2*G[{0, 1/(yu*yv)}, yw])/32 + 
     (G[{0}, yw]*G[{1}, yv^(-1)]^2*G[{0, 1/(yu*yv)}, yw])/32 - 
     (G[{1}, yu^(-1)]*G[{1}, yv^(-1)]^2*G[{0, 1/(yu*yv)}, yw])/32 + 
     (7*G[{1}, yv^(-1)]^3*G[{0, 1/(yu*yv)}, yw])/128 + 
     (Pi^2*G[{1}, yw]*G[{0, 1/(yu*yv)}, yw])/48 - 
     (G[{0}, yu^(-1)]*G[{1}, yu^(-1)]*G[{1}, yw]*G[{0, 1/(yu*yv)}, yw])/16 - 
     (G[{0}, yv^(-1)]*G[{1}, yu^(-1)]*G[{1}, yw]*G[{0, 1/(yu*yv)}, yw])/16 + 
     (G[{0}, yw]*G[{1}, yu^(-1)]*G[{1}, yw]*G[{0, 1/(yu*yv)}, yw])/16 + 
     (G[{1}, yu^(-1)]^2*G[{1}, yw]*G[{0, 1/(yu*yv)}, yw])/16 + 
     (G[{0}, yu^(-1)]*G[{1}, yv^(-1)]*G[{1}, yw]*G[{0, 1/(yu*yv)}, yw])/16 + 
     (G[{0}, yv^(-1)]*G[{1}, yv^(-1)]*G[{1}, yw]*G[{0, 1/(yu*yv)}, yw])/16 - 
     (G[{0}, yw]*G[{1}, yv^(-1)]*G[{1}, yw]*G[{0, 1/(yu*yv)}, yw])/16 - 
     (G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*G[{1}, yw]*G[{0, 1/(yu*yv)}, yw])/16 - 
     (7*G[{1}, yv^(-1)]^2*G[{1}, yw]*G[{0, 1/(yu*yv)}, yw])/128 + 
     (G[{0}, yu^(-1)]*G[{1}, yw]^2*G[{0, 1/(yu*yv)}, yw])/32 + 
     (G[{0}, yv^(-1)]*G[{1}, yw]^2*G[{0, 1/(yu*yv)}, yw])/32 - 
     (G[{0}, yw]*G[{1}, yw]^2*G[{0, 1/(yu*yv)}, yw])/32 - 
     (G[{1}, yu^(-1)]*G[{1}, yw]^2*G[{0, 1/(yu*yv)}, yw])/32 - 
     (15*G[{1}, yv^(-1)]*G[{1}, yw]^2*G[{0, 1/(yu*yv)}, yw])/128 - 
     (5*G[{1}, yw]^3*G[{0, 1/(yu*yv)}, yw])/128 + 
     (Pi^2*G[{yu}, yv^(-1)]*G[{0, 1/(yu*yv)}, yw])/24 - 
     (G[{1}, yu^(-1)]^2*G[{yu}, yv^(-1)]*G[{0, 1/(yu*yv)}, yw])/32 + 
     (G[{0}, yu^(-1)]*G[{1}, yv^(-1)]*G[{yu}, yv^(-1)]*G[{0, 1/(yu*yv)}, yw])/
      8 + (G[{0}, yv^(-1)]*G[{1}, yv^(-1)]*G[{yu}, yv^(-1)]*
       G[{0, 1/(yu*yv)}, yw])/8 - (G[{0}, yw]*G[{1}, yv^(-1)]*
       G[{yu}, yv^(-1)]*G[{0, 1/(yu*yv)}, yw])/8 + 
     (G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*G[{yu}, yv^(-1)]*G[{0, 1/(yu*yv)}, yw])/
      16 - (G[{1}, yv^(-1)]^2*G[{yu}, yv^(-1)]*G[{0, 1/(yu*yv)}, yw])/32 + 
     (G[{1}, yu^(-1)]*G[{1}, yw]*G[{yu}, yv^(-1)]*G[{0, 1/(yu*yv)}, yw])/16 + 
     (3*G[{1}, yv^(-1)]*G[{1}, yw]*G[{yu}, yv^(-1)]*G[{0, 1/(yu*yv)}, yw])/
      32 + (11*G[{1}, yw]^2*G[{yu}, yv^(-1)]*G[{0, 1/(yu*yv)}, yw])/128 - 
     (G[{0}, yu^(-1)]*G[{yu}, yv^(-1)]^2*G[{0, 1/(yu*yv)}, yw])/16 - 
     (G[{0}, yv^(-1)]*G[{yu}, yv^(-1)]^2*G[{0, 1/(yu*yv)}, yw])/16 + 
     (G[{0}, yw]*G[{yu}, yv^(-1)]^2*G[{0, 1/(yu*yv)}, yw])/16 - 
     (G[{1}, yv^(-1)]*G[{yu}, yv^(-1)]^2*G[{0, 1/(yu*yv)}, yw])/8 - 
     (5*G[{1}, yw]*G[{yu}, yv^(-1)]^2*G[{0, 1/(yu*yv)}, yw])/64 + 
     (G[{yu}, yv^(-1)]^3*G[{0, 1/(yu*yv)}, yw])/12 - 
     (G[{1}, yu^(-1)]^2*G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv)}, yw])/32 + 
     (G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*G[{1/(yu*yv)}, yw]*
       G[{0, 1/(yu*yv)}, yw])/8 - (5*G[{1}, yv^(-1)]^2*G[{1/(yu*yv)}, yw]*
       G[{0, 1/(yu*yv)}, yw])/128 - (G[{0}, yu^(-1)]*G[{1}, yw]*
       G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv)}, yw])/16 - 
     (G[{0}, yv^(-1)]*G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv)}, yw])/
      16 + (G[{0}, yw]*G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv)}, yw])/
      16 + (3*G[{1}, yu^(-1)]*G[{1}, yw]*G[{1/(yu*yv)}, yw]*
       G[{0, 1/(yu*yv)}, yw])/16 - (G[{1}, yv^(-1)]*G[{1}, yw]*
       G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv)}, yw])/64 + 
     (7*G[{1}, yw]^2*G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv)}, yw])/128 - 
     (G[{1}, yu^(-1)]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*
       G[{0, 1/(yu*yv)}, yw])/8 + (3*G[{1}, yv^(-1)]*G[{yu^(-1)}, yw]*
       G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv)}, yw])/32 + 
     (3*G[{1}, yw]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv)}, yw])/
      32 - (7*G[{yu^(-1)}, yw]^2*G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv)}, yw])/
      64 - (G[{1}, yu^(-1)]*G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw]*
       G[{0, 1/(yu*yv)}, yw])/16 - (3*G[{1}, yv^(-1)]*G[{yu}, yv^(-1)]*
       G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv)}, yw])/32 - 
     (3*G[{1}, yw]*G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv)}, yw])/
      64 + (G[{yu^(-1)}, yw]*G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw]*
       G[{0, 1/(yu*yv)}, yw])/32 + (5*G[{yu}, yv^(-1)]^2*G[{1/(yu*yv)}, yw]*
       G[{0, 1/(yu*yv)}, yw])/64 - (G[{1}, yu^(-1)]*G[{yv^(-1)}, yw]*
       G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv)}, yw])/16 + 
     (G[{1}, yv^(-1)]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*
       G[{0, 1/(yu*yv)}, yw])/16 - (G[{1}, yw]*G[{yv^(-1)}, yw]*
       G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv)}, yw])/16 + 
     (G[{yv^(-1)}, yw]^2*G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv)}, yw])/16 + 
     (G[{1}, yu^(-1)]*G[{1/(yu*yv)}, yw]^2*G[{0, 1/(yu*yv)}, yw])/16 - 
     (G[{1}, yv^(-1)]*G[{1/(yu*yv)}, yw]^2*G[{0, 1/(yu*yv)}, yw])/128 + 
     (7*G[{1}, yw]*G[{1/(yu*yv)}, yw]^2*G[{0, 1/(yu*yv)}, yw])/128 + 
     (G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2*G[{0, 1/(yu*yv)}, yw])/128 - 
     (7*G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw]^2*G[{0, 1/(yu*yv)}, yw])/128 - 
     (G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2*G[{0, 1/(yu*yv)}, yw])/16 + 
     (G[{1}, yw]*G[{0, 1}, yu^(-1)]*G[{0, 1/(yu*yv)}, yw])/16 + 
     (G[{yu}, yv^(-1)]*G[{0, 1}, yu^(-1)]*G[{0, 1/(yu*yv)}, yw])/16 + 
     (G[{1}, yu^(-1)]*G[{0, 1}, yv^(-1)]*G[{0, 1/(yu*yv)}, yw])/16 - 
     (7*G[{1}, yv^(-1)]*G[{0, 1}, yv^(-1)]*G[{0, 1/(yu*yv)}, yw])/64 + 
     (G[{1}, yw]*G[{0, 1}, yv^(-1)]*G[{0, 1/(yu*yv)}, yw])/64 + 
     (G[{yu}, yv^(-1)]*G[{0, 1}, yv^(-1)]*G[{0, 1/(yu*yv)}, yw])/16 + 
     (3*G[{1/(yu*yv)}, yw]*G[{0, 1}, yv^(-1)]*G[{0, 1/(yu*yv)}, yw])/64 - 
     (G[{1}, yu^(-1)]*G[{0, 1}, yw]*G[{0, 1/(yu*yv)}, yw])/16 + 
     (G[{1}, yv^(-1)]*G[{0, 1}, yw]*G[{0, 1/(yu*yv)}, yw])/8 + 
     (G[{1}, yw]*G[{0, 1}, yw]*G[{0, 1/(yu*yv)}, yw])/16 - 
     (G[{yu}, yv^(-1)]*G[{0, 1}, yw]*G[{0, 1/(yu*yv)}, yw])/16 - 
     (G[{1/(yu*yv)}, yw]*G[{0, 1}, yw]*G[{0, 1/(yu*yv)}, yw])/16 + 
     (G[{1}, yu^(-1)]*G[{0, yu^(-1)}, yw]*G[{0, 1/(yu*yv)}, yw])/16 - 
     (G[{1}, yv^(-1)]*G[{0, yu^(-1)}, yw]*G[{0, 1/(yu*yv)}, yw])/16 - 
     (G[{1}, yw]*G[{0, yu^(-1)}, yw]*G[{0, 1/(yu*yv)}, yw])/16 + 
     (G[{1/(yu*yv)}, yw]*G[{0, yu^(-1)}, yw]*G[{0, 1/(yu*yv)}, yw])/16 - 
     (G[{1}, yu^(-1)]*G[{0, yu}, yv^(-1)]*G[{0, 1/(yu*yv)}, yw])/16 + 
     (7*G[{1}, yv^(-1)]*G[{0, yu}, yv^(-1)]*G[{0, 1/(yu*yv)}, yw])/64 - 
     (G[{1}, yw]*G[{0, yu}, yv^(-1)]*G[{0, 1/(yu*yv)}, yw])/64 - 
     (G[{yu}, yv^(-1)]*G[{0, yu}, yv^(-1)]*G[{0, 1/(yu*yv)}, yw])/16 - 
     (3*G[{1/(yu*yv)}, yw]*G[{0, yu}, yv^(-1)]*G[{0, 1/(yu*yv)}, yw])/64 + 
     (G[{1}, yu^(-1)]*G[{0, yv^(-1)}, yw]*G[{0, 1/(yu*yv)}, yw])/8 - 
     (G[{1}, yv^(-1)]*G[{0, yv^(-1)}, yw]*G[{0, 1/(yu*yv)}, yw])/8 - 
     (G[{1}, yw]*G[{0, yv^(-1)}, yw]*G[{0, 1/(yu*yv)}, yw])/16 + 
     (G[{1/(yu*yv)}, yw]*G[{0, yv^(-1)}, yw]*G[{0, 1/(yu*yv)}, yw])/16 - 
     (G[{1}, yu^(-1)]*G[{0, 1/(yu*yv)}, yw]^2)/16 + 
     (G[{1}, yv^(-1)]*G[{0, 1/(yu*yv)}, yw]^2)/32 + 
     (G[{1}, yw]*G[{0, 1/(yu*yv)}, yw]^2)/32 + 
     (G[{yu}, yv^(-1)]*G[{0, 1/(yu*yv)}, yw]^2)/32 - 
     (G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv)}, yw]^2)/32 - 
     (Pi^2*G[{0}, yu^(-1)]*G[{1, yu^(-1)}, yw])/32 - 
     (Pi^2*G[{0}, yv^(-1)]*G[{1, yu^(-1)}, yw])/32 + 
     (Pi^2*G[{0}, yw]*G[{1, yu^(-1)}, yw])/32 + 
     (Pi^2*G[{1}, yu^(-1)]*G[{1, yu^(-1)}, yw])/32 + 
     (19*Pi^2*G[{1}, yv^(-1)]*G[{1, yu^(-1)}, yw])/768 - 
     (3*G[{0}, yu^(-1)]^2*G[{1}, yv^(-1)]*G[{1, yu^(-1)}, yw])/64 - 
     (3*G[{0}, yu^(-1)]*G[{0}, yv^(-1)]*G[{1}, yv^(-1)]*G[{1, yu^(-1)}, yw])/
      32 - (3*G[{0}, yv^(-1)]^2*G[{1}, yv^(-1)]*G[{1, yu^(-1)}, yw])/64 + 
     (3*G[{0}, yu^(-1)]*G[{0}, yw]*G[{1}, yv^(-1)]*G[{1, yu^(-1)}, yw])/32 + 
     (3*G[{0}, yv^(-1)]*G[{0}, yw]*G[{1}, yv^(-1)]*G[{1, yu^(-1)}, yw])/32 - 
     (3*G[{0}, yw]^2*G[{1}, yv^(-1)]*G[{1, yu^(-1)}, yw])/64 - 
     (G[{0}, yu^(-1)]*G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*G[{1, yu^(-1)}, yw])/
      32 - (G[{0}, yv^(-1)]*G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*
       G[{1, yu^(-1)}, yw])/32 + (G[{0}, yw]*G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*
       G[{1, yu^(-1)}, yw])/32 + (5*G[{1}, yu^(-1)]^2*G[{1}, yv^(-1)]*
       G[{1, yu^(-1)}, yw])/64 + (G[{0}, yu^(-1)]*G[{1}, yv^(-1)]^2*
       G[{1, yu^(-1)}, yw])/16 + (G[{0}, yv^(-1)]*G[{1}, yv^(-1)]^2*
       G[{1, yu^(-1)}, yw])/16 - (G[{0}, yw]*G[{1}, yv^(-1)]^2*
       G[{1, yu^(-1)}, yw])/16 - (G[{1}, yu^(-1)]*G[{1}, yv^(-1)]^2*
       G[{1, yu^(-1)}, yw])/16 + (G[{1}, yv^(-1)]^3*G[{1, yu^(-1)}, yw])/
      128 - (5*Pi^2*G[{1}, yw]*G[{1, yu^(-1)}, yw])/768 - 
     (3*G[{0}, yu^(-1)]^2*G[{1}, yw]*G[{1, yu^(-1)}, yw])/64 - 
     (3*G[{0}, yu^(-1)]*G[{0}, yv^(-1)]*G[{1}, yw]*G[{1, yu^(-1)}, yw])/32 - 
     (3*G[{0}, yv^(-1)]^2*G[{1}, yw]*G[{1, yu^(-1)}, yw])/64 + 
     (3*G[{0}, yu^(-1)]*G[{0}, yw]*G[{1}, yw]*G[{1, yu^(-1)}, yw])/32 + 
     (3*G[{0}, yv^(-1)]*G[{0}, yw]*G[{1}, yw]*G[{1, yu^(-1)}, yw])/32 - 
     (3*G[{0}, yw]^2*G[{1}, yw]*G[{1, yu^(-1)}, yw])/64 + 
     (3*G[{0}, yu^(-1)]*G[{1}, yu^(-1)]*G[{1}, yw]*G[{1, yu^(-1)}, yw])/32 + 
     (3*G[{0}, yv^(-1)]*G[{1}, yu^(-1)]*G[{1}, yw]*G[{1, yu^(-1)}, yw])/32 - 
     (3*G[{0}, yw]*G[{1}, yu^(-1)]*G[{1}, yw]*G[{1, yu^(-1)}, yw])/32 - 
     (3*G[{1}, yu^(-1)]^2*G[{1}, yw]*G[{1, yu^(-1)}, yw])/64 + 
     (G[{0}, yu^(-1)]*G[{1}, yv^(-1)]*G[{1}, yw]*G[{1, yu^(-1)}, yw])/16 + 
     (G[{0}, yv^(-1)]*G[{1}, yv^(-1)]*G[{1}, yw]*G[{1, yu^(-1)}, yw])/16 - 
     (G[{0}, yw]*G[{1}, yv^(-1)]*G[{1}, yw]*G[{1, yu^(-1)}, yw])/16 - 
     (3*G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*G[{1}, yw]*G[{1, yu^(-1)}, yw])/16 + 
     (7*G[{1}, yv^(-1)]^2*G[{1}, yw]*G[{1, yu^(-1)}, yw])/128 + 
     (9*G[{1}, yv^(-1)]*G[{1}, yw]^2*G[{1, yu^(-1)}, yw])/128 + 
     (3*G[{1}, yw]^3*G[{1, yu^(-1)}, yw])/128 + 
     (5*Pi^2*G[{yu}, yv^(-1)]*G[{1, yu^(-1)}, yw])/768 + 
     (3*G[{0}, yu^(-1)]^2*G[{yu}, yv^(-1)]*G[{1, yu^(-1)}, yw])/64 + 
     (3*G[{0}, yu^(-1)]*G[{0}, yv^(-1)]*G[{yu}, yv^(-1)]*G[{1, yu^(-1)}, yw])/
      32 + (3*G[{0}, yv^(-1)]^2*G[{yu}, yv^(-1)]*G[{1, yu^(-1)}, yw])/64 - 
     (3*G[{0}, yu^(-1)]*G[{0}, yw]*G[{yu}, yv^(-1)]*G[{1, yu^(-1)}, yw])/32 - 
     (3*G[{0}, yv^(-1)]*G[{0}, yw]*G[{yu}, yv^(-1)]*G[{1, yu^(-1)}, yw])/32 + 
     (3*G[{0}, yw]^2*G[{yu}, yv^(-1)]*G[{1, yu^(-1)}, yw])/64 + 
     (G[{0}, yu^(-1)]*G[{1}, yu^(-1)]*G[{yu}, yv^(-1)]*G[{1, yu^(-1)}, yw])/
      32 + (G[{0}, yv^(-1)]*G[{1}, yu^(-1)]*G[{yu}, yv^(-1)]*
       G[{1, yu^(-1)}, yw])/32 - (G[{0}, yw]*G[{1}, yu^(-1)]*G[{yu}, yv^(-1)]*
       G[{1, yu^(-1)}, yw])/32 - (5*G[{1}, yu^(-1)]^2*G[{yu}, yv^(-1)]*
       G[{1, yu^(-1)}, yw])/64 + (G[{0}, yu^(-1)]*G[{1}, yv^(-1)]*
       G[{yu}, yv^(-1)]*G[{1, yu^(-1)}, yw])/32 + 
     (G[{0}, yv^(-1)]*G[{1}, yv^(-1)]*G[{yu}, yv^(-1)]*G[{1, yu^(-1)}, yw])/
      32 - (G[{0}, yw]*G[{1}, yv^(-1)]*G[{yu}, yv^(-1)]*G[{1, yu^(-1)}, yw])/
      32 + (3*G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*G[{yu}, yv^(-1)]*
       G[{1, yu^(-1)}, yw])/32 - (G[{1}, yv^(-1)]^2*G[{yu}, yv^(-1)]*
       G[{1, yu^(-1)}, yw])/8 + (G[{0}, yu^(-1)]*G[{1}, yw]*G[{yu}, yv^(-1)]*
       G[{1, yu^(-1)}, yw])/32 + (G[{0}, yv^(-1)]*G[{1}, yw]*G[{yu}, yv^(-1)]*
       G[{1, yu^(-1)}, yw])/32 - (G[{0}, yw]*G[{1}, yw]*G[{yu}, yv^(-1)]*
       G[{1, yu^(-1)}, yw])/32 + (3*G[{1}, yu^(-1)]*G[{1}, yw]*
       G[{yu}, yv^(-1)]*G[{1, yu^(-1)}, yw])/32 - 
     (5*G[{1}, yv^(-1)]*G[{1}, yw]*G[{yu}, yv^(-1)]*G[{1, yu^(-1)}, yw])/32 - 
     (9*G[{1}, yw]^2*G[{yu}, yv^(-1)]*G[{1, yu^(-1)}, yw])/128 - 
     (G[{0}, yu^(-1)]*G[{yu}, yv^(-1)]^2*G[{1, yu^(-1)}, yw])/8 - 
     (G[{0}, yv^(-1)]*G[{yu}, yv^(-1)]^2*G[{1, yu^(-1)}, yw])/8 + 
     (G[{0}, yw]*G[{yu}, yv^(-1)]^2*G[{1, yu^(-1)}, yw])/8 + 
     (7*G[{1}, yv^(-1)]*G[{yu}, yv^(-1)]^2*G[{1, yu^(-1)}, yw])/64 + 
     (3*G[{yu}, yv^(-1)]^3*G[{1, yu^(-1)}, yw])/64 - 
     (5*Pi^2*G[{1/(yu*yv)}, yw]*G[{1, yu^(-1)}, yw])/768 + 
     (3*G[{0}, yu^(-1)]^2*G[{1/(yu*yv)}, yw]*G[{1, yu^(-1)}, yw])/128 + 
     (3*G[{0}, yu^(-1)]*G[{0}, yv^(-1)]*G[{1/(yu*yv)}, yw]*
       G[{1, yu^(-1)}, yw])/64 + (3*G[{0}, yv^(-1)]^2*G[{1/(yu*yv)}, yw]*
       G[{1, yu^(-1)}, yw])/128 - (3*G[{0}, yu^(-1)]*G[{0}, yw]*
       G[{1/(yu*yv)}, yw]*G[{1, yu^(-1)}, yw])/64 - 
     (3*G[{0}, yv^(-1)]*G[{0}, yw]*G[{1/(yu*yv)}, yw]*G[{1, yu^(-1)}, yw])/
      64 + (3*G[{0}, yw]^2*G[{1/(yu*yv)}, yw]*G[{1, yu^(-1)}, yw])/128 - 
     (3*G[{0}, yu^(-1)]*G[{1}, yu^(-1)]*G[{1/(yu*yv)}, yw]*
       G[{1, yu^(-1)}, yw])/64 - (3*G[{0}, yv^(-1)]*G[{1}, yu^(-1)]*
       G[{1/(yu*yv)}, yw]*G[{1, yu^(-1)}, yw])/64 + 
     (3*G[{0}, yw]*G[{1}, yu^(-1)]*G[{1/(yu*yv)}, yw]*G[{1, yu^(-1)}, yw])/
      64 + (3*G[{1}, yu^(-1)]^2*G[{1/(yu*yv)}, yw]*G[{1, yu^(-1)}, yw])/128 - 
     (5*G[{0}, yu^(-1)]*G[{1}, yv^(-1)]*G[{1/(yu*yv)}, yw]*
       G[{1, yu^(-1)}, yw])/64 - (5*G[{0}, yv^(-1)]*G[{1}, yv^(-1)]*
       G[{1/(yu*yv)}, yw]*G[{1, yu^(-1)}, yw])/64 + 
     (5*G[{0}, yw]*G[{1}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{1, yu^(-1)}, yw])/
      64 + (5*G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*G[{1/(yu*yv)}, yw]*
       G[{1, yu^(-1)}, yw])/64 - (G[{1}, yv^(-1)]^2*G[{1/(yu*yv)}, yw]*
       G[{1, yu^(-1)}, yw])/32 - (3*G[{0}, yu^(-1)]*G[{1}, yw]*
       G[{1/(yu*yv)}, yw]*G[{1, yu^(-1)}, yw])/64 - 
     (3*G[{0}, yv^(-1)]*G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{1, yu^(-1)}, yw])/
      64 + (3*G[{0}, yw]*G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{1, yu^(-1)}, yw])/
      64 + (3*G[{1}, yu^(-1)]*G[{1}, yw]*G[{1/(yu*yv)}, yw]*
       G[{1, yu^(-1)}, yw])/64 - (G[{1}, yv^(-1)]*G[{1}, yw]*
       G[{1/(yu*yv)}, yw]*G[{1, yu^(-1)}, yw])/8 - 
     (11*G[{1}, yw]^2*G[{1/(yu*yv)}, yw]*G[{1, yu^(-1)}, yw])/128 + 
     (G[{0}, yu^(-1)]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*
       G[{1, yu^(-1)}, yw])/16 + (G[{0}, yv^(-1)]*G[{yu^(-1)}, yw]*
       G[{1/(yu*yv)}, yw]*G[{1, yu^(-1)}, yw])/16 - 
     (G[{0}, yw]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{1, yu^(-1)}, yw])/
      16 - (G[{1}, yu^(-1)]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*
       G[{1, yu^(-1)}, yw])/16 + (G[{1}, yw]*G[{yu^(-1)}, yw]*
       G[{1/(yu*yv)}, yw]*G[{1, yu^(-1)}, yw])/16 - 
     (G[{yu^(-1)}, yw]^2*G[{1/(yu*yv)}, yw]*G[{1, yu^(-1)}, yw])/64 + 
     (G[{0}, yu^(-1)]*G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw]*
       G[{1, yu^(-1)}, yw])/32 + (G[{0}, yv^(-1)]*G[{yu}, yv^(-1)]*
       G[{1/(yu*yv)}, yw]*G[{1, yu^(-1)}, yw])/32 - 
     (G[{0}, yw]*G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{1, yu^(-1)}, yw])/
      32 - (G[{1}, yu^(-1)]*G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw]*
       G[{1, yu^(-1)}, yw])/32 + (7*G[{1}, yv^(-1)]*G[{yu}, yv^(-1)]*
       G[{1/(yu*yv)}, yw]*G[{1, yu^(-1)}, yw])/64 + 
     (11*G[{1}, yw]*G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{1, yu^(-1)}, yw])/
      64 - (G[{yu^(-1)}, yw]*G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw]*
       G[{1, yu^(-1)}, yw])/16 - (9*G[{yu}, yv^(-1)]^2*G[{1/(yu*yv)}, yw]*
       G[{1, yu^(-1)}, yw])/128 - (G[{0}, yu^(-1)]*G[{yv^(-1)}, yw]*
       G[{1/(yu*yv)}, yw]*G[{1, yu^(-1)}, yw])/16 - 
     (G[{0}, yv^(-1)]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*
       G[{1, yu^(-1)}, yw])/16 + (G[{0}, yw]*G[{yv^(-1)}, yw]*
       G[{1/(yu*yv)}, yw]*G[{1, yu^(-1)}, yw])/16 + 
     (5*G[{1}, yv^(-1)]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*
       G[{1, yu^(-1)}, yw])/32 + (G[{1}, yw]*G[{yv^(-1)}, yw]*
       G[{1/(yu*yv)}, yw]*G[{1, yu^(-1)}, yw])/32 - 
     (G[{yu^(-1)}, yw]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*
       G[{1, yu^(-1)}, yw])/16 - (G[{yu}, yv^(-1)]*G[{yv^(-1)}, yw]*
       G[{1/(yu*yv)}, yw]*G[{1, yu^(-1)}, yw])/32 + 
     (G[{yv^(-1)}, yw]^2*G[{1/(yu*yv)}, yw]*G[{1, yu^(-1)}, yw])/32 + 
     (3*G[{0}, yu^(-1)]*G[{1/(yu*yv)}, yw]^2*G[{1, yu^(-1)}, yw])/64 + 
     (3*G[{0}, yv^(-1)]*G[{1/(yu*yv)}, yw]^2*G[{1, yu^(-1)}, yw])/64 - 
     (3*G[{0}, yw]*G[{1/(yu*yv)}, yw]^2*G[{1, yu^(-1)}, yw])/64 + 
     (3*G[{1}, yu^(-1)]*G[{1/(yu*yv)}, yw]^2*G[{1, yu^(-1)}, yw])/64 - 
     (G[{1}, yv^(-1)]*G[{1/(yu*yv)}, yw]^2*G[{1, yu^(-1)}, yw])/32 + 
     (7*G[{1}, yw]*G[{1/(yu*yv)}, yw]^2*G[{1, yu^(-1)}, yw])/64 + 
     (5*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2*G[{1, yu^(-1)}, yw])/64 - 
     (7*G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw]^2*G[{1, yu^(-1)}, yw])/64 - 
     (3*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2*G[{1, yu^(-1)}, yw])/64 - 
     (G[{0}, yu^(-1)]*G[{0, 1}, yu^(-1)]*G[{1, yu^(-1)}, yw])/8 - 
     (G[{0}, yv^(-1)]*G[{0, 1}, yu^(-1)]*G[{1, yu^(-1)}, yw])/8 + 
     (G[{0}, yw]*G[{0, 1}, yu^(-1)]*G[{1, yu^(-1)}, yw])/8 + 
     (G[{1}, yu^(-1)]*G[{0, 1}, yu^(-1)]*G[{1, yu^(-1)}, yw])/8 - 
     (G[{1}, yw]*G[{0, 1}, yu^(-1)]*G[{1, yu^(-1)}, yw])/8 + 
     (G[{yu}, yv^(-1)]*G[{0, 1}, yu^(-1)]*G[{1, yu^(-1)}, yw])/8 - 
     (G[{0}, yu^(-1)]*G[{0, 1}, yv^(-1)]*G[{1, yu^(-1)}, yw])/16 - 
     (G[{0}, yv^(-1)]*G[{0, 1}, yv^(-1)]*G[{1, yu^(-1)}, yw])/16 + 
     (G[{0}, yw]*G[{0, 1}, yv^(-1)]*G[{1, yu^(-1)}, yw])/16 + 
     (G[{1}, yu^(-1)]*G[{0, 1}, yv^(-1)]*G[{1, yu^(-1)}, yw])/16 + 
     (3*G[{1}, yv^(-1)]*G[{0, 1}, yv^(-1)]*G[{1, yu^(-1)}, yw])/64 - 
     (G[{1}, yw]*G[{0, 1}, yv^(-1)]*G[{1, yu^(-1)}, yw])/64 + 
     (G[{1/(yu*yv)}, yw]*G[{0, 1}, yv^(-1)]*G[{1, yu^(-1)}, yw])/32 + 
     (G[{1}, yv^(-1)]*G[{0, 1}, yw]*G[{1, yu^(-1)}, yw])/32 + 
     (G[{1}, yw]*G[{0, 1}, yw]*G[{1, yu^(-1)}, yw])/32 - 
     (G[{yu}, yv^(-1)]*G[{0, 1}, yw]*G[{1, yu^(-1)}, yw])/32 - 
     (G[{1/(yu*yv)}, yw]*G[{0, 1}, yw]*G[{1, yu^(-1)}, yw])/64 - 
     (G[{1}, yv^(-1)]*G[{0, yu^(-1)}, yw]*G[{1, yu^(-1)}, yw])/32 - 
     (G[{1}, yw]*G[{0, yu^(-1)}, yw]*G[{1, yu^(-1)}, yw])/32 + 
     (G[{yu}, yv^(-1)]*G[{0, yu^(-1)}, yw]*G[{1, yu^(-1)}, yw])/32 + 
     (G[{1/(yu*yv)}, yw]*G[{0, yu^(-1)}, yw]*G[{1, yu^(-1)}, yw])/64 + 
     (G[{0}, yu^(-1)]*G[{0, yu}, yv^(-1)]*G[{1, yu^(-1)}, yw])/16 + 
     (G[{0}, yv^(-1)]*G[{0, yu}, yv^(-1)]*G[{1, yu^(-1)}, yw])/16 - 
     (G[{0}, yw]*G[{0, yu}, yv^(-1)]*G[{1, yu^(-1)}, yw])/16 - 
     (G[{1}, yu^(-1)]*G[{0, yu}, yv^(-1)]*G[{1, yu^(-1)}, yw])/16 - 
     (3*G[{1}, yv^(-1)]*G[{0, yu}, yv^(-1)]*G[{1, yu^(-1)}, yw])/64 + 
     (G[{1}, yw]*G[{0, yu}, yv^(-1)]*G[{1, yu^(-1)}, yw])/64 - 
     (G[{1/(yu*yv)}, yw]*G[{0, yu}, yv^(-1)]*G[{1, yu^(-1)}, yw])/32 - 
     (G[{1}, yv^(-1)]*G[{0, yv^(-1)}, yw]*G[{1, yu^(-1)}, yw])/32 - 
     (G[{1}, yw]*G[{0, yv^(-1)}, yw]*G[{1, yu^(-1)}, yw])/32 + 
     (G[{yu}, yv^(-1)]*G[{0, yv^(-1)}, yw]*G[{1, yu^(-1)}, yw])/32 + 
     (G[{1/(yu*yv)}, yw]*G[{0, yv^(-1)}, yw]*G[{1, yu^(-1)}, yw])/64 + 
     (G[{1}, yv^(-1)]*G[{0, 1/(yu*yv)}, yw]*G[{1, yu^(-1)}, yw])/32 + 
     (G[{1}, yw]*G[{0, 1/(yu*yv)}, yw]*G[{1, yu^(-1)}, yw])/32 - 
     (G[{yu}, yv^(-1)]*G[{0, 1/(yu*yv)}, yw]*G[{1, yu^(-1)}, yw])/32 - 
     (G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv)}, yw]*G[{1, yu^(-1)}, yw])/64 - 
     (G[{0}, yu^(-1)]*G[{1, yu^(-1)}, yw]^2)/32 - 
     (G[{0}, yv^(-1)]*G[{1, yu^(-1)}, yw]^2)/32 + 
     (G[{0}, yw]*G[{1, yu^(-1)}, yw]^2)/32 + 
     (G[{1}, yu^(-1)]*G[{1, yu^(-1)}, yw]^2)/32 + 
     (G[{1}, yv^(-1)]*G[{1, yu^(-1)}, yw]^2)/32 + 
     (G[{1/(yu*yv)}, yw]*G[{1, yu^(-1)}, yw]^2)/128 - 
     (Pi^2*G[{0}, yu^(-1)]*G[{1, yu}, yv^(-1)])/32 - 
     (Pi^2*G[{0}, yv^(-1)]*G[{1, yu}, yv^(-1)])/32 + 
     (Pi^2*G[{0}, yw]*G[{1, yu}, yv^(-1)])/32 - 
     (Pi^2*G[{1}, yu^(-1)]*G[{1, yu}, yv^(-1)])/96 + 
     (G[{0}, yu^(-1)]*G[{1}, yu^(-1)]^2*G[{1, yu}, yv^(-1)])/32 + 
     (G[{0}, yv^(-1)]*G[{1}, yu^(-1)]^2*G[{1, yu}, yv^(-1)])/32 - 
     (G[{0}, yw]*G[{1}, yu^(-1)]^2*G[{1, yu}, yv^(-1)])/32 - 
     (G[{1}, yu^(-1)]^3*G[{1, yu}, yv^(-1)])/32 - 
     (13*Pi^2*G[{1}, yv^(-1)]*G[{1, yu}, yv^(-1)])/768 - 
     (3*G[{0}, yu^(-1)]^2*G[{1}, yv^(-1)]*G[{1, yu}, yv^(-1)])/64 - 
     (3*G[{0}, yu^(-1)]*G[{0}, yv^(-1)]*G[{1}, yv^(-1)]*G[{1, yu}, yv^(-1)])/
      32 - (3*G[{0}, yv^(-1)]^2*G[{1}, yv^(-1)]*G[{1, yu}, yv^(-1)])/64 + 
     (3*G[{0}, yu^(-1)]*G[{0}, yw]*G[{1}, yv^(-1)]*G[{1, yu}, yv^(-1)])/32 + 
     (3*G[{0}, yv^(-1)]*G[{0}, yw]*G[{1}, yv^(-1)]*G[{1, yu}, yv^(-1)])/32 - 
     (3*G[{0}, yw]^2*G[{1}, yv^(-1)]*G[{1, yu}, yv^(-1)])/64 - 
     (3*G[{0}, yu^(-1)]*G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*G[{1, yu}, yv^(-1)])/
      32 - (3*G[{0}, yv^(-1)]*G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*
       G[{1, yu}, yv^(-1)])/32 + (3*G[{0}, yw]*G[{1}, yu^(-1)]*
       G[{1}, yv^(-1)]*G[{1, yu}, yv^(-1)])/32 + 
     (11*G[{1}, yu^(-1)]^2*G[{1}, yv^(-1)]*G[{1, yu}, yv^(-1)])/64 - 
     (G[{1}, yu^(-1)]*G[{1}, yv^(-1)]^2*G[{1, yu}, yv^(-1)])/16 + 
     (3*G[{1}, yv^(-1)]^3*G[{1, yu}, yv^(-1)])/64 - 
     (43*Pi^2*G[{1}, yw]*G[{1, yu}, yv^(-1)])/768 - 
     (3*G[{0}, yu^(-1)]^2*G[{1}, yw]*G[{1, yu}, yv^(-1)])/128 - 
     (3*G[{0}, yu^(-1)]*G[{0}, yv^(-1)]*G[{1}, yw]*G[{1, yu}, yv^(-1)])/64 - 
     (3*G[{0}, yv^(-1)]^2*G[{1}, yw]*G[{1, yu}, yv^(-1)])/128 + 
     (3*G[{0}, yu^(-1)]*G[{0}, yw]*G[{1}, yw]*G[{1, yu}, yv^(-1)])/64 + 
     (3*G[{0}, yv^(-1)]*G[{0}, yw]*G[{1}, yw]*G[{1, yu}, yv^(-1)])/64 - 
     (3*G[{0}, yw]^2*G[{1}, yw]*G[{1, yu}, yv^(-1)])/128 + 
     (3*G[{0}, yu^(-1)]*G[{1}, yu^(-1)]*G[{1}, yw]*G[{1, yu}, yv^(-1)])/64 + 
     (3*G[{0}, yv^(-1)]*G[{1}, yu^(-1)]*G[{1}, yw]*G[{1, yu}, yv^(-1)])/64 - 
     (3*G[{0}, yw]*G[{1}, yu^(-1)]*G[{1}, yw]*G[{1, yu}, yv^(-1)])/64 - 
     (3*G[{1}, yu^(-1)]^2*G[{1}, yw]*G[{1, yu}, yv^(-1)])/128 - 
     (11*G[{0}, yu^(-1)]*G[{1}, yv^(-1)]*G[{1}, yw]*G[{1, yu}, yv^(-1)])/64 - 
     (11*G[{0}, yv^(-1)]*G[{1}, yv^(-1)]*G[{1}, yw]*G[{1, yu}, yv^(-1)])/64 + 
     (11*G[{0}, yw]*G[{1}, yv^(-1)]*G[{1}, yw]*G[{1, yu}, yv^(-1)])/64 - 
     (5*G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*G[{1}, yw]*G[{1, yu}, yv^(-1)])/64 + 
     (7*G[{1}, yv^(-1)]^2*G[{1}, yw]*G[{1, yu}, yv^(-1)])/128 - 
     (3*G[{0}, yu^(-1)]*G[{1}, yw]^2*G[{1, yu}, yv^(-1)])/64 - 
     (3*G[{0}, yv^(-1)]*G[{1}, yw]^2*G[{1, yu}, yv^(-1)])/64 + 
     (3*G[{0}, yw]*G[{1}, yw]^2*G[{1, yu}, yv^(-1)])/64 + 
     (5*G[{1}, yu^(-1)]*G[{1}, yw]^2*G[{1, yu}, yv^(-1)])/64 - 
     (19*G[{1}, yv^(-1)]*G[{1}, yw]^2*G[{1, yu}, yv^(-1)])/128 - 
     (3*G[{1}, yw]^3*G[{1, yu}, yv^(-1)])/128 - 
     (G[{1}, yu^(-1)]*G[{1}, yw]*G[{yu}, yv^(-1)]*G[{1, yu}, yv^(-1)])/4 + 
     (3*G[{1}, yv^(-1)]*G[{1}, yw]*G[{yu}, yv^(-1)]*G[{1, yu}, yv^(-1)])/16 + 
     (7*G[{1}, yw]^2*G[{yu}, yv^(-1)]*G[{1, yu}, yv^(-1)])/128 - 
     (G[{1}, yw]*G[{yu}, yv^(-1)]^2*G[{1, yu}, yv^(-1)])/16 - 
     (5*Pi^2*G[{1/(yu*yv)}, yw]*G[{1, yu}, yv^(-1)])/768 + 
     (3*G[{0}, yu^(-1)]^2*G[{1/(yu*yv)}, yw]*G[{1, yu}, yv^(-1)])/128 + 
     (3*G[{0}, yu^(-1)]*G[{0}, yv^(-1)]*G[{1/(yu*yv)}, yw]*
       G[{1, yu}, yv^(-1)])/64 + (3*G[{0}, yv^(-1)]^2*G[{1/(yu*yv)}, yw]*
       G[{1, yu}, yv^(-1)])/128 - (3*G[{0}, yu^(-1)]*G[{0}, yw]*
       G[{1/(yu*yv)}, yw]*G[{1, yu}, yv^(-1)])/64 - 
     (3*G[{0}, yv^(-1)]*G[{0}, yw]*G[{1/(yu*yv)}, yw]*G[{1, yu}, yv^(-1)])/
      64 + (3*G[{0}, yw]^2*G[{1/(yu*yv)}, yw]*G[{1, yu}, yv^(-1)])/128 - 
     (3*G[{0}, yu^(-1)]*G[{1}, yu^(-1)]*G[{1/(yu*yv)}, yw]*
       G[{1, yu}, yv^(-1)])/64 - (3*G[{0}, yv^(-1)]*G[{1}, yu^(-1)]*
       G[{1/(yu*yv)}, yw]*G[{1, yu}, yv^(-1)])/64 + 
     (3*G[{0}, yw]*G[{1}, yu^(-1)]*G[{1/(yu*yv)}, yw]*G[{1, yu}, yv^(-1)])/
      64 + (11*G[{1}, yu^(-1)]^2*G[{1/(yu*yv)}, yw]*G[{1, yu}, yv^(-1)])/
      128 - (G[{0}, yu^(-1)]*G[{1}, yv^(-1)]*G[{1/(yu*yv)}, yw]*
       G[{1, yu}, yv^(-1)])/64 - (G[{0}, yv^(-1)]*G[{1}, yv^(-1)]*
       G[{1/(yu*yv)}, yw]*G[{1, yu}, yv^(-1)])/64 + 
     (G[{0}, yw]*G[{1}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{1, yu}, yv^(-1)])/64 - 
     (7*G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*G[{1/(yu*yv)}, yw]*
       G[{1, yu}, yv^(-1)])/64 - (7*G[{1}, yv^(-1)]^2*G[{1/(yu*yv)}, yw]*
       G[{1, yu}, yv^(-1)])/128 - (5*G[{1}, yu^(-1)]*G[{1}, yw]*
       G[{1/(yu*yv)}, yw]*G[{1, yu}, yv^(-1)])/16 + 
     (9*G[{1}, yv^(-1)]*G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{1, yu}, yv^(-1)])/
      64 + (9*G[{1}, yw]^2*G[{1/(yu*yv)}, yw]*G[{1, yu}, yv^(-1)])/128 + 
     (G[{0}, yu^(-1)]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*
       G[{1, yu}, yv^(-1)])/16 + (G[{0}, yv^(-1)]*G[{yu^(-1)}, yw]*
       G[{1/(yu*yv)}, yw]*G[{1, yu}, yv^(-1)])/16 - 
     (G[{0}, yw]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{1, yu}, yv^(-1)])/
      16 + (3*G[{1}, yu^(-1)]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*
       G[{1, yu}, yv^(-1)])/16 - (3*G[{1}, yv^(-1)]*G[{yu^(-1)}, yw]*
       G[{1/(yu*yv)}, yw]*G[{1, yu}, yv^(-1)])/32 - 
     (13*G[{1}, yw]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{1, yu}, yv^(-1)])/
      64 + (3*G[{yu^(-1)}, yw]^2*G[{1/(yu*yv)}, yw]*G[{1, yu}, yv^(-1)])/32 + 
     (G[{1}, yu^(-1)]*G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw]*
       G[{1, yu}, yv^(-1)])/4 - (3*G[{1}, yv^(-1)]*G[{yu}, yv^(-1)]*
       G[{1/(yu*yv)}, yw]*G[{1, yu}, yv^(-1)])/16 - 
     (7*G[{1}, yw]*G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{1, yu}, yv^(-1)])/
      64 + (G[{yu^(-1)}, yw]*G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw]*
       G[{1, yu}, yv^(-1)])/8 + (G[{yu}, yv^(-1)]^2*G[{1/(yu*yv)}, yw]*
       G[{1, yu}, yv^(-1)])/16 - (G[{0}, yu^(-1)]*G[{yv^(-1)}, yw]*
       G[{1/(yu*yv)}, yw]*G[{1, yu}, yv^(-1)])/16 - 
     (G[{0}, yv^(-1)]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*
       G[{1, yu}, yv^(-1)])/16 + (G[{0}, yw]*G[{yv^(-1)}, yw]*
       G[{1/(yu*yv)}, yw]*G[{1, yu}, yv^(-1)])/16 + 
     (G[{1}, yu^(-1)]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*
       G[{1, yu}, yv^(-1)])/16 - (G[{1}, yv^(-1)]*G[{yv^(-1)}, yw]*
       G[{1/(yu*yv)}, yw]*G[{1, yu}, yv^(-1)])/32 - 
     (3*G[{1}, yw]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{1, yu}, yv^(-1)])/
      64 + (G[{yu^(-1)}, yw]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*
       G[{1, yu}, yv^(-1)])/16 - (3*G[{yv^(-1)}, yw]^2*G[{1/(yu*yv)}, yw]*
       G[{1, yu}, yv^(-1)])/32 + (3*G[{0}, yu^(-1)]*G[{1/(yu*yv)}, yw]^2*
       G[{1, yu}, yv^(-1)])/64 + (3*G[{0}, yv^(-1)]*G[{1/(yu*yv)}, yw]^2*
       G[{1, yu}, yv^(-1)])/64 - (3*G[{0}, yw]*G[{1/(yu*yv)}, yw]^2*
       G[{1, yu}, yv^(-1)])/64 - (G[{1}, yu^(-1)]*G[{1/(yu*yv)}, yw]^2*
       G[{1, yu}, yv^(-1)])/64 - (3*G[{1}, yv^(-1)]*G[{1/(yu*yv)}, yw]^2*
       G[{1, yu}, yv^(-1)])/128 + (G[{1}, yw]*G[{1/(yu*yv)}, yw]^2*
       G[{1, yu}, yv^(-1)])/128 + (9*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2*
       G[{1, yu}, yv^(-1)])/128 - (G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw]^2*
       G[{1, yu}, yv^(-1)])/128 + (G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2*
       G[{1, yu}, yv^(-1)])/64 - (G[{0}, yu^(-1)]*G[{0, 1}, yu^(-1)]*
       G[{1, yu}, yv^(-1)])/16 - (G[{0}, yv^(-1)]*G[{0, 1}, yu^(-1)]*
       G[{1, yu}, yv^(-1)])/16 + (G[{0}, yw]*G[{0, 1}, yu^(-1)]*
       G[{1, yu}, yv^(-1)])/16 - (G[{1}, yu^(-1)]*G[{0, 1}, yu^(-1)]*
       G[{1, yu}, yv^(-1)])/16 - (G[{1}, yv^(-1)]*G[{0, 1}, yu^(-1)]*
       G[{1, yu}, yv^(-1)])/16 - (3*G[{1}, yw]*G[{0, 1}, yu^(-1)]*
       G[{1, yu}, yv^(-1)])/16 + (G[{1/(yu*yv)}, yw]*G[{0, 1}, yu^(-1)]*
       G[{1, yu}, yv^(-1)])/16 - (G[{0}, yu^(-1)]*G[{0, 1}, yv^(-1)]*
       G[{1, yu}, yv^(-1)])/16 - (G[{0}, yv^(-1)]*G[{0, 1}, yv^(-1)]*
       G[{1, yu}, yv^(-1)])/16 + (G[{0}, yw]*G[{0, 1}, yv^(-1)]*
       G[{1, yu}, yv^(-1)])/16 - (G[{1}, yv^(-1)]*G[{0, 1}, yv^(-1)]*
       G[{1, yu}, yv^(-1)])/32 - (7*G[{1}, yw]*G[{0, 1}, yv^(-1)]*
       G[{1, yu}, yv^(-1)])/64 - (G[{1/(yu*yv)}, yw]*G[{0, 1}, yv^(-1)]*
       G[{1, yu}, yv^(-1)])/64 + (G[{1}, yu^(-1)]*G[{0, 1}, yw]*
       G[{1, yu}, yv^(-1)])/8 - (3*G[{1}, yv^(-1)]*G[{0, 1}, yw]*
       G[{1, yu}, yv^(-1)])/32 - (3*G[{1}, yw]*G[{0, 1}, yw]*
       G[{1, yu}, yv^(-1)])/64 + (3*G[{1/(yu*yv)}, yw]*G[{0, 1}, yw]*
       G[{1, yu}, yv^(-1)])/64 - (G[{0}, yu^(-1)]*G[{0, yu^(-1)}, yw]*
       G[{1, yu}, yv^(-1)])/16 - (G[{0}, yv^(-1)]*G[{0, yu^(-1)}, yw]*
       G[{1, yu}, yv^(-1)])/16 + (G[{0}, yw]*G[{0, yu^(-1)}, yw]*
       G[{1, yu}, yv^(-1)])/16 - (G[{1}, yu^(-1)]*G[{0, yu^(-1)}, yw]*
       G[{1, yu}, yv^(-1)])/16 + (G[{1}, yv^(-1)]*G[{0, yu^(-1)}, yw]*
       G[{1, yu}, yv^(-1)])/32 + (3*G[{1}, yw]*G[{0, yu^(-1)}, yw]*
       G[{1, yu}, yv^(-1)])/64 - (3*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1)}, yw]*
       G[{1, yu}, yv^(-1)])/64 + (G[{0}, yu^(-1)]*G[{0, yu}, yv^(-1)]*
       G[{1, yu}, yv^(-1)])/16 + (G[{0}, yv^(-1)]*G[{0, yu}, yv^(-1)]*
       G[{1, yu}, yv^(-1)])/16 - (G[{0}, yw]*G[{0, yu}, yv^(-1)]*
       G[{1, yu}, yv^(-1)])/16 + (G[{1}, yv^(-1)]*G[{0, yu}, yv^(-1)]*
       G[{1, yu}, yv^(-1)])/32 + (7*G[{1}, yw]*G[{0, yu}, yv^(-1)]*
       G[{1, yu}, yv^(-1)])/64 + (G[{1/(yu*yv)}, yw]*G[{0, yu}, yv^(-1)]*
       G[{1, yu}, yv^(-1)])/64 + (G[{0}, yu^(-1)]*G[{0, yv^(-1)}, yw]*
       G[{1, yu}, yv^(-1)])/16 + (G[{0}, yv^(-1)]*G[{0, yv^(-1)}, yw]*
       G[{1, yu}, yv^(-1)])/16 - (G[{0}, yw]*G[{0, yv^(-1)}, yw]*
       G[{1, yu}, yv^(-1)])/16 - (G[{1}, yu^(-1)]*G[{0, yv^(-1)}, yw]*
       G[{1, yu}, yv^(-1)])/16 + (G[{1}, yv^(-1)]*G[{0, yv^(-1)}, yw]*
       G[{1, yu}, yv^(-1)])/32 + (3*G[{1}, yw]*G[{0, yv^(-1)}, yw]*
       G[{1, yu}, yv^(-1)])/64 - (3*G[{1/(yu*yv)}, yw]*G[{0, yv^(-1)}, yw]*
       G[{1, yu}, yv^(-1)])/64 + (G[{1}, yv^(-1)]*G[{0, 1/(yu*yv)}, yw]*
       G[{1, yu}, yv^(-1)])/32 - (3*G[{1}, yw]*G[{0, 1/(yu*yv)}, yw]*
       G[{1, yu}, yv^(-1)])/64 + (3*G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv)}, yw]*
       G[{1, yu}, yv^(-1)])/64 + (G[{0}, yu^(-1)]*G[{1, yu^(-1)}, yw]*
       G[{1, yu}, yv^(-1)])/16 + (G[{0}, yv^(-1)]*G[{1, yu^(-1)}, yw]*
       G[{1, yu}, yv^(-1)])/16 - (G[{0}, yw]*G[{1, yu^(-1)}, yw]*
       G[{1, yu}, yv^(-1)])/16 - (G[{1}, yu^(-1)]*G[{1, yu^(-1)}, yw]*
       G[{1, yu}, yv^(-1)])/16 + (G[{1}, yv^(-1)]*G[{1, yu^(-1)}, yw]*
       G[{1, yu}, yv^(-1)])/32 + (7*G[{1}, yw]*G[{1, yu^(-1)}, yw]*
       G[{1, yu}, yv^(-1)])/64 - (G[{yu}, yv^(-1)]*G[{1, yu^(-1)}, yw]*
       G[{1, yu}, yv^(-1)])/8 + (G[{1/(yu*yv)}, yw]*G[{1, yu^(-1)}, yw]*
       G[{1, yu}, yv^(-1)])/32 - (G[{1}, yu^(-1)]*G[{1, yu}, yv^(-1)]^2)/8 + 
     (3*G[{1}, yv^(-1)]*G[{1, yu}, yv^(-1)]^2)/32 + 
     (5*G[{1}, yw]*G[{1, yu}, yv^(-1)]^2)/128 - 
     (5*G[{1/(yu*yv)}, yw]*G[{1, yu}, yv^(-1)]^2)/128 - 
     (Pi^2*G[{0}, yu^(-1)]*G[{1, yv^(-1)}, yw])/96 - 
     (Pi^2*G[{0}, yv^(-1)]*G[{1, yv^(-1)}, yw])/96 + 
     (Pi^2*G[{0}, yw]*G[{1, yv^(-1)}, yw])/96 - 
     (Pi^2*G[{1}, yu^(-1)]*G[{1, yv^(-1)}, yw])/48 + 
     (G[{0}, yu^(-1)]*G[{1}, yu^(-1)]^2*G[{1, yv^(-1)}, yw])/32 + 
     (G[{0}, yv^(-1)]*G[{1}, yu^(-1)]^2*G[{1, yv^(-1)}, yw])/32 - 
     (G[{0}, yw]*G[{1}, yu^(-1)]^2*G[{1, yv^(-1)}, yw])/32 - 
     (G[{1}, yu^(-1)]^3*G[{1, yv^(-1)}, yw])/32 + 
     (Pi^2*G[{1}, yv^(-1)]*G[{1, yv^(-1)}, yw])/24 - 
     (G[{0}, yu^(-1)]*G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*G[{1, yv^(-1)}, yw])/
      16 - (G[{0}, yv^(-1)]*G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*
       G[{1, yv^(-1)}, yw])/16 + (G[{0}, yw]*G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*
       G[{1, yv^(-1)}, yw])/16 + (G[{1}, yu^(-1)]^2*G[{1}, yv^(-1)]*
       G[{1, yv^(-1)}, yw])/32 + (G[{0}, yu^(-1)]*G[{1}, yv^(-1)]^2*
       G[{1, yv^(-1)}, yw])/16 + (G[{0}, yv^(-1)]*G[{1}, yv^(-1)]^2*
       G[{1, yv^(-1)}, yw])/16 - (G[{0}, yw]*G[{1}, yv^(-1)]^2*
       G[{1, yv^(-1)}, yw])/16 - (5*G[{1}, yv^(-1)]^3*G[{1, yv^(-1)}, yw])/
      128 - (Pi^2*G[{1}, yw]*G[{1, yv^(-1)}, yw])/96 - 
     (G[{0}, yu^(-1)]*G[{1}, yu^(-1)]*G[{1}, yw]*G[{1, yv^(-1)}, yw])/16 - 
     (G[{0}, yv^(-1)]*G[{1}, yu^(-1)]*G[{1}, yw]*G[{1, yv^(-1)}, yw])/16 + 
     (G[{0}, yw]*G[{1}, yu^(-1)]*G[{1}, yw]*G[{1, yv^(-1)}, yw])/16 + 
     (3*G[{1}, yu^(-1)]^2*G[{1}, yw]*G[{1, yv^(-1)}, yw])/32 + 
     (G[{0}, yu^(-1)]*G[{1}, yv^(-1)]*G[{1}, yw]*G[{1, yv^(-1)}, yw])/8 + 
     (G[{0}, yv^(-1)]*G[{1}, yv^(-1)]*G[{1}, yw]*G[{1, yv^(-1)}, yw])/8 - 
     (G[{0}, yw]*G[{1}, yv^(-1)]*G[{1}, yw]*G[{1, yv^(-1)}, yw])/8 - 
     (G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*G[{1}, yw]*G[{1, yv^(-1)}, yw])/8 - 
     (19*G[{1}, yv^(-1)]^2*G[{1}, yw]*G[{1, yv^(-1)}, yw])/128 - 
     (G[{1}, yu^(-1)]*G[{1}, yw]^2*G[{1, yv^(-1)}, yw])/32 - 
     (11*G[{1}, yv^(-1)]*G[{1}, yw]^2*G[{1, yv^(-1)}, yw])/128 - 
     (5*G[{1}, yw]^3*G[{1, yv^(-1)}, yw])/128 - 
     (G[{0}, yu^(-1)]*G[{1}, yw]*G[{yu}, yv^(-1)]*G[{1, yv^(-1)}, yw])/16 - 
     (G[{0}, yv^(-1)]*G[{1}, yw]*G[{yu}, yv^(-1)]*G[{1, yv^(-1)}, yw])/16 + 
     (G[{0}, yw]*G[{1}, yw]*G[{yu}, yv^(-1)]*G[{1, yv^(-1)}, yw])/16 + 
     (G[{1}, yu^(-1)]*G[{1}, yw]*G[{yu}, yv^(-1)]*G[{1, yv^(-1)}, yw])/16 + 
     (7*G[{1}, yv^(-1)]*G[{1}, yw]*G[{yu}, yv^(-1)]*G[{1, yv^(-1)}, yw])/32 + 
     (15*G[{1}, yw]^2*G[{yu}, yv^(-1)]*G[{1, yv^(-1)}, yw])/128 - 
     (5*G[{1}, yw]*G[{yu}, yv^(-1)]^2*G[{1, yv^(-1)}, yw])/64 - 
     (G[{1}, yu^(-1)]^2*G[{1/(yu*yv)}, yw]*G[{1, yv^(-1)}, yw])/16 - 
     (G[{0}, yu^(-1)]*G[{1}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{1, yv^(-1)}, yw])/
      16 - (G[{0}, yv^(-1)]*G[{1}, yv^(-1)]*G[{1/(yu*yv)}, yw]*
       G[{1, yv^(-1)}, yw])/16 + (G[{0}, yw]*G[{1}, yv^(-1)]*
       G[{1/(yu*yv)}, yw]*G[{1, yv^(-1)}, yw])/16 + 
     (3*G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*G[{1/(yu*yv)}, yw]*
       G[{1, yv^(-1)}, yw])/16 + (3*G[{1}, yv^(-1)]^2*G[{1/(yu*yv)}, yw]*
       G[{1, yv^(-1)}, yw])/128 - (G[{0}, yu^(-1)]*G[{1}, yw]*
       G[{1/(yu*yv)}, yw]*G[{1, yv^(-1)}, yw])/8 - 
     (G[{0}, yv^(-1)]*G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{1, yv^(-1)}, yw])/8 + 
     (G[{0}, yw]*G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{1, yv^(-1)}, yw])/8 + 
     (3*G[{1}, yu^(-1)]*G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{1, yv^(-1)}, yw])/
      16 + (15*G[{1}, yv^(-1)]*G[{1}, yw]*G[{1/(yu*yv)}, yw]*
       G[{1, yv^(-1)}, yw])/64 + (11*G[{1}, yw]^2*G[{1/(yu*yv)}, yw]*
       G[{1, yv^(-1)}, yw])/128 - (G[{1}, yu^(-1)]*G[{yu^(-1)}, yw]*
       G[{1/(yu*yv)}, yw]*G[{1, yv^(-1)}, yw])/4 + 
     (3*G[{1}, yv^(-1)]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*
       G[{1, yv^(-1)}, yw])/32 - (5*G[{1}, yw]*G[{yu^(-1)}, yw]*
       G[{1/(yu*yv)}, yw]*G[{1, yv^(-1)}, yw])/32 - 
     (7*G[{yu^(-1)}, yw]^2*G[{1/(yu*yv)}, yw]*G[{1, yv^(-1)}, yw])/64 + 
     (G[{0}, yu^(-1)]*G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw]*
       G[{1, yv^(-1)}, yw])/16 + (G[{0}, yv^(-1)]*G[{yu}, yv^(-1)]*
       G[{1/(yu*yv)}, yw]*G[{1, yv^(-1)}, yw])/16 - 
     (G[{0}, yw]*G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{1, yv^(-1)}, yw])/
      16 - (G[{1}, yu^(-1)]*G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw]*
       G[{1, yv^(-1)}, yw])/16 - (7*G[{1}, yv^(-1)]*G[{yu}, yv^(-1)]*
       G[{1/(yu*yv)}, yw]*G[{1, yv^(-1)}, yw])/32 - 
     (11*G[{1}, yw]*G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{1, yv^(-1)}, yw])/
      64 + (5*G[{yu^(-1)}, yw]*G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw]*
       G[{1, yv^(-1)}, yw])/32 + (5*G[{yu}, yv^(-1)]^2*G[{1/(yu*yv)}, yw]*
       G[{1, yv^(-1)}, yw])/64 - (G[{1}, yu^(-1)]*G[{yv^(-1)}, yw]*
       G[{1/(yu*yv)}, yw]*G[{1, yv^(-1)}, yw])/16 + 
     (3*G[{1}, yv^(-1)]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*
       G[{1, yv^(-1)}, yw])/16 + (G[{1}, yw]*G[{yv^(-1)}, yw]*
       G[{1/(yu*yv)}, yw]*G[{1, yv^(-1)}, yw])/8 - 
     (G[{yu^(-1)}, yw]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*
       G[{1, yv^(-1)}, yw])/8 - (G[{yu}, yv^(-1)]*G[{yv^(-1)}, yw]*
       G[{1/(yu*yv)}, yw]*G[{1, yv^(-1)}, yw])/8 + 
     (G[{yv^(-1)}, yw]^2*G[{1/(yu*yv)}, yw]*G[{1, yv^(-1)}, yw])/8 + 
     (G[{1}, yu^(-1)]*G[{1/(yu*yv)}, yw]^2*G[{1, yv^(-1)}, yw])/16 - 
     (G[{1}, yv^(-1)]*G[{1/(yu*yv)}, yw]^2*G[{1, yv^(-1)}, yw])/128 + 
     (7*G[{1}, yw]*G[{1/(yu*yv)}, yw]^2*G[{1, yv^(-1)}, yw])/128 + 
     (G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2*G[{1, yv^(-1)}, yw])/128 - 
     (7*G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw]^2*G[{1, yv^(-1)}, yw])/128 - 
     (G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2*G[{1, yv^(-1)}, yw])/16 - 
     (G[{1}, yu^(-1)]*G[{0, 1}, yu^(-1)]*G[{1, yv^(-1)}, yw])/16 + 
     (G[{1}, yv^(-1)]*G[{0, 1}, yu^(-1)]*G[{1, yv^(-1)}, yw])/16 + 
     (G[{1}, yw]*G[{0, 1}, yu^(-1)]*G[{1, yv^(-1)}, yw])/16 - 
     (G[{1/(yu*yv)}, yw]*G[{0, 1}, yu^(-1)]*G[{1, yv^(-1)}, yw])/16 - 
     (G[{0}, yu^(-1)]*G[{0, 1}, yv^(-1)]*G[{1, yv^(-1)}, yw])/16 - 
     (G[{0}, yv^(-1)]*G[{0, 1}, yv^(-1)]*G[{1, yv^(-1)}, yw])/16 + 
     (G[{0}, yw]*G[{0, 1}, yv^(-1)]*G[{1, yv^(-1)}, yw])/16 + 
     (G[{1}, yu^(-1)]*G[{0, 1}, yv^(-1)]*G[{1, yv^(-1)}, yw])/16 + 
     (5*G[{1}, yv^(-1)]*G[{0, 1}, yv^(-1)]*G[{1, yv^(-1)}, yw])/64 + 
     (G[{1}, yw]*G[{0, 1}, yv^(-1)]*G[{1, yv^(-1)}, yw])/64 + 
     (3*G[{1/(yu*yv)}, yw]*G[{0, 1}, yv^(-1)]*G[{1, yv^(-1)}, yw])/64 - 
     (G[{1}, yu^(-1)]*G[{0, 1}, yw]*G[{1, yv^(-1)}, yw])/16 + 
     (G[{1}, yv^(-1)]*G[{0, 1}, yw]*G[{1, yv^(-1)}, yw])/16 - 
     (G[{1}, yw]*G[{0, 1}, yw]*G[{1, yv^(-1)}, yw])/16 - 
     (G[{1/(yu*yv)}, yw]*G[{0, 1}, yw]*G[{1, yv^(-1)}, yw])/16 + 
     (G[{1}, yu^(-1)]*G[{0, yu^(-1)}, yw]*G[{1, yv^(-1)}, yw])/16 - 
     (G[{1}, yv^(-1)]*G[{0, yu^(-1)}, yw]*G[{1, yv^(-1)}, yw])/16 + 
     (G[{1}, yw]*G[{0, yu^(-1)}, yw]*G[{1, yv^(-1)}, yw])/16 + 
     (G[{1/(yu*yv)}, yw]*G[{0, yu^(-1)}, yw]*G[{1, yv^(-1)}, yw])/16 + 
     (G[{0}, yu^(-1)]*G[{0, yu}, yv^(-1)]*G[{1, yv^(-1)}, yw])/16 + 
     (G[{0}, yv^(-1)]*G[{0, yu}, yv^(-1)]*G[{1, yv^(-1)}, yw])/16 - 
     (G[{0}, yw]*G[{0, yu}, yv^(-1)]*G[{1, yv^(-1)}, yw])/16 - 
     (G[{1}, yu^(-1)]*G[{0, yu}, yv^(-1)]*G[{1, yv^(-1)}, yw])/16 - 
     (5*G[{1}, yv^(-1)]*G[{0, yu}, yv^(-1)]*G[{1, yv^(-1)}, yw])/64 - 
     (G[{1}, yw]*G[{0, yu}, yv^(-1)]*G[{1, yv^(-1)}, yw])/64 - 
     (3*G[{1/(yu*yv)}, yw]*G[{0, yu}, yv^(-1)]*G[{1, yv^(-1)}, yw])/64 + 
     (G[{1}, yu^(-1)]*G[{0, yv^(-1)}, yw]*G[{1, yv^(-1)}, yw])/16 - 
     (G[{1}, yv^(-1)]*G[{0, yv^(-1)}, yw]*G[{1, yv^(-1)}, yw])/16 + 
     (G[{1}, yw]*G[{0, yv^(-1)}, yw]*G[{1, yv^(-1)}, yw])/16 + 
     (G[{1/(yu*yv)}, yw]*G[{0, yv^(-1)}, yw]*G[{1, yv^(-1)}, yw])/16 - 
     (G[{1}, yu^(-1)]*G[{0, 1/(yu*yv)}, yw]*G[{1, yv^(-1)}, yw])/16 + 
     (G[{1}, yv^(-1)]*G[{0, 1/(yu*yv)}, yw]*G[{1, yv^(-1)}, yw])/16 - 
     (G[{1}, yw]*G[{0, 1/(yu*yv)}, yw]*G[{1, yv^(-1)}, yw])/16 - 
     (G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv)}, yw]*G[{1, yv^(-1)}, yw])/16 - 
     (G[{0}, yu^(-1)]*G[{1, yu^(-1)}, yw]*G[{1, yv^(-1)}, yw])/16 - 
     (G[{0}, yv^(-1)]*G[{1, yu^(-1)}, yw]*G[{1, yv^(-1)}, yw])/16 + 
     (G[{0}, yw]*G[{1, yu^(-1)}, yw]*G[{1, yv^(-1)}, yw])/16 + 
     (5*G[{1}, yv^(-1)]*G[{1, yu^(-1)}, yw]*G[{1, yv^(-1)}, yw])/32 + 
     (G[{1}, yw]*G[{1, yu^(-1)}, yw]*G[{1, yv^(-1)}, yw])/32 - 
     (G[{yu}, yv^(-1)]*G[{1, yu^(-1)}, yw]*G[{1, yv^(-1)}, yw])/32 - 
     (G[{1/(yu*yv)}, yw]*G[{1, yu^(-1)}, yw]*G[{1, yv^(-1)}, yw])/64 - 
     (G[{0}, yu^(-1)]*G[{1, yu}, yv^(-1)]*G[{1, yv^(-1)}, yw])/16 - 
     (G[{0}, yv^(-1)]*G[{1, yu}, yv^(-1)]*G[{1, yv^(-1)}, yw])/16 + 
     (G[{0}, yw]*G[{1, yu}, yv^(-1)]*G[{1, yv^(-1)}, yw])/16 + 
     (G[{1}, yu^(-1)]*G[{1, yu}, yv^(-1)]*G[{1, yv^(-1)}, yw])/16 - 
     (G[{1}, yv^(-1)]*G[{1, yu}, yv^(-1)]*G[{1, yv^(-1)}, yw])/32 - 
     (3*G[{1}, yw]*G[{1, yu}, yv^(-1)]*G[{1, yv^(-1)}, yw])/64 + 
     (7*G[{1/(yu*yv)}, yw]*G[{1, yu}, yv^(-1)]*G[{1, yv^(-1)}, yw])/64 - 
     (G[{1}, yu^(-1)]*G[{1, yv^(-1)}, yw]^2)/32 + 
     (3*G[{1}, yv^(-1)]*G[{1, yv^(-1)}, yw]^2)/32 + 
     (G[{1}, yw]*G[{1, yv^(-1)}, yw]^2)/16 - 
     (G[{yu}, yv^(-1)]*G[{1, yv^(-1)}, yw]^2)/16 - 
     (G[{1/(yu*yv)}, yw]*G[{1, yv^(-1)}, yw]^2)/16 + 
     (Pi^2*G[{0}, yu^(-1)]*G[{1, 1/(yu*yv)}, yw])/32 + 
     (Pi^2*G[{0}, yv^(-1)]*G[{1, 1/(yu*yv)}, yw])/32 - 
     (Pi^2*G[{0}, yw]*G[{1, 1/(yu*yv)}, yw])/32 + 
     (Pi^2*G[{1}, yu^(-1)]*G[{1, 1/(yu*yv)}, yw])/96 - 
     (G[{0}, yu^(-1)]*G[{1}, yu^(-1)]^2*G[{1, 1/(yu*yv)}, yw])/32 - 
     (G[{0}, yv^(-1)]*G[{1}, yu^(-1)]^2*G[{1, 1/(yu*yv)}, yw])/32 + 
     (G[{0}, yw]*G[{1}, yu^(-1)]^2*G[{1, 1/(yu*yv)}, yw])/32 + 
     (G[{1}, yu^(-1)]^3*G[{1, 1/(yu*yv)}, yw])/32 + 
     (13*Pi^2*G[{1}, yv^(-1)]*G[{1, 1/(yu*yv)}, yw])/768 + 
     (3*G[{0}, yu^(-1)]^2*G[{1}, yv^(-1)]*G[{1, 1/(yu*yv)}, yw])/64 + 
     (3*G[{0}, yu^(-1)]*G[{0}, yv^(-1)]*G[{1}, yv^(-1)]*
       G[{1, 1/(yu*yv)}, yw])/32 + (3*G[{0}, yv^(-1)]^2*G[{1}, yv^(-1)]*
       G[{1, 1/(yu*yv)}, yw])/64 - (3*G[{0}, yu^(-1)]*G[{0}, yw]*
       G[{1}, yv^(-1)]*G[{1, 1/(yu*yv)}, yw])/32 - 
     (3*G[{0}, yv^(-1)]*G[{0}, yw]*G[{1}, yv^(-1)]*G[{1, 1/(yu*yv)}, yw])/
      32 + (3*G[{0}, yw]^2*G[{1}, yv^(-1)]*G[{1, 1/(yu*yv)}, yw])/64 + 
     (3*G[{0}, yu^(-1)]*G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*
       G[{1, 1/(yu*yv)}, yw])/32 + (3*G[{0}, yv^(-1)]*G[{1}, yu^(-1)]*
       G[{1}, yv^(-1)]*G[{1, 1/(yu*yv)}, yw])/32 - 
     (3*G[{0}, yw]*G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*G[{1, 1/(yu*yv)}, yw])/
      32 - (11*G[{1}, yu^(-1)]^2*G[{1}, yv^(-1)]*G[{1, 1/(yu*yv)}, yw])/64 + 
     (G[{1}, yu^(-1)]*G[{1}, yv^(-1)]^2*G[{1, 1/(yu*yv)}, yw])/16 - 
     (3*G[{1}, yv^(-1)]^3*G[{1, 1/(yu*yv)}, yw])/64 + 
     (61*Pi^2*G[{1}, yw]*G[{1, 1/(yu*yv)}, yw])/768 + 
     (3*G[{0}, yu^(-1)]^2*G[{1}, yw]*G[{1, 1/(yu*yv)}, yw])/64 + 
     (3*G[{0}, yu^(-1)]*G[{0}, yv^(-1)]*G[{1}, yw]*G[{1, 1/(yu*yv)}, yw])/
      32 + (3*G[{0}, yv^(-1)]^2*G[{1}, yw]*G[{1, 1/(yu*yv)}, yw])/64 - 
     (3*G[{0}, yu^(-1)]*G[{0}, yw]*G[{1}, yw]*G[{1, 1/(yu*yv)}, yw])/32 - 
     (3*G[{0}, yv^(-1)]*G[{0}, yw]*G[{1}, yw]*G[{1, 1/(yu*yv)}, yw])/32 + 
     (3*G[{0}, yw]^2*G[{1}, yw]*G[{1, 1/(yu*yv)}, yw])/64 - 
     (G[{0}, yu^(-1)]*G[{1}, yu^(-1)]*G[{1}, yw]*G[{1, 1/(yu*yv)}, yw])/32 - 
     (G[{0}, yv^(-1)]*G[{1}, yu^(-1)]*G[{1}, yw]*G[{1, 1/(yu*yv)}, yw])/32 + 
     (G[{0}, yw]*G[{1}, yu^(-1)]*G[{1}, yw]*G[{1, 1/(yu*yv)}, yw])/32 - 
     (3*G[{1}, yu^(-1)]^2*G[{1}, yw]*G[{1, 1/(yu*yv)}, yw])/64 + 
     (3*G[{0}, yu^(-1)]*G[{1}, yv^(-1)]*G[{1}, yw]*G[{1, 1/(yu*yv)}, yw])/
      16 + (3*G[{0}, yv^(-1)]*G[{1}, yv^(-1)]*G[{1}, yw]*
       G[{1, 1/(yu*yv)}, yw])/16 - (3*G[{0}, yw]*G[{1}, yv^(-1)]*G[{1}, yw]*
       G[{1, 1/(yu*yv)}, yw])/16 + (3*G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*
       G[{1}, yw]*G[{1, 1/(yu*yv)}, yw])/16 - 
     (9*G[{1}, yv^(-1)]^2*G[{1}, yw]*G[{1, 1/(yu*yv)}, yw])/64 + 
     (G[{0}, yu^(-1)]*G[{1}, yw]^2*G[{1, 1/(yu*yv)}, yw])/8 + 
     (G[{0}, yv^(-1)]*G[{1}, yw]^2*G[{1, 1/(yu*yv)}, yw])/8 - 
     (G[{0}, yw]*G[{1}, yw]^2*G[{1, 1/(yu*yv)}, yw])/8 - 
     (3*G[{1}, yu^(-1)]*G[{1}, yw]^2*G[{1, 1/(yu*yv)}, yw])/32 + 
     (G[{1}, yv^(-1)]*G[{1}, yw]^2*G[{1, 1/(yu*yv)}, yw])/32 + 
     (G[{1}, yw]^3*G[{1, 1/(yu*yv)}, yw])/16 - 
     (23*Pi^2*G[{yu}, yv^(-1)]*G[{1, 1/(yu*yv)}, yw])/256 - 
     (3*G[{0}, yu^(-1)]^2*G[{yu}, yv^(-1)]*G[{1, 1/(yu*yv)}, yw])/64 - 
     (3*G[{0}, yu^(-1)]*G[{0}, yv^(-1)]*G[{yu}, yv^(-1)]*
       G[{1, 1/(yu*yv)}, yw])/32 - (3*G[{0}, yv^(-1)]^2*G[{yu}, yv^(-1)]*
       G[{1, 1/(yu*yv)}, yw])/64 + (3*G[{0}, yu^(-1)]*G[{0}, yw]*
       G[{yu}, yv^(-1)]*G[{1, 1/(yu*yv)}, yw])/32 + 
     (3*G[{0}, yv^(-1)]*G[{0}, yw]*G[{yu}, yv^(-1)]*G[{1, 1/(yu*yv)}, yw])/
      32 - (3*G[{0}, yw]^2*G[{yu}, yv^(-1)]*G[{1, 1/(yu*yv)}, yw])/64 - 
     (G[{0}, yu^(-1)]*G[{1}, yu^(-1)]*G[{yu}, yv^(-1)]*G[{1, 1/(yu*yv)}, yw])/
      32 - (G[{0}, yv^(-1)]*G[{1}, yu^(-1)]*G[{yu}, yv^(-1)]*
       G[{1, 1/(yu*yv)}, yw])/32 + (G[{0}, yw]*G[{1}, yu^(-1)]*
       G[{yu}, yv^(-1)]*G[{1, 1/(yu*yv)}, yw])/32 + 
     (9*G[{1}, yu^(-1)]^2*G[{yu}, yv^(-1)]*G[{1, 1/(yu*yv)}, yw])/64 - 
     (9*G[{0}, yu^(-1)]*G[{1}, yv^(-1)]*G[{yu}, yv^(-1)]*
       G[{1, 1/(yu*yv)}, yw])/32 - (9*G[{0}, yv^(-1)]*G[{1}, yv^(-1)]*
       G[{yu}, yv^(-1)]*G[{1, 1/(yu*yv)}, yw])/32 + 
     (9*G[{0}, yw]*G[{1}, yv^(-1)]*G[{yu}, yv^(-1)]*G[{1, 1/(yu*yv)}, yw])/
      32 - (7*G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*G[{yu}, yv^(-1)]*
       G[{1, 1/(yu*yv)}, yw])/32 + (3*G[{1}, yv^(-1)]^2*G[{yu}, yv^(-1)]*
       G[{1, 1/(yu*yv)}, yw])/16 - (11*G[{0}, yu^(-1)]*G[{1}, yw]*
       G[{yu}, yv^(-1)]*G[{1, 1/(yu*yv)}, yw])/32 - 
     (11*G[{0}, yv^(-1)]*G[{1}, yw]*G[{yu}, yv^(-1)]*G[{1, 1/(yu*yv)}, yw])/
      32 + (11*G[{0}, yw]*G[{1}, yw]*G[{yu}, yv^(-1)]*G[{1, 1/(yu*yv)}, yw])/
      32 - (G[{1}, yu^(-1)]*G[{1}, yw]*G[{yu}, yv^(-1)]*
       G[{1, 1/(yu*yv)}, yw])/32 - (G[{1}, yv^(-1)]*G[{1}, yw]*
       G[{yu}, yv^(-1)]*G[{1, 1/(yu*yv)}, yw])/8 - 
     (3*G[{1}, yw]^2*G[{yu}, yv^(-1)]*G[{1, 1/(yu*yv)}, yw])/16 + 
     (G[{0}, yu^(-1)]*G[{yu}, yv^(-1)]^2*G[{1, 1/(yu*yv)}, yw])/4 + 
     (G[{0}, yv^(-1)]*G[{yu}, yv^(-1)]^2*G[{1, 1/(yu*yv)}, yw])/4 - 
     (G[{0}, yw]*G[{yu}, yv^(-1)]^2*G[{1, 1/(yu*yv)}, yw])/4 + 
     (9*G[{1}, yv^(-1)]*G[{yu}, yv^(-1)]^2*G[{1, 1/(yu*yv)}, yw])/64 + 
     (27*G[{1}, yw]*G[{yu}, yv^(-1)]^2*G[{1, 1/(yu*yv)}, yw])/64 - 
     (41*G[{yu}, yv^(-1)]^3*G[{1, 1/(yu*yv)}, yw])/192 + 
     (5*Pi^2*G[{1/(yu*yv)}, yw]*G[{1, 1/(yu*yv)}, yw])/768 - 
     (3*G[{0}, yu^(-1)]^2*G[{1/(yu*yv)}, yw]*G[{1, 1/(yu*yv)}, yw])/128 - 
     (3*G[{0}, yu^(-1)]*G[{0}, yv^(-1)]*G[{1/(yu*yv)}, yw]*
       G[{1, 1/(yu*yv)}, yw])/64 - (3*G[{0}, yv^(-1)]^2*G[{1/(yu*yv)}, yw]*
       G[{1, 1/(yu*yv)}, yw])/128 + (3*G[{0}, yu^(-1)]*G[{0}, yw]*
       G[{1/(yu*yv)}, yw]*G[{1, 1/(yu*yv)}, yw])/64 + 
     (3*G[{0}, yv^(-1)]*G[{0}, yw]*G[{1/(yu*yv)}, yw]*G[{1, 1/(yu*yv)}, yw])/
      64 - (3*G[{0}, yw]^2*G[{1/(yu*yv)}, yw]*G[{1, 1/(yu*yv)}, yw])/128 - 
     (5*G[{0}, yu^(-1)]*G[{1}, yu^(-1)]*G[{1/(yu*yv)}, yw]*
       G[{1, 1/(yu*yv)}, yw])/64 - (5*G[{0}, yv^(-1)]*G[{1}, yu^(-1)]*
       G[{1/(yu*yv)}, yw]*G[{1, 1/(yu*yv)}, yw])/64 + 
     (5*G[{0}, yw]*G[{1}, yu^(-1)]*G[{1/(yu*yv)}, yw]*G[{1, 1/(yu*yv)}, yw])/
      64 + (13*G[{1}, yu^(-1)]^2*G[{1/(yu*yv)}, yw]*G[{1, 1/(yu*yv)}, yw])/
      128 + (G[{0}, yu^(-1)]*G[{1}, yv^(-1)]*G[{1/(yu*yv)}, yw]*
       G[{1, 1/(yu*yv)}, yw])/64 + (G[{0}, yv^(-1)]*G[{1}, yv^(-1)]*
       G[{1/(yu*yv)}, yw]*G[{1, 1/(yu*yv)}, yw])/64 - 
     (G[{0}, yw]*G[{1}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{1, 1/(yu*yv)}, yw])/
      64 - (G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*G[{1/(yu*yv)}, yw]*
       G[{1, 1/(yu*yv)}, yw])/64 + (7*G[{1}, yv^(-1)]^2*G[{1/(yu*yv)}, yw]*
       G[{1, 1/(yu*yv)}, yw])/128 - (13*G[{0}, yu^(-1)]*G[{1}, yw]*
       G[{1/(yu*yv)}, yw]*G[{1, 1/(yu*yv)}, yw])/64 - 
     (13*G[{0}, yv^(-1)]*G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{1, 1/(yu*yv)}, yw])/
      64 + (13*G[{0}, yw]*G[{1}, yw]*G[{1/(yu*yv)}, yw]*
       G[{1, 1/(yu*yv)}, yw])/64 + (G[{1}, yu^(-1)]*G[{1}, yw]*
       G[{1/(yu*yv)}, yw]*G[{1, 1/(yu*yv)}, yw])/64 + 
     (7*G[{1}, yv^(-1)]*G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{1, 1/(yu*yv)}, yw])/
      64 - (9*G[{1}, yw]^2*G[{1/(yu*yv)}, yw]*G[{1, 1/(yu*yv)}, yw])/64 - 
     (G[{0}, yu^(-1)]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*
       G[{1, 1/(yu*yv)}, yw])/16 - (G[{0}, yv^(-1)]*G[{yu^(-1)}, yw]*
       G[{1/(yu*yv)}, yw]*G[{1, 1/(yu*yv)}, yw])/16 + 
     (G[{0}, yw]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{1, 1/(yu*yv)}, yw])/
      16 + (G[{1}, yu^(-1)]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*
       G[{1, 1/(yu*yv)}, yw])/16 + (3*G[{1}, yv^(-1)]*G[{yu^(-1)}, yw]*
       G[{1/(yu*yv)}, yw]*G[{1, 1/(yu*yv)}, yw])/32 + 
     (G[{1}, yw]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{1, 1/(yu*yv)}, yw])/
      32 - (3*G[{yu^(-1)}, yw]^2*G[{1/(yu*yv)}, yw]*G[{1, 1/(yu*yv)}, yw])/
      32 + (5*G[{0}, yu^(-1)]*G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw]*
       G[{1, 1/(yu*yv)}, yw])/32 + (5*G[{0}, yv^(-1)]*G[{yu}, yv^(-1)]*
       G[{1/(yu*yv)}, yw]*G[{1, 1/(yu*yv)}, yw])/32 - 
     (5*G[{0}, yw]*G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{1, 1/(yu*yv)}, yw])/
      32 - (G[{1}, yu^(-1)]*G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw]*
       G[{1, 1/(yu*yv)}, yw])/32 - (5*G[{1}, yv^(-1)]*G[{yu}, yv^(-1)]*
       G[{1/(yu*yv)}, yw]*G[{1, 1/(yu*yv)}, yw])/64 + 
     (9*G[{1}, yw]*G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{1, 1/(yu*yv)}, yw])/
      32 - (G[{yu^(-1)}, yw]*G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw]*
       G[{1, 1/(yu*yv)}, yw])/32 - (13*G[{yu}, yv^(-1)]^2*G[{1/(yu*yv)}, yw]*
       G[{1, 1/(yu*yv)}, yw])/128 + (G[{0}, yu^(-1)]*G[{yv^(-1)}, yw]*
       G[{1/(yu*yv)}, yw]*G[{1, 1/(yu*yv)}, yw])/16 + 
     (G[{0}, yv^(-1)]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*
       G[{1, 1/(yu*yv)}, yw])/16 - (G[{0}, yw]*G[{yv^(-1)}, yw]*
       G[{1/(yu*yv)}, yw]*G[{1, 1/(yu*yv)}, yw])/16 - 
     (G[{1}, yu^(-1)]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*
       G[{1, 1/(yu*yv)}, yw])/16 - (7*G[{1}, yv^(-1)]*G[{yv^(-1)}, yw]*
       G[{1/(yu*yv)}, yw]*G[{1, 1/(yu*yv)}, yw])/32 - 
     (5*G[{1}, yw]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{1, 1/(yu*yv)}, yw])/
      32 + (3*G[{yu^(-1)}, yw]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*
       G[{1, 1/(yu*yv)}, yw])/16 + (5*G[{yu}, yv^(-1)]*G[{yv^(-1)}, yw]*
       G[{1/(yu*yv)}, yw]*G[{1, 1/(yu*yv)}, yw])/32 - 
     (G[{yv^(-1)}, yw]^2*G[{1/(yu*yv)}, yw]*G[{1, 1/(yu*yv)}, yw])/32 - 
     (3*G[{0}, yu^(-1)]*G[{1/(yu*yv)}, yw]^2*G[{1, 1/(yu*yv)}, yw])/64 - 
     (3*G[{0}, yv^(-1)]*G[{1/(yu*yv)}, yw]^2*G[{1, 1/(yu*yv)}, yw])/64 + 
     (3*G[{0}, yw]*G[{1/(yu*yv)}, yw]^2*G[{1, 1/(yu*yv)}, yw])/64 + 
     (G[{1}, yu^(-1)]*G[{1/(yu*yv)}, yw]^2*G[{1, 1/(yu*yv)}, yw])/64 + 
     (3*G[{1}, yv^(-1)]*G[{1/(yu*yv)}, yw]^2*G[{1, 1/(yu*yv)}, yw])/128 - 
     (7*G[{1}, yw]*G[{1/(yu*yv)}, yw]^2*G[{1, 1/(yu*yv)}, yw])/128 - 
     (9*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2*G[{1, 1/(yu*yv)}, yw])/128 + 
     (7*G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw]^2*G[{1, 1/(yu*yv)}, yw])/128 - 
     (G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2*G[{1, 1/(yu*yv)}, yw])/64 + 
     (G[{0}, yu^(-1)]*G[{0, 1}, yu^(-1)]*G[{1, 1/(yu*yv)}, yw])/16 + 
     (G[{0}, yv^(-1)]*G[{0, 1}, yu^(-1)]*G[{1, 1/(yu*yv)}, yw])/16 - 
     (G[{0}, yw]*G[{0, 1}, yu^(-1)]*G[{1, 1/(yu*yv)}, yw])/16 + 
     (G[{1}, yu^(-1)]*G[{0, 1}, yu^(-1)]*G[{1, 1/(yu*yv)}, yw])/16 + 
     (G[{1}, yv^(-1)]*G[{0, 1}, yu^(-1)]*G[{1, 1/(yu*yv)}, yw])/16 + 
     (5*G[{1}, yw]*G[{0, 1}, yu^(-1)]*G[{1, 1/(yu*yv)}, yw])/16 - 
     (G[{yu}, yv^(-1)]*G[{0, 1}, yu^(-1)]*G[{1, 1/(yu*yv)}, yw])/4 + 
     (G[{1/(yu*yv)}, yw]*G[{0, 1}, yu^(-1)]*G[{1, 1/(yu*yv)}, yw])/16 + 
     (G[{0}, yu^(-1)]*G[{0, 1}, yv^(-1)]*G[{1, 1/(yu*yv)}, yw])/16 + 
     (G[{0}, yv^(-1)]*G[{0, 1}, yv^(-1)]*G[{1, 1/(yu*yv)}, yw])/16 - 
     (G[{0}, yw]*G[{0, 1}, yv^(-1)]*G[{1, 1/(yu*yv)}, yw])/16 + 
     (G[{1}, yv^(-1)]*G[{0, 1}, yv^(-1)]*G[{1, 1/(yu*yv)}, yw])/32 + 
     (5*G[{1}, yw]*G[{0, 1}, yv^(-1)]*G[{1, 1/(yu*yv)}, yw])/32 - 
     (G[{yu}, yv^(-1)]*G[{0, 1}, yv^(-1)]*G[{1, 1/(yu*yv)}, yw])/8 + 
     (G[{1/(yu*yv)}, yw]*G[{0, 1}, yv^(-1)]*G[{1, 1/(yu*yv)}, yw])/64 + 
     (G[{0}, yu^(-1)]*G[{0, 1}, yw]*G[{1, 1/(yu*yv)}, yw])/16 + 
     (G[{0}, yv^(-1)]*G[{0, 1}, yw]*G[{1, 1/(yu*yv)}, yw])/16 - 
     (G[{0}, yw]*G[{0, 1}, yw]*G[{1, 1/(yu*yv)}, yw])/16 - 
     (G[{1}, yu^(-1)]*G[{0, 1}, yw]*G[{1, 1/(yu*yv)}, yw])/16 - 
     (3*G[{1}, yv^(-1)]*G[{0, 1}, yw]*G[{1, 1/(yu*yv)}, yw])/32 - 
     (3*G[{1}, yw]*G[{0, 1}, yw]*G[{1, 1/(yu*yv)}, yw])/32 + 
     (G[{yu}, yv^(-1)]*G[{0, 1}, yw]*G[{1, 1/(yu*yv)}, yw])/32 - 
     (3*G[{1/(yu*yv)}, yw]*G[{0, 1}, yw]*G[{1, 1/(yu*yv)}, yw])/64 - 
     (G[{0}, yu^(-1)]*G[{0, yu^(-1)}, yw]*G[{1, 1/(yu*yv)}, yw])/16 - 
     (G[{0}, yv^(-1)]*G[{0, yu^(-1)}, yw]*G[{1, 1/(yu*yv)}, yw])/16 + 
     (G[{0}, yw]*G[{0, yu^(-1)}, yw]*G[{1, 1/(yu*yv)}, yw])/16 + 
     (G[{1}, yu^(-1)]*G[{0, yu^(-1)}, yw]*G[{1, 1/(yu*yv)}, yw])/16 + 
     (3*G[{1}, yv^(-1)]*G[{0, yu^(-1)}, yw]*G[{1, 1/(yu*yv)}, yw])/32 + 
     (3*G[{1}, yw]*G[{0, yu^(-1)}, yw]*G[{1, 1/(yu*yv)}, yw])/32 - 
     (G[{yu}, yv^(-1)]*G[{0, yu^(-1)}, yw]*G[{1, 1/(yu*yv)}, yw])/32 + 
     (3*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1)}, yw]*G[{1, 1/(yu*yv)}, yw])/64 - 
     (G[{0}, yu^(-1)]*G[{0, yu}, yv^(-1)]*G[{1, 1/(yu*yv)}, yw])/16 - 
     (G[{0}, yv^(-1)]*G[{0, yu}, yv^(-1)]*G[{1, 1/(yu*yv)}, yw])/16 + 
     (G[{0}, yw]*G[{0, yu}, yv^(-1)]*G[{1, 1/(yu*yv)}, yw])/16 - 
     (G[{1}, yv^(-1)]*G[{0, yu}, yv^(-1)]*G[{1, 1/(yu*yv)}, yw])/32 - 
     (5*G[{1}, yw]*G[{0, yu}, yv^(-1)]*G[{1, 1/(yu*yv)}, yw])/32 + 
     (G[{yu}, yv^(-1)]*G[{0, yu}, yv^(-1)]*G[{1, 1/(yu*yv)}, yw])/8 - 
     (G[{1/(yu*yv)}, yw]*G[{0, yu}, yv^(-1)]*G[{1, 1/(yu*yv)}, yw])/64 - 
     (G[{0}, yu^(-1)]*G[{0, yv^(-1)}, yw]*G[{1, 1/(yu*yv)}, yw])/16 - 
     (G[{0}, yv^(-1)]*G[{0, yv^(-1)}, yw]*G[{1, 1/(yu*yv)}, yw])/16 + 
     (G[{0}, yw]*G[{0, yv^(-1)}, yw]*G[{1, 1/(yu*yv)}, yw])/16 + 
     (G[{1}, yu^(-1)]*G[{0, yv^(-1)}, yw]*G[{1, 1/(yu*yv)}, yw])/16 + 
     (3*G[{1}, yv^(-1)]*G[{0, yv^(-1)}, yw]*G[{1, 1/(yu*yv)}, yw])/32 + 
     (3*G[{1}, yw]*G[{0, yv^(-1)}, yw]*G[{1, 1/(yu*yv)}, yw])/32 - 
     (G[{yu}, yv^(-1)]*G[{0, yv^(-1)}, yw]*G[{1, 1/(yu*yv)}, yw])/32 + 
     (3*G[{1/(yu*yv)}, yw]*G[{0, yv^(-1)}, yw]*G[{1, 1/(yu*yv)}, yw])/64 + 
     (G[{0}, yu^(-1)]*G[{0, 1/(yu*yv)}, yw]*G[{1, 1/(yu*yv)}, yw])/16 + 
     (G[{0}, yv^(-1)]*G[{0, 1/(yu*yv)}, yw]*G[{1, 1/(yu*yv)}, yw])/16 - 
     (G[{0}, yw]*G[{0, 1/(yu*yv)}, yw]*G[{1, 1/(yu*yv)}, yw])/16 - 
     (G[{1}, yu^(-1)]*G[{0, 1/(yu*yv)}, yw]*G[{1, 1/(yu*yv)}, yw])/16 - 
     (3*G[{1}, yv^(-1)]*G[{0, 1/(yu*yv)}, yw]*G[{1, 1/(yu*yv)}, yw])/32 - 
     (3*G[{1}, yw]*G[{0, 1/(yu*yv)}, yw]*G[{1, 1/(yu*yv)}, yw])/32 + 
     (G[{yu}, yv^(-1)]*G[{0, 1/(yu*yv)}, yw]*G[{1, 1/(yu*yv)}, yw])/32 - 
     (3*G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv)}, yw]*G[{1, 1/(yu*yv)}, yw])/64 + 
     (G[{0}, yu^(-1)]*G[{1, yu^(-1)}, yw]*G[{1, 1/(yu*yv)}, yw])/8 + 
     (G[{0}, yv^(-1)]*G[{1, yu^(-1)}, yw]*G[{1, 1/(yu*yv)}, yw])/8 - 
     (G[{0}, yw]*G[{1, yu^(-1)}, yw]*G[{1, 1/(yu*yv)}, yw])/8 - 
     (G[{1}, yu^(-1)]*G[{1, yu^(-1)}, yw]*G[{1, 1/(yu*yv)}, yw])/16 - 
     (5*G[{1}, yv^(-1)]*G[{1, yu^(-1)}, yw]*G[{1, 1/(yu*yv)}, yw])/32 + 
     (G[{1}, yw]*G[{1, yu^(-1)}, yw]*G[{1, 1/(yu*yv)}, yw])/32 - 
     (G[{yu}, yv^(-1)]*G[{1, yu^(-1)}, yw]*G[{1, 1/(yu*yv)}, yw])/32 - 
     (G[{1/(yu*yv)}, yw]*G[{1, yu^(-1)}, yw]*G[{1, 1/(yu*yv)}, yw])/32 + 
     (G[{1}, yu^(-1)]*G[{1, yu}, yv^(-1)]*G[{1, 1/(yu*yv)}, yw])/4 - 
     (3*G[{1}, yv^(-1)]*G[{1, yu}, yv^(-1)]*G[{1, 1/(yu*yv)}, yw])/16 - 
     (5*G[{1}, yw]*G[{1, yu}, yv^(-1)]*G[{1, 1/(yu*yv)}, yw])/32 + 
     (G[{yu}, yv^(-1)]*G[{1, yu}, yv^(-1)]*G[{1, 1/(yu*yv)}, yw])/8 - 
     (3*G[{1/(yu*yv)}, yw]*G[{1, yu}, yv^(-1)]*G[{1, 1/(yu*yv)}, yw])/64 + 
     (G[{0}, yu^(-1)]*G[{1, yv^(-1)}, yw]*G[{1, 1/(yu*yv)}, yw])/8 + 
     (G[{0}, yv^(-1)]*G[{1, yv^(-1)}, yw]*G[{1, 1/(yu*yv)}, yw])/8 - 
     (G[{0}, yw]*G[{1, yv^(-1)}, yw]*G[{1, 1/(yu*yv)}, yw])/8 - 
     (5*G[{1}, yu^(-1)]*G[{1, yv^(-1)}, yw]*G[{1, 1/(yu*yv)}, yw])/16 + 
     (G[{1}, yv^(-1)]*G[{1, yv^(-1)}, yw]*G[{1, 1/(yu*yv)}, yw])/32 - 
     (G[{1}, yw]*G[{1, yv^(-1)}, yw]*G[{1, 1/(yu*yv)}, yw])/32 + 
     (G[{yu}, yv^(-1)]*G[{1, yv^(-1)}, yw]*G[{1, 1/(yu*yv)}, yw])/32 + 
     (G[{1/(yu*yv)}, yw]*G[{1, yv^(-1)}, yw]*G[{1, 1/(yu*yv)}, yw])/64 - 
     (G[{0}, yu^(-1)]*G[{1, 1/(yu*yv)}, yw]^2)/16 - 
     (G[{0}, yv^(-1)]*G[{1, 1/(yu*yv)}, yw]^2)/16 + 
     (G[{0}, yw]*G[{1, 1/(yu*yv)}, yw]^2)/16 + 
     (G[{1}, yu^(-1)]*G[{1, 1/(yu*yv)}, yw]^2)/8 - 
     (G[{1}, yv^(-1)]*G[{1, 1/(yu*yv)}, yw]^2)/32 - 
     (G[{1}, yw]*G[{1, 1/(yu*yv)}, yw]^2)/32 + 
     (G[{yu}, yv^(-1)]*G[{1, 1/(yu*yv)}, yw]^2)/32 - 
     (5*G[{1/(yu*yv)}, yw]*G[{1, 1/(yu*yv)}, yw]^2)/128 - 
     (Pi^2*G[{0}, yu^(-1)]*G[{yu^(-1), 1/(yu*yv)}, yw])/96 - 
     (Pi^2*G[{0}, yv^(-1)]*G[{yu^(-1), 1/(yu*yv)}, yw])/96 + 
     (Pi^2*G[{0}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw])/96 - 
     (Pi^2*G[{1}, yu^(-1)]*G[{yu^(-1), 1/(yu*yv)}, yw])/96 + 
     (19*Pi^2*G[{1}, yv^(-1)]*G[{yu^(-1), 1/(yu*yv)}, yw])/768 - 
     (3*G[{0}, yu^(-1)]^2*G[{1}, yv^(-1)]*G[{yu^(-1), 1/(yu*yv)}, yw])/64 - 
     (3*G[{0}, yu^(-1)]*G[{0}, yv^(-1)]*G[{1}, yv^(-1)]*
       G[{yu^(-1), 1/(yu*yv)}, yw])/32 - (3*G[{0}, yv^(-1)]^2*G[{1}, yv^(-1)]*
       G[{yu^(-1), 1/(yu*yv)}, yw])/64 + (3*G[{0}, yu^(-1)]*G[{0}, yw]*
       G[{1}, yv^(-1)]*G[{yu^(-1), 1/(yu*yv)}, yw])/32 + 
     (3*G[{0}, yv^(-1)]*G[{0}, yw]*G[{1}, yv^(-1)]*G[{yu^(-1), 1/(yu*yv)}, 
        yw])/32 - (3*G[{0}, yw]^2*G[{1}, yv^(-1)]*G[{yu^(-1), 1/(yu*yv)}, 
        yw])/64 - (G[{0}, yu^(-1)]*G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*
       G[{yu^(-1), 1/(yu*yv)}, yw])/32 - (G[{0}, yv^(-1)]*G[{1}, yu^(-1)]*
       G[{1}, yv^(-1)]*G[{yu^(-1), 1/(yu*yv)}, yw])/32 + 
     (G[{0}, yw]*G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*G[{yu^(-1), 1/(yu*yv)}, yw])/
      32 + (5*G[{1}, yu^(-1)]^2*G[{1}, yv^(-1)]*G[{yu^(-1), 1/(yu*yv)}, yw])/
      64 + (G[{0}, yu^(-1)]*G[{1}, yv^(-1)]^2*G[{yu^(-1), 1/(yu*yv)}, yw])/
      8 + (G[{0}, yv^(-1)]*G[{1}, yv^(-1)]^2*G[{yu^(-1), 1/(yu*yv)}, yw])/8 - 
     (G[{0}, yw]*G[{1}, yv^(-1)]^2*G[{yu^(-1), 1/(yu*yv)}, yw])/8 - 
     (13*G[{1}, yv^(-1)]^3*G[{yu^(-1), 1/(yu*yv)}, yw])/128 - 
     (7*Pi^2*G[{1}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw])/256 - 
     (3*G[{0}, yu^(-1)]^2*G[{1}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw])/64 - 
     (3*G[{0}, yu^(-1)]*G[{0}, yv^(-1)]*G[{1}, yw]*G[{yu^(-1), 1/(yu*yv)}, 
        yw])/32 - (3*G[{0}, yv^(-1)]^2*G[{1}, yw]*G[{yu^(-1), 1/(yu*yv)}, 
        yw])/64 + (3*G[{0}, yu^(-1)]*G[{0}, yw]*G[{1}, yw]*
       G[{yu^(-1), 1/(yu*yv)}, yw])/32 + (3*G[{0}, yv^(-1)]*G[{0}, yw]*
       G[{1}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw])/32 - 
     (3*G[{0}, yw]^2*G[{1}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw])/64 + 
     (3*G[{0}, yu^(-1)]*G[{1}, yu^(-1)]*G[{1}, yw]*G[{yu^(-1), 1/(yu*yv)}, 
        yw])/32 + (3*G[{0}, yv^(-1)]*G[{1}, yu^(-1)]*G[{1}, yw]*
       G[{yu^(-1), 1/(yu*yv)}, yw])/32 - (3*G[{0}, yw]*G[{1}, yu^(-1)]*
       G[{1}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw])/32 - 
     (3*G[{1}, yu^(-1)]^2*G[{1}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw])/64 - 
     (G[{0}, yu^(-1)]*G[{1}, yv^(-1)]*G[{1}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw])/
      16 - (G[{0}, yv^(-1)]*G[{1}, yv^(-1)]*G[{1}, yw]*
       G[{yu^(-1), 1/(yu*yv)}, yw])/16 + 
     (G[{0}, yw]*G[{1}, yv^(-1)]*G[{1}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw])/16 - 
     (G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*G[{1}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw])/
      16 + (5*G[{1}, yv^(-1)]^2*G[{1}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw])/128 - 
     (G[{0}, yu^(-1)]*G[{1}, yw]^2*G[{yu^(-1), 1/(yu*yv)}, yw])/8 - 
     (G[{0}, yv^(-1)]*G[{1}, yw]^2*G[{yu^(-1), 1/(yu*yv)}, yw])/8 + 
     (G[{0}, yw]*G[{1}, yw]^2*G[{yu^(-1), 1/(yu*yv)}, yw])/8 + 
     (G[{1}, yu^(-1)]*G[{1}, yw]^2*G[{yu^(-1), 1/(yu*yv)}, yw])/8 + 
     (7*G[{1}, yv^(-1)]*G[{1}, yw]^2*G[{yu^(-1), 1/(yu*yv)}, yw])/128 - 
     (3*G[{1}, yw]^3*G[{yu^(-1), 1/(yu*yv)}, yw])/128 - 
     (Pi^2*G[{yu^(-1)}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw])/256 + 
     (3*G[{0}, yu^(-1)]^2*G[{yu^(-1)}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw])/64 + 
     (3*G[{0}, yu^(-1)]*G[{0}, yv^(-1)]*G[{yu^(-1)}, yw]*
       G[{yu^(-1), 1/(yu*yv)}, yw])/32 + 
     (3*G[{0}, yv^(-1)]^2*G[{yu^(-1)}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw])/64 - 
     (3*G[{0}, yu^(-1)]*G[{0}, yw]*G[{yu^(-1)}, yw]*G[{yu^(-1), 1/(yu*yv)}, 
        yw])/32 - (3*G[{0}, yv^(-1)]*G[{0}, yw]*G[{yu^(-1)}, yw]*
       G[{yu^(-1), 1/(yu*yv)}, yw])/32 + (3*G[{0}, yw]^2*G[{yu^(-1)}, yw]*
       G[{yu^(-1), 1/(yu*yv)}, yw])/64 - (3*G[{0}, yu^(-1)]*G[{1}, yu^(-1)]*
       G[{yu^(-1)}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw])/32 - 
     (3*G[{0}, yv^(-1)]*G[{1}, yu^(-1)]*G[{yu^(-1)}, yw]*
       G[{yu^(-1), 1/(yu*yv)}, yw])/32 + (3*G[{0}, yw]*G[{1}, yu^(-1)]*
       G[{yu^(-1)}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw])/32 + 
     (3*G[{1}, yu^(-1)]^2*G[{yu^(-1)}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw])/64 - 
     (3*G[{0}, yu^(-1)]*G[{1}, yv^(-1)]*G[{yu^(-1)}, yw]*
       G[{yu^(-1), 1/(yu*yv)}, yw])/32 - (3*G[{0}, yv^(-1)]*G[{1}, yv^(-1)]*
       G[{yu^(-1)}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw])/32 + 
     (3*G[{0}, yw]*G[{1}, yv^(-1)]*G[{yu^(-1)}, yw]*G[{yu^(-1), 1/(yu*yv)}, 
        yw])/32 + (3*G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*G[{yu^(-1)}, yw]*
       G[{yu^(-1), 1/(yu*yv)}, yw])/32 + (G[{1}, yv^(-1)]^2*G[{yu^(-1)}, yw]*
       G[{yu^(-1), 1/(yu*yv)}, yw])/32 + (7*G[{0}, yu^(-1)]*G[{1}, yw]*
       G[{yu^(-1)}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw])/32 + 
     (7*G[{0}, yv^(-1)]*G[{1}, yw]*G[{yu^(-1)}, yw]*G[{yu^(-1), 1/(yu*yv)}, 
        yw])/32 - (7*G[{0}, yw]*G[{1}, yw]*G[{yu^(-1)}, yw]*
       G[{yu^(-1), 1/(yu*yv)}, yw])/32 - (7*G[{1}, yu^(-1)]*G[{1}, yw]*
       G[{yu^(-1)}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw])/32 - 
     (G[{1}, yv^(-1)]*G[{1}, yw]*G[{yu^(-1)}, yw]*G[{yu^(-1), 1/(yu*yv)}, 
        yw])/4 - (G[{1}, yw]^2*G[{yu^(-1)}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw])/
      64 - (G[{0}, yu^(-1)]*G[{yu^(-1)}, yw]^2*G[{yu^(-1), 1/(yu*yv)}, yw])/
      16 - (G[{0}, yv^(-1)]*G[{yu^(-1)}, yw]^2*G[{yu^(-1), 1/(yu*yv)}, yw])/
      16 + (G[{0}, yw]*G[{yu^(-1)}, yw]^2*G[{yu^(-1), 1/(yu*yv)}, yw])/16 + 
     (G[{1}, yu^(-1)]*G[{yu^(-1)}, yw]^2*G[{yu^(-1), 1/(yu*yv)}, yw])/16 + 
     (11*G[{1}, yv^(-1)]*G[{yu^(-1)}, yw]^2*G[{yu^(-1), 1/(yu*yv)}, yw])/64 + 
     (7*G[{1}, yw]*G[{yu^(-1)}, yw]^2*G[{yu^(-1), 1/(yu*yv)}, yw])/64 - 
     (11*G[{yu^(-1)}, yw]^3*G[{yu^(-1), 1/(yu*yv)}, yw])/192 + 
     (5*Pi^2*G[{yu}, yv^(-1)]*G[{yu^(-1), 1/(yu*yv)}, yw])/768 + 
     (3*G[{0}, yu^(-1)]^2*G[{yu}, yv^(-1)]*G[{yu^(-1), 1/(yu*yv)}, yw])/64 + 
     (3*G[{0}, yu^(-1)]*G[{0}, yv^(-1)]*G[{yu}, yv^(-1)]*
       G[{yu^(-1), 1/(yu*yv)}, yw])/32 + 
     (3*G[{0}, yv^(-1)]^2*G[{yu}, yv^(-1)]*G[{yu^(-1), 1/(yu*yv)}, yw])/64 - 
     (3*G[{0}, yu^(-1)]*G[{0}, yw]*G[{yu}, yv^(-1)]*G[{yu^(-1), 1/(yu*yv)}, 
        yw])/32 - (3*G[{0}, yv^(-1)]*G[{0}, yw]*G[{yu}, yv^(-1)]*
       G[{yu^(-1), 1/(yu*yv)}, yw])/32 + (3*G[{0}, yw]^2*G[{yu}, yv^(-1)]*
       G[{yu^(-1), 1/(yu*yv)}, yw])/64 + (G[{0}, yu^(-1)]*G[{1}, yu^(-1)]*
       G[{yu}, yv^(-1)]*G[{yu^(-1), 1/(yu*yv)}, yw])/32 + 
     (G[{0}, yv^(-1)]*G[{1}, yu^(-1)]*G[{yu}, yv^(-1)]*
       G[{yu^(-1), 1/(yu*yv)}, yw])/32 - 
     (G[{0}, yw]*G[{1}, yu^(-1)]*G[{yu}, yv^(-1)]*G[{yu^(-1), 1/(yu*yv)}, 
        yw])/32 - (5*G[{1}, yu^(-1)]^2*G[{yu}, yv^(-1)]*
       G[{yu^(-1), 1/(yu*yv)}, yw])/64 + (G[{0}, yu^(-1)]*G[{1}, yv^(-1)]*
       G[{yu}, yv^(-1)]*G[{yu^(-1), 1/(yu*yv)}, yw])/32 + 
     (G[{0}, yv^(-1)]*G[{1}, yv^(-1)]*G[{yu}, yv^(-1)]*
       G[{yu^(-1), 1/(yu*yv)}, yw])/32 - 
     (G[{0}, yw]*G[{1}, yv^(-1)]*G[{yu}, yv^(-1)]*G[{yu^(-1), 1/(yu*yv)}, 
        yw])/32 + (3*G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*G[{yu}, yv^(-1)]*
       G[{yu^(-1), 1/(yu*yv)}, yw])/32 - (G[{1}, yv^(-1)]^2*G[{yu}, yv^(-1)]*
       G[{yu^(-1), 1/(yu*yv)}, yw])/8 + (5*G[{0}, yu^(-1)]*G[{1}, yw]*
       G[{yu}, yv^(-1)]*G[{yu^(-1), 1/(yu*yv)}, yw])/32 + 
     (5*G[{0}, yv^(-1)]*G[{1}, yw]*G[{yu}, yv^(-1)]*G[{yu^(-1), 1/(yu*yv)}, 
        yw])/32 - (5*G[{0}, yw]*G[{1}, yw]*G[{yu}, yv^(-1)]*
       G[{yu^(-1), 1/(yu*yv)}, yw])/32 - 
     (G[{1}, yu^(-1)]*G[{1}, yw]*G[{yu}, yv^(-1)]*G[{yu^(-1), 1/(yu*yv)}, 
        yw])/32 - (3*G[{1}, yv^(-1)]*G[{1}, yw]*G[{yu}, yv^(-1)]*
       G[{yu^(-1), 1/(yu*yv)}, yw])/32 + (9*G[{1}, yw]^2*G[{yu}, yv^(-1)]*
       G[{yu^(-1), 1/(yu*yv)}, yw])/128 + 
     (7*G[{1}, yv^(-1)]*G[{yu^(-1)}, yw]*G[{yu}, yv^(-1)]*
       G[{yu^(-1), 1/(yu*yv)}, yw])/32 + 
     (G[{1}, yw]*G[{yu^(-1)}, yw]*G[{yu}, yv^(-1)]*G[{yu^(-1), 1/(yu*yv)}, 
        yw])/32 - (7*G[{yu^(-1)}, yw]^2*G[{yu}, yv^(-1)]*
       G[{yu^(-1), 1/(yu*yv)}, yw])/64 - (G[{0}, yu^(-1)]*G[{yu}, yv^(-1)]^2*
       G[{yu^(-1), 1/(yu*yv)}, yw])/8 - (G[{0}, yv^(-1)]*G[{yu}, yv^(-1)]^2*
       G[{yu^(-1), 1/(yu*yv)}, yw])/8 + (G[{0}, yw]*G[{yu}, yv^(-1)]^2*
       G[{yu^(-1), 1/(yu*yv)}, yw])/8 + (7*G[{1}, yv^(-1)]*G[{yu}, yv^(-1)]^2*
       G[{yu^(-1), 1/(yu*yv)}, yw])/64 - (3*G[{1}, yw]*G[{yu}, yv^(-1)]^2*
       G[{yu^(-1), 1/(yu*yv)}, yw])/32 - 
     (7*G[{yu^(-1)}, yw]*G[{yu}, yv^(-1)]^2*G[{yu^(-1), 1/(yu*yv)}, yw])/64 + 
     (3*G[{yu}, yv^(-1)]^3*G[{yu^(-1), 1/(yu*yv)}, yw])/64 - 
     (5*Pi^2*G[{1/(yu*yv)}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw])/768 + 
     (3*G[{0}, yu^(-1)]^2*G[{1/(yu*yv)}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw])/
      128 + (3*G[{0}, yu^(-1)]*G[{0}, yv^(-1)]*G[{1/(yu*yv)}, yw]*
       G[{yu^(-1), 1/(yu*yv)}, yw])/64 + 
     (3*G[{0}, yv^(-1)]^2*G[{1/(yu*yv)}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw])/
      128 - (3*G[{0}, yu^(-1)]*G[{0}, yw]*G[{1/(yu*yv)}, yw]*
       G[{yu^(-1), 1/(yu*yv)}, yw])/64 - (3*G[{0}, yv^(-1)]*G[{0}, yw]*
       G[{1/(yu*yv)}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw])/64 + 
     (3*G[{0}, yw]^2*G[{1/(yu*yv)}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw])/128 + 
     (5*G[{0}, yu^(-1)]*G[{1}, yu^(-1)]*G[{1/(yu*yv)}, yw]*
       G[{yu^(-1), 1/(yu*yv)}, yw])/64 + (5*G[{0}, yv^(-1)]*G[{1}, yu^(-1)]*
       G[{1/(yu*yv)}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw])/64 - 
     (5*G[{0}, yw]*G[{1}, yu^(-1)]*G[{1/(yu*yv)}, yw]*G[{yu^(-1), 1/(yu*yv)}, 
        yw])/64 - (5*G[{1}, yu^(-1)]^2*G[{1/(yu*yv)}, yw]*
       G[{yu^(-1), 1/(yu*yv)}, yw])/128 - 
     (5*G[{0}, yu^(-1)]*G[{1}, yv^(-1)]*G[{1/(yu*yv)}, yw]*
       G[{yu^(-1), 1/(yu*yv)}, yw])/64 - (5*G[{0}, yv^(-1)]*G[{1}, yv^(-1)]*
       G[{1/(yu*yv)}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw])/64 + 
     (5*G[{0}, yw]*G[{1}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{yu^(-1), 1/(yu*yv)}, 
        yw])/64 - (11*G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*G[{1/(yu*yv)}, yw]*
       G[{yu^(-1), 1/(yu*yv)}, yw])/64 + 
     (3*G[{1}, yv^(-1)]^2*G[{1/(yu*yv)}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw])/
      64 + (13*G[{0}, yu^(-1)]*G[{1}, yw]*G[{1/(yu*yv)}, yw]*
       G[{yu^(-1), 1/(yu*yv)}, yw])/64 + (13*G[{0}, yv^(-1)]*G[{1}, yw]*
       G[{1/(yu*yv)}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw])/64 - 
     (13*G[{0}, yw]*G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{yu^(-1), 1/(yu*yv)}, 
        yw])/64 - (13*G[{1}, yu^(-1)]*G[{1}, yw]*G[{1/(yu*yv)}, yw]*
       G[{yu^(-1), 1/(yu*yv)}, yw])/64 - (11*G[{1}, yv^(-1)]*G[{1}, yw]*
       G[{1/(yu*yv)}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw])/32 - 
     (9*G[{1}, yw]^2*G[{1/(yu*yv)}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw])/128 - 
     (G[{0}, yu^(-1)]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*
       G[{yu^(-1), 1/(yu*yv)}, yw])/32 - (G[{0}, yv^(-1)]*G[{yu^(-1)}, yw]*
       G[{1/(yu*yv)}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw])/32 + 
     (G[{0}, yw]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{yu^(-1), 1/(yu*yv)}, 
        yw])/32 + (9*G[{1}, yu^(-1)]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*
       G[{yu^(-1), 1/(yu*yv)}, yw])/32 + (5*G[{1}, yv^(-1)]*G[{yu^(-1)}, yw]*
       G[{1/(yu*yv)}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw])/64 + 
     (19*G[{1}, yw]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*
       G[{yu^(-1), 1/(yu*yv)}, yw])/64 - 
     (5*G[{yu^(-1)}, yw]^2*G[{1/(yu*yv)}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw])/
      128 - (3*G[{0}, yu^(-1)]*G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw]*
       G[{yu^(-1), 1/(yu*yv)}, yw])/32 - (3*G[{0}, yv^(-1)]*G[{yu}, yv^(-1)]*
       G[{1/(yu*yv)}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw])/32 + 
     (3*G[{0}, yw]*G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw]*
       G[{yu^(-1), 1/(yu*yv)}, yw])/32 + (3*G[{1}, yu^(-1)]*G[{yu}, yv^(-1)]*
       G[{1/(yu*yv)}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw])/32 + 
     (19*G[{1}, yv^(-1)]*G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw]*
       G[{yu^(-1), 1/(yu*yv)}, yw])/64 + (9*G[{1}, yw]*G[{yu}, yv^(-1)]*
       G[{1/(yu*yv)}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw])/64 - 
     (19*G[{yu^(-1)}, yw]*G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw]*
       G[{yu^(-1), 1/(yu*yv)}, yw])/64 - 
     (13*G[{yu}, yv^(-1)]^2*G[{1/(yu*yv)}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw])/
      128 - (G[{0}, yu^(-1)]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*
       G[{yu^(-1), 1/(yu*yv)}, yw])/16 - (G[{0}, yv^(-1)]*G[{yv^(-1)}, yw]*
       G[{1/(yu*yv)}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw])/16 + 
     (G[{0}, yw]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{yu^(-1), 1/(yu*yv)}, 
        yw])/16 + (G[{1}, yu^(-1)]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*
       G[{yu^(-1), 1/(yu*yv)}, yw])/8 + (G[{1}, yv^(-1)]*G[{yv^(-1)}, yw]*
       G[{1/(yu*yv)}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw])/32 + 
     (G[{1}, yw]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{yu^(-1), 1/(yu*yv)}, 
        yw])/32 - (G[{yu^(-1)}, yw]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*
       G[{yu^(-1), 1/(yu*yv)}, yw])/32 - (G[{yu}, yv^(-1)]*G[{yv^(-1)}, yw]*
       G[{1/(yu*yv)}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw])/32 - 
     (3*G[{yv^(-1)}, yw]^2*G[{1/(yu*yv)}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw])/
      32 + (3*G[{0}, yu^(-1)]*G[{1/(yu*yv)}, yw]^2*G[{yu^(-1), 1/(yu*yv)}, 
        yw])/64 + (3*G[{0}, yv^(-1)]*G[{1/(yu*yv)}, yw]^2*
       G[{yu^(-1), 1/(yu*yv)}, yw])/64 - (3*G[{0}, yw]*G[{1/(yu*yv)}, yw]^2*
       G[{yu^(-1), 1/(yu*yv)}, yw])/64 - 
     (5*G[{1}, yu^(-1)]*G[{1/(yu*yv)}, yw]^2*G[{yu^(-1), 1/(yu*yv)}, yw])/
      64 - (G[{1}, yv^(-1)]*G[{1/(yu*yv)}, yw]^2*G[{yu^(-1), 1/(yu*yv)}, yw])/
      64 + (G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2*G[{yu^(-1), 1/(yu*yv)}, 
        yw])/64 + (5*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2*
       G[{yu^(-1), 1/(yu*yv)}, yw])/64 - (G[{1}, yu^(-1)]*G[{0, 1}, yu^(-1)]*
       G[{yu^(-1), 1/(yu*yv)}, yw])/8 - (G[{1}, yw]*G[{0, 1}, yu^(-1)]*
       G[{yu^(-1), 1/(yu*yv)}, yw])/8 + (G[{yu}, yv^(-1)]*G[{0, 1}, yu^(-1)]*
       G[{yu^(-1), 1/(yu*yv)}, yw])/8 - (G[{0}, yu^(-1)]*G[{0, 1}, yv^(-1)]*
       G[{yu^(-1), 1/(yu*yv)}, yw])/16 - (G[{0}, yv^(-1)]*G[{0, 1}, yv^(-1)]*
       G[{yu^(-1), 1/(yu*yv)}, yw])/16 + (G[{0}, yw]*G[{0, 1}, yv^(-1)]*
       G[{yu^(-1), 1/(yu*yv)}, yw])/16 - (G[{1}, yu^(-1)]*G[{0, 1}, yv^(-1)]*
       G[{yu^(-1), 1/(yu*yv)}, yw])/16 + 
     (17*G[{1}, yv^(-1)]*G[{0, 1}, yv^(-1)]*G[{yu^(-1), 1/(yu*yv)}, yw])/64 + 
     (5*G[{1}, yw]*G[{0, 1}, yv^(-1)]*G[{yu^(-1), 1/(yu*yv)}, yw])/64 - 
     (3*G[{yu^(-1)}, yw]*G[{0, 1}, yv^(-1)]*G[{yu^(-1), 1/(yu*yv)}, yw])/16 - 
     (G[{1/(yu*yv)}, yw]*G[{0, 1}, yv^(-1)]*G[{yu^(-1), 1/(yu*yv)}, yw])/16 + 
     (G[{1}, yu^(-1)]*G[{0, 1}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw])/8 - 
     (3*G[{1}, yv^(-1)]*G[{0, 1}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw])/32 - 
     (3*G[{1}, yw]*G[{0, 1}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw])/32 + 
     (7*G[{yu^(-1)}, yw]*G[{0, 1}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw])/32 - 
     (G[{yu}, yv^(-1)]*G[{0, 1}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw])/32 + 
     (7*G[{1/(yu*yv)}, yw]*G[{0, 1}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw])/64 - 
     (G[{1}, yu^(-1)]*G[{0, yu^(-1)}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw])/8 + 
     (3*G[{1}, yv^(-1)]*G[{0, yu^(-1)}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw])/32 + 
     (3*G[{1}, yw]*G[{0, yu^(-1)}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw])/32 - 
     (7*G[{yu^(-1)}, yw]*G[{0, yu^(-1)}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw])/
      32 + (G[{yu}, yv^(-1)]*G[{0, yu^(-1)}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw])/
      32 - (7*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1)}, yw]*G[{yu^(-1), 1/(yu*yv)}, 
        yw])/64 + (G[{0}, yu^(-1)]*G[{0, yu}, yv^(-1)]*
       G[{yu^(-1), 1/(yu*yv)}, yw])/16 + (G[{0}, yv^(-1)]*G[{0, yu}, yv^(-1)]*
       G[{yu^(-1), 1/(yu*yv)}, yw])/16 - (G[{0}, yw]*G[{0, yu}, yv^(-1)]*
       G[{yu^(-1), 1/(yu*yv)}, yw])/16 + (G[{1}, yu^(-1)]*G[{0, yu}, yv^(-1)]*
       G[{yu^(-1), 1/(yu*yv)}, yw])/16 - 
     (17*G[{1}, yv^(-1)]*G[{0, yu}, yv^(-1)]*G[{yu^(-1), 1/(yu*yv)}, yw])/
      64 - (5*G[{1}, yw]*G[{0, yu}, yv^(-1)]*G[{yu^(-1), 1/(yu*yv)}, yw])/
      64 + (3*G[{yu^(-1)}, yw]*G[{0, yu}, yv^(-1)]*G[{yu^(-1), 1/(yu*yv)}, 
        yw])/16 + (G[{1/(yu*yv)}, yw]*G[{0, yu}, yv^(-1)]*
       G[{yu^(-1), 1/(yu*yv)}, yw])/16 - (G[{1}, yu^(-1)]*G[{0, yv^(-1)}, yw]*
       G[{yu^(-1), 1/(yu*yv)}, yw])/8 + 
     (3*G[{1}, yv^(-1)]*G[{0, yv^(-1)}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw])/32 + 
     (3*G[{1}, yw]*G[{0, yv^(-1)}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw])/32 - 
     (7*G[{yu^(-1)}, yw]*G[{0, yv^(-1)}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw])/
      32 + (G[{yu}, yv^(-1)]*G[{0, yv^(-1)}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw])/
      32 - (7*G[{1/(yu*yv)}, yw]*G[{0, yv^(-1)}, yw]*G[{yu^(-1), 1/(yu*yv)}, 
        yw])/64 + (G[{1}, yu^(-1)]*G[{0, 1/(yu*yv)}, yw]*
       G[{yu^(-1), 1/(yu*yv)}, yw])/8 - 
     (3*G[{1}, yv^(-1)]*G[{0, 1/(yu*yv)}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw])/
      32 - (3*G[{1}, yw]*G[{0, 1/(yu*yv)}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw])/
      32 + (7*G[{yu^(-1)}, yw]*G[{0, 1/(yu*yv)}, yw]*G[{yu^(-1), 1/(yu*yv)}, 
        yw])/32 - (G[{yu}, yv^(-1)]*G[{0, 1/(yu*yv)}, yw]*
       G[{yu^(-1), 1/(yu*yv)}, yw])/32 + 
     (7*G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv)}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw])/
      64 - (G[{0}, yu^(-1)]*G[{1, yu^(-1)}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw])/
      16 - (G[{0}, yv^(-1)]*G[{1, yu^(-1)}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw])/
      16 + (G[{0}, yw]*G[{1, yu^(-1)}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw])/16 + 
     (G[{1}, yu^(-1)]*G[{1, yu^(-1)}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw])/16 - 
     (G[{1}, yw]*G[{1, yu^(-1)}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw])/16 + 
     (G[{yu^(-1)}, yw]*G[{1, yu^(-1)}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw])/32 + 
     (G[{yu}, yv^(-1)]*G[{1, yu^(-1)}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw])/16 + 
     (3*G[{1/(yu*yv)}, yw]*G[{1, yu^(-1)}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw])/
      64 - (G[{0}, yu^(-1)]*G[{1, yu}, yv^(-1)]*G[{yu^(-1), 1/(yu*yv)}, yw])/
      16 - (G[{0}, yv^(-1)]*G[{1, yu}, yv^(-1)]*G[{yu^(-1), 1/(yu*yv)}, yw])/
      16 + (G[{0}, yw]*G[{1, yu}, yv^(-1)]*G[{yu^(-1), 1/(yu*yv)}, yw])/16 - 
     (3*G[{1}, yu^(-1)]*G[{1, yu}, yv^(-1)]*G[{yu^(-1), 1/(yu*yv)}, yw])/16 + 
     (3*G[{1}, yv^(-1)]*G[{1, yu}, yv^(-1)]*G[{yu^(-1), 1/(yu*yv)}, yw])/32 + 
     (13*G[{1}, yw]*G[{1, yu}, yv^(-1)]*G[{yu^(-1), 1/(yu*yv)}, yw])/64 - 
     (3*G[{yu^(-1)}, yw]*G[{1, yu}, yv^(-1)]*G[{yu^(-1), 1/(yu*yv)}, yw])/
      16 - (G[{yu}, yv^(-1)]*G[{1, yu}, yv^(-1)]*G[{yu^(-1), 1/(yu*yv)}, yw])/
      8 - (G[{1/(yu*yv)}, yw]*G[{1, yu}, yv^(-1)]*G[{yu^(-1), 1/(yu*yv)}, 
        yw])/16 + (G[{1}, yu^(-1)]*G[{1, yv^(-1)}, yw]*
       G[{yu^(-1), 1/(yu*yv)}, yw])/4 - 
     (3*G[{1}, yv^(-1)]*G[{1, yv^(-1)}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw])/32 + 
     (5*G[{1}, yw]*G[{1, yv^(-1)}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw])/32 + 
     (7*G[{yu^(-1)}, yw]*G[{1, yv^(-1)}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw])/
      32 - (5*G[{yu}, yv^(-1)]*G[{1, yv^(-1)}, yw]*G[{yu^(-1), 1/(yu*yv)}, 
        yw])/32 + (7*G[{1/(yu*yv)}, yw]*G[{1, yv^(-1)}, yw]*
       G[{yu^(-1), 1/(yu*yv)}, yw])/64 + 
     (G[{0}, yu^(-1)]*G[{1, 1/(yu*yv)}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw])/16 + 
     (G[{0}, yv^(-1)]*G[{1, 1/(yu*yv)}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw])/16 - 
     (G[{0}, yw]*G[{1, 1/(yu*yv)}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw])/16 - 
     (G[{1}, yu^(-1)]*G[{1, 1/(yu*yv)}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw])/16 - 
     (3*G[{1}, yv^(-1)]*G[{1, 1/(yu*yv)}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw])/
      32 - (G[{1}, yw]*G[{1, 1/(yu*yv)}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw])/
      32 + (3*G[{yu^(-1)}, yw]*G[{1, 1/(yu*yv)}, yw]*G[{yu^(-1), 1/(yu*yv)}, 
        yw])/16 + (G[{yu}, yv^(-1)]*G[{1, 1/(yu*yv)}, yw]*
       G[{yu^(-1), 1/(yu*yv)}, yw])/32 + 
     (G[{1/(yu*yv)}, yw]*G[{1, 1/(yu*yv)}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw])/
      16 - (G[{0}, yu^(-1)]*G[{yu^(-1), 1/(yu*yv)}, yw]^2)/32 - 
     (G[{0}, yv^(-1)]*G[{yu^(-1), 1/(yu*yv)}, yw]^2)/32 + 
     (G[{0}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw]^2)/32 - 
     (3*G[{1}, yu^(-1)]*G[{yu^(-1), 1/(yu*yv)}, yw]^2)/32 + 
     (3*G[{1}, yv^(-1)]*G[{yu^(-1), 1/(yu*yv)}, yw]^2)/32 - 
     (G[{1}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw]^2)/16 - 
     (3*G[{yu^(-1)}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw]^2)/32 + 
     (G[{yu}, yv^(-1)]*G[{yu^(-1), 1/(yu*yv)}, yw]^2)/16 - 
     (11*G[{1/(yu*yv)}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw]^2)/128 + 
     (Pi^2*G[{0}, yu^(-1)]*G[{yv^(-1), 1/(yu*yv)}, yw])/96 + 
     (Pi^2*G[{0}, yv^(-1)]*G[{yv^(-1), 1/(yu*yv)}, yw])/96 - 
     (Pi^2*G[{0}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw])/96 + 
     (Pi^2*G[{1}, yu^(-1)]*G[{yv^(-1), 1/(yu*yv)}, yw])/48 - 
     (G[{0}, yu^(-1)]*G[{1}, yu^(-1)]^2*G[{yv^(-1), 1/(yu*yv)}, yw])/32 - 
     (G[{0}, yv^(-1)]*G[{1}, yu^(-1)]^2*G[{yv^(-1), 1/(yu*yv)}, yw])/32 + 
     (G[{0}, yw]*G[{1}, yu^(-1)]^2*G[{yv^(-1), 1/(yu*yv)}, yw])/32 + 
     (G[{1}, yu^(-1)]^3*G[{yv^(-1), 1/(yu*yv)}, yw])/32 - 
     (Pi^2*G[{1}, yv^(-1)]*G[{yv^(-1), 1/(yu*yv)}, yw])/24 + 
     (G[{0}, yu^(-1)]*G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*G[{yv^(-1), 1/(yu*yv)}, 
        yw])/16 + (G[{0}, yv^(-1)]*G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*
       G[{yv^(-1), 1/(yu*yv)}, yw])/16 - 
     (G[{0}, yw]*G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*G[{yv^(-1), 1/(yu*yv)}, yw])/
      16 - (G[{1}, yu^(-1)]^2*G[{1}, yv^(-1)]*G[{yv^(-1), 1/(yu*yv)}, yw])/
      32 - (G[{0}, yu^(-1)]*G[{1}, yv^(-1)]^2*G[{yv^(-1), 1/(yu*yv)}, yw])/
      16 - (G[{0}, yv^(-1)]*G[{1}, yv^(-1)]^2*G[{yv^(-1), 1/(yu*yv)}, yw])/
      16 + (G[{0}, yw]*G[{1}, yv^(-1)]^2*G[{yv^(-1), 1/(yu*yv)}, yw])/16 + 
     (5*G[{1}, yv^(-1)]^3*G[{yv^(-1), 1/(yu*yv)}, yw])/128 + 
     (Pi^2*G[{1}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw])/96 + 
     (G[{0}, yu^(-1)]*G[{1}, yu^(-1)]*G[{1}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw])/
      16 + (G[{0}, yv^(-1)]*G[{1}, yu^(-1)]*G[{1}, yw]*
       G[{yv^(-1), 1/(yu*yv)}, yw])/16 - 
     (G[{0}, yw]*G[{1}, yu^(-1)]*G[{1}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw])/16 - 
     (3*G[{1}, yu^(-1)]^2*G[{1}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw])/32 - 
     (G[{0}, yu^(-1)]*G[{1}, yv^(-1)]*G[{1}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw])/
      8 - (G[{0}, yv^(-1)]*G[{1}, yv^(-1)]*G[{1}, yw]*G[{yv^(-1), 1/(yu*yv)}, 
        yw])/8 + (G[{0}, yw]*G[{1}, yv^(-1)]*G[{1}, yw]*
       G[{yv^(-1), 1/(yu*yv)}, yw])/8 + (G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*
       G[{1}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw])/8 + 
     (19*G[{1}, yv^(-1)]^2*G[{1}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw])/128 + 
     (G[{1}, yu^(-1)]*G[{1}, yw]^2*G[{yv^(-1), 1/(yu*yv)}, yw])/32 + 
     (11*G[{1}, yv^(-1)]*G[{1}, yw]^2*G[{yv^(-1), 1/(yu*yv)}, yw])/128 + 
     (5*G[{1}, yw]^3*G[{yv^(-1), 1/(yu*yv)}, yw])/128 + 
     (Pi^2*G[{yu^(-1)}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw])/32 - 
     (G[{0}, yu^(-1)]*G[{1}, yu^(-1)]*G[{yu^(-1)}, yw]*
       G[{yv^(-1), 1/(yu*yv)}, yw])/8 - (G[{0}, yv^(-1)]*G[{1}, yu^(-1)]*
       G[{yu^(-1)}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw])/8 + 
     (G[{0}, yw]*G[{1}, yu^(-1)]*G[{yu^(-1)}, yw]*G[{yv^(-1), 1/(yu*yv)}, 
        yw])/8 + (G[{1}, yu^(-1)]^2*G[{yu^(-1)}, yw]*G[{yv^(-1), 1/(yu*yv)}, 
        yw])/8 + (G[{0}, yu^(-1)]*G[{1}, yv^(-1)]*G[{yu^(-1)}, yw]*
       G[{yv^(-1), 1/(yu*yv)}, yw])/8 + (G[{0}, yv^(-1)]*G[{1}, yv^(-1)]*
       G[{yu^(-1)}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw])/8 - 
     (G[{0}, yw]*G[{1}, yv^(-1)]*G[{yu^(-1)}, yw]*G[{yv^(-1), 1/(yu*yv)}, 
        yw])/8 - (3*G[{1}, yv^(-1)]^2*G[{yu^(-1)}, yw]*
       G[{yv^(-1), 1/(yu*yv)}, yw])/32 - 
     (G[{1}, yu^(-1)]*G[{1}, yw]*G[{yu^(-1)}, yw]*G[{yv^(-1), 1/(yu*yv)}, 
        yw])/8 - (G[{1}, yv^(-1)]*G[{1}, yw]*G[{yu^(-1)}, yw]*
       G[{yv^(-1), 1/(yu*yv)}, yw])/16 - (3*G[{1}, yw]^2*G[{yu^(-1)}, yw]*
       G[{yv^(-1), 1/(yu*yv)}, yw])/32 - (G[{0}, yu^(-1)]*G[{yu^(-1)}, yw]^2*
       G[{yv^(-1), 1/(yu*yv)}, yw])/16 - (G[{0}, yv^(-1)]*G[{yu^(-1)}, yw]^2*
       G[{yv^(-1), 1/(yu*yv)}, yw])/16 + (G[{0}, yw]*G[{yu^(-1)}, yw]^2*
       G[{yv^(-1), 1/(yu*yv)}, yw])/16 + (G[{1}, yu^(-1)]*G[{yu^(-1)}, yw]^2*
       G[{yv^(-1), 1/(yu*yv)}, yw])/16 + (G[{1}, yv^(-1)]*G[{yu^(-1)}, yw]^2*
       G[{yv^(-1), 1/(yu*yv)}, yw])/16 - 
     (G[{yu^(-1)}, yw]^3*G[{yv^(-1), 1/(yu*yv)}, yw])/48 + 
     (G[{0}, yu^(-1)]*G[{1}, yw]*G[{yu}, yv^(-1)]*G[{yv^(-1), 1/(yu*yv)}, 
        yw])/16 + (G[{0}, yv^(-1)]*G[{1}, yw]*G[{yu}, yv^(-1)]*
       G[{yv^(-1), 1/(yu*yv)}, yw])/16 - 
     (G[{0}, yw]*G[{1}, yw]*G[{yu}, yv^(-1)]*G[{yv^(-1), 1/(yu*yv)}, yw])/
      16 - (G[{1}, yu^(-1)]*G[{1}, yw]*G[{yu}, yv^(-1)]*
       G[{yv^(-1), 1/(yu*yv)}, yw])/16 - (7*G[{1}, yv^(-1)]*G[{1}, yw]*
       G[{yu}, yv^(-1)]*G[{yv^(-1), 1/(yu*yv)}, yw])/32 - 
     (15*G[{1}, yw]^2*G[{yu}, yv^(-1)]*G[{yv^(-1), 1/(yu*yv)}, yw])/128 + 
     (3*G[{1}, yw]*G[{yu^(-1)}, yw]*G[{yu}, yv^(-1)]*G[{yv^(-1), 1/(yu*yv)}, 
        yw])/16 + (5*G[{1}, yw]*G[{yu}, yv^(-1)]^2*G[{yv^(-1), 1/(yu*yv)}, 
        yw])/64 - (Pi^2*G[{yv^(-1)}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw])/32 - 
     (G[{1}, yu^(-1)]^2*G[{yv^(-1)}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw])/16 + 
     (G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*G[{yv^(-1)}, yw]*
       G[{yv^(-1), 1/(yu*yv)}, yw])/8 - (5*G[{1}, yv^(-1)]^2*G[{yv^(-1)}, yw]*
       G[{yv^(-1), 1/(yu*yv)}, yw])/32 - 
     (G[{0}, yu^(-1)]*G[{1}, yw]*G[{yv^(-1)}, yw]*G[{yv^(-1), 1/(yu*yv)}, 
        yw])/8 - (G[{0}, yv^(-1)]*G[{1}, yw]*G[{yv^(-1)}, yw]*
       G[{yv^(-1), 1/(yu*yv)}, yw])/8 + 
     (G[{0}, yw]*G[{1}, yw]*G[{yv^(-1)}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw])/8 + 
     (G[{1}, yu^(-1)]*G[{1}, yw]*G[{yv^(-1)}, yw]*G[{yv^(-1), 1/(yu*yv)}, 
        yw])/4 + (G[{1}, yv^(-1)]*G[{1}, yw]*G[{yv^(-1)}, yw]*
       G[{yv^(-1), 1/(yu*yv)}, yw])/16 + (G[{1}, yw]^2*G[{yv^(-1)}, yw]*
       G[{yv^(-1), 1/(yu*yv)}, yw])/32 + (G[{0}, yu^(-1)]*G[{yu^(-1)}, yw]*
       G[{yv^(-1)}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw])/8 + 
     (G[{0}, yv^(-1)]*G[{yu^(-1)}, yw]*G[{yv^(-1)}, yw]*
       G[{yv^(-1), 1/(yu*yv)}, yw])/8 - (G[{0}, yw]*G[{yu^(-1)}, yw]*
       G[{yv^(-1)}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw])/8 - 
     (3*G[{1}, yu^(-1)]*G[{yu^(-1)}, yw]*G[{yv^(-1)}, yw]*
       G[{yv^(-1), 1/(yu*yv)}, yw])/8 + (G[{1}, yv^(-1)]*G[{yu^(-1)}, yw]*
       G[{yv^(-1)}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw])/8 - 
     (G[{yu^(-1)}, yw]^2*G[{yv^(-1)}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw])/16 - 
     (G[{1}, yw]*G[{yu}, yv^(-1)]*G[{yv^(-1)}, yw]*G[{yv^(-1), 1/(yu*yv)}, 
        yw])/16 + (G[{0}, yu^(-1)]*G[{yv^(-1)}, yw]^2*G[{yv^(-1), 1/(yu*yv)}, 
        yw])/16 + (G[{0}, yv^(-1)]*G[{yv^(-1)}, yw]^2*G[{yv^(-1), 1/(yu*yv)}, 
        yw])/16 - (G[{0}, yw]*G[{yv^(-1)}, yw]^2*G[{yv^(-1), 1/(yu*yv)}, yw])/
      16 + (G[{1}, yu^(-1)]*G[{yv^(-1)}, yw]^2*G[{yv^(-1), 1/(yu*yv)}, yw])/
      16 - (3*G[{1}, yv^(-1)]*G[{yv^(-1)}, yw]^2*G[{yv^(-1), 1/(yu*yv)}, yw])/
      16 + (3*G[{yu^(-1)}, yw]*G[{yv^(-1)}, yw]^2*G[{yv^(-1), 1/(yu*yv)}, 
        yw])/16 - (G[{yv^(-1)}, yw]^3*G[{yv^(-1), 1/(yu*yv)}, yw])/48 + 
     (G[{0}, yu^(-1)]*G[{1}, yv^(-1)]*G[{1/(yu*yv)}, yw]*
       G[{yv^(-1), 1/(yu*yv)}, yw])/16 + (G[{0}, yv^(-1)]*G[{1}, yv^(-1)]*
       G[{1/(yu*yv)}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw])/16 - 
     (G[{0}, yw]*G[{1}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{yv^(-1), 1/(yu*yv)}, 
        yw])/16 - (G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*G[{1/(yu*yv)}, yw]*
       G[{yv^(-1), 1/(yu*yv)}, yw])/16 - 
     (3*G[{1}, yv^(-1)]^2*G[{1/(yu*yv)}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw])/
      128 + (G[{0}, yu^(-1)]*G[{1}, yw]*G[{1/(yu*yv)}, yw]*
       G[{yv^(-1), 1/(yu*yv)}, yw])/8 + (G[{0}, yv^(-1)]*G[{1}, yw]*
       G[{1/(yu*yv)}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw])/8 - 
     (G[{0}, yw]*G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw])/
      8 - (G[{1}, yu^(-1)]*G[{1}, yw]*G[{1/(yu*yv)}, yw]*
       G[{yv^(-1), 1/(yu*yv)}, yw])/16 + 
     (G[{1}, yv^(-1)]*G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{yv^(-1), 1/(yu*yv)}, 
        yw])/64 + (13*G[{1}, yw]^2*G[{1/(yu*yv)}, yw]*G[{yv^(-1), 1/(yu*yv)}, 
        yw])/128 - (G[{0}, yu^(-1)]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*
       G[{yv^(-1), 1/(yu*yv)}, yw])/8 - (G[{0}, yv^(-1)]*G[{yu^(-1)}, yw]*
       G[{1/(yu*yv)}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw])/8 + 
     (G[{0}, yw]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{yv^(-1), 1/(yu*yv)}, 
        yw])/8 + (G[{1}, yu^(-1)]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*
       G[{yv^(-1), 1/(yu*yv)}, yw])/16 + (5*G[{1}, yv^(-1)]*G[{yu^(-1)}, yw]*
       G[{1/(yu*yv)}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw])/32 - 
     (G[{1}, yw]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{yv^(-1), 1/(yu*yv)}, 
        yw])/32 - (5*G[{yu^(-1)}, yw]^2*G[{1/(yu*yv)}, yw]*
       G[{yv^(-1), 1/(yu*yv)}, yw])/64 - (G[{0}, yu^(-1)]*G[{yu}, yv^(-1)]*
       G[{1/(yu*yv)}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw])/16 - 
     (G[{0}, yv^(-1)]*G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw]*
       G[{yv^(-1), 1/(yu*yv)}, yw])/16 + 
     (G[{0}, yw]*G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{yv^(-1), 1/(yu*yv)}, 
        yw])/16 + (G[{1}, yu^(-1)]*G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw]*
       G[{yv^(-1), 1/(yu*yv)}, yw])/16 - (G[{1}, yv^(-1)]*G[{yu}, yv^(-1)]*
       G[{1/(yu*yv)}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw])/32 - 
     (13*G[{1}, yw]*G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw]*
       G[{yv^(-1), 1/(yu*yv)}, yw])/64 + (G[{yu^(-1)}, yw]*G[{yu}, yv^(-1)]*
       G[{1/(yu*yv)}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw])/32 + 
     (3*G[{yu}, yv^(-1)]^2*G[{1/(yu*yv)}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw])/
      64 - (G[{0}, yu^(-1)]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*
       G[{yv^(-1), 1/(yu*yv)}, yw])/16 - (G[{0}, yv^(-1)]*G[{yv^(-1)}, yw]*
       G[{1/(yu*yv)}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw])/16 + 
     (G[{0}, yw]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{yv^(-1), 1/(yu*yv)}, 
        yw])/16 + (G[{1}, yu^(-1)]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*
       G[{yv^(-1), 1/(yu*yv)}, yw])/8 + (G[{1}, yv^(-1)]*G[{yv^(-1)}, yw]*
       G[{1/(yu*yv)}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw])/16 + 
     (G[{1}, yw]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{yv^(-1), 1/(yu*yv)}, 
        yw])/16 - (G[{yu^(-1)}, yw]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*
       G[{yv^(-1), 1/(yu*yv)}, yw])/16 - (G[{yu}, yv^(-1)]*G[{yv^(-1)}, yw]*
       G[{1/(yu*yv)}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw])/16 - 
     (G[{yv^(-1)}, yw]^2*G[{1/(yu*yv)}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw])/16 - 
     (G[{1}, yu^(-1)]*G[{1/(yu*yv)}, yw]^2*G[{yv^(-1), 1/(yu*yv)}, yw])/16 + 
     (G[{1}, yv^(-1)]*G[{1/(yu*yv)}, yw]^2*G[{yv^(-1), 1/(yu*yv)}, yw])/128 - 
     (7*G[{1}, yw]*G[{1/(yu*yv)}, yw]^2*G[{yv^(-1), 1/(yu*yv)}, yw])/128 - 
     (G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2*G[{yv^(-1), 1/(yu*yv)}, yw])/
      128 + (7*G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw]^2*G[{yv^(-1), 1/(yu*yv)}, 
        yw])/128 + (G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2*
       G[{yv^(-1), 1/(yu*yv)}, yw])/16 + (G[{1}, yu^(-1)]*G[{0, 1}, yu^(-1)]*
       G[{yv^(-1), 1/(yu*yv)}, yw])/16 - (G[{1}, yv^(-1)]*G[{0, 1}, yu^(-1)]*
       G[{yv^(-1), 1/(yu*yv)}, yw])/16 - (G[{1}, yw]*G[{0, 1}, yu^(-1)]*
       G[{yv^(-1), 1/(yu*yv)}, yw])/16 + (G[{yu^(-1)}, yw]*G[{0, 1}, yu^(-1)]*
       G[{yv^(-1), 1/(yu*yv)}, yw])/8 - (G[{yv^(-1)}, yw]*G[{0, 1}, yu^(-1)]*
       G[{yv^(-1), 1/(yu*yv)}, yw])/8 - 
     (G[{1/(yu*yv)}, yw]*G[{0, 1}, yu^(-1)]*G[{yv^(-1), 1/(yu*yv)}, yw])/16 + 
     (G[{0}, yu^(-1)]*G[{0, 1}, yv^(-1)]*G[{yv^(-1), 1/(yu*yv)}, yw])/16 + 
     (G[{0}, yv^(-1)]*G[{0, 1}, yv^(-1)]*G[{yv^(-1), 1/(yu*yv)}, yw])/16 - 
     (G[{0}, yw]*G[{0, 1}, yv^(-1)]*G[{yv^(-1), 1/(yu*yv)}, yw])/16 - 
     (G[{1}, yu^(-1)]*G[{0, 1}, yv^(-1)]*G[{yv^(-1), 1/(yu*yv)}, yw])/16 - 
     (5*G[{1}, yv^(-1)]*G[{0, 1}, yv^(-1)]*G[{yv^(-1), 1/(yu*yv)}, yw])/64 - 
     (G[{1}, yw]*G[{0, 1}, yv^(-1)]*G[{yv^(-1), 1/(yu*yv)}, yw])/64 + 
     (G[{yu^(-1)}, yw]*G[{0, 1}, yv^(-1)]*G[{yv^(-1), 1/(yu*yv)}, yw])/16 + 
     (G[{yv^(-1)}, yw]*G[{0, 1}, yv^(-1)]*G[{yv^(-1), 1/(yu*yv)}, yw])/16 - 
     (3*G[{1/(yu*yv)}, yw]*G[{0, 1}, yv^(-1)]*G[{yv^(-1), 1/(yu*yv)}, yw])/
      64 + (G[{1}, yu^(-1)]*G[{0, 1}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw])/16 - 
     (G[{1}, yv^(-1)]*G[{0, 1}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw])/16 + 
     (G[{1}, yw]*G[{0, 1}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw])/16 - 
     (G[{yv^(-1)}, yw]*G[{0, 1}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw])/8 + 
     (G[{1/(yu*yv)}, yw]*G[{0, 1}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw])/16 - 
     (G[{1}, yu^(-1)]*G[{0, yu^(-1)}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw])/16 + 
     (G[{1}, yv^(-1)]*G[{0, yu^(-1)}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw])/16 - 
     (G[{1}, yw]*G[{0, yu^(-1)}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw])/16 + 
     (G[{yv^(-1)}, yw]*G[{0, yu^(-1)}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw])/8 - 
     (G[{1/(yu*yv)}, yw]*G[{0, yu^(-1)}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw])/
      16 - (G[{0}, yu^(-1)]*G[{0, yu}, yv^(-1)]*G[{yv^(-1), 1/(yu*yv)}, yw])/
      16 - (G[{0}, yv^(-1)]*G[{0, yu}, yv^(-1)]*G[{yv^(-1), 1/(yu*yv)}, yw])/
      16 + (G[{0}, yw]*G[{0, yu}, yv^(-1)]*G[{yv^(-1), 1/(yu*yv)}, yw])/16 + 
     (G[{1}, yu^(-1)]*G[{0, yu}, yv^(-1)]*G[{yv^(-1), 1/(yu*yv)}, yw])/16 + 
     (5*G[{1}, yv^(-1)]*G[{0, yu}, yv^(-1)]*G[{yv^(-1), 1/(yu*yv)}, yw])/64 + 
     (G[{1}, yw]*G[{0, yu}, yv^(-1)]*G[{yv^(-1), 1/(yu*yv)}, yw])/64 - 
     (G[{yu^(-1)}, yw]*G[{0, yu}, yv^(-1)]*G[{yv^(-1), 1/(yu*yv)}, yw])/16 - 
     (G[{yv^(-1)}, yw]*G[{0, yu}, yv^(-1)]*G[{yv^(-1), 1/(yu*yv)}, yw])/16 + 
     (3*G[{1/(yu*yv)}, yw]*G[{0, yu}, yv^(-1)]*G[{yv^(-1), 1/(yu*yv)}, yw])/
      64 - (G[{1}, yu^(-1)]*G[{0, yv^(-1)}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw])/
      16 + (G[{1}, yv^(-1)]*G[{0, yv^(-1)}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw])/
      16 - (G[{1}, yw]*G[{0, yv^(-1)}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw])/16 + 
     (G[{yv^(-1)}, yw]*G[{0, yv^(-1)}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw])/8 - 
     (G[{1/(yu*yv)}, yw]*G[{0, yv^(-1)}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw])/
      16 + (G[{1}, yu^(-1)]*G[{0, 1/(yu*yv)}, yw]*G[{yv^(-1), 1/(yu*yv)}, 
        yw])/16 - (G[{1}, yv^(-1)]*G[{0, 1/(yu*yv)}, yw]*
       G[{yv^(-1), 1/(yu*yv)}, yw])/16 + (G[{1}, yw]*G[{0, 1/(yu*yv)}, yw]*
       G[{yv^(-1), 1/(yu*yv)}, yw])/16 - 
     (G[{yv^(-1)}, yw]*G[{0, 1/(yu*yv)}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw])/8 + 
     (G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv)}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw])/
      16 + (G[{0}, yu^(-1)]*G[{1, yu^(-1)}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw])/
      16 + (G[{0}, yv^(-1)]*G[{1, yu^(-1)}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw])/
      16 - (G[{0}, yw]*G[{1, yu^(-1)}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw])/16 - 
     (5*G[{1}, yv^(-1)]*G[{1, yu^(-1)}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw])/32 - 
     (G[{1}, yw]*G[{1, yu^(-1)}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw])/32 + 
     (G[{yu^(-1)}, yw]*G[{1, yu^(-1)}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw])/16 + 
     (G[{yu}, yv^(-1)]*G[{1, yu^(-1)}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw])/32 - 
     (G[{yv^(-1)}, yw]*G[{1, yu^(-1)}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw])/16 + 
     (G[{1/(yu*yv)}, yw]*G[{1, yu^(-1)}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw])/
      64 + (G[{0}, yu^(-1)]*G[{1, yu}, yv^(-1)]*G[{yv^(-1), 1/(yu*yv)}, yw])/
      16 + (G[{0}, yv^(-1)]*G[{1, yu}, yv^(-1)]*G[{yv^(-1), 1/(yu*yv)}, yw])/
      16 - (G[{0}, yw]*G[{1, yu}, yv^(-1)]*G[{yv^(-1), 1/(yu*yv)}, yw])/16 - 
     (G[{1}, yu^(-1)]*G[{1, yu}, yv^(-1)]*G[{yv^(-1), 1/(yu*yv)}, yw])/16 + 
     (G[{1}, yv^(-1)]*G[{1, yu}, yv^(-1)]*G[{yv^(-1), 1/(yu*yv)}, yw])/32 + 
     (3*G[{1}, yw]*G[{1, yu}, yv^(-1)]*G[{yv^(-1), 1/(yu*yv)}, yw])/64 - 
     (G[{yu^(-1)}, yw]*G[{1, yu}, yv^(-1)]*G[{yv^(-1), 1/(yu*yv)}, yw])/16 + 
     (3*G[{yv^(-1)}, yw]*G[{1, yu}, yv^(-1)]*G[{yv^(-1), 1/(yu*yv)}, yw])/
      16 + (G[{1/(yu*yv)}, yw]*G[{1, yu}, yv^(-1)]*G[{yv^(-1), 1/(yu*yv)}, 
        yw])/64 + (G[{1}, yu^(-1)]*G[{1, yv^(-1)}, yw]*
       G[{yv^(-1), 1/(yu*yv)}, yw])/16 - 
     (3*G[{1}, yv^(-1)]*G[{1, yv^(-1)}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw])/16 - 
     (G[{1}, yw]*G[{1, yv^(-1)}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw])/8 + 
     (G[{yu^(-1)}, yw]*G[{1, yv^(-1)}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw])/8 + 
     (G[{yu}, yv^(-1)]*G[{1, yv^(-1)}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw])/8 - 
     (G[{yv^(-1)}, yw]*G[{1, yv^(-1)}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw])/4 - 
     (G[{0}, yu^(-1)]*G[{1, 1/(yu*yv)}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw])/16 - 
     (G[{0}, yv^(-1)]*G[{1, 1/(yu*yv)}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw])/16 + 
     (G[{0}, yw]*G[{1, 1/(yu*yv)}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw])/16 + 
     (G[{1}, yu^(-1)]*G[{1, 1/(yu*yv)}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw])/16 + 
     (7*G[{1}, yv^(-1)]*G[{1, 1/(yu*yv)}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw])/
      32 + (5*G[{1}, yw]*G[{1, 1/(yu*yv)}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw])/
      32 - (3*G[{yu^(-1)}, yw]*G[{1, 1/(yu*yv)}, yw]*G[{yv^(-1), 1/(yu*yv)}, 
        yw])/16 - (5*G[{yu}, yv^(-1)]*G[{1, 1/(yu*yv)}, yw]*
       G[{yv^(-1), 1/(yu*yv)}, yw])/32 + 
     (G[{yv^(-1)}, yw]*G[{1, 1/(yu*yv)}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw])/
      16 + (7*G[{1/(yu*yv)}, yw]*G[{1, 1/(yu*yv)}, yw]*
       G[{yv^(-1), 1/(yu*yv)}, yw])/64 + 
     (G[{0}, yu^(-1)]*G[{yu^(-1), 1/(yu*yv)}, yw]*G[{yv^(-1), 1/(yu*yv)}, 
        yw])/16 + (G[{0}, yv^(-1)]*G[{yu^(-1), 1/(yu*yv)}, yw]*
       G[{yv^(-1), 1/(yu*yv)}, yw])/16 - 
     (G[{0}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw])/
      16 - (G[{1}, yu^(-1)]*G[{yu^(-1), 1/(yu*yv)}, yw]*
       G[{yv^(-1), 1/(yu*yv)}, yw])/8 - 
     (G[{1}, yv^(-1)]*G[{yu^(-1), 1/(yu*yv)}, yw]*G[{yv^(-1), 1/(yu*yv)}, 
        yw])/32 - (G[{1}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw]*
       G[{yv^(-1), 1/(yu*yv)}, yw])/32 + 
     (G[{yu^(-1)}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw]*G[{yv^(-1), 1/(yu*yv)}, 
        yw])/32 + (G[{yu}, yv^(-1)]*G[{yu^(-1), 1/(yu*yv)}, yw]*
       G[{yv^(-1), 1/(yu*yv)}, yw])/32 + 
     (3*G[{yv^(-1)}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw]*G[{yv^(-1), 1/(yu*yv)}, 
        yw])/16 - (7*G[{1/(yu*yv)}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw]*
       G[{yv^(-1), 1/(yu*yv)}, yw])/64 - 
     (G[{1}, yu^(-1)]*G[{yv^(-1), 1/(yu*yv)}, yw]^2)/32 - 
     (G[{1}, yv^(-1)]*G[{yv^(-1), 1/(yu*yv)}, yw]^2)/32 - 
     (G[{1}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw]^2)/16 + 
     (G[{yu^(-1)}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw]^2)/32 + 
     (G[{yu}, yv^(-1)]*G[{yv^(-1), 1/(yu*yv)}, yw]^2)/16 + 
     (G[{yv^(-1)}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw]^2)/32 - 
     (G[{1/(yu*yv)}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw]^2)/16 + 
     (G[{0}, yu^(-1)]*G[{1}, yu^(-1)]*G[{0, 0, 1}, yu^(-1)])/16 + 
     (G[{0}, yv^(-1)]*G[{1}, yu^(-1)]*G[{0, 0, 1}, yu^(-1)])/16 - 
     (G[{0}, yw]*G[{1}, yu^(-1)]*G[{0, 0, 1}, yu^(-1)])/16 - 
     (G[{1}, yu^(-1)]^2*G[{0, 0, 1}, yu^(-1)])/32 - 
     (G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*G[{0, 0, 1}, yu^(-1)])/16 - 
     (G[{0}, yu^(-1)]*G[{1}, yw]*G[{0, 0, 1}, yu^(-1)])/16 - 
     (G[{0}, yv^(-1)]*G[{1}, yw]*G[{0, 0, 1}, yu^(-1)])/16 + 
     (G[{0}, yw]*G[{1}, yw]*G[{0, 0, 1}, yu^(-1)])/16 + 
     (G[{1}, yu^(-1)]*G[{1}, yw]*G[{0, 0, 1}, yu^(-1)])/16 - 
     (G[{1}, yw]^2*G[{0, 0, 1}, yu^(-1)])/32 + 
     (G[{1}, yw]*G[{yu}, yv^(-1)]*G[{0, 0, 1}, yu^(-1)])/16 + 
     (G[{1}, yu^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, 0, 1}, yu^(-1)])/16 + 
     (G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 0, 1}, yu^(-1)])/16 - 
     (G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, 0, 1}, yu^(-1)])/16 - 
     (G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 0, 1}, yu^(-1)])/16 - 
     (G[{0, 1}, yw]*G[{0, 0, 1}, yu^(-1)])/16 - 
     (G[{0, yu}, yv^(-1)]*G[{0, 0, 1}, yu^(-1)])/16 + 
     (G[{0, yv^(-1)}, yw]*G[{0, 0, 1}, yu^(-1)])/16 + 
     (G[{1, yu}, yv^(-1)]*G[{0, 0, 1}, yu^(-1)])/16 - 
     (G[{1, yv^(-1)}, yw]*G[{0, 0, 1}, yu^(-1)])/16 - 
     (G[{1, 1/(yu*yv)}, yw]*G[{0, 0, 1}, yu^(-1)])/16 + 
     (G[{yv^(-1), 1/(yu*yv)}, yw]*G[{0, 0, 1}, yu^(-1)])/16 + 
     (11*Pi^2*G[{0, 0, 1}, yv^(-1)])/768 + 
     (3*G[{0}, yu^(-1)]^2*G[{0, 0, 1}, yv^(-1)])/128 + 
     (3*G[{0}, yu^(-1)]*G[{0}, yv^(-1)]*G[{0, 0, 1}, yv^(-1)])/64 + 
     (3*G[{0}, yv^(-1)]^2*G[{0, 0, 1}, yv^(-1)])/128 - 
     (3*G[{0}, yu^(-1)]*G[{0}, yw]*G[{0, 0, 1}, yv^(-1)])/64 - 
     (3*G[{0}, yv^(-1)]*G[{0}, yw]*G[{0, 0, 1}, yv^(-1)])/64 + 
     (3*G[{0}, yw]^2*G[{0, 0, 1}, yv^(-1)])/128 + 
     (G[{0}, yu^(-1)]*G[{1}, yu^(-1)]*G[{0, 0, 1}, yv^(-1)])/64 + 
     (G[{0}, yv^(-1)]*G[{1}, yu^(-1)]*G[{0, 0, 1}, yv^(-1)])/64 - 
     (G[{0}, yw]*G[{1}, yu^(-1)]*G[{0, 0, 1}, yv^(-1)])/64 - 
     (5*G[{1}, yu^(-1)]^2*G[{0, 0, 1}, yv^(-1)])/128 - 
     (3*G[{0}, yu^(-1)]*G[{1}, yv^(-1)]*G[{0, 0, 1}, yv^(-1)])/64 - 
     (3*G[{0}, yv^(-1)]*G[{1}, yv^(-1)]*G[{0, 0, 1}, yv^(-1)])/64 + 
     (3*G[{0}, yw]*G[{1}, yv^(-1)]*G[{0, 0, 1}, yv^(-1)])/64 - 
     (G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*G[{0, 0, 1}, yv^(-1)])/64 + 
     (5*G[{1}, yv^(-1)]^2*G[{0, 0, 1}, yv^(-1)])/128 - 
     (G[{0}, yu^(-1)]*G[{1}, yw]*G[{0, 0, 1}, yv^(-1)])/64 - 
     (G[{0}, yv^(-1)]*G[{1}, yw]*G[{0, 0, 1}, yv^(-1)])/64 + 
     (G[{0}, yw]*G[{1}, yw]*G[{0, 0, 1}, yv^(-1)])/64 + 
     (G[{1}, yu^(-1)]*G[{1}, yw]*G[{0, 0, 1}, yv^(-1)])/64 - 
     (G[{1}, yv^(-1)]*G[{1}, yw]*G[{0, 0, 1}, yv^(-1)])/64 - 
     (G[{1}, yw]^2*G[{0, 0, 1}, yv^(-1)])/64 + 
     (G[{1}, yw]*G[{yu}, yv^(-1)]*G[{0, 0, 1}, yv^(-1)])/32 + 
     (3*G[{0}, yu^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, 0, 1}, yv^(-1)])/64 + 
     (3*G[{0}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, 0, 1}, yv^(-1)])/64 - 
     (3*G[{0}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 0, 1}, yv^(-1)])/64 + 
     (G[{1}, yu^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, 0, 1}, yv^(-1)])/64 - 
     (5*G[{1}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, 0, 1}, yv^(-1)])/64 + 
     (G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 0, 1}, yv^(-1)])/32 + 
     (5*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 0, 1}, yv^(-1)])/64 - 
     (G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, 0, 1}, yv^(-1)])/32 - 
     (G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 0, 1}, yv^(-1)])/64 - 
     (G[{0, 1}, yv^(-1)]*G[{0, 0, 1}, yv^(-1)])/32 - 
     (G[{0, 1}, yw]*G[{0, 0, 1}, yv^(-1)])/64 - 
     (3*G[{0, yu^(-1)}, yw]*G[{0, 0, 1}, yv^(-1)])/64 - 
     (G[{0, yu}, yv^(-1)]*G[{0, 0, 1}, yv^(-1)])/32 + 
     (G[{0, yv^(-1)}, yw]*G[{0, 0, 1}, yv^(-1)])/64 + 
     (3*G[{0, 1/(yu*yv)}, yw]*G[{0, 0, 1}, yv^(-1)])/64 + 
     (G[{1, yu^(-1)}, yw]*G[{0, 0, 1}, yv^(-1)])/64 + 
     (G[{1, yu}, yv^(-1)]*G[{0, 0, 1}, yv^(-1)])/32 - 
     (G[{1, yv^(-1)}, yw]*G[{0, 0, 1}, yv^(-1)])/64 - 
     (G[{1, 1/(yu*yv)}, yw]*G[{0, 0, 1}, yv^(-1)])/32 - 
     (5*G[{yu^(-1), 1/(yu*yv)}, yw]*G[{0, 0, 1}, yv^(-1)])/64 + 
     (G[{yv^(-1), 1/(yu*yv)}, yw]*G[{0, 0, 1}, yv^(-1)])/64 + 
     (Pi^2*G[{0, 0, 1}, yw])/96 + (G[{1}, yv^(-1)]^2*G[{0, 0, 1}, yw])/8 + 
     (G[{1}, yv^(-1)]*G[{1}, yw]*G[{0, 0, 1}, yw])/4 + 
     (G[{1}, yw]^2*G[{0, 0, 1}, yw])/16 - 
     (G[{1}, yv^(-1)]*G[{yu}, yv^(-1)]*G[{0, 0, 1}, yw])/4 - 
     (G[{1}, yw]*G[{yu}, yv^(-1)]*G[{0, 0, 1}, yw])/4 + 
     (G[{yu}, yv^(-1)]^2*G[{0, 0, 1}, yw])/8 - 
     (G[{1}, yu^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, 0, 1}, yw])/8 - 
     (G[{1}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, 0, 1}, yw])/8 - 
     (G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 0, 1}, yw])/8 + 
     (G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, 0, 1}, yw])/4 + 
     (G[{0, 1}, yw]*G[{0, 0, 1}, yw])/8 - 
     (G[{0, yu^(-1)}, yw]*G[{0, 0, 1}, yw])/8 + 
     (G[{1, 1/(yu*yv)}, yw]*G[{0, 0, 1}, yw])/8 - 
     (Pi^2*G[{0, 0, yu^(-1)}, yw])/96 + 
     (G[{1}, yv^(-1)]^2*G[{0, 0, yu^(-1)}, yw])/16 - 
     (G[{1}, yv^(-1)]*G[{1}, yw]*G[{0, 0, yu^(-1)}, yw])/8 - 
     (G[{1}, yw]^2*G[{0, 0, yu^(-1)}, yw])/16 + 
     (G[{1}, yw]*G[{yu}, yv^(-1)]*G[{0, 0, yu^(-1)}, yw])/8 + 
     (G[{1}, yu^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, 0, yu^(-1)}, yw])/8 + 
     (G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 0, yu^(-1)}, yw])/8 - 
     (G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, 0, yu^(-1)}, yw])/8 - 
     (G[{0, 1}, yv^(-1)]*G[{0, 0, yu^(-1)}, yw])/8 - 
     (G[{0, 1}, yw]*G[{0, 0, yu^(-1)}, yw])/8 + 
     (G[{0, yu^(-1)}, yw]*G[{0, 0, yu^(-1)}, yw])/8 + 
     (G[{0, yu}, yv^(-1)]*G[{0, 0, yu^(-1)}, yw])/8 - 
     (G[{1, yu}, yv^(-1)]*G[{0, 0, yu^(-1)}, yw])/8 - 
     (G[{1, 1/(yu*yv)}, yw]*G[{0, 0, yu^(-1)}, yw])/8 - 
     (19*Pi^2*G[{0, 0, yu}, yv^(-1)])/768 - 
     (3*G[{0}, yu^(-1)]^2*G[{0, 0, yu}, yv^(-1)])/128 - 
     (3*G[{0}, yu^(-1)]*G[{0}, yv^(-1)]*G[{0, 0, yu}, yv^(-1)])/64 - 
     (3*G[{0}, yv^(-1)]^2*G[{0, 0, yu}, yv^(-1)])/128 + 
     (3*G[{0}, yu^(-1)]*G[{0}, yw]*G[{0, 0, yu}, yv^(-1)])/64 + 
     (3*G[{0}, yv^(-1)]*G[{0}, yw]*G[{0, 0, yu}, yv^(-1)])/64 - 
     (3*G[{0}, yw]^2*G[{0, 0, yu}, yv^(-1)])/128 - 
     (G[{0}, yu^(-1)]*G[{1}, yu^(-1)]*G[{0, 0, yu}, yv^(-1)])/64 - 
     (G[{0}, yv^(-1)]*G[{1}, yu^(-1)]*G[{0, 0, yu}, yv^(-1)])/64 + 
     (G[{0}, yw]*G[{1}, yu^(-1)]*G[{0, 0, yu}, yv^(-1)])/64 + 
     (5*G[{1}, yu^(-1)]^2*G[{0, 0, yu}, yv^(-1)])/128 + 
     (3*G[{0}, yu^(-1)]*G[{1}, yv^(-1)]*G[{0, 0, yu}, yv^(-1)])/64 + 
     (3*G[{0}, yv^(-1)]*G[{1}, yv^(-1)]*G[{0, 0, yu}, yv^(-1)])/64 - 
     (3*G[{0}, yw]*G[{1}, yv^(-1)]*G[{0, 0, yu}, yv^(-1)])/64 + 
     (G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*G[{0, 0, yu}, yv^(-1)])/64 - 
     (5*G[{1}, yv^(-1)]^2*G[{0, 0, yu}, yv^(-1)])/128 + 
     (G[{0}, yu^(-1)]*G[{1}, yw]*G[{0, 0, yu}, yv^(-1)])/64 + 
     (G[{0}, yv^(-1)]*G[{1}, yw]*G[{0, 0, yu}, yv^(-1)])/64 - 
     (G[{0}, yw]*G[{1}, yw]*G[{0, 0, yu}, yv^(-1)])/64 - 
     (G[{1}, yu^(-1)]*G[{1}, yw]*G[{0, 0, yu}, yv^(-1)])/64 + 
     (G[{1}, yv^(-1)]*G[{1}, yw]*G[{0, 0, yu}, yv^(-1)])/64 + 
     (G[{1}, yw]^2*G[{0, 0, yu}, yv^(-1)])/64 - 
     (G[{1}, yw]*G[{yu}, yv^(-1)]*G[{0, 0, yu}, yv^(-1)])/32 - 
     (3*G[{0}, yu^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, 0, yu}, yv^(-1)])/64 - 
     (3*G[{0}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, 0, yu}, yv^(-1)])/64 + 
     (3*G[{0}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 0, yu}, yv^(-1)])/64 - 
     (G[{1}, yu^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, 0, yu}, yv^(-1)])/64 + 
     (5*G[{1}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, 0, yu}, yv^(-1)])/64 - 
     (G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 0, yu}, yv^(-1)])/32 - 
     (5*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 0, yu}, yv^(-1)])/64 + 
     (G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, 0, yu}, yv^(-1)])/32 + 
     (G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 0, yu}, yv^(-1)])/64 - 
     (G[{0, 1}, yu^(-1)]*G[{0, 0, yu}, yv^(-1)])/16 + 
     (G[{0, 1}, yv^(-1)]*G[{0, 0, yu}, yv^(-1)])/32 + 
     (G[{0, 1}, yw]*G[{0, 0, yu}, yv^(-1)])/64 + 
     (3*G[{0, yu^(-1)}, yw]*G[{0, 0, yu}, yv^(-1)])/64 + 
     (G[{0, yu}, yv^(-1)]*G[{0, 0, yu}, yv^(-1)])/32 - 
     (G[{0, yv^(-1)}, yw]*G[{0, 0, yu}, yv^(-1)])/64 - 
     (3*G[{0, 1/(yu*yv)}, yw]*G[{0, 0, yu}, yv^(-1)])/64 - 
     (G[{1, yu^(-1)}, yw]*G[{0, 0, yu}, yv^(-1)])/64 - 
     (G[{1, yu}, yv^(-1)]*G[{0, 0, yu}, yv^(-1)])/32 + 
     (G[{1, yv^(-1)}, yw]*G[{0, 0, yu}, yv^(-1)])/64 + 
     (G[{1, 1/(yu*yv)}, yw]*G[{0, 0, yu}, yv^(-1)])/32 + 
     (5*G[{yu^(-1), 1/(yu*yv)}, yw]*G[{0, 0, yu}, yv^(-1)])/64 - 
     (G[{yv^(-1), 1/(yu*yv)}, yw]*G[{0, 0, yu}, yv^(-1)])/64 + 
     (Pi^2*G[{0, 0, yv^(-1)}, yw])/96 - 
     (G[{1}, yu^(-1)]^2*G[{0, 0, yv^(-1)}, yw])/16 + 
     (G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*G[{0, 0, yv^(-1)}, yw])/8 - 
     (G[{1}, yv^(-1)]^2*G[{0, 0, yv^(-1)}, yw])/8 + 
     (G[{1}, yu^(-1)]*G[{1}, yw]*G[{0, 0, yv^(-1)}, yw])/8 - 
     (G[{1}, yv^(-1)]*G[{1}, yw]*G[{0, 0, yv^(-1)}, yw])/4 - 
     (G[{1}, yw]^2*G[{0, 0, yv^(-1)}, yw])/16 + 
     (G[{1}, yw]*G[{yu}, yv^(-1)]*G[{0, 0, yv^(-1)}, yw])/8 + 
     (G[{1}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, 0, yv^(-1)}, yw])/8 + 
     (G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 0, yv^(-1)}, yw])/8 - 
     (G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, 0, yv^(-1)}, yw])/8 + 
     (G[{0, 1}, yv^(-1)]*G[{0, 0, yv^(-1)}, yw])/8 - 
     (G[{0, 1}, yw]*G[{0, 0, yv^(-1)}, yw])/8 + 
     (G[{0, yu^(-1)}, yw]*G[{0, 0, yv^(-1)}, yw])/8 - 
     (G[{0, yu}, yv^(-1)]*G[{0, 0, yv^(-1)}, yw])/8 + 
     (G[{1, yu}, yv^(-1)]*G[{0, 0, yv^(-1)}, yw])/8 - 
     (G[{1, 1/(yu*yv)}, yw]*G[{0, 0, yv^(-1)}, yw])/8 - 
     (Pi^2*G[{0, 0, 1/(yu*yv)}, yw])/96 + 
     (G[{1}, yu^(-1)]^2*G[{0, 0, 1/(yu*yv)}, yw])/16 - 
     (G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*G[{0, 0, 1/(yu*yv)}, yw])/8 - 
     (G[{1}, yv^(-1)]^2*G[{0, 0, 1/(yu*yv)}, yw])/16 - 
     (G[{1}, yu^(-1)]*G[{1}, yw]*G[{0, 0, 1/(yu*yv)}, yw])/8 + 
     (G[{1}, yv^(-1)]*G[{1}, yw]*G[{0, 0, 1/(yu*yv)}, yw])/8 + 
     (G[{1}, yw]^2*G[{0, 0, 1/(yu*yv)}, yw])/16 + 
     (G[{1}, yv^(-1)]*G[{yu}, yv^(-1)]*G[{0, 0, 1/(yu*yv)}, yw])/4 - 
     (G[{yu}, yv^(-1)]^2*G[{0, 0, 1/(yu*yv)}, yw])/8 - 
     (G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 0, 1/(yu*yv)}, yw])/8 + 
     (G[{0, 1}, yw]*G[{0, 0, 1/(yu*yv)}, yw])/8 - 
     (G[{0, yu^(-1)}, yw]*G[{0, 0, 1/(yu*yv)}, yw])/8 + 
     (G[{1, 1/(yu*yv)}, yw]*G[{0, 0, 1/(yu*yv)}, yw])/8 + 
     (Pi^2*G[{0, 1, 1}, yu^(-1)])/16 - (G[{0}, yu^(-1)]*G[{1}, yu^(-1)]*
       G[{0, 1, 1}, yu^(-1)])/16 - (G[{0}, yv^(-1)]*G[{1}, yu^(-1)]*
       G[{0, 1, 1}, yu^(-1)])/16 + (G[{0}, yw]*G[{1}, yu^(-1)]*
       G[{0, 1, 1}, yu^(-1)])/16 - (G[{1}, yu^(-1)]^2*G[{0, 1, 1}, yu^(-1)])/
      32 + (G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*G[{0, 1, 1}, yu^(-1)])/16 - 
     (G[{1}, yv^(-1)]^2*G[{0, 1, 1}, yu^(-1)])/8 + 
     (G[{0}, yu^(-1)]*G[{1}, yw]*G[{0, 1, 1}, yu^(-1)])/16 + 
     (G[{0}, yv^(-1)]*G[{1}, yw]*G[{0, 1, 1}, yu^(-1)])/16 - 
     (G[{0}, yw]*G[{1}, yw]*G[{0, 1, 1}, yu^(-1)])/16 + 
     (G[{1}, yu^(-1)]*G[{1}, yw]*G[{0, 1, 1}, yu^(-1)])/16 - 
     (3*G[{1}, yv^(-1)]*G[{1}, yw]*G[{0, 1, 1}, yu^(-1)])/8 - 
     (G[{1}, yw]^2*G[{0, 1, 1}, yu^(-1)])/32 + 
     (5*G[{1}, yw]*G[{yu}, yv^(-1)]*G[{0, 1, 1}, yu^(-1)])/16 - 
     (G[{1}, yu^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, 1, 1}, yu^(-1)])/16 + 
     (G[{1}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, 1, 1}, yu^(-1)])/4 + 
     (5*G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1, 1}, yu^(-1)])/16 - 
     (G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1, 1}, yu^(-1)])/4 - 
     (5*G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, 1, 1}, yu^(-1)])/16 + 
     (G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1, 1}, yu^(-1)])/16 + 
     (3*G[{0, 1}, yu^(-1)]*G[{0, 1, 1}, yu^(-1)])/16 + 
     (G[{0, 1}, yv^(-1)]*G[{0, 1, 1}, yu^(-1)])/4 - 
     (3*G[{0, 1}, yw]*G[{0, 1, 1}, yu^(-1)])/16 + 
     (G[{0, yu^(-1)}, yw]*G[{0, 1, 1}, yu^(-1)])/4 - 
     (5*G[{0, yu}, yv^(-1)]*G[{0, 1, 1}, yu^(-1)])/16 - 
     (G[{0, yv^(-1)}, yw]*G[{0, 1, 1}, yu^(-1)])/16 + 
     (5*G[{1, yu}, yv^(-1)]*G[{0, 1, 1}, yu^(-1)])/16 + 
     (G[{1, yv^(-1)}, yw]*G[{0, 1, 1}, yu^(-1)])/16 - 
     (5*G[{1, 1/(yu*yv)}, yw]*G[{0, 1, 1}, yu^(-1)])/16 + 
     (G[{yu^(-1), 1/(yu*yv)}, yw]*G[{0, 1, 1}, yu^(-1)])/4 - 
     (G[{yv^(-1), 1/(yu*yv)}, yw]*G[{0, 1, 1}, yu^(-1)])/16 + 
     (7*Pi^2*G[{0, 1, 1}, yv^(-1)])/384 - 
     (3*G[{0}, yu^(-1)]^2*G[{0, 1, 1}, yv^(-1)])/128 - 
     (3*G[{0}, yu^(-1)]*G[{0}, yv^(-1)]*G[{0, 1, 1}, yv^(-1)])/64 - 
     (3*G[{0}, yv^(-1)]^2*G[{0, 1, 1}, yv^(-1)])/128 + 
     (3*G[{0}, yu^(-1)]*G[{0}, yw]*G[{0, 1, 1}, yv^(-1)])/64 + 
     (3*G[{0}, yv^(-1)]*G[{0}, yw]*G[{0, 1, 1}, yv^(-1)])/64 - 
     (3*G[{0}, yw]^2*G[{0, 1, 1}, yv^(-1)])/128 - 
     (5*G[{0}, yu^(-1)]*G[{1}, yu^(-1)]*G[{0, 1, 1}, yv^(-1)])/64 - 
     (5*G[{0}, yv^(-1)]*G[{1}, yu^(-1)]*G[{0, 1, 1}, yv^(-1)])/64 + 
     (5*G[{0}, yw]*G[{1}, yu^(-1)]*G[{0, 1, 1}, yv^(-1)])/64 + 
     (17*G[{1}, yu^(-1)]^2*G[{0, 1, 1}, yv^(-1)])/128 - 
     (5*G[{0}, yu^(-1)]*G[{1}, yv^(-1)]*G[{0, 1, 1}, yv^(-1)])/64 - 
     (5*G[{0}, yv^(-1)]*G[{1}, yv^(-1)]*G[{0, 1, 1}, yv^(-1)])/64 + 
     (5*G[{0}, yw]*G[{1}, yv^(-1)]*G[{0, 1, 1}, yv^(-1)])/64 + 
     (G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*G[{0, 1, 1}, yv^(-1)])/64 + 
     (17*G[{1}, yv^(-1)]^2*G[{0, 1, 1}, yv^(-1)])/128 - 
     (7*G[{0}, yu^(-1)]*G[{1}, yw]*G[{0, 1, 1}, yv^(-1)])/64 - 
     (7*G[{0}, yv^(-1)]*G[{1}, yw]*G[{0, 1, 1}, yv^(-1)])/64 + 
     (7*G[{0}, yw]*G[{1}, yw]*G[{0, 1, 1}, yv^(-1)])/64 - 
     (5*G[{1}, yu^(-1)]*G[{1}, yw]*G[{0, 1, 1}, yv^(-1)])/64 - 
     (G[{1}, yv^(-1)]*G[{1}, yw]*G[{0, 1, 1}, yv^(-1)])/64 - 
     (G[{1}, yw]^2*G[{0, 1, 1}, yv^(-1)])/8 + 
     (3*G[{1}, yw]*G[{yu}, yv^(-1)]*G[{0, 1, 1}, yv^(-1)])/32 + 
     (5*G[{0}, yu^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, 1, 1}, yv^(-1)])/64 + 
     (5*G[{0}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, 1, 1}, yv^(-1)])/64 - 
     (5*G[{0}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1, 1}, yv^(-1)])/64 - 
     (G[{1}, yu^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, 1, 1}, yv^(-1)])/64 - 
     (17*G[{1}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, 1, 1}, yv^(-1)])/64 + 
     (11*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1, 1}, yv^(-1)])/64 - 
     (3*G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, 1, 1}, yv^(-1)])/32 + 
     (G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1, 1}, yv^(-1)])/64 + 
     (3*G[{1/(yu*yv)}, yw]^2*G[{0, 1, 1}, yv^(-1)])/64 + 
     (9*G[{0, 1}, yv^(-1)]*G[{0, 1, 1}, yv^(-1)])/64 - 
     (7*G[{0, 1}, yw]*G[{0, 1, 1}, yv^(-1)])/64 + 
     (3*G[{0, yu^(-1)}, yw]*G[{0, 1, 1}, yv^(-1)])/64 - 
     (3*G[{0, yu}, yv^(-1)]*G[{0, 1, 1}, yv^(-1)])/32 - 
     (G[{0, yv^(-1)}, yw]*G[{0, 1, 1}, yv^(-1)])/64 + 
     (5*G[{0, 1/(yu*yv)}, yw]*G[{0, 1, 1}, yv^(-1)])/64 - 
     (G[{1, yu^(-1)}, yw]*G[{0, 1, 1}, yv^(-1)])/64 + 
     (3*G[{1, yu}, yv^(-1)]*G[{0, 1, 1}, yv^(-1)])/32 + 
     (G[{1, yv^(-1)}, yw]*G[{0, 1, 1}, yv^(-1)])/64 - 
     (3*G[{1, 1/(yu*yv)}, yw]*G[{0, 1, 1}, yv^(-1)])/32 - 
     (11*G[{yu^(-1), 1/(yu*yv)}, yw]*G[{0, 1, 1}, yv^(-1)])/64 - 
     (G[{yv^(-1), 1/(yu*yv)}, yw]*G[{0, 1, 1}, yv^(-1)])/64 + 
     (Pi^2*G[{0, 1, 1}, yw])/96 + (G[{0}, yu^(-1)]*G[{1}, yv^(-1)]*
       G[{0, 1, 1}, yw])/16 + (G[{0}, yv^(-1)]*G[{1}, yv^(-1)]*
       G[{0, 1, 1}, yw])/16 - (G[{0}, yw]*G[{1}, yv^(-1)]*G[{0, 1, 1}, yw])/
      16 + (G[{0}, yu^(-1)]*G[{1}, yw]*G[{0, 1, 1}, yw])/8 + 
     (G[{0}, yv^(-1)]*G[{1}, yw]*G[{0, 1, 1}, yw])/8 - 
     (G[{0}, yw]*G[{1}, yw]*G[{0, 1, 1}, yw])/8 - 
     (G[{1}, yu^(-1)]*G[{1}, yw]*G[{0, 1, 1}, yw])/8 + 
     (G[{1}, yv^(-1)]*G[{1}, yw]*G[{0, 1, 1}, yw])/16 + 
     (G[{1}, yw]^2*G[{0, 1, 1}, yw])/32 - 
     (G[{0}, yu^(-1)]*G[{yu}, yv^(-1)]*G[{0, 1, 1}, yw])/16 - 
     (G[{0}, yv^(-1)]*G[{yu}, yv^(-1)]*G[{0, 1, 1}, yw])/16 + 
     (G[{0}, yw]*G[{yu}, yv^(-1)]*G[{0, 1, 1}, yw])/16 - 
     (G[{1}, yv^(-1)]*G[{yu}, yv^(-1)]*G[{0, 1, 1}, yw])/8 - 
     (3*G[{1}, yw]*G[{yu}, yv^(-1)]*G[{0, 1, 1}, yw])/16 + 
     (G[{yu}, yv^(-1)]^2*G[{0, 1, 1}, yw])/8 - 
     (G[{0}, yu^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, 1, 1}, yw])/8 - 
     (G[{0}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, 1, 1}, yw])/8 + 
     (G[{0}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1, 1}, yw])/8 - 
     (G[{1}, yu^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, 1, 1}, yw])/16 + 
     (G[{1}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, 1, 1}, yw])/8 - 
     (G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1, 1}, yw])/16 - 
     (G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1, 1}, yw])/8 + 
     (3*G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, 1, 1}, yw])/16 + 
     (G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1, 1}, yw])/16 + 
     (G[{0, 1}, yu^(-1)]*G[{0, 1, 1}, yw])/16 + 
     (G[{0, 1}, yv^(-1)]*G[{0, 1, 1}, yw])/16 - 
     (G[{0, 1}, yw]*G[{0, 1, 1}, yw])/8 - 
     (G[{0, yu^(-1)}, yw]*G[{0, 1, 1}, yw])/16 - 
     (G[{0, yu}, yv^(-1)]*G[{0, 1, 1}, yw])/16 - 
     (G[{0, yv^(-1)}, yw]*G[{0, 1, 1}, yw])/16 + 
     (G[{1, yv^(-1)}, yw]*G[{0, 1, 1}, yw])/16 + 
     (G[{1, 1/(yu*yv)}, yw]*G[{0, 1, 1}, yw])/16 + 
     (G[{yu^(-1), 1/(yu*yv)}, yw]*G[{0, 1, 1}, yw])/8 - 
     (G[{yv^(-1), 1/(yu*yv)}, yw]*G[{0, 1, 1}, yw])/16 - 
     (Pi^2*G[{0, 1, yu^(-1)}, yw])/32 - (G[{0}, yu^(-1)]*G[{1}, yv^(-1)]*
       G[{0, 1, yu^(-1)}, yw])/8 - (G[{0}, yv^(-1)]*G[{1}, yv^(-1)]*
       G[{0, 1, yu^(-1)}, yw])/8 + (G[{0}, yw]*G[{1}, yv^(-1)]*
       G[{0, 1, yu^(-1)}, yw])/8 + (3*G[{1}, yv^(-1)]^2*
       G[{0, 1, yu^(-1)}, yw])/32 - (3*G[{0}, yu^(-1)]*G[{1}, yw]*
       G[{0, 1, yu^(-1)}, yw])/16 - (3*G[{0}, yv^(-1)]*G[{1}, yw]*
       G[{0, 1, yu^(-1)}, yw])/16 + (3*G[{0}, yw]*G[{1}, yw]*
       G[{0, 1, yu^(-1)}, yw])/16 + (3*G[{1}, yu^(-1)]*G[{1}, yw]*
       G[{0, 1, yu^(-1)}, yw])/16 + (G[{1}, yv^(-1)]*G[{1}, yw]*
       G[{0, 1, yu^(-1)}, yw])/4 + (G[{1}, yw]^2*G[{0, 1, yu^(-1)}, yw])/32 + 
     (G[{0}, yu^(-1)]*G[{yu}, yv^(-1)]*G[{0, 1, yu^(-1)}, yw])/8 + 
     (G[{0}, yv^(-1)]*G[{yu}, yv^(-1)]*G[{0, 1, yu^(-1)}, yw])/8 - 
     (G[{0}, yw]*G[{yu}, yv^(-1)]*G[{0, 1, yu^(-1)}, yw])/8 - 
     (G[{1}, yw]*G[{yu}, yv^(-1)]*G[{0, 1, yu^(-1)}, yw])/16 - 
     (G[{yu}, yv^(-1)]^2*G[{0, 1, yu^(-1)}, yw])/8 + 
     (G[{0}, yu^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, 1, yu^(-1)}, yw])/8 + 
     (G[{0}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, 1, yu^(-1)}, yw])/8 - 
     (G[{0}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1, yu^(-1)}, yw])/8 - 
     (G[{1}, yu^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, 1, yu^(-1)}, yw])/16 - 
     (G[{1}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, 1, yu^(-1)}, yw])/4 - 
     (G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1, yu^(-1)}, yw])/16 + 
     (G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1, yu^(-1)}, yw])/8 + 
     (G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, 1, yu^(-1)}, yw])/16 - 
     (G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1, yu^(-1)}, yw])/16 - 
     (G[{0, 1}, yu^(-1)]*G[{0, 1, yu^(-1)}, yw])/8 - 
     (G[{0, 1}, yv^(-1)]*G[{0, 1, yu^(-1)}, yw])/16 - 
     (G[{0, yu^(-1)}, yw]*G[{0, 1, yu^(-1)}, yw])/16 + 
     (G[{0, yu}, yv^(-1)]*G[{0, 1, yu^(-1)}, yw])/16 + 
     (G[{0, yv^(-1)}, yw]*G[{0, 1, yu^(-1)}, yw])/16 + 
     (G[{1, yu}, yv^(-1)]*G[{0, 1, yu^(-1)}, yw])/16 - 
     (G[{1, yv^(-1)}, yw]*G[{0, 1, yu^(-1)}, yw])/16 + 
     (G[{1, 1/(yu*yv)}, yw]*G[{0, 1, yu^(-1)}, yw])/16 - 
     (G[{yu^(-1), 1/(yu*yv)}, yw]*G[{0, 1, yu^(-1)}, yw])/8 + 
     (G[{yv^(-1), 1/(yu*yv)}, yw]*G[{0, 1, yu^(-1)}, yw])/16 + 
     (37*Pi^2*G[{0, 1, yu}, yv^(-1)])/768 + 
     (3*G[{0}, yu^(-1)]^2*G[{0, 1, yu}, yv^(-1)])/64 + 
     (3*G[{0}, yu^(-1)]*G[{0}, yv^(-1)]*G[{0, 1, yu}, yv^(-1)])/32 + 
     (3*G[{0}, yv^(-1)]^2*G[{0, 1, yu}, yv^(-1)])/64 - 
     (3*G[{0}, yu^(-1)]*G[{0}, yw]*G[{0, 1, yu}, yv^(-1)])/32 - 
     (3*G[{0}, yv^(-1)]*G[{0}, yw]*G[{0, 1, yu}, yv^(-1)])/32 + 
     (3*G[{0}, yw]^2*G[{0, 1, yu}, yv^(-1)])/64 + 
     (G[{0}, yu^(-1)]*G[{1}, yu^(-1)]*G[{0, 1, yu}, yv^(-1)])/32 + 
     (G[{0}, yv^(-1)]*G[{1}, yu^(-1)]*G[{0, 1, yu}, yv^(-1)])/32 - 
     (G[{0}, yw]*G[{1}, yu^(-1)]*G[{0, 1, yu}, yv^(-1)])/32 - 
     (7*G[{1}, yu^(-1)]^2*G[{0, 1, yu}, yv^(-1)])/64 + 
     (3*G[{0}, yu^(-1)]*G[{1}, yv^(-1)]*G[{0, 1, yu}, yv^(-1)])/32 + 
     (3*G[{0}, yv^(-1)]*G[{1}, yv^(-1)]*G[{0, 1, yu}, yv^(-1)])/32 - 
     (3*G[{0}, yw]*G[{1}, yv^(-1)]*G[{0, 1, yu}, yv^(-1)])/32 - 
     (G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*G[{0, 1, yu}, yv^(-1)])/32 - 
     (3*G[{1}, yv^(-1)]^2*G[{0, 1, yu}, yv^(-1)])/32 + 
     (5*G[{0}, yu^(-1)]*G[{1}, yw]*G[{0, 1, yu}, yv^(-1)])/32 + 
     (5*G[{0}, yv^(-1)]*G[{1}, yw]*G[{0, 1, yu}, yv^(-1)])/32 - 
     (5*G[{0}, yw]*G[{1}, yw]*G[{0, 1, yu}, yv^(-1)])/32 + 
     (G[{1}, yu^(-1)]*G[{1}, yw]*G[{0, 1, yu}, yv^(-1)])/32 + 
     (7*G[{1}, yw]^2*G[{0, 1, yu}, yv^(-1)])/64 - 
     (G[{1}, yw]*G[{yu}, yv^(-1)]*G[{0, 1, yu}, yv^(-1)])/16 - 
     (3*G[{0}, yu^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, 1, yu}, yv^(-1)])/32 - 
     (3*G[{0}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, 1, yu}, yv^(-1)])/32 + 
     (3*G[{0}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1, yu}, yv^(-1)])/32 + 
     (G[{1}, yu^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, 1, yu}, yv^(-1)])/32 + 
     (3*G[{1}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, 1, yu}, yv^(-1)])/16 + 
     (G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1, yu}, yv^(-1)])/32 - 
     (3*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1, yu}, yv^(-1)])/32 + 
     (G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, 1, yu}, yv^(-1)])/16 - 
     (G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1, yu}, yv^(-1)])/32 - 
     (3*G[{1/(yu*yv)}, yw]^2*G[{0, 1, yu}, yv^(-1)])/64 + 
     (3*G[{0, 1}, yu^(-1)]*G[{0, 1, yu}, yv^(-1)])/16 + 
     (G[{0, 1}, yv^(-1)]*G[{0, 1, yu}, yv^(-1)])/16 + 
     (G[{0, 1}, yw]*G[{0, 1, yu}, yv^(-1)])/32 + 
     (G[{0, yu^(-1)}, yw]*G[{0, 1, yu}, yv^(-1)])/32 + 
     (G[{0, yu}, yv^(-1)]*G[{0, 1, yu}, yv^(-1)])/16 + 
     (G[{0, yv^(-1)}, yw]*G[{0, 1, yu}, yv^(-1)])/32 - 
     (3*G[{0, 1/(yu*yv)}, yw]*G[{0, 1, yu}, yv^(-1)])/32 + 
     (G[{1, yu^(-1)}, yw]*G[{0, 1, yu}, yv^(-1)])/32 - 
     (G[{1, yu}, yv^(-1)]*G[{0, 1, yu}, yv^(-1)])/16 - 
     (G[{1, yv^(-1)}, yw]*G[{0, 1, yu}, yv^(-1)])/32 + 
     (G[{1, 1/(yu*yv)}, yw]*G[{0, 1, yu}, yv^(-1)])/16 + 
     (3*G[{yu^(-1), 1/(yu*yv)}, yw]*G[{0, 1, yu}, yv^(-1)])/32 + 
     (G[{yv^(-1), 1/(yu*yv)}, yw]*G[{0, 1, yu}, yv^(-1)])/32 + 
     (G[{0}, yu^(-1)]*G[{1}, yu^(-1)]*G[{0, 1, yv^(-1)}, yw])/16 + 
     (G[{0}, yv^(-1)]*G[{1}, yu^(-1)]*G[{0, 1, yv^(-1)}, yw])/16 - 
     (G[{0}, yw]*G[{1}, yu^(-1)]*G[{0, 1, yv^(-1)}, yw])/16 - 
     (G[{1}, yu^(-1)]^2*G[{0, 1, yv^(-1)}, yw])/32 - 
     (G[{0}, yu^(-1)]*G[{1}, yv^(-1)]*G[{0, 1, yv^(-1)}, yw])/16 - 
     (G[{0}, yv^(-1)]*G[{1}, yv^(-1)]*G[{0, 1, yv^(-1)}, yw])/16 + 
     (G[{0}, yw]*G[{1}, yv^(-1)]*G[{0, 1, yv^(-1)}, yw])/16 - 
     (G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*G[{0, 1, yv^(-1)}, yw])/16 + 
     (G[{1}, yv^(-1)]^2*G[{0, 1, yv^(-1)}, yw])/8 - 
     (G[{0}, yu^(-1)]*G[{1}, yw]*G[{0, 1, yv^(-1)}, yw])/16 - 
     (G[{0}, yv^(-1)]*G[{1}, yw]*G[{0, 1, yv^(-1)}, yw])/16 + 
     (G[{0}, yw]*G[{1}, yw]*G[{0, 1, yv^(-1)}, yw])/16 + 
     (G[{1}, yu^(-1)]*G[{1}, yw]*G[{0, 1, yv^(-1)}, yw])/16 + 
     (G[{1}, yv^(-1)]*G[{1}, yw]*G[{0, 1, yv^(-1)}, yw])/8 + 
     (G[{1}, yw]^2*G[{0, 1, yv^(-1)}, yw])/32 - 
     (G[{1}, yw]*G[{yu}, yv^(-1)]*G[{0, 1, yv^(-1)}, yw])/16 + 
     (G[{0}, yu^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, 1, yv^(-1)}, yw])/8 + 
     (G[{0}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, 1, yv^(-1)}, yw])/8 - 
     (G[{0}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1, yv^(-1)}, yw])/8 - 
     (G[{1}, yu^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, 1, yv^(-1)}, yw])/16 - 
     (G[{1}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, 1, yv^(-1)}, yw])/4 - 
     (G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1, yv^(-1)}, yw])/16 + 
     (G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1, yv^(-1)}, yw])/8 + 
     (G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, 1, yv^(-1)}, yw])/16 - 
     (G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1, yv^(-1)}, yw])/16 - 
     (G[{0, 1}, yv^(-1)]*G[{0, 1, yv^(-1)}, yw])/16 + 
     (G[{0, 1}, yw]*G[{0, 1, yv^(-1)}, yw])/16 - 
     (3*G[{0, yu^(-1)}, yw]*G[{0, 1, yv^(-1)}, yw])/16 + 
     (G[{0, yu}, yv^(-1)]*G[{0, 1, yv^(-1)}, yw])/16 + 
     (G[{0, yv^(-1)}, yw]*G[{0, 1, yv^(-1)}, yw])/16 - 
     (G[{1, yu}, yv^(-1)]*G[{0, 1, yv^(-1)}, yw])/16 - 
     (G[{1, yv^(-1)}, yw]*G[{0, 1, yv^(-1)}, yw])/16 + 
     (G[{1, 1/(yu*yv)}, yw]*G[{0, 1, yv^(-1)}, yw])/16 - 
     (G[{yu^(-1), 1/(yu*yv)}, yw]*G[{0, 1, yv^(-1)}, yw])/8 + 
     (G[{yv^(-1), 1/(yu*yv)}, yw]*G[{0, 1, yv^(-1)}, yw])/16 - 
     (Pi^2*G[{0, 1, 1/(yu*yv)}, yw])/96 + 
     (G[{0}, yu^(-1)]*G[{1}, yv^(-1)]*G[{0, 1, 1/(yu*yv)}, yw])/16 + 
     (G[{0}, yv^(-1)]*G[{1}, yv^(-1)]*G[{0, 1, 1/(yu*yv)}, yw])/16 - 
     (G[{0}, yw]*G[{1}, yv^(-1)]*G[{0, 1, 1/(yu*yv)}, yw])/16 + 
     (G[{0}, yu^(-1)]*G[{1}, yw]*G[{0, 1, 1/(yu*yv)}, yw])/16 + 
     (G[{0}, yv^(-1)]*G[{1}, yw]*G[{0, 1, 1/(yu*yv)}, yw])/16 - 
     (G[{0}, yw]*G[{1}, yw]*G[{0, 1, 1/(yu*yv)}, yw])/16 - 
     (G[{1}, yu^(-1)]*G[{1}, yw]*G[{0, 1, 1/(yu*yv)}, yw])/8 + 
     (G[{1}, yv^(-1)]*G[{1}, yw]*G[{0, 1, 1/(yu*yv)}, yw])/16 + 
     (G[{1}, yw]^2*G[{0, 1, 1/(yu*yv)}, yw])/32 - 
     (G[{0}, yu^(-1)]*G[{yu}, yv^(-1)]*G[{0, 1, 1/(yu*yv)}, yw])/16 - 
     (G[{0}, yv^(-1)]*G[{yu}, yv^(-1)]*G[{0, 1, 1/(yu*yv)}, yw])/16 + 
     (G[{0}, yw]*G[{yu}, yv^(-1)]*G[{0, 1, 1/(yu*yv)}, yw])/16 - 
     (G[{1}, yv^(-1)]*G[{yu}, yv^(-1)]*G[{0, 1, 1/(yu*yv)}, yw])/8 - 
     (G[{1}, yw]*G[{yu}, yv^(-1)]*G[{0, 1, 1/(yu*yv)}, yw])/16 + 
     (G[{yu}, yv^(-1)]^2*G[{0, 1, 1/(yu*yv)}, yw])/8 - 
     (G[{0}, yu^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, 1, 1/(yu*yv)}, yw])/16 - 
     (G[{0}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, 1, 1/(yu*yv)}, yw])/16 + 
     (G[{0}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1, 1/(yu*yv)}, yw])/16 - 
     (G[{1}, yu^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, 1, 1/(yu*yv)}, yw])/16 + 
     (G[{1}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, 1, 1/(yu*yv)}, yw])/8 - 
     (G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1, 1/(yu*yv)}, yw])/16 - 
     (G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1, 1/(yu*yv)}, yw])/8 + 
     (G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, 1, 1/(yu*yv)}, yw])/16 + 
     (G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1, 1/(yu*yv)}, yw])/16 - 
     (G[{0, 1}, yu^(-1)]*G[{0, 1, 1/(yu*yv)}, yw])/16 - 
     (G[{0, 1}, yv^(-1)]*G[{0, 1, 1/(yu*yv)}, yw])/16 + 
     (G[{0, yu^(-1)}, yw]*G[{0, 1, 1/(yu*yv)}, yw])/16 + 
     (G[{0, yu}, yv^(-1)]*G[{0, 1, 1/(yu*yv)}, yw])/16 - 
     (G[{0, yv^(-1)}, yw]*G[{0, 1, 1/(yu*yv)}, yw])/16 - 
     (G[{0, 1/(yu*yv)}, yw]*G[{0, 1, 1/(yu*yv)}, yw])/16 + 
     (G[{1, yv^(-1)}, yw]*G[{0, 1, 1/(yu*yv)}, yw])/16 + 
     (G[{1, 1/(yu*yv)}, yw]*G[{0, 1, 1/(yu*yv)}, yw])/16 + 
     (G[{yu^(-1), 1/(yu*yv)}, yw]*G[{0, 1, 1/(yu*yv)}, yw])/8 - 
     (G[{yv^(-1), 1/(yu*yv)}, yw]*G[{0, 1, 1/(yu*yv)}, yw])/16 - 
     (G[{1}, yv^(-1)]^2*G[{0, yu^(-1), 1}, yw])/16 - 
     (G[{0}, yu^(-1)]*G[{1}, yw]*G[{0, yu^(-1), 1}, yw])/8 - 
     (G[{0}, yv^(-1)]*G[{1}, yw]*G[{0, yu^(-1), 1}, yw])/8 + 
     (G[{0}, yw]*G[{1}, yw]*G[{0, yu^(-1), 1}, yw])/8 + 
     (G[{1}, yu^(-1)]*G[{1}, yw]*G[{0, yu^(-1), 1}, yw])/8 - 
     (G[{1}, yv^(-1)]*G[{1}, yw]*G[{0, yu^(-1), 1}, yw])/16 - 
     (G[{1}, yw]^2*G[{0, yu^(-1), 1}, yw])/32 + 
     (G[{1}, yv^(-1)]*G[{yu}, yv^(-1)]*G[{0, yu^(-1), 1}, yw])/8 + 
     (3*G[{1}, yw]*G[{yu}, yv^(-1)]*G[{0, yu^(-1), 1}, yw])/16 - 
     (G[{yu}, yv^(-1)]^2*G[{0, yu^(-1), 1}, yw])/16 + 
     (G[{0}, yu^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1), 1}, yw])/16 + 
     (G[{0}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1), 1}, yw])/16 - 
     (G[{0}, yw]*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1), 1}, yw])/16 + 
     (G[{1}, yu^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1), 1}, yw])/16 - 
     (G[{1}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1), 1}, yw])/8 + 
     (G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1), 1}, yw])/16 + 
     (G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1), 1}, yw])/8 - 
     (G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1), 1}, yw])/16 - 
     (G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1), 1}, yw])/16 + 
     (G[{0, 1}, yw]*G[{0, yu^(-1), 1}, yw])/16 - 
     (G[{0, yu^(-1)}, yw]*G[{0, yu^(-1), 1}, yw])/16 + 
     (G[{0, yv^(-1)}, yw]*G[{0, yu^(-1), 1}, yw])/16 + 
     (G[{0, 1/(yu*yv)}, yw]*G[{0, yu^(-1), 1}, yw])/16 - 
     (G[{1, yv^(-1)}, yw]*G[{0, yu^(-1), 1}, yw])/16 - 
     (G[{1, 1/(yu*yv)}, yw]*G[{0, yu^(-1), 1}, yw])/16 - 
     (G[{yu^(-1), 1/(yu*yv)}, yw]*G[{0, yu^(-1), 1}, yw])/8 + 
     (G[{yv^(-1), 1/(yu*yv)}, yw]*G[{0, yu^(-1), 1}, yw])/16 + 
     (Pi^2*G[{0, yu^(-1), yu^(-1)}, yw])/96 + 
     (G[{1}, yv^(-1)]^2*G[{0, yu^(-1), yu^(-1)}, yw])/32 + 
     (3*G[{0}, yu^(-1)]*G[{1}, yw]*G[{0, yu^(-1), yu^(-1)}, yw])/16 + 
     (3*G[{0}, yv^(-1)]*G[{1}, yw]*G[{0, yu^(-1), yu^(-1)}, yw])/16 - 
     (3*G[{0}, yw]*G[{1}, yw]*G[{0, yu^(-1), yu^(-1)}, yw])/16 - 
     (3*G[{1}, yu^(-1)]*G[{1}, yw]*G[{0, yu^(-1), yu^(-1)}, yw])/16 - 
     (G[{1}, yv^(-1)]*G[{1}, yw]*G[{0, yu^(-1), yu^(-1)}, yw])/4 - 
     (G[{1}, yw]^2*G[{0, yu^(-1), yu^(-1)}, yw])/32 + 
     (G[{1}, yw]*G[{yu}, yv^(-1)]*G[{0, yu^(-1), yu^(-1)}, yw])/16 - 
     (G[{0}, yu^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1), yu^(-1)}, yw])/16 - 
     (G[{0}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1), yu^(-1)}, yw])/16 + 
     (G[{0}, yw]*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1), yu^(-1)}, yw])/16 + 
     (G[{1}, yu^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1), yu^(-1)}, yw])/16 + 
     (G[{1}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1), yu^(-1)}, yw])/8 + 
     (G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1), yu^(-1)}, yw])/16 - 
     (G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1), yu^(-1)}, yw])/8 - 
     (G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1), yu^(-1)}, yw])/16 + 
     (G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1), yu^(-1)}, yw])/16 - 
     (G[{0, 1}, yv^(-1)]*G[{0, yu^(-1), yu^(-1)}, yw])/16 + 
     (G[{0, 1}, yw]*G[{0, yu^(-1), yu^(-1)}, yw])/8 - 
     (G[{0, yu^(-1)}, yw]*G[{0, yu^(-1), yu^(-1)}, yw])/8 + 
     (G[{0, yu}, yv^(-1)]*G[{0, yu^(-1), yu^(-1)}, yw])/16 - 
     (G[{0, yv^(-1)}, yw]*G[{0, yu^(-1), yu^(-1)}, yw])/16 - 
     (G[{0, 1/(yu*yv)}, yw]*G[{0, yu^(-1), yu^(-1)}, yw])/16 - 
     (G[{1, yu}, yv^(-1)]*G[{0, yu^(-1), yu^(-1)}, yw])/16 + 
     (G[{1, yv^(-1)}, yw]*G[{0, yu^(-1), yu^(-1)}, yw])/16 - 
     (G[{1, 1/(yu*yv)}, yw]*G[{0, yu^(-1), yu^(-1)}, yw])/16 + 
     (G[{yu^(-1), 1/(yu*yv)}, yw]*G[{0, yu^(-1), yu^(-1)}, yw])/8 - 
     (G[{yv^(-1), 1/(yu*yv)}, yw]*G[{0, yu^(-1), yu^(-1)}, yw])/16 + 
     (Pi^2*G[{0, yu^(-1), yv^(-1)}, yw])/32 - 
     (G[{0}, yu^(-1)]*G[{1}, yu^(-1)]*G[{0, yu^(-1), yv^(-1)}, yw])/8 - 
     (G[{0}, yv^(-1)]*G[{1}, yu^(-1)]*G[{0, yu^(-1), yv^(-1)}, yw])/8 + 
     (G[{0}, yw]*G[{1}, yu^(-1)]*G[{0, yu^(-1), yv^(-1)}, yw])/8 + 
     (G[{1}, yu^(-1)]^2*G[{0, yu^(-1), yv^(-1)}, yw])/8 + 
     (G[{0}, yu^(-1)]*G[{1}, yv^(-1)]*G[{0, yu^(-1), yv^(-1)}, yw])/8 + 
     (G[{0}, yv^(-1)]*G[{1}, yv^(-1)]*G[{0, yu^(-1), yv^(-1)}, yw])/8 - 
     (G[{0}, yw]*G[{1}, yv^(-1)]*G[{0, yu^(-1), yv^(-1)}, yw])/8 - 
     (3*G[{1}, yv^(-1)]^2*G[{0, yu^(-1), yv^(-1)}, yw])/32 + 
     (G[{0}, yu^(-1)]*G[{1}, yw]*G[{0, yu^(-1), yv^(-1)}, yw])/8 + 
     (G[{0}, yv^(-1)]*G[{1}, yw]*G[{0, yu^(-1), yv^(-1)}, yw])/8 - 
     (G[{0}, yw]*G[{1}, yw]*G[{0, yu^(-1), yv^(-1)}, yw])/8 - 
     (3*G[{1}, yu^(-1)]*G[{1}, yw]*G[{0, yu^(-1), yv^(-1)}, yw])/16 - 
     (G[{1}, yv^(-1)]*G[{1}, yw]*G[{0, yu^(-1), yv^(-1)}, yw])/8 - 
     (G[{1}, yw]^2*G[{0, yu^(-1), yv^(-1)}, yw])/32 + 
     (G[{1}, yw]*G[{yu}, yv^(-1)]*G[{0, yu^(-1), yv^(-1)}, yw])/16 - 
     (G[{0}, yu^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1), yv^(-1)}, yw])/8 - 
     (G[{0}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1), yv^(-1)}, yw])/8 + 
     (G[{0}, yw]*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1), yv^(-1)}, yw])/8 + 
     (G[{1}, yu^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1), yv^(-1)}, yw])/16 + 
     (G[{1}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1), yv^(-1)}, yw])/4 + 
     (G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1), yv^(-1)}, yw])/16 - 
     (G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1), yv^(-1)}, yw])/8 - 
     (G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1), yv^(-1)}, yw])/16 + 
     (G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1), yv^(-1)}, yw])/16 + 
     (G[{0, 1}, yu^(-1)]*G[{0, yu^(-1), yv^(-1)}, yw])/8 + 
     (G[{0, 1}, yv^(-1)]*G[{0, yu^(-1), yv^(-1)}, yw])/16 - 
     (G[{0, yu}, yv^(-1)]*G[{0, yu^(-1), yv^(-1)}, yw])/16 - 
     (G[{0, yv^(-1)}, yw]*G[{0, yu^(-1), yv^(-1)}, yw])/16 - 
     (G[{1, yu}, yv^(-1)]*G[{0, yu^(-1), yv^(-1)}, yw])/16 + 
     (G[{1, yv^(-1)}, yw]*G[{0, yu^(-1), yv^(-1)}, yw])/16 - 
     (G[{1, 1/(yu*yv)}, yw]*G[{0, yu^(-1), yv^(-1)}, yw])/16 + 
     (G[{yu^(-1), 1/(yu*yv)}, yw]*G[{0, yu^(-1), yv^(-1)}, yw])/8 - 
     (G[{yv^(-1), 1/(yu*yv)}, yw]*G[{0, yu^(-1), yv^(-1)}, yw])/16 - 
     (Pi^2*G[{0, yu^(-1), 1/(yu*yv)}, yw])/96 + 
     (G[{0}, yu^(-1)]*G[{1}, yu^(-1)]*G[{0, yu^(-1), 1/(yu*yv)}, yw])/16 + 
     (G[{0}, yv^(-1)]*G[{1}, yu^(-1)]*G[{0, yu^(-1), 1/(yu*yv)}, yw])/16 - 
     (G[{0}, yw]*G[{1}, yu^(-1)]*G[{0, yu^(-1), 1/(yu*yv)}, yw])/16 - 
     (3*G[{1}, yu^(-1)]^2*G[{0, yu^(-1), 1/(yu*yv)}, yw])/32 - 
     (G[{0}, yu^(-1)]*G[{1}, yv^(-1)]*G[{0, yu^(-1), 1/(yu*yv)}, yw])/16 - 
     (G[{0}, yv^(-1)]*G[{1}, yv^(-1)]*G[{0, yu^(-1), 1/(yu*yv)}, yw])/16 + 
     (G[{0}, yw]*G[{1}, yv^(-1)]*G[{0, yu^(-1), 1/(yu*yv)}, yw])/16 + 
     (G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*G[{0, yu^(-1), 1/(yu*yv)}, yw])/16 + 
     (3*G[{1}, yv^(-1)]^2*G[{0, yu^(-1), 1/(yu*yv)}, yw])/32 - 
     (G[{0}, yu^(-1)]*G[{1}, yw]*G[{0, yu^(-1), 1/(yu*yv)}, yw])/8 - 
     (G[{0}, yv^(-1)]*G[{1}, yw]*G[{0, yu^(-1), 1/(yu*yv)}, yw])/8 + 
     (G[{0}, yw]*G[{1}, yw]*G[{0, yu^(-1), 1/(yu*yv)}, yw])/8 + 
     (G[{1}, yu^(-1)]*G[{1}, yw]*G[{0, yu^(-1), 1/(yu*yv)}, yw])/4 + 
     (G[{1}, yv^(-1)]*G[{1}, yw]*G[{0, yu^(-1), 1/(yu*yv)}, yw])/16 - 
     (G[{1}, yw]^2*G[{0, yu^(-1), 1/(yu*yv)}, yw])/32 - 
     (G[{1}, yv^(-1)]*G[{yu}, yv^(-1)]*G[{0, yu^(-1), 1/(yu*yv)}, yw])/8 - 
     (G[{1}, yw]*G[{yu}, yv^(-1)]*G[{0, yu^(-1), 1/(yu*yv)}, yw])/16 + 
     (G[{yu}, yv^(-1)]^2*G[{0, yu^(-1), 1/(yu*yv)}, yw])/16 + 
     (G[{0}, yu^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1), 1/(yu*yv)}, yw])/16 + 
     (G[{0}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1), 1/(yu*yv)}, yw])/16 - 
     (G[{0}, yw]*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1), 1/(yu*yv)}, yw])/16 + 
     (G[{1}, yu^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1), 1/(yu*yv)}, yw])/16 - 
     (G[{1}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1), 1/(yu*yv)}, yw])/8 + 
     (G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1), 1/(yu*yv)}, yw])/16 + 
     (G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1), 1/(yu*yv)}, yw])/8 - 
     (G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1), 1/(yu*yv)}, yw])/
      16 - (G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1), 1/(yu*yv)}, 
        yw])/16 - (G[{0, 1}, yw]*G[{0, yu^(-1), 1/(yu*yv)}, yw])/8 + 
     (G[{0, yu^(-1)}, yw]*G[{0, yu^(-1), 1/(yu*yv)}, yw])/8 + 
     (G[{0, yv^(-1)}, yw]*G[{0, yu^(-1), 1/(yu*yv)}, yw])/16 + 
     (G[{0, 1/(yu*yv)}, yw]*G[{0, yu^(-1), 1/(yu*yv)}, yw])/16 - 
     (G[{1, yv^(-1)}, yw]*G[{0, yu^(-1), 1/(yu*yv)}, yw])/16 - 
     (G[{1, 1/(yu*yv)}, yw]*G[{0, yu^(-1), 1/(yu*yv)}, yw])/16 - 
     (G[{yu^(-1), 1/(yu*yv)}, yw]*G[{0, yu^(-1), 1/(yu*yv)}, yw])/8 + 
     (G[{yv^(-1), 1/(yu*yv)}, yw]*G[{0, yu^(-1), 1/(yu*yv)}, yw])/16 + 
     (3*Pi^2*G[{0, yu, 1}, yv^(-1)])/128 + 
     (3*G[{0}, yu^(-1)]^2*G[{0, yu, 1}, yv^(-1)])/128 + 
     (3*G[{0}, yu^(-1)]*G[{0}, yv^(-1)]*G[{0, yu, 1}, yv^(-1)])/64 + 
     (3*G[{0}, yv^(-1)]^2*G[{0, yu, 1}, yv^(-1)])/128 - 
     (3*G[{0}, yu^(-1)]*G[{0}, yw]*G[{0, yu, 1}, yv^(-1)])/64 - 
     (3*G[{0}, yv^(-1)]*G[{0}, yw]*G[{0, yu, 1}, yv^(-1)])/64 + 
     (3*G[{0}, yw]^2*G[{0, yu, 1}, yv^(-1)])/128 + 
     (5*G[{0}, yu^(-1)]*G[{1}, yu^(-1)]*G[{0, yu, 1}, yv^(-1)])/64 + 
     (5*G[{0}, yv^(-1)]*G[{1}, yu^(-1)]*G[{0, yu, 1}, yv^(-1)])/64 - 
     (5*G[{0}, yw]*G[{1}, yu^(-1)]*G[{0, yu, 1}, yv^(-1)])/64 - 
     (21*G[{1}, yu^(-1)]^2*G[{0, yu, 1}, yv^(-1)])/128 + 
     (9*G[{0}, yu^(-1)]*G[{1}, yv^(-1)]*G[{0, yu, 1}, yv^(-1)])/64 + 
     (9*G[{0}, yv^(-1)]*G[{1}, yv^(-1)]*G[{0, yu, 1}, yv^(-1)])/64 - 
     (9*G[{0}, yw]*G[{1}, yv^(-1)]*G[{0, yu, 1}, yv^(-1)])/64 - 
     (G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*G[{0, yu, 1}, yv^(-1)])/64 - 
     (17*G[{1}, yv^(-1)]^2*G[{0, yu, 1}, yv^(-1)])/128 + 
     (11*G[{0}, yu^(-1)]*G[{1}, yw]*G[{0, yu, 1}, yv^(-1)])/64 + 
     (11*G[{0}, yv^(-1)]*G[{1}, yw]*G[{0, yu, 1}, yv^(-1)])/64 - 
     (11*G[{0}, yw]*G[{1}, yw]*G[{0, yu, 1}, yv^(-1)])/64 + 
     (5*G[{1}, yu^(-1)]*G[{1}, yw]*G[{0, yu, 1}, yv^(-1)])/64 + 
     (G[{1}, yv^(-1)]*G[{1}, yw]*G[{0, yu, 1}, yv^(-1)])/64 + 
     (G[{1}, yw]^2*G[{0, yu, 1}, yv^(-1)])/8 - 
     (3*G[{1}, yw]*G[{yu}, yv^(-1)]*G[{0, yu, 1}, yv^(-1)])/32 - 
     (9*G[{0}, yu^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, yu, 1}, yv^(-1)])/64 - 
     (9*G[{0}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, yu, 1}, yv^(-1)])/64 + 
     (9*G[{0}, yw]*G[{1/(yu*yv)}, yw]*G[{0, yu, 1}, yv^(-1)])/64 + 
     (G[{1}, yu^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, yu, 1}, yv^(-1)])/64 + 
     (17*G[{1}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, yu, 1}, yv^(-1)])/64 - 
     (11*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{0, yu, 1}, yv^(-1)])/64 + 
     (3*G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, yu, 1}, yv^(-1)])/32 - 
     (G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{0, yu, 1}, yv^(-1)])/64 - 
     (3*G[{1/(yu*yv)}, yw]^2*G[{0, yu, 1}, yv^(-1)])/64 + 
     (G[{0, 1}, yu^(-1)]*G[{0, yu, 1}, yv^(-1)])/16 + 
     (3*G[{0, 1}, yv^(-1)]*G[{0, yu, 1}, yv^(-1)])/64 + 
     (3*G[{0, 1}, yw]*G[{0, yu, 1}, yv^(-1)])/64 + 
     (5*G[{0, yu^(-1)}, yw]*G[{0, yu, 1}, yv^(-1)])/64 - 
     (3*G[{0, yu}, yv^(-1)]*G[{0, yu, 1}, yv^(-1)])/64 + 
     (G[{0, yv^(-1)}, yw]*G[{0, yu, 1}, yv^(-1)])/64 - 
     (9*G[{0, 1/(yu*yv)}, yw]*G[{0, yu, 1}, yv^(-1)])/64 + 
     (G[{1, yu^(-1)}, yw]*G[{0, yu, 1}, yv^(-1)])/64 - 
     (3*G[{1, yu}, yv^(-1)]*G[{0, yu, 1}, yv^(-1)])/32 - 
     (G[{1, yv^(-1)}, yw]*G[{0, yu, 1}, yv^(-1)])/64 + 
     (3*G[{1, 1/(yu*yv)}, yw]*G[{0, yu, 1}, yv^(-1)])/32 + 
     (11*G[{yu^(-1), 1/(yu*yv)}, yw]*G[{0, yu, 1}, yv^(-1)])/64 + 
     (G[{yv^(-1), 1/(yu*yv)}, yw]*G[{0, yu, 1}, yv^(-1)])/64 - 
     (23*Pi^2*G[{0, yu, yu}, yv^(-1)])/256 - 
     (3*G[{0}, yu^(-1)]^2*G[{0, yu, yu}, yv^(-1)])/64 - 
     (3*G[{0}, yu^(-1)]*G[{0}, yv^(-1)]*G[{0, yu, yu}, yv^(-1)])/32 - 
     (3*G[{0}, yv^(-1)]^2*G[{0, yu, yu}, yv^(-1)])/64 + 
     (3*G[{0}, yu^(-1)]*G[{0}, yw]*G[{0, yu, yu}, yv^(-1)])/32 + 
     (3*G[{0}, yv^(-1)]*G[{0}, yw]*G[{0, yu, yu}, yv^(-1)])/32 - 
     (3*G[{0}, yw]^2*G[{0, yu, yu}, yv^(-1)])/64 - 
     (G[{0}, yu^(-1)]*G[{1}, yu^(-1)]*G[{0, yu, yu}, yv^(-1)])/32 - 
     (G[{0}, yv^(-1)]*G[{1}, yu^(-1)]*G[{0, yu, yu}, yv^(-1)])/32 + 
     (G[{0}, yw]*G[{1}, yu^(-1)]*G[{0, yu, yu}, yv^(-1)])/32 + 
     (9*G[{1}, yu^(-1)]^2*G[{0, yu, yu}, yv^(-1)])/64 - 
     (5*G[{0}, yu^(-1)]*G[{1}, yv^(-1)]*G[{0, yu, yu}, yv^(-1)])/32 - 
     (5*G[{0}, yv^(-1)]*G[{1}, yv^(-1)]*G[{0, yu, yu}, yv^(-1)])/32 + 
     (5*G[{0}, yw]*G[{1}, yv^(-1)]*G[{0, yu, yu}, yv^(-1)])/32 + 
     (G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*G[{0, yu, yu}, yv^(-1)])/32 + 
     (3*G[{1}, yv^(-1)]^2*G[{0, yu, yu}, yv^(-1)])/32 - 
     (7*G[{0}, yu^(-1)]*G[{1}, yw]*G[{0, yu, yu}, yv^(-1)])/32 - 
     (7*G[{0}, yv^(-1)]*G[{1}, yw]*G[{0, yu, yu}, yv^(-1)])/32 + 
     (7*G[{0}, yw]*G[{1}, yw]*G[{0, yu, yu}, yv^(-1)])/32 - 
     (G[{1}, yu^(-1)]*G[{1}, yw]*G[{0, yu, yu}, yv^(-1)])/32 - 
     (7*G[{1}, yw]^2*G[{0, yu, yu}, yv^(-1)])/64 + 
     (G[{1}, yw]*G[{yu}, yv^(-1)]*G[{0, yu, yu}, yv^(-1)])/16 + 
     (5*G[{0}, yu^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, yu, yu}, yv^(-1)])/32 + 
     (5*G[{0}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, yu, yu}, yv^(-1)])/32 - 
     (5*G[{0}, yw]*G[{1/(yu*yv)}, yw]*G[{0, yu, yu}, yv^(-1)])/32 - 
     (G[{1}, yu^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, yu, yu}, yv^(-1)])/32 - 
     (3*G[{1}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, yu, yu}, yv^(-1)])/16 - 
     (G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{0, yu, yu}, yv^(-1)])/32 + 
     (3*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{0, yu, yu}, yv^(-1)])/32 - 
     (G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, yu, yu}, yv^(-1)])/16 + 
     (G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{0, yu, yu}, yv^(-1)])/32 + 
     (3*G[{1/(yu*yv)}, yw]^2*G[{0, yu, yu}, yv^(-1)])/64 - 
     (G[{0, 1}, yu^(-1)]*G[{0, yu, yu}, yv^(-1)])/4 - 
     (G[{0, 1}, yv^(-1)]*G[{0, yu, yu}, yv^(-1)])/8 + 
     (G[{0, 1}, yw]*G[{0, yu, yu}, yv^(-1)])/32 - 
     (5*G[{0, yu^(-1)}, yw]*G[{0, yu, yu}, yv^(-1)])/32 + 
     (G[{0, yu}, yv^(-1)]*G[{0, yu, yu}, yv^(-1)])/8 - 
     (G[{0, yv^(-1)}, yw]*G[{0, yu, yu}, yv^(-1)])/32 + 
     (5*G[{0, 1/(yu*yv)}, yw]*G[{0, yu, yu}, yv^(-1)])/32 - 
     (G[{1, yu^(-1)}, yw]*G[{0, yu, yu}, yv^(-1)])/32 + 
     (G[{1, yu}, yv^(-1)]*G[{0, yu, yu}, yv^(-1)])/16 + 
     (G[{1, yv^(-1)}, yw]*G[{0, yu, yu}, yv^(-1)])/32 - 
     (G[{1, 1/(yu*yv)}, yw]*G[{0, yu, yu}, yv^(-1)])/16 - 
     (3*G[{yu^(-1), 1/(yu*yv)}, yw]*G[{0, yu, yu}, yv^(-1)])/32 - 
     (G[{yv^(-1), 1/(yu*yv)}, yw]*G[{0, yu, yu}, yv^(-1)])/32 + 
     (Pi^2*G[{0, yv^(-1), 1}, yw])/24 - 
     (G[{1}, yu^(-1)]^2*G[{0, yv^(-1), 1}, yw])/32 + 
     (G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*G[{0, yv^(-1), 1}, yw])/16 + 
     (G[{1}, yv^(-1)]^2*G[{0, yv^(-1), 1}, yw])/32 + 
     (G[{1}, yu^(-1)]*G[{1}, yw]*G[{0, yv^(-1), 1}, yw])/8 - 
     (G[{1}, yv^(-1)]*G[{1}, yw]*G[{0, yv^(-1), 1}, yw])/16 - 
     (G[{1}, yw]^2*G[{0, yv^(-1), 1}, yw])/32 - 
     (G[{1}, yv^(-1)]*G[{yu}, yv^(-1)]*G[{0, yv^(-1), 1}, yw])/8 - 
     (G[{1}, yw]*G[{yu}, yv^(-1)]*G[{0, yv^(-1), 1}, yw])/16 + 
     (G[{yu}, yv^(-1)]^2*G[{0, yv^(-1), 1}, yw])/16 + 
     (G[{0}, yu^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, yv^(-1), 1}, yw])/16 + 
     (G[{0}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, yv^(-1), 1}, yw])/16 - 
     (G[{0}, yw]*G[{1/(yu*yv)}, yw]*G[{0, yv^(-1), 1}, yw])/16 + 
     (G[{1}, yu^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, yv^(-1), 1}, yw])/16 - 
     (G[{1}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, yv^(-1), 1}, yw])/8 + 
     (G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{0, yv^(-1), 1}, yw])/16 + 
     (G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{0, yv^(-1), 1}, yw])/8 - 
     (G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, yv^(-1), 1}, yw])/16 - 
     (G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{0, yv^(-1), 1}, yw])/16 + 
     (G[{0, 1}, yu^(-1)]*G[{0, yv^(-1), 1}, yw])/16 + 
     (G[{0, 1}, yv^(-1)]*G[{0, yv^(-1), 1}, yw])/16 + 
     (G[{0, 1}, yw]*G[{0, yv^(-1), 1}, yw])/16 - 
     (G[{0, yu^(-1)}, yw]*G[{0, yv^(-1), 1}, yw])/16 - 
     (G[{0, yu}, yv^(-1)]*G[{0, yv^(-1), 1}, yw])/16 - 
     (G[{0, yv^(-1)}, yw]*G[{0, yv^(-1), 1}, yw])/16 + 
     (G[{0, 1/(yu*yv)}, yw]*G[{0, yv^(-1), 1}, yw])/16 - 
     (G[{1, yv^(-1)}, yw]*G[{0, yv^(-1), 1}, yw])/16 - 
     (G[{1, 1/(yu*yv)}, yw]*G[{0, yv^(-1), 1}, yw])/16 - 
     (G[{yu^(-1), 1/(yu*yv)}, yw]*G[{0, yv^(-1), 1}, yw])/8 + 
     (G[{yv^(-1), 1/(yu*yv)}, yw]*G[{0, yv^(-1), 1}, yw])/16 + 
     (Pi^2*G[{0, yv^(-1), yu^(-1)}, yw])/32 - 
     (G[{0}, yu^(-1)]*G[{1}, yu^(-1)]*G[{0, yv^(-1), yu^(-1)}, yw])/8 - 
     (G[{0}, yv^(-1)]*G[{1}, yu^(-1)]*G[{0, yv^(-1), yu^(-1)}, yw])/8 + 
     (G[{0}, yw]*G[{1}, yu^(-1)]*G[{0, yv^(-1), yu^(-1)}, yw])/8 + 
     (G[{1}, yu^(-1)]^2*G[{0, yv^(-1), yu^(-1)}, yw])/8 + 
     (G[{0}, yu^(-1)]*G[{1}, yv^(-1)]*G[{0, yv^(-1), yu^(-1)}, yw])/8 + 
     (G[{0}, yv^(-1)]*G[{1}, yv^(-1)]*G[{0, yv^(-1), yu^(-1)}, yw])/8 - 
     (G[{0}, yw]*G[{1}, yv^(-1)]*G[{0, yv^(-1), yu^(-1)}, yw])/8 - 
     (3*G[{1}, yv^(-1)]^2*G[{0, yv^(-1), yu^(-1)}, yw])/32 + 
     (G[{0}, yu^(-1)]*G[{1}, yw]*G[{0, yv^(-1), yu^(-1)}, yw])/8 + 
     (G[{0}, yv^(-1)]*G[{1}, yw]*G[{0, yv^(-1), yu^(-1)}, yw])/8 - 
     (G[{0}, yw]*G[{1}, yw]*G[{0, yv^(-1), yu^(-1)}, yw])/8 - 
     (3*G[{1}, yu^(-1)]*G[{1}, yw]*G[{0, yv^(-1), yu^(-1)}, yw])/16 - 
     (G[{1}, yv^(-1)]*G[{1}, yw]*G[{0, yv^(-1), yu^(-1)}, yw])/8 - 
     (G[{1}, yw]^2*G[{0, yv^(-1), yu^(-1)}, yw])/32 + 
     (G[{1}, yw]*G[{yu}, yv^(-1)]*G[{0, yv^(-1), yu^(-1)}, yw])/16 - 
     (G[{0}, yu^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, yv^(-1), yu^(-1)}, yw])/8 - 
     (G[{0}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, yv^(-1), yu^(-1)}, yw])/8 + 
     (G[{0}, yw]*G[{1/(yu*yv)}, yw]*G[{0, yv^(-1), yu^(-1)}, yw])/8 + 
     (G[{1}, yu^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, yv^(-1), yu^(-1)}, yw])/16 + 
     (G[{1}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, yv^(-1), yu^(-1)}, yw])/4 + 
     (G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{0, yv^(-1), yu^(-1)}, yw])/16 - 
     (G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{0, yv^(-1), yu^(-1)}, yw])/8 - 
     (G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, yv^(-1), yu^(-1)}, yw])/16 + 
     (G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{0, yv^(-1), yu^(-1)}, yw])/16 + 
     (G[{0, 1}, yu^(-1)]*G[{0, yv^(-1), yu^(-1)}, yw])/8 + 
     (G[{0, 1}, yv^(-1)]*G[{0, yv^(-1), yu^(-1)}, yw])/16 - 
     (G[{0, yu}, yv^(-1)]*G[{0, yv^(-1), yu^(-1)}, yw])/16 - 
     (G[{1, yu}, yv^(-1)]*G[{0, yv^(-1), yu^(-1)}, yw])/16 + 
     (G[{1, yv^(-1)}, yw]*G[{0, yv^(-1), yu^(-1)}, yw])/16 - 
     (G[{1, 1/(yu*yv)}, yw]*G[{0, yv^(-1), yu^(-1)}, yw])/16 + 
     (G[{yu^(-1), 1/(yu*yv)}, yw]*G[{0, yv^(-1), yu^(-1)}, yw])/8 - 
     (G[{yv^(-1), 1/(yu*yv)}, yw]*G[{0, yv^(-1), yu^(-1)}, yw])/16 - 
     (Pi^2*G[{0, yv^(-1), yv^(-1)}, yw])/32 - 
     (G[{1}, yu^(-1)]^2*G[{0, yv^(-1), yv^(-1)}, yw])/16 + 
     (G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*G[{0, yv^(-1), yv^(-1)}, yw])/8 - 
     (5*G[{1}, yv^(-1)]^2*G[{0, yv^(-1), yv^(-1)}, yw])/32 - 
     (G[{0}, yu^(-1)]*G[{1}, yw]*G[{0, yv^(-1), yv^(-1)}, yw])/16 - 
     (G[{0}, yv^(-1)]*G[{1}, yw]*G[{0, yv^(-1), yv^(-1)}, yw])/16 + 
     (G[{0}, yw]*G[{1}, yw]*G[{0, yv^(-1), yv^(-1)}, yw])/16 + 
     (3*G[{1}, yu^(-1)]*G[{1}, yw]*G[{0, yv^(-1), yv^(-1)}, yw])/16 - 
     (G[{1}, yv^(-1)]*G[{1}, yw]*G[{0, yv^(-1), yv^(-1)}, yw])/8 - 
     (G[{1}, yw]^2*G[{0, yv^(-1), yv^(-1)}, yw])/32 + 
     (G[{1}, yw]*G[{yu}, yv^(-1)]*G[{0, yv^(-1), yv^(-1)}, yw])/16 - 
     (G[{0}, yu^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, yv^(-1), yv^(-1)}, yw])/16 - 
     (G[{0}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, yv^(-1), yv^(-1)}, yw])/16 + 
     (G[{0}, yw]*G[{1/(yu*yv)}, yw]*G[{0, yv^(-1), yv^(-1)}, yw])/16 - 
     (G[{1}, yu^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, yv^(-1), yv^(-1)}, yw])/16 + 
     (G[{1}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, yv^(-1), yv^(-1)}, yw])/4 + 
     (G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{0, yv^(-1), yv^(-1)}, yw])/16 - 
     (G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{0, yv^(-1), yv^(-1)}, yw])/8 - 
     (G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, yv^(-1), yv^(-1)}, yw])/16 + 
     (G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{0, yv^(-1), yv^(-1)}, yw])/16 - 
     (G[{0, 1}, yu^(-1)]*G[{0, yv^(-1), yv^(-1)}, yw])/8 + 
     (G[{0, 1}, yv^(-1)]*G[{0, yv^(-1), yv^(-1)}, yw])/16 - 
     (G[{0, 1}, yw]*G[{0, yv^(-1), yv^(-1)}, yw])/8 + 
     (G[{0, yu^(-1)}, yw]*G[{0, yv^(-1), yv^(-1)}, yw])/8 - 
     (G[{0, yu}, yv^(-1)]*G[{0, yv^(-1), yv^(-1)}, yw])/16 + 
     (G[{0, yv^(-1)}, yw]*G[{0, yv^(-1), yv^(-1)}, yw])/8 - 
     (G[{0, 1/(yu*yv)}, yw]*G[{0, yv^(-1), yv^(-1)}, yw])/16 + 
     (3*G[{1, yu}, yv^(-1)]*G[{0, yv^(-1), yv^(-1)}, yw])/16 + 
     (G[{1, yv^(-1)}, yw]*G[{0, yv^(-1), yv^(-1)}, yw])/16 - 
     (G[{1, 1/(yu*yv)}, yw]*G[{0, yv^(-1), yv^(-1)}, yw])/16 + 
     (G[{yu^(-1), 1/(yu*yv)}, yw]*G[{0, yv^(-1), yv^(-1)}, yw])/8 - 
     (G[{yv^(-1), 1/(yu*yv)}, yw]*G[{0, yv^(-1), yv^(-1)}, yw])/16 + 
     (Pi^2*G[{0, yv^(-1), 1/(yu*yv)}, yw])/96 + 
     (G[{0}, yu^(-1)]*G[{1}, yu^(-1)]*G[{0, yv^(-1), 1/(yu*yv)}, yw])/16 + 
     (G[{0}, yv^(-1)]*G[{1}, yu^(-1)]*G[{0, yv^(-1), 1/(yu*yv)}, yw])/16 - 
     (G[{0}, yw]*G[{1}, yu^(-1)]*G[{0, yv^(-1), 1/(yu*yv)}, yw])/16 - 
     (G[{1}, yu^(-1)]^2*G[{0, yv^(-1), 1/(yu*yv)}, yw])/16 - 
     (G[{0}, yu^(-1)]*G[{1}, yv^(-1)]*G[{0, yv^(-1), 1/(yu*yv)}, yw])/16 - 
     (G[{0}, yv^(-1)]*G[{1}, yv^(-1)]*G[{0, yv^(-1), 1/(yu*yv)}, yw])/16 + 
     (G[{0}, yw]*G[{1}, yv^(-1)]*G[{0, yv^(-1), 1/(yu*yv)}, yw])/16 - 
     (3*G[{1}, yv^(-1)]*G[{1}, yw]*G[{0, yv^(-1), 1/(yu*yv)}, yw])/16 - 
     (G[{1}, yw]^2*G[{0, yv^(-1), 1/(yu*yv)}, yw])/32 + 
     (G[{1}, yv^(-1)]*G[{yu}, yv^(-1)]*G[{0, yv^(-1), 1/(yu*yv)}, yw])/8 + 
     (3*G[{1}, yw]*G[{yu}, yv^(-1)]*G[{0, yv^(-1), 1/(yu*yv)}, yw])/16 - 
     (G[{yu}, yv^(-1)]^2*G[{0, yv^(-1), 1/(yu*yv)}, yw])/16 + 
     (G[{0}, yu^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, yv^(-1), 1/(yu*yv)}, yw])/16 + 
     (G[{0}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, yv^(-1), 1/(yu*yv)}, yw])/16 - 
     (G[{0}, yw]*G[{1/(yu*yv)}, yw]*G[{0, yv^(-1), 1/(yu*yv)}, yw])/16 + 
     (G[{1}, yu^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, yv^(-1), 1/(yu*yv)}, yw])/16 - 
     (G[{1}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, yv^(-1), 1/(yu*yv)}, yw])/8 + 
     (G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{0, yv^(-1), 1/(yu*yv)}, yw])/16 + 
     (G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{0, yv^(-1), 1/(yu*yv)}, yw])/8 - 
     (G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, yv^(-1), 1/(yu*yv)}, yw])/
      16 - (G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{0, yv^(-1), 1/(yu*yv)}, 
        yw])/16 + (G[{0, 1}, yu^(-1)]*G[{0, yv^(-1), 1/(yu*yv)}, yw])/16 + 
     (G[{0, 1}, yv^(-1)]*G[{0, yv^(-1), 1/(yu*yv)}, yw])/16 - 
     (G[{0, yu}, yv^(-1)]*G[{0, yv^(-1), 1/(yu*yv)}, yw])/16 + 
     (G[{0, 1/(yu*yv)}, yw]*G[{0, yv^(-1), 1/(yu*yv)}, yw])/16 - 
     (G[{1, yv^(-1)}, yw]*G[{0, yv^(-1), 1/(yu*yv)}, yw])/16 - 
     (G[{1, 1/(yu*yv)}, yw]*G[{0, yv^(-1), 1/(yu*yv)}, yw])/16 - 
     (G[{yu^(-1), 1/(yu*yv)}, yw]*G[{0, yv^(-1), 1/(yu*yv)}, yw])/8 + 
     (G[{yv^(-1), 1/(yu*yv)}, yw]*G[{0, yv^(-1), 1/(yu*yv)}, yw])/16 - 
     (5*Pi^2*G[{0, 1/(yu*yv), 1}, yw])/96 + 
     (G[{1}, yu^(-1)]^2*G[{0, 1/(yu*yv), 1}, yw])/32 - 
     (G[{0}, yu^(-1)]*G[{1}, yv^(-1)]*G[{0, 1/(yu*yv), 1}, yw])/16 - 
     (G[{0}, yv^(-1)]*G[{1}, yv^(-1)]*G[{0, 1/(yu*yv), 1}, yw])/16 + 
     (G[{0}, yw]*G[{1}, yv^(-1)]*G[{0, 1/(yu*yv), 1}, yw])/16 - 
     (G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*G[{0, 1/(yu*yv), 1}, yw])/16 + 
     (G[{1}, yv^(-1)]^2*G[{0, 1/(yu*yv), 1}, yw])/32 - 
     (G[{1}, yu^(-1)]*G[{1}, yw]*G[{0, 1/(yu*yv), 1}, yw])/8 + 
     (G[{1}, yv^(-1)]*G[{1}, yw]*G[{0, 1/(yu*yv), 1}, yw])/16 + 
     (G[{1}, yw]^2*G[{0, 1/(yu*yv), 1}, yw])/32 + 
     (G[{0}, yu^(-1)]*G[{yu}, yv^(-1)]*G[{0, 1/(yu*yv), 1}, yw])/16 + 
     (G[{0}, yv^(-1)]*G[{yu}, yv^(-1)]*G[{0, 1/(yu*yv), 1}, yw])/16 - 
     (G[{0}, yw]*G[{yu}, yv^(-1)]*G[{0, 1/(yu*yv), 1}, yw])/16 + 
     (G[{1}, yv^(-1)]*G[{yu}, yv^(-1)]*G[{0, 1/(yu*yv), 1}, yw])/8 + 
     (G[{1}, yw]*G[{yu}, yv^(-1)]*G[{0, 1/(yu*yv), 1}, yw])/16 - 
     (G[{yu}, yv^(-1)]^2*G[{0, 1/(yu*yv), 1}, yw])/8 - 
     (G[{1}, yu^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv), 1}, yw])/16 + 
     (G[{1}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv), 1}, yw])/8 - 
     (G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv), 1}, yw])/16 - 
     (G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv), 1}, yw])/8 - 
     (G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv), 1}, yw])/16 + 
     (G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv), 1}, yw])/16 - 
     (G[{0, 1}, yu^(-1)]*G[{0, 1/(yu*yv), 1}, yw])/8 - 
     (G[{0, 1}, yv^(-1)]*G[{0, 1/(yu*yv), 1}, yw])/8 + 
     (G[{0, yu}, yv^(-1)]*G[{0, 1/(yu*yv), 1}, yw])/8 + 
     (G[{1, yv^(-1)}, yw]*G[{0, 1/(yu*yv), 1}, yw])/16 + 
     (G[{1, 1/(yu*yv)}, yw]*G[{0, 1/(yu*yv), 1}, yw])/16 + 
     (G[{yu^(-1), 1/(yu*yv)}, yw]*G[{0, 1/(yu*yv), 1}, yw])/8 - 
     (G[{yv^(-1), 1/(yu*yv)}, yw]*G[{0, 1/(yu*yv), 1}, yw])/16 - 
     (Pi^2*G[{0, 1/(yu*yv), yu^(-1)}, yw])/96 + 
     (G[{0}, yu^(-1)]*G[{1}, yu^(-1)]*G[{0, 1/(yu*yv), yu^(-1)}, yw])/8 + 
     (G[{0}, yv^(-1)]*G[{1}, yu^(-1)]*G[{0, 1/(yu*yv), yu^(-1)}, yw])/8 - 
     (G[{0}, yw]*G[{1}, yu^(-1)]*G[{0, 1/(yu*yv), yu^(-1)}, yw])/8 - 
     (G[{1}, yu^(-1)]^2*G[{0, 1/(yu*yv), yu^(-1)}, yw])/8 - 
     (G[{1}, yv^(-1)]^2*G[{0, 1/(yu*yv), yu^(-1)}, yw])/32 - 
     (G[{0}, yu^(-1)]*G[{1}, yw]*G[{0, 1/(yu*yv), yu^(-1)}, yw])/8 - 
     (G[{0}, yv^(-1)]*G[{1}, yw]*G[{0, 1/(yu*yv), yu^(-1)}, yw])/8 + 
     (G[{0}, yw]*G[{1}, yw]*G[{0, 1/(yu*yv), yu^(-1)}, yw])/8 + 
     (3*G[{1}, yu^(-1)]*G[{1}, yw]*G[{0, 1/(yu*yv), yu^(-1)}, yw])/16 + 
     (G[{1}, yv^(-1)]*G[{1}, yw]*G[{0, 1/(yu*yv), yu^(-1)}, yw])/8 + 
     (G[{1}, yw]^2*G[{0, 1/(yu*yv), yu^(-1)}, yw])/32 - 
     (G[{0}, yu^(-1)]*G[{yu}, yv^(-1)]*G[{0, 1/(yu*yv), yu^(-1)}, yw])/8 - 
     (G[{0}, yv^(-1)]*G[{yu}, yv^(-1)]*G[{0, 1/(yu*yv), yu^(-1)}, yw])/8 + 
     (G[{0}, yw]*G[{yu}, yv^(-1)]*G[{0, 1/(yu*yv), yu^(-1)}, yw])/8 - 
     (G[{1}, yw]*G[{yu}, yv^(-1)]*G[{0, 1/(yu*yv), yu^(-1)}, yw])/16 + 
     (G[{yu}, yv^(-1)]^2*G[{0, 1/(yu*yv), yu^(-1)}, yw])/8 + 
     (G[{0}, yu^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv), yu^(-1)}, yw])/16 + 
     (G[{0}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv), yu^(-1)}, yw])/16 - 
     (G[{0}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv), yu^(-1)}, yw])/16 - 
     (G[{1}, yu^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv), yu^(-1)}, yw])/16 - 
     (G[{1}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv), yu^(-1)}, yw])/8 - 
     (G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv), yu^(-1)}, yw])/16 + 
     (G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv), yu^(-1)}, yw])/8 + 
     (G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv), yu^(-1)}, yw])/
      16 - (G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv), yu^(-1)}, 
        yw])/16 + (G[{0, 1}, yv^(-1)]*G[{0, 1/(yu*yv), yu^(-1)}, yw])/16 - 
     (G[{0, 1}, yw]*G[{0, 1/(yu*yv), yu^(-1)}, yw])/8 + 
     (G[{0, yu^(-1)}, yw]*G[{0, 1/(yu*yv), yu^(-1)}, yw])/8 - 
     (G[{0, yu}, yv^(-1)]*G[{0, 1/(yu*yv), yu^(-1)}, yw])/16 + 
     (G[{0, yv^(-1)}, yw]*G[{0, 1/(yu*yv), yu^(-1)}, yw])/8 - 
     (G[{0, 1/(yu*yv)}, yw]*G[{0, 1/(yu*yv), yu^(-1)}, yw])/8 + 
     (G[{1, yu}, yv^(-1)]*G[{0, 1/(yu*yv), yu^(-1)}, yw])/16 - 
     (G[{1, yv^(-1)}, yw]*G[{0, 1/(yu*yv), yu^(-1)}, yw])/16 + 
     (G[{1, 1/(yu*yv)}, yw]*G[{0, 1/(yu*yv), yu^(-1)}, yw])/16 - 
     (G[{yu^(-1), 1/(yu*yv)}, yw]*G[{0, 1/(yu*yv), yu^(-1)}, yw])/8 + 
     (G[{yv^(-1), 1/(yu*yv)}, yw]*G[{0, 1/(yu*yv), yu^(-1)}, yw])/16 + 
     (G[{0}, yu^(-1)]*G[{1}, yu^(-1)]*G[{0, 1/(yu*yv), yv^(-1)}, yw])/16 + 
     (G[{0}, yv^(-1)]*G[{1}, yu^(-1)]*G[{0, 1/(yu*yv), yv^(-1)}, yw])/16 - 
     (G[{0}, yw]*G[{1}, yu^(-1)]*G[{0, 1/(yu*yv), yv^(-1)}, yw])/16 - 
     (G[{1}, yu^(-1)]^2*G[{0, 1/(yu*yv), yv^(-1)}, yw])/32 - 
     (G[{0}, yu^(-1)]*G[{1}, yv^(-1)]*G[{0, 1/(yu*yv), yv^(-1)}, yw])/16 - 
     (G[{0}, yv^(-1)]*G[{1}, yv^(-1)]*G[{0, 1/(yu*yv), yv^(-1)}, yw])/16 + 
     (G[{0}, yw]*G[{1}, yv^(-1)]*G[{0, 1/(yu*yv), yv^(-1)}, yw])/16 - 
     (G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*G[{0, 1/(yu*yv), yv^(-1)}, yw])/16 + 
     (G[{1}, yv^(-1)]^2*G[{0, 1/(yu*yv), yv^(-1)}, yw])/8 - 
     (G[{1}, yu^(-1)]*G[{1}, yw]*G[{0, 1/(yu*yv), yv^(-1)}, yw])/16 + 
     (G[{1}, yv^(-1)]*G[{1}, yw]*G[{0, 1/(yu*yv), yv^(-1)}, yw])/8 + 
     (G[{1}, yw]^2*G[{0, 1/(yu*yv), yv^(-1)}, yw])/32 - 
     (G[{1}, yw]*G[{yu}, yv^(-1)]*G[{0, 1/(yu*yv), yv^(-1)}, yw])/16 + 
     (G[{0}, yu^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv), yv^(-1)}, yw])/16 + 
     (G[{0}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv), yv^(-1)}, yw])/16 - 
     (G[{0}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv), yv^(-1)}, yw])/16 + 
     (G[{1}, yu^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv), yv^(-1)}, yw])/16 - 
     (G[{1}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv), yv^(-1)}, yw])/4 - 
     (G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv), yv^(-1)}, yw])/16 + 
     (G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv), yv^(-1)}, yw])/8 + 
     (G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv), yv^(-1)}, yw])/
      16 - (G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv), yv^(-1)}, 
        yw])/16 - (G[{0, 1}, yv^(-1)]*G[{0, 1/(yu*yv), yv^(-1)}, yw])/16 + 
     (G[{0, 1}, yw]*G[{0, 1/(yu*yv), yv^(-1)}, yw])/16 - 
     (G[{0, yu^(-1)}, yw]*G[{0, 1/(yu*yv), yv^(-1)}, yw])/16 + 
     (G[{0, yu}, yv^(-1)]*G[{0, 1/(yu*yv), yv^(-1)}, yw])/16 - 
     (G[{0, yv^(-1)}, yw]*G[{0, 1/(yu*yv), yv^(-1)}, yw])/16 + 
     (G[{0, 1/(yu*yv)}, yw]*G[{0, 1/(yu*yv), yv^(-1)}, yw])/16 - 
     (G[{1, yu}, yv^(-1)]*G[{0, 1/(yu*yv), yv^(-1)}, yw])/16 - 
     (G[{1, yv^(-1)}, yw]*G[{0, 1/(yu*yv), yv^(-1)}, yw])/16 + 
     (G[{1, 1/(yu*yv)}, yw]*G[{0, 1/(yu*yv), yv^(-1)}, yw])/16 - 
     (G[{yu^(-1), 1/(yu*yv)}, yw]*G[{0, 1/(yu*yv), yv^(-1)}, yw])/8 + 
     (G[{yv^(-1), 1/(yu*yv)}, yw]*G[{0, 1/(yu*yv), yv^(-1)}, yw])/16 + 
     (Pi^2*G[{0, 1/(yu*yv), 1/(yu*yv)}, yw])/96 - 
     (G[{0}, yu^(-1)]*G[{1}, yu^(-1)]*G[{0, 1/(yu*yv), 1/(yu*yv)}, yw])/8 - 
     (G[{0}, yv^(-1)]*G[{1}, yu^(-1)]*G[{0, 1/(yu*yv), 1/(yu*yv)}, yw])/8 + 
     (G[{0}, yw]*G[{1}, yu^(-1)]*G[{0, 1/(yu*yv), 1/(yu*yv)}, yw])/8 + 
     (5*G[{1}, yu^(-1)]^2*G[{0, 1/(yu*yv), 1/(yu*yv)}, yw])/32 + 
     (G[{0}, yu^(-1)]*G[{1}, yv^(-1)]*G[{0, 1/(yu*yv), 1/(yu*yv)}, yw])/16 + 
     (G[{0}, yv^(-1)]*G[{1}, yv^(-1)]*G[{0, 1/(yu*yv), 1/(yu*yv)}, yw])/16 - 
     (G[{0}, yw]*G[{1}, yv^(-1)]*G[{0, 1/(yu*yv), 1/(yu*yv)}, yw])/16 - 
     (G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*G[{0, 1/(yu*yv), 1/(yu*yv)}, yw])/16 - 
     (3*G[{1}, yv^(-1)]^2*G[{0, 1/(yu*yv), 1/(yu*yv)}, yw])/32 + 
     (G[{0}, yu^(-1)]*G[{1}, yw]*G[{0, 1/(yu*yv), 1/(yu*yv)}, yw])/16 + 
     (G[{0}, yv^(-1)]*G[{1}, yw]*G[{0, 1/(yu*yv), 1/(yu*yv)}, yw])/16 - 
     (G[{0}, yw]*G[{1}, yw]*G[{0, 1/(yu*yv), 1/(yu*yv)}, yw])/16 - 
     (G[{1}, yu^(-1)]*G[{1}, yw]*G[{0, 1/(yu*yv), 1/(yu*yv)}, yw])/8 + 
     (G[{1}, yv^(-1)]*G[{1}, yw]*G[{0, 1/(yu*yv), 1/(yu*yv)}, yw])/16 + 
     (G[{1}, yw]^2*G[{0, 1/(yu*yv), 1/(yu*yv)}, yw])/32 + 
     (G[{0}, yu^(-1)]*G[{yu}, yv^(-1)]*G[{0, 1/(yu*yv), 1/(yu*yv)}, yw])/16 + 
     (G[{0}, yv^(-1)]*G[{yu}, yv^(-1)]*G[{0, 1/(yu*yv), 1/(yu*yv)}, yw])/16 - 
     (G[{0}, yw]*G[{yu}, yv^(-1)]*G[{0, 1/(yu*yv), 1/(yu*yv)}, yw])/16 + 
     (G[{1}, yv^(-1)]*G[{yu}, yv^(-1)]*G[{0, 1/(yu*yv), 1/(yu*yv)}, yw])/8 - 
     (G[{1}, yw]*G[{yu}, yv^(-1)]*G[{0, 1/(yu*yv), 1/(yu*yv)}, yw])/16 - 
     (G[{yu}, yv^(-1)]^2*G[{0, 1/(yu*yv), 1/(yu*yv)}, yw])/8 - 
     (G[{0}, yu^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv), 1/(yu*yv)}, yw])/
      16 - (G[{0}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv), 1/(yu*yv)}, 
        yw])/16 + (G[{0}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv), 1/(yu*yv)}, 
        yw])/16 - (G[{1}, yu^(-1)]*G[{1/(yu*yv)}, yw]*
       G[{0, 1/(yu*yv), 1/(yu*yv)}, yw])/16 + 
     (G[{1}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv), 1/(yu*yv)}, yw])/
      8 - (G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv), 1/(yu*yv)}, yw])/
      16 - (G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv), 1/(yu*yv)}, 
        yw])/8 + (G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw]*
       G[{0, 1/(yu*yv), 1/(yu*yv)}, yw])/16 + 
     (G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv), 1/(yu*yv)}, yw])/
      16 + (G[{0, 1}, yw]*G[{0, 1/(yu*yv), 1/(yu*yv)}, yw])/8 - 
     (G[{0, yu^(-1)}, yw]*G[{0, 1/(yu*yv), 1/(yu*yv)}, yw])/8 - 
     (G[{0, yv^(-1)}, yw]*G[{0, 1/(yu*yv), 1/(yu*yv)}, yw])/8 + 
     (G[{0, 1/(yu*yv)}, yw]*G[{0, 1/(yu*yv), 1/(yu*yv)}, yw])/8 + 
     (G[{1, yv^(-1)}, yw]*G[{0, 1/(yu*yv), 1/(yu*yv)}, yw])/16 + 
     (G[{1, 1/(yu*yv)}, yw]*G[{0, 1/(yu*yv), 1/(yu*yv)}, yw])/16 + 
     (G[{yu^(-1), 1/(yu*yv)}, yw]*G[{0, 1/(yu*yv), 1/(yu*yv)}, yw])/8 - 
     (G[{yv^(-1), 1/(yu*yv)}, yw]*G[{0, 1/(yu*yv), 1/(yu*yv)}, yw])/16 + 
     (5*Pi^2*G[{1, 1, yu^(-1)}, yw])/384 + 
     (3*G[{0}, yu^(-1)]^2*G[{1, 1, yu^(-1)}, yw])/128 + 
     (3*G[{0}, yu^(-1)]*G[{0}, yv^(-1)]*G[{1, 1, yu^(-1)}, yw])/64 + 
     (3*G[{0}, yv^(-1)]^2*G[{1, 1, yu^(-1)}, yw])/128 - 
     (3*G[{0}, yu^(-1)]*G[{0}, yw]*G[{1, 1, yu^(-1)}, yw])/64 - 
     (3*G[{0}, yv^(-1)]*G[{0}, yw]*G[{1, 1, yu^(-1)}, yw])/64 + 
     (3*G[{0}, yw]^2*G[{1, 1, yu^(-1)}, yw])/128 - 
     (3*G[{0}, yu^(-1)]*G[{1}, yu^(-1)]*G[{1, 1, yu^(-1)}, yw])/64 - 
     (3*G[{0}, yv^(-1)]*G[{1}, yu^(-1)]*G[{1, 1, yu^(-1)}, yw])/64 + 
     (3*G[{0}, yw]*G[{1}, yu^(-1)]*G[{1, 1, yu^(-1)}, yw])/64 + 
     (3*G[{1}, yu^(-1)]^2*G[{1, 1, yu^(-1)}, yw])/128 + 
     (5*G[{0}, yu^(-1)]*G[{1}, yv^(-1)]*G[{1, 1, yu^(-1)}, yw])/64 + 
     (5*G[{0}, yv^(-1)]*G[{1}, yv^(-1)]*G[{1, 1, yu^(-1)}, yw])/64 - 
     (5*G[{0}, yw]*G[{1}, yv^(-1)]*G[{1, 1, yu^(-1)}, yw])/64 + 
     (3*G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*G[{1, 1, yu^(-1)}, yw])/64 - 
     (27*G[{1}, yv^(-1)]^2*G[{1, 1, yu^(-1)}, yw])/128 + 
     (15*G[{0}, yu^(-1)]*G[{1}, yw]*G[{1, 1, yu^(-1)}, yw])/64 + 
     (15*G[{0}, yv^(-1)]*G[{1}, yw]*G[{1, 1, yu^(-1)}, yw])/64 - 
     (15*G[{0}, yw]*G[{1}, yw]*G[{1, 1, yu^(-1)}, yw])/64 - 
     (15*G[{1}, yu^(-1)]*G[{1}, yw]*G[{1, 1, yu^(-1)}, yw])/64 - 
     (29*G[{1}, yv^(-1)]*G[{1}, yw]*G[{1, 1, yu^(-1)}, yw])/64 - 
     (7*G[{1}, yw]^2*G[{1, 1, yu^(-1)}, yw])/64 - 
     (G[{0}, yu^(-1)]*G[{yu}, yv^(-1)]*G[{1, 1, yu^(-1)}, yw])/8 - 
     (G[{0}, yv^(-1)]*G[{yu}, yv^(-1)]*G[{1, 1, yu^(-1)}, yw])/8 + 
     (G[{0}, yw]*G[{yu}, yv^(-1)]*G[{1, 1, yu^(-1)}, yw])/8 + 
     (23*G[{1}, yv^(-1)]*G[{yu}, yv^(-1)]*G[{1, 1, yu^(-1)}, yw])/64 + 
     (7*G[{1}, yw]*G[{yu}, yv^(-1)]*G[{1, 1, yu^(-1)}, yw])/32 - 
     (7*G[{yu}, yv^(-1)]^2*G[{1, 1, yu^(-1)}, yw])/128 - 
     (5*G[{0}, yu^(-1)]*G[{1/(yu*yv)}, yw]*G[{1, 1, yu^(-1)}, yw])/64 - 
     (5*G[{0}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{1, 1, yu^(-1)}, yw])/64 + 
     (5*G[{0}, yw]*G[{1/(yu*yv)}, yw]*G[{1, 1, yu^(-1)}, yw])/64 + 
     (5*G[{1}, yu^(-1)]*G[{1/(yu*yv)}, yw]*G[{1, 1, yu^(-1)}, yw])/64 + 
     (G[{1}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{1, 1, yu^(-1)}, yw])/8 + 
     (3*G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{1, 1, yu^(-1)}, yw])/64 - 
     (3*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{1, 1, yu^(-1)}, yw])/64 - 
     (3*G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{1, 1, yu^(-1)}, yw])/64 - 
     (5*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{1, 1, yu^(-1)}, yw])/64 - 
     (3*G[{1/(yu*yv)}, yw]^2*G[{1, 1, yu^(-1)}, yw])/64 + 
     (G[{0, 1}, yu^(-1)]*G[{1, 1, yu^(-1)}, yw])/8 - 
     (G[{0, 1}, yv^(-1)]*G[{1, 1, yu^(-1)}, yw])/64 + 
     (7*G[{0, 1}, yw]*G[{1, 1, yu^(-1)}, yw])/64 - 
     (7*G[{0, yu^(-1)}, yw]*G[{1, 1, yu^(-1)}, yw])/64 + 
     (G[{0, yu}, yv^(-1)]*G[{1, 1, yu^(-1)}, yw])/64 - 
     (7*G[{0, yv^(-1)}, yw]*G[{1, 1, yu^(-1)}, yw])/64 + 
     (7*G[{0, 1/(yu*yv)}, yw]*G[{1, 1, yu^(-1)}, yw])/64 + 
     (G[{1, yu^(-1)}, yw]*G[{1, 1, yu^(-1)}, yw])/64 - 
     (9*G[{1, yu}, yv^(-1)]*G[{1, 1, yu^(-1)}, yw])/64 - 
     (5*G[{1, yv^(-1)}, yw]*G[{1, 1, yu^(-1)}, yw])/64 + 
     (G[{1, 1/(yu*yv)}, yw]*G[{1, 1, yu^(-1)}, yw])/32 + 
     (3*G[{yu^(-1), 1/(yu*yv)}, yw]*G[{1, 1, yu^(-1)}, yw])/64 + 
     (5*G[{yv^(-1), 1/(yu*yv)}, yw]*G[{1, 1, yu^(-1)}, yw])/64 + 
     (3*Pi^2*G[{1, 1, yu}, yv^(-1)])/128 + 
     (3*G[{0}, yu^(-1)]^2*G[{1, 1, yu}, yv^(-1)])/128 + 
     (3*G[{0}, yu^(-1)]*G[{0}, yv^(-1)]*G[{1, 1, yu}, yv^(-1)])/64 + 
     (3*G[{0}, yv^(-1)]^2*G[{1, 1, yu}, yv^(-1)])/128 - 
     (3*G[{0}, yu^(-1)]*G[{0}, yw]*G[{1, 1, yu}, yv^(-1)])/64 - 
     (3*G[{0}, yv^(-1)]*G[{0}, yw]*G[{1, 1, yu}, yv^(-1)])/64 + 
     (3*G[{0}, yw]^2*G[{1, 1, yu}, yv^(-1)])/128 + 
     (9*G[{0}, yu^(-1)]*G[{1}, yu^(-1)]*G[{1, 1, yu}, yv^(-1)])/64 + 
     (9*G[{0}, yv^(-1)]*G[{1}, yu^(-1)]*G[{1, 1, yu}, yv^(-1)])/64 - 
     (9*G[{0}, yw]*G[{1}, yu^(-1)]*G[{1, 1, yu}, yv^(-1)])/64 - 
     (33*G[{1}, yu^(-1)]^2*G[{1, 1, yu}, yv^(-1)])/128 + 
     (G[{0}, yu^(-1)]*G[{1}, yv^(-1)]*G[{1, 1, yu}, yv^(-1)])/64 + 
     (G[{0}, yv^(-1)]*G[{1}, yv^(-1)]*G[{1, 1, yu}, yv^(-1)])/64 - 
     (G[{0}, yw]*G[{1}, yv^(-1)]*G[{1, 1, yu}, yv^(-1)])/64 + 
     (15*G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*G[{1, 1, yu}, yv^(-1)])/64 - 
     (11*G[{1}, yv^(-1)]^2*G[{1, 1, yu}, yv^(-1)])/128 + 
     (15*G[{0}, yu^(-1)]*G[{1}, yw]*G[{1, 1, yu}, yv^(-1)])/64 + 
     (15*G[{0}, yv^(-1)]*G[{1}, yw]*G[{1, 1, yu}, yv^(-1)])/64 - 
     (15*G[{0}, yw]*G[{1}, yw]*G[{1, 1, yu}, yv^(-1)])/64 + 
     (21*G[{1}, yu^(-1)]*G[{1}, yw]*G[{1, 1, yu}, yv^(-1)])/64 - 
     (7*G[{1}, yv^(-1)]*G[{1}, yw]*G[{1, 1, yu}, yv^(-1)])/32 + 
     (5*G[{1}, yw]^2*G[{1, 1, yu}, yv^(-1)])/32 - 
     (5*G[{1}, yw]*G[{yu}, yv^(-1)]*G[{1, 1, yu}, yv^(-1)])/32 - 
     (9*G[{0}, yu^(-1)]*G[{1/(yu*yv)}, yw]*G[{1, 1, yu}, yv^(-1)])/64 - 
     (9*G[{0}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{1, 1, yu}, yv^(-1)])/64 + 
     (9*G[{0}, yw]*G[{1/(yu*yv)}, yw]*G[{1, 1, yu}, yv^(-1)])/64 - 
     (3*G[{1}, yu^(-1)]*G[{1/(yu*yv)}, yw]*G[{1, 1, yu}, yv^(-1)])/64 + 
     (G[{1}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{1, 1, yu}, yv^(-1)])/4 - 
     (G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{1, 1, yu}, yv^(-1)])/16 - 
     (11*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{1, 1, yu}, yv^(-1)])/64 + 
     (5*G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{1, 1, yu}, yv^(-1)])/32 + 
     (3*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{1, 1, yu}, yv^(-1)])/64 - 
     (3*G[{1/(yu*yv)}, yw]^2*G[{1, 1, yu}, yv^(-1)])/64 + 
     (3*G[{0, 1}, yv^(-1)]*G[{1, 1, yu}, yv^(-1)])/64 + 
     (7*G[{0, 1}, yw]*G[{1, 1, yu}, yv^(-1)])/64 + 
     (5*G[{0, yu^(-1)}, yw]*G[{1, 1, yu}, yv^(-1)])/64 - 
     (3*G[{0, yu}, yv^(-1)]*G[{1, 1, yu}, yv^(-1)])/64 - 
     (3*G[{0, yv^(-1)}, yw]*G[{1, 1, yu}, yv^(-1)])/64 - 
     (9*G[{0, 1/(yu*yv)}, yw]*G[{1, 1, yu}, yv^(-1)])/64 + 
     (G[{1, yu^(-1)}, yw]*G[{1, 1, yu}, yv^(-1)])/64 - 
     (5*G[{1, yu}, yv^(-1)]*G[{1, 1, yu}, yv^(-1)])/32 + 
     (3*G[{1, yv^(-1)}, yw]*G[{1, 1, yu}, yv^(-1)])/64 + 
     (5*G[{1, 1/(yu*yv)}, yw]*G[{1, 1, yu}, yv^(-1)])/32 + 
     (11*G[{yu^(-1), 1/(yu*yv)}, yw]*G[{1, 1, yu}, yv^(-1)])/64 - 
     (3*G[{yv^(-1), 1/(yu*yv)}, yw]*G[{1, 1, yu}, yv^(-1)])/64 + 
     (7*Pi^2*G[{1, 1, yv^(-1)}, yw])/96 - 
     (G[{0}, yu^(-1)]*G[{1}, yu^(-1)]*G[{1, 1, yv^(-1)}, yw])/16 - 
     (G[{0}, yv^(-1)]*G[{1}, yu^(-1)]*G[{1, 1, yv^(-1)}, yw])/16 + 
     (G[{0}, yw]*G[{1}, yu^(-1)]*G[{1, 1, yv^(-1)}, yw])/16 + 
     (G[{1}, yu^(-1)]^2*G[{1, 1, yv^(-1)}, yw])/32 + 
     (G[{0}, yu^(-1)]*G[{1}, yv^(-1)]*G[{1, 1, yv^(-1)}, yw])/16 + 
     (G[{0}, yv^(-1)]*G[{1}, yv^(-1)]*G[{1, 1, yv^(-1)}, yw])/16 - 
     (G[{0}, yw]*G[{1}, yv^(-1)]*G[{1, 1, yv^(-1)}, yw])/16 + 
     (G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*G[{1, 1, yv^(-1)}, yw])/16 + 
     (G[{1}, yv^(-1)]^2*G[{1, 1, yv^(-1)}, yw])/16 + 
     (G[{0}, yu^(-1)]*G[{1}, yw]*G[{1, 1, yv^(-1)}, yw])/8 + 
     (G[{0}, yv^(-1)]*G[{1}, yw]*G[{1, 1, yv^(-1)}, yw])/8 - 
     (G[{0}, yw]*G[{1}, yw]*G[{1, 1, yv^(-1)}, yw])/8 - 
     (G[{1}, yu^(-1)]*G[{1}, yw]*G[{1, 1, yv^(-1)}, yw])/4 + 
     (G[{1}, yv^(-1)]*G[{1}, yw]*G[{1, 1, yv^(-1)}, yw])/16 + 
     (G[{1}, yw]^2*G[{1, 1, yv^(-1)}, yw])/32 - 
     (G[{1}, yv^(-1)]*G[{yu}, yv^(-1)]*G[{1, 1, yv^(-1)}, yw])/4 - 
     (G[{1}, yw]*G[{yu}, yv^(-1)]*G[{1, 1, yv^(-1)}, yw])/16 + 
     (G[{yu}, yv^(-1)]^2*G[{1, 1, yv^(-1)}, yw])/8 + 
     (G[{1}, yu^(-1)]*G[{1/(yu*yv)}, yw]*G[{1, 1, yv^(-1)}, yw])/4 - 
     (3*G[{1}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{1, 1, yv^(-1)}, yw])/8 - 
     (G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{1, 1, yv^(-1)}, yw])/8 + 
     (3*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{1, 1, yv^(-1)}, yw])/8 + 
     (G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{1, 1, yv^(-1)}, yw])/8 - 
     (G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{1, 1, yv^(-1)}, yw])/8 + 
     (G[{0, 1}, yu^(-1)]*G[{1, 1, yv^(-1)}, yw])/8 + 
     (G[{0, 1}, yv^(-1)]*G[{1, 1, yv^(-1)}, yw])/16 + 
     (G[{0, 1}, yw]*G[{1, 1, yv^(-1)}, yw])/8 - 
     (G[{0, yu^(-1)}, yw]*G[{1, 1, yv^(-1)}, yw])/8 - 
     (G[{0, yu}, yv^(-1)]*G[{1, 1, yv^(-1)}, yw])/16 - 
     (G[{0, yv^(-1)}, yw]*G[{1, 1, yv^(-1)}, yw])/8 + 
     (G[{0, 1/(yu*yv)}, yw]*G[{1, 1, yv^(-1)}, yw])/8 - 
     (G[{1, yu}, yv^(-1)]*G[{1, 1, yv^(-1)}, yw])/16 - 
     (G[{1, yv^(-1)}, yw]*G[{1, 1, yv^(-1)}, yw])/8 + 
     (G[{1, 1/(yu*yv)}, yw]*G[{1, 1, yv^(-1)}, yw])/4 - 
     (3*G[{yu^(-1), 1/(yu*yv)}, yw]*G[{1, 1, yv^(-1)}, yw])/8 + 
     (G[{yv^(-1), 1/(yu*yv)}, yw]*G[{1, 1, yv^(-1)}, yw])/8 - 
     (41*Pi^2*G[{1, 1, 1/(yu*yv)}, yw])/384 - 
     (3*G[{0}, yu^(-1)]^2*G[{1, 1, 1/(yu*yv)}, yw])/128 - 
     (3*G[{0}, yu^(-1)]*G[{0}, yv^(-1)]*G[{1, 1, 1/(yu*yv)}, yw])/64 - 
     (3*G[{0}, yv^(-1)]^2*G[{1, 1, 1/(yu*yv)}, yw])/128 + 
     (3*G[{0}, yu^(-1)]*G[{0}, yw]*G[{1, 1, 1/(yu*yv)}, yw])/64 + 
     (3*G[{0}, yv^(-1)]*G[{0}, yw]*G[{1, 1, 1/(yu*yv)}, yw])/64 - 
     (3*G[{0}, yw]^2*G[{1, 1, 1/(yu*yv)}, yw])/128 + 
     (7*G[{0}, yu^(-1)]*G[{1}, yu^(-1)]*G[{1, 1, 1/(yu*yv)}, yw])/64 + 
     (7*G[{0}, yv^(-1)]*G[{1}, yu^(-1)]*G[{1, 1, 1/(yu*yv)}, yw])/64 - 
     (7*G[{0}, yw]*G[{1}, yu^(-1)]*G[{1, 1, 1/(yu*yv)}, yw])/64 - 
     (7*G[{1}, yu^(-1)]^2*G[{1, 1, 1/(yu*yv)}, yw])/128 - 
     (17*G[{0}, yu^(-1)]*G[{1}, yv^(-1)]*G[{1, 1, 1/(yu*yv)}, yw])/64 - 
     (17*G[{0}, yv^(-1)]*G[{1}, yv^(-1)]*G[{1, 1, 1/(yu*yv)}, yw])/64 + 
     (17*G[{0}, yw]*G[{1}, yv^(-1)]*G[{1, 1, 1/(yu*yv)}, yw])/64 - 
     (7*G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*G[{1, 1, 1/(yu*yv)}, yw])/64 + 
     (19*G[{1}, yv^(-1)]^2*G[{1, 1, 1/(yu*yv)}, yw])/128 - 
     (15*G[{0}, yu^(-1)]*G[{1}, yw]*G[{1, 1, 1/(yu*yv)}, yw])/64 - 
     (15*G[{0}, yv^(-1)]*G[{1}, yw]*G[{1, 1, 1/(yu*yv)}, yw])/64 + 
     (15*G[{0}, yw]*G[{1}, yw]*G[{1, 1, 1/(yu*yv)}, yw])/64 + 
     (23*G[{1}, yu^(-1)]*G[{1}, yw]*G[{1, 1, 1/(yu*yv)}, yw])/64 + 
     (G[{1}, yv^(-1)]*G[{1}, yw]*G[{1, 1, 1/(yu*yv)}, yw])/64 - 
     (3*G[{1}, yw]^2*G[{1, 1, 1/(yu*yv)}, yw])/64 + 
     (G[{0}, yu^(-1)]*G[{yu}, yv^(-1)]*G[{1, 1, 1/(yu*yv)}, yw])/4 + 
     (G[{0}, yv^(-1)]*G[{yu}, yv^(-1)]*G[{1, 1, 1/(yu*yv)}, yw])/4 - 
     (G[{0}, yw]*G[{yu}, yv^(-1)]*G[{1, 1, 1/(yu*yv)}, yw])/4 + 
     (9*G[{1}, yv^(-1)]*G[{yu}, yv^(-1)]*G[{1, 1, 1/(yu*yv)}, yw])/64 + 
     (3*G[{1}, yw]*G[{yu}, yv^(-1)]*G[{1, 1, 1/(yu*yv)}, yw])/32 - 
     (41*G[{yu}, yv^(-1)]^2*G[{1, 1, 1/(yu*yv)}, yw])/128 + 
     (21*G[{0}, yu^(-1)]*G[{1/(yu*yv)}, yw]*G[{1, 1, 1/(yu*yv)}, yw])/64 + 
     (21*G[{0}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{1, 1, 1/(yu*yv)}, yw])/64 - 
     (21*G[{0}, yw]*G[{1/(yu*yv)}, yw]*G[{1, 1, 1/(yu*yv)}, yw])/64 - 
     (13*G[{1}, yu^(-1)]*G[{1/(yu*yv)}, yw]*G[{1, 1, 1/(yu*yv)}, yw])/64 + 
     (29*G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{1, 1, 1/(yu*yv)}, yw])/64 - 
     (5*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{1, 1, 1/(yu*yv)}, yw])/64 - 
     (29*G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{1, 1, 1/(yu*yv)}, yw])/64 + 
     (5*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{1, 1, 1/(yu*yv)}, yw])/64 + 
     (3*G[{1/(yu*yv)}, yw]^2*G[{1, 1, 1/(yu*yv)}, yw])/64 - 
     (3*G[{0, 1}, yu^(-1)]*G[{1, 1, 1/(yu*yv)}, yw])/8 - 
     (11*G[{0, 1}, yv^(-1)]*G[{1, 1, 1/(yu*yv)}, yw])/64 + 
     (G[{0, 1}, yw]*G[{1, 1, 1/(yu*yv)}, yw])/64 - 
     (G[{0, yu^(-1)}, yw]*G[{1, 1, 1/(yu*yv)}, yw])/64 + 
     (11*G[{0, yu}, yv^(-1)]*G[{1, 1, 1/(yu*yv)}, yw])/64 - 
     (G[{0, yv^(-1)}, yw]*G[{1, 1, 1/(yu*yv)}, yw])/64 + 
     (G[{0, 1/(yu*yv)}, yw]*G[{1, 1, 1/(yu*yv)}, yw])/64 - 
     (G[{1, yu^(-1)}, yw]*G[{1, 1, 1/(yu*yv)}, yw])/64 + 
     (13*G[{1, yu}, yv^(-1)]*G[{1, 1, 1/(yu*yv)}, yw])/64 + 
     (5*G[{1, yv^(-1)}, yw]*G[{1, 1, 1/(yu*yv)}, yw])/64 - 
     (13*G[{1, 1/(yu*yv)}, yw]*G[{1, 1, 1/(yu*yv)}, yw])/32 + 
     (5*G[{yu^(-1), 1/(yu*yv)}, yw]*G[{1, 1, 1/(yu*yv)}, yw])/64 - 
     (5*G[{yv^(-1), 1/(yu*yv)}, yw]*G[{1, 1, 1/(yu*yv)}, yw])/64 - 
     (19*Pi^2*G[{1, yu^(-1), yu^(-1)}, yw])/768 + 
     (3*G[{0}, yu^(-1)]^2*G[{1, yu^(-1), yu^(-1)}, yw])/64 + 
     (3*G[{0}, yu^(-1)]*G[{0}, yv^(-1)]*G[{1, yu^(-1), yu^(-1)}, yw])/32 + 
     (3*G[{0}, yv^(-1)]^2*G[{1, yu^(-1), yu^(-1)}, yw])/64 - 
     (3*G[{0}, yu^(-1)]*G[{0}, yw]*G[{1, yu^(-1), yu^(-1)}, yw])/32 - 
     (3*G[{0}, yv^(-1)]*G[{0}, yw]*G[{1, yu^(-1), yu^(-1)}, yw])/32 + 
     (3*G[{0}, yw]^2*G[{1, yu^(-1), yu^(-1)}, yw])/64 - 
     (3*G[{0}, yu^(-1)]*G[{1}, yu^(-1)]*G[{1, yu^(-1), yu^(-1)}, yw])/32 - 
     (3*G[{0}, yv^(-1)]*G[{1}, yu^(-1)]*G[{1, yu^(-1), yu^(-1)}, yw])/32 + 
     (3*G[{0}, yw]*G[{1}, yu^(-1)]*G[{1, yu^(-1), yu^(-1)}, yw])/32 + 
     (3*G[{1}, yu^(-1)]^2*G[{1, yu^(-1), yu^(-1)}, yw])/64 - 
     (3*G[{0}, yu^(-1)]*G[{1}, yv^(-1)]*G[{1, yu^(-1), yu^(-1)}, yw])/32 - 
     (3*G[{0}, yv^(-1)]*G[{1}, yv^(-1)]*G[{1, yu^(-1), yu^(-1)}, yw])/32 + 
     (3*G[{0}, yw]*G[{1}, yv^(-1)]*G[{1, yu^(-1), yu^(-1)}, yw])/32 + 
     (3*G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*G[{1, yu^(-1), yu^(-1)}, yw])/32 - 
     (G[{1}, yv^(-1)]^2*G[{1, yu^(-1), yu^(-1)}, yw])/32 - 
     (G[{0}, yu^(-1)]*G[{1}, yw]*G[{1, yu^(-1), yu^(-1)}, yw])/32 - 
     (G[{0}, yv^(-1)]*G[{1}, yw]*G[{1, yu^(-1), yu^(-1)}, yw])/32 + 
     (G[{0}, yw]*G[{1}, yw]*G[{1, yu^(-1), yu^(-1)}, yw])/32 + 
     (G[{1}, yu^(-1)]*G[{1}, yw]*G[{1, yu^(-1), yu^(-1)}, yw])/32 - 
     (G[{1}, yv^(-1)]*G[{1}, yw]*G[{1, yu^(-1), yu^(-1)}, yw])/8 - 
     (5*G[{1}, yw]^2*G[{1, yu^(-1), yu^(-1)}, yw])/64 + 
     (7*G[{1}, yv^(-1)]*G[{yu}, yv^(-1)]*G[{1, yu^(-1), yu^(-1)}, yw])/32 + 
     (5*G[{1}, yw]*G[{yu}, yv^(-1)]*G[{1, yu^(-1), yu^(-1)}, yw])/32 - 
     (7*G[{yu}, yv^(-1)]^2*G[{1, yu^(-1), yu^(-1)}, yw])/64 + 
     (G[{0}, yu^(-1)]*G[{1/(yu*yv)}, yw]*G[{1, yu^(-1), yu^(-1)}, yw])/32 + 
     (G[{0}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{1, yu^(-1), yu^(-1)}, yw])/32 - 
     (G[{0}, yw]*G[{1/(yu*yv)}, yw]*G[{1, yu^(-1), yu^(-1)}, yw])/32 - 
     (G[{1}, yu^(-1)]*G[{1/(yu*yv)}, yw]*G[{1, yu^(-1), yu^(-1)}, yw])/32 + 
     (G[{1}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{1, yu^(-1), yu^(-1)}, yw])/64 + 
     (3*G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{1, yu^(-1), yu^(-1)}, yw])/64 + 
     (G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{1, yu^(-1), yu^(-1)}, yw])/32 - 
     (3*G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{1, yu^(-1), yu^(-1)}, yw])/
      64 - (3*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{1, yu^(-1), yu^(-1)}, 
        yw])/32 - (3*G[{1/(yu*yv)}, yw]^2*G[{1, yu^(-1), yu^(-1)}, yw])/64 - 
     (G[{0, 1}, yv^(-1)]*G[{1, yu^(-1), yu^(-1)}, yw])/16 - 
     (G[{0, 1}, yw]*G[{1, yu^(-1), yu^(-1)}, yw])/32 + 
     (G[{0, yu^(-1)}, yw]*G[{1, yu^(-1), yu^(-1)}, yw])/32 + 
     (G[{0, yu}, yv^(-1)]*G[{1, yu^(-1), yu^(-1)}, yw])/16 + 
     (G[{0, yv^(-1)}, yw]*G[{1, yu^(-1), yu^(-1)}, yw])/32 - 
     (G[{0, 1/(yu*yv)}, yw]*G[{1, yu^(-1), yu^(-1)}, yw])/32 - 
     (3*G[{1, yu^(-1)}, yw]*G[{1, yu^(-1), yu^(-1)}, yw])/32 - 
     (G[{1, yu}, yv^(-1)]*G[{1, yu^(-1), yu^(-1)}, yw])/16 - 
     (3*G[{1, yv^(-1)}, yw]*G[{1, yu^(-1), yu^(-1)}, yw])/32 + 
     (G[{1, 1/(yu*yv)}, yw]*G[{1, yu^(-1), yu^(-1)}, yw])/8 - 
     (G[{yu^(-1), 1/(yu*yv)}, yw]*G[{1, yu^(-1), yu^(-1)}, yw])/32 + 
     (3*G[{yv^(-1), 1/(yu*yv)}, yw]*G[{1, yu^(-1), yu^(-1)}, yw])/32 - 
     (Pi^2*G[{1, yu^(-1), yv^(-1)}, yw])/32 + 
     (G[{0}, yu^(-1)]*G[{1}, yu^(-1)]*G[{1, yu^(-1), yv^(-1)}, yw])/8 + 
     (G[{0}, yv^(-1)]*G[{1}, yu^(-1)]*G[{1, yu^(-1), yv^(-1)}, yw])/8 - 
     (G[{0}, yw]*G[{1}, yu^(-1)]*G[{1, yu^(-1), yv^(-1)}, yw])/8 - 
     (G[{1}, yu^(-1)]^2*G[{1, yu^(-1), yv^(-1)}, yw])/8 - 
     (G[{0}, yu^(-1)]*G[{1}, yv^(-1)]*G[{1, yu^(-1), yv^(-1)}, yw])/8 - 
     (G[{0}, yv^(-1)]*G[{1}, yv^(-1)]*G[{1, yu^(-1), yv^(-1)}, yw])/8 + 
     (G[{0}, yw]*G[{1}, yv^(-1)]*G[{1, yu^(-1), yv^(-1)}, yw])/8 + 
     (3*G[{1}, yv^(-1)]^2*G[{1, yu^(-1), yv^(-1)}, yw])/32 + 
     (G[{1}, yu^(-1)]*G[{1}, yw]*G[{1, yu^(-1), yv^(-1)}, yw])/8 + 
     (G[{1}, yv^(-1)]*G[{1}, yw]*G[{1, yu^(-1), yv^(-1)}, yw])/16 + 
     (3*G[{1}, yw]^2*G[{1, yu^(-1), yv^(-1)}, yw])/32 - 
     (3*G[{1}, yw]*G[{yu}, yv^(-1)]*G[{1, yu^(-1), yv^(-1)}, yw])/16 + 
     (G[{0}, yu^(-1)]*G[{1/(yu*yv)}, yw]*G[{1, yu^(-1), yv^(-1)}, yw])/8 + 
     (G[{0}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{1, yu^(-1), yv^(-1)}, yw])/8 - 
     (G[{0}, yw]*G[{1/(yu*yv)}, yw]*G[{1, yu^(-1), yv^(-1)}, yw])/8 - 
     (G[{1}, yu^(-1)]*G[{1/(yu*yv)}, yw]*G[{1, yu^(-1), yv^(-1)}, yw])/16 - 
     (G[{1}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{1, yu^(-1), yv^(-1)}, yw])/4 - 
     (G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{1, yu^(-1), yv^(-1)}, yw])/16 + 
     (G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{1, yu^(-1), yv^(-1)}, yw])/8 + 
     (G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{1, yu^(-1), yv^(-1)}, yw])/16 - 
     (G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{1, yu^(-1), yv^(-1)}, yw])/16 - 
     (G[{0, 1}, yu^(-1)]*G[{1, yu^(-1), yv^(-1)}, yw])/8 - 
     (G[{0, 1}, yv^(-1)]*G[{1, yu^(-1), yv^(-1)}, yw])/16 + 
     (G[{0, yu}, yv^(-1)]*G[{1, yu^(-1), yv^(-1)}, yw])/16 - 
     (G[{1, yu^(-1)}, yw]*G[{1, yu^(-1), yv^(-1)}, yw])/16 + 
     (G[{1, yu}, yv^(-1)]*G[{1, yu^(-1), yv^(-1)}, yw])/16 - 
     (G[{1, yv^(-1)}, yw]*G[{1, yu^(-1), yv^(-1)}, yw])/16 + 
     (G[{1, 1/(yu*yv)}, yw]*G[{1, yu^(-1), yv^(-1)}, yw])/16 - 
     (G[{yu^(-1), 1/(yu*yv)}, yw]*G[{1, yu^(-1), yv^(-1)}, yw])/8 + 
     (G[{yv^(-1), 1/(yu*yv)}, yw]*G[{1, yu^(-1), yv^(-1)}, yw])/16 + 
     (5*Pi^2*G[{1, yu^(-1), 1/(yu*yv)}, yw])/768 - 
     (3*G[{0}, yu^(-1)]^2*G[{1, yu^(-1), 1/(yu*yv)}, yw])/128 - 
     (3*G[{0}, yu^(-1)]*G[{0}, yv^(-1)]*G[{1, yu^(-1), 1/(yu*yv)}, yw])/64 - 
     (3*G[{0}, yv^(-1)]^2*G[{1, yu^(-1), 1/(yu*yv)}, yw])/128 + 
     (3*G[{0}, yu^(-1)]*G[{0}, yw]*G[{1, yu^(-1), 1/(yu*yv)}, yw])/64 + 
     (3*G[{0}, yv^(-1)]*G[{0}, yw]*G[{1, yu^(-1), 1/(yu*yv)}, yw])/64 - 
     (3*G[{0}, yw]^2*G[{1, yu^(-1), 1/(yu*yv)}, yw])/128 - 
     (5*G[{0}, yu^(-1)]*G[{1}, yu^(-1)]*G[{1, yu^(-1), 1/(yu*yv)}, yw])/64 - 
     (5*G[{0}, yv^(-1)]*G[{1}, yu^(-1)]*G[{1, yu^(-1), 1/(yu*yv)}, yw])/64 + 
     (5*G[{0}, yw]*G[{1}, yu^(-1)]*G[{1, yu^(-1), 1/(yu*yv)}, yw])/64 + 
     (13*G[{1}, yu^(-1)]^2*G[{1, yu^(-1), 1/(yu*yv)}, yw])/128 + 
     (3*G[{0}, yu^(-1)]*G[{1}, yv^(-1)]*G[{1, yu^(-1), 1/(yu*yv)}, yw])/64 + 
     (3*G[{0}, yv^(-1)]*G[{1}, yv^(-1)]*G[{1, yu^(-1), 1/(yu*yv)}, yw])/64 - 
     (3*G[{0}, yw]*G[{1}, yv^(-1)]*G[{1, yu^(-1), 1/(yu*yv)}, yw])/64 - 
     (3*G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*G[{1, yu^(-1), 1/(yu*yv)}, yw])/64 + 
     (5*G[{1}, yv^(-1)]^2*G[{1, yu^(-1), 1/(yu*yv)}, yw])/128 - 
     (7*G[{0}, yu^(-1)]*G[{1}, yw]*G[{1, yu^(-1), 1/(yu*yv)}, yw])/64 - 
     (7*G[{0}, yv^(-1)]*G[{1}, yw]*G[{1, yu^(-1), 1/(yu*yv)}, yw])/64 + 
     (7*G[{0}, yw]*G[{1}, yw]*G[{1, yu^(-1), 1/(yu*yv)}, yw])/64 - 
     (G[{1}, yu^(-1)]*G[{1}, yw]*G[{1, yu^(-1), 1/(yu*yv)}, yw])/64 + 
     (7*G[{1}, yv^(-1)]*G[{1}, yw]*G[{1, yu^(-1), 1/(yu*yv)}, yw])/64 - 
     (G[{1}, yw]^2*G[{1, yu^(-1), 1/(yu*yv)}, yw])/16 + 
     (G[{0}, yu^(-1)]*G[{yu}, yv^(-1)]*G[{1, yu^(-1), 1/(yu*yv)}, yw])/8 + 
     (G[{0}, yv^(-1)]*G[{yu}, yv^(-1)]*G[{1, yu^(-1), 1/(yu*yv)}, yw])/8 - 
     (G[{0}, yw]*G[{yu}, yv^(-1)]*G[{1, yu^(-1), 1/(yu*yv)}, yw])/8 - 
     (7*G[{1}, yv^(-1)]*G[{yu}, yv^(-1)]*G[{1, yu^(-1), 1/(yu*yv)}, yw])/64 + 
     (G[{1}, yw]*G[{yu}, yv^(-1)]*G[{1, yu^(-1), 1/(yu*yv)}, yw])/8 - 
     (9*G[{yu}, yv^(-1)]^2*G[{1, yu^(-1), 1/(yu*yv)}, yw])/128 - 
     (7*G[{0}, yu^(-1)]*G[{1/(yu*yv)}, yw]*G[{1, yu^(-1), 1/(yu*yv)}, yw])/
      64 - (7*G[{0}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{1, yu^(-1), 1/(yu*yv)}, 
        yw])/64 + (7*G[{0}, yw]*G[{1/(yu*yv)}, yw]*G[{1, yu^(-1), 1/(yu*yv)}, 
        yw])/64 - (5*G[{1}, yu^(-1)]*G[{1/(yu*yv)}, yw]*
       G[{1, yu^(-1), 1/(yu*yv)}, yw])/64 + 
     (7*G[{1}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{1, yu^(-1), 1/(yu*yv)}, yw])/
      64 - (3*G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{1, yu^(-1), 1/(yu*yv)}, yw])/
      16 - (13*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{1, yu^(-1), 1/(yu*yv)}, 
        yw])/64 + (3*G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw]*
       G[{1, yu^(-1), 1/(yu*yv)}, yw])/16 + 
     (5*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{1, yu^(-1), 1/(yu*yv)}, yw])/
      64 - (G[{0, 1}, yv^(-1)]*G[{1, yu^(-1), 1/(yu*yv)}, yw])/64 + 
     (G[{0, 1}, yw]*G[{1, yu^(-1), 1/(yu*yv)}, yw])/64 - 
     (G[{0, yu^(-1)}, yw]*G[{1, yu^(-1), 1/(yu*yv)}, yw])/64 + 
     (G[{0, yu}, yv^(-1)]*G[{1, yu^(-1), 1/(yu*yv)}, yw])/64 - 
     (G[{0, yv^(-1)}, yw]*G[{1, yu^(-1), 1/(yu*yv)}, yw])/64 + 
     (G[{0, 1/(yu*yv)}, yw]*G[{1, yu^(-1), 1/(yu*yv)}, yw])/64 - 
     (G[{1, yu}, yv^(-1)]*G[{1, yu^(-1), 1/(yu*yv)}, yw])/64 + 
     (13*G[{1, yv^(-1)}, yw]*G[{1, yu^(-1), 1/(yu*yv)}, yw])/64 + 
     (3*G[{1, 1/(yu*yv)}, yw]*G[{1, yu^(-1), 1/(yu*yv)}, yw])/32 + 
     (13*G[{yu^(-1), 1/(yu*yv)}, yw]*G[{1, yu^(-1), 1/(yu*yv)}, yw])/64 - 
     (5*G[{yv^(-1), 1/(yu*yv)}, yw]*G[{1, yu^(-1), 1/(yu*yv)}, yw])/64 + 
     (23*Pi^2*G[{1, yu, yu}, yv^(-1)])/256 + 
     (3*G[{0}, yu^(-1)]^2*G[{1, yu, yu}, yv^(-1)])/64 + 
     (3*G[{0}, yu^(-1)]*G[{0}, yv^(-1)]*G[{1, yu, yu}, yv^(-1)])/32 + 
     (3*G[{0}, yv^(-1)]^2*G[{1, yu, yu}, yv^(-1)])/64 - 
     (3*G[{0}, yu^(-1)]*G[{0}, yw]*G[{1, yu, yu}, yv^(-1)])/32 - 
     (3*G[{0}, yv^(-1)]*G[{0}, yw]*G[{1, yu, yu}, yv^(-1)])/32 + 
     (3*G[{0}, yw]^2*G[{1, yu, yu}, yv^(-1)])/64 + 
     (G[{0}, yu^(-1)]*G[{1}, yu^(-1)]*G[{1, yu, yu}, yv^(-1)])/32 + 
     (G[{0}, yv^(-1)]*G[{1}, yu^(-1)]*G[{1, yu, yu}, yv^(-1)])/32 - 
     (G[{0}, yw]*G[{1}, yu^(-1)]*G[{1, yu, yu}, yv^(-1)])/32 - 
     (9*G[{1}, yu^(-1)]^2*G[{1, yu, yu}, yv^(-1)])/64 + 
     (9*G[{0}, yu^(-1)]*G[{1}, yv^(-1)]*G[{1, yu, yu}, yv^(-1)])/32 + 
     (9*G[{0}, yv^(-1)]*G[{1}, yv^(-1)]*G[{1, yu, yu}, yv^(-1)])/32 - 
     (9*G[{0}, yw]*G[{1}, yv^(-1)]*G[{1, yu, yu}, yv^(-1)])/32 + 
     (7*G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*G[{1, yu, yu}, yv^(-1)])/32 - 
     (3*G[{1}, yv^(-1)]^2*G[{1, yu, yu}, yv^(-1)])/16 + 
     (7*G[{0}, yu^(-1)]*G[{1}, yw]*G[{1, yu, yu}, yv^(-1)])/32 + 
     (7*G[{0}, yv^(-1)]*G[{1}, yw]*G[{1, yu, yu}, yv^(-1)])/32 - 
     (7*G[{0}, yw]*G[{1}, yw]*G[{1, yu, yu}, yv^(-1)])/32 + 
     (9*G[{1}, yu^(-1)]*G[{1}, yw]*G[{1, yu, yu}, yv^(-1)])/32 + 
     (3*G[{1}, yv^(-1)]*G[{1}, yw]*G[{1, yu, yu}, yv^(-1)])/64 + 
     (7*G[{1}, yw]^2*G[{1, yu, yu}, yv^(-1)])/64 + 
     (3*G[{1}, yw]*G[{yu}, yv^(-1)]*G[{1, yu, yu}, yv^(-1)])/16 - 
     (G[{0}, yu^(-1)]*G[{1/(yu*yv)}, yw]*G[{1, yu, yu}, yv^(-1)])/32 - 
     (G[{0}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{1, yu, yu}, yv^(-1)])/32 + 
     (G[{0}, yw]*G[{1/(yu*yv)}, yw]*G[{1, yu, yu}, yv^(-1)])/32 - 
     (7*G[{1}, yu^(-1)]*G[{1/(yu*yv)}, yw]*G[{1, yu, yu}, yv^(-1)])/32 + 
     (33*G[{1}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{1, yu, yu}, yv^(-1)])/64 + 
     (9*G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{1, yu, yu}, yv^(-1)])/32 - 
     (11*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{1, yu, yu}, yv^(-1)])/32 - 
     (3*G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{1, yu, yu}, yv^(-1)])/16 + 
     (3*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{1, yu, yu}, yv^(-1)])/32 - 
     (3*G[{1/(yu*yv)}, yw]^2*G[{1, yu, yu}, yv^(-1)])/64 + 
     (G[{0, 1}, yu^(-1)]*G[{1, yu, yu}, yv^(-1)])/4 + 
     (G[{0, 1}, yv^(-1)]*G[{1, yu, yu}, yv^(-1)])/8 - 
     (G[{0, 1}, yw]*G[{1, yu, yu}, yv^(-1)])/32 + 
     (5*G[{0, yu^(-1)}, yw]*G[{1, yu, yu}, yv^(-1)])/32 - 
     (G[{0, yu}, yv^(-1)]*G[{1, yu, yu}, yv^(-1)])/8 - 
     (3*G[{0, yv^(-1)}, yw]*G[{1, yu, yu}, yv^(-1)])/32 - 
     (G[{0, 1/(yu*yv)}, yw]*G[{1, yu, yu}, yv^(-1)])/32 + 
     (G[{1, yu^(-1)}, yw]*G[{1, yu, yu}, yv^(-1)])/32 - 
     (G[{1, yu}, yv^(-1)]*G[{1, yu, yu}, yv^(-1)])/8 + 
     (3*G[{1, yv^(-1)}, yw]*G[{1, yu, yu}, yv^(-1)])/32 - 
     (3*G[{1, 1/(yu*yv)}, yw]*G[{1, yu, yu}, yv^(-1)])/16 + 
     (11*G[{yu^(-1), 1/(yu*yv)}, yw]*G[{1, yu, yu}, yv^(-1)])/32 - 
     (3*G[{yv^(-1), 1/(yu*yv)}, yw]*G[{1, yu, yu}, yv^(-1)])/32 - 
     (Pi^2*G[{1, yv^(-1), yu^(-1)}, yw])/32 + 
     (G[{0}, yu^(-1)]*G[{1}, yu^(-1)]*G[{1, yv^(-1), yu^(-1)}, yw])/8 + 
     (G[{0}, yv^(-1)]*G[{1}, yu^(-1)]*G[{1, yv^(-1), yu^(-1)}, yw])/8 - 
     (G[{0}, yw]*G[{1}, yu^(-1)]*G[{1, yv^(-1), yu^(-1)}, yw])/8 - 
     (G[{1}, yu^(-1)]^2*G[{1, yv^(-1), yu^(-1)}, yw])/8 - 
     (G[{0}, yu^(-1)]*G[{1}, yv^(-1)]*G[{1, yv^(-1), yu^(-1)}, yw])/8 - 
     (G[{0}, yv^(-1)]*G[{1}, yv^(-1)]*G[{1, yv^(-1), yu^(-1)}, yw])/8 + 
     (G[{0}, yw]*G[{1}, yv^(-1)]*G[{1, yv^(-1), yu^(-1)}, yw])/8 + 
     (3*G[{1}, yv^(-1)]^2*G[{1, yv^(-1), yu^(-1)}, yw])/32 + 
     (G[{1}, yu^(-1)]*G[{1}, yw]*G[{1, yv^(-1), yu^(-1)}, yw])/8 + 
     (G[{1}, yv^(-1)]*G[{1}, yw]*G[{1, yv^(-1), yu^(-1)}, yw])/16 + 
     (3*G[{1}, yw]^2*G[{1, yv^(-1), yu^(-1)}, yw])/32 - 
     (3*G[{1}, yw]*G[{yu}, yv^(-1)]*G[{1, yv^(-1), yu^(-1)}, yw])/16 + 
     (G[{0}, yu^(-1)]*G[{1/(yu*yv)}, yw]*G[{1, yv^(-1), yu^(-1)}, yw])/8 + 
     (G[{0}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{1, yv^(-1), yu^(-1)}, yw])/8 - 
     (G[{0}, yw]*G[{1/(yu*yv)}, yw]*G[{1, yv^(-1), yu^(-1)}, yw])/8 - 
     (G[{1}, yu^(-1)]*G[{1/(yu*yv)}, yw]*G[{1, yv^(-1), yu^(-1)}, yw])/16 - 
     (G[{1}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{1, yv^(-1), yu^(-1)}, yw])/4 - 
     (G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{1, yv^(-1), yu^(-1)}, yw])/16 + 
     (G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{1, yv^(-1), yu^(-1)}, yw])/8 + 
     (G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{1, yv^(-1), yu^(-1)}, yw])/16 - 
     (G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{1, yv^(-1), yu^(-1)}, yw])/16 - 
     (G[{0, 1}, yu^(-1)]*G[{1, yv^(-1), yu^(-1)}, yw])/8 - 
     (G[{0, 1}, yv^(-1)]*G[{1, yv^(-1), yu^(-1)}, yw])/16 + 
     (G[{0, yu}, yv^(-1)]*G[{1, yv^(-1), yu^(-1)}, yw])/16 - 
     (G[{1, yu^(-1)}, yw]*G[{1, yv^(-1), yu^(-1)}, yw])/16 + 
     (G[{1, yu}, yv^(-1)]*G[{1, yv^(-1), yu^(-1)}, yw])/16 - 
     (G[{1, yv^(-1)}, yw]*G[{1, yv^(-1), yu^(-1)}, yw])/8 + 
     (G[{1, 1/(yu*yv)}, yw]*G[{1, yv^(-1), yu^(-1)}, yw])/16 - 
     (G[{yu^(-1), 1/(yu*yv)}, yw]*G[{1, yv^(-1), yu^(-1)}, yw])/8 + 
     (G[{yv^(-1), 1/(yu*yv)}, yw]*G[{1, yv^(-1), yu^(-1)}, yw])/16 + 
     (Pi^2*G[{1, yv^(-1), yv^(-1)}, yw])/32 + 
     (G[{1}, yu^(-1)]^2*G[{1, yv^(-1), yv^(-1)}, yw])/16 - 
     (G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*G[{1, yv^(-1), yv^(-1)}, yw])/8 + 
     (5*G[{1}, yv^(-1)]^2*G[{1, yv^(-1), yv^(-1)}, yw])/32 + 
     (G[{0}, yu^(-1)]*G[{1}, yw]*G[{1, yv^(-1), yv^(-1)}, yw])/8 + 
     (G[{0}, yv^(-1)]*G[{1}, yw]*G[{1, yv^(-1), yv^(-1)}, yw])/8 - 
     (G[{0}, yw]*G[{1}, yw]*G[{1, yv^(-1), yv^(-1)}, yw])/8 - 
     (G[{1}, yu^(-1)]*G[{1}, yw]*G[{1, yv^(-1), yv^(-1)}, yw])/4 - 
     (G[{1}, yv^(-1)]*G[{1}, yw]*G[{1, yv^(-1), yv^(-1)}, yw])/16 - 
     (G[{1}, yw]^2*G[{1, yv^(-1), yv^(-1)}, yw])/32 + 
     (G[{1}, yw]*G[{yu}, yv^(-1)]*G[{1, yv^(-1), yv^(-1)}, yw])/16 + 
     (G[{0}, yu^(-1)]*G[{1/(yu*yv)}, yw]*G[{1, yv^(-1), yv^(-1)}, yw])/16 + 
     (G[{0}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{1, yv^(-1), yv^(-1)}, yw])/16 - 
     (G[{0}, yw]*G[{1/(yu*yv)}, yw]*G[{1, yv^(-1), yv^(-1)}, yw])/16 + 
     (3*G[{1}, yu^(-1)]*G[{1/(yu*yv)}, yw]*G[{1, yv^(-1), yv^(-1)}, yw])/16 - 
     (G[{1}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{1, yv^(-1), yv^(-1)}, yw])/2 - 
     (3*G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{1, yv^(-1), yv^(-1)}, yw])/16 + 
     (3*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{1, yv^(-1), yv^(-1)}, yw])/8 + 
     (3*G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{1, yv^(-1), yv^(-1)}, yw])/
      16 - (3*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{1, yv^(-1), yv^(-1)}, 
        yw])/16 + (G[{0, 1}, yu^(-1)]*G[{1, yv^(-1), yv^(-1)}, yw])/8 - 
     (G[{0, 1}, yv^(-1)]*G[{1, yv^(-1), yv^(-1)}, yw])/16 + 
     (G[{0, 1}, yw]*G[{1, yv^(-1), yv^(-1)}, yw])/8 - 
     (G[{0, yu^(-1)}, yw]*G[{1, yv^(-1), yv^(-1)}, yw])/8 + 
     (G[{0, yu}, yv^(-1)]*G[{1, yv^(-1), yv^(-1)}, yw])/16 - 
     (G[{0, yv^(-1)}, yw]*G[{1, yv^(-1), yv^(-1)}, yw])/8 + 
     (G[{0, 1/(yu*yv)}, yw]*G[{1, yv^(-1), yv^(-1)}, yw])/8 + 
     (G[{1, yu^(-1)}, yw]*G[{1, yv^(-1), yv^(-1)}, yw])/16 - 
     (3*G[{1, yu}, yv^(-1)]*G[{1, yv^(-1), yv^(-1)}, yw])/16 + 
     (G[{1, yv^(-1)}, yw]*G[{1, yv^(-1), yv^(-1)}, yw])/4 + 
     (5*G[{1, 1/(yu*yv)}, yw]*G[{1, yv^(-1), yv^(-1)}, yw])/16 - 
     (3*G[{yu^(-1), 1/(yu*yv)}, yw]*G[{1, yv^(-1), yv^(-1)}, yw])/8 + 
     (3*G[{yv^(-1), 1/(yu*yv)}, yw]*G[{1, yv^(-1), yv^(-1)}, yw])/16 - 
     (Pi^2*G[{1, yv^(-1), 1/(yu*yv)}, yw])/96 - 
     (G[{0}, yu^(-1)]*G[{1}, yu^(-1)]*G[{1, yv^(-1), 1/(yu*yv)}, yw])/16 - 
     (G[{0}, yv^(-1)]*G[{1}, yu^(-1)]*G[{1, yv^(-1), 1/(yu*yv)}, yw])/16 + 
     (G[{0}, yw]*G[{1}, yu^(-1)]*G[{1, yv^(-1), 1/(yu*yv)}, yw])/16 + 
     (3*G[{1}, yu^(-1)]^2*G[{1, yv^(-1), 1/(yu*yv)}, yw])/32 + 
     (G[{0}, yu^(-1)]*G[{1}, yv^(-1)]*G[{1, yv^(-1), 1/(yu*yv)}, yw])/16 + 
     (G[{0}, yv^(-1)]*G[{1}, yv^(-1)]*G[{1, yv^(-1), 1/(yu*yv)}, yw])/16 - 
     (G[{0}, yw]*G[{1}, yv^(-1)]*G[{1, yv^(-1), 1/(yu*yv)}, yw])/16 - 
     (G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*G[{1, yv^(-1), 1/(yu*yv)}, yw])/16 + 
     (G[{1}, yv^(-1)]*G[{1}, yw]*G[{1, yv^(-1), 1/(yu*yv)}, yw])/16 + 
     (G[{1}, yw]^2*G[{1, yv^(-1), 1/(yu*yv)}, yw])/32 - 
     (G[{1}, yw]*G[{yu}, yv^(-1)]*G[{1, yv^(-1), 1/(yu*yv)}, yw])/16 - 
     (G[{0}, yu^(-1)]*G[{1/(yu*yv)}, yw]*G[{1, yv^(-1), 1/(yu*yv)}, yw])/16 - 
     (G[{0}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{1, yv^(-1), 1/(yu*yv)}, yw])/16 + 
     (G[{0}, yw]*G[{1/(yu*yv)}, yw]*G[{1, yv^(-1), 1/(yu*yv)}, yw])/16 - 
     (G[{1}, yu^(-1)]*G[{1/(yu*yv)}, yw]*G[{1, yv^(-1), 1/(yu*yv)}, yw])/8 + 
     (G[{1}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{1, yv^(-1), 1/(yu*yv)}, yw])/8 - 
     (G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{1, yv^(-1), 1/(yu*yv)}, yw])/8 - 
     (G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{1, yv^(-1), 1/(yu*yv)}, yw])/8 + 
     (G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{1, yv^(-1), 1/(yu*yv)}, yw])/8 + 
     (G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{1, yv^(-1), 1/(yu*yv)}, yw])/8 - 
     (G[{0, 1}, yv^(-1)]*G[{1, yv^(-1), 1/(yu*yv)}, yw])/16 + 
     (G[{0, yu}, yv^(-1)]*G[{1, yv^(-1), 1/(yu*yv)}, yw])/16 - 
     (G[{1, yu^(-1)}, yw]*G[{1, yv^(-1), 1/(yu*yv)}, yw])/16 - 
     (G[{1, yu}, yv^(-1)]*G[{1, yv^(-1), 1/(yu*yv)}, yw])/16 + 
     (G[{1, 1/(yu*yv)}, yw]*G[{1, yv^(-1), 1/(yu*yv)}, yw])/8 + 
     (G[{yu^(-1), 1/(yu*yv)}, yw]*G[{1, yv^(-1), 1/(yu*yv)}, yw])/8 - 
     (G[{yv^(-1), 1/(yu*yv)}, yw]*G[{1, yv^(-1), 1/(yu*yv)}, yw])/8 - 
     (5*Pi^2*G[{1, 1/(yu*yv), yu^(-1)}, yw])/768 - 
     (3*G[{0}, yu^(-1)]^2*G[{1, 1/(yu*yv), yu^(-1)}, yw])/64 - 
     (3*G[{0}, yu^(-1)]*G[{0}, yv^(-1)]*G[{1, 1/(yu*yv), yu^(-1)}, yw])/32 - 
     (3*G[{0}, yv^(-1)]^2*G[{1, 1/(yu*yv), yu^(-1)}, yw])/64 + 
     (3*G[{0}, yu^(-1)]*G[{0}, yw]*G[{1, 1/(yu*yv), yu^(-1)}, yw])/32 + 
     (3*G[{0}, yv^(-1)]*G[{0}, yw]*G[{1, 1/(yu*yv), yu^(-1)}, yw])/32 - 
     (3*G[{0}, yw]^2*G[{1, 1/(yu*yv), yu^(-1)}, yw])/64 - 
     (G[{0}, yu^(-1)]*G[{1}, yu^(-1)]*G[{1, 1/(yu*yv), yu^(-1)}, yw])/32 - 
     (G[{0}, yv^(-1)]*G[{1}, yu^(-1)]*G[{1, 1/(yu*yv), yu^(-1)}, yw])/32 + 
     (G[{0}, yw]*G[{1}, yu^(-1)]*G[{1, 1/(yu*yv), yu^(-1)}, yw])/32 + 
     (5*G[{1}, yu^(-1)]^2*G[{1, 1/(yu*yv), yu^(-1)}, yw])/64 - 
     (G[{0}, yu^(-1)]*G[{1}, yv^(-1)]*G[{1, 1/(yu*yv), yu^(-1)}, yw])/32 - 
     (G[{0}, yv^(-1)]*G[{1}, yv^(-1)]*G[{1, 1/(yu*yv), yu^(-1)}, yw])/32 + 
     (G[{0}, yw]*G[{1}, yv^(-1)]*G[{1, 1/(yu*yv), yu^(-1)}, yw])/32 - 
     (3*G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*G[{1, 1/(yu*yv), yu^(-1)}, yw])/32 + 
     (G[{1}, yv^(-1)]^2*G[{1, 1/(yu*yv), yu^(-1)}, yw])/8 - 
     (7*G[{0}, yu^(-1)]*G[{1}, yw]*G[{1, 1/(yu*yv), yu^(-1)}, yw])/32 - 
     (7*G[{0}, yv^(-1)]*G[{1}, yw]*G[{1, 1/(yu*yv), yu^(-1)}, yw])/32 + 
     (7*G[{0}, yw]*G[{1}, yw]*G[{1, 1/(yu*yv), yu^(-1)}, yw])/32 + 
     (3*G[{1}, yu^(-1)]*G[{1}, yw]*G[{1, 1/(yu*yv), yu^(-1)}, yw])/32 + 
     (3*G[{1}, yv^(-1)]*G[{1}, yw]*G[{1, 1/(yu*yv), yu^(-1)}, yw])/16 - 
     (5*G[{1}, yw]^2*G[{1, 1/(yu*yv), yu^(-1)}, yw])/64 + 
     (G[{0}, yu^(-1)]*G[{yu}, yv^(-1)]*G[{1, 1/(yu*yv), yu^(-1)}, yw])/4 + 
     (G[{0}, yv^(-1)]*G[{yu}, yv^(-1)]*G[{1, 1/(yu*yv), yu^(-1)}, yw])/4 - 
     (G[{0}, yw]*G[{yu}, yv^(-1)]*G[{1, 1/(yu*yv), yu^(-1)}, yw])/4 - 
     (7*G[{1}, yv^(-1)]*G[{yu}, yv^(-1)]*G[{1, 1/(yu*yv), yu^(-1)}, yw])/32 + 
     (5*G[{1}, yw]*G[{yu}, yv^(-1)]*G[{1, 1/(yu*yv), yu^(-1)}, yw])/32 - 
     (9*G[{yu}, yv^(-1)]^2*G[{1, 1/(yu*yv), yu^(-1)}, yw])/64 + 
     (3*G[{0}, yu^(-1)]*G[{1/(yu*yv)}, yw]*G[{1, 1/(yu*yv), yu^(-1)}, yw])/
      32 + (3*G[{0}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{1, 1/(yu*yv), yu^(-1)}, 
        yw])/32 - (3*G[{0}, yw]*G[{1/(yu*yv)}, yw]*G[{1, 1/(yu*yv), yu^(-1)}, 
        yw])/32 - (G[{1}, yu^(-1)]*G[{1/(yu*yv)}, yw]*
       G[{1, 1/(yu*yv), yu^(-1)}, yw])/32 - 
     (17*G[{1}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{1, 1/(yu*yv), yu^(-1)}, yw])/
      64 - (7*G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{1, 1/(yu*yv), yu^(-1)}, yw])/
      64 + (3*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{1, 1/(yu*yv), yu^(-1)}, 
        yw])/32 + (7*G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw]*
       G[{1, 1/(yu*yv), yu^(-1)}, yw])/64 + 
     (G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{1, 1/(yu*yv), yu^(-1)}, yw])/
      32 + (3*G[{1/(yu*yv)}, yw]^2*G[{1, 1/(yu*yv), yu^(-1)}, yw])/64 - 
     (G[{0, 1}, yu^(-1)]*G[{1, 1/(yu*yv), yu^(-1)}, yw])/8 + 
     (G[{0, 1}, yw]*G[{1, 1/(yu*yv), yu^(-1)}, yw])/32 - 
     (G[{0, yu^(-1)}, yw]*G[{1, 1/(yu*yv), yu^(-1)}, yw])/32 - 
     (G[{0, yv^(-1)}, yw]*G[{1, 1/(yu*yv), yu^(-1)}, yw])/32 + 
     (G[{0, 1/(yu*yv)}, yw]*G[{1, 1/(yu*yv), yu^(-1)}, yw])/32 + 
     (G[{1, yu^(-1)}, yw]*G[{1, 1/(yu*yv), yu^(-1)}, yw])/32 + 
     (G[{1, yu}, yv^(-1)]*G[{1, 1/(yu*yv), yu^(-1)}, yw])/8 - 
     (3*G[{1, yv^(-1)}, yw]*G[{1, 1/(yu*yv), yu^(-1)}, yw])/32 + 
     (G[{1, 1/(yu*yv)}, yw]*G[{1, 1/(yu*yv), yu^(-1)}, yw])/8 - 
     (3*G[{yu^(-1), 1/(yu*yv)}, yw]*G[{1, 1/(yu*yv), yu^(-1)}, yw])/32 - 
     (G[{yv^(-1), 1/(yu*yv)}, yw]*G[{1, 1/(yu*yv), yu^(-1)}, yw])/32 + 
     (G[{0}, yu^(-1)]*G[{1/(yu*yv)}, yw]*G[{1, 1/(yu*yv), yv^(-1)}, yw])/16 + 
     (G[{0}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{1, 1/(yu*yv), yv^(-1)}, yw])/16 - 
     (G[{0}, yw]*G[{1/(yu*yv)}, yw]*G[{1, 1/(yu*yv), yv^(-1)}, yw])/16 - 
     (G[{1}, yu^(-1)]*G[{1/(yu*yv)}, yw]*G[{1, 1/(yu*yv), yv^(-1)}, yw])/4 + 
     (G[{1}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{1, 1/(yu*yv), yv^(-1)}, yw])/4 + 
     (G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{1, 1/(yu*yv), yv^(-1)}, yw])/8 - 
     (G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{1, 1/(yu*yv), yv^(-1)}, yw])/4 - 
     (G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{1, 1/(yu*yv), yv^(-1)}, yw])/8 + 
     (G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{1, 1/(yu*yv), yv^(-1)}, yw])/8 + 
     (G[{yu^(-1), 1/(yu*yv)}, yw]*G[{1, 1/(yu*yv), yv^(-1)}, yw])/4 - 
     (G[{yv^(-1), 1/(yu*yv)}, yw]*G[{1, 1/(yu*yv), yv^(-1)}, yw])/8 - 
     (13*Pi^2*G[{1, 1/(yu*yv), 1/(yu*yv)}, yw])/768 + 
     (3*G[{0}, yu^(-1)]^2*G[{1, 1/(yu*yv), 1/(yu*yv)}, yw])/128 + 
     (3*G[{0}, yu^(-1)]*G[{0}, yv^(-1)]*G[{1, 1/(yu*yv), 1/(yu*yv)}, yw])/
      64 + (3*G[{0}, yv^(-1)]^2*G[{1, 1/(yu*yv), 1/(yu*yv)}, yw])/128 - 
     (3*G[{0}, yu^(-1)]*G[{0}, yw]*G[{1, 1/(yu*yv), 1/(yu*yv)}, yw])/64 - 
     (3*G[{0}, yv^(-1)]*G[{0}, yw]*G[{1, 1/(yu*yv), 1/(yu*yv)}, yw])/64 + 
     (3*G[{0}, yw]^2*G[{1, 1/(yu*yv), 1/(yu*yv)}, yw])/128 + 
     (9*G[{0}, yu^(-1)]*G[{1}, yu^(-1)]*G[{1, 1/(yu*yv), 1/(yu*yv)}, yw])/
      64 + (9*G[{0}, yv^(-1)]*G[{1}, yu^(-1)]*G[{1, 1/(yu*yv), 1/(yu*yv)}, 
        yw])/64 - (9*G[{0}, yw]*G[{1}, yu^(-1)]*G[{1, 1/(yu*yv), 1/(yu*yv)}, 
        yw])/64 - (25*G[{1}, yu^(-1)]^2*G[{1, 1/(yu*yv), 1/(yu*yv)}, yw])/
      128 + (G[{0}, yu^(-1)]*G[{1}, yv^(-1)]*G[{1, 1/(yu*yv), 1/(yu*yv)}, 
        yw])/64 + (G[{0}, yv^(-1)]*G[{1}, yv^(-1)]*
       G[{1, 1/(yu*yv), 1/(yu*yv)}, yw])/64 - 
     (G[{0}, yw]*G[{1}, yv^(-1)]*G[{1, 1/(yu*yv), 1/(yu*yv)}, yw])/64 + 
     (7*G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*G[{1, 1/(yu*yv), 1/(yu*yv)}, yw])/
      64 - (5*G[{1}, yv^(-1)]^2*G[{1, 1/(yu*yv), 1/(yu*yv)}, yw])/128 + 
     (15*G[{0}, yu^(-1)]*G[{1}, yw]*G[{1, 1/(yu*yv), 1/(yu*yv)}, yw])/64 + 
     (15*G[{0}, yv^(-1)]*G[{1}, yw]*G[{1, 1/(yu*yv), 1/(yu*yv)}, yw])/64 - 
     (15*G[{0}, yw]*G[{1}, yw]*G[{1, 1/(yu*yv), 1/(yu*yv)}, yw])/64 + 
     (9*G[{1}, yu^(-1)]*G[{1}, yw]*G[{1, 1/(yu*yv), 1/(yu*yv)}, yw])/64 + 
     (13*G[{1}, yv^(-1)]*G[{1}, yw]*G[{1, 1/(yu*yv), 1/(yu*yv)}, yw])/64 + 
     (13*G[{1}, yw]^2*G[{1, 1/(yu*yv), 1/(yu*yv)}, yw])/32 - 
     (G[{0}, yu^(-1)]*G[{yu}, yv^(-1)]*G[{1, 1/(yu*yv), 1/(yu*yv)}, yw])/4 - 
     (G[{0}, yv^(-1)]*G[{yu}, yv^(-1)]*G[{1, 1/(yu*yv), 1/(yu*yv)}, yw])/4 + 
     (G[{0}, yw]*G[{yu}, yv^(-1)]*G[{1, 1/(yu*yv), 1/(yu*yv)}, yw])/4 - 
     (9*G[{1}, yv^(-1)]*G[{yu}, yv^(-1)]*G[{1, 1/(yu*yv), 1/(yu*yv)}, yw])/
      64 - (13*G[{1}, yw]*G[{yu}, yv^(-1)]*G[{1, 1/(yu*yv), 1/(yu*yv)}, yw])/
      16 + (41*G[{yu}, yv^(-1)]^2*G[{1, 1/(yu*yv), 1/(yu*yv)}, yw])/128 + 
     (3*G[{0}, yu^(-1)]*G[{1/(yu*yv)}, yw]*G[{1, 1/(yu*yv), 1/(yu*yv)}, yw])/
      64 + (3*G[{0}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{1, 1/(yu*yv), 1/(yu*yv)}, 
        yw])/64 - (3*G[{0}, yw]*G[{1/(yu*yv)}, yw]*
       G[{1, 1/(yu*yv), 1/(yu*yv)}, yw])/64 + 
     (5*G[{1}, yu^(-1)]*G[{1/(yu*yv)}, yw]*G[{1, 1/(yu*yv), 1/(yu*yv)}, yw])/
      64 + (G[{1}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{1, 1/(yu*yv), 1/(yu*yv)}, 
        yw])/64 + (3*G[{1}, yw]*G[{1/(yu*yv)}, yw]*
       G[{1, 1/(yu*yv), 1/(yu*yv)}, yw])/16 + 
     (5*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{1, 1/(yu*yv), 1/(yu*yv)}, yw])/
      64 - (3*G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw]*
       G[{1, 1/(yu*yv), 1/(yu*yv)}, yw])/16 - 
     (5*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{1, 1/(yu*yv), 1/(yu*yv)}, yw])/
      64 - (G[{0, 1}, yu^(-1)]*G[{1, 1/(yu*yv), 1/(yu*yv)}, yw])/8 - 
     (3*G[{0, 1}, yv^(-1)]*G[{1, 1/(yu*yv), 1/(yu*yv)}, yw])/64 - 
     (G[{0, 1}, yw]*G[{1, 1/(yu*yv), 1/(yu*yv)}, yw])/64 + 
     (G[{0, yu^(-1)}, yw]*G[{1, 1/(yu*yv), 1/(yu*yv)}, yw])/64 + 
     (3*G[{0, yu}, yv^(-1)]*G[{1, 1/(yu*yv), 1/(yu*yv)}, yw])/64 + 
     (G[{0, yv^(-1)}, yw]*G[{1, 1/(yu*yv), 1/(yu*yv)}, yw])/64 - 
     (G[{0, 1/(yu*yv)}, yw]*G[{1, 1/(yu*yv), 1/(yu*yv)}, yw])/64 - 
     (G[{1, yu^(-1)}, yw]*G[{1, 1/(yu*yv), 1/(yu*yv)}, yw])/16 + 
     (5*G[{1, yu}, yv^(-1)]*G[{1, 1/(yu*yv), 1/(yu*yv)}, yw])/64 - 
     (9*G[{1, yv^(-1)}, yw]*G[{1, 1/(yu*yv), 1/(yu*yv)}, yw])/64 + 
     (11*G[{1, 1/(yu*yv)}, yw]*G[{1, 1/(yu*yv), 1/(yu*yv)}, yw])/64 - 
     (5*G[{yu^(-1), 1/(yu*yv)}, yw]*G[{1, 1/(yu*yv), 1/(yu*yv)}, yw])/64 + 
     (5*G[{yv^(-1), 1/(yu*yv)}, yw]*G[{1, 1/(yu*yv), 1/(yu*yv)}, yw])/64 + 
     (Pi^2*G[{yu^(-1), yu^(-1), 1/(yu*yv)}, yw])/256 - 
     (3*G[{0}, yu^(-1)]^2*G[{yu^(-1), yu^(-1), 1/(yu*yv)}, yw])/64 - 
     (3*G[{0}, yu^(-1)]*G[{0}, yv^(-1)]*G[{yu^(-1), yu^(-1), 1/(yu*yv)}, yw])/
      32 - (3*G[{0}, yv^(-1)]^2*G[{yu^(-1), yu^(-1), 1/(yu*yv)}, yw])/64 + 
     (3*G[{0}, yu^(-1)]*G[{0}, yw]*G[{yu^(-1), yu^(-1), 1/(yu*yv)}, yw])/32 + 
     (3*G[{0}, yv^(-1)]*G[{0}, yw]*G[{yu^(-1), yu^(-1), 1/(yu*yv)}, yw])/32 - 
     (3*G[{0}, yw]^2*G[{yu^(-1), yu^(-1), 1/(yu*yv)}, yw])/64 + 
     (3*G[{0}, yu^(-1)]*G[{1}, yu^(-1)]*G[{yu^(-1), yu^(-1), 1/(yu*yv)}, yw])/
      32 + (3*G[{0}, yv^(-1)]*G[{1}, yu^(-1)]*
       G[{yu^(-1), yu^(-1), 1/(yu*yv)}, yw])/32 - 
     (3*G[{0}, yw]*G[{1}, yu^(-1)]*G[{yu^(-1), yu^(-1), 1/(yu*yv)}, yw])/32 - 
     (3*G[{1}, yu^(-1)]^2*G[{yu^(-1), yu^(-1), 1/(yu*yv)}, yw])/64 + 
     (3*G[{0}, yu^(-1)]*G[{1}, yv^(-1)]*G[{yu^(-1), yu^(-1), 1/(yu*yv)}, yw])/
      32 + (3*G[{0}, yv^(-1)]*G[{1}, yv^(-1)]*
       G[{yu^(-1), yu^(-1), 1/(yu*yv)}, yw])/32 - 
     (3*G[{0}, yw]*G[{1}, yv^(-1)]*G[{yu^(-1), yu^(-1), 1/(yu*yv)}, yw])/32 - 
     (3*G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*G[{yu^(-1), yu^(-1), 1/(yu*yv)}, yw])/
      32 - (G[{1}, yv^(-1)]^2*G[{yu^(-1), yu^(-1), 1/(yu*yv)}, yw])/32 - 
     (7*G[{0}, yu^(-1)]*G[{1}, yw]*G[{yu^(-1), yu^(-1), 1/(yu*yv)}, yw])/32 - 
     (7*G[{0}, yv^(-1)]*G[{1}, yw]*G[{yu^(-1), yu^(-1), 1/(yu*yv)}, yw])/32 + 
     (7*G[{0}, yw]*G[{1}, yw]*G[{yu^(-1), yu^(-1), 1/(yu*yv)}, yw])/32 + 
     (7*G[{1}, yu^(-1)]*G[{1}, yw]*G[{yu^(-1), yu^(-1), 1/(yu*yv)}, yw])/32 + 
     (G[{1}, yv^(-1)]*G[{1}, yw]*G[{yu^(-1), yu^(-1), 1/(yu*yv)}, yw])/4 + 
     (G[{1}, yw]^2*G[{yu^(-1), yu^(-1), 1/(yu*yv)}, yw])/64 + 
     (G[{0}, yu^(-1)]*G[{yu^(-1)}, yw]*G[{yu^(-1), yu^(-1), 1/(yu*yv)}, yw])/
      8 + (G[{0}, yv^(-1)]*G[{yu^(-1)}, yw]*G[{yu^(-1), yu^(-1), 1/(yu*yv)}, 
        yw])/8 - (G[{0}, yw]*G[{yu^(-1)}, yw]*
       G[{yu^(-1), yu^(-1), 1/(yu*yv)}, yw])/8 - 
     (G[{1}, yu^(-1)]*G[{yu^(-1)}, yw]*G[{yu^(-1), yu^(-1), 1/(yu*yv)}, yw])/
      8 - (11*G[{1}, yv^(-1)]*G[{yu^(-1)}, yw]*
       G[{yu^(-1), yu^(-1), 1/(yu*yv)}, yw])/32 - 
     (7*G[{1}, yw]*G[{yu^(-1)}, yw]*G[{yu^(-1), yu^(-1), 1/(yu*yv)}, yw])/
      32 + (11*G[{yu^(-1)}, yw]^2*G[{yu^(-1), yu^(-1), 1/(yu*yv)}, yw])/64 - 
     (7*G[{1}, yv^(-1)]*G[{yu}, yv^(-1)]*G[{yu^(-1), yu^(-1), 1/(yu*yv)}, 
        yw])/32 - (G[{1}, yw]*G[{yu}, yv^(-1)]*
       G[{yu^(-1), yu^(-1), 1/(yu*yv)}, yw])/32 + 
     (7*G[{yu^(-1)}, yw]*G[{yu}, yv^(-1)]*G[{yu^(-1), yu^(-1), 1/(yu*yv)}, 
        yw])/32 + (7*G[{yu}, yv^(-1)]^2*G[{yu^(-1), yu^(-1), 1/(yu*yv)}, yw])/
      64 + (3*G[{0}, yu^(-1)]*G[{1/(yu*yv)}, yw]*
       G[{yu^(-1), yu^(-1), 1/(yu*yv)}, yw])/32 + 
     (3*G[{0}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{yu^(-1), yu^(-1), 1/(yu*yv)}, 
        yw])/32 - (3*G[{0}, yw]*G[{1/(yu*yv)}, yw]*
       G[{yu^(-1), yu^(-1), 1/(yu*yv)}, yw])/32 - 
     (3*G[{1}, yu^(-1)]*G[{1/(yu*yv)}, yw]*G[{yu^(-1), yu^(-1), 1/(yu*yv)}, 
        yw])/32 - (17*G[{1}, yv^(-1)]*G[{1/(yu*yv)}, yw]*
       G[{yu^(-1), yu^(-1), 1/(yu*yv)}, yw])/64 - 
     (11*G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{yu^(-1), yu^(-1), 1/(yu*yv)}, yw])/
      64 + (17*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*
       G[{yu^(-1), yu^(-1), 1/(yu*yv)}, yw])/64 + 
     (11*G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{yu^(-1), yu^(-1), 1/(yu*yv)}, 
        yw])/64 - (G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*
       G[{yu^(-1), yu^(-1), 1/(yu*yv)}, yw])/32 + 
     (3*G[{1/(yu*yv)}, yw]^2*G[{yu^(-1), yu^(-1), 1/(yu*yv)}, yw])/64 + 
     (3*G[{0, 1}, yv^(-1)]*G[{yu^(-1), yu^(-1), 1/(yu*yv)}, yw])/16 - 
     (7*G[{0, 1}, yw]*G[{yu^(-1), yu^(-1), 1/(yu*yv)}, yw])/32 + 
     (7*G[{0, yu^(-1)}, yw]*G[{yu^(-1), yu^(-1), 1/(yu*yv)}, yw])/32 - 
     (3*G[{0, yu}, yv^(-1)]*G[{yu^(-1), yu^(-1), 1/(yu*yv)}, yw])/16 + 
     (7*G[{0, yv^(-1)}, yw]*G[{yu^(-1), yu^(-1), 1/(yu*yv)}, yw])/32 - 
     (7*G[{0, 1/(yu*yv)}, yw]*G[{yu^(-1), yu^(-1), 1/(yu*yv)}, yw])/32 - 
     (G[{1, yu^(-1)}, yw]*G[{yu^(-1), yu^(-1), 1/(yu*yv)}, yw])/32 + 
     (3*G[{1, yu}, yv^(-1)]*G[{yu^(-1), yu^(-1), 1/(yu*yv)}, yw])/16 - 
     (7*G[{1, yv^(-1)}, yw]*G[{yu^(-1), yu^(-1), 1/(yu*yv)}, yw])/32 - 
     (3*G[{1, 1/(yu*yv)}, yw]*G[{yu^(-1), yu^(-1), 1/(yu*yv)}, yw])/16 - 
     (7*G[{yu^(-1), 1/(yu*yv)}, yw]*G[{yu^(-1), yu^(-1), 1/(yu*yv)}, yw])/
      32 + (G[{yv^(-1), 1/(yu*yv)}, yw]*G[{yu^(-1), yu^(-1), 1/(yu*yv)}, yw])/
      32 + (Pi^2*G[{yu^(-1), 1/(yu*yv), yv^(-1)}, yw])/32 - 
     (G[{0}, yu^(-1)]*G[{1}, yu^(-1)]*G[{yu^(-1), 1/(yu*yv), yv^(-1)}, yw])/
      8 - (G[{0}, yv^(-1)]*G[{1}, yu^(-1)]*G[{yu^(-1), 1/(yu*yv), yv^(-1)}, 
        yw])/8 + (G[{0}, yw]*G[{1}, yu^(-1)]*G[{yu^(-1), 1/(yu*yv), yv^(-1)}, 
        yw])/8 + (G[{1}, yu^(-1)]^2*G[{yu^(-1), 1/(yu*yv), yv^(-1)}, yw])/8 + 
     (G[{0}, yu^(-1)]*G[{1}, yv^(-1)]*G[{yu^(-1), 1/(yu*yv), yv^(-1)}, yw])/
      8 + (G[{0}, yv^(-1)]*G[{1}, yv^(-1)]*G[{yu^(-1), 1/(yu*yv), yv^(-1)}, 
        yw])/8 - (G[{0}, yw]*G[{1}, yv^(-1)]*G[{yu^(-1), 1/(yu*yv), yv^(-1)}, 
        yw])/8 - (3*G[{1}, yv^(-1)]^2*G[{yu^(-1), 1/(yu*yv), yv^(-1)}, yw])/
      32 - (G[{1}, yu^(-1)]*G[{1}, yw]*G[{yu^(-1), 1/(yu*yv), yv^(-1)}, yw])/
      8 - (G[{1}, yv^(-1)]*G[{1}, yw]*G[{yu^(-1), 1/(yu*yv), yv^(-1)}, yw])/
      16 - (3*G[{1}, yw]^2*G[{yu^(-1), 1/(yu*yv), yv^(-1)}, yw])/32 - 
     (G[{0}, yu^(-1)]*G[{yu^(-1)}, yw]*G[{yu^(-1), 1/(yu*yv), yv^(-1)}, yw])/
      8 - (G[{0}, yv^(-1)]*G[{yu^(-1)}, yw]*G[{yu^(-1), 1/(yu*yv), yv^(-1)}, 
        yw])/8 + (G[{0}, yw]*G[{yu^(-1)}, yw]*
       G[{yu^(-1), 1/(yu*yv), yv^(-1)}, yw])/8 + 
     (G[{1}, yu^(-1)]*G[{yu^(-1)}, yw]*G[{yu^(-1), 1/(yu*yv), yv^(-1)}, yw])/
      8 + (G[{1}, yv^(-1)]*G[{yu^(-1)}, yw]*G[{yu^(-1), 1/(yu*yv), yv^(-1)}, 
        yw])/8 - (G[{yu^(-1)}, yw]^2*G[{yu^(-1), 1/(yu*yv), yv^(-1)}, yw])/
      16 + (3*G[{1}, yw]*G[{yu}, yv^(-1)]*G[{yu^(-1), 1/(yu*yv), yv^(-1)}, 
        yw])/16 - (G[{0}, yu^(-1)]*G[{1/(yu*yv)}, yw]*
       G[{yu^(-1), 1/(yu*yv), yv^(-1)}, yw])/8 - 
     (G[{0}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{yu^(-1), 1/(yu*yv), yv^(-1)}, 
        yw])/8 + (G[{0}, yw]*G[{1/(yu*yv)}, yw]*
       G[{yu^(-1), 1/(yu*yv), yv^(-1)}, yw])/8 + 
     (G[{1}, yu^(-1)]*G[{1/(yu*yv)}, yw]*G[{yu^(-1), 1/(yu*yv), yv^(-1)}, 
        yw])/16 + (G[{1}, yv^(-1)]*G[{1/(yu*yv)}, yw]*
       G[{yu^(-1), 1/(yu*yv), yv^(-1)}, yw])/4 + 
     (G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{yu^(-1), 1/(yu*yv), yv^(-1)}, yw])/
      16 - (G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*
       G[{yu^(-1), 1/(yu*yv), yv^(-1)}, yw])/4 - 
     (G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{yu^(-1), 1/(yu*yv), yv^(-1)}, 
        yw])/16 + (G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*
       G[{yu^(-1), 1/(yu*yv), yv^(-1)}, yw])/16 + 
     (G[{0, 1}, yu^(-1)]*G[{yu^(-1), 1/(yu*yv), yv^(-1)}, yw])/8 + 
     (G[{0, 1}, yv^(-1)]*G[{yu^(-1), 1/(yu*yv), yv^(-1)}, yw])/16 - 
     (G[{0, yu}, yv^(-1)]*G[{yu^(-1), 1/(yu*yv), yv^(-1)}, yw])/16 + 
     (G[{1, yu^(-1)}, yw]*G[{yu^(-1), 1/(yu*yv), yv^(-1)}, yw])/16 - 
     (G[{1, yu}, yv^(-1)]*G[{yu^(-1), 1/(yu*yv), yv^(-1)}, yw])/16 + 
     (G[{1, yv^(-1)}, yw]*G[{yu^(-1), 1/(yu*yv), yv^(-1)}, yw])/8 - 
     (3*G[{1, 1/(yu*yv)}, yw]*G[{yu^(-1), 1/(yu*yv), yv^(-1)}, yw])/16 + 
     (G[{yu^(-1), 1/(yu*yv)}, yw]*G[{yu^(-1), 1/(yu*yv), yv^(-1)}, yw])/16 - 
     (G[{yv^(-1), 1/(yu*yv)}, yw]*G[{yu^(-1), 1/(yu*yv), yv^(-1)}, yw])/16 - 
     (11*Pi^2*G[{yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/768 - 
     (3*G[{0}, yu^(-1)]^2*G[{yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/128 - 
     (3*G[{0}, yu^(-1)]*G[{0}, yv^(-1)]*G[{yu^(-1), 1/(yu*yv), 1/(yu*yv)}, 
        yw])/64 - (3*G[{0}, yv^(-1)]^2*G[{yu^(-1), 1/(yu*yv), 1/(yu*yv)}, 
        yw])/128 + (3*G[{0}, yu^(-1)]*G[{0}, yw]*
       G[{yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/64 + 
     (3*G[{0}, yv^(-1)]*G[{0}, yw]*G[{yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/
      64 - (3*G[{0}, yw]^2*G[{yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/128 + 
     (3*G[{0}, yu^(-1)]*G[{1}, yu^(-1)]*G[{yu^(-1), 1/(yu*yv), 1/(yu*yv)}, 
        yw])/64 + (3*G[{0}, yv^(-1)]*G[{1}, yu^(-1)]*
       G[{yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/64 - 
     (3*G[{0}, yw]*G[{1}, yu^(-1)]*G[{yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/
      64 - (11*G[{1}, yu^(-1)]^2*G[{yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/
      128 - (5*G[{0}, yu^(-1)]*G[{1}, yv^(-1)]*
       G[{yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/64 - 
     (5*G[{0}, yv^(-1)]*G[{1}, yv^(-1)]*G[{yu^(-1), 1/(yu*yv), 1/(yu*yv)}, 
        yw])/64 + (5*G[{0}, yw]*G[{1}, yv^(-1)]*
       G[{yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/64 + 
     (5*G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*G[{yu^(-1), 1/(yu*yv), 1/(yu*yv)}, 
        yw])/64 + (29*G[{1}, yv^(-1)]^2*G[{yu^(-1), 1/(yu*yv), 1/(yu*yv)}, 
        yw])/128 - (23*G[{0}, yu^(-1)]*G[{1}, yw]*
       G[{yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/64 - 
     (23*G[{0}, yv^(-1)]*G[{1}, yw]*G[{yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/
      64 + (23*G[{0}, yw]*G[{1}, yw]*G[{yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/
      64 + (15*G[{1}, yu^(-1)]*G[{1}, yw]*G[{yu^(-1), 1/(yu*yv), 1/(yu*yv)}, 
        yw])/64 + (39*G[{1}, yv^(-1)]*G[{1}, yw]*
       G[{yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/64 + 
     (G[{1}, yw]^2*G[{yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/16 + 
     (5*G[{0}, yu^(-1)]*G[{yu^(-1)}, yw]*G[{yu^(-1), 1/(yu*yv), 1/(yu*yv)}, 
        yw])/16 + (5*G[{0}, yv^(-1)]*G[{yu^(-1)}, yw]*
       G[{yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/16 - 
     (5*G[{0}, yw]*G[{yu^(-1)}, yw]*G[{yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/
      16 - (5*G[{1}, yu^(-1)]*G[{yu^(-1)}, yw]*
       G[{yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/16 - 
     (43*G[{1}, yv^(-1)]*G[{yu^(-1)}, yw]*G[{yu^(-1), 1/(yu*yv), 1/(yu*yv)}, 
        yw])/64 - (23*G[{1}, yw]*G[{yu^(-1)}, yw]*
       G[{yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/64 + 
     (43*G[{yu^(-1)}, yw]^2*G[{yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/128 + 
     (G[{0}, yu^(-1)]*G[{yu}, yv^(-1)]*G[{yu^(-1), 1/(yu*yv), 1/(yu*yv)}, 
        yw])/8 + (G[{0}, yv^(-1)]*G[{yu}, yv^(-1)]*
       G[{yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/8 - 
     (G[{0}, yw]*G[{yu}, yv^(-1)]*G[{yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/8 - 
     (23*G[{1}, yv^(-1)]*G[{yu}, yv^(-1)]*G[{yu^(-1), 1/(yu*yv), 1/(yu*yv)}, 
        yw])/64 - (G[{1}, yw]*G[{yu}, yv^(-1)]*
       G[{yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/8 + 
     (23*G[{yu^(-1)}, yw]*G[{yu}, yv^(-1)]*G[{yu^(-1), 1/(yu*yv), 1/(yu*yv)}, 
        yw])/64 + (7*G[{yu}, yv^(-1)]^2*G[{yu^(-1), 1/(yu*yv), 1/(yu*yv)}, 
        yw])/128 + (G[{0}, yu^(-1)]*G[{1/(yu*yv)}, yw]*
       G[{yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/64 + 
     (G[{0}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{yu^(-1), 1/(yu*yv), 1/(yu*yv)}, 
        yw])/64 - (G[{0}, yw]*G[{1/(yu*yv)}, yw]*
       G[{yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/64 + 
     (3*G[{1}, yu^(-1)]*G[{1/(yu*yv)}, yw]*G[{yu^(-1), 1/(yu*yv), 1/(yu*yv)}, 
        yw])/64 - (9*G[{1}, yv^(-1)]*G[{1/(yu*yv)}, yw]*
       G[{yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/64 - 
     (G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/
      16 + (9*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*
       G[{yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/64 + 
     (G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{yu^(-1), 1/(yu*yv), 1/(yu*yv)}, 
        yw])/16 - (3*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*
       G[{yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/64 - 
     (G[{0, 1}, yv^(-1)]*G[{yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/64 - 
     (15*G[{0, 1}, yw]*G[{yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/64 + 
     (15*G[{0, yu^(-1)}, yw]*G[{yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/64 + 
     (G[{0, yu}, yv^(-1)]*G[{yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/64 + 
     (15*G[{0, yv^(-1)}, yw]*G[{yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/64 - 
     (15*G[{0, 1/(yu*yv)}, yw]*G[{yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/64 - 
     (G[{1, yu^(-1)}, yw]*G[{yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/4 - 
     (G[{1, yu}, yv^(-1)]*G[{yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/64 - 
     (15*G[{1, yv^(-1)}, yw]*G[{yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/64 + 
     (G[{1, 1/(yu*yv)}, yw]*G[{yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/64 + 
     (7*G[{yu^(-1), 1/(yu*yv)}, yw]*G[{yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/
      32 + (3*G[{yv^(-1), 1/(yu*yv)}, yw]*G[{yu^(-1), 1/(yu*yv), 1/(yu*yv)}, 
        yw])/64 + (Pi^2*G[{yv^(-1), yv^(-1), 1/(yu*yv)}, yw])/32 + 
     (G[{1}, yu^(-1)]^2*G[{yv^(-1), yv^(-1), 1/(yu*yv)}, yw])/16 - 
     (G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*G[{yv^(-1), yv^(-1), 1/(yu*yv)}, yw])/
      8 + (5*G[{1}, yv^(-1)]^2*G[{yv^(-1), yv^(-1), 1/(yu*yv)}, yw])/32 + 
     (G[{0}, yu^(-1)]*G[{1}, yw]*G[{yv^(-1), yv^(-1), 1/(yu*yv)}, yw])/8 + 
     (G[{0}, yv^(-1)]*G[{1}, yw]*G[{yv^(-1), yv^(-1), 1/(yu*yv)}, yw])/8 - 
     (G[{0}, yw]*G[{1}, yw]*G[{yv^(-1), yv^(-1), 1/(yu*yv)}, yw])/8 - 
     (G[{1}, yu^(-1)]*G[{1}, yw]*G[{yv^(-1), yv^(-1), 1/(yu*yv)}, yw])/4 - 
     (G[{1}, yv^(-1)]*G[{1}, yw]*G[{yv^(-1), yv^(-1), 1/(yu*yv)}, yw])/16 - 
     (G[{1}, yw]^2*G[{yv^(-1), yv^(-1), 1/(yu*yv)}, yw])/32 - 
     (G[{0}, yu^(-1)]*G[{yu^(-1)}, yw]*G[{yv^(-1), yv^(-1), 1/(yu*yv)}, yw])/
      8 - (G[{0}, yv^(-1)]*G[{yu^(-1)}, yw]*G[{yv^(-1), yv^(-1), 1/(yu*yv)}, 
        yw])/8 + (G[{0}, yw]*G[{yu^(-1)}, yw]*
       G[{yv^(-1), yv^(-1), 1/(yu*yv)}, yw])/8 + 
     (3*G[{1}, yu^(-1)]*G[{yu^(-1)}, yw]*G[{yv^(-1), yv^(-1), 1/(yu*yv)}, 
        yw])/8 - (G[{1}, yv^(-1)]*G[{yu^(-1)}, yw]*
       G[{yv^(-1), yv^(-1), 1/(yu*yv)}, yw])/8 + 
     (G[{yu^(-1)}, yw]^2*G[{yv^(-1), yv^(-1), 1/(yu*yv)}, yw])/16 + 
     (G[{1}, yw]*G[{yu}, yv^(-1)]*G[{yv^(-1), yv^(-1), 1/(yu*yv)}, yw])/16 - 
     (G[{0}, yu^(-1)]*G[{yv^(-1)}, yw]*G[{yv^(-1), yv^(-1), 1/(yu*yv)}, yw])/
      8 - (G[{0}, yv^(-1)]*G[{yv^(-1)}, yw]*G[{yv^(-1), yv^(-1), 1/(yu*yv)}, 
        yw])/8 + (G[{0}, yw]*G[{yv^(-1)}, yw]*
       G[{yv^(-1), yv^(-1), 1/(yu*yv)}, yw])/8 - 
     (G[{1}, yu^(-1)]*G[{yv^(-1)}, yw]*G[{yv^(-1), yv^(-1), 1/(yu*yv)}, yw])/
      8 + (3*G[{1}, yv^(-1)]*G[{yv^(-1)}, yw]*
       G[{yv^(-1), yv^(-1), 1/(yu*yv)}, yw])/8 - 
     (3*G[{yu^(-1)}, yw]*G[{yv^(-1)}, yw]*G[{yv^(-1), yv^(-1), 1/(yu*yv)}, 
        yw])/8 + (G[{yv^(-1)}, yw]^2*G[{yv^(-1), yv^(-1), 1/(yu*yv)}, yw])/
      16 + (G[{0}, yu^(-1)]*G[{1/(yu*yv)}, yw]*
       G[{yv^(-1), yv^(-1), 1/(yu*yv)}, yw])/16 + 
     (G[{0}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{yv^(-1), yv^(-1), 1/(yu*yv)}, 
        yw])/16 - (G[{0}, yw]*G[{1/(yu*yv)}, yw]*
       G[{yv^(-1), yv^(-1), 1/(yu*yv)}, yw])/16 - 
     (G[{1}, yu^(-1)]*G[{1/(yu*yv)}, yw]*G[{yv^(-1), yv^(-1), 1/(yu*yv)}, 
        yw])/16 + (G[{1}, yw]*G[{1/(yu*yv)}, yw]*
       G[{yv^(-1), yv^(-1), 1/(yu*yv)}, yw])/16 - 
     (G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{yv^(-1), yv^(-1), 1/(yu*yv)}, 
        yw])/16 + (G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*
       G[{yv^(-1), yv^(-1), 1/(yu*yv)}, yw])/16 + 
     (G[{0, 1}, yu^(-1)]*G[{yv^(-1), yv^(-1), 1/(yu*yv)}, yw])/8 - 
     (G[{0, 1}, yv^(-1)]*G[{yv^(-1), yv^(-1), 1/(yu*yv)}, yw])/16 + 
     (G[{0, 1}, yw]*G[{yv^(-1), yv^(-1), 1/(yu*yv)}, yw])/8 - 
     (G[{0, yu^(-1)}, yw]*G[{yv^(-1), yv^(-1), 1/(yu*yv)}, yw])/8 + 
     (G[{0, yu}, yv^(-1)]*G[{yv^(-1), yv^(-1), 1/(yu*yv)}, yw])/16 - 
     (G[{0, yv^(-1)}, yw]*G[{yv^(-1), yv^(-1), 1/(yu*yv)}, yw])/8 + 
     (G[{0, 1/(yu*yv)}, yw]*G[{yv^(-1), yv^(-1), 1/(yu*yv)}, yw])/8 + 
     (G[{1, yu^(-1)}, yw]*G[{yv^(-1), yv^(-1), 1/(yu*yv)}, yw])/16 - 
     (3*G[{1, yu}, yv^(-1)]*G[{yv^(-1), yv^(-1), 1/(yu*yv)}, yw])/16 + 
     (G[{1, yv^(-1)}, yw]*G[{yv^(-1), yv^(-1), 1/(yu*yv)}, yw])/4 - 
     (G[{1, 1/(yu*yv)}, yw]*G[{yv^(-1), yv^(-1), 1/(yu*yv)}, yw])/16 - 
     (3*G[{yu^(-1), 1/(yu*yv)}, yw]*G[{yv^(-1), yv^(-1), 1/(yu*yv)}, yw])/
      16 - (G[{yv^(-1), 1/(yu*yv)}, yw]*G[{yv^(-1), yv^(-1), 1/(yu*yv)}, yw])/
      16 + (Pi^2*G[{yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/96 + 
     (G[{0}, yu^(-1)]*G[{1}, yu^(-1)]*G[{yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/
      16 + (G[{0}, yv^(-1)]*G[{1}, yu^(-1)]*
       G[{yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/16 - 
     (G[{0}, yw]*G[{1}, yu^(-1)]*G[{yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/16 - 
     (G[{1}, yu^(-1)]^2*G[{yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/32 - 
     (G[{0}, yu^(-1)]*G[{1}, yv^(-1)]*G[{yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/
      16 - (G[{0}, yv^(-1)]*G[{1}, yv^(-1)]*
       G[{yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/16 + 
     (G[{0}, yw]*G[{1}, yv^(-1)]*G[{yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/16 - 
     (G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*G[{yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/
      16 - (G[{1}, yu^(-1)]*G[{1}, yw]*G[{yv^(-1), 1/(yu*yv), 1/(yu*yv)}, 
        yw])/8 - (5*G[{1}, yv^(-1)]*G[{1}, yw]*
       G[{yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/16 - 
     (7*G[{1}, yw]^2*G[{yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/32 + 
     (G[{0}, yu^(-1)]*G[{yu^(-1)}, yw]*G[{yv^(-1), 1/(yu*yv), 1/(yu*yv)}, 
        yw])/16 + (G[{0}, yv^(-1)]*G[{yu^(-1)}, yw]*
       G[{yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/16 - 
     (G[{0}, yw]*G[{yu^(-1)}, yw]*G[{yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/
      16 + (3*G[{1}, yu^(-1)]*G[{yu^(-1)}, yw]*
       G[{yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/16 - 
     (G[{1}, yv^(-1)]*G[{yu^(-1)}, yw]*G[{yv^(-1), 1/(yu*yv), 1/(yu*yv)}, 
        yw])/16 + (G[{1}, yw]*G[{yu^(-1)}, yw]*
       G[{yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/4 + 
     (G[{yu^(-1)}, yw]^2*G[{yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/32 + 
     (G[{1}, yv^(-1)]*G[{yu}, yv^(-1)]*G[{yv^(-1), 1/(yu*yv), 1/(yu*yv)}, 
        yw])/4 + (7*G[{1}, yw]*G[{yu}, yv^(-1)]*
       G[{yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/16 - 
     (G[{yu^(-1)}, yw]*G[{yu}, yv^(-1)]*G[{yv^(-1), 1/(yu*yv), 1/(yu*yv)}, 
        yw])/4 - (G[{yu}, yv^(-1)]^2*G[{yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/
      8 - (G[{0}, yu^(-1)]*G[{yv^(-1)}, yw]*
       G[{yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/16 - 
     (G[{0}, yv^(-1)]*G[{yv^(-1)}, yw]*G[{yv^(-1), 1/(yu*yv), 1/(yu*yv)}, 
        yw])/16 + (G[{0}, yw]*G[{yv^(-1)}, yw]*
       G[{yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/16 - 
     (G[{1}, yu^(-1)]*G[{yv^(-1)}, yw]*G[{yv^(-1), 1/(yu*yv), 1/(yu*yv)}, 
        yw])/16 + (3*G[{1}, yv^(-1)]*G[{yv^(-1)}, yw]*
       G[{yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/16 - 
     (3*G[{yu^(-1)}, yw]*G[{yv^(-1)}, yw]*G[{yv^(-1), 1/(yu*yv), 1/(yu*yv)}, 
        yw])/16 + (G[{yv^(-1)}, yw]^2*G[{yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/
      32 + (G[{0}, yu^(-1)]*G[{1/(yu*yv)}, yw]*
       G[{yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/16 + 
     (G[{0}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{yv^(-1), 1/(yu*yv), 1/(yu*yv)}, 
        yw])/16 - (G[{0}, yw]*G[{1/(yu*yv)}, yw]*
       G[{yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/16 - 
     (G[{1}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{yv^(-1), 1/(yu*yv), 1/(yu*yv)}, 
        yw])/8 + (G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*
       G[{yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/8 + 
     (G[{0, 1}, yu^(-1)]*G[{yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/8 + 
     (G[{0, 1}, yv^(-1)]*G[{yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/16 - 
     (G[{0, yu}, yv^(-1)]*G[{yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/16 + 
     (G[{1, yu^(-1)}, yw]*G[{yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/16 - 
     (G[{1, yu}, yv^(-1)]*G[{yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/16 + 
     (G[{1, yv^(-1)}, yw]*G[{yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/8 - 
     (3*G[{1, 1/(yu*yv)}, yw]*G[{yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/16 + 
     (G[{yu^(-1), 1/(yu*yv)}, yw]*G[{yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/
      16 + (G[{yv^(-1), 1/(yu*yv)}, yw]*G[{yv^(-1), 1/(yu*yv), 1/(yu*yv)}, 
        yw])/8 + (G[{1}, yu^(-1)]*G[{0, 0, 1, 1}, yu^(-1)])/8 - 
     (G[{1}, yw]*G[{0, 0, 1, 1}, yu^(-1)])/8 + 
     (G[{0}, yu^(-1)]*G[{0, 0, 1, 1}, yv^(-1)])/8 + 
     (G[{0}, yv^(-1)]*G[{0, 0, 1, 1}, yv^(-1)])/8 - 
     (G[{0}, yw]*G[{0, 0, 1, 1}, yv^(-1)])/8 + 
     (G[{1}, yu^(-1)]*G[{0, 0, 1, 1}, yv^(-1)])/16 - 
     (3*G[{1}, yv^(-1)]*G[{0, 0, 1, 1}, yv^(-1)])/32 + 
     (G[{1}, yw]*G[{0, 0, 1, 1}, yv^(-1)])/32 + 
     (3*G[{1/(yu*yv)}, yw]*G[{0, 0, 1, 1}, yv^(-1)])/32 - 
     (G[{0}, yu^(-1)]*G[{0, 0, 1, 1}, yw])/16 - 
     (G[{0}, yv^(-1)]*G[{0, 0, 1, 1}, yw])/16 + 
     (G[{0}, yw]*G[{0, 0, 1, 1}, yw])/16 + 
     (G[{1}, yu^(-1)]*G[{0, 0, 1, 1}, yw])/16 + 
     (G[{1}, yv^(-1)]*G[{0, 0, 1, 1}, yw])/16 + 
     (G[{1}, yw]*G[{0, 0, 1, 1}, yw])/8 - 
     (G[{1/(yu*yv)}, yw]*G[{0, 0, 1, 1}, yw])/8 + 
     (G[{0}, yu^(-1)]*G[{0, 0, 1, yu^(-1)}, yw])/16 + 
     (G[{0}, yv^(-1)]*G[{0, 0, 1, yu^(-1)}, yw])/16 - 
     (G[{0}, yw]*G[{0, 0, 1, yu^(-1)}, yw])/16 - 
     (G[{1}, yu^(-1)]*G[{0, 0, 1, yu^(-1)}, yw])/16 - 
     (G[{1}, yv^(-1)]*G[{0, 0, 1, yu^(-1)}, yw])/16 - 
     (G[{1}, yw]*G[{0, 0, 1, yu^(-1)}, yw])/8 + 
     (G[{1/(yu*yv)}, yw]*G[{0, 0, 1, yu^(-1)}, yw])/8 - 
     (3*G[{0}, yu^(-1)]*G[{0, 0, 1, yu}, yv^(-1)])/16 - 
     (3*G[{0}, yv^(-1)]*G[{0, 0, 1, yu}, yv^(-1)])/16 + 
     (3*G[{0}, yw]*G[{0, 0, 1, yu}, yv^(-1)])/16 + 
     (3*G[{1}, yv^(-1)]*G[{0, 0, 1, yu}, yv^(-1)])/32 - 
     (5*G[{1}, yw]*G[{0, 0, 1, yu}, yv^(-1)])/32 - 
     (3*G[{1/(yu*yv)}, yw]*G[{0, 0, 1, yu}, yv^(-1)])/32 - 
     (G[{0}, yu^(-1)]*G[{0, 0, 1, yv^(-1)}, yw])/16 - 
     (G[{0}, yv^(-1)]*G[{0, 0, 1, yv^(-1)}, yw])/16 + 
     (G[{0}, yw]*G[{0, 0, 1, yv^(-1)}, yw])/16 + 
     (G[{1}, yu^(-1)]*G[{0, 0, 1, yv^(-1)}, yw])/16 + 
     (G[{1}, yv^(-1)]*G[{0, 0, 1, yv^(-1)}, yw])/16 - 
     (G[{1}, yw]*G[{0, 0, 1, yv^(-1)}, yw])/8 + 
     (G[{1/(yu*yv)}, yw]*G[{0, 0, 1, yv^(-1)}, yw])/8 + 
     (G[{0}, yu^(-1)]*G[{0, 0, 1, 1/(yu*yv)}, yw])/16 + 
     (G[{0}, yv^(-1)]*G[{0, 0, 1, 1/(yu*yv)}, yw])/16 - 
     (G[{0}, yw]*G[{0, 0, 1, 1/(yu*yv)}, yw])/16 + 
     (G[{1}, yu^(-1)]*G[{0, 0, 1, 1/(yu*yv)}, yw])/16 - 
     (3*G[{1}, yv^(-1)]*G[{0, 0, 1, 1/(yu*yv)}, yw])/16 + 
     (G[{0}, yu^(-1)]*G[{0, 0, yu^(-1), 1}, yw])/16 + 
     (G[{0}, yv^(-1)]*G[{0, 0, yu^(-1), 1}, yw])/16 - 
     (G[{0}, yw]*G[{0, 0, yu^(-1), 1}, yw])/16 - 
     (G[{1}, yu^(-1)]*G[{0, 0, yu^(-1), 1}, yw])/16 + 
     (3*G[{1}, yv^(-1)]*G[{0, 0, yu^(-1), 1}, yw])/16 - 
     (G[{yu}, yv^(-1)]*G[{0, 0, yu^(-1), 1}, yw])/4 - 
     (G[{0}, yu^(-1)]*G[{0, 0, yu^(-1), yu^(-1)}, yw])/16 - 
     (G[{0}, yv^(-1)]*G[{0, 0, yu^(-1), yu^(-1)}, yw])/16 + 
     (G[{0}, yw]*G[{0, 0, yu^(-1), yu^(-1)}, yw])/16 + 
     (G[{1}, yu^(-1)]*G[{0, 0, yu^(-1), yu^(-1)}, yw])/16 + 
     (G[{1}, yv^(-1)]*G[{0, 0, yu^(-1), yu^(-1)}, yw])/16 + 
     (G[{1}, yw]*G[{0, 0, yu^(-1), yu^(-1)}, yw])/8 + 
     (G[{0}, yu^(-1)]*G[{0, 0, yu^(-1), yv^(-1)}, yw])/16 + 
     (G[{0}, yv^(-1)]*G[{0, 0, yu^(-1), yv^(-1)}, yw])/16 - 
     (G[{0}, yw]*G[{0, 0, yu^(-1), yv^(-1)}, yw])/16 - 
     (3*G[{1}, yu^(-1)]*G[{0, 0, yu^(-1), yv^(-1)}, yw])/16 + 
     (G[{1}, yv^(-1)]*G[{0, 0, yu^(-1), yv^(-1)}, yw])/16 + 
     (G[{1}, yw]*G[{0, 0, yu^(-1), yv^(-1)}, yw])/4 - 
     (G[{1/(yu*yv)}, yw]*G[{0, 0, yu^(-1), yv^(-1)}, yw])/8 - 
     (G[{0}, yu^(-1)]*G[{0, 0, yu^(-1), 1/(yu*yv)}, yw])/16 - 
     (G[{0}, yv^(-1)]*G[{0, 0, yu^(-1), 1/(yu*yv)}, yw])/16 + 
     (G[{0}, yw]*G[{0, 0, yu^(-1), 1/(yu*yv)}, yw])/16 + 
     (G[{1}, yu^(-1)]*G[{0, 0, yu^(-1), 1/(yu*yv)}, yw])/16 + 
     (G[{1}, yv^(-1)]*G[{0, 0, yu^(-1), 1/(yu*yv)}, yw])/16 - 
     (G[{1}, yw]*G[{0, 0, yu^(-1), 1/(yu*yv)}, yw])/8 - 
     (3*G[{0}, yu^(-1)]*G[{0, 0, yu, 1}, yv^(-1)])/16 - 
     (3*G[{0}, yv^(-1)]*G[{0, 0, yu, 1}, yv^(-1)])/16 + 
     (3*G[{0}, yw]*G[{0, 0, yu, 1}, yv^(-1)])/16 - 
     (G[{1}, yu^(-1)]*G[{0, 0, yu, 1}, yv^(-1)])/16 + 
     (3*G[{1}, yv^(-1)]*G[{0, 0, yu, 1}, yv^(-1)])/32 - 
     (5*G[{1}, yw]*G[{0, 0, yu, 1}, yv^(-1)])/32 - 
     (3*G[{1/(yu*yv)}, yw]*G[{0, 0, yu, 1}, yv^(-1)])/32 + 
     (G[{0}, yu^(-1)]*G[{0, 0, yu, yu}, yv^(-1)])/4 + 
     (G[{0}, yv^(-1)]*G[{0, 0, yu, yu}, yv^(-1)])/4 - 
     (G[{0}, yw]*G[{0, 0, yu, yu}, yv^(-1)])/4 - 
     (3*G[{1}, yv^(-1)]*G[{0, 0, yu, yu}, yv^(-1)])/32 + 
     (5*G[{1}, yw]*G[{0, 0, yu, yu}, yv^(-1)])/32 + 
     (3*G[{1/(yu*yv)}, yw]*G[{0, 0, yu, yu}, yv^(-1)])/32 - 
     (G[{0}, yu^(-1)]*G[{0, 0, yv^(-1), 1}, yw])/16 - 
     (G[{0}, yv^(-1)]*G[{0, 0, yv^(-1), 1}, yw])/16 + 
     (G[{0}, yw]*G[{0, 0, yv^(-1), 1}, yw])/16 - 
     (G[{1}, yu^(-1)]*G[{0, 0, yv^(-1), 1}, yw])/16 + 
     (3*G[{1}, yv^(-1)]*G[{0, 0, yv^(-1), 1}, yw])/16 + 
     (G[{0}, yu^(-1)]*G[{0, 0, yv^(-1), yu^(-1)}, yw])/16 + 
     (G[{0}, yv^(-1)]*G[{0, 0, yv^(-1), yu^(-1)}, yw])/16 - 
     (G[{0}, yw]*G[{0, 0, yv^(-1), yu^(-1)}, yw])/16 - 
     (3*G[{1}, yu^(-1)]*G[{0, 0, yv^(-1), yu^(-1)}, yw])/16 + 
     (G[{1}, yv^(-1)]*G[{0, 0, yv^(-1), yu^(-1)}, yw])/16 + 
     (G[{1}, yw]*G[{0, 0, yv^(-1), yu^(-1)}, yw])/4 - 
     (G[{1/(yu*yv)}, yw]*G[{0, 0, yv^(-1), yu^(-1)}, yw])/8 + 
     (G[{0}, yu^(-1)]*G[{0, 0, yv^(-1), yv^(-1)}, yw])/16 + 
     (G[{0}, yv^(-1)]*G[{0, 0, yv^(-1), yv^(-1)}, yw])/16 - 
     (G[{0}, yw]*G[{0, 0, yv^(-1), yv^(-1)}, yw])/16 + 
     (G[{1}, yu^(-1)]*G[{0, 0, yv^(-1), yv^(-1)}, yw])/16 - 
     (3*G[{1}, yv^(-1)]*G[{0, 0, yv^(-1), yv^(-1)}, yw])/16 - 
     (G[{1}, yw]*G[{0, 0, yv^(-1), yv^(-1)}, yw])/8 - 
     (G[{0}, yu^(-1)]*G[{0, 0, yv^(-1), 1/(yu*yv)}, yw])/16 - 
     (G[{0}, yv^(-1)]*G[{0, 0, yv^(-1), 1/(yu*yv)}, yw])/16 + 
     (G[{0}, yw]*G[{0, 0, yv^(-1), 1/(yu*yv)}, yw])/16 - 
     (G[{1}, yu^(-1)]*G[{0, 0, yv^(-1), 1/(yu*yv)}, yw])/16 + 
     (3*G[{1}, yv^(-1)]*G[{0, 0, yv^(-1), 1/(yu*yv)}, yw])/16 + 
     (G[{1}, yw]*G[{0, 0, yv^(-1), 1/(yu*yv)}, yw])/8 + 
     (G[{0}, yu^(-1)]*G[{0, 0, 1/(yu*yv), 1}, yw])/16 + 
     (G[{0}, yv^(-1)]*G[{0, 0, 1/(yu*yv), 1}, yw])/16 - 
     (G[{0}, yw]*G[{0, 0, 1/(yu*yv), 1}, yw])/16 + 
     (G[{1}, yu^(-1)]*G[{0, 0, 1/(yu*yv), 1}, yw])/16 - 
     (7*G[{1}, yv^(-1)]*G[{0, 0, 1/(yu*yv), 1}, yw])/16 - 
     (G[{1}, yw]*G[{0, 0, 1/(yu*yv), 1}, yw])/8 + 
     (G[{yu}, yv^(-1)]*G[{0, 0, 1/(yu*yv), 1}, yw])/4 + 
     (G[{1/(yu*yv)}, yw]*G[{0, 0, 1/(yu*yv), 1}, yw])/8 - 
     (G[{0}, yu^(-1)]*G[{0, 0, 1/(yu*yv), yu^(-1)}, yw])/16 - 
     (G[{0}, yv^(-1)]*G[{0, 0, 1/(yu*yv), yu^(-1)}, yw])/16 + 
     (G[{0}, yw]*G[{0, 0, 1/(yu*yv), yu^(-1)}, yw])/16 + 
     (3*G[{1}, yu^(-1)]*G[{0, 0, 1/(yu*yv), yu^(-1)}, yw])/16 + 
     (3*G[{1}, yv^(-1)]*G[{0, 0, 1/(yu*yv), yu^(-1)}, yw])/16 - 
     (G[{1}, yw]*G[{0, 0, 1/(yu*yv), yu^(-1)}, yw])/8 - 
     (G[{yu}, yv^(-1)]*G[{0, 0, 1/(yu*yv), yu^(-1)}, yw])/4 - 
     (G[{0}, yu^(-1)]*G[{0, 0, 1/(yu*yv), yv^(-1)}, yw])/16 - 
     (G[{0}, yv^(-1)]*G[{0, 0, 1/(yu*yv), yv^(-1)}, yw])/16 + 
     (G[{0}, yw]*G[{0, 0, 1/(yu*yv), yv^(-1)}, yw])/16 - 
     (G[{1}, yu^(-1)]*G[{0, 0, 1/(yu*yv), yv^(-1)}, yw])/16 + 
     (3*G[{1}, yv^(-1)]*G[{0, 0, 1/(yu*yv), yv^(-1)}, yw])/16 + 
     (G[{1}, yw]*G[{0, 0, 1/(yu*yv), yv^(-1)}, yw])/8 + 
     (G[{0}, yu^(-1)]*G[{0, 0, 1/(yu*yv), 1/(yu*yv)}, yw])/16 + 
     (G[{0}, yv^(-1)]*G[{0, 0, 1/(yu*yv), 1/(yu*yv)}, yw])/16 - 
     (G[{0}, yw]*G[{0, 0, 1/(yu*yv), 1/(yu*yv)}, yw])/16 - 
     (G[{1}, yu^(-1)]*G[{0, 0, 1/(yu*yv), 1/(yu*yv)}, yw])/16 - 
     (G[{1}, yv^(-1)]*G[{0, 0, 1/(yu*yv), 1/(yu*yv)}, yw])/16 + 
     (G[{1}, yv^(-1)]*G[{0, 1, 0, yu^(-1)}, yw])/8 + 
     (G[{1}, yw]*G[{0, 1, 0, yu^(-1)}, yw])/16 - 
     (G[{yu}, yv^(-1)]*G[{0, 1, 0, yu^(-1)}, yw])/8 - 
     (G[{1}, yw]*G[{0, 1, 0, yu}, yv^(-1)])/16 - 
     (G[{0}, yu^(-1)]*G[{0, 1, 0, yv^(-1)}, yw])/16 - 
     (G[{0}, yv^(-1)]*G[{0, 1, 0, yv^(-1)}, yw])/16 + 
     (G[{0}, yw]*G[{0, 1, 0, yv^(-1)}, yw])/16 + 
     (G[{1}, yu^(-1)]*G[{0, 1, 0, yv^(-1)}, yw])/16 + 
     (G[{1}, yv^(-1)]*G[{0, 1, 0, yv^(-1)}, yw])/16 - 
     (G[{1}, yw]*G[{0, 1, 0, yv^(-1)}, yw])/16 + 
     (G[{0}, yu^(-1)]*G[{0, 1, 0, 1/(yu*yv)}, yw])/16 + 
     (G[{0}, yv^(-1)]*G[{0, 1, 0, 1/(yu*yv)}, yw])/16 - 
     (G[{0}, yw]*G[{0, 1, 0, 1/(yu*yv)}, yw])/16 - 
     (G[{1}, yu^(-1)]*G[{0, 1, 0, 1/(yu*yv)}, yw])/16 - 
     (3*G[{1}, yv^(-1)]*G[{0, 1, 0, 1/(yu*yv)}, yw])/16 + 
     (G[{yu}, yv^(-1)]*G[{0, 1, 0, 1/(yu*yv)}, yw])/8 + 
     (3*G[{1}, yu^(-1)]*G[{0, 1, 1, 1}, yu^(-1)])/16 - 
     (3*G[{1}, yw]*G[{0, 1, 1, 1}, yu^(-1)])/16 + 
     (3*G[{0}, yu^(-1)]*G[{0, 1, 1, 1}, yv^(-1)])/16 + 
     (3*G[{0}, yv^(-1)]*G[{0, 1, 1, 1}, yv^(-1)])/16 - 
     (3*G[{0}, yw]*G[{0, 1, 1, 1}, yv^(-1)])/16 - 
     (G[{1}, yu^(-1)]*G[{0, 1, 1, 1}, yv^(-1)])/8 - 
     (9*G[{1}, yv^(-1)]*G[{0, 1, 1, 1}, yv^(-1)])/64 + 
     (3*G[{1}, yw]*G[{0, 1, 1, 1}, yv^(-1)])/64 + 
     (9*G[{1/(yu*yv)}, yw]*G[{0, 1, 1, 1}, yv^(-1)])/64 - 
     (3*G[{0}, yu^(-1)]*G[{0, 1, 1, 1}, yw])/16 - 
     (3*G[{0}, yv^(-1)]*G[{0, 1, 1, 1}, yw])/16 + 
     (3*G[{0}, yw]*G[{0, 1, 1, 1}, yw])/16 + 
     (3*G[{1}, yu^(-1)]*G[{0, 1, 1, 1}, yw])/16 + 
     (G[{1}, yv^(-1)]*G[{0, 1, 1, 1}, yw])/8 + 
     (G[{1}, yw]*G[{0, 1, 1, 1}, yw])/8 + 
     (G[{yu}, yv^(-1)]*G[{0, 1, 1, 1}, yw])/16 - 
     (G[{1/(yu*yv)}, yw]*G[{0, 1, 1, 1}, yw])/8 + 
     (G[{0}, yu^(-1)]*G[{0, 1, 1, yu^(-1)}, yw])/16 + 
     (G[{0}, yv^(-1)]*G[{0, 1, 1, yu^(-1)}, yw])/16 - 
     (G[{0}, yw]*G[{0, 1, 1, yu^(-1)}, yw])/16 - 
     (G[{1}, yu^(-1)]*G[{0, 1, 1, yu^(-1)}, yw])/16 - 
     (3*G[{1}, yv^(-1)]*G[{0, 1, 1, yu^(-1)}, yw])/16 - 
     (G[{1}, yw]*G[{0, 1, 1, yu^(-1)}, yw])/16 + 
     (G[{yu}, yv^(-1)]*G[{0, 1, 1, yu^(-1)}, yw])/8 + 
     (G[{0}, yu^(-1)]*G[{0, 1, 1, yu}, yv^(-1)])/16 + 
     (G[{0}, yv^(-1)]*G[{0, 1, 1, yu}, yv^(-1)])/16 - 
     (G[{0}, yw]*G[{0, 1, 1, yu}, yv^(-1)])/16 - 
     (5*G[{1}, yv^(-1)]*G[{0, 1, 1, yu}, yv^(-1)])/64 + 
     (11*G[{1}, yw]*G[{0, 1, 1, yu}, yv^(-1)])/64 + 
     (5*G[{1/(yu*yv)}, yw]*G[{0, 1, 1, yu}, yv^(-1)])/64 + 
     (G[{0}, yu^(-1)]*G[{0, 1, 1, yv^(-1)}, yw])/8 + 
     (G[{0}, yv^(-1)]*G[{0, 1, 1, yv^(-1)}, yw])/8 - 
     (G[{0}, yw]*G[{0, 1, 1, yv^(-1)}, yw])/8 - 
     (3*G[{1}, yu^(-1)]*G[{0, 1, 1, yv^(-1)}, yw])/16 - 
     (G[{1}, yv^(-1)]*G[{0, 1, 1, yv^(-1)}, yw])/16 + 
     (G[{1}, yw]*G[{0, 1, 1, yv^(-1)}, yw])/16 + 
     (G[{1}, yu^(-1)]*G[{0, 1, 1, 1/(yu*yv)}, yw])/4 + 
     (G[{1}, yv^(-1)]*G[{0, 1, 1, 1/(yu*yv)}, yw])/16 - 
     (5*G[{yu}, yv^(-1)]*G[{0, 1, 1, 1/(yu*yv)}, yw])/16 + 
     (G[{0}, yu^(-1)]*G[{0, 1, yu^(-1), 1}, yw])/16 + 
     (G[{0}, yv^(-1)]*G[{0, 1, yu^(-1), 1}, yw])/16 - 
     (G[{0}, yw]*G[{0, 1, yu^(-1), 1}, yw])/16 - 
     (G[{1}, yu^(-1)]*G[{0, 1, yu^(-1), 1}, yw])/16 - 
     (3*G[{1}, yv^(-1)]*G[{0, 1, yu^(-1), 1}, yw])/16 + 
     (G[{yu}, yv^(-1)]*G[{0, 1, yu^(-1), 1}, yw])/8 + 
     (G[{0}, yu^(-1)]*G[{0, 1, yu^(-1), yu^(-1)}, yw])/8 + 
     (G[{0}, yv^(-1)]*G[{0, 1, yu^(-1), yu^(-1)}, yw])/8 - 
     (G[{0}, yw]*G[{0, 1, yu^(-1), yu^(-1)}, yw])/8 - 
     (G[{1}, yu^(-1)]*G[{0, 1, yu^(-1), yu^(-1)}, yw])/8 - 
     (G[{1}, yv^(-1)]*G[{0, 1, yu^(-1), yu^(-1)}, yw])/8 - 
     (G[{1}, yw]*G[{0, 1, yu^(-1), yu^(-1)}, yw])/4 + 
     (G[{1/(yu*yv)}, yw]*G[{0, 1, yu^(-1), yu^(-1)}, yw])/8 + 
     (G[{1}, yu^(-1)]*G[{0, 1, yu^(-1), yv^(-1)}, yw])/8 - 
     (G[{1}, yv^(-1)]*G[{0, 1, yu^(-1), yv^(-1)}, yw])/8 - 
     (G[{1}, yw]*G[{0, 1, yu^(-1), yv^(-1)}, yw])/8 + 
     (G[{1/(yu*yv)}, yw]*G[{0, 1, yu^(-1), yv^(-1)}, yw])/8 - 
     (G[{0}, yu^(-1)]*G[{0, 1, yu^(-1), 1/(yu*yv)}, yw])/8 - 
     (G[{0}, yv^(-1)]*G[{0, 1, yu^(-1), 1/(yu*yv)}, yw])/8 + 
     (G[{0}, yw]*G[{0, 1, yu^(-1), 1/(yu*yv)}, yw])/8 - 
     (G[{1}, yu^(-1)]*G[{0, 1, yu^(-1), 1/(yu*yv)}, yw])/16 + 
     (3*G[{1}, yv^(-1)]*G[{0, 1, yu^(-1), 1/(yu*yv)}, yw])/16 + 
     (G[{yu}, yv^(-1)]*G[{0, 1, yu^(-1), 1/(yu*yv)}, yw])/8 + 
     (G[{0}, yu^(-1)]*G[{0, 1, yu, 1}, yv^(-1)])/16 + 
     (G[{0}, yv^(-1)]*G[{0, 1, yu, 1}, yv^(-1)])/16 - 
     (G[{0}, yw]*G[{0, 1, yu, 1}, yv^(-1)])/16 + 
     (3*G[{1}, yu^(-1)]*G[{0, 1, yu, 1}, yv^(-1)])/16 - 
     (5*G[{1}, yv^(-1)]*G[{0, 1, yu, 1}, yv^(-1)])/64 + 
     (3*G[{1}, yw]*G[{0, 1, yu, 1}, yv^(-1)])/64 + 
     (5*G[{1/(yu*yv)}, yw]*G[{0, 1, yu, 1}, yv^(-1)])/64 - 
     (3*G[{0}, yu^(-1)]*G[{0, 1, yu, yu}, yv^(-1)])/8 - 
     (3*G[{0}, yv^(-1)]*G[{0, 1, yu, yu}, yv^(-1)])/8 + 
     (3*G[{0}, yw]*G[{0, 1, yu, yu}, yv^(-1)])/8 + 
     (11*G[{1}, yv^(-1)]*G[{0, 1, yu, yu}, yv^(-1)])/64 - 
     (21*G[{1}, yw]*G[{0, 1, yu, yu}, yv^(-1)])/64 - 
     (11*G[{1/(yu*yv)}, yw]*G[{0, 1, yu, yu}, yv^(-1)])/64 + 
     (G[{0}, yu^(-1)]*G[{0, 1, yv^(-1), 1}, yw])/8 + 
     (G[{0}, yv^(-1)]*G[{0, 1, yv^(-1), 1}, yw])/8 - 
     (G[{0}, yw]*G[{0, 1, yv^(-1), 1}, yw])/8 - 
     (G[{1}, yu^(-1)]*G[{0, 1, yv^(-1), 1}, yw])/8 - 
     (G[{1}, yv^(-1)]*G[{0, 1, yv^(-1), 1}, yw])/8 + 
     (G[{1}, yu^(-1)]*G[{0, 1, yv^(-1), yu^(-1)}, yw])/8 - 
     (G[{1}, yv^(-1)]*G[{0, 1, yv^(-1), yu^(-1)}, yw])/8 - 
     (G[{1}, yw]*G[{0, 1, yv^(-1), yu^(-1)}, yw])/8 + 
     (G[{1/(yu*yv)}, yw]*G[{0, 1, yv^(-1), yu^(-1)}, yw])/8 - 
     (G[{0}, yu^(-1)]*G[{0, 1, yv^(-1), yv^(-1)}, yw])/8 - 
     (G[{0}, yv^(-1)]*G[{0, 1, yv^(-1), yv^(-1)}, yw])/8 + 
     (G[{0}, yw]*G[{0, 1, yv^(-1), yv^(-1)}, yw])/8 + 
     (G[{1}, yu^(-1)]*G[{0, 1, yv^(-1), yv^(-1)}, yw])/8 + 
     (G[{1}, yv^(-1)]*G[{0, 1, yv^(-1), yv^(-1)}, yw])/8 + 
     (G[{1/(yu*yv)}, yw]*G[{0, 1, yv^(-1), yv^(-1)}, yw])/8 - 
     (G[{0}, yu^(-1)]*G[{0, 1, yv^(-1), 1/(yu*yv)}, yw])/16 - 
     (G[{0}, yv^(-1)]*G[{0, 1, yv^(-1), 1/(yu*yv)}, yw])/16 + 
     (G[{0}, yw]*G[{0, 1, yv^(-1), 1/(yu*yv)}, yw])/16 + 
     (G[{1}, yv^(-1)]*G[{0, 1, yv^(-1), 1/(yu*yv)}, yw])/8 + 
     (3*G[{1}, yu^(-1)]*G[{0, 1, 1/(yu*yv), 1}, yw])/16 + 
     (G[{1}, yv^(-1)]*G[{0, 1, 1/(yu*yv), 1}, yw])/8 - 
     (5*G[{yu}, yv^(-1)]*G[{0, 1, 1/(yu*yv), 1}, yw])/16 - 
     (G[{0}, yu^(-1)]*G[{0, 1, 1/(yu*yv), yu^(-1)}, yw])/16 - 
     (G[{0}, yv^(-1)]*G[{0, 1, 1/(yu*yv), yu^(-1)}, yw])/16 + 
     (G[{0}, yw]*G[{0, 1, 1/(yu*yv), yu^(-1)}, yw])/16 - 
     (G[{1}, yu^(-1)]*G[{0, 1, 1/(yu*yv), yu^(-1)}, yw])/16 + 
     (G[{1}, yv^(-1)]*G[{0, 1, 1/(yu*yv), yu^(-1)}, yw])/16 - 
     (G[{1}, yw]*G[{0, 1, 1/(yu*yv), yu^(-1)}, yw])/16 + 
     (G[{yu}, yv^(-1)]*G[{0, 1, 1/(yu*yv), yu^(-1)}, yw])/8 + 
     (G[{1}, yu^(-1)]*G[{0, 1, 1/(yu*yv), yv^(-1)}, yw])/16 - 
     (G[{1}, yv^(-1)]*G[{0, 1, 1/(yu*yv), yv^(-1)}, yw])/16 + 
     (G[{1}, yw]*G[{0, 1, 1/(yu*yv), yv^(-1)}, yw])/16 + 
     (G[{0}, yu^(-1)]*G[{0, 1, 1/(yu*yv), 1/(yu*yv)}, yw])/16 + 
     (G[{0}, yv^(-1)]*G[{0, 1, 1/(yu*yv), 1/(yu*yv)}, yw])/16 - 
     (G[{0}, yw]*G[{0, 1, 1/(yu*yv), 1/(yu*yv)}, yw])/16 - 
     (3*G[{1}, yv^(-1)]*G[{0, 1, 1/(yu*yv), 1/(yu*yv)}, yw])/16 + 
     (G[{yu}, yv^(-1)]*G[{0, 1, 1/(yu*yv), 1/(yu*yv)}, yw])/16 + 
     (G[{0}, yu^(-1)]*G[{0, yu^(-1), 0, yv^(-1)}, yw])/16 + 
     (G[{0}, yv^(-1)]*G[{0, yu^(-1), 0, yv^(-1)}, yw])/16 - 
     (G[{0}, yw]*G[{0, yu^(-1), 0, yv^(-1)}, yw])/16 - 
     (G[{1}, yu^(-1)]*G[{0, yu^(-1), 0, yv^(-1)}, yw])/8 + 
     (G[{1}, yw]*G[{0, yu^(-1), 0, yv^(-1)}, yw])/8 - 
     (G[{0}, yu^(-1)]*G[{0, yu^(-1), 0, 1/(yu*yv)}, yw])/16 - 
     (G[{0}, yv^(-1)]*G[{0, yu^(-1), 0, 1/(yu*yv)}, yw])/16 + 
     (G[{0}, yw]*G[{0, yu^(-1), 0, 1/(yu*yv)}, yw])/16 + 
     (G[{1}, yu^(-1)]*G[{0, yu^(-1), 0, 1/(yu*yv)}, yw])/8 + 
     (G[{1}, yv^(-1)]*G[{0, yu^(-1), 0, 1/(yu*yv)}, yw])/8 - 
     (G[{1}, yw]*G[{0, yu^(-1), 0, 1/(yu*yv)}, yw])/16 - 
     (G[{yu}, yv^(-1)]*G[{0, yu^(-1), 0, 1/(yu*yv)}, yw])/8 + 
     (3*G[{0}, yu^(-1)]*G[{0, yu^(-1), 1, 1}, yw])/16 + 
     (3*G[{0}, yv^(-1)]*G[{0, yu^(-1), 1, 1}, yw])/16 - 
     (3*G[{0}, yw]*G[{0, yu^(-1), 1, 1}, yw])/16 - 
     (3*G[{1}, yu^(-1)]*G[{0, yu^(-1), 1, 1}, yw])/16 - 
     (G[{1}, yv^(-1)]*G[{0, yu^(-1), 1, 1}, yw])/8 - 
     (G[{1}, yw]*G[{0, yu^(-1), 1, 1}, yw])/8 - 
     (G[{yu}, yv^(-1)]*G[{0, yu^(-1), 1, 1}, yw])/16 - 
     (G[{0}, yu^(-1)]*G[{0, yu^(-1), 1, yu^(-1)}, yw])/16 - 
     (G[{0}, yv^(-1)]*G[{0, yu^(-1), 1, yu^(-1)}, yw])/16 + 
     (G[{0}, yw]*G[{0, yu^(-1), 1, yu^(-1)}, yw])/16 + 
     (G[{1}, yu^(-1)]*G[{0, yu^(-1), 1, yu^(-1)}, yw])/16 + 
     (3*G[{1}, yv^(-1)]*G[{0, yu^(-1), 1, yu^(-1)}, yw])/16 + 
     (G[{1}, yw]*G[{0, yu^(-1), 1, yu^(-1)}, yw])/16 - 
     (G[{yu}, yv^(-1)]*G[{0, yu^(-1), 1, yu^(-1)}, yw])/8 - 
     (G[{0}, yu^(-1)]*G[{0, yu^(-1), 1, yv^(-1)}, yw])/16 - 
     (G[{0}, yv^(-1)]*G[{0, yu^(-1), 1, yv^(-1)}, yw])/16 + 
     (G[{0}, yw]*G[{0, yu^(-1), 1, yv^(-1)}, yw])/16 + 
     (G[{1}, yu^(-1)]*G[{0, yu^(-1), 1, yv^(-1)}, yw])/16 + 
     (G[{1}, yv^(-1)]*G[{0, yu^(-1), 1, yv^(-1)}, yw])/16 - 
     (G[{1}, yw]*G[{0, yu^(-1), 1, yv^(-1)}, yw])/16 - 
     (G[{1}, yu^(-1)]*G[{0, yu^(-1), 1, 1/(yu*yv)}, yw])/8 + 
     (G[{1}, yv^(-1)]*G[{0, yu^(-1), 1, 1/(yu*yv)}, yw])/16 + 
     (G[{yu}, yv^(-1)]*G[{0, yu^(-1), 1, 1/(yu*yv)}, yw])/16 - 
     (G[{0}, yu^(-1)]*G[{0, yu^(-1), yu^(-1), 1}, yw])/16 - 
     (G[{0}, yv^(-1)]*G[{0, yu^(-1), yu^(-1), 1}, yw])/16 + 
     (G[{0}, yw]*G[{0, yu^(-1), yu^(-1), 1}, yw])/16 + 
     (G[{1}, yu^(-1)]*G[{0, yu^(-1), yu^(-1), 1}, yw])/16 + 
     (3*G[{1}, yv^(-1)]*G[{0, yu^(-1), yu^(-1), 1}, yw])/16 - 
     (G[{yu}, yv^(-1)]*G[{0, yu^(-1), yu^(-1), 1}, yw])/8 - 
     (G[{0}, yu^(-1)]*G[{0, yu^(-1), yu^(-1), yu^(-1)}, yw])/8 - 
     (G[{0}, yv^(-1)]*G[{0, yu^(-1), yu^(-1), yu^(-1)}, yw])/8 + 
     (G[{0}, yw]*G[{0, yu^(-1), yu^(-1), yu^(-1)}, yw])/8 + 
     (G[{1}, yu^(-1)]*G[{0, yu^(-1), yu^(-1), yu^(-1)}, yw])/8 + 
     (G[{1}, yv^(-1)]*G[{0, yu^(-1), yu^(-1), yu^(-1)}, yw])/8 + 
     (G[{1}, yw]*G[{0, yu^(-1), yu^(-1), yu^(-1)}, yw])/4 - 
     (G[{0}, yu^(-1)]*G[{0, yu^(-1), yu^(-1), yv^(-1)}, yw])/8 - 
     (G[{0}, yv^(-1)]*G[{0, yu^(-1), yu^(-1), yv^(-1)}, yw])/8 + 
     (G[{0}, yw]*G[{0, yu^(-1), yu^(-1), yv^(-1)}, yw])/8 + 
     (G[{1}, yu^(-1)]*G[{0, yu^(-1), yu^(-1), yv^(-1)}, yw])/8 + 
     (G[{1}, yv^(-1)]*G[{0, yu^(-1), yu^(-1), yv^(-1)}, yw])/8 + 
     (G[{1}, yw]*G[{0, yu^(-1), yu^(-1), yv^(-1)}, yw])/8 - 
     (G[{1/(yu*yv)}, yw]*G[{0, yu^(-1), yu^(-1), yv^(-1)}, yw])/8 + 
     (3*G[{0}, yu^(-1)]*G[{0, yu^(-1), yu^(-1), 1/(yu*yv)}, yw])/16 + 
     (3*G[{0}, yv^(-1)]*G[{0, yu^(-1), yu^(-1), 1/(yu*yv)}, yw])/16 - 
     (3*G[{0}, yw]*G[{0, yu^(-1), yu^(-1), 1/(yu*yv)}, yw])/16 - 
     (3*G[{1}, yu^(-1)]*G[{0, yu^(-1), yu^(-1), 1/(yu*yv)}, yw])/16 - 
     (5*G[{1}, yv^(-1)]*G[{0, yu^(-1), yu^(-1), 1/(yu*yv)}, yw])/16 + 
     (G[{yu}, yv^(-1)]*G[{0, yu^(-1), yu^(-1), 1/(yu*yv)}, yw])/8 - 
     (G[{0}, yu^(-1)]*G[{0, yu^(-1), yv^(-1), 1}, yw])/8 - 
     (G[{0}, yv^(-1)]*G[{0, yu^(-1), yv^(-1), 1}, yw])/8 + 
     (G[{0}, yw]*G[{0, yu^(-1), yv^(-1), 1}, yw])/8 + 
     (G[{1}, yu^(-1)]*G[{0, yu^(-1), yv^(-1), 1}, yw])/16 + 
     (G[{1}, yv^(-1)]*G[{0, yu^(-1), yv^(-1), 1}, yw])/16 + 
     (G[{yu}, yv^(-1)]*G[{0, yu^(-1), yv^(-1), 1}, yw])/8 - 
     (G[{0}, yu^(-1)]*G[{0, yu^(-1), yv^(-1), yu^(-1)}, yw])/8 - 
     (G[{0}, yv^(-1)]*G[{0, yu^(-1), yv^(-1), yu^(-1)}, yw])/8 + 
     (G[{0}, yw]*G[{0, yu^(-1), yv^(-1), yu^(-1)}, yw])/8 + 
     (G[{1}, yu^(-1)]*G[{0, yu^(-1), yv^(-1), yu^(-1)}, yw])/8 + 
     (G[{1}, yv^(-1)]*G[{0, yu^(-1), yv^(-1), yu^(-1)}, yw])/8 + 
     (G[{1}, yw]*G[{0, yu^(-1), yv^(-1), yu^(-1)}, yw])/8 - 
     (G[{1/(yu*yv)}, yw]*G[{0, yu^(-1), yv^(-1), yu^(-1)}, yw])/8 + 
     (G[{0}, yu^(-1)]*G[{0, yu^(-1), yv^(-1), yv^(-1)}, yw])/8 + 
     (G[{0}, yv^(-1)]*G[{0, yu^(-1), yv^(-1), yv^(-1)}, yw])/8 - 
     (G[{0}, yw]*G[{0, yu^(-1), yv^(-1), yv^(-1)}, yw])/8 - 
     (3*G[{1}, yu^(-1)]*G[{0, yu^(-1), yv^(-1), yv^(-1)}, yw])/8 + 
     (G[{1}, yv^(-1)]*G[{0, yu^(-1), yv^(-1), yv^(-1)}, yw])/8 + 
     (G[{1}, yw]*G[{0, yu^(-1), yv^(-1), yv^(-1)}, yw])/8 - 
     (G[{1/(yu*yv)}, yw]*G[{0, yu^(-1), yv^(-1), yv^(-1)}, yw])/8 + 
     (G[{0}, yu^(-1)]*G[{0, yu^(-1), yv^(-1), 1/(yu*yv)}, yw])/8 + 
     (G[{0}, yv^(-1)]*G[{0, yu^(-1), yv^(-1), 1/(yu*yv)}, yw])/8 - 
     (G[{0}, yw]*G[{0, yu^(-1), yv^(-1), 1/(yu*yv)}, yw])/8 + 
     (G[{1}, yu^(-1)]*G[{0, yu^(-1), yv^(-1), 1/(yu*yv)}, yw])/16 - 
     (3*G[{1}, yv^(-1)]*G[{0, yu^(-1), yv^(-1), 1/(yu*yv)}, yw])/16 - 
     (G[{yu}, yv^(-1)]*G[{0, yu^(-1), yv^(-1), 1/(yu*yv)}, yw])/8 - 
     (G[{1}, yu^(-1)]*G[{0, yu^(-1), 1/(yu*yv), 1}, yw])/8 + 
     (3*G[{1}, yv^(-1)]*G[{0, yu^(-1), 1/(yu*yv), 1}, yw])/16 + 
     (G[{1}, yw]*G[{0, yu^(-1), 1/(yu*yv), 1}, yw])/8 - 
     (G[{yu}, yv^(-1)]*G[{0, yu^(-1), 1/(yu*yv), 1}, yw])/16 + 
     (3*G[{0}, yu^(-1)]*G[{0, yu^(-1), 1/(yu*yv), yu^(-1)}, yw])/16 + 
     (3*G[{0}, yv^(-1)]*G[{0, yu^(-1), 1/(yu*yv), yu^(-1)}, yw])/16 - 
     (3*G[{0}, yw]*G[{0, yu^(-1), 1/(yu*yv), yu^(-1)}, yw])/16 - 
     (3*G[{1}, yu^(-1)]*G[{0, yu^(-1), 1/(yu*yv), yu^(-1)}, yw])/16 - 
     (5*G[{1}, yv^(-1)]*G[{0, yu^(-1), 1/(yu*yv), yu^(-1)}, yw])/16 - 
     (G[{1}, yw]*G[{0, yu^(-1), 1/(yu*yv), yu^(-1)}, yw])/16 + 
     (G[{yu}, yv^(-1)]*G[{0, yu^(-1), 1/(yu*yv), yu^(-1)}, yw])/8 + 
     (G[{0}, yu^(-1)]*G[{0, yu^(-1), 1/(yu*yv), yv^(-1)}, yw])/16 + 
     (G[{0}, yv^(-1)]*G[{0, yu^(-1), 1/(yu*yv), yv^(-1)}, yw])/16 - 
     (G[{0}, yw]*G[{0, yu^(-1), 1/(yu*yv), yv^(-1)}, yw])/16 + 
     (G[{1}, yu^(-1)]*G[{0, yu^(-1), 1/(yu*yv), yv^(-1)}, yw])/16 - 
     (3*G[{1}, yv^(-1)]*G[{0, yu^(-1), 1/(yu*yv), yv^(-1)}, yw])/16 - 
     (3*G[{1}, yw]*G[{0, yu^(-1), 1/(yu*yv), yv^(-1)}, yw])/16 - 
     (3*G[{0}, yu^(-1)]*G[{0, yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/16 - 
     (3*G[{0}, yv^(-1)]*G[{0, yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/16 + 
     (3*G[{0}, yw]*G[{0, yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/16 + 
     (G[{1}, yu^(-1)]*G[{0, yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/16 + 
     (G[{1}, yv^(-1)]*G[{0, yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/4 + 
     (G[{yu}, yv^(-1)]*G[{0, yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/16 - 
     (G[{0}, yu^(-1)]*G[{0, yu, 1, 1}, yv^(-1)])/8 - 
     (G[{0}, yv^(-1)]*G[{0, yu, 1, 1}, yv^(-1)])/8 + 
     (G[{0}, yw]*G[{0, yu, 1, 1}, yv^(-1)])/8 + 
     (3*G[{1}, yu^(-1)]*G[{0, yu, 1, 1}, yv^(-1)])/16 + 
     (G[{1}, yv^(-1)]*G[{0, yu, 1, 1}, yv^(-1)])/64 - 
     (11*G[{1}, yw]*G[{0, yu, 1, 1}, yv^(-1)])/64 - 
     (G[{1/(yu*yv)}, yw]*G[{0, yu, 1, 1}, yv^(-1)])/64 - 
     (3*G[{0}, yu^(-1)]*G[{0, yu, 1, yu}, yv^(-1)])/16 - 
     (3*G[{0}, yv^(-1)]*G[{0, yu, 1, yu}, yv^(-1)])/16 + 
     (3*G[{0}, yw]*G[{0, yu, 1, yu}, yv^(-1)])/16 + 
     (5*G[{1}, yv^(-1)]*G[{0, yu, 1, yu}, yv^(-1)])/64 - 
     (11*G[{1}, yw]*G[{0, yu, 1, yu}, yv^(-1)])/64 - 
     (5*G[{1/(yu*yv)}, yw]*G[{0, yu, 1, yu}, yv^(-1)])/64 - 
     (G[{0}, yu^(-1)]*G[{0, yu, yu, 1}, yv^(-1)])/8 - 
     (G[{0}, yv^(-1)]*G[{0, yu, yu, 1}, yv^(-1)])/8 + 
     (G[{0}, yw]*G[{0, yu, yu, 1}, yv^(-1)])/8 - 
     (G[{1}, yu^(-1)]*G[{0, yu, yu, 1}, yv^(-1)])/4 + 
     (5*G[{1}, yv^(-1)]*G[{0, yu, yu, 1}, yv^(-1)])/64 - 
     (3*G[{1}, yw]*G[{0, yu, yu, 1}, yv^(-1)])/64 - 
     (5*G[{1/(yu*yv)}, yw]*G[{0, yu, yu, 1}, yv^(-1)])/64 + 
     (G[{0}, yu^(-1)]*G[{0, yu, yu, yu}, yv^(-1)])/2 + 
     (G[{0}, yv^(-1)]*G[{0, yu, yu, yu}, yv^(-1)])/2 - 
     (G[{0}, yw]*G[{0, yu, yu, yu}, yv^(-1)])/2 - 
     (3*G[{1}, yv^(-1)]*G[{0, yu, yu, yu}, yv^(-1)])/64 + 
     (29*G[{1}, yw]*G[{0, yu, yu, yu}, yv^(-1)])/64 + 
     (3*G[{1/(yu*yv)}, yw]*G[{0, yu, yu, yu}, yv^(-1)])/64 - 
     (G[{1}, yu^(-1)]*G[{0, yv^(-1), 0, 1/(yu*yv)}, yw])/16 + 
     (G[{1}, yv^(-1)]*G[{0, yv^(-1), 0, 1/(yu*yv)}, yw])/16 + 
     (G[{1}, yw]*G[{0, yv^(-1), 0, 1/(yu*yv)}, yw])/16 + 
     (G[{0}, yu^(-1)]*G[{0, yv^(-1), 1, 1}, yw])/16 + 
     (G[{0}, yv^(-1)]*G[{0, yv^(-1), 1, 1}, yw])/16 - 
     (G[{0}, yw]*G[{0, yv^(-1), 1, 1}, yw])/16 - 
     (G[{1}, yu^(-1)]*G[{0, yv^(-1), 1, 1}, yw])/4 + 
     (G[{1}, yv^(-1)]*G[{0, yv^(-1), 1, 1}, yw])/16 + 
     (G[{1}, yw]*G[{0, yv^(-1), 1, 1}, yw])/8 + 
     (G[{yu}, yv^(-1)]*G[{0, yv^(-1), 1, 1}, yw])/16 - 
     (G[{0}, yu^(-1)]*G[{0, yv^(-1), 1, yu^(-1)}, yw])/16 - 
     (G[{0}, yv^(-1)]*G[{0, yv^(-1), 1, yu^(-1)}, yw])/16 + 
     (G[{0}, yw]*G[{0, yv^(-1), 1, yu^(-1)}, yw])/16 + 
     (G[{1}, yu^(-1)]*G[{0, yv^(-1), 1, yu^(-1)}, yw])/16 - 
     (G[{1}, yv^(-1)]*G[{0, yv^(-1), 1, yu^(-1)}, yw])/16 + 
     (G[{1}, yw]*G[{0, yv^(-1), 1, yu^(-1)}, yw])/16 + 
     (G[{yu}, yv^(-1)]*G[{0, yv^(-1), 1, yu^(-1)}, yw])/8 - 
     (G[{0}, yu^(-1)]*G[{0, yv^(-1), 1, yv^(-1)}, yw])/16 - 
     (G[{0}, yv^(-1)]*G[{0, yv^(-1), 1, yv^(-1)}, yw])/16 + 
     (G[{0}, yw]*G[{0, yv^(-1), 1, yv^(-1)}, yw])/16 + 
     (G[{1}, yu^(-1)]*G[{0, yv^(-1), 1, yv^(-1)}, yw])/16 + 
     (G[{1}, yv^(-1)]*G[{0, yv^(-1), 1, yv^(-1)}, yw])/16 - 
     (G[{1}, yw]*G[{0, yv^(-1), 1, yv^(-1)}, yw])/16 - 
     (G[{1}, yu^(-1)]*G[{0, yv^(-1), 1, 1/(yu*yv)}, yw])/16 + 
     (G[{1}, yv^(-1)]*G[{0, yv^(-1), 1, 1/(yu*yv)}, yw])/8 - 
     (G[{yu}, yv^(-1)]*G[{0, yv^(-1), 1, 1/(yu*yv)}, yw])/16 - 
     (G[{0}, yu^(-1)]*G[{0, yv^(-1), yu^(-1), 1}, yw])/8 - 
     (G[{0}, yv^(-1)]*G[{0, yv^(-1), yu^(-1), 1}, yw])/8 + 
     (G[{0}, yw]*G[{0, yv^(-1), yu^(-1), 1}, yw])/8 + 
     (G[{1}, yu^(-1)]*G[{0, yv^(-1), yu^(-1), 1}, yw])/16 + 
     (G[{1}, yv^(-1)]*G[{0, yv^(-1), yu^(-1), 1}, yw])/16 + 
     (G[{yu}, yv^(-1)]*G[{0, yv^(-1), yu^(-1), 1}, yw])/8 - 
     (G[{0}, yu^(-1)]*G[{0, yv^(-1), yu^(-1), yu^(-1)}, yw])/8 - 
     (G[{0}, yv^(-1)]*G[{0, yv^(-1), yu^(-1), yu^(-1)}, yw])/8 + 
     (G[{0}, yw]*G[{0, yv^(-1), yu^(-1), yu^(-1)}, yw])/8 + 
     (G[{1}, yu^(-1)]*G[{0, yv^(-1), yu^(-1), yu^(-1)}, yw])/8 + 
     (G[{1}, yv^(-1)]*G[{0, yv^(-1), yu^(-1), yu^(-1)}, yw])/8 + 
     (G[{1}, yw]*G[{0, yv^(-1), yu^(-1), yu^(-1)}, yw])/8 - 
     (G[{1/(yu*yv)}, yw]*G[{0, yv^(-1), yu^(-1), yu^(-1)}, yw])/8 + 
     (G[{0}, yu^(-1)]*G[{0, yv^(-1), yu^(-1), yv^(-1)}, yw])/8 + 
     (G[{0}, yv^(-1)]*G[{0, yv^(-1), yu^(-1), yv^(-1)}, yw])/8 - 
     (G[{0}, yw]*G[{0, yv^(-1), yu^(-1), yv^(-1)}, yw])/8 - 
     (3*G[{1}, yu^(-1)]*G[{0, yv^(-1), yu^(-1), yv^(-1)}, yw])/8 + 
     (G[{1}, yv^(-1)]*G[{0, yv^(-1), yu^(-1), yv^(-1)}, yw])/8 + 
     (G[{1}, yw]*G[{0, yv^(-1), yu^(-1), yv^(-1)}, yw])/8 - 
     (G[{1/(yu*yv)}, yw]*G[{0, yv^(-1), yu^(-1), yv^(-1)}, yw])/8 + 
     (G[{0}, yu^(-1)]*G[{0, yv^(-1), yu^(-1), 1/(yu*yv)}, yw])/8 + 
     (G[{0}, yv^(-1)]*G[{0, yv^(-1), yu^(-1), 1/(yu*yv)}, yw])/8 - 
     (G[{0}, yw]*G[{0, yv^(-1), yu^(-1), 1/(yu*yv)}, yw])/8 + 
     (G[{1}, yu^(-1)]*G[{0, yv^(-1), yu^(-1), 1/(yu*yv)}, yw])/16 - 
     (3*G[{1}, yv^(-1)]*G[{0, yv^(-1), yu^(-1), 1/(yu*yv)}, yw])/16 - 
     (G[{yu}, yv^(-1)]*G[{0, yv^(-1), yu^(-1), 1/(yu*yv)}, yw])/8 - 
     (G[{0}, yu^(-1)]*G[{0, yv^(-1), yv^(-1), 1}, yw])/16 - 
     (G[{0}, yv^(-1)]*G[{0, yv^(-1), yv^(-1), 1}, yw])/16 + 
     (G[{0}, yw]*G[{0, yv^(-1), yv^(-1), 1}, yw])/16 + 
     (G[{1}, yu^(-1)]*G[{0, yv^(-1), yv^(-1), 1}, yw])/16 + 
     (3*G[{1}, yv^(-1)]*G[{0, yv^(-1), yv^(-1), 1}, yw])/16 - 
     (G[{yu}, yv^(-1)]*G[{0, yv^(-1), yv^(-1), 1}, yw])/8 + 
     (G[{0}, yu^(-1)]*G[{0, yv^(-1), yv^(-1), yu^(-1)}, yw])/8 + 
     (G[{0}, yv^(-1)]*G[{0, yv^(-1), yv^(-1), yu^(-1)}, yw])/8 - 
     (G[{0}, yw]*G[{0, yv^(-1), yv^(-1), yu^(-1)}, yw])/8 - 
     (3*G[{1}, yu^(-1)]*G[{0, yv^(-1), yv^(-1), yu^(-1)}, yw])/8 + 
     (G[{1}, yv^(-1)]*G[{0, yv^(-1), yv^(-1), yu^(-1)}, yw])/8 + 
     (G[{1}, yw]*G[{0, yv^(-1), yv^(-1), yu^(-1)}, yw])/8 - 
     (G[{1/(yu*yv)}, yw]*G[{0, yv^(-1), yv^(-1), yu^(-1)}, yw])/8 + 
     (G[{0}, yu^(-1)]*G[{0, yv^(-1), yv^(-1), yv^(-1)}, yw])/8 + 
     (G[{0}, yv^(-1)]*G[{0, yv^(-1), yv^(-1), yv^(-1)}, yw])/8 - 
     (G[{0}, yw]*G[{0, yv^(-1), yv^(-1), yv^(-1)}, yw])/8 + 
     (G[{1}, yu^(-1)]*G[{0, yv^(-1), yv^(-1), yv^(-1)}, yw])/8 - 
     (3*G[{1}, yv^(-1)]*G[{0, yv^(-1), yv^(-1), yv^(-1)}, yw])/8 - 
     (G[{1}, yw]*G[{0, yv^(-1), yv^(-1), yv^(-1)}, yw])/4 - 
     (G[{0}, yu^(-1)]*G[{0, yv^(-1), yv^(-1), 1/(yu*yv)}, yw])/16 - 
     (G[{0}, yv^(-1)]*G[{0, yv^(-1), yv^(-1), 1/(yu*yv)}, yw])/16 + 
     (G[{0}, yw]*G[{0, yv^(-1), yv^(-1), 1/(yu*yv)}, yw])/16 + 
     (G[{1}, yu^(-1)]*G[{0, yv^(-1), yv^(-1), 1/(yu*yv)}, yw])/16 - 
     (G[{1}, yv^(-1)]*G[{0, yv^(-1), yv^(-1), 1/(yu*yv)}, yw])/16 + 
     (G[{yu}, yv^(-1)]*G[{0, yv^(-1), yv^(-1), 1/(yu*yv)}, yw])/8 - 
     (G[{1}, yu^(-1)]*G[{0, yv^(-1), 1/(yu*yv), 1}, yw])/16 - 
     (G[{1}, yw]*G[{0, yv^(-1), 1/(yu*yv), 1}, yw])/8 + 
     (G[{yu}, yv^(-1)]*G[{0, yv^(-1), 1/(yu*yv), 1}, yw])/16 + 
     (G[{0}, yu^(-1)]*G[{0, yv^(-1), 1/(yu*yv), yu^(-1)}, yw])/16 + 
     (G[{0}, yv^(-1)]*G[{0, yv^(-1), 1/(yu*yv), yu^(-1)}, yw])/16 - 
     (G[{0}, yw]*G[{0, yv^(-1), 1/(yu*yv), yu^(-1)}, yw])/16 + 
     (G[{1}, yu^(-1)]*G[{0, yv^(-1), 1/(yu*yv), yu^(-1)}, yw])/16 - 
     (G[{1}, yv^(-1)]*G[{0, yv^(-1), 1/(yu*yv), yu^(-1)}, yw])/16 + 
     (3*G[{1}, yw]*G[{0, yv^(-1), 1/(yu*yv), yu^(-1)}, yw])/16 - 
     (G[{yu}, yv^(-1)]*G[{0, yv^(-1), 1/(yu*yv), yu^(-1)}, yw])/8 - 
     (G[{0}, yu^(-1)]*G[{0, yv^(-1), 1/(yu*yv), yv^(-1)}, yw])/16 - 
     (G[{0}, yv^(-1)]*G[{0, yv^(-1), 1/(yu*yv), yv^(-1)}, yw])/16 + 
     (G[{0}, yw]*G[{0, yv^(-1), 1/(yu*yv), yv^(-1)}, yw])/16 + 
     (G[{1}, yu^(-1)]*G[{0, yv^(-1), 1/(yu*yv), yv^(-1)}, yw])/16 + 
     (G[{1}, yv^(-1)]*G[{0, yv^(-1), 1/(yu*yv), yv^(-1)}, yw])/16 + 
     (G[{1}, yw]*G[{0, yv^(-1), 1/(yu*yv), yv^(-1)}, yw])/16 - 
     (G[{0}, yu^(-1)]*G[{0, yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/16 - 
     (G[{0}, yv^(-1)]*G[{0, yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/16 + 
     (G[{0}, yw]*G[{0, yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/16 + 
     (3*G[{1}, yv^(-1)]*G[{0, yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/16 - 
     (G[{yu}, yv^(-1)]*G[{0, yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/16 - 
     (G[{0}, yu^(-1)]*G[{0, 1/(yu*yv), 1, 1}, yw])/16 - 
     (G[{0}, yv^(-1)]*G[{0, 1/(yu*yv), 1, 1}, yw])/16 + 
     (G[{0}, yw]*G[{0, 1/(yu*yv), 1, 1}, yw])/16 + 
     (G[{1}, yu^(-1)]*G[{0, 1/(yu*yv), 1, 1}, yw])/4 - 
     (G[{1}, yv^(-1)]*G[{0, 1/(yu*yv), 1, 1}, yw])/16 - 
     (G[{1}, yw]*G[{0, 1/(yu*yv), 1, 1}, yw])/8 - 
     (G[{yu}, yv^(-1)]*G[{0, 1/(yu*yv), 1, 1}, yw])/16 + 
     (G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv), 1, 1}, yw])/8 + 
     (G[{0}, yu^(-1)]*G[{0, 1/(yu*yv), 1, yu^(-1)}, yw])/16 + 
     (G[{0}, yv^(-1)]*G[{0, 1/(yu*yv), 1, yu^(-1)}, yw])/16 - 
     (G[{0}, yw]*G[{0, 1/(yu*yv), 1, yu^(-1)}, yw])/16 - 
     (G[{1}, yu^(-1)]*G[{0, 1/(yu*yv), 1, yu^(-1)}, yw])/16 + 
     (G[{1}, yv^(-1)]*G[{0, 1/(yu*yv), 1, yu^(-1)}, yw])/16 - 
     (G[{1}, yw]*G[{0, 1/(yu*yv), 1, yu^(-1)}, yw])/16 - 
     (G[{yu}, yv^(-1)]*G[{0, 1/(yu*yv), 1, yu^(-1)}, yw])/8 + 
     (G[{1}, yu^(-1)]*G[{0, 1/(yu*yv), 1, yv^(-1)}, yw])/16 - 
     (G[{1}, yv^(-1)]*G[{0, 1/(yu*yv), 1, yv^(-1)}, yw])/16 + 
     (G[{1}, yw]*G[{0, 1/(yu*yv), 1, yv^(-1)}, yw])/16 - 
     (G[{1}, yu^(-1)]*G[{0, 1/(yu*yv), 1, 1/(yu*yv)}, yw])/16 - 
     (G[{1}, yv^(-1)]*G[{0, 1/(yu*yv), 1, 1/(yu*yv)}, yw])/4 + 
     (5*G[{yu}, yv^(-1)]*G[{0, 1/(yu*yv), 1, 1/(yu*yv)}, yw])/16 + 
     (G[{0}, yu^(-1)]*G[{0, 1/(yu*yv), yu^(-1), 1}, yw])/8 + 
     (G[{0}, yv^(-1)]*G[{0, 1/(yu*yv), yu^(-1), 1}, yw])/8 - 
     (G[{0}, yw]*G[{0, 1/(yu*yv), yu^(-1), 1}, yw])/8 - 
     (G[{1}, yu^(-1)]*G[{0, 1/(yu*yv), yu^(-1), 1}, yw])/16 - 
     (G[{1}, yv^(-1)]*G[{0, 1/(yu*yv), yu^(-1), 1}, yw])/16 - 
     (G[{yu}, yv^(-1)]*G[{0, 1/(yu*yv), yu^(-1), 1}, yw])/8 + 
     (G[{0}, yu^(-1)]*G[{0, 1/(yu*yv), yu^(-1), yu^(-1)}, yw])/8 + 
     (G[{0}, yv^(-1)]*G[{0, 1/(yu*yv), yu^(-1), yu^(-1)}, yw])/8 - 
     (G[{0}, yw]*G[{0, 1/(yu*yv), yu^(-1), yu^(-1)}, yw])/8 - 
     (G[{1}, yu^(-1)]*G[{0, 1/(yu*yv), yu^(-1), yu^(-1)}, yw])/8 - 
     (G[{1}, yv^(-1)]*G[{0, 1/(yu*yv), yu^(-1), yu^(-1)}, yw])/8 - 
     (G[{1}, yw]*G[{0, 1/(yu*yv), yu^(-1), yu^(-1)}, yw])/8 + 
     (G[{1}, yu^(-1)]*G[{0, 1/(yu*yv), yu^(-1), yv^(-1)}, yw])/8 - 
     (G[{1}, yv^(-1)]*G[{0, 1/(yu*yv), yu^(-1), yv^(-1)}, yw])/8 - 
     (G[{1}, yw]*G[{0, 1/(yu*yv), yu^(-1), yv^(-1)}, yw])/8 + 
     (G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv), yu^(-1), yv^(-1)}, yw])/8 - 
     (3*G[{0}, yu^(-1)]*G[{0, 1/(yu*yv), yu^(-1), 1/(yu*yv)}, yw])/16 - 
     (3*G[{0}, yv^(-1)]*G[{0, 1/(yu*yv), yu^(-1), 1/(yu*yv)}, yw])/16 + 
     (3*G[{0}, yw]*G[{0, 1/(yu*yv), yu^(-1), 1/(yu*yv)}, yw])/16 + 
     (3*G[{1}, yu^(-1)]*G[{0, 1/(yu*yv), yu^(-1), 1/(yu*yv)}, yw])/16 + 
     (5*G[{1}, yv^(-1)]*G[{0, 1/(yu*yv), yu^(-1), 1/(yu*yv)}, yw])/16 - 
     (G[{yu}, yv^(-1)]*G[{0, 1/(yu*yv), yu^(-1), 1/(yu*yv)}, yw])/8 + 
     (G[{0}, yu^(-1)]*G[{0, 1/(yu*yv), yv^(-1), 1}, yw])/16 + 
     (G[{0}, yv^(-1)]*G[{0, 1/(yu*yv), yv^(-1), 1}, yw])/16 - 
     (G[{0}, yw]*G[{0, 1/(yu*yv), yv^(-1), 1}, yw])/16 - 
     (G[{1}, yv^(-1)]*G[{0, 1/(yu*yv), yv^(-1), 1}, yw])/8 + 
     (G[{1}, yu^(-1)]*G[{0, 1/(yu*yv), yv^(-1), yu^(-1)}, yw])/8 - 
     (G[{1}, yv^(-1)]*G[{0, 1/(yu*yv), yv^(-1), yu^(-1)}, yw])/8 - 
     (G[{1}, yw]*G[{0, 1/(yu*yv), yv^(-1), yu^(-1)}, yw])/8 + 
     (G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv), yv^(-1), yu^(-1)}, yw])/8 - 
     (G[{0}, yu^(-1)]*G[{0, 1/(yu*yv), yv^(-1), yv^(-1)}, yw])/8 - 
     (G[{0}, yv^(-1)]*G[{0, 1/(yu*yv), yv^(-1), yv^(-1)}, yw])/8 + 
     (G[{0}, yw]*G[{0, 1/(yu*yv), yv^(-1), yv^(-1)}, yw])/8 + 
     (G[{1}, yu^(-1)]*G[{0, 1/(yu*yv), yv^(-1), yv^(-1)}, yw])/8 + 
     (G[{1}, yv^(-1)]*G[{0, 1/(yu*yv), yv^(-1), yv^(-1)}, yw])/8 + 
     (G[{1}, yw]*G[{0, 1/(yu*yv), yv^(-1), yv^(-1)}, yw])/8 - 
     (G[{1}, yu^(-1)]*G[{0, 1/(yu*yv), yv^(-1), 1/(yu*yv)}, yw])/8 + 
     (G[{1}, yv^(-1)]*G[{0, 1/(yu*yv), yv^(-1), 1/(yu*yv)}, yw])/8 - 
     (5*G[{1}, yv^(-1)]*G[{0, 1/(yu*yv), 1/(yu*yv), 1}, yw])/16 + 
     (5*G[{yu}, yv^(-1)]*G[{0, 1/(yu*yv), 1/(yu*yv), 1}, yw])/16 - 
     (3*G[{0}, yu^(-1)]*G[{0, 1/(yu*yv), 1/(yu*yv), yu^(-1)}, yw])/16 - 
     (3*G[{0}, yv^(-1)]*G[{0, 1/(yu*yv), 1/(yu*yv), yu^(-1)}, yw])/16 + 
     (3*G[{0}, yw]*G[{0, 1/(yu*yv), 1/(yu*yv), yu^(-1)}, yw])/16 + 
     (3*G[{1}, yu^(-1)]*G[{0, 1/(yu*yv), 1/(yu*yv), yu^(-1)}, yw])/16 + 
     (5*G[{1}, yv^(-1)]*G[{0, 1/(yu*yv), 1/(yu*yv), yu^(-1)}, yw])/16 - 
     (G[{1}, yw]*G[{0, 1/(yu*yv), 1/(yu*yv), yu^(-1)}, yw])/16 - 
     (G[{yu}, yv^(-1)]*G[{0, 1/(yu*yv), 1/(yu*yv), yu^(-1)}, yw])/8 - 
     (3*G[{1}, yu^(-1)]*G[{0, 1/(yu*yv), 1/(yu*yv), yv^(-1)}, yw])/16 + 
     (3*G[{1}, yv^(-1)]*G[{0, 1/(yu*yv), 1/(yu*yv), yv^(-1)}, yw])/16 + 
     (G[{1}, yw]*G[{0, 1/(yu*yv), 1/(yu*yv), yv^(-1)}, yw])/16 + 
     (3*G[{0}, yu^(-1)]*G[{0, 1/(yu*yv), 1/(yu*yv), 1/(yu*yv)}, yw])/16 + 
     (3*G[{0}, yv^(-1)]*G[{0, 1/(yu*yv), 1/(yu*yv), 1/(yu*yv)}, yw])/16 - 
     (3*G[{0}, yw]*G[{0, 1/(yu*yv), 1/(yu*yv), 1/(yu*yv)}, yw])/16 - 
     (G[{1}, yu^(-1)]*G[{0, 1/(yu*yv), 1/(yu*yv), 1/(yu*yv)}, yw])/16 - 
     (G[{1}, yv^(-1)]*G[{0, 1/(yu*yv), 1/(yu*yv), 1/(yu*yv)}, yw])/4 - 
     (G[{yu}, yv^(-1)]*G[{0, 1/(yu*yv), 1/(yu*yv), 1/(yu*yv)}, yw])/16 - 
     (5*G[{0}, yu^(-1)]*G[{1, 1, 1, yu^(-1)}, yw])/16 - 
     (5*G[{0}, yv^(-1)]*G[{1, 1, 1, yu^(-1)}, yw])/16 + 
     (5*G[{0}, yw]*G[{1, 1, 1, yu^(-1)}, yw])/16 + 
     (5*G[{1}, yu^(-1)]*G[{1, 1, 1, yu^(-1)}, yw])/16 + 
     (23*G[{1}, yv^(-1)]*G[{1, 1, 1, yu^(-1)}, yw])/64 + 
     (3*G[{1}, yw]*G[{1, 1, 1, yu^(-1)}, yw])/64 - 
     (3*G[{yu}, yv^(-1)]*G[{1, 1, 1, yu^(-1)}, yw])/64 + 
     (G[{1/(yu*yv)}, yw]*G[{1, 1, 1, yu^(-1)}, yw])/64 + 
     (G[{0}, yu^(-1)]*G[{1, 1, 1, yu}, yv^(-1)])/8 + 
     (G[{0}, yv^(-1)]*G[{1, 1, 1, yu}, yv^(-1)])/8 - 
     (G[{0}, yw]*G[{1, 1, 1, yu}, yv^(-1)])/8 - 
     (3*G[{1}, yu^(-1)]*G[{1, 1, 1, yu}, yv^(-1)])/16 - 
     (5*G[{1}, yv^(-1)]*G[{1, 1, 1, yu}, yv^(-1)])/64 + 
     (15*G[{1}, yw]*G[{1, 1, 1, yu}, yv^(-1)])/64 + 
     (G[{1/(yu*yv)}, yw]*G[{1, 1, 1, yu}, yv^(-1)])/64 + 
     (G[{1}, yu^(-1)]*G[{1, 1, 1, yv^(-1)}, yw])/4 - 
     (G[{1}, yv^(-1)]*G[{1, 1, 1, yv^(-1)}, yw])/16 + 
     (3*G[{1}, yw]*G[{1, 1, 1, yv^(-1)}, yw])/16 - 
     (3*G[{yu}, yv^(-1)]*G[{1, 1, 1, yv^(-1)}, yw])/16 - 
     (G[{1/(yu*yv)}, yw]*G[{1, 1, 1, yv^(-1)}, yw])/8 - 
     (G[{0}, yu^(-1)]*G[{1, 1, 1, 1/(yu*yv)}, yw])/16 - 
     (G[{0}, yv^(-1)]*G[{1, 1, 1, 1/(yu*yv)}, yw])/16 + 
     (G[{0}, yw]*G[{1, 1, 1, 1/(yu*yv)}, yw])/16 - 
     (3*G[{1}, yu^(-1)]*G[{1, 1, 1, 1/(yu*yv)}, yw])/16 - 
     (3*G[{1}, yv^(-1)]*G[{1, 1, 1, 1/(yu*yv)}, yw])/64 - 
     (23*G[{1}, yw]*G[{1, 1, 1, 1/(yu*yv)}, yw])/64 + 
     (23*G[{yu}, yv^(-1)]*G[{1, 1, 1, 1/(yu*yv)}, yw])/64 - 
     (9*G[{1/(yu*yv)}, yw]*G[{1, 1, 1, 1/(yu*yv)}, yw])/64 - 
     (3*G[{0}, yu^(-1)]*G[{1, 1, yu^(-1), yu^(-1)}, yw])/16 - 
     (3*G[{0}, yv^(-1)]*G[{1, 1, yu^(-1), yu^(-1)}, yw])/16 + 
     (3*G[{0}, yw]*G[{1, 1, yu^(-1), yu^(-1)}, yw])/16 + 
     (3*G[{1}, yu^(-1)]*G[{1, 1, yu^(-1), yu^(-1)}, yw])/16 + 
     (35*G[{1}, yv^(-1)]*G[{1, 1, yu^(-1), yu^(-1)}, yw])/64 + 
     (23*G[{1}, yw]*G[{1, 1, yu^(-1), yu^(-1)}, yw])/64 - 
     (23*G[{yu}, yv^(-1)]*G[{1, 1, yu^(-1), yu^(-1)}, yw])/64 - 
     (5*G[{1/(yu*yv)}, yw]*G[{1, 1, yu^(-1), yu^(-1)}, yw])/64 - 
     (3*G[{0}, yu^(-1)]*G[{1, 1, yu^(-1), yv^(-1)}, yw])/16 - 
     (3*G[{0}, yv^(-1)]*G[{1, 1, yu^(-1), yv^(-1)}, yw])/16 + 
     (3*G[{0}, yw]*G[{1, 1, yu^(-1), yv^(-1)}, yw])/16 + 
     (3*G[{1}, yu^(-1)]*G[{1, 1, yu^(-1), yv^(-1)}, yw])/16 - 
     (G[{1}, yv^(-1)]*G[{1, 1, yu^(-1), yv^(-1)}, yw])/16 - 
     (G[{1}, yw]*G[{1, 1, yu^(-1), yv^(-1)}, yw])/4 + 
     (G[{yu}, yv^(-1)]*G[{1, 1, yu^(-1), yv^(-1)}, yw])/4 + 
     (5*G[{0}, yu^(-1)]*G[{1, 1, yu^(-1), 1/(yu*yv)}, yw])/16 + 
     (5*G[{0}, yv^(-1)]*G[{1, 1, yu^(-1), 1/(yu*yv)}, yw])/16 - 
     (5*G[{0}, yw]*G[{1, 1, yu^(-1), 1/(yu*yv)}, yw])/16 - 
     (5*G[{1}, yu^(-1)]*G[{1, 1, yu^(-1), 1/(yu*yv)}, yw])/16 + 
     (5*G[{1}, yw]*G[{1, 1, yu^(-1), 1/(yu*yv)}, yw])/16 - 
     (5*G[{yu}, yv^(-1)]*G[{1, 1, yu^(-1), 1/(yu*yv)}, yw])/16 + 
     (3*G[{1/(yu*yv)}, yw]*G[{1, 1, yu^(-1), 1/(yu*yv)}, yw])/32 - 
     (G[{0}, yu^(-1)]*G[{1, 1, yu, yu}, yv^(-1)])/4 - 
     (G[{0}, yv^(-1)]*G[{1, 1, yu, yu}, yv^(-1)])/4 + 
     (G[{0}, yw]*G[{1, 1, yu, yu}, yv^(-1)])/4 - 
     (9*G[{1}, yv^(-1)]*G[{1, 1, yu, yu}, yv^(-1)])/64 - 
     (27*G[{1}, yw]*G[{1, 1, yu, yu}, yv^(-1)])/64 - 
     (5*G[{1/(yu*yv)}, yw]*G[{1, 1, yu, yu}, yv^(-1)])/64 - 
     (3*G[{0}, yu^(-1)]*G[{1, 1, yv^(-1), yu^(-1)}, yw])/16 - 
     (3*G[{0}, yv^(-1)]*G[{1, 1, yv^(-1), yu^(-1)}, yw])/16 + 
     (3*G[{0}, yw]*G[{1, 1, yv^(-1), yu^(-1)}, yw])/16 + 
     (3*G[{1}, yu^(-1)]*G[{1, 1, yv^(-1), yu^(-1)}, yw])/16 - 
     (G[{1}, yv^(-1)]*G[{1, 1, yv^(-1), yu^(-1)}, yw])/16 - 
     (G[{1}, yw]*G[{1, 1, yv^(-1), yu^(-1)}, yw])/4 + 
     (G[{yu}, yv^(-1)]*G[{1, 1, yv^(-1), yu^(-1)}, yw])/4 - 
     (G[{0}, yu^(-1)]*G[{1, 1, yv^(-1), yv^(-1)}, yw])/16 - 
     (G[{0}, yv^(-1)]*G[{1, 1, yv^(-1), yv^(-1)}, yw])/16 + 
     (G[{0}, yw]*G[{1, 1, yv^(-1), yv^(-1)}, yw])/16 - 
     (G[{1}, yu^(-1)]*G[{1, 1, yv^(-1), yv^(-1)}, yw])/16 + 
     (3*G[{1}, yv^(-1)]*G[{1, 1, yv^(-1), yv^(-1)}, yw])/16 - 
     (G[{1/(yu*yv)}, yw]*G[{1, 1, yv^(-1), yv^(-1)}, yw])/8 + 
     (G[{1}, yu^(-1)]*G[{1, 1, yv^(-1), 1/(yu*yv)}, yw])/4 - 
     (3*G[{1}, yv^(-1)]*G[{1, 1, yv^(-1), 1/(yu*yv)}, yw])/16 + 
     (G[{1}, yw]*G[{1, 1, yv^(-1), 1/(yu*yv)}, yw])/16 - 
     (G[{yu}, yv^(-1)]*G[{1, 1, yv^(-1), 1/(yu*yv)}, yw])/16 + 
     (G[{0}, yu^(-1)]*G[{1, 1, 1/(yu*yv), yu^(-1)}, yw])/4 + 
     (G[{0}, yv^(-1)]*G[{1, 1, 1/(yu*yv), yu^(-1)}, yw])/4 - 
     (G[{0}, yw]*G[{1, 1, 1/(yu*yv), yu^(-1)}, yw])/4 - 
     (G[{1}, yu^(-1)]*G[{1, 1, 1/(yu*yv), yu^(-1)}, yw])/4 - 
     (7*G[{1}, yv^(-1)]*G[{1, 1, 1/(yu*yv), yu^(-1)}, yw])/64 + 
     (9*G[{1}, yw]*G[{1, 1, 1/(yu*yv), yu^(-1)}, yw])/64 - 
     (9*G[{yu}, yv^(-1)]*G[{1, 1, 1/(yu*yv), yu^(-1)}, yw])/64 + 
     (5*G[{1/(yu*yv)}, yw]*G[{1, 1, 1/(yu*yv), yu^(-1)}, yw])/64 - 
     (G[{0}, yu^(-1)]*G[{1, 1, 1/(yu*yv), yv^(-1)}, yw])/8 - 
     (G[{0}, yv^(-1)]*G[{1, 1, 1/(yu*yv), yv^(-1)}, yw])/8 + 
     (G[{0}, yw]*G[{1, 1, 1/(yu*yv), yv^(-1)}, yw])/8 + 
     (G[{1}, yu^(-1)]*G[{1, 1, 1/(yu*yv), yv^(-1)}, yw])/2 - 
     (G[{1}, yv^(-1)]*G[{1, 1, 1/(yu*yv), yv^(-1)}, yw])/4 + 
     (G[{1/(yu*yv)}, yw]*G[{1, 1, 1/(yu*yv), yv^(-1)}, yw])/8 - 
     (5*G[{0}, yu^(-1)]*G[{1, 1, 1/(yu*yv), 1/(yu*yv)}, yw])/16 - 
     (5*G[{0}, yv^(-1)]*G[{1, 1, 1/(yu*yv), 1/(yu*yv)}, yw])/16 + 
     (5*G[{0}, yw]*G[{1, 1, 1/(yu*yv), 1/(yu*yv)}, yw])/16 - 
     (3*G[{1}, yu^(-1)]*G[{1, 1, 1/(yu*yv), 1/(yu*yv)}, yw])/16 - 
     (3*G[{1}, yv^(-1)]*G[{1, 1, 1/(yu*yv), 1/(yu*yv)}, yw])/16 - 
     G[{1}, yw]*G[{1, 1, 1/(yu*yv), 1/(yu*yv)}, yw] + 
     G[{yu}, yv^(-1)]*G[{1, 1, 1/(yu*yv), 1/(yu*yv)}, yw] - 
     (3*G[{1/(yu*yv)}, yw]*G[{1, 1, 1/(yu*yv), 1/(yu*yv)}, yw])/32 - 
     (G[{0}, yu^(-1)]*G[{1, yu^(-1), 1, yv^(-1)}, yw])/16 - 
     (G[{0}, yv^(-1)]*G[{1, yu^(-1), 1, yv^(-1)}, yw])/16 + 
     (G[{0}, yw]*G[{1, yu^(-1), 1, yv^(-1)}, yw])/16 + 
     (G[{1}, yu^(-1)]*G[{1, yu^(-1), 1, yv^(-1)}, yw])/8 - 
     (G[{1}, yv^(-1)]*G[{1, yu^(-1), 1, yv^(-1)}, yw])/8 - 
     (G[{1}, yw]*G[{1, yu^(-1), 1, yv^(-1)}, yw])/8 + 
     (G[{yu}, yv^(-1)]*G[{1, yu^(-1), 1, yv^(-1)}, yw])/8 + 
     (G[{0}, yu^(-1)]*G[{1, yu^(-1), 1, 1/(yu*yv)}, yw])/16 + 
     (G[{0}, yv^(-1)]*G[{1, yu^(-1), 1, 1/(yu*yv)}, yw])/16 - 
     (G[{0}, yw]*G[{1, yu^(-1), 1, 1/(yu*yv)}, yw])/16 - 
     (G[{1}, yu^(-1)]*G[{1, yu^(-1), 1, 1/(yu*yv)}, yw])/8 + 
     (G[{1}, yv^(-1)]*G[{1, yu^(-1), 1, 1/(yu*yv)}, yw])/8 + 
     (G[{1}, yw]*G[{1, yu^(-1), 1, 1/(yu*yv)}, yw])/8 - 
     (G[{yu}, yv^(-1)]*G[{1, yu^(-1), 1, 1/(yu*yv)}, yw])/8 + 
     (G[{0}, yu^(-1)]*G[{1, yu^(-1), yu^(-1), yu^(-1)}, yw])/8 + 
     (G[{0}, yv^(-1)]*G[{1, yu^(-1), yu^(-1), yu^(-1)}, yw])/8 - 
     (G[{0}, yw]*G[{1, yu^(-1), yu^(-1), yu^(-1)}, yw])/8 - 
     (G[{1}, yu^(-1)]*G[{1, yu^(-1), yu^(-1), yu^(-1)}, yw])/8 + 
     (3*G[{1}, yv^(-1)]*G[{1, yu^(-1), yu^(-1), yu^(-1)}, yw])/32 + 
     (7*G[{1}, yw]*G[{1, yu^(-1), yu^(-1), yu^(-1)}, yw])/32 - 
     (7*G[{yu}, yv^(-1)]*G[{1, yu^(-1), yu^(-1), yu^(-1)}, yw])/32 - 
     (3*G[{1/(yu*yv)}, yw]*G[{1, yu^(-1), yu^(-1), yu^(-1)}, yw])/64 + 
     (G[{0}, yu^(-1)]*G[{1, yu^(-1), yu^(-1), yv^(-1)}, yw])/8 + 
     (G[{0}, yv^(-1)]*G[{1, yu^(-1), yu^(-1), yv^(-1)}, yw])/8 - 
     (G[{0}, yw]*G[{1, yu^(-1), yu^(-1), yv^(-1)}, yw])/8 - 
     (G[{1}, yu^(-1)]*G[{1, yu^(-1), yu^(-1), yv^(-1)}, yw])/8 - 
     (G[{1}, yv^(-1)]*G[{1, yu^(-1), yu^(-1), yv^(-1)}, yw])/8 + 
     (G[{1/(yu*yv)}, yw]*G[{1, yu^(-1), yu^(-1), yv^(-1)}, yw])/8 - 
     (G[{0}, yu^(-1)]*G[{1, yu^(-1), yu^(-1), 1/(yu*yv)}, yw])/16 - 
     (G[{0}, yv^(-1)]*G[{1, yu^(-1), yu^(-1), 1/(yu*yv)}, yw])/16 + 
     (G[{0}, yw]*G[{1, yu^(-1), yu^(-1), 1/(yu*yv)}, yw])/16 + 
     (G[{1}, yu^(-1)]*G[{1, yu^(-1), yu^(-1), 1/(yu*yv)}, yw])/16 - 
     (3*G[{1}, yv^(-1)]*G[{1, yu^(-1), yu^(-1), 1/(yu*yv)}, yw])/64 - 
     (7*G[{1}, yw]*G[{1, yu^(-1), yu^(-1), 1/(yu*yv)}, yw])/64 + 
     (7*G[{yu}, yv^(-1)]*G[{1, yu^(-1), yu^(-1), 1/(yu*yv)}, yw])/64 + 
     (3*G[{1/(yu*yv)}, yw]*G[{1, yu^(-1), yu^(-1), 1/(yu*yv)}, yw])/32 + 
     (G[{0}, yu^(-1)]*G[{1, yu^(-1), yv^(-1), yu^(-1)}, yw])/8 + 
     (G[{0}, yv^(-1)]*G[{1, yu^(-1), yv^(-1), yu^(-1)}, yw])/8 - 
     (G[{0}, yw]*G[{1, yu^(-1), yv^(-1), yu^(-1)}, yw])/8 - 
     (G[{1}, yu^(-1)]*G[{1, yu^(-1), yv^(-1), yu^(-1)}, yw])/8 - 
     (G[{1}, yv^(-1)]*G[{1, yu^(-1), yv^(-1), yu^(-1)}, yw])/8 + 
     (G[{1/(yu*yv)}, yw]*G[{1, yu^(-1), yv^(-1), yu^(-1)}, yw])/8 - 
     (G[{0}, yu^(-1)]*G[{1, yu^(-1), yv^(-1), yv^(-1)}, yw])/8 - 
     (G[{0}, yv^(-1)]*G[{1, yu^(-1), yv^(-1), yv^(-1)}, yw])/8 + 
     (G[{0}, yw]*G[{1, yu^(-1), yv^(-1), yv^(-1)}, yw])/8 + 
     (3*G[{1}, yu^(-1)]*G[{1, yu^(-1), yv^(-1), yv^(-1)}, yw])/8 - 
     (G[{1}, yv^(-1)]*G[{1, yu^(-1), yv^(-1), yv^(-1)}, yw])/8 + 
     (G[{1/(yu*yv)}, yw]*G[{1, yu^(-1), yv^(-1), yv^(-1)}, yw])/8 - 
     (G[{0}, yu^(-1)]*G[{1, yu^(-1), yv^(-1), 1/(yu*yv)}, yw])/8 - 
     (G[{0}, yv^(-1)]*G[{1, yu^(-1), yv^(-1), 1/(yu*yv)}, yw])/8 + 
     (G[{0}, yw]*G[{1, yu^(-1), yv^(-1), 1/(yu*yv)}, yw])/8 - 
     (G[{1}, yu^(-1)]*G[{1, yu^(-1), yv^(-1), 1/(yu*yv)}, yw])/16 + 
     (3*G[{1}, yv^(-1)]*G[{1, yu^(-1), yv^(-1), 1/(yu*yv)}, yw])/16 - 
     (G[{1}, yw]*G[{1, yu^(-1), yv^(-1), 1/(yu*yv)}, yw])/8 + 
     (G[{yu}, yv^(-1)]*G[{1, yu^(-1), yv^(-1), 1/(yu*yv)}, yw])/8 - 
     (G[{0}, yu^(-1)]*G[{1, yu^(-1), 1/(yu*yv), yu^(-1)}, yw])/16 - 
     (G[{0}, yv^(-1)]*G[{1, yu^(-1), 1/(yu*yv), yu^(-1)}, yw])/16 + 
     (G[{0}, yw]*G[{1, yu^(-1), 1/(yu*yv), yu^(-1)}, yw])/16 + 
     (G[{1}, yu^(-1)]*G[{1, yu^(-1), 1/(yu*yv), yu^(-1)}, yw])/16 - 
     (3*G[{1}, yv^(-1)]*G[{1, yu^(-1), 1/(yu*yv), yu^(-1)}, yw])/64 - 
     (7*G[{1}, yw]*G[{1, yu^(-1), 1/(yu*yv), yu^(-1)}, yw])/64 + 
     (7*G[{yu}, yv^(-1)]*G[{1, yu^(-1), 1/(yu*yv), yu^(-1)}, yw])/64 + 
     (3*G[{1/(yu*yv)}, yw]*G[{1, yu^(-1), 1/(yu*yv), yu^(-1)}, yw])/32 + 
     (G[{0}, yu^(-1)]*G[{1, yu^(-1), 1/(yu*yv), yv^(-1)}, yw])/16 + 
     (G[{0}, yv^(-1)]*G[{1, yu^(-1), 1/(yu*yv), yv^(-1)}, yw])/16 - 
     (G[{0}, yw]*G[{1, yu^(-1), 1/(yu*yv), yv^(-1)}, yw])/16 - 
     (3*G[{1}, yu^(-1)]*G[{1, yu^(-1), 1/(yu*yv), yv^(-1)}, yw])/16 + 
     (G[{1}, yv^(-1)]*G[{1, yu^(-1), 1/(yu*yv), yv^(-1)}, yw])/16 + 
     (G[{0}, yu^(-1)]*G[{1, yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/8 + 
     (G[{0}, yv^(-1)]*G[{1, yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/8 - 
     (G[{0}, yw]*G[{1, yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/8 + 
     (G[{1}, yu^(-1)]*G[{1, yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/16 - 
     (9*G[{1}, yv^(-1)]*G[{1, yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/64 + 
     (11*G[{1}, yw]*G[{1, yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/64 - 
     (11*G[{yu}, yv^(-1)]*G[{1, yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/64 - 
     (G[{0}, yu^(-1)]*G[{1, yu, yu, yu}, yv^(-1)])/2 - 
     (G[{0}, yv^(-1)]*G[{1, yu, yu, yu}, yv^(-1)])/2 + 
     (G[{0}, yw]*G[{1, yu, yu, yu}, yv^(-1)])/2 - 
     (9*G[{1}, yv^(-1)]*G[{1, yu, yu, yu}, yv^(-1)])/32 - 
     (61*G[{1}, yw]*G[{1, yu, yu, yu}, yv^(-1)])/64 - 
     (3*G[{1/(yu*yv)}, yw]*G[{1, yu, yu, yu}, yv^(-1)])/64 - 
     (G[{0}, yu^(-1)]*G[{1, yv^(-1), 1, 1/(yu*yv)}, yw])/16 - 
     (G[{0}, yv^(-1)]*G[{1, yv^(-1), 1, 1/(yu*yv)}, yw])/16 + 
     (G[{0}, yw]*G[{1, yv^(-1), 1, 1/(yu*yv)}, yw])/16 + 
     (G[{1}, yu^(-1)]*G[{1, yv^(-1), 1, 1/(yu*yv)}, yw])/4 - 
     (G[{1}, yv^(-1)]*G[{1, yv^(-1), 1, 1/(yu*yv)}, yw])/4 - 
     (G[{1}, yw]*G[{1, yv^(-1), 1, 1/(yu*yv)}, yw])/8 + 
     (G[{yu}, yv^(-1)]*G[{1, yv^(-1), 1, 1/(yu*yv)}, yw])/8 + 
     (G[{0}, yu^(-1)]*G[{1, yv^(-1), yu^(-1), yu^(-1)}, yw])/8 + 
     (G[{0}, yv^(-1)]*G[{1, yv^(-1), yu^(-1), yu^(-1)}, yw])/8 - 
     (G[{0}, yw]*G[{1, yv^(-1), yu^(-1), yu^(-1)}, yw])/8 - 
     (G[{1}, yu^(-1)]*G[{1, yv^(-1), yu^(-1), yu^(-1)}, yw])/8 - 
     (G[{1}, yv^(-1)]*G[{1, yv^(-1), yu^(-1), yu^(-1)}, yw])/8 + 
     (G[{1/(yu*yv)}, yw]*G[{1, yv^(-1), yu^(-1), yu^(-1)}, yw])/8 - 
     (G[{0}, yu^(-1)]*G[{1, yv^(-1), yu^(-1), yv^(-1)}, yw])/8 - 
     (G[{0}, yv^(-1)]*G[{1, yv^(-1), yu^(-1), yv^(-1)}, yw])/8 + 
     (G[{0}, yw]*G[{1, yv^(-1), yu^(-1), yv^(-1)}, yw])/8 + 
     (3*G[{1}, yu^(-1)]*G[{1, yv^(-1), yu^(-1), yv^(-1)}, yw])/8 - 
     (G[{1}, yv^(-1)]*G[{1, yv^(-1), yu^(-1), yv^(-1)}, yw])/8 + 
     (G[{1/(yu*yv)}, yw]*G[{1, yv^(-1), yu^(-1), yv^(-1)}, yw])/8 - 
     (G[{0}, yu^(-1)]*G[{1, yv^(-1), yu^(-1), 1/(yu*yv)}, yw])/8 - 
     (G[{0}, yv^(-1)]*G[{1, yv^(-1), yu^(-1), 1/(yu*yv)}, yw])/8 + 
     (G[{0}, yw]*G[{1, yv^(-1), yu^(-1), 1/(yu*yv)}, yw])/8 - 
     (G[{1}, yu^(-1)]*G[{1, yv^(-1), yu^(-1), 1/(yu*yv)}, yw])/16 + 
     (3*G[{1}, yv^(-1)]*G[{1, yv^(-1), yu^(-1), 1/(yu*yv)}, yw])/16 - 
     (G[{1}, yw]*G[{1, yv^(-1), yu^(-1), 1/(yu*yv)}, yw])/8 + 
     (G[{yu}, yv^(-1)]*G[{1, yv^(-1), yu^(-1), 1/(yu*yv)}, yw])/8 - 
     (G[{0}, yu^(-1)]*G[{1, yv^(-1), yv^(-1), yu^(-1)}, yw])/8 - 
     (G[{0}, yv^(-1)]*G[{1, yv^(-1), yv^(-1), yu^(-1)}, yw])/8 + 
     (G[{0}, yw]*G[{1, yv^(-1), yv^(-1), yu^(-1)}, yw])/8 + 
     (3*G[{1}, yu^(-1)]*G[{1, yv^(-1), yv^(-1), yu^(-1)}, yw])/8 - 
     (G[{1}, yv^(-1)]*G[{1, yv^(-1), yv^(-1), yu^(-1)}, yw])/8 + 
     (G[{1/(yu*yv)}, yw]*G[{1, yv^(-1), yv^(-1), yu^(-1)}, yw])/8 - 
     (G[{0}, yu^(-1)]*G[{1, yv^(-1), yv^(-1), yv^(-1)}, yw])/8 - 
     (G[{0}, yv^(-1)]*G[{1, yv^(-1), yv^(-1), yv^(-1)}, yw])/8 + 
     (G[{0}, yw]*G[{1, yv^(-1), yv^(-1), yv^(-1)}, yw])/8 - 
     (G[{1}, yu^(-1)]*G[{1, yv^(-1), yv^(-1), yv^(-1)}, yw])/8 + 
     (3*G[{1}, yv^(-1)]*G[{1, yv^(-1), yv^(-1), yv^(-1)}, yw])/8 + 
     (G[{0}, yu^(-1)]*G[{1, yv^(-1), yv^(-1), 1/(yu*yv)}, yw])/16 + 
     (G[{0}, yv^(-1)]*G[{1, yv^(-1), yv^(-1), 1/(yu*yv)}, yw])/16 - 
     (G[{0}, yw]*G[{1, yv^(-1), yv^(-1), 1/(yu*yv)}, yw])/16 - 
     (3*G[{1}, yu^(-1)]*G[{1, yv^(-1), yv^(-1), 1/(yu*yv)}, yw])/16 + 
     (5*G[{1}, yv^(-1)]*G[{1, yv^(-1), yv^(-1), 1/(yu*yv)}, yw])/16 + 
     (G[{1}, yw]*G[{1, yv^(-1), yv^(-1), 1/(yu*yv)}, yw])/4 - 
     (G[{yu}, yv^(-1)]*G[{1, yv^(-1), yv^(-1), 1/(yu*yv)}, yw])/4 - 
     (G[{0}, yu^(-1)]*G[{1, yv^(-1), 1/(yu*yv), yu^(-1)}, yw])/16 - 
     (G[{0}, yv^(-1)]*G[{1, yv^(-1), 1/(yu*yv), yu^(-1)}, yw])/16 + 
     (G[{0}, yw]*G[{1, yv^(-1), 1/(yu*yv), yu^(-1)}, yw])/16 + 
     (G[{1}, yu^(-1)]*G[{1, yv^(-1), 1/(yu*yv), yu^(-1)}, yw])/16 + 
     (G[{1}, yv^(-1)]*G[{1, yv^(-1), 1/(yu*yv), yu^(-1)}, yw])/16 + 
     (G[{0}, yu^(-1)]*G[{1, yv^(-1), 1/(yu*yv), yv^(-1)}, yw])/16 + 
     (G[{0}, yv^(-1)]*G[{1, yv^(-1), 1/(yu*yv), yv^(-1)}, yw])/16 - 
     (G[{0}, yw]*G[{1, yv^(-1), 1/(yu*yv), yv^(-1)}, yw])/16 - 
     (3*G[{1}, yu^(-1)]*G[{1, yv^(-1), 1/(yu*yv), yv^(-1)}, yw])/16 + 
     (G[{1}, yv^(-1)]*G[{1, yv^(-1), 1/(yu*yv), yv^(-1)}, yw])/16 + 
     (G[{0}, yu^(-1)]*G[{1, yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/16 + 
     (G[{0}, yv^(-1)]*G[{1, yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/16 - 
     (G[{0}, yw]*G[{1, yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/16 + 
     (G[{1}, yu^(-1)]*G[{1, yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/8 - 
     (3*G[{1}, yv^(-1)]*G[{1, yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/16 + 
     (G[{1}, yw]*G[{1, yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/16 - 
     (G[{yu}, yv^(-1)]*G[{1, yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/16 - 
     (7*G[{1}, yv^(-1)]*G[{1, 1/(yu*yv), yu^(-1), yu^(-1)}, yw])/32 - 
     (7*G[{1}, yw]*G[{1, 1/(yu*yv), yu^(-1), yu^(-1)}, yw])/32 + 
     (7*G[{yu}, yv^(-1)]*G[{1, 1/(yu*yv), yu^(-1), yu^(-1)}, yw])/32 + 
     (11*G[{1/(yu*yv)}, yw]*G[{1, 1/(yu*yv), yu^(-1), yu^(-1)}, yw])/64 - 
     (G[{0}, yu^(-1)]*G[{1, 1/(yu*yv), yu^(-1), 1/(yu*yv)}, yw])/16 - 
     (G[{0}, yv^(-1)]*G[{1, 1/(yu*yv), yu^(-1), 1/(yu*yv)}, yw])/16 + 
     (G[{0}, yw]*G[{1, 1/(yu*yv), yu^(-1), 1/(yu*yv)}, yw])/16 - 
     (G[{1}, yu^(-1)]*G[{1, 1/(yu*yv), yu^(-1), 1/(yu*yv)}, yw])/8 + 
     (15*G[{1}, yv^(-1)]*G[{1, 1/(yu*yv), yu^(-1), 1/(yu*yv)}, yw])/64 - 
     (G[{1}, yw]*G[{1, 1/(yu*yv), yu^(-1), 1/(yu*yv)}, yw])/64 + 
     (G[{yu}, yv^(-1)]*G[{1, 1/(yu*yv), yu^(-1), 1/(yu*yv)}, yw])/64 - 
     (3*G[{1/(yu*yv)}, yw]*G[{1, 1/(yu*yv), yu^(-1), 1/(yu*yv)}, yw])/32 + 
     (G[{1/(yu*yv)}, yw]*G[{1, 1/(yu*yv), yv^(-1), yv^(-1)}, yw])/8 - 
     (G[{0}, yu^(-1)]*G[{1, 1/(yu*yv), yv^(-1), 1/(yu*yv)}, yw])/16 - 
     (G[{0}, yv^(-1)]*G[{1, 1/(yu*yv), yv^(-1), 1/(yu*yv)}, yw])/16 + 
     (G[{0}, yw]*G[{1, 1/(yu*yv), yv^(-1), 1/(yu*yv)}, yw])/16 + 
     (G[{1}, yu^(-1)]*G[{1, 1/(yu*yv), yv^(-1), 1/(yu*yv)}, yw])/4 - 
     (G[{1}, yv^(-1)]*G[{1, 1/(yu*yv), yv^(-1), 1/(yu*yv)}, yw])/4 - 
     (G[{1}, yw]*G[{1, 1/(yu*yv), yv^(-1), 1/(yu*yv)}, yw])/8 + 
     (G[{yu}, yv^(-1)]*G[{1, 1/(yu*yv), yv^(-1), 1/(yu*yv)}, yw])/8 - 
     (G[{1}, yu^(-1)]*G[{1, 1/(yu*yv), 1/(yu*yv), yu^(-1)}, yw])/4 + 
     (7*G[{1}, yv^(-1)]*G[{1, 1/(yu*yv), 1/(yu*yv), yu^(-1)}, yw])/64 - 
     (9*G[{1}, yw]*G[{1, 1/(yu*yv), 1/(yu*yv), yu^(-1)}, yw])/64 + 
     (9*G[{yu}, yv^(-1)]*G[{1, 1/(yu*yv), 1/(yu*yv), yu^(-1)}, yw])/64 - 
     (3*G[{1/(yu*yv)}, yw]*G[{1, 1/(yu*yv), 1/(yu*yv), yu^(-1)}, yw])/32 - 
     (G[{0}, yu^(-1)]*G[{1, 1/(yu*yv), 1/(yu*yv), yv^(-1)}, yw])/8 - 
     (G[{0}, yv^(-1)]*G[{1, 1/(yu*yv), 1/(yu*yv), yv^(-1)}, yw])/8 + 
     (G[{0}, yw]*G[{1, 1/(yu*yv), 1/(yu*yv), yv^(-1)}, yw])/8 + 
     (G[{1}, yu^(-1)]*G[{1, 1/(yu*yv), 1/(yu*yv), yv^(-1)}, yw])/2 - 
     (G[{1}, yv^(-1)]*G[{1, 1/(yu*yv), 1/(yu*yv), yv^(-1)}, yw])/4 - 
     (G[{0}, yu^(-1)]*G[{1, 1/(yu*yv), 1/(yu*yv), 1/(yu*yv)}, yw])/16 - 
     (G[{0}, yv^(-1)]*G[{1, 1/(yu*yv), 1/(yu*yv), 1/(yu*yv)}, yw])/16 + 
     (G[{0}, yw]*G[{1, 1/(yu*yv), 1/(yu*yv), 1/(yu*yv)}, yw])/16 - 
     (3*G[{1}, yu^(-1)]*G[{1, 1/(yu*yv), 1/(yu*yv), 1/(yu*yv)}, yw])/16 - 
     (3*G[{1}, yv^(-1)]*G[{1, 1/(yu*yv), 1/(yu*yv), 1/(yu*yv)}, yw])/64 - 
     (23*G[{1}, yw]*G[{1, 1/(yu*yv), 1/(yu*yv), 1/(yu*yv)}, yw])/64 + 
     (23*G[{yu}, yv^(-1)]*G[{1, 1/(yu*yv), 1/(yu*yv), 1/(yu*yv)}, yw])/64 - 
     (G[{0}, yu^(-1)]*G[{yu^(-1), yu^(-1), yu^(-1), 1/(yu*yv)}, yw])/8 - 
     (G[{0}, yv^(-1)]*G[{yu^(-1), yu^(-1), yu^(-1), 1/(yu*yv)}, yw])/8 + 
     (G[{0}, yw]*G[{yu^(-1), yu^(-1), yu^(-1), 1/(yu*yv)}, yw])/8 + 
     (G[{1}, yu^(-1)]*G[{yu^(-1), yu^(-1), yu^(-1), 1/(yu*yv)}, yw])/8 + 
     (11*G[{1}, yv^(-1)]*G[{yu^(-1), yu^(-1), yu^(-1), 1/(yu*yv)}, yw])/32 + 
     (7*G[{1}, yw]*G[{yu^(-1), yu^(-1), yu^(-1), 1/(yu*yv)}, yw])/32 - 
     (11*G[{yu^(-1)}, yw]*G[{yu^(-1), yu^(-1), yu^(-1), 1/(yu*yv)}, yw])/32 - 
     (7*G[{yu}, yv^(-1)]*G[{yu^(-1), yu^(-1), yu^(-1), 1/(yu*yv)}, yw])/32 - 
     (3*G[{1/(yu*yv)}, yw]*G[{yu^(-1), yu^(-1), yu^(-1), 1/(yu*yv)}, yw])/
      64 + (G[{0}, yu^(-1)]*G[{yu^(-1), yu^(-1), 1/(yu*yv), yv^(-1)}, yw])/
      8 + (G[{0}, yv^(-1)]*G[{yu^(-1), yu^(-1), 1/(yu*yv), yv^(-1)}, yw])/8 - 
     (G[{0}, yw]*G[{yu^(-1), yu^(-1), 1/(yu*yv), yv^(-1)}, yw])/8 - 
     (G[{1}, yu^(-1)]*G[{yu^(-1), yu^(-1), 1/(yu*yv), yv^(-1)}, yw])/8 - 
     (G[{1}, yv^(-1)]*G[{yu^(-1), yu^(-1), 1/(yu*yv), yv^(-1)}, yw])/8 + 
     (G[{yu^(-1)}, yw]*G[{yu^(-1), yu^(-1), 1/(yu*yv), yv^(-1)}, yw])/8 + 
     (G[{1/(yu*yv)}, yw]*G[{yu^(-1), yu^(-1), 1/(yu*yv), yv^(-1)}, yw])/8 - 
     (5*G[{0}, yu^(-1)]*G[{yu^(-1), yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/16 - 
     (5*G[{0}, yv^(-1)]*G[{yu^(-1), yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/16 + 
     (5*G[{0}, yw]*G[{yu^(-1), yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/16 + 
     (5*G[{1}, yu^(-1)]*G[{yu^(-1), yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/16 + 
     (43*G[{1}, yv^(-1)]*G[{yu^(-1), yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/
      64 + (23*G[{1}, yw]*G[{yu^(-1), yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/
      64 - (43*G[{yu^(-1)}, yw]*G[{yu^(-1), yu^(-1), 1/(yu*yv), 1/(yu*yv)}, 
        yw])/64 - (23*G[{yu}, yv^(-1)]*G[{yu^(-1), yu^(-1), 1/(yu*yv), 
         1/(yu*yv)}, yw])/64 - (3*G[{1/(yu*yv)}, yw]*
       G[{yu^(-1), yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/32 + 
     (G[{0}, yu^(-1)]*G[{yu^(-1), 1/(yu*yv), yv^(-1), yv^(-1)}, yw])/8 + 
     (G[{0}, yv^(-1)]*G[{yu^(-1), 1/(yu*yv), yv^(-1), yv^(-1)}, yw])/8 - 
     (G[{0}, yw]*G[{yu^(-1), 1/(yu*yv), yv^(-1), yv^(-1)}, yw])/8 - 
     (3*G[{1}, yu^(-1)]*G[{yu^(-1), 1/(yu*yv), yv^(-1), yv^(-1)}, yw])/8 + 
     (G[{1}, yv^(-1)]*G[{yu^(-1), 1/(yu*yv), yv^(-1), yv^(-1)}, yw])/8 - 
     (G[{yu^(-1)}, yw]*G[{yu^(-1), 1/(yu*yv), yv^(-1), yv^(-1)}, yw])/8 - 
     (G[{1/(yu*yv)}, yw]*G[{yu^(-1), 1/(yu*yv), yv^(-1), yv^(-1)}, yw])/8 + 
     (G[{0}, yu^(-1)]*G[{yu^(-1), 1/(yu*yv), yv^(-1), 1/(yu*yv)}, yw])/8 + 
     (G[{0}, yv^(-1)]*G[{yu^(-1), 1/(yu*yv), yv^(-1), 1/(yu*yv)}, yw])/8 - 
     (G[{0}, yw]*G[{yu^(-1), 1/(yu*yv), yv^(-1), 1/(yu*yv)}, yw])/8 + 
     (G[{1}, yu^(-1)]*G[{yu^(-1), 1/(yu*yv), yv^(-1), 1/(yu*yv)}, yw])/16 - 
     (3*G[{1}, yv^(-1)]*G[{yu^(-1), 1/(yu*yv), yv^(-1), 1/(yu*yv)}, yw])/16 + 
     (G[{1}, yw]*G[{yu^(-1), 1/(yu*yv), yv^(-1), 1/(yu*yv)}, yw])/8 + 
     (3*G[{yu^(-1)}, yw]*G[{yu^(-1), 1/(yu*yv), yv^(-1), 1/(yu*yv)}, yw])/
      16 - (G[{yu}, yv^(-1)]*G[{yu^(-1), 1/(yu*yv), yv^(-1), 1/(yu*yv)}, yw])/
      8 + (3*G[{0}, yu^(-1)]*G[{yu^(-1), 1/(yu*yv), 1/(yu*yv), yv^(-1)}, yw])/
      16 + (3*G[{0}, yv^(-1)]*G[{yu^(-1), 1/(yu*yv), 1/(yu*yv), yv^(-1)}, 
        yw])/16 - (3*G[{0}, yw]*G[{yu^(-1), 1/(yu*yv), 1/(yu*yv), yv^(-1)}, 
        yw])/16 - (G[{1}, yu^(-1)]*G[{yu^(-1), 1/(yu*yv), 1/(yu*yv), 
         yv^(-1)}, yw])/16 - (5*G[{1}, yv^(-1)]*
       G[{yu^(-1), 1/(yu*yv), 1/(yu*yv), yv^(-1)}, yw])/16 + 
     (5*G[{yu^(-1)}, yw]*G[{yu^(-1), 1/(yu*yv), 1/(yu*yv), yv^(-1)}, yw])/
      16 - (G[{0}, yu^(-1)]*G[{yu^(-1), 1/(yu*yv), 1/(yu*yv), 1/(yu*yv)}, 
        yw])/4 - (G[{0}, yv^(-1)]*G[{yu^(-1), 1/(yu*yv), 1/(yu*yv), 
         1/(yu*yv)}, yw])/4 + 
     (G[{0}, yw]*G[{yu^(-1), 1/(yu*yv), 1/(yu*yv), 1/(yu*yv)}, yw])/4 + 
     (3*G[{1}, yu^(-1)]*G[{yu^(-1), 1/(yu*yv), 1/(yu*yv), 1/(yu*yv)}, yw])/
      16 + (23*G[{1}, yv^(-1)]*G[{yu^(-1), 1/(yu*yv), 1/(yu*yv), 1/(yu*yv)}, 
        yw])/64 + (3*G[{1}, yw]*G[{yu^(-1), 1/(yu*yv), 1/(yu*yv), 1/(yu*yv)}, 
        yw])/64 - (23*G[{yu^(-1)}, yw]*G[{yu^(-1), 1/(yu*yv), 1/(yu*yv), 
         1/(yu*yv)}, yw])/64 - (3*G[{yu}, yv^(-1)]*
       G[{yu^(-1), 1/(yu*yv), 1/(yu*yv), 1/(yu*yv)}, yw])/64 + 
     (G[{0}, yu^(-1)]*G[{yv^(-1), yv^(-1), yv^(-1), 1/(yu*yv)}, yw])/8 + 
     (G[{0}, yv^(-1)]*G[{yv^(-1), yv^(-1), yv^(-1), 1/(yu*yv)}, yw])/8 - 
     (G[{0}, yw]*G[{yv^(-1), yv^(-1), yv^(-1), 1/(yu*yv)}, yw])/8 + 
     (G[{1}, yu^(-1)]*G[{yv^(-1), yv^(-1), yv^(-1), 1/(yu*yv)}, yw])/8 - 
     (3*G[{1}, yv^(-1)]*G[{yv^(-1), yv^(-1), yv^(-1), 1/(yu*yv)}, yw])/8 + 
     (3*G[{yu^(-1)}, yw]*G[{yv^(-1), yv^(-1), yv^(-1), 1/(yu*yv)}, yw])/8 - 
     (G[{yv^(-1)}, yw]*G[{yv^(-1), yv^(-1), yv^(-1), 1/(yu*yv)}, yw])/8 + 
     (G[{0}, yu^(-1)]*G[{yv^(-1), yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/16 + 
     (G[{0}, yv^(-1)]*G[{yv^(-1), yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/16 - 
     (G[{0}, yw]*G[{yv^(-1), yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/16 + 
     (G[{1}, yu^(-1)]*G[{yv^(-1), yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/16 - 
     (3*G[{1}, yv^(-1)]*G[{yv^(-1), yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/16 + 
     (3*G[{yu^(-1)}, yw]*G[{yv^(-1), yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/
      16 - (G[{yv^(-1)}, yw]*G[{yv^(-1), yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/
      16 - (G[{0}, yu^(-1)]*G[{yv^(-1), 1/(yu*yv), 1/(yu*yv), 1/(yu*yv)}, 
        yw])/16 - (G[{0}, yv^(-1)]*G[{yv^(-1), 1/(yu*yv), 1/(yu*yv), 
         1/(yu*yv)}, yw])/16 + 
     (G[{0}, yw]*G[{yv^(-1), 1/(yu*yv), 1/(yu*yv), 1/(yu*yv)}, yw])/16 + 
     (G[{1}, yu^(-1)]*G[{yv^(-1), 1/(yu*yv), 1/(yu*yv), 1/(yu*yv)}, yw])/8 + 
     (3*G[{1}, yv^(-1)]*G[{yv^(-1), 1/(yu*yv), 1/(yu*yv), 1/(yu*yv)}, yw])/
      16 + (3*G[{1}, yw]*G[{yv^(-1), 1/(yu*yv), 1/(yu*yv), 1/(yu*yv)}, yw])/
      16 - (3*G[{yu^(-1)}, yw]*G[{yv^(-1), 1/(yu*yv), 1/(yu*yv), 1/(yu*yv)}, 
        yw])/16 - (3*G[{yu}, yv^(-1)]*G[{yv^(-1), 1/(yu*yv), 1/(yu*yv), 
         1/(yu*yv)}, yw])/16 - (G[{yv^(-1)}, yw]*
       G[{yv^(-1), 1/(yu*yv), 1/(yu*yv), 1/(yu*yv)}, yw])/8 + 
     (3*G[{0, 0, 0, 1, 1}, yv^(-1)])/16 - (9*G[{0, 0, 0, 1, 1}, yw])/16 + 
     (9*G[{0, 0, 0, 1, yu^(-1)}, yw])/16 + (3*G[{0, 0, 0, 1, yv^(-1)}, yw])/
      16 - (3*G[{0, 0, 0, 1, 1/(yu*yv)}, yw])/16 + 
     (9*G[{0, 0, 0, yu^(-1), 1}, yw])/16 - 
     (9*G[{0, 0, 0, yu^(-1), yu^(-1)}, yw])/16 - 
     (3*G[{0, 0, 0, yu^(-1), yv^(-1)}, yw])/16 + 
     (3*G[{0, 0, 0, yu^(-1), 1/(yu*yv)}, yw])/16 - 
     (3*G[{0, 0, 0, yu, yu}, yv^(-1)])/16 + (3*G[{0, 0, 0, yv^(-1), 1}, yw])/
      16 - (3*G[{0, 0, 0, yv^(-1), yu^(-1)}, yw])/16 + 
     (3*G[{0, 0, 0, yv^(-1), yv^(-1)}, yw])/16 - 
     (3*G[{0, 0, 0, yv^(-1), 1/(yu*yv)}, yw])/16 - 
     (3*G[{0, 0, 0, 1/(yu*yv), 1}, yw])/16 + 
     (3*G[{0, 0, 0, 1/(yu*yv), yu^(-1)}, yw])/16 - 
     (3*G[{0, 0, 0, 1/(yu*yv), yv^(-1)}, yw])/16 + 
     (3*G[{0, 0, 0, 1/(yu*yv), 1/(yu*yv)}, yw])/16 + 
     (7*G[{0, 0, 1, 0, 1}, yv^(-1)])/64 - (3*G[{0, 0, 1, 0, 1}, yw])/16 + 
     (3*G[{0, 0, 1, 0, yu^(-1)}, yw])/16 - (3*G[{0, 0, 1, 0, yu}, yv^(-1)])/
      64 + G[{0, 0, 1, 0, yv^(-1)}, yw]/16 - G[{0, 0, 1, 0, 1/(yu*yv)}, yw]/
      16 - (15*G[{0, 0, 1, 1, 1}, yu^(-1)])/16 - 
     (3*G[{0, 0, 1, 1, 1}, yv^(-1)])/4 + (3*G[{0, 0, 1, 1, 1}, yw])/8 + 
     (5*G[{0, 0, 1, 1, yu^(-1)}, yw])/16 - (5*G[{0, 0, 1, 1, yu}, yv^(-1)])/
      32 + (3*G[{0, 0, 1, 1, yv^(-1)}, yw])/16 + G[{0, 0, 1, yu^(-1), 1}, yw]/
      8 + (3*G[{0, 0, 1, yu^(-1), yu^(-1)}, yw])/16 + 
     (3*G[{0, 0, 1, yu^(-1), yv^(-1)}, yw])/16 - 
     G[{0, 0, 1, yu^(-1), 1/(yu*yv)}, yw]/8 - 
     (7*G[{0, 0, 1, yu, 1}, yv^(-1)])/64 + (9*G[{0, 0, 1, yu, yu}, yv^(-1)])/
      64 + G[{0, 0, 1, yv^(-1), 1}, yw]/8 + 
     (3*G[{0, 0, 1, yv^(-1), yu^(-1)}, yw])/16 - 
     (5*G[{0, 0, 1, yv^(-1), yv^(-1)}, yw])/16 + 
     G[{0, 0, 1, 1/(yu*yv), yu^(-1)}, yw]/16 + 
     G[{0, 0, 1, 1/(yu*yv), yv^(-1)}, yw]/16 + 
     G[{0, 0, 1, 1/(yu*yv), 1/(yu*yv)}, yw]/8 + 
     (3*G[{0, 0, yu^(-1), 0, 1}, yw])/16 - 
     (3*G[{0, 0, yu^(-1), 0, yu^(-1)}, yw])/16 - 
     G[{0, 0, yu^(-1), 0, yv^(-1)}, yw]/16 + 
     G[{0, 0, yu^(-1), 0, 1/(yu*yv)}, yw]/16 + G[{0, 0, yu^(-1), 1, 1}, yw]/
      4 - (3*G[{0, 0, yu^(-1), 1, yu^(-1)}, yw])/16 + 
     G[{0, 0, yu^(-1), 1, yv^(-1)}, yw]/16 - 
     G[{0, 0, yu^(-1), yu^(-1), 1}, yw]/8 + 
     (9*G[{0, 0, yu^(-1), yu^(-1), yu^(-1)}, yw])/16 - 
     G[{0, 0, yu^(-1), yu^(-1), yv^(-1)}, yw]/16 - 
     G[{0, 0, yu^(-1), yv^(-1), 1}, yw]/4 - 
     G[{0, 0, yu^(-1), yv^(-1), yu^(-1)}, yw]/16 + 
     (5*G[{0, 0, yu^(-1), yv^(-1), yv^(-1)}, yw])/16 + 
     G[{0, 0, yu^(-1), yv^(-1), 1/(yu*yv)}, yw]/8 + 
     G[{0, 0, yu^(-1), 1/(yu*yv), 1}, yw]/8 - 
     G[{0, 0, yu^(-1), 1/(yu*yv), yu^(-1)}, yw]/16 + 
     G[{0, 0, yu^(-1), 1/(yu*yv), yv^(-1)}, yw]/16 - 
     (3*G[{0, 0, yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/8 - 
     (3*G[{0, 0, yu, 0, 1}, yv^(-1)])/64 - G[{0, 0, yu, 0, yu}, yv^(-1)]/64 + 
     G[{0, 0, yu, 1, 1}, yv^(-1)]/32 + (5*G[{0, 0, yu, 1, yu}, yv^(-1)])/16 + 
     (33*G[{0, 0, yu, yu, 1}, yv^(-1)])/64 - 
     (65*G[{0, 0, yu, yu, yu}, yv^(-1)])/64 + G[{0, 0, yv^(-1), 0, 1}, yw]/
      16 - G[{0, 0, yv^(-1), 0, yu^(-1)}, yw]/16 + 
     G[{0, 0, yv^(-1), 0, yv^(-1)}, yw]/16 - 
     G[{0, 0, yv^(-1), 0, 1/(yu*yv)}, yw]/16 - 
     (3*G[{0, 0, yv^(-1), 1, yu^(-1)}, yw])/16 + 
     G[{0, 0, yv^(-1), 1, yv^(-1)}, yw]/16 - 
     G[{0, 0, yv^(-1), yu^(-1), 1}, yw]/4 - 
     G[{0, 0, yv^(-1), yu^(-1), yu^(-1)}, yw]/16 + 
     (3*G[{0, 0, yv^(-1), yu^(-1), yv^(-1)}, yw])/16 + 
     G[{0, 0, yv^(-1), yu^(-1), 1/(yu*yv)}, yw]/8 + 
     (3*G[{0, 0, yv^(-1), yv^(-1), 1}, yw])/8 + 
     G[{0, 0, yv^(-1), yv^(-1), yu^(-1)}, yw]/16 - 
     (7*G[{0, 0, yv^(-1), yv^(-1), yv^(-1)}, yw])/16 - 
     G[{0, 0, yv^(-1), 1/(yu*yv), 1}, yw]/8 - 
     (3*G[{0, 0, yv^(-1), 1/(yu*yv), yu^(-1)}, yw])/16 + 
     G[{0, 0, yv^(-1), 1/(yu*yv), yv^(-1)}, yw]/16 - 
     G[{0, 0, yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw]/8 - 
     G[{0, 0, 1/(yu*yv), 0, 1}, yw]/16 + G[{0, 0, 1/(yu*yv), 0, yu^(-1)}, yw]/
      16 - G[{0, 0, 1/(yu*yv), 0, yv^(-1)}, yw]/16 + 
     G[{0, 0, 1/(yu*yv), 0, 1/(yu*yv)}, yw]/16 - 
     G[{0, 0, 1/(yu*yv), 1, 1}, yw]/8 + 
     (7*G[{0, 0, 1/(yu*yv), 1, yu^(-1)}, yw])/16 - 
     G[{0, 0, 1/(yu*yv), 1, yv^(-1)}, yw]/16 - 
     G[{0, 0, 1/(yu*yv), 1, 1/(yu*yv)}, yw]/8 + 
     (3*G[{0, 0, 1/(yu*yv), yu^(-1), 1}, yw])/8 - 
     (3*G[{0, 0, 1/(yu*yv), yu^(-1), yu^(-1)}, yw])/16 - 
     (3*G[{0, 0, 1/(yu*yv), yu^(-1), yv^(-1)}, yw])/16 - 
     G[{0, 0, 1/(yu*yv), yv^(-1), 1}, yw]/8 - 
     (3*G[{0, 0, 1/(yu*yv), yv^(-1), yu^(-1)}, yw])/16 + 
     G[{0, 0, 1/(yu*yv), yv^(-1), yv^(-1)}, yw]/16 - 
     G[{0, 0, 1/(yu*yv), 1/(yu*yv), 1}, yw]/4 + 
     (7*G[{0, 0, 1/(yu*yv), 1/(yu*yv), yu^(-1)}, yw])/16 + 
     G[{0, 0, 1/(yu*yv), 1/(yu*yv), yv^(-1)}, yw]/16 - 
     (3*G[{0, 0, 1/(yu*yv), 1/(yu*yv), 1/(yu*yv)}, yw])/8 - 
     (5*G[{0, 1, 0, 1, 1}, yu^(-1)])/16 - (15*G[{0, 1, 0, 1, 1}, yv^(-1)])/
      64 + G[{0, 1, 0, 1, 1}, yw]/4 + (3*G[{0, 1, 0, 1, yu^(-1)}, yw])/16 - 
     (7*G[{0, 1, 0, 1, yu}, yv^(-1)])/64 + G[{0, 1, 0, 1, yv^(-1)}, yw]/8 - 
     G[{0, 1, 0, 1, 1/(yu*yv)}, yw]/16 + G[{0, 1, 0, yu^(-1), 1}, yw]/16 - 
     G[{0, 1, 0, yu^(-1), yu^(-1)}, yw]/16 + 
     G[{0, 1, 0, yu^(-1), yv^(-1)}, yw]/16 - G[{0, 1, 0, yu, 1}, yv^(-1)]/
      16 - G[{0, 1, 0, yu, yu}, yv^(-1)]/16 + G[{0, 1, 0, yv^(-1), 1}, yw]/
      16 + G[{0, 1, 0, yv^(-1), yu^(-1)}, yw]/16 - 
     (3*G[{0, 1, 0, yv^(-1), yv^(-1)}, yw])/16 + 
     G[{0, 1, 0, yv^(-1), 1/(yu*yv)}, yw]/16 - G[{0, 1, 0, 1/(yu*yv), 1}, yw]/
      8 + G[{0, 1, 0, 1/(yu*yv), yu^(-1)}, yw]/8 + 
     G[{0, 1, 0, 1/(yu*yv), yv^(-1)}, yw]/8 + 
     G[{0, 1, 0, 1/(yu*yv), 1/(yu*yv)}, yw]/16 + 
     (3*G[{0, 1, 1, 0, yu^(-1)}, yw])/16 - (3*G[{0, 1, 1, 0, yu}, yv^(-1)])/
      64 + (3*G[{0, 1, 1, 0, yv^(-1)}, yw])/16 - 
     G[{0, 1, 1, 0, 1/(yu*yv)}, yw]/8 - G[{0, 1, 1, 1, 1}, yu^(-1)]/8 - 
     G[{0, 1, 1, 1, 1}, yv^(-1)]/4 - (3*G[{0, 1, 1, 1, 1}, yw])/16 - 
     G[{0, 1, 1, 1, yu^(-1)}, yw]/8 + (9*G[{0, 1, 1, 1, yu}, yv^(-1)])/64 - 
     (3*G[{0, 1, 1, 1, yv^(-1)}, yw])/16 + G[{0, 1, 1, 1, 1/(yu*yv)}, yw]/8 - 
     G[{0, 1, 1, yu^(-1), 1}, yw]/16 + (3*G[{0, 1, 1, yu^(-1), yu^(-1)}, yw])/
      16 + G[{0, 1, 1, yu^(-1), yv^(-1)}, yw]/16 + 
     (3*G[{0, 1, 1, yu, 1}, yv^(-1)])/32 - (9*G[{0, 1, 1, yu, yu}, yv^(-1)])/
      64 - G[{0, 1, 1, yv^(-1), 1}, yw]/16 + 
     G[{0, 1, 1, yv^(-1), yu^(-1)}, yw]/16 + 
     (3*G[{0, 1, 1, yv^(-1), yv^(-1)}, yw])/16 + 
     (5*G[{0, 1, 1, 1/(yu*yv), 1}, yw])/16 - 
     G[{0, 1, 1, 1/(yu*yv), yu^(-1)}, yw]/16 - 
     G[{0, 1, 1, 1/(yu*yv), yv^(-1)}, yw]/4 + 
     G[{0, 1, yu^(-1), 0, yu^(-1)}, yw]/16 - 
     G[{0, 1, yu^(-1), 0, yv^(-1)}, yw]/16 - G[{0, 1, yu^(-1), 1, 1}, yw]/8 + 
     (3*G[{0, 1, yu^(-1), 1, yu^(-1)}, yw])/16 + 
     G[{0, 1, yu^(-1), 1, yv^(-1)}, yw]/16 + 
     G[{0, 1, yu^(-1), yu^(-1), 1}, yw]/4 + 
     G[{0, 1, yu^(-1), yu^(-1), yu^(-1)}, yw]/8 + 
     G[{0, 1, yu^(-1), yu^(-1), yv^(-1)}, yw]/8 - 
     G[{0, 1, yu^(-1), yu^(-1), 1/(yu*yv)}, yw]/8 + 
     G[{0, 1, yu^(-1), yv^(-1), 1}, yw]/8 + 
     G[{0, 1, yu^(-1), yv^(-1), yu^(-1)}, yw]/8 - 
     G[{0, 1, yu^(-1), yv^(-1), yv^(-1)}, yw]/8 - 
     G[{0, 1, yu^(-1), yv^(-1), 1/(yu*yv)}, yw]/8 - 
     G[{0, 1, yu^(-1), 1/(yu*yv), 1}, yw]/8 - 
     (3*G[{0, 1, yu^(-1), 1/(yu*yv), yu^(-1)}, yw])/16 + 
     G[{0, 1, yu^(-1), 1/(yu*yv), yv^(-1)}, yw]/16 - 
     G[{0, 1, yu, 0, yu}, yv^(-1)]/8 + G[{0, 1, yu, 1, 1}, yv^(-1)]/32 - 
     (17*G[{0, 1, yu, 1, yu}, yv^(-1)])/64 - 
     (13*G[{0, 1, yu, yu, 1}, yv^(-1)])/64 + 
     (25*G[{0, 1, yu, yu, yu}, yv^(-1)])/32 + 
     G[{0, 1, yv^(-1), 0, yu^(-1)}, yw]/8 - 
     G[{0, 1, yv^(-1), 0, yv^(-1)}, yw]/8 + 
     G[{0, 1, yv^(-1), 0, 1/(yu*yv)}, yw]/16 + 
     G[{0, 1, yv^(-1), 1, yu^(-1)}, yw]/8 + 
     G[{0, 1, yv^(-1), 1, yv^(-1)}, yw]/8 + 
     G[{0, 1, yv^(-1), yu^(-1), 1}, yw]/8 + 
     G[{0, 1, yv^(-1), yu^(-1), yu^(-1)}, yw]/8 - 
     G[{0, 1, yv^(-1), yu^(-1), yv^(-1)}, yw]/8 - 
     G[{0, 1, yv^(-1), yu^(-1), 1/(yu*yv)}, yw]/8 - 
     G[{0, 1, yv^(-1), yv^(-1), yu^(-1)}, yw]/8 - 
     G[{0, 1, yv^(-1), yv^(-1), yv^(-1)}, yw]/8 - 
     G[{0, 1, yv^(-1), yv^(-1), 1/(yu*yv)}, yw]/8 - 
     G[{0, 1, yv^(-1), 1/(yu*yv), yu^(-1)}, yw]/8 - 
     G[{0, 1, 1/(yu*yv), 0, yu^(-1)}, yw]/16 + 
     G[{0, 1, 1/(yu*yv), 0, yv^(-1)}, yw]/16 + 
     G[{0, 1, 1/(yu*yv), 0, 1/(yu*yv)}, yw]/16 + 
     (5*G[{0, 1, 1/(yu*yv), 1, 1}, yw])/16 - 
     G[{0, 1, 1/(yu*yv), 1, yu^(-1)}, yw]/8 - 
     (3*G[{0, 1, 1/(yu*yv), 1, yv^(-1)}, yw])/16 - 
     G[{0, 1, 1/(yu*yv), yu^(-1), 1}, yw]/16 - 
     G[{0, 1, 1/(yu*yv), yu^(-1), yu^(-1)}, yw]/16 + 
     G[{0, 1, 1/(yu*yv), yu^(-1), yv^(-1)}, yw]/16 - 
     G[{0, 1, 1/(yu*yv), yv^(-1), 1}, yw]/16 + 
     G[{0, 1, 1/(yu*yv), yv^(-1), yu^(-1)}, yw]/16 - 
     G[{0, 1, 1/(yu*yv), yv^(-1), yv^(-1)}, yw]/16 - 
     G[{0, 1, 1/(yu*yv), 1/(yu*yv), 1}, yw]/16 + 
     (3*G[{0, 1, 1/(yu*yv), 1/(yu*yv), yu^(-1)}, yw])/16 + 
     (5*G[{0, yu^(-1), 0, yu^(-1), yu^(-1)}, yw])/16 - 
     G[{0, yu^(-1), 0, yv^(-1), 1}, yw]/8 + 
     (3*G[{0, yu^(-1), 0, yv^(-1), yv^(-1)}, yw])/16 + 
     (3*G[{0, yu^(-1), 0, 1/(yu*yv), 1}, yw])/16 - 
     G[{0, yu^(-1), 0, 1/(yu*yv), yu^(-1)}, yw]/8 - 
     G[{0, yu^(-1), 0, 1/(yu*yv), yv^(-1)}, yw]/16 - 
     (3*G[{0, yu^(-1), 0, 1/(yu*yv), 1/(yu*yv)}, yw])/16 - 
     G[{0, yu^(-1), 1, 0, yv^(-1)}, yw]/8 + (3*G[{0, yu^(-1), 1, 1, 1}, yw])/
      16 + G[{0, yu^(-1), 1, 1, yu^(-1)}, yw]/8 + 
     (3*G[{0, yu^(-1), 1, 1, yv^(-1)}, yw])/16 + 
     G[{0, yu^(-1), 1, yu^(-1), 1}, yw]/16 - 
     (3*G[{0, yu^(-1), 1, yu^(-1), yu^(-1)}, yw])/16 - 
     G[{0, yu^(-1), 1, yu^(-1), yv^(-1)}, yw]/16 + 
     G[{0, yu^(-1), 1, yv^(-1), 1}, yw]/16 - 
     G[{0, yu^(-1), 1, yv^(-1), yu^(-1)}, yw]/16 - 
     G[{0, yu^(-1), 1, yv^(-1), yv^(-1)}, yw]/16 - 
     G[{0, yu^(-1), 1, 1/(yu*yv), 1}, yw]/16 - 
     G[{0, yu^(-1), 1, 1/(yu*yv), yu^(-1)}, yw]/16 + 
     G[{0, yu^(-1), 1, 1/(yu*yv), yv^(-1)}, yw]/8 - 
     G[{0, yu^(-1), yu^(-1), 0, yv^(-1)}, yw]/16 + 
     (3*G[{0, yu^(-1), yu^(-1), 0, 1/(yu*yv)}, yw])/16 + 
     G[{0, yu^(-1), yu^(-1), 1, 1}, yw]/8 - 
     (3*G[{0, yu^(-1), yu^(-1), 1, yu^(-1)}, yw])/16 - 
     G[{0, yu^(-1), yu^(-1), 1, yv^(-1)}, yw]/16 - 
     G[{0, yu^(-1), yu^(-1), yu^(-1), 1}, yw]/4 - 
     G[{0, yu^(-1), yu^(-1), yu^(-1), yu^(-1)}, yw]/8 - 
     G[{0, yu^(-1), yu^(-1), yu^(-1), yv^(-1)}, yw]/8 - 
     G[{0, yu^(-1), yu^(-1), yv^(-1), 1}, yw]/8 - 
     G[{0, yu^(-1), yu^(-1), yv^(-1), yu^(-1)}, yw]/8 - 
     G[{0, yu^(-1), yu^(-1), yv^(-1), yv^(-1)}, yw]/8 + 
     G[{0, yu^(-1), yu^(-1), yv^(-1), 1/(yu*yv)}, yw]/8 - 
     G[{0, yu^(-1), yu^(-1), 1/(yu*yv), 1}, yw]/8 + 
     (5*G[{0, yu^(-1), yu^(-1), 1/(yu*yv), yu^(-1)}, yw])/16 + 
     (3*G[{0, yu^(-1), yu^(-1), 1/(yu*yv), yv^(-1)}, yw])/16 + 
     G[{0, yu^(-1), yv^(-1), 0, yv^(-1)}, yw]/16 - 
     G[{0, yu^(-1), yv^(-1), 1, 1}, yw]/8 - 
     G[{0, yu^(-1), yv^(-1), 1, yu^(-1)}, yw]/16 - 
     G[{0, yu^(-1), yv^(-1), 1, yv^(-1)}, yw]/16 - 
     G[{0, yu^(-1), yv^(-1), yu^(-1), 1}, yw]/8 - 
     G[{0, yu^(-1), yv^(-1), yu^(-1), yu^(-1)}, yw]/8 - 
     G[{0, yu^(-1), yv^(-1), yu^(-1), yv^(-1)}, yw]/8 + 
     G[{0, yu^(-1), yv^(-1), yu^(-1), 1/(yu*yv)}, yw]/8 - 
     G[{0, yu^(-1), yv^(-1), yv^(-1), 1}, yw]/8 - 
     G[{0, yu^(-1), yv^(-1), yv^(-1), yu^(-1)}, yw]/8 + 
     (3*G[{0, yu^(-1), yv^(-1), yv^(-1), yv^(-1)}, yw])/8 + 
     G[{0, yu^(-1), yv^(-1), yv^(-1), 1/(yu*yv)}, yw]/8 + 
     G[{0, yu^(-1), yv^(-1), 1/(yu*yv), 1}, yw]/8 + 
     (3*G[{0, yu^(-1), yv^(-1), 1/(yu*yv), yu^(-1)}, yw])/16 - 
     G[{0, yu^(-1), yv^(-1), 1/(yu*yv), yv^(-1)}, yw]/16 + 
     G[{0, yu^(-1), 1/(yu*yv), 0, yv^(-1)}, yw]/16 - 
     (3*G[{0, yu^(-1), 1/(yu*yv), 0, 1/(yu*yv)}, yw])/16 - 
     G[{0, yu^(-1), 1/(yu*yv), 1, 1}, yw]/16 - 
     (3*G[{0, yu^(-1), 1/(yu*yv), 1, yu^(-1)}, yw])/16 + 
     G[{0, yu^(-1), 1/(yu*yv), 1, yv^(-1)}, yw]/8 - 
     G[{0, yu^(-1), 1/(yu*yv), yu^(-1), 1}, yw]/16 + 
     (5*G[{0, yu^(-1), 1/(yu*yv), yu^(-1), yu^(-1)}, yw])/16 + 
     (3*G[{0, yu^(-1), 1/(yu*yv), yu^(-1), yv^(-1)}, yw])/16 + 
     (3*G[{0, yu^(-1), 1/(yu*yv), yv^(-1), 1}, yw])/16 + 
     (3*G[{0, yu^(-1), 1/(yu*yv), yv^(-1), yu^(-1)}, yw])/16 - 
     G[{0, yu^(-1), 1/(yu*yv), yv^(-1), yv^(-1)}, yw]/16 - 
     G[{0, yu^(-1), 1/(yu*yv), 1/(yu*yv), 1}, yw]/16 - 
     G[{0, yu^(-1), 1/(yu*yv), 1/(yu*yv), yu^(-1)}, yw]/4 - 
     G[{0, yu^(-1), 1/(yu*yv), 1/(yu*yv), yv^(-1)}, yw]/16 + 
     (9*G[{0, yu, 0, yu, 1}, yv^(-1)])/64 - 
     (3*G[{0, yu, 0, yu, yu}, yv^(-1)])/16 + G[{0, yu, 1, 1, 1}, yv^(-1)]/
      16 - G[{0, yu, 1, 1, yu}, yv^(-1)]/64 - 
     (3*G[{0, yu, 1, yu, 1}, yv^(-1)])/32 + 
     (25*G[{0, yu, 1, yu, yu}, yv^(-1)])/64 + G[{0, yu, yu, 1, 1}, yv^(-1)]/
      32 + (25*G[{0, yu, yu, 1, yu}, yv^(-1)])/64 + 
     (21*G[{0, yu, yu, yu, 1}, yv^(-1)])/64 - 
     (41*G[{0, yu, yu, yu, yu}, yv^(-1)])/32 + 
     G[{0, yv^(-1), 0, yv^(-1), 1}, yw]/8 - 
     G[{0, yv^(-1), 0, yv^(-1), yu^(-1)}, yw]/16 - 
     (3*G[{0, yv^(-1), 0, yv^(-1), yv^(-1)}, yw])/16 - 
     G[{0, yv^(-1), 0, 1/(yu*yv), 1}, yw]/16 - 
     G[{0, yv^(-1), 0, 1/(yu*yv), yu^(-1)}, yw]/16 + 
     G[{0, yv^(-1), 0, 1/(yu*yv), yv^(-1)}, yw]/16 - 
     G[{0, yv^(-1), 0, 1/(yu*yv), 1/(yu*yv)}, yw]/16 - 
     (3*G[{0, yv^(-1), 1, 1, 1}, yw])/16 - G[{0, yv^(-1), 1, 1, yu^(-1)}, yw]/
      16 + G[{0, yv^(-1), 1, 1, yv^(-1)}, yw]/4 - 
     (3*G[{0, yv^(-1), 1, yu^(-1), 1}, yw])/16 + 
     G[{0, yv^(-1), 1, yu^(-1), yu^(-1)}, yw]/16 - 
     G[{0, yv^(-1), 1, yu^(-1), yv^(-1)}, yw]/16 + 
     G[{0, yv^(-1), 1, yv^(-1), 1}, yw]/16 - 
     G[{0, yv^(-1), 1, yv^(-1), yu^(-1)}, yw]/16 - 
     G[{0, yv^(-1), 1, yv^(-1), yv^(-1)}, yw]/16 + 
     G[{0, yv^(-1), 1, 1/(yu*yv), 1}, yw]/16 - 
     G[{0, yv^(-1), 1, 1/(yu*yv), yu^(-1)}, yw]/8 + 
     G[{0, yv^(-1), 1, 1/(yu*yv), yv^(-1)}, yw]/16 - 
     G[{0, yv^(-1), yu^(-1), 1, 1}, yw]/8 - 
     G[{0, yv^(-1), yu^(-1), 1, yu^(-1)}, yw]/16 - 
     G[{0, yv^(-1), yu^(-1), 1, yv^(-1)}, yw]/16 - 
     G[{0, yv^(-1), yu^(-1), yu^(-1), 1}, yw]/8 - 
     G[{0, yv^(-1), yu^(-1), yu^(-1), yu^(-1)}, yw]/8 - 
     G[{0, yv^(-1), yu^(-1), yu^(-1), yv^(-1)}, yw]/8 + 
     G[{0, yv^(-1), yu^(-1), yu^(-1), 1/(yu*yv)}, yw]/8 - 
     G[{0, yv^(-1), yu^(-1), yv^(-1), 1}, yw]/8 - 
     G[{0, yv^(-1), yu^(-1), yv^(-1), yu^(-1)}, yw]/8 + 
     (3*G[{0, yv^(-1), yu^(-1), yv^(-1), yv^(-1)}, yw])/8 + 
     G[{0, yv^(-1), yu^(-1), yv^(-1), 1/(yu*yv)}, yw]/8 + 
     G[{0, yv^(-1), yu^(-1), 1/(yu*yv), 1}, yw]/8 + 
     (3*G[{0, yv^(-1), yu^(-1), 1/(yu*yv), yu^(-1)}, yw])/16 - 
     G[{0, yv^(-1), yu^(-1), 1/(yu*yv), yv^(-1)}, yw]/16 - 
     G[{0, yv^(-1), yv^(-1), 0, 1/(yu*yv)}, yw]/16 + 
     G[{0, yv^(-1), yv^(-1), 1, 1}, yw]/8 - 
     (3*G[{0, yv^(-1), yv^(-1), 1, yu^(-1)}, yw])/16 - 
     G[{0, yv^(-1), yv^(-1), 1, yv^(-1)}, yw]/16 - 
     G[{0, yv^(-1), yv^(-1), yu^(-1), 1}, yw]/8 - 
     G[{0, yv^(-1), yv^(-1), yu^(-1), yu^(-1)}, yw]/8 + 
     (3*G[{0, yv^(-1), yv^(-1), yu^(-1), yv^(-1)}, yw])/8 + 
     G[{0, yv^(-1), yv^(-1), yu^(-1), 1/(yu*yv)}, yw]/8 + 
     G[{0, yv^(-1), yv^(-1), yv^(-1), 1}, yw]/4 + 
     (3*G[{0, yv^(-1), yv^(-1), yv^(-1), yu^(-1)}, yw])/8 - 
     G[{0, yv^(-1), yv^(-1), yv^(-1), yv^(-1)}, yw]/8 - 
     G[{0, yv^(-1), yv^(-1), 1/(yu*yv), 1}, yw]/8 + 
     G[{0, yv^(-1), yv^(-1), 1/(yu*yv), yu^(-1)}, yw]/16 - 
     G[{0, yv^(-1), yv^(-1), 1/(yu*yv), yv^(-1)}, yw]/16 - 
     G[{0, yv^(-1), 1/(yu*yv), 0, 1/(yu*yv)}, yw]/16 + 
     G[{0, yv^(-1), 1/(yu*yv), 1, 1}, yw]/16 + 
     G[{0, yv^(-1), 1/(yu*yv), 1, yv^(-1)}, yw]/16 - 
     G[{0, yv^(-1), 1/(yu*yv), yu^(-1), 1}, yw]/16 + 
     G[{0, yv^(-1), 1/(yu*yv), yu^(-1), yu^(-1)}, yw]/16 - 
     G[{0, yv^(-1), 1/(yu*yv), yu^(-1), yv^(-1)}, yw]/16 - 
     G[{0, yv^(-1), 1/(yu*yv), yv^(-1), 1}, yw]/16 - 
     G[{0, yv^(-1), 1/(yu*yv), yv^(-1), yu^(-1)}, yw]/16 - 
     G[{0, yv^(-1), 1/(yu*yv), yv^(-1), yv^(-1)}, yw]/16 + 
     G[{0, yv^(-1), 1/(yu*yv), 1/(yu*yv), 1}, yw]/16 - 
     (3*G[{0, yv^(-1), 1/(yu*yv), 1/(yu*yv), yu^(-1)}, yw])/16 - 
     G[{0, 1/(yu*yv), 0, 1/(yu*yv), 1}, yw]/8 + 
     (3*G[{0, 1/(yu*yv), 0, 1/(yu*yv), yu^(-1)}, yw])/16 - 
     (3*G[{0, 1/(yu*yv), 0, 1/(yu*yv), 1/(yu*yv)}, yw])/16 + 
     (3*G[{0, 1/(yu*yv), 1, 1, 1}, yw])/16 + 
     G[{0, 1/(yu*yv), 1, 1, yu^(-1)}, yw]/16 - 
     G[{0, 1/(yu*yv), 1, 1, yv^(-1)}, yw]/4 - 
     G[{0, 1/(yu*yv), 1, 1, 1/(yu*yv)}, yw]/8 + 
     (3*G[{0, 1/(yu*yv), 1, yu^(-1), 1}, yw])/16 - 
     G[{0, 1/(yu*yv), 1, yu^(-1), yu^(-1)}, yw]/16 + 
     G[{0, 1/(yu*yv), 1, yu^(-1), yv^(-1)}, yw]/16 - 
     G[{0, 1/(yu*yv), 1, yv^(-1), 1}, yw]/16 + 
     G[{0, 1/(yu*yv), 1, yv^(-1), yu^(-1)}, yw]/16 - 
     G[{0, 1/(yu*yv), 1, yv^(-1), yv^(-1)}, yw]/16 - 
     (5*G[{0, 1/(yu*yv), 1, 1/(yu*yv), 1}, yw])/16 + 
     G[{0, 1/(yu*yv), 1, 1/(yu*yv), yu^(-1)}, yw]/4 + 
     G[{0, 1/(yu*yv), 1, 1/(yu*yv), yv^(-1)}, yw]/16 + 
     G[{0, 1/(yu*yv), yu^(-1), 1, 1}, yw]/8 + 
     G[{0, 1/(yu*yv), yu^(-1), 1, yu^(-1)}, yw]/16 + 
     G[{0, 1/(yu*yv), yu^(-1), 1, yv^(-1)}, yw]/16 + 
     G[{0, 1/(yu*yv), yu^(-1), yu^(-1), 1}, yw]/8 + 
     G[{0, 1/(yu*yv), yu^(-1), yu^(-1), yu^(-1)}, yw]/8 + 
     G[{0, 1/(yu*yv), yu^(-1), yu^(-1), yv^(-1)}, yw]/8 + 
     G[{0, 1/(yu*yv), yu^(-1), yv^(-1), 1}, yw]/8 + 
     G[{0, 1/(yu*yv), yu^(-1), yv^(-1), yu^(-1)}, yw]/8 - 
     G[{0, 1/(yu*yv), yu^(-1), yv^(-1), yv^(-1)}, yw]/8 - 
     G[{0, 1/(yu*yv), yu^(-1), yv^(-1), 1/(yu*yv)}, yw]/8 + 
     G[{0, 1/(yu*yv), yu^(-1), 1/(yu*yv), 1}, yw]/8 - 
     (5*G[{0, 1/(yu*yv), yu^(-1), 1/(yu*yv), yu^(-1)}, yw])/16 - 
     (3*G[{0, 1/(yu*yv), yu^(-1), 1/(yu*yv), yv^(-1)}, yw])/16 + 
     G[{0, 1/(yu*yv), yv^(-1), 1, yu^(-1)}, yw]/8 + 
     G[{0, 1/(yu*yv), yv^(-1), yu^(-1), 1}, yw]/8 + 
     G[{0, 1/(yu*yv), yv^(-1), yu^(-1), yu^(-1)}, yw]/8 - 
     G[{0, 1/(yu*yv), yv^(-1), yu^(-1), yv^(-1)}, yw]/8 - 
     G[{0, 1/(yu*yv), yv^(-1), yu^(-1), 1/(yu*yv)}, yw]/8 - 
     G[{0, 1/(yu*yv), yv^(-1), yv^(-1), 1}, yw]/8 - 
     G[{0, 1/(yu*yv), yv^(-1), yv^(-1), yu^(-1)}, yw]/8 - 
     G[{0, 1/(yu*yv), yv^(-1), yv^(-1), yv^(-1)}, yw]/8 - 
     G[{0, 1/(yu*yv), yv^(-1), 1/(yu*yv), yu^(-1)}, yw]/8 + 
     G[{0, 1/(yu*yv), yv^(-1), 1/(yu*yv), yv^(-1)}, yw]/8 - 
     (5*G[{0, 1/(yu*yv), 1/(yu*yv), 1, 1}, yw])/16 + 
     (5*G[{0, 1/(yu*yv), 1/(yu*yv), 1, yu^(-1)}, yw])/16 + 
     (3*G[{0, 1/(yu*yv), 1/(yu*yv), yu^(-1), 1}, yw])/16 - 
     (5*G[{0, 1/(yu*yv), 1/(yu*yv), yu^(-1), yu^(-1)}, yw])/16 - 
     (3*G[{0, 1/(yu*yv), 1/(yu*yv), yu^(-1), yv^(-1)}, yw])/16 - 
     G[{0, 1/(yu*yv), 1/(yu*yv), yv^(-1), 1}, yw]/16 - 
     (3*G[{0, 1/(yu*yv), 1/(yu*yv), yv^(-1), yu^(-1)}, yw])/16 + 
     (3*G[{0, 1/(yu*yv), 1/(yu*yv), yv^(-1), yv^(-1)}, yw])/16 + 
     G[{0, 1/(yu*yv), 1/(yu*yv), 1/(yu*yv), 1}, yw]/16 + 
     G[{0, 1/(yu*yv), 1/(yu*yv), 1/(yu*yv), yu^(-1)}, yw]/4 + 
     G[{0, 1/(yu*yv), 1/(yu*yv), 1/(yu*yv), yv^(-1)}, yw]/16 + 
     (5*G[{1, 1, 1, 1, yu^(-1)}, yw])/16 + G[{1, 1, 1, 1, yu}, yv^(-1)]/16 - 
     (7*G[{1, 1, 1, 1, yv^(-1)}, yw])/16 + G[{1, 1, 1, 1, 1/(yu*yv)}, yw]/2 - 
     G[{1, 1, 1, yu^(-1), yu^(-1)}, yw]/8 + 
     (5*G[{1, 1, 1, yu^(-1), yv^(-1)}, yw])/8 - 
     (7*G[{1, 1, 1, yu^(-1), 1/(yu*yv)}, yw])/16 + 
     (5*G[{1, 1, 1, yu, yu}, yv^(-1)])/8 + 
     (5*G[{1, 1, 1, yv^(-1), yu^(-1)}, yw])/8 + 
     (7*G[{1, 1, 1, yv^(-1), yv^(-1)}, yw])/8 - 
     (19*G[{1, 1, 1, yv^(-1), 1/(yu*yv)}, yw])/16 - 
     (3*G[{1, 1, 1, 1/(yu*yv), yu^(-1)}, yw])/8 - 
     (9*G[{1, 1, 1, 1/(yu*yv), yv^(-1)}, yw])/8 + 
     3*G[{1, 1, 1, 1/(yu*yv), 1/(yu*yv)}, yw] + 
     (5*G[{1, 1, yu^(-1), 1, yu^(-1)}, yw])/64 + 
     (5*G[{1, 1, yu^(-1), 1, yv^(-1)}, yw])/16 - 
     (9*G[{1, 1, yu^(-1), 1, 1/(yu*yv)}, yw])/64 - 
     (19*G[{1, 1, yu^(-1), yu^(-1), yu^(-1)}, yw])/64 + 
     G[{1, 1, yu^(-1), yu^(-1), yv^(-1)}, yw]/16 - 
     (5*G[{1, 1, yu^(-1), yu^(-1), 1/(yu*yv)}, yw])/64 + 
     G[{1, 1, yu^(-1), yv^(-1), yu^(-1)}, yw]/16 - 
     (5*G[{1, 1, yu^(-1), yv^(-1), yv^(-1)}, yw])/16 - 
     G[{1, 1, yu^(-1), 1/(yu*yv), yv^(-1)}, yw]/16 - 
     G[{1, 1, yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw]/4 + 
     (13*G[{1, 1, yu, 1, yu}, yv^(-1)])/64 + 
     (81*G[{1, 1, yu, yu, yu}, yv^(-1)])/64 + 
     (3*G[{1, 1, yv^(-1), 1, yu^(-1)}, yw])/16 + 
     (3*G[{1, 1, yv^(-1), 1, yv^(-1)}, yw])/8 - 
     (7*G[{1, 1, yv^(-1), 1, 1/(yu*yv)}, yw])/16 + 
     G[{1, 1, yv^(-1), yu^(-1), yu^(-1)}, yw]/16 - 
     (3*G[{1, 1, yv^(-1), yu^(-1), yv^(-1)}, yw])/16 - 
     G[{1, 1, yv^(-1), yv^(-1), yu^(-1)}, yw]/16 - 
     (13*G[{1, 1, yv^(-1), yv^(-1), yv^(-1)}, yw])/16 - 
     (3*G[{1, 1, yv^(-1), yv^(-1), 1/(yu*yv)}, yw])/8 + 
     (3*G[{1, 1, yv^(-1), 1/(yu*yv), yu^(-1)}, yw])/16 - 
     G[{1, 1, yv^(-1), 1/(yu*yv), yv^(-1)}, yw]/4 - 
     G[{1, 1, yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw]/8 - 
     (9*G[{1, 1, 1/(yu*yv), 1, yu^(-1)}, yw])/64 - 
     (7*G[{1, 1, 1/(yu*yv), 1, yv^(-1)}, yw])/16 + 
     (61*G[{1, 1, 1/(yu*yv), 1, 1/(yu*yv)}, yw])/64 + 
     (7*G[{1, 1, 1/(yu*yv), yu^(-1), yu^(-1)}, yw])/64 + 
     G[{1, 1, 1/(yu*yv), yu^(-1), yv^(-1)}, yw]/4 - 
     (5*G[{1, 1, 1/(yu*yv), yu^(-1), 1/(yu*yv)}, yw])/64 + 
     G[{1, 1, 1/(yu*yv), yv^(-1), yu^(-1)}, yw]/4 - 
     G[{1, 1, 1/(yu*yv), yv^(-1), yv^(-1)}, yw]/2 - 
     G[{1, 1, 1/(yu*yv), yv^(-1), 1/(yu*yv)}, yw]/8 - 
     (3*G[{1, 1, 1/(yu*yv), 1/(yu*yv), yu^(-1)}, yw])/16 - 
     (5*G[{1, 1, 1/(yu*yv), 1/(yu*yv), yv^(-1)}, yw])/16 - 
     (7*G[{1, 1, 1/(yu*yv), 1/(yu*yv), 1/(yu*yv)}, yw])/16 + 
     G[{1, yu^(-1), 1, yu^(-1), yu^(-1)}, yw]/8 + 
     G[{1, yu^(-1), 1, yu^(-1), yv^(-1)}, yw]/8 - 
     (5*G[{1, yu^(-1), 1, yu^(-1), 1/(yu*yv)}, yw])/64 + 
     G[{1, yu^(-1), 1, yv^(-1), yu^(-1)}, yw]/8 - 
     (3*G[{1, yu^(-1), 1, yv^(-1), yv^(-1)}, yw])/16 - 
     G[{1, yu^(-1), 1, 1/(yu*yv), yu^(-1)}, yw]/8 - 
     G[{1, yu^(-1), 1, 1/(yu*yv), yv^(-1)}, yw]/16 - 
     (5*G[{1, yu^(-1), 1, 1/(yu*yv), 1/(yu*yv)}, yw])/64 + 
     G[{1, yu^(-1), yu^(-1), 1, yv^(-1)}, yw]/16 - 
     G[{1, yu^(-1), yu^(-1), 1, 1/(yu*yv)}, yw]/16 - 
     (3*G[{1, yu^(-1), yu^(-1), yu^(-1), yu^(-1)}, yw])/32 + 
     G[{1, yu^(-1), yu^(-1), yu^(-1), yv^(-1)}, yw]/8 + 
     (3*G[{1, yu^(-1), yu^(-1), yu^(-1), 1/(yu*yv)}, yw])/64 + 
     G[{1, yu^(-1), yu^(-1), yv^(-1), yu^(-1)}, yw]/8 + 
     G[{1, yu^(-1), yu^(-1), yv^(-1), yv^(-1)}, yw]/8 - 
     G[{1, yu^(-1), yu^(-1), yv^(-1), 1/(yu*yv)}, yw]/8 + 
     (3*G[{1, yu^(-1), yu^(-1), 1/(yu*yv), yu^(-1)}, yw])/64 - 
     G[{1, yu^(-1), yu^(-1), 1/(yu*yv), yv^(-1)}, yw]/16 - 
     (3*G[{1, yu^(-1), yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/32 - 
     G[{1, yu^(-1), yv^(-1), 1, yv^(-1)}, yw]/16 + 
     G[{1, yu^(-1), yv^(-1), 1, 1/(yu*yv)}, yw]/8 + 
     G[{1, yu^(-1), yv^(-1), yu^(-1), yu^(-1)}, yw]/8 + 
     G[{1, yu^(-1), yv^(-1), yu^(-1), yv^(-1)}, yw]/8 - 
     G[{1, yu^(-1), yv^(-1), yu^(-1), 1/(yu*yv)}, yw]/8 + 
     G[{1, yu^(-1), yv^(-1), yv^(-1), yu^(-1)}, yw]/8 - 
     (3*G[{1, yu^(-1), yv^(-1), yv^(-1), yv^(-1)}, yw])/8 - 
     G[{1, yu^(-1), yv^(-1), yv^(-1), 1/(yu*yv)}, yw]/8 - 
     (3*G[{1, yu^(-1), yv^(-1), 1/(yu*yv), yu^(-1)}, yw])/16 + 
     G[{1, yu^(-1), yv^(-1), 1/(yu*yv), yv^(-1)}, yw]/16 - 
     (3*G[{1, yu^(-1), 1/(yu*yv), 1, yv^(-1)}, yw])/16 - 
     (5*G[{1, yu^(-1), 1/(yu*yv), 1, 1/(yu*yv)}, yw])/64 + 
     (3*G[{1, yu^(-1), 1/(yu*yv), yu^(-1), yu^(-1)}, yw])/64 - 
     G[{1, yu^(-1), 1/(yu*yv), yu^(-1), yv^(-1)}, yw]/16 - 
     (3*G[{1, yu^(-1), 1/(yu*yv), yu^(-1), 1/(yu*yv)}, yw])/32 - 
     G[{1, yu^(-1), 1/(yu*yv), yv^(-1), yu^(-1)}, yw]/16 + 
     (3*G[{1, yu^(-1), 1/(yu*yv), yv^(-1), yv^(-1)}, yw])/16 + 
     (9*G[{1, yu^(-1), 1/(yu*yv), 1/(yu*yv), yu^(-1)}, yw])/64 - 
     G[{1, yu^(-1), 1/(yu*yv), 1/(yu*yv), yv^(-1)}, yw]/16 + 
     (5*G[{1, yu, 1, yu, yu}, yv^(-1)])/16 + 
     (41*G[{1, yu, yu, yu, yu}, yv^(-1)])/32 + 
     G[{1, yv^(-1), 1, yv^(-1), yu^(-1)}, yw]/16 - 
     (7*G[{1, yv^(-1), 1, yv^(-1), yv^(-1)}, yw])/16 - 
     G[{1, yv^(-1), 1, yv^(-1), 1/(yu*yv)}, yw]/4 + 
     G[{1, yv^(-1), 1, 1/(yu*yv), yu^(-1)}, yw]/4 - 
     G[{1, yv^(-1), 1, 1/(yu*yv), yv^(-1)}, yw]/4 - 
     G[{1, yv^(-1), 1, 1/(yu*yv), 1/(yu*yv)}, yw]/16 + 
     G[{1, yv^(-1), yu^(-1), 1, 1/(yu*yv)}, yw]/8 + 
     G[{1, yv^(-1), yu^(-1), yu^(-1), yu^(-1)}, yw]/8 + 
     G[{1, yv^(-1), yu^(-1), yu^(-1), yv^(-1)}, yw]/8 - 
     G[{1, yv^(-1), yu^(-1), yu^(-1), 1/(yu*yv)}, yw]/8 + 
     G[{1, yv^(-1), yu^(-1), yv^(-1), yu^(-1)}, yw]/8 - 
     (3*G[{1, yv^(-1), yu^(-1), yv^(-1), yv^(-1)}, yw])/8 - 
     G[{1, yv^(-1), yu^(-1), yv^(-1), 1/(yu*yv)}, yw]/8 - 
     (3*G[{1, yv^(-1), yu^(-1), 1/(yu*yv), yu^(-1)}, yw])/16 + 
     G[{1, yv^(-1), yu^(-1), 1/(yu*yv), yv^(-1)}, yw]/16 - 
     (3*G[{1, yv^(-1), yv^(-1), 1, 1/(yu*yv)}, yw])/8 + 
     G[{1, yv^(-1), yv^(-1), yu^(-1), yu^(-1)}, yw]/8 - 
     (3*G[{1, yv^(-1), yv^(-1), yu^(-1), yv^(-1)}, yw])/8 - 
     G[{1, yv^(-1), yv^(-1), yu^(-1), 1/(yu*yv)}, yw]/8 - 
     (3*G[{1, yv^(-1), yv^(-1), yv^(-1), yu^(-1)}, yw])/8 + 
     G[{1, yv^(-1), yv^(-1), yv^(-1), yv^(-1)}, yw]/8 - 
     (5*G[{1, yv^(-1), yv^(-1), 1/(yu*yv), yu^(-1)}, yw])/16 + 
     (3*G[{1, yv^(-1), yv^(-1), 1/(yu*yv), yv^(-1)}, yw])/16 - 
     G[{1, yv^(-1), 1/(yu*yv), 1, 1/(yu*yv)}, yw]/16 - 
     G[{1, yv^(-1), 1/(yu*yv), yu^(-1), yu^(-1)}, yw]/16 - 
     G[{1, yv^(-1), 1/(yu*yv), yu^(-1), yv^(-1)}, yw]/16 - 
     G[{1, yv^(-1), 1/(yu*yv), yv^(-1), yu^(-1)}, yw]/16 + 
     (3*G[{1, yv^(-1), 1/(yu*yv), yv^(-1), yv^(-1)}, yw])/16 + 
     (3*G[{1, yv^(-1), 1/(yu*yv), 1/(yu*yv), yu^(-1)}, yw])/16 - 
     G[{1, yv^(-1), 1/(yu*yv), 1/(yu*yv), yv^(-1)}, yw]/8 - 
     (3*G[{1, 1/(yu*yv), 1, 1/(yu*yv), yu^(-1)}, yw])/16 - 
     G[{1, 1/(yu*yv), 1, 1/(yu*yv), yv^(-1)}, yw]/4 - 
     (17*G[{1, 1/(yu*yv), 1, 1/(yu*yv), 1/(yu*yv)}, yw])/64 + 
     (7*G[{1, 1/(yu*yv), yu^(-1), yu^(-1), yu^(-1)}, yw])/32 - 
     (11*G[{1, 1/(yu*yv), yu^(-1), yu^(-1), 1/(yu*yv)}, yw])/64 - 
     (15*G[{1, 1/(yu*yv), yu^(-1), 1/(yu*yv), yu^(-1)}, yw])/64 + 
     G[{1, 1/(yu*yv), yu^(-1), 1/(yu*yv), yv^(-1)}, yw]/8 + 
     (3*G[{1, 1/(yu*yv), yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/32 - 
     G[{1, 1/(yu*yv), yv^(-1), yv^(-1), 1/(yu*yv)}, yw]/8 + 
     G[{1, 1/(yu*yv), yv^(-1), 1/(yu*yv), yu^(-1)}, yw]/4 - 
     G[{1, 1/(yu*yv), yv^(-1), 1/(yu*yv), yv^(-1)}, yw]/4 - 
     (7*G[{1, 1/(yu*yv), 1/(yu*yv), yu^(-1), yu^(-1)}, yw])/64 + 
     G[{1, 1/(yu*yv), 1/(yu*yv), yu^(-1), yv^(-1)}, yw]/4 + 
     (3*G[{1, 1/(yu*yv), 1/(yu*yv), yu^(-1), 1/(yu*yv)}, yw])/32 + 
     G[{1, 1/(yu*yv), 1/(yu*yv), yv^(-1), yu^(-1)}, yw]/4 - 
     G[{1, 1/(yu*yv), 1/(yu*yv), yv^(-1), yv^(-1)}, yw]/2 + 
     (3*G[{1, 1/(yu*yv), 1/(yu*yv), 1/(yu*yv), yu^(-1)}, yw])/64 + 
     (3*G[{1, 1/(yu*yv), 1/(yu*yv), 1/(yu*yv), yv^(-1)}, yw])/16 + 
     (11*G[{yu^(-1), yu^(-1), yu^(-1), yu^(-1), 1/(yu*yv)}, yw])/32 - 
     G[{yu^(-1), yu^(-1), yu^(-1), 1/(yu*yv), yv^(-1)}, yw]/8 + 
     (123*G[{yu^(-1), yu^(-1), yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/64 + 
     (5*G[{yu^(-1), yu^(-1), 1/(yu*yv), yu^(-1), 1/(yu*yv)}, yw])/8 + 
     G[{yu^(-1), yu^(-1), 1/(yu*yv), yv^(-1), yv^(-1)}, yw]/8 - 
     G[{yu^(-1), yu^(-1), 1/(yu*yv), yv^(-1), 1/(yu*yv)}, yw]/8 - 
     (3*G[{yu^(-1), yu^(-1), 1/(yu*yv), 1/(yu*yv), yv^(-1)}, yw])/16 - 
     (7*G[{yu^(-1), yu^(-1), 1/(yu*yv), 1/(yu*yv), 1/(yu*yv)}, yw])/16 + 
     G[{yu^(-1), 1/(yu*yv), yu^(-1), 1/(yu*yv), yv^(-1)}, yw]/16 - 
     (17*G[{yu^(-1), 1/(yu*yv), yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/64 + 
     (3*G[{yu^(-1), 1/(yu*yv), yv^(-1), yv^(-1), yv^(-1)}, yw])/8 + 
     G[{yu^(-1), 1/(yu*yv), yv^(-1), yv^(-1), 1/(yu*yv)}, yw]/8 - 
     G[{yu^(-1), 1/(yu*yv), yv^(-1), 1/(yu*yv), yv^(-1)}, yw]/16 + 
     G[{yu^(-1), 1/(yu*yv), 1/(yu*yv), yv^(-1), yv^(-1)}, yw]/16 - 
     (3*G[{yu^(-1), 1/(yu*yv), 1/(yu*yv), 1/(yu*yv), yv^(-1)}, yw])/16 + 
     G[{yv^(-1), yv^(-1), yv^(-1), yv^(-1), 1/(yu*yv)}, yw]/8 + 
     (3*G[{yv^(-1), yv^(-1), yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/16 + 
     G[{yv^(-1), yv^(-1), 1/(yu*yv), yv^(-1), 1/(yu*yv)}, yw]/16 - 
     G[{yv^(-1), yv^(-1), 1/(yu*yv), 1/(yu*yv), 1/(yu*yv)}, yw]/4 - 
     G[{yv^(-1), 1/(yu*yv), yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw]/8 - 
     (Pi^2*Zeta[3])/32 + (G[{0}, yu^(-1)]*G[{1}, yu^(-1)]*Zeta[3])/8 + 
     (G[{0}, yv^(-1)]*G[{1}, yu^(-1)]*Zeta[3])/8 - 
     (G[{0}, yw]*G[{1}, yu^(-1)]*Zeta[3])/8 - 
     (G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*Zeta[3])/8 + 
     (9*G[{1}, yv^(-1)]^2*Zeta[3])/64 - (G[{0}, yu^(-1)]*G[{1}, yw]*Zeta[3])/
      8 - (G[{0}, yv^(-1)]*G[{1}, yw]*Zeta[3])/8 + 
     (G[{0}, yw]*G[{1}, yw]*Zeta[3])/8 + (13*G[{1}, yv^(-1)]*G[{1}, yw]*
       Zeta[3])/32 + (9*G[{1}, yw]^2*Zeta[3])/64 - 
     (9*G[{1}, yw]*G[{yu}, yv^(-1)]*Zeta[3])/32 + 
     (G[{1}, yu^(-1)]*G[{1/(yu*yv)}, yw]*Zeta[3])/8 - 
     (9*G[{1}, yv^(-1)]*G[{1/(yu*yv)}, yw]*Zeta[3])/32 - 
     (9*G[{1}, yw]*G[{1/(yu*yv)}, yw]*Zeta[3])/32 + 
     (9*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*Zeta[3])/32 + 
     (9*G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw]*Zeta[3])/32 - 
     (G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*Zeta[3])/8 - 
     (9*G[{0, 1}, yv^(-1)]*Zeta[3])/32 - (G[{0, yu^(-1)}, yw]*Zeta[3])/8 + 
     (9*G[{0, yu}, yv^(-1)]*Zeta[3])/32 + (G[{0, yv^(-1)}, yw]*Zeta[3])/8 - 
     (9*G[{1, yu^(-1)}, yw]*Zeta[3])/32 - (9*G[{1, yu}, yv^(-1)]*Zeta[3])/
      32 - (G[{1, yv^(-1)}, yw]*Zeta[3])/8 + 
     (9*G[{1, 1/(yu*yv)}, yw]*Zeta[3])/32 - 
     (9*G[{yu^(-1), 1/(yu*yv)}, yw]*Zeta[3])/32 + 
     (G[{yv^(-1), 1/(yu*yv)}, yw]*Zeta[3])/8 + Zeta[5]/4
 
QepwuvRegII = -(Pi^2*G[{1}, yu^(-1)]^3)/576 + 
     (Pi^2*G[{1}, yu^(-1)]^2*G[{1}, yv^(-1)])/192 - 
     (Pi^2*G[{1}, yu^(-1)]*G[{1}, yv^(-1)]^2)/96 + 
     (11*Pi^2*G[{1}, yv^(-1)]^3)/2304 + 
     (3*G[{1}, yu^(-1)]^2*G[{1}, yv^(-1)]^3)/256 + 
     (G[{1}, yu^(-1)]*G[{1}, yv^(-1)]^4)/96 + (Pi^4*G[{1}, yw])/1152 - 
     (Pi^2*G[{0}, yu^(-1)]^2*G[{1}, yw])/192 - 
     (Pi^2*G[{0}, yu^(-1)]*G[{0}, yv^(-1)]*G[{1}, yw])/96 - 
     (Pi^2*G[{0}, yv^(-1)]^2*G[{1}, yw])/192 + 
     (Pi^2*G[{0}, yu^(-1)]*G[{0}, yw]*G[{1}, yw])/96 + 
     (Pi^2*G[{0}, yv^(-1)]*G[{0}, yw]*G[{1}, yw])/96 - 
     (Pi^2*G[{0}, yw]^2*G[{1}, yw])/192 + 
     (Pi^2*G[{0}, yu^(-1)]*G[{1}, yu^(-1)]*G[{1}, yw])/96 + 
     (Pi^2*G[{0}, yv^(-1)]*G[{1}, yu^(-1)]*G[{1}, yw])/96 - 
     (Pi^2*G[{0}, yw]*G[{1}, yu^(-1)]*G[{1}, yw])/96 - 
     (Pi^2*G[{1}, yu^(-1)]^2*G[{1}, yw])/192 - 
     (Pi^2*G[{0}, yu^(-1)]*G[{1}, yv^(-1)]*G[{1}, yw])/48 - 
     (Pi^2*G[{0}, yv^(-1)]*G[{1}, yv^(-1)]*G[{1}, yw])/48 + 
     (Pi^2*G[{0}, yw]*G[{1}, yv^(-1)]*G[{1}, yw])/48 + 
     (11*Pi^2*G[{1}, yv^(-1)]^2*G[{1}, yw])/768 + 
     (9*G[{1}, yu^(-1)]^2*G[{1}, yv^(-1)]^2*G[{1}, yw])/256 - 
     (7*G[{1}, yu^(-1)]*G[{1}, yv^(-1)]^3*G[{1}, yw])/192 - 
     (Pi^2*G[{0}, yu^(-1)]*G[{1}, yw]^2)/96 - 
     (Pi^2*G[{0}, yv^(-1)]*G[{1}, yw]^2)/96 + (Pi^2*G[{0}, yw]*G[{1}, yw]^2)/
      96 + (G[{0}, yu^(-1)]^2*G[{1}, yu^(-1)]*G[{1}, yw]^2)/64 + 
     (G[{0}, yu^(-1)]*G[{0}, yv^(-1)]*G[{1}, yu^(-1)]*G[{1}, yw]^2)/32 + 
     (G[{0}, yv^(-1)]^2*G[{1}, yu^(-1)]*G[{1}, yw]^2)/64 - 
     (G[{0}, yu^(-1)]*G[{0}, yw]*G[{1}, yu^(-1)]*G[{1}, yw]^2)/32 - 
     (G[{0}, yv^(-1)]*G[{0}, yw]*G[{1}, yu^(-1)]*G[{1}, yw]^2)/32 + 
     (G[{0}, yw]^2*G[{1}, yu^(-1)]*G[{1}, yw]^2)/64 - 
     (G[{0}, yu^(-1)]*G[{1}, yu^(-1)]^2*G[{1}, yw]^2)/32 - 
     (G[{0}, yv^(-1)]*G[{1}, yu^(-1)]^2*G[{1}, yw]^2)/32 + 
     (G[{0}, yw]*G[{1}, yu^(-1)]^2*G[{1}, yw]^2)/32 + 
     (G[{1}, yu^(-1)]^3*G[{1}, yw]^2)/64 - 
     (3*Pi^2*G[{1}, yv^(-1)]*G[{1}, yw]^2)/256 + 
     (G[{0}, yu^(-1)]^2*G[{1}, yv^(-1)]*G[{1}, yw]^2)/64 + 
     (G[{0}, yu^(-1)]*G[{0}, yv^(-1)]*G[{1}, yv^(-1)]*G[{1}, yw]^2)/32 + 
     (G[{0}, yv^(-1)]^2*G[{1}, yv^(-1)]*G[{1}, yw]^2)/64 - 
     (G[{0}, yu^(-1)]*G[{0}, yw]*G[{1}, yv^(-1)]*G[{1}, yw]^2)/32 - 
     (G[{0}, yv^(-1)]*G[{0}, yw]*G[{1}, yv^(-1)]*G[{1}, yw]^2)/32 + 
     (G[{0}, yw]^2*G[{1}, yv^(-1)]*G[{1}, yw]^2)/64 + 
     (G[{0}, yu^(-1)]*G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*G[{1}, yw]^2)/16 + 
     (G[{0}, yv^(-1)]*G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*G[{1}, yw]^2)/16 - 
     (G[{0}, yw]*G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*G[{1}, yw]^2)/16 - 
     (11*G[{1}, yu^(-1)]^2*G[{1}, yv^(-1)]*G[{1}, yw]^2)/256 + 
     (G[{0}, yu^(-1)]*G[{1}, yv^(-1)]^2*G[{1}, yw]^2)/64 + 
     (G[{0}, yv^(-1)]*G[{1}, yv^(-1)]^2*G[{1}, yw]^2)/64 - 
     (G[{0}, yw]*G[{1}, yv^(-1)]^2*G[{1}, yw]^2)/64 - 
     (G[{1}, yu^(-1)]*G[{1}, yv^(-1)]^2*G[{1}, yw]^2)/8 - 
     (5*G[{1}, yv^(-1)]^3*G[{1}, yw]^2)/256 - (25*Pi^2*G[{1}, yw]^3)/2304 + 
     (G[{0}, yu^(-1)]^2*G[{1}, yw]^3)/96 + 
     (G[{0}, yu^(-1)]*G[{0}, yv^(-1)]*G[{1}, yw]^3)/48 + 
     (G[{0}, yv^(-1)]^2*G[{1}, yw]^3)/96 - 
     (G[{0}, yu^(-1)]*G[{0}, yw]*G[{1}, yw]^3)/48 - 
     (G[{0}, yv^(-1)]*G[{0}, yw]*G[{1}, yw]^3)/48 + 
     (G[{0}, yw]^2*G[{1}, yw]^3)/96 + (G[{0}, yu^(-1)]*G[{1}, yu^(-1)]*
       G[{1}, yw]^3)/48 + (G[{0}, yv^(-1)]*G[{1}, yu^(-1)]*G[{1}, yw]^3)/48 - 
     (G[{0}, yw]*G[{1}, yu^(-1)]*G[{1}, yw]^3)/48 - 
     (5*G[{1}, yu^(-1)]^2*G[{1}, yw]^3)/256 + 
     (5*G[{0}, yu^(-1)]*G[{1}, yv^(-1)]*G[{1}, yw]^3)/96 + 
     (5*G[{0}, yv^(-1)]*G[{1}, yv^(-1)]*G[{1}, yw]^3)/96 - 
     (5*G[{0}, yw]*G[{1}, yv^(-1)]*G[{1}, yw]^3)/96 - 
     (7*G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*G[{1}, yw]^3)/192 - 
     (7*G[{1}, yv^(-1)]^2*G[{1}, yw]^3)/256 + 
     (11*G[{0}, yu^(-1)]*G[{1}, yw]^4)/384 + 
     (11*G[{0}, yv^(-1)]*G[{1}, yw]^4)/384 - (11*G[{0}, yw]*G[{1}, yw]^4)/
      384 - (G[{1}, yu^(-1)]*G[{1}, yw]^4)/192 + 
     (5*G[{1}, yv^(-1)]*G[{1}, yw]^4)/768 + (3*G[{1}, yw]^5)/256 + 
     (Pi^2*G[{0}, yu^(-1)]*G[{1}, yw]*G[{yu}, yv^(-1)])/48 + 
     (Pi^2*G[{0}, yv^(-1)]*G[{1}, yw]*G[{yu}, yv^(-1)])/48 - 
     (Pi^2*G[{0}, yw]*G[{1}, yw]*G[{yu}, yv^(-1)])/48 - 
     (Pi^2*G[{1}, yu^(-1)]*G[{1}, yw]*G[{yu}, yv^(-1)])/96 + 
     (7*Pi^2*G[{1}, yv^(-1)]*G[{1}, yw]*G[{yu}, yv^(-1)])/768 - 
     (3*G[{1}, yu^(-1)]^2*G[{1}, yv^(-1)]*G[{1}, yw]*G[{yu}, yv^(-1)])/64 + 
     (G[{1}, yu^(-1)]*G[{1}, yv^(-1)]^2*G[{1}, yw]*G[{yu}, yv^(-1)])/8 - 
     (3*G[{1}, yv^(-1)]^3*G[{1}, yw]*G[{yu}, yv^(-1)])/128 + 
     (25*Pi^2*G[{1}, yw]^2*G[{yu}, yv^(-1)])/768 - 
     (G[{0}, yu^(-1)]^2*G[{1}, yw]^2*G[{yu}, yv^(-1)])/32 - 
     (G[{0}, yu^(-1)]*G[{0}, yv^(-1)]*G[{1}, yw]^2*G[{yu}, yv^(-1)])/16 - 
     (G[{0}, yv^(-1)]^2*G[{1}, yw]^2*G[{yu}, yv^(-1)])/32 + 
     (G[{0}, yu^(-1)]*G[{0}, yw]*G[{1}, yw]^2*G[{yu}, yv^(-1)])/16 + 
     (G[{0}, yv^(-1)]*G[{0}, yw]*G[{1}, yw]^2*G[{yu}, yv^(-1)])/16 - 
     (G[{0}, yw]^2*G[{1}, yw]^2*G[{yu}, yv^(-1)])/32 - 
     (G[{0}, yu^(-1)]*G[{1}, yu^(-1)]*G[{1}, yw]^2*G[{yu}, yv^(-1)])/16 - 
     (G[{0}, yv^(-1)]*G[{1}, yu^(-1)]*G[{1}, yw]^2*G[{yu}, yv^(-1)])/16 + 
     (G[{0}, yw]*G[{1}, yu^(-1)]*G[{1}, yw]^2*G[{yu}, yv^(-1)])/16 + 
     (15*G[{1}, yu^(-1)]^2*G[{1}, yw]^2*G[{yu}, yv^(-1)])/256 - 
     (G[{0}, yu^(-1)]*G[{1}, yv^(-1)]*G[{1}, yw]^2*G[{yu}, yv^(-1)])/16 - 
     (G[{0}, yv^(-1)]*G[{1}, yv^(-1)]*G[{1}, yw]^2*G[{yu}, yv^(-1)])/16 + 
     (G[{0}, yw]*G[{1}, yv^(-1)]*G[{1}, yw]^2*G[{yu}, yv^(-1)])/16 + 
     (25*G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*G[{1}, yw]^2*G[{yu}, yv^(-1)])/128 + 
     (3*G[{1}, yv^(-1)]^2*G[{1}, yw]^2*G[{yu}, yv^(-1)])/64 - 
     (11*G[{0}, yu^(-1)]*G[{1}, yw]^3*G[{yu}, yv^(-1)])/96 - 
     (11*G[{0}, yv^(-1)]*G[{1}, yw]^3*G[{yu}, yv^(-1)])/96 + 
     (11*G[{0}, yw]*G[{1}, yw]^3*G[{yu}, yv^(-1)])/96 + 
     (13*G[{1}, yu^(-1)]*G[{1}, yw]^3*G[{yu}, yv^(-1)])/384 + 
     (G[{1}, yv^(-1)]*G[{1}, yw]^3*G[{yu}, yv^(-1)])/24 - 
     (15*G[{1}, yw]^4*G[{yu}, yv^(-1)])/256 - 
     (31*Pi^2*G[{1}, yw]*G[{yu}, yv^(-1)]^2)/1536 + 
     (3*G[{1}, yu^(-1)]^2*G[{1}, yw]*G[{yu}, yv^(-1)]^2)/128 - 
     (7*G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*G[{1}, yw]*G[{yu}, yv^(-1)]^2)/64 - 
     (G[{1}, yv^(-1)]^2*G[{1}, yw]*G[{yu}, yv^(-1)]^2)/128 + 
     (G[{0}, yu^(-1)]*G[{1}, yw]^2*G[{yu}, yv^(-1)]^2)/8 + 
     (G[{0}, yv^(-1)]*G[{1}, yw]^2*G[{yu}, yv^(-1)]^2)/8 - 
     (G[{0}, yw]*G[{1}, yw]^2*G[{yu}, yv^(-1)]^2)/8 - 
     (3*G[{1}, yu^(-1)]*G[{1}, yw]^2*G[{yu}, yv^(-1)]^2)/32 - 
     (29*G[{1}, yv^(-1)]*G[{1}, yw]^2*G[{yu}, yv^(-1)]^2)/256 + 
     (59*G[{1}, yw]^3*G[{yu}, yv^(-1)]^2)/768 + 
     (G[{1}, yu^(-1)]*G[{1}, yw]*G[{yu}, yv^(-1)]^3)/48 + 
     (7*G[{1}, yv^(-1)]*G[{1}, yw]*G[{yu}, yv^(-1)]^3)/192 - 
     (11*G[{1}, yw]^2*G[{yu}, yv^(-1)]^3)/768 - 
     (11*G[{1}, yw]*G[{yu}, yv^(-1)]^4)/768 - (Pi^4*G[{1/(yu*yv)}, yw])/
      1152 + (Pi^2*G[{0}, yu^(-1)]^2*G[{1/(yu*yv)}, yw])/192 + 
     (Pi^2*G[{0}, yu^(-1)]*G[{0}, yv^(-1)]*G[{1/(yu*yv)}, yw])/96 + 
     (Pi^2*G[{0}, yv^(-1)]^2*G[{1/(yu*yv)}, yw])/192 - 
     (Pi^2*G[{0}, yu^(-1)]*G[{0}, yw]*G[{1/(yu*yv)}, yw])/96 - 
     (Pi^2*G[{0}, yv^(-1)]*G[{0}, yw]*G[{1/(yu*yv)}, yw])/96 + 
     (Pi^2*G[{0}, yw]^2*G[{1/(yu*yv)}, yw])/192 - 
     (Pi^2*G[{0}, yu^(-1)]*G[{1}, yu^(-1)]*G[{1/(yu*yv)}, yw])/96 - 
     (Pi^2*G[{0}, yv^(-1)]*G[{1}, yu^(-1)]*G[{1/(yu*yv)}, yw])/96 + 
     (Pi^2*G[{0}, yw]*G[{1}, yu^(-1)]*G[{1/(yu*yv)}, yw])/96 + 
     (Pi^2*G[{1}, yu^(-1)]^2*G[{1/(yu*yv)}, yw])/192 + 
     (Pi^2*G[{0}, yu^(-1)]*G[{1}, yv^(-1)]*G[{1/(yu*yv)}, yw])/48 + 
     (Pi^2*G[{0}, yv^(-1)]*G[{1}, yv^(-1)]*G[{1/(yu*yv)}, yw])/48 - 
     (Pi^2*G[{0}, yw]*G[{1}, yv^(-1)]*G[{1/(yu*yv)}, yw])/48 - 
     (11*Pi^2*G[{1}, yv^(-1)]^2*G[{1/(yu*yv)}, yw])/768 - 
     (9*G[{1}, yu^(-1)]^2*G[{1}, yv^(-1)]^2*G[{1/(yu*yv)}, yw])/256 + 
     (7*G[{1}, yu^(-1)]*G[{1}, yv^(-1)]^3*G[{1/(yu*yv)}, yw])/192 + 
     (Pi^2*G[{0}, yu^(-1)]*G[{1}, yw]*G[{1/(yu*yv)}, yw])/48 + 
     (Pi^2*G[{0}, yv^(-1)]*G[{1}, yw]*G[{1/(yu*yv)}, yw])/48 - 
     (Pi^2*G[{0}, yw]*G[{1}, yw]*G[{1/(yu*yv)}, yw])/48 - 
     (G[{0}, yu^(-1)]^2*G[{1}, yu^(-1)]*G[{1}, yw]*G[{1/(yu*yv)}, yw])/32 - 
     (G[{0}, yu^(-1)]*G[{0}, yv^(-1)]*G[{1}, yu^(-1)]*G[{1}, yw]*
       G[{1/(yu*yv)}, yw])/16 - (G[{0}, yv^(-1)]^2*G[{1}, yu^(-1)]*G[{1}, yw]*
       G[{1/(yu*yv)}, yw])/32 + (G[{0}, yu^(-1)]*G[{0}, yw]*G[{1}, yu^(-1)]*
       G[{1}, yw]*G[{1/(yu*yv)}, yw])/16 + 
     (G[{0}, yv^(-1)]*G[{0}, yw]*G[{1}, yu^(-1)]*G[{1}, yw]*
       G[{1/(yu*yv)}, yw])/16 - (G[{0}, yw]^2*G[{1}, yu^(-1)]*G[{1}, yw]*
       G[{1/(yu*yv)}, yw])/32 + (G[{0}, yu^(-1)]*G[{1}, yu^(-1)]^2*G[{1}, yw]*
       G[{1/(yu*yv)}, yw])/16 + (G[{0}, yv^(-1)]*G[{1}, yu^(-1)]^2*G[{1}, yw]*
       G[{1/(yu*yv)}, yw])/16 - (G[{0}, yw]*G[{1}, yu^(-1)]^2*G[{1}, yw]*
       G[{1/(yu*yv)}, yw])/16 - (G[{1}, yu^(-1)]^3*G[{1}, yw]*
       G[{1/(yu*yv)}, yw])/32 + (3*Pi^2*G[{1}, yv^(-1)]*G[{1}, yw]*
       G[{1/(yu*yv)}, yw])/128 - (G[{0}, yu^(-1)]^2*G[{1}, yv^(-1)]*
       G[{1}, yw]*G[{1/(yu*yv)}, yw])/32 - 
     (G[{0}, yu^(-1)]*G[{0}, yv^(-1)]*G[{1}, yv^(-1)]*G[{1}, yw]*
       G[{1/(yu*yv)}, yw])/16 - (G[{0}, yv^(-1)]^2*G[{1}, yv^(-1)]*G[{1}, yw]*
       G[{1/(yu*yv)}, yw])/32 + (G[{0}, yu^(-1)]*G[{0}, yw]*G[{1}, yv^(-1)]*
       G[{1}, yw]*G[{1/(yu*yv)}, yw])/16 + 
     (G[{0}, yv^(-1)]*G[{0}, yw]*G[{1}, yv^(-1)]*G[{1}, yw]*
       G[{1/(yu*yv)}, yw])/16 - (G[{0}, yw]^2*G[{1}, yv^(-1)]*G[{1}, yw]*
       G[{1/(yu*yv)}, yw])/32 - (G[{0}, yu^(-1)]*G[{1}, yu^(-1)]*
       G[{1}, yv^(-1)]*G[{1}, yw]*G[{1/(yu*yv)}, yw])/8 - 
     (G[{0}, yv^(-1)]*G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*G[{1}, yw]*
       G[{1/(yu*yv)}, yw])/8 + (G[{0}, yw]*G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*
       G[{1}, yw]*G[{1/(yu*yv)}, yw])/8 + 
     (11*G[{1}, yu^(-1)]^2*G[{1}, yv^(-1)]*G[{1}, yw]*G[{1/(yu*yv)}, yw])/
      128 - (G[{0}, yu^(-1)]*G[{1}, yv^(-1)]^2*G[{1}, yw]*G[{1/(yu*yv)}, yw])/
      32 - (G[{0}, yv^(-1)]*G[{1}, yv^(-1)]^2*G[{1}, yw]*G[{1/(yu*yv)}, yw])/
      32 + (G[{0}, yw]*G[{1}, yv^(-1)]^2*G[{1}, yw]*G[{1/(yu*yv)}, yw])/32 + 
     (G[{1}, yu^(-1)]*G[{1}, yv^(-1)]^2*G[{1}, yw]*G[{1/(yu*yv)}, yw])/4 + 
     (5*G[{1}, yv^(-1)]^3*G[{1}, yw]*G[{1/(yu*yv)}, yw])/128 + 
     (25*Pi^2*G[{1}, yw]^2*G[{1/(yu*yv)}, yw])/768 - 
     (G[{0}, yu^(-1)]^2*G[{1}, yw]^2*G[{1/(yu*yv)}, yw])/32 - 
     (G[{0}, yu^(-1)]*G[{0}, yv^(-1)]*G[{1}, yw]^2*G[{1/(yu*yv)}, yw])/16 - 
     (G[{0}, yv^(-1)]^2*G[{1}, yw]^2*G[{1/(yu*yv)}, yw])/32 + 
     (G[{0}, yu^(-1)]*G[{0}, yw]*G[{1}, yw]^2*G[{1/(yu*yv)}, yw])/16 + 
     (G[{0}, yv^(-1)]*G[{0}, yw]*G[{1}, yw]^2*G[{1/(yu*yv)}, yw])/16 - 
     (G[{0}, yw]^2*G[{1}, yw]^2*G[{1/(yu*yv)}, yw])/32 - 
     (G[{0}, yu^(-1)]*G[{1}, yu^(-1)]*G[{1}, yw]^2*G[{1/(yu*yv)}, yw])/16 - 
     (G[{0}, yv^(-1)]*G[{1}, yu^(-1)]*G[{1}, yw]^2*G[{1/(yu*yv)}, yw])/16 + 
     (G[{0}, yw]*G[{1}, yu^(-1)]*G[{1}, yw]^2*G[{1/(yu*yv)}, yw])/16 + 
     (15*G[{1}, yu^(-1)]^2*G[{1}, yw]^2*G[{1/(yu*yv)}, yw])/256 - 
     (5*G[{0}, yu^(-1)]*G[{1}, yv^(-1)]*G[{1}, yw]^2*G[{1/(yu*yv)}, yw])/32 - 
     (5*G[{0}, yv^(-1)]*G[{1}, yv^(-1)]*G[{1}, yw]^2*G[{1/(yu*yv)}, yw])/32 + 
     (5*G[{0}, yw]*G[{1}, yv^(-1)]*G[{1}, yw]^2*G[{1/(yu*yv)}, yw])/32 + 
     (7*G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*G[{1}, yw]^2*G[{1/(yu*yv)}, yw])/64 + 
     (21*G[{1}, yv^(-1)]^2*G[{1}, yw]^2*G[{1/(yu*yv)}, yw])/256 - 
     (11*G[{0}, yu^(-1)]*G[{1}, yw]^3*G[{1/(yu*yv)}, yw])/96 - 
     (11*G[{0}, yv^(-1)]*G[{1}, yw]^3*G[{1/(yu*yv)}, yw])/96 + 
     (11*G[{0}, yw]*G[{1}, yw]^3*G[{1/(yu*yv)}, yw])/96 + 
     (G[{1}, yu^(-1)]*G[{1}, yw]^3*G[{1/(yu*yv)}, yw])/48 - 
     (5*G[{1}, yv^(-1)]*G[{1}, yw]^3*G[{1/(yu*yv)}, yw])/192 - 
     (15*G[{1}, yw]^4*G[{1/(yu*yv)}, yw])/256 - 
     (Pi^2*G[{0}, yu^(-1)]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw])/48 - 
     (Pi^2*G[{0}, yv^(-1)]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw])/48 + 
     (Pi^2*G[{0}, yw]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw])/48 - 
     (Pi^2*G[{1}, yu^(-1)]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw])/96 + 
     (G[{0}, yu^(-1)]^2*G[{1}, yu^(-1)]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw])/
      32 + (G[{0}, yu^(-1)]*G[{0}, yv^(-1)]*G[{1}, yu^(-1)]*G[{yu^(-1)}, yw]*
       G[{1/(yu*yv)}, yw])/16 + (G[{0}, yv^(-1)]^2*G[{1}, yu^(-1)]*
       G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw])/32 - 
     (G[{0}, yu^(-1)]*G[{0}, yw]*G[{1}, yu^(-1)]*G[{yu^(-1)}, yw]*
       G[{1/(yu*yv)}, yw])/16 - (G[{0}, yv^(-1)]*G[{0}, yw]*G[{1}, yu^(-1)]*
       G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw])/16 + 
     (G[{0}, yw]^2*G[{1}, yu^(-1)]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw])/32 - 
     (G[{0}, yu^(-1)]*G[{1}, yu^(-1)]^2*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw])/
      16 - (G[{0}, yv^(-1)]*G[{1}, yu^(-1)]^2*G[{yu^(-1)}, yw]*
       G[{1/(yu*yv)}, yw])/16 + (G[{0}, yw]*G[{1}, yu^(-1)]^2*
       G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw])/16 + 
     (G[{1}, yu^(-1)]^3*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw])/32 + 
     (11*Pi^2*G[{1}, yv^(-1)]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw])/256 - 
     (G[{0}, yu^(-1)]^2*G[{1}, yv^(-1)]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw])/
      32 - (G[{0}, yu^(-1)]*G[{0}, yv^(-1)]*G[{1}, yv^(-1)]*G[{yu^(-1)}, yw]*
       G[{1/(yu*yv)}, yw])/16 - (G[{0}, yv^(-1)]^2*G[{1}, yv^(-1)]*
       G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw])/32 + 
     (G[{0}, yu^(-1)]*G[{0}, yw]*G[{1}, yv^(-1)]*G[{yu^(-1)}, yw]*
       G[{1/(yu*yv)}, yw])/16 + (G[{0}, yv^(-1)]*G[{0}, yw]*G[{1}, yv^(-1)]*
       G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw])/16 - 
     (G[{0}, yw]^2*G[{1}, yv^(-1)]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw])/32 + 
     (G[{0}, yu^(-1)]*G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*G[{yu^(-1)}, yw]*
       G[{1/(yu*yv)}, yw])/8 + (G[{0}, yv^(-1)]*G[{1}, yu^(-1)]*
       G[{1}, yv^(-1)]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw])/8 - 
     (G[{0}, yw]*G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*G[{yu^(-1)}, yw]*
       G[{1/(yu*yv)}, yw])/8 - (3*G[{1}, yu^(-1)]^2*G[{1}, yv^(-1)]*
       G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw])/64 - 
     (G[{0}, yu^(-1)]*G[{1}, yv^(-1)]^2*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw])/
      32 - (G[{0}, yv^(-1)]*G[{1}, yv^(-1)]^2*G[{yu^(-1)}, yw]*
       G[{1/(yu*yv)}, yw])/32 + (G[{0}, yw]*G[{1}, yv^(-1)]^2*
       G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw])/32 - 
     (3*G[{1}, yu^(-1)]*G[{1}, yv^(-1)]^2*G[{yu^(-1)}, yw]*
       G[{1/(yu*yv)}, yw])/32 + (G[{1}, yv^(-1)]^3*G[{yu^(-1)}, yw]*
       G[{1/(yu*yv)}, yw])/16 + (Pi^2*G[{1}, yw]*G[{yu^(-1)}, yw]*
       G[{1/(yu*yv)}, yw])/768 - (G[{0}, yu^(-1)]^2*G[{1}, yw]*
       G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw])/32 - 
     (G[{0}, yu^(-1)]*G[{0}, yv^(-1)]*G[{1}, yw]*G[{yu^(-1)}, yw]*
       G[{1/(yu*yv)}, yw])/16 - (G[{0}, yv^(-1)]^2*G[{1}, yw]*
       G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw])/32 + 
     (G[{0}, yu^(-1)]*G[{0}, yw]*G[{1}, yw]*G[{yu^(-1)}, yw]*
       G[{1/(yu*yv)}, yw])/16 + (G[{0}, yv^(-1)]*G[{0}, yw]*G[{1}, yw]*
       G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw])/16 - 
     (G[{0}, yw]^2*G[{1}, yw]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw])/32 + 
     (G[{0}, yu^(-1)]*G[{1}, yu^(-1)]*G[{1}, yw]*G[{yu^(-1)}, yw]*
       G[{1/(yu*yv)}, yw])/4 + (G[{0}, yv^(-1)]*G[{1}, yu^(-1)]*G[{1}, yw]*
       G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw])/4 - 
     (G[{0}, yw]*G[{1}, yu^(-1)]*G[{1}, yw]*G[{yu^(-1)}, yw]*
       G[{1/(yu*yv)}, yw])/4 - (11*G[{1}, yu^(-1)]^2*G[{1}, yw]*
       G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw])/64 - 
     (3*G[{0}, yu^(-1)]*G[{1}, yv^(-1)]*G[{1}, yw]*G[{yu^(-1)}, yw]*
       G[{1/(yu*yv)}, yw])/16 - (3*G[{0}, yv^(-1)]*G[{1}, yv^(-1)]*G[{1}, yw]*
       G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw])/16 + 
     (3*G[{0}, yw]*G[{1}, yv^(-1)]*G[{1}, yw]*G[{yu^(-1)}, yw]*
       G[{1/(yu*yv)}, yw])/16 - (G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*G[{1}, yw]*
       G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw])/8 + 
     (G[{1}, yv^(-1)]^2*G[{1}, yw]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw])/8 - 
     (G[{0}, yu^(-1)]*G[{1}, yw]^2*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw])/16 - 
     (G[{0}, yv^(-1)]*G[{1}, yw]^2*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw])/16 + 
     (G[{0}, yw]*G[{1}, yw]^2*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw])/16 + 
     (G[{1}, yu^(-1)]*G[{1}, yw]^2*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw])/16 - 
     (5*G[{1}, yv^(-1)]*G[{1}, yw]^2*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw])/
      64 - (3*G[{1}, yw]^3*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw])/64 - 
     (41*Pi^2*G[{yu^(-1)}, yw]^2*G[{1/(yu*yv)}, yw])/1536 + 
     (G[{0}, yu^(-1)]^2*G[{yu^(-1)}, yw]^2*G[{1/(yu*yv)}, yw])/32 + 
     (G[{0}, yu^(-1)]*G[{0}, yv^(-1)]*G[{yu^(-1)}, yw]^2*G[{1/(yu*yv)}, yw])/
      16 + (G[{0}, yv^(-1)]^2*G[{yu^(-1)}, yw]^2*G[{1/(yu*yv)}, yw])/32 - 
     (G[{0}, yu^(-1)]*G[{0}, yw]*G[{yu^(-1)}, yw]^2*G[{1/(yu*yv)}, yw])/16 - 
     (G[{0}, yv^(-1)]*G[{0}, yw]*G[{yu^(-1)}, yw]^2*G[{1/(yu*yv)}, yw])/16 + 
     (G[{0}, yw]^2*G[{yu^(-1)}, yw]^2*G[{1/(yu*yv)}, yw])/32 - 
     (G[{0}, yu^(-1)]*G[{1}, yu^(-1)]*G[{yu^(-1)}, yw]^2*G[{1/(yu*yv)}, yw])/
      8 - (G[{0}, yv^(-1)]*G[{1}, yu^(-1)]*G[{yu^(-1)}, yw]^2*
       G[{1/(yu*yv)}, yw])/8 + (G[{0}, yw]*G[{1}, yu^(-1)]*G[{yu^(-1)}, yw]^2*
       G[{1/(yu*yv)}, yw])/8 + (9*G[{1}, yu^(-1)]^2*G[{yu^(-1)}, yw]^2*
       G[{1/(yu*yv)}, yw])/128 + (G[{0}, yu^(-1)]*G[{1}, yv^(-1)]*
       G[{yu^(-1)}, yw]^2*G[{1/(yu*yv)}, yw])/8 + 
     (G[{0}, yv^(-1)]*G[{1}, yv^(-1)]*G[{yu^(-1)}, yw]^2*G[{1/(yu*yv)}, yw])/
      8 - (G[{0}, yw]*G[{1}, yv^(-1)]*G[{yu^(-1)}, yw]^2*G[{1/(yu*yv)}, yw])/
      8 + (7*G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*G[{yu^(-1)}, yw]^2*
       G[{1/(yu*yv)}, yw])/64 - (29*G[{1}, yv^(-1)]^2*G[{yu^(-1)}, yw]^2*
       G[{1/(yu*yv)}, yw])/128 + (G[{0}, yu^(-1)]*G[{1}, yw]*
       G[{yu^(-1)}, yw]^2*G[{1/(yu*yv)}, yw])/4 + 
     (G[{0}, yv^(-1)]*G[{1}, yw]*G[{yu^(-1)}, yw]^2*G[{1/(yu*yv)}, yw])/4 - 
     (G[{0}, yw]*G[{1}, yw]*G[{yu^(-1)}, yw]^2*G[{1/(yu*yv)}, yw])/4 - 
     (7*G[{1}, yu^(-1)]*G[{1}, yw]*G[{yu^(-1)}, yw]^2*G[{1/(yu*yv)}, yw])/
      64 - (13*G[{1}, yv^(-1)]*G[{1}, yw]*G[{yu^(-1)}, yw]^2*
       G[{1/(yu*yv)}, yw])/64 + (3*G[{1}, yw]^2*G[{yu^(-1)}, yw]^2*
       G[{1/(yu*yv)}, yw])/32 - (G[{0}, yu^(-1)]*G[{yu^(-1)}, yw]^3*
       G[{1/(yu*yv)}, yw])/12 - (G[{0}, yv^(-1)]*G[{yu^(-1)}, yw]^3*
       G[{1/(yu*yv)}, yw])/12 + (G[{0}, yw]*G[{yu^(-1)}, yw]^3*
       G[{1/(yu*yv)}, yw])/12 + (41*G[{1}, yv^(-1)]*G[{yu^(-1)}, yw]^3*
       G[{1/(yu*yv)}, yw])/192 + (3*G[{1}, yw]*G[{yu^(-1)}, yw]^3*
       G[{1/(yu*yv)}, yw])/64 - (41*G[{yu^(-1)}, yw]^4*G[{1/(yu*yv)}, yw])/
      768 - (Pi^2*G[{0}, yu^(-1)]*G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw])/48 - 
     (Pi^2*G[{0}, yv^(-1)]*G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw])/48 + 
     (Pi^2*G[{0}, yw]*G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw])/48 + 
     (Pi^2*G[{1}, yu^(-1)]*G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw])/96 - 
     (7*Pi^2*G[{1}, yv^(-1)]*G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw])/768 + 
     (3*G[{1}, yu^(-1)]^2*G[{1}, yv^(-1)]*G[{yu}, yv^(-1)]*
       G[{1/(yu*yv)}, yw])/64 - (G[{1}, yu^(-1)]*G[{1}, yv^(-1)]^2*
       G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw])/8 + 
     (3*G[{1}, yv^(-1)]^3*G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw])/128 - 
     (25*Pi^2*G[{1}, yw]*G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw])/384 + 
     (G[{0}, yu^(-1)]^2*G[{1}, yw]*G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw])/16 + 
     (G[{0}, yu^(-1)]*G[{0}, yv^(-1)]*G[{1}, yw]*G[{yu}, yv^(-1)]*
       G[{1/(yu*yv)}, yw])/8 + (G[{0}, yv^(-1)]^2*G[{1}, yw]*G[{yu}, yv^(-1)]*
       G[{1/(yu*yv)}, yw])/16 - (G[{0}, yu^(-1)]*G[{0}, yw]*G[{1}, yw]*
       G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw])/8 - 
     (G[{0}, yv^(-1)]*G[{0}, yw]*G[{1}, yw]*G[{yu}, yv^(-1)]*
       G[{1/(yu*yv)}, yw])/8 + (G[{0}, yw]^2*G[{1}, yw]*G[{yu}, yv^(-1)]*
       G[{1/(yu*yv)}, yw])/16 + (G[{0}, yu^(-1)]*G[{1}, yu^(-1)]*G[{1}, yw]*
       G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw])/8 + 
     (G[{0}, yv^(-1)]*G[{1}, yu^(-1)]*G[{1}, yw]*G[{yu}, yv^(-1)]*
       G[{1/(yu*yv)}, yw])/8 - (G[{0}, yw]*G[{1}, yu^(-1)]*G[{1}, yw]*
       G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw])/8 - 
     (15*G[{1}, yu^(-1)]^2*G[{1}, yw]*G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw])/
      128 + (G[{0}, yu^(-1)]*G[{1}, yv^(-1)]*G[{1}, yw]*G[{yu}, yv^(-1)]*
       G[{1/(yu*yv)}, yw])/8 + (G[{0}, yv^(-1)]*G[{1}, yv^(-1)]*G[{1}, yw]*
       G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw])/8 - 
     (G[{0}, yw]*G[{1}, yv^(-1)]*G[{1}, yw]*G[{yu}, yv^(-1)]*
       G[{1/(yu*yv)}, yw])/8 - (25*G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*G[{1}, yw]*
       G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw])/64 - 
     (3*G[{1}, yv^(-1)]^2*G[{1}, yw]*G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw])/
      32 + (11*G[{0}, yu^(-1)]*G[{1}, yw]^2*G[{yu}, yv^(-1)]*
       G[{1/(yu*yv)}, yw])/32 + (11*G[{0}, yv^(-1)]*G[{1}, yw]^2*
       G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw])/32 - 
     (11*G[{0}, yw]*G[{1}, yw]^2*G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw])/32 - 
     (13*G[{1}, yu^(-1)]*G[{1}, yw]^2*G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw])/
      128 - (G[{1}, yv^(-1)]*G[{1}, yw]^2*G[{yu}, yv^(-1)]*
       G[{1/(yu*yv)}, yw])/8 + (15*G[{1}, yw]^3*G[{yu}, yv^(-1)]*
       G[{1/(yu*yv)}, yw])/64 + (7*Pi^2*G[{yu^(-1)}, yw]*G[{yu}, yv^(-1)]*
       G[{1/(yu*yv)}, yw])/768 - (G[{0}, yu^(-1)]*G[{1}, yu^(-1)]*
       G[{yu^(-1)}, yw]*G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw])/8 - 
     (G[{0}, yv^(-1)]*G[{1}, yu^(-1)]*G[{yu^(-1)}, yw]*G[{yu}, yv^(-1)]*
       G[{1/(yu*yv)}, yw])/8 + (G[{0}, yw]*G[{1}, yu^(-1)]*G[{yu^(-1)}, yw]*
       G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw])/8 + 
     (5*G[{1}, yu^(-1)]^2*G[{yu^(-1)}, yw]*G[{yu}, yv^(-1)]*
       G[{1/(yu*yv)}, yw])/64 + (G[{0}, yu^(-1)]*G[{1}, yv^(-1)]*
       G[{yu^(-1)}, yw]*G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw])/8 + 
     (G[{0}, yv^(-1)]*G[{1}, yv^(-1)]*G[{yu^(-1)}, yw]*G[{yu}, yv^(-1)]*
       G[{1/(yu*yv)}, yw])/8 - (G[{0}, yw]*G[{1}, yv^(-1)]*G[{yu^(-1)}, yw]*
       G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw])/8 + 
     (3*G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*G[{yu^(-1)}, yw]*G[{yu}, yv^(-1)]*
       G[{1/(yu*yv)}, yw])/32 - (5*G[{1}, yv^(-1)]^2*G[{yu^(-1)}, yw]*
       G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw])/64 + 
     (G[{0}, yu^(-1)]*G[{1}, yw]*G[{yu^(-1)}, yw]*G[{yu}, yv^(-1)]*
       G[{1/(yu*yv)}, yw])/16 + (G[{0}, yv^(-1)]*G[{1}, yw]*G[{yu^(-1)}, yw]*
       G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw])/16 - 
     (G[{0}, yw]*G[{1}, yw]*G[{yu^(-1)}, yw]*G[{yu}, yv^(-1)]*
       G[{1/(yu*yv)}, yw])/16 - (G[{1}, yu^(-1)]*G[{1}, yw]*G[{yu^(-1)}, yw]*
       G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw])/32 + 
     (3*G[{1}, yv^(-1)]*G[{1}, yw]*G[{yu^(-1)}, yw]*G[{yu}, yv^(-1)]*
       G[{1/(yu*yv)}, yw])/16 + (9*G[{1}, yw]^2*G[{yu^(-1)}, yw]*
       G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw])/64 - 
     (G[{0}, yu^(-1)]*G[{yu^(-1)}, yw]^2*G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw])/
      8 - (G[{0}, yv^(-1)]*G[{yu^(-1)}, yw]^2*G[{yu}, yv^(-1)]*
       G[{1/(yu*yv)}, yw])/8 + (G[{0}, yw]*G[{yu^(-1)}, yw]^2*
       G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw])/8 + 
     (9*G[{1}, yv^(-1)]*G[{yu^(-1)}, yw]^2*G[{yu}, yv^(-1)]*
       G[{1/(yu*yv)}, yw])/64 - (3*G[{1}, yw]*G[{yu^(-1)}, yw]^2*
       G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw])/16 - 
     (3*G[{yu^(-1)}, yw]^3*G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw])/64 + 
     (31*Pi^2*G[{yu}, yv^(-1)]^2*G[{1/(yu*yv)}, yw])/1536 - 
     (3*G[{1}, yu^(-1)]^2*G[{yu}, yv^(-1)]^2*G[{1/(yu*yv)}, yw])/128 + 
     (7*G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*G[{yu}, yv^(-1)]^2*
       G[{1/(yu*yv)}, yw])/64 + (G[{1}, yv^(-1)]^2*G[{yu}, yv^(-1)]^2*
       G[{1/(yu*yv)}, yw])/128 - (G[{0}, yu^(-1)]*G[{1}, yw]*
       G[{yu}, yv^(-1)]^2*G[{1/(yu*yv)}, yw])/4 - 
     (G[{0}, yv^(-1)]*G[{1}, yw]*G[{yu}, yv^(-1)]^2*G[{1/(yu*yv)}, yw])/4 + 
     (G[{0}, yw]*G[{1}, yw]*G[{yu}, yv^(-1)]^2*G[{1/(yu*yv)}, yw])/4 + 
     (3*G[{1}, yu^(-1)]*G[{1}, yw]*G[{yu}, yv^(-1)]^2*G[{1/(yu*yv)}, yw])/
      16 + (29*G[{1}, yv^(-1)]*G[{1}, yw]*G[{yu}, yv^(-1)]^2*
       G[{1/(yu*yv)}, yw])/128 - (59*G[{1}, yw]^2*G[{yu}, yv^(-1)]^2*
       G[{1/(yu*yv)}, yw])/256 - (7*G[{1}, yv^(-1)]*G[{yu^(-1)}, yw]*
       G[{yu}, yv^(-1)]^2*G[{1/(yu*yv)}, yw])/64 - 
     (9*G[{1}, yw]*G[{yu^(-1)}, yw]*G[{yu}, yv^(-1)]^2*G[{1/(yu*yv)}, yw])/
      64 + (7*G[{yu^(-1)}, yw]^2*G[{yu}, yv^(-1)]^2*G[{1/(yu*yv)}, yw])/128 - 
     (G[{1}, yu^(-1)]*G[{yu}, yv^(-1)]^3*G[{1/(yu*yv)}, yw])/48 - 
     (7*G[{1}, yv^(-1)]*G[{yu}, yv^(-1)]^3*G[{1/(yu*yv)}, yw])/192 + 
     (11*G[{1}, yw]*G[{yu}, yv^(-1)]^3*G[{1/(yu*yv)}, yw])/384 + 
     (7*G[{yu^(-1)}, yw]*G[{yu}, yv^(-1)]^3*G[{1/(yu*yv)}, yw])/192 + 
     (11*G[{yu}, yv^(-1)]^4*G[{1/(yu*yv)}, yw])/768 + 
     (Pi^2*G[{0}, yu^(-1)]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw])/96 + 
     (Pi^2*G[{0}, yv^(-1)]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw])/96 - 
     (Pi^2*G[{0}, yw]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw])/96 - 
     (G[{0}, yu^(-1)]^2*G[{1}, yu^(-1)]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw])/
      32 - (G[{0}, yu^(-1)]*G[{0}, yv^(-1)]*G[{1}, yu^(-1)]*G[{yv^(-1)}, yw]*
       G[{1/(yu*yv)}, yw])/16 - (G[{0}, yv^(-1)]^2*G[{1}, yu^(-1)]*
       G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw])/32 + 
     (G[{0}, yu^(-1)]*G[{0}, yw]*G[{1}, yu^(-1)]*G[{yv^(-1)}, yw]*
       G[{1/(yu*yv)}, yw])/16 + (G[{0}, yv^(-1)]*G[{0}, yw]*G[{1}, yu^(-1)]*
       G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw])/16 - 
     (G[{0}, yw]^2*G[{1}, yu^(-1)]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw])/32 + 
     (G[{0}, yu^(-1)]*G[{1}, yu^(-1)]^2*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw])/
      16 + (G[{0}, yv^(-1)]*G[{1}, yu^(-1)]^2*G[{yv^(-1)}, yw]*
       G[{1/(yu*yv)}, yw])/16 - (G[{0}, yw]*G[{1}, yu^(-1)]^2*
       G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw])/16 - 
     (G[{1}, yu^(-1)]^3*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw])/32 - 
     (Pi^2*G[{1}, yv^(-1)]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw])/96 + 
     (G[{0}, yu^(-1)]^2*G[{1}, yv^(-1)]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw])/
      32 + (G[{0}, yu^(-1)]*G[{0}, yv^(-1)]*G[{1}, yv^(-1)]*G[{yv^(-1)}, yw]*
       G[{1/(yu*yv)}, yw])/16 + (G[{0}, yv^(-1)]^2*G[{1}, yv^(-1)]*
       G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw])/32 - 
     (G[{0}, yu^(-1)]*G[{0}, yw]*G[{1}, yv^(-1)]*G[{yv^(-1)}, yw]*
       G[{1/(yu*yv)}, yw])/16 - (G[{0}, yv^(-1)]*G[{0}, yw]*G[{1}, yv^(-1)]*
       G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw])/16 + 
     (G[{0}, yw]^2*G[{1}, yv^(-1)]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw])/32 - 
     (G[{0}, yu^(-1)]*G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*G[{yv^(-1)}, yw]*
       G[{1/(yu*yv)}, yw])/8 - (G[{0}, yv^(-1)]*G[{1}, yu^(-1)]*
       G[{1}, yv^(-1)]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw])/8 + 
     (G[{0}, yw]*G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*G[{yv^(-1)}, yw]*
       G[{1/(yu*yv)}, yw])/8 + (3*G[{1}, yu^(-1)]^2*G[{1}, yv^(-1)]*
       G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw])/32 + 
     (G[{0}, yu^(-1)]*G[{1}, yv^(-1)]^2*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw])/
      32 + (G[{0}, yv^(-1)]*G[{1}, yv^(-1)]^2*G[{yv^(-1)}, yw]*
       G[{1/(yu*yv)}, yw])/32 - (G[{0}, yw]*G[{1}, yv^(-1)]^2*
       G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw])/32 - 
     (G[{1}, yu^(-1)]*G[{1}, yv^(-1)]^2*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw])/
      32 - (5*G[{1}, yv^(-1)]^3*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw])/128 + 
     (Pi^2*G[{1}, yw]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw])/48 - 
     (G[{0}, yu^(-1)]^2*G[{1}, yw]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw])/32 - 
     (G[{0}, yu^(-1)]*G[{0}, yv^(-1)]*G[{1}, yw]*G[{yv^(-1)}, yw]*
       G[{1/(yu*yv)}, yw])/16 - (G[{0}, yv^(-1)]^2*G[{1}, yw]*
       G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw])/32 + 
     (G[{0}, yu^(-1)]*G[{0}, yw]*G[{1}, yw]*G[{yv^(-1)}, yw]*
       G[{1/(yu*yv)}, yw])/16 + (G[{0}, yv^(-1)]*G[{0}, yw]*G[{1}, yw]*
       G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw])/16 - 
     (G[{0}, yw]^2*G[{1}, yw]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw])/32 + 
     (G[{1}, yu^(-1)]^2*G[{1}, yw]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw])/32 + 
     (G[{0}, yu^(-1)]*G[{1}, yv^(-1)]*G[{1}, yw]*G[{yv^(-1)}, yw]*
       G[{1/(yu*yv)}, yw])/16 + (G[{0}, yv^(-1)]*G[{1}, yv^(-1)]*G[{1}, yw]*
       G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw])/16 - 
     (G[{0}, yw]*G[{1}, yv^(-1)]*G[{1}, yw]*G[{yv^(-1)}, yw]*
       G[{1/(yu*yv)}, yw])/16 - (3*G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*G[{1}, yw]*
       G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw])/16 - 
     (3*G[{1}, yv^(-1)]^2*G[{1}, yw]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw])/
      128 - (G[{0}, yu^(-1)]*G[{1}, yw]^2*G[{yv^(-1)}, yw]*
       G[{1/(yu*yv)}, yw])/16 - (G[{0}, yv^(-1)]*G[{1}, yw]^2*
       G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw])/16 + 
     (G[{0}, yw]*G[{1}, yw]^2*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw])/16 + 
     (G[{1}, yv^(-1)]*G[{1}, yw]^2*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw])/128 - 
     (5*G[{1}, yw]^3*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw])/128 - 
     (Pi^2*G[{yu}, yv^(-1)]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw])/96 + 
     (G[{0}, yu^(-1)]*G[{1}, yu^(-1)]*G[{yu}, yv^(-1)]*G[{yv^(-1)}, yw]*
       G[{1/(yu*yv)}, yw])/8 + (G[{0}, yv^(-1)]*G[{1}, yu^(-1)]*
       G[{yu}, yv^(-1)]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw])/8 - 
     (G[{0}, yw]*G[{1}, yu^(-1)]*G[{yu}, yv^(-1)]*G[{yv^(-1)}, yw]*
       G[{1/(yu*yv)}, yw])/8 - (G[{1}, yu^(-1)]^2*G[{yu}, yv^(-1)]*
       G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw])/8 - 
     (G[{0}, yu^(-1)]*G[{1}, yv^(-1)]*G[{yu}, yv^(-1)]*G[{yv^(-1)}, yw]*
       G[{1/(yu*yv)}, yw])/8 - (G[{0}, yv^(-1)]*G[{1}, yv^(-1)]*
       G[{yu}, yv^(-1)]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw])/8 + 
     (G[{0}, yw]*G[{1}, yv^(-1)]*G[{yu}, yv^(-1)]*G[{yv^(-1)}, yw]*
       G[{1/(yu*yv)}, yw])/8 + (G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*
       G[{yu}, yv^(-1)]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw])/8 + 
     (3*G[{1}, yv^(-1)]^2*G[{yu}, yv^(-1)]*G[{yv^(-1)}, yw]*
       G[{1/(yu*yv)}, yw])/32 + (G[{0}, yu^(-1)]*G[{1}, yw]*G[{yu}, yv^(-1)]*
       G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw])/16 + 
     (G[{0}, yv^(-1)]*G[{1}, yw]*G[{yu}, yv^(-1)]*G[{yv^(-1)}, yw]*
       G[{1/(yu*yv)}, yw])/16 - (G[{0}, yw]*G[{1}, yw]*G[{yu}, yv^(-1)]*
       G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw])/16 + 
     (G[{1}, yu^(-1)]*G[{1}, yw]*G[{yu}, yv^(-1)]*G[{yv^(-1)}, yw]*
       G[{1/(yu*yv)}, yw])/8 - (G[{1}, yv^(-1)]*G[{1}, yw]*G[{yu}, yv^(-1)]*
       G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw])/32 + 
     (15*G[{1}, yw]^2*G[{yu}, yv^(-1)]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw])/
      128 - (G[{1}, yu^(-1)]*G[{yu}, yv^(-1)]^2*G[{yv^(-1)}, yw]*
       G[{1/(yu*yv)}, yw])/16 - (7*G[{1}, yw]*G[{yu}, yv^(-1)]^2*
       G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw])/64 + 
     (G[{yu}, yv^(-1)]^3*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw])/48 - 
     (Pi^2*G[{yv^(-1)}, yw]^2*G[{1/(yu*yv)}, yw])/192 + 
     (G[{0}, yu^(-1)]^2*G[{yv^(-1)}, yw]^2*G[{1/(yu*yv)}, yw])/32 + 
     (G[{0}, yu^(-1)]*G[{0}, yv^(-1)]*G[{yv^(-1)}, yw]^2*G[{1/(yu*yv)}, yw])/
      16 + (G[{0}, yv^(-1)]^2*G[{yv^(-1)}, yw]^2*G[{1/(yu*yv)}, yw])/32 - 
     (G[{0}, yu^(-1)]*G[{0}, yw]*G[{yv^(-1)}, yw]^2*G[{1/(yu*yv)}, yw])/16 - 
     (G[{0}, yv^(-1)]*G[{0}, yw]*G[{yv^(-1)}, yw]^2*G[{1/(yu*yv)}, yw])/16 + 
     (G[{0}, yw]^2*G[{yv^(-1)}, yw]^2*G[{1/(yu*yv)}, yw])/32 - 
     (G[{0}, yu^(-1)]*G[{1}, yu^(-1)]*G[{yv^(-1)}, yw]^2*G[{1/(yu*yv)}, yw])/
      16 - (G[{0}, yv^(-1)]*G[{1}, yu^(-1)]*G[{yv^(-1)}, yw]^2*
       G[{1/(yu*yv)}, yw])/16 + (G[{0}, yw]*G[{1}, yu^(-1)]*
       G[{yv^(-1)}, yw]^2*G[{1/(yu*yv)}, yw])/16 + 
     (G[{1}, yu^(-1)]^2*G[{yv^(-1)}, yw]^2*G[{1/(yu*yv)}, yw])/32 + 
     (G[{0}, yu^(-1)]*G[{1}, yv^(-1)]*G[{yv^(-1)}, yw]^2*G[{1/(yu*yv)}, yw])/
      16 + (G[{0}, yv^(-1)]*G[{1}, yv^(-1)]*G[{yv^(-1)}, yw]^2*
       G[{1/(yu*yv)}, yw])/16 - (G[{0}, yw]*G[{1}, yv^(-1)]*
       G[{yv^(-1)}, yw]^2*G[{1/(yu*yv)}, yw])/16 - 
     (G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*G[{yv^(-1)}, yw]^2*G[{1/(yu*yv)}, yw])/
      8 - (G[{1}, yv^(-1)]^2*G[{yv^(-1)}, yw]^2*G[{1/(yu*yv)}, yw])/64 + 
     (G[{0}, yu^(-1)]*G[{1}, yw]*G[{yv^(-1)}, yw]^2*G[{1/(yu*yv)}, yw])/16 + 
     (G[{0}, yv^(-1)]*G[{1}, yw]*G[{yv^(-1)}, yw]^2*G[{1/(yu*yv)}, yw])/16 - 
     (G[{0}, yw]*G[{1}, yw]*G[{yv^(-1)}, yw]^2*G[{1/(yu*yv)}, yw])/16 - 
     (G[{1}, yu^(-1)]*G[{1}, yw]*G[{yv^(-1)}, yw]^2*G[{1/(yu*yv)}, yw])/16 + 
     (3*G[{1}, yv^(-1)]*G[{1}, yw]*G[{yv^(-1)}, yw]^2*G[{1/(yu*yv)}, yw])/
      32 + (5*G[{1}, yw]^2*G[{yv^(-1)}, yw]^2*G[{1/(yu*yv)}, yw])/64 - 
     (G[{0}, yu^(-1)]*G[{yu}, yv^(-1)]*G[{yv^(-1)}, yw]^2*G[{1/(yu*yv)}, yw])/
      8 - (G[{0}, yv^(-1)]*G[{yu}, yv^(-1)]*G[{yv^(-1)}, yw]^2*
       G[{1/(yu*yv)}, yw])/8 + (G[{0}, yw]*G[{yu}, yv^(-1)]*
       G[{yv^(-1)}, yw]^2*G[{1/(yu*yv)}, yw])/8 + 
     (3*G[{1}, yu^(-1)]*G[{yu}, yv^(-1)]*G[{yv^(-1)}, yw]^2*
       G[{1/(yu*yv)}, yw])/16 - (5*G[{1}, yw]*G[{yu}, yv^(-1)]*
       G[{yv^(-1)}, yw]^2*G[{1/(yu*yv)}, yw])/32 + 
     (G[{yu}, yv^(-1)]^2*G[{yv^(-1)}, yw]^2*G[{1/(yu*yv)}, yw])/32 + 
     (G[{0}, yu^(-1)]*G[{yv^(-1)}, yw]^3*G[{1/(yu*yv)}, yw])/24 + 
     (G[{0}, yv^(-1)]*G[{yv^(-1)}, yw]^3*G[{1/(yu*yv)}, yw])/24 - 
     (G[{0}, yw]*G[{yv^(-1)}, yw]^3*G[{1/(yu*yv)}, yw])/24 - 
     (G[{1}, yu^(-1)]*G[{yv^(-1)}, yw]^3*G[{1/(yu*yv)}, yw])/48 + 
     (G[{1}, yw]*G[{yv^(-1)}, yw]^3*G[{1/(yu*yv)}, yw])/16 - 
     (G[{yu}, yv^(-1)]*G[{yv^(-1)}, yw]^3*G[{1/(yu*yv)}, yw])/16 + 
     (G[{yv^(-1)}, yw]^4*G[{1/(yu*yv)}, yw])/192 - 
     (Pi^2*G[{1}, yu^(-1)]*G[{1/(yu*yv)}, yw]^2)/192 + 
     (G[{0}, yu^(-1)]^2*G[{1}, yu^(-1)]*G[{1/(yu*yv)}, yw]^2)/64 + 
     (G[{0}, yu^(-1)]*G[{0}, yv^(-1)]*G[{1}, yu^(-1)]*G[{1/(yu*yv)}, yw]^2)/
      32 + (G[{0}, yv^(-1)]^2*G[{1}, yu^(-1)]*G[{1/(yu*yv)}, yw]^2)/64 - 
     (G[{0}, yu^(-1)]*G[{0}, yw]*G[{1}, yu^(-1)]*G[{1/(yu*yv)}, yw]^2)/32 - 
     (G[{0}, yv^(-1)]*G[{0}, yw]*G[{1}, yu^(-1)]*G[{1/(yu*yv)}, yw]^2)/32 + 
     (G[{0}, yw]^2*G[{1}, yu^(-1)]*G[{1/(yu*yv)}, yw]^2)/64 - 
     (G[{0}, yu^(-1)]*G[{1}, yu^(-1)]^2*G[{1/(yu*yv)}, yw]^2)/32 - 
     (G[{0}, yv^(-1)]*G[{1}, yu^(-1)]^2*G[{1/(yu*yv)}, yw]^2)/32 + 
     (G[{0}, yw]*G[{1}, yu^(-1)]^2*G[{1/(yu*yv)}, yw]^2)/32 + 
     (G[{1}, yu^(-1)]^3*G[{1/(yu*yv)}, yw]^2)/64 - 
     (11*Pi^2*G[{1}, yv^(-1)]*G[{1/(yu*yv)}, yw]^2)/1536 + 
     (G[{0}, yu^(-1)]^2*G[{1}, yv^(-1)]*G[{1/(yu*yv)}, yw]^2)/64 + 
     (G[{0}, yu^(-1)]*G[{0}, yv^(-1)]*G[{1}, yv^(-1)]*G[{1/(yu*yv)}, yw]^2)/
      32 + (G[{0}, yv^(-1)]^2*G[{1}, yv^(-1)]*G[{1/(yu*yv)}, yw]^2)/64 - 
     (G[{0}, yu^(-1)]*G[{0}, yw]*G[{1}, yv^(-1)]*G[{1/(yu*yv)}, yw]^2)/32 - 
     (G[{0}, yv^(-1)]*G[{0}, yw]*G[{1}, yv^(-1)]*G[{1/(yu*yv)}, yw]^2)/32 + 
     (G[{0}, yw]^2*G[{1}, yv^(-1)]*G[{1/(yu*yv)}, yw]^2)/64 + 
     (G[{0}, yu^(-1)]*G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*G[{1/(yu*yv)}, yw]^2)/
      16 + (G[{0}, yv^(-1)]*G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*
       G[{1/(yu*yv)}, yw]^2)/16 - (G[{0}, yw]*G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*
       G[{1/(yu*yv)}, yw]^2)/16 - (17*G[{1}, yu^(-1)]^2*G[{1}, yv^(-1)]*
       G[{1/(yu*yv)}, yw]^2)/256 + (G[{0}, yu^(-1)]*G[{1}, yv^(-1)]^2*
       G[{1/(yu*yv)}, yw]^2)/64 + (G[{0}, yv^(-1)]*G[{1}, yv^(-1)]^2*
       G[{1/(yu*yv)}, yw]^2)/64 - (G[{0}, yw]*G[{1}, yv^(-1)]^2*
       G[{1/(yu*yv)}, yw]^2)/64 - (G[{1}, yu^(-1)]*G[{1}, yv^(-1)]^2*
       G[{1/(yu*yv)}, yw]^2)/16 - (G[{1}, yv^(-1)]^3*G[{1/(yu*yv)}, yw]^2)/
      32 - (19*Pi^2*G[{1}, yw]*G[{1/(yu*yv)}, yw]^2)/1536 + 
     (G[{0}, yu^(-1)]^2*G[{1}, yw]*G[{1/(yu*yv)}, yw]^2)/32 + 
     (G[{0}, yu^(-1)]*G[{0}, yv^(-1)]*G[{1}, yw]*G[{1/(yu*yv)}, yw]^2)/16 + 
     (G[{0}, yv^(-1)]^2*G[{1}, yw]*G[{1/(yu*yv)}, yw]^2)/32 - 
     (G[{0}, yu^(-1)]*G[{0}, yw]*G[{1}, yw]*G[{1/(yu*yv)}, yw]^2)/16 - 
     (G[{0}, yv^(-1)]*G[{0}, yw]*G[{1}, yw]*G[{1/(yu*yv)}, yw]^2)/16 + 
     (G[{0}, yw]^2*G[{1}, yw]*G[{1/(yu*yv)}, yw]^2)/32 - 
     (5*G[{1}, yu^(-1)]^2*G[{1}, yw]*G[{1/(yu*yv)}, yw]^2)/256 + 
     (3*G[{0}, yu^(-1)]*G[{1}, yv^(-1)]*G[{1}, yw]*G[{1/(yu*yv)}, yw]^2)/32 + 
     (3*G[{0}, yv^(-1)]*G[{1}, yv^(-1)]*G[{1}, yw]*G[{1/(yu*yv)}, yw]^2)/32 - 
     (3*G[{0}, yw]*G[{1}, yv^(-1)]*G[{1}, yw]*G[{1/(yu*yv)}, yw]^2)/32 - 
     (G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*G[{1}, yw]*G[{1/(yu*yv)}, yw]^2)/64 - 
     (9*G[{1}, yv^(-1)]^2*G[{1}, yw]*G[{1/(yu*yv)}, yw]^2)/128 + 
     (7*G[{0}, yu^(-1)]*G[{1}, yw]^2*G[{1/(yu*yv)}, yw]^2)/64 + 
     (7*G[{0}, yv^(-1)]*G[{1}, yw]^2*G[{1/(yu*yv)}, yw]^2)/64 - 
     (7*G[{0}, yw]*G[{1}, yw]^2*G[{1/(yu*yv)}, yw]^2)/64 - 
     (G[{1}, yu^(-1)]*G[{1}, yw]^2*G[{1/(yu*yv)}, yw]^2)/32 + 
     (3*G[{1}, yv^(-1)]*G[{1}, yw]^2*G[{1/(yu*yv)}, yw]^2)/256 + 
     (17*G[{1}, yw]^3*G[{1/(yu*yv)}, yw]^2)/256 + 
     (11*Pi^2*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2)/1536 - 
     (G[{0}, yu^(-1)]^2*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2)/64 - 
     (G[{0}, yu^(-1)]*G[{0}, yv^(-1)]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2)/
      32 - (G[{0}, yv^(-1)]^2*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2)/64 + 
     (G[{0}, yu^(-1)]*G[{0}, yw]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2)/32 + 
     (G[{0}, yv^(-1)]*G[{0}, yw]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2)/32 - 
     (G[{0}, yw]^2*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2)/64 + 
     (G[{1}, yu^(-1)]^2*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2)/256 + 
     (11*G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*G[{yu^(-1)}, yw]*
       G[{1/(yu*yv)}, yw]^2)/128 + (G[{1}, yv^(-1)]^2*G[{yu^(-1)}, yw]*
       G[{1/(yu*yv)}, yw]^2)/16 - (G[{0}, yu^(-1)]*G[{1}, yw]*
       G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2)/16 - 
     (G[{0}, yv^(-1)]*G[{1}, yw]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2)/16 + 
     (G[{0}, yw]*G[{1}, yw]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2)/16 + 
     (5*G[{1}, yu^(-1)]*G[{1}, yw]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2)/
      128 + (5*G[{1}, yv^(-1)]*G[{1}, yw]*G[{yu^(-1)}, yw]*
       G[{1/(yu*yv)}, yw]^2)/32 + (9*G[{1}, yw]^2*G[{yu^(-1)}, yw]*
       G[{1/(yu*yv)}, yw]^2)/256 - (G[{1}, yu^(-1)]*G[{yu^(-1)}, yw]^2*
       G[{1/(yu*yv)}, yw]^2)/64 - (15*G[{1}, yv^(-1)]*G[{yu^(-1)}, yw]^2*
       G[{1/(yu*yv)}, yw]^2)/256 - (19*G[{1}, yw]*G[{yu^(-1)}, yw]^2*
       G[{1/(yu*yv)}, yw]^2)/256 + (5*G[{yu^(-1)}, yw]^3*
       G[{1/(yu*yv)}, yw]^2)/256 + (19*Pi^2*G[{yu}, yv^(-1)]*
       G[{1/(yu*yv)}, yw]^2)/1536 - (G[{0}, yu^(-1)]^2*G[{yu}, yv^(-1)]*
       G[{1/(yu*yv)}, yw]^2)/32 - (G[{0}, yu^(-1)]*G[{0}, yv^(-1)]*
       G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw]^2)/16 - 
     (G[{0}, yv^(-1)]^2*G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw]^2)/32 + 
     (G[{0}, yu^(-1)]*G[{0}, yw]*G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw]^2)/16 + 
     (G[{0}, yv^(-1)]*G[{0}, yw]*G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw]^2)/16 - 
     (G[{0}, yw]^2*G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw]^2)/32 - 
     (G[{0}, yu^(-1)]*G[{1}, yu^(-1)]*G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw]^2)/
      16 - (G[{0}, yv^(-1)]*G[{1}, yu^(-1)]*G[{yu}, yv^(-1)]*
       G[{1/(yu*yv)}, yw]^2)/16 + (G[{0}, yw]*G[{1}, yu^(-1)]*
       G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw]^2)/16 + 
     (21*G[{1}, yu^(-1)]^2*G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw]^2)/256 - 
     (G[{0}, yu^(-1)]*G[{1}, yv^(-1)]*G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw]^2)/
      16 - (G[{0}, yv^(-1)]*G[{1}, yv^(-1)]*G[{yu}, yv^(-1)]*
       G[{1/(yu*yv)}, yw]^2)/16 + (G[{0}, yw]*G[{1}, yv^(-1)]*
       G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw]^2)/16 + 
     (11*G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*G[{yu}, yv^(-1)]*
       G[{1/(yu*yv)}, yw]^2)/128 + (5*G[{1}, yv^(-1)]^2*G[{yu}, yv^(-1)]*
       G[{1/(yu*yv)}, yw]^2)/128 - (7*G[{0}, yu^(-1)]*G[{1}, yw]*
       G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw]^2)/32 - 
     (7*G[{0}, yv^(-1)]*G[{1}, yw]*G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw]^2)/
      32 + (7*G[{0}, yw]*G[{1}, yw]*G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw]^2)/
      32 + (7*G[{1}, yu^(-1)]*G[{1}, yw]*G[{yu}, yv^(-1)]*
       G[{1/(yu*yv)}, yw]^2)/128 + (3*G[{1}, yv^(-1)]*G[{1}, yw]*
       G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw]^2)/64 - 
     (51*G[{1}, yw]^2*G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw]^2)/256 + 
     (G[{0}, yu^(-1)]*G[{yu^(-1)}, yw]*G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw]^2)/
      16 + (G[{0}, yv^(-1)]*G[{yu^(-1)}, yw]*G[{yu}, yv^(-1)]*
       G[{1/(yu*yv)}, yw]^2)/16 - (G[{0}, yw]*G[{yu^(-1)}, yw]*
       G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw]^2)/16 - 
     (3*G[{1}, yu^(-1)]*G[{yu^(-1)}, yw]*G[{yu}, yv^(-1)]*
       G[{1/(yu*yv)}, yw]^2)/32 - (19*G[{1}, yv^(-1)]*G[{yu^(-1)}, yw]*
       G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw]^2)/128 - 
     (9*G[{1}, yw]*G[{yu^(-1)}, yw]*G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw]^2)/
      128 + (19*G[{yu^(-1)}, yw]^2*G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw]^2)/
      256 + (G[{0}, yu^(-1)]*G[{yu}, yv^(-1)]^2*G[{1/(yu*yv)}, yw]^2)/8 + 
     (G[{0}, yv^(-1)]*G[{yu}, yv^(-1)]^2*G[{1/(yu*yv)}, yw]^2)/8 - 
     (G[{0}, yw]*G[{yu}, yv^(-1)]^2*G[{1/(yu*yv)}, yw]^2)/8 - 
     (G[{1}, yu^(-1)]*G[{yu}, yv^(-1)]^2*G[{1/(yu*yv)}, yw]^2)/16 - 
     (15*G[{1}, yv^(-1)]*G[{yu}, yv^(-1)]^2*G[{1/(yu*yv)}, yw]^2)/256 + 
     (43*G[{1}, yw]*G[{yu}, yv^(-1)]^2*G[{1/(yu*yv)}, yw]^2)/256 + 
     (15*G[{yu^(-1)}, yw]*G[{yu}, yv^(-1)]^2*G[{1/(yu*yv)}, yw]^2)/256 - 
     (11*G[{yu}, yv^(-1)]^3*G[{1/(yu*yv)}, yw]^2)/256 + 
     (Pi^2*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2)/192 - 
     (G[{0}, yu^(-1)]^2*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2)/64 - 
     (G[{0}, yu^(-1)]*G[{0}, yv^(-1)]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2)/
      32 - (G[{0}, yv^(-1)]^2*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2)/64 + 
     (G[{0}, yu^(-1)]*G[{0}, yw]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2)/32 + 
     (G[{0}, yv^(-1)]*G[{0}, yw]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2)/32 - 
     (G[{0}, yw]^2*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2)/64 + 
     (G[{1}, yu^(-1)]^2*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2)/64 + 
     (G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2)/
      8 + (G[{1}, yv^(-1)]^2*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2)/128 - 
     (G[{0}, yu^(-1)]*G[{1}, yw]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2)/16 - 
     (G[{0}, yv^(-1)]*G[{1}, yw]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2)/16 + 
     (G[{0}, yw]*G[{1}, yw]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2)/16 + 
     (3*G[{1}, yu^(-1)]*G[{1}, yw]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2)/
      32 + (5*G[{1}, yv^(-1)]*G[{1}, yw]*G[{yv^(-1)}, yw]*
       G[{1/(yu*yv)}, yw]^2)/64 + (3*G[{1}, yw]^2*G[{yv^(-1)}, yw]*
       G[{1/(yu*yv)}, yw]^2)/128 - (G[{1}, yu^(-1)]*G[{yu^(-1)}, yw]*
       G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2)/16 - 
     (G[{1}, yv^(-1)]*G[{yu^(-1)}, yw]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2)/
      32 - (3*G[{1}, yw]*G[{yu^(-1)}, yw]*G[{yv^(-1)}, yw]*
       G[{1/(yu*yv)}, yw]^2)/32 + (G[{yu^(-1)}, yw]^2*G[{yv^(-1)}, yw]*
       G[{1/(yu*yv)}, yw]^2)/64 + (G[{0}, yu^(-1)]*G[{yu}, yv^(-1)]*
       G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2)/16 + 
     (G[{0}, yv^(-1)]*G[{yu}, yv^(-1)]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2)/
      16 - (G[{0}, yw]*G[{yu}, yv^(-1)]*G[{yv^(-1)}, yw]*
       G[{1/(yu*yv)}, yw]^2)/16 - (5*G[{1}, yu^(-1)]*G[{yu}, yv^(-1)]*
       G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2)/32 - 
     (3*G[{1}, yv^(-1)]*G[{yu}, yv^(-1)]*G[{yv^(-1)}, yw]*
       G[{1/(yu*yv)}, yw]^2)/32 - (3*G[{1}, yw]*G[{yu}, yv^(-1)]*
       G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2)/64 + 
     (3*G[{yu^(-1)}, yw]*G[{yu}, yv^(-1)]*G[{yv^(-1)}, yw]*
       G[{1/(yu*yv)}, yw]^2)/32 + (G[{yu}, yv^(-1)]^2*G[{yv^(-1)}, yw]*
       G[{1/(yu*yv)}, yw]^2)/16 - (3*G[{1}, yu^(-1)]*G[{yv^(-1)}, yw]^2*
       G[{1/(yu*yv)}, yw]^2)/64 - (G[{1}, yv^(-1)]*G[{yv^(-1)}, yw]^2*
       G[{1/(yu*yv)}, yw]^2)/32 - (5*G[{1}, yw]*G[{yv^(-1)}, yw]^2*
       G[{1/(yu*yv)}, yw]^2)/64 + (G[{yu^(-1)}, yw]*G[{yv^(-1)}, yw]^2*
       G[{1/(yu*yv)}, yw]^2)/32 + (5*G[{yu}, yv^(-1)]*G[{yv^(-1)}, yw]^2*
       G[{1/(yu*yv)}, yw]^2)/64 + (G[{yv^(-1)}, yw]^3*G[{1/(yu*yv)}, yw]^2)/
      64 + (G[{0}, yu^(-1)]*G[{1}, yu^(-1)]*G[{1/(yu*yv)}, yw]^3)/48 + 
     (G[{0}, yv^(-1)]*G[{1}, yu^(-1)]*G[{1/(yu*yv)}, yw]^3)/48 - 
     (G[{0}, yw]*G[{1}, yu^(-1)]*G[{1/(yu*yv)}, yw]^3)/48 - 
     (G[{1}, yu^(-1)]^2*G[{1/(yu*yv)}, yw]^3)/48 - 
     (G[{0}, yu^(-1)]*G[{1}, yv^(-1)]*G[{1/(yu*yv)}, yw]^3)/96 - 
     (G[{0}, yv^(-1)]*G[{1}, yv^(-1)]*G[{1/(yu*yv)}, yw]^3)/96 + 
     (G[{0}, yw]*G[{1}, yv^(-1)]*G[{1/(yu*yv)}, yw]^3)/96 - 
     (3*G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*G[{1/(yu*yv)}, yw]^3)/128 + 
     (G[{1}, yv^(-1)]^2*G[{1/(yu*yv)}, yw]^3)/96 + 
     (G[{0}, yu^(-1)]*G[{1}, yw]*G[{1/(yu*yv)}, yw]^3)/96 + 
     (G[{0}, yv^(-1)]*G[{1}, yw]*G[{1/(yu*yv)}, yw]^3)/96 - 
     (G[{0}, yw]*G[{1}, yw]*G[{1/(yu*yv)}, yw]^3)/96 - 
     (3*G[{1}, yu^(-1)]*G[{1}, yw]*G[{1/(yu*yv)}, yw]^3)/128 - 
     (3*G[{1}, yv^(-1)]*G[{1}, yw]*G[{1/(yu*yv)}, yw]^3)/128 - 
     (5*G[{1}, yw]^2*G[{1/(yu*yv)}, yw]^3)/384 + 
     (G[{0}, yu^(-1)]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]^3)/96 + 
     (G[{0}, yv^(-1)]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]^3)/96 - 
     (G[{0}, yw]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]^3)/96 + 
     (3*G[{1}, yu^(-1)]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]^3)/128 - 
     (G[{1}, yv^(-1)]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]^3)/48 + 
     (3*G[{1}, yw]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]^3)/128 + 
     (G[{yu^(-1)}, yw]^2*G[{1/(yu*yv)}, yw]^3)/96 - 
     (G[{0}, yu^(-1)]*G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw]^3)/96 - 
     (G[{0}, yv^(-1)]*G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw]^3)/96 + 
     (G[{0}, yw]*G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw]^3)/96 + 
     (3*G[{1}, yu^(-1)]*G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw]^3)/128 + 
     (3*G[{1}, yv^(-1)]*G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw]^3)/128 + 
     (5*G[{1}, yw]*G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw]^3)/192 - 
     (3*G[{yu^(-1)}, yw]*G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw]^3)/128 - 
     (5*G[{yu}, yv^(-1)]^2*G[{1/(yu*yv)}, yw]^3)/384 - 
     (G[{0}, yu^(-1)]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]^3)/48 - 
     (G[{0}, yv^(-1)]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]^3)/48 + 
     (G[{0}, yw]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]^3)/48 + 
     (G[{1}, yu^(-1)]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]^3)/24 + 
     (3*G[{1}, yv^(-1)]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]^3)/128 + 
     (3*G[{1}, yw]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]^3)/128 - 
     (3*G[{yu^(-1)}, yw]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]^3)/128 - 
     (3*G[{yu}, yv^(-1)]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]^3)/128 - 
     (G[{yv^(-1)}, yw]^2*G[{1/(yu*yv)}, yw]^3)/48 + 
     (Pi^2*G[{1}, yu^(-1)]*G[{0, 1}, yu^(-1)])/96 - 
     (G[{1}, yu^(-1)]^3*G[{0, 1}, yu^(-1)])/96 - 
     (Pi^2*G[{1}, yv^(-1)]*G[{0, 1}, yu^(-1)])/96 + 
     (G[{1}, yu^(-1)]^2*G[{1}, yv^(-1)]*G[{0, 1}, yu^(-1)])/32 - 
     (G[{1}, yu^(-1)]*G[{1}, yv^(-1)]^2*G[{0, 1}, yu^(-1)])/32 + 
     (5*G[{1}, yv^(-1)]^3*G[{0, 1}, yu^(-1)])/128 + 
     (Pi^2*G[{1}, yw]*G[{0, 1}, yu^(-1)])/96 - 
     (G[{0}, yu^(-1)]^2*G[{1}, yw]*G[{0, 1}, yu^(-1)])/32 - 
     (G[{0}, yu^(-1)]*G[{0}, yv^(-1)]*G[{1}, yw]*G[{0, 1}, yu^(-1)])/16 - 
     (G[{0}, yv^(-1)]^2*G[{1}, yw]*G[{0, 1}, yu^(-1)])/32 + 
     (G[{0}, yu^(-1)]*G[{0}, yw]*G[{1}, yw]*G[{0, 1}, yu^(-1)])/16 + 
     (G[{0}, yv^(-1)]*G[{0}, yw]*G[{1}, yw]*G[{0, 1}, yu^(-1)])/16 - 
     (G[{0}, yw]^2*G[{1}, yw]*G[{0, 1}, yu^(-1)])/32 + 
     (G[{0}, yu^(-1)]*G[{1}, yu^(-1)]*G[{1}, yw]*G[{0, 1}, yu^(-1)])/16 + 
     (G[{0}, yv^(-1)]*G[{1}, yu^(-1)]*G[{1}, yw]*G[{0, 1}, yu^(-1)])/16 - 
     (G[{0}, yw]*G[{1}, yu^(-1)]*G[{1}, yw]*G[{0, 1}, yu^(-1)])/16 - 
     (G[{1}, yu^(-1)]^2*G[{1}, yw]*G[{0, 1}, yu^(-1)])/32 - 
     (G[{0}, yu^(-1)]*G[{1}, yv^(-1)]*G[{1}, yw]*G[{0, 1}, yu^(-1)])/8 - 
     (G[{0}, yv^(-1)]*G[{1}, yv^(-1)]*G[{1}, yw]*G[{0, 1}, yu^(-1)])/8 + 
     (G[{0}, yw]*G[{1}, yv^(-1)]*G[{1}, yw]*G[{0, 1}, yu^(-1)])/8 + 
     (G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*G[{1}, yw]*G[{0, 1}, yu^(-1)])/16 + 
     (7*G[{1}, yv^(-1)]^2*G[{1}, yw]*G[{0, 1}, yu^(-1)])/128 - 
     (13*G[{1}, yv^(-1)]*G[{1}, yw]^2*G[{0, 1}, yu^(-1)])/128 - 
     (5*G[{1}, yw]^3*G[{0, 1}, yu^(-1)])/384 + 
     (G[{0}, yu^(-1)]*G[{1}, yw]*G[{yu}, yv^(-1)]*G[{0, 1}, yu^(-1)])/8 + 
     (G[{0}, yv^(-1)]*G[{1}, yw]*G[{yu}, yv^(-1)]*G[{0, 1}, yu^(-1)])/8 - 
     (G[{0}, yw]*G[{1}, yw]*G[{yu}, yv^(-1)]*G[{0, 1}, yu^(-1)])/8 - 
     (G[{1}, yu^(-1)]*G[{1}, yw]*G[{yu}, yv^(-1)]*G[{0, 1}, yu^(-1)])/8 + 
     (3*G[{1}, yv^(-1)]*G[{1}, yw]*G[{yu}, yv^(-1)]*G[{0, 1}, yu^(-1)])/32 + 
     (13*G[{1}, yw]^2*G[{yu}, yv^(-1)]*G[{0, 1}, yu^(-1)])/128 - 
     (7*G[{1}, yw]*G[{yu}, yv^(-1)]^2*G[{0, 1}, yu^(-1)])/64 - 
     (Pi^2*G[{1/(yu*yv)}, yw]*G[{0, 1}, yu^(-1)])/96 + 
     (G[{0}, yu^(-1)]^2*G[{1/(yu*yv)}, yw]*G[{0, 1}, yu^(-1)])/32 + 
     (G[{0}, yu^(-1)]*G[{0}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, 1}, yu^(-1)])/
      16 + (G[{0}, yv^(-1)]^2*G[{1/(yu*yv)}, yw]*G[{0, 1}, yu^(-1)])/32 - 
     (G[{0}, yu^(-1)]*G[{0}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1}, yu^(-1)])/16 - 
     (G[{0}, yv^(-1)]*G[{0}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1}, yu^(-1)])/16 + 
     (G[{0}, yw]^2*G[{1/(yu*yv)}, yw]*G[{0, 1}, yu^(-1)])/32 - 
     (G[{0}, yu^(-1)]*G[{1}, yu^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, 1}, yu^(-1)])/
      16 - (G[{0}, yv^(-1)]*G[{1}, yu^(-1)]*G[{1/(yu*yv)}, yw]*
       G[{0, 1}, yu^(-1)])/16 + (G[{0}, yw]*G[{1}, yu^(-1)]*
       G[{1/(yu*yv)}, yw]*G[{0, 1}, yu^(-1)])/16 + 
     (G[{1}, yu^(-1)]^2*G[{1/(yu*yv)}, yw]*G[{0, 1}, yu^(-1)])/32 + 
     (G[{0}, yu^(-1)]*G[{1}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, 1}, yu^(-1)])/
      8 + (G[{0}, yv^(-1)]*G[{1}, yv^(-1)]*G[{1/(yu*yv)}, yw]*
       G[{0, 1}, yu^(-1)])/8 - (G[{0}, yw]*G[{1}, yv^(-1)]*G[{1/(yu*yv)}, yw]*
       G[{0, 1}, yu^(-1)])/8 - (G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*
       G[{1/(yu*yv)}, yw]*G[{0, 1}, yu^(-1)])/16 - 
     (7*G[{1}, yv^(-1)]^2*G[{1/(yu*yv)}, yw]*G[{0, 1}, yu^(-1)])/128 + 
     (13*G[{1}, yv^(-1)]*G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1}, yu^(-1)])/
      64 + (5*G[{1}, yw]^2*G[{1/(yu*yv)}, yw]*G[{0, 1}, yu^(-1)])/128 - 
     (G[{1}, yu^(-1)]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1}, yu^(-1)])/
      16 + (3*G[{1}, yv^(-1)]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*
       G[{0, 1}, yu^(-1)])/32 - (G[{1}, yw]*G[{yu^(-1)}, yw]*
       G[{1/(yu*yv)}, yw]*G[{0, 1}, yu^(-1)])/32 - 
     (G[{yu^(-1)}, yw]^2*G[{1/(yu*yv)}, yw]*G[{0, 1}, yu^(-1)])/64 - 
     (G[{0}, yu^(-1)]*G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, 1}, yu^(-1)])/
      8 - (G[{0}, yv^(-1)]*G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw]*
       G[{0, 1}, yu^(-1)])/8 + (G[{0}, yw]*G[{yu}, yv^(-1)]*
       G[{1/(yu*yv)}, yw]*G[{0, 1}, yu^(-1)])/8 + 
     (G[{1}, yu^(-1)]*G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, 1}, yu^(-1)])/
      8 - (3*G[{1}, yv^(-1)]*G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw]*
       G[{0, 1}, yu^(-1)])/32 - (13*G[{1}, yw]*G[{yu}, yv^(-1)]*
       G[{1/(yu*yv)}, yw]*G[{0, 1}, yu^(-1)])/64 - 
     (G[{yu^(-1)}, yw]*G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw]*
       G[{0, 1}, yu^(-1)])/32 + (7*G[{yu}, yv^(-1)]^2*G[{1/(yu*yv)}, yw]*
       G[{0, 1}, yu^(-1)])/64 - (G[{0}, yu^(-1)]*G[{yv^(-1)}, yw]*
       G[{1/(yu*yv)}, yw]*G[{0, 1}, yu^(-1)])/16 - 
     (G[{0}, yv^(-1)]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1}, yu^(-1)])/
      16 + (G[{0}, yw]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*
       G[{0, 1}, yu^(-1)])/16 + (G[{1}, yu^(-1)]*G[{yv^(-1)}, yw]*
       G[{1/(yu*yv)}, yw]*G[{0, 1}, yu^(-1)])/16 + 
     (G[{1}, yv^(-1)]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1}, yu^(-1)])/
      16 - (G[{1}, yw]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*
       G[{0, 1}, yu^(-1)])/16 - (G[{yv^(-1)}, yw]^2*G[{1/(yu*yv)}, yw]*
       G[{0, 1}, yu^(-1)])/16 + (G[{0}, yu^(-1)]*G[{1/(yu*yv)}, yw]^2*
       G[{0, 1}, yu^(-1)])/16 + (G[{0}, yv^(-1)]*G[{1/(yu*yv)}, yw]^2*
       G[{0, 1}, yu^(-1)])/16 - (G[{0}, yw]*G[{1/(yu*yv)}, yw]^2*
       G[{0, 1}, yu^(-1)])/16 - (G[{1}, yu^(-1)]*G[{1/(yu*yv)}, yw]^2*
       G[{0, 1}, yu^(-1)])/16 - (7*G[{1}, yv^(-1)]*G[{1/(yu*yv)}, yw]^2*
       G[{0, 1}, yu^(-1)])/128 + (G[{1}, yw]*G[{1/(yu*yv)}, yw]^2*
       G[{0, 1}, yu^(-1)])/128 + (7*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2*
       G[{0, 1}, yu^(-1)])/128 - (G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw]^2*
       G[{0, 1}, yu^(-1)])/128 + (G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2*
       G[{0, 1}, yu^(-1)])/16 + (G[{1}, yw]*G[{0, 1}, yu^(-1)]^2)/32 - 
     (G[{1/(yu*yv)}, yw]*G[{0, 1}, yu^(-1)]^2)/32 + 
     (Pi^2*G[{1}, yu^(-1)]*G[{0, 1}, yv^(-1)])/96 - 
     (13*Pi^2*G[{1}, yv^(-1)]*G[{0, 1}, yv^(-1)])/768 - 
     (3*G[{1}, yu^(-1)]^2*G[{1}, yv^(-1)]*G[{0, 1}, yv^(-1)])/128 - 
     (3*G[{1}, yu^(-1)]*G[{1}, yv^(-1)]^2*G[{0, 1}, yv^(-1)])/64 + 
     (11*G[{1}, yv^(-1)]^3*G[{0, 1}, yv^(-1)])/384 + 
     (11*Pi^2*G[{1}, yw]*G[{0, 1}, yv^(-1)])/768 - 
     (G[{0}, yu^(-1)]^2*G[{1}, yw]*G[{0, 1}, yv^(-1)])/32 - 
     (G[{0}, yu^(-1)]*G[{0}, yv^(-1)]*G[{1}, yw]*G[{0, 1}, yv^(-1)])/16 - 
     (G[{0}, yv^(-1)]^2*G[{1}, yw]*G[{0, 1}, yv^(-1)])/32 + 
     (G[{0}, yu^(-1)]*G[{0}, yw]*G[{1}, yw]*G[{0, 1}, yv^(-1)])/16 + 
     (G[{0}, yv^(-1)]*G[{0}, yw]*G[{1}, yw]*G[{0, 1}, yv^(-1)])/16 - 
     (G[{0}, yw]^2*G[{1}, yw]*G[{0, 1}, yv^(-1)])/32 + 
     (G[{1}, yu^(-1)]^2*G[{1}, yw]*G[{0, 1}, yv^(-1)])/128 - 
     (G[{0}, yu^(-1)]*G[{1}, yv^(-1)]*G[{1}, yw]*G[{0, 1}, yv^(-1)])/8 - 
     (G[{0}, yv^(-1)]*G[{1}, yv^(-1)]*G[{1}, yw]*G[{0, 1}, yv^(-1)])/8 + 
     (G[{0}, yw]*G[{1}, yv^(-1)]*G[{1}, yw]*G[{0, 1}, yv^(-1)])/8 + 
     (G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*G[{1}, yw]*G[{0, 1}, yv^(-1)])/16 + 
     (11*G[{1}, yv^(-1)]^2*G[{1}, yw]*G[{0, 1}, yv^(-1)])/128 - 
     (3*G[{0}, yu^(-1)]*G[{1}, yw]^2*G[{0, 1}, yv^(-1)])/32 - 
     (3*G[{0}, yv^(-1)]*G[{1}, yw]^2*G[{0, 1}, yv^(-1)])/32 + 
     (3*G[{0}, yw]*G[{1}, yw]^2*G[{0, 1}, yv^(-1)])/32 + 
     (G[{1}, yu^(-1)]*G[{1}, yw]^2*G[{0, 1}, yv^(-1)])/64 - 
     (G[{1}, yv^(-1)]*G[{1}, yw]^2*G[{0, 1}, yv^(-1)])/32 - 
     (13*G[{1}, yw]^3*G[{0, 1}, yv^(-1)])/192 + 
     (G[{0}, yu^(-1)]*G[{1}, yw]*G[{yu}, yv^(-1)]*G[{0, 1}, yv^(-1)])/8 + 
     (G[{0}, yv^(-1)]*G[{1}, yw]*G[{yu}, yv^(-1)]*G[{0, 1}, yv^(-1)])/8 - 
     (G[{0}, yw]*G[{1}, yw]*G[{yu}, yv^(-1)]*G[{0, 1}, yv^(-1)])/8 - 
     (G[{1}, yu^(-1)]*G[{1}, yw]*G[{yu}, yv^(-1)]*G[{0, 1}, yv^(-1)])/16 + 
     (5*G[{1}, yv^(-1)]*G[{1}, yw]*G[{yu}, yv^(-1)]*G[{0, 1}, yv^(-1)])/64 + 
     (21*G[{1}, yw]^2*G[{yu}, yv^(-1)]*G[{0, 1}, yv^(-1)])/128 - 
     (3*G[{1}, yw]*G[{yu}, yv^(-1)]^2*G[{0, 1}, yv^(-1)])/32 - 
     (11*Pi^2*G[{1/(yu*yv)}, yw]*G[{0, 1}, yv^(-1)])/768 + 
     (G[{0}, yu^(-1)]^2*G[{1/(yu*yv)}, yw]*G[{0, 1}, yv^(-1)])/32 + 
     (G[{0}, yu^(-1)]*G[{0}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, 1}, yv^(-1)])/
      16 + (G[{0}, yv^(-1)]^2*G[{1/(yu*yv)}, yw]*G[{0, 1}, yv^(-1)])/32 - 
     (G[{0}, yu^(-1)]*G[{0}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1}, yv^(-1)])/16 - 
     (G[{0}, yv^(-1)]*G[{0}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1}, yv^(-1)])/16 + 
     (G[{0}, yw]^2*G[{1/(yu*yv)}, yw]*G[{0, 1}, yv^(-1)])/32 - 
     (G[{1}, yu^(-1)]^2*G[{1/(yu*yv)}, yw]*G[{0, 1}, yv^(-1)])/128 + 
     (G[{0}, yu^(-1)]*G[{1}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, 1}, yv^(-1)])/
      8 + (G[{0}, yv^(-1)]*G[{1}, yv^(-1)]*G[{1/(yu*yv)}, yw]*
       G[{0, 1}, yv^(-1)])/8 - (G[{0}, yw]*G[{1}, yv^(-1)]*G[{1/(yu*yv)}, yw]*
       G[{0, 1}, yv^(-1)])/8 - (G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*
       G[{1/(yu*yv)}, yw]*G[{0, 1}, yv^(-1)])/16 - 
     (11*G[{1}, yv^(-1)]^2*G[{1/(yu*yv)}, yw]*G[{0, 1}, yv^(-1)])/128 + 
     (3*G[{0}, yu^(-1)]*G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1}, yv^(-1)])/
      16 + (3*G[{0}, yv^(-1)]*G[{1}, yw]*G[{1/(yu*yv)}, yw]*
       G[{0, 1}, yv^(-1)])/16 - (3*G[{0}, yw]*G[{1}, yw]*G[{1/(yu*yv)}, yw]*
       G[{0, 1}, yv^(-1)])/16 - (G[{1}, yu^(-1)]*G[{1}, yw]*
       G[{1/(yu*yv)}, yw]*G[{0, 1}, yv^(-1)])/32 + 
     (G[{1}, yv^(-1)]*G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1}, yv^(-1)])/16 + 
     (13*G[{1}, yw]^2*G[{1/(yu*yv)}, yw]*G[{0, 1}, yv^(-1)])/64 - 
     (G[{0}, yu^(-1)]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1}, yv^(-1)])/
      16 - (G[{0}, yv^(-1)]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*
       G[{0, 1}, yv^(-1)])/16 + (G[{0}, yw]*G[{yu^(-1)}, yw]*
       G[{1/(yu*yv)}, yw]*G[{0, 1}, yv^(-1)])/16 + 
     (5*G[{1}, yv^(-1)]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*
       G[{0, 1}, yv^(-1)])/32 + (G[{1}, yw]*G[{yu^(-1)}, yw]*
       G[{1/(yu*yv)}, yw]*G[{0, 1}, yv^(-1)])/32 - 
     (G[{yu^(-1)}, yw]^2*G[{1/(yu*yv)}, yw]*G[{0, 1}, yv^(-1)])/16 - 
     (G[{0}, yu^(-1)]*G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, 1}, yv^(-1)])/
      8 - (G[{0}, yv^(-1)]*G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw]*
       G[{0, 1}, yv^(-1)])/8 + (G[{0}, yw]*G[{yu}, yv^(-1)]*
       G[{1/(yu*yv)}, yw]*G[{0, 1}, yv^(-1)])/8 + 
     (G[{1}, yu^(-1)]*G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, 1}, yv^(-1)])/
      16 - (5*G[{1}, yv^(-1)]*G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw]*
       G[{0, 1}, yv^(-1)])/64 - (21*G[{1}, yw]*G[{yu}, yv^(-1)]*
       G[{1/(yu*yv)}, yw]*G[{0, 1}, yv^(-1)])/64 + 
     (3*G[{yu}, yv^(-1)]^2*G[{1/(yu*yv)}, yw]*G[{0, 1}, yv^(-1)])/32 + 
     (G[{1}, yu^(-1)]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1}, yv^(-1)])/
      16 + (G[{1}, yv^(-1)]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*
       G[{0, 1}, yv^(-1)])/64 + (5*G[{1}, yw]*G[{yv^(-1)}, yw]*
       G[{1/(yu*yv)}, yw]*G[{0, 1}, yv^(-1)])/64 - 
     (G[{yu}, yv^(-1)]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*
       G[{0, 1}, yv^(-1)])/16 - (G[{yv^(-1)}, yw]^2*G[{1/(yu*yv)}, yw]*
       G[{0, 1}, yv^(-1)])/32 - (G[{0}, yu^(-1)]*G[{1/(yu*yv)}, yw]^2*
       G[{0, 1}, yv^(-1)])/32 - (G[{0}, yv^(-1)]*G[{1/(yu*yv)}, yw]^2*
       G[{0, 1}, yv^(-1)])/32 + (G[{0}, yw]*G[{1/(yu*yv)}, yw]^2*
       G[{0, 1}, yv^(-1)])/32 - (G[{1}, yu^(-1)]*G[{1/(yu*yv)}, yw]^2*
       G[{0, 1}, yv^(-1)])/64 + (G[{1}, yv^(-1)]*G[{1/(yu*yv)}, yw]^2*
       G[{0, 1}, yv^(-1)])/128 - (9*G[{1}, yw]*G[{1/(yu*yv)}, yw]^2*
       G[{0, 1}, yv^(-1)])/128 - (G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2*
       G[{0, 1}, yv^(-1)])/128 + (9*G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw]^2*
       G[{0, 1}, yv^(-1)])/128 + (G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2*
       G[{0, 1}, yv^(-1)])/64 - (5*G[{1}, yv^(-1)]*G[{0, 1}, yu^(-1)]*
       G[{0, 1}, yv^(-1)])/64 + (3*G[{1}, yw]*G[{0, 1}, yu^(-1)]*
       G[{0, 1}, yv^(-1)])/64 - (3*G[{1/(yu*yv)}, yw]*G[{0, 1}, yu^(-1)]*
       G[{0, 1}, yv^(-1)])/64 - (3*G[{1}, yv^(-1)]*G[{0, 1}, yv^(-1)]^2)/
      128 + (G[{1}, yw]*G[{0, 1}, yv^(-1)]^2)/128 - 
     (G[{1/(yu*yv)}, yw]*G[{0, 1}, yv^(-1)]^2)/128 - 
     (Pi^2*G[{0}, yu^(-1)]*G[{0, 1}, yw])/96 - 
     (Pi^2*G[{0}, yv^(-1)]*G[{0, 1}, yw])/96 + 
     (Pi^2*G[{0}, yw]*G[{0, 1}, yw])/96 + 
     (Pi^2*G[{1}, yu^(-1)]*G[{0, 1}, yw])/96 - 
     (Pi^2*G[{1}, yv^(-1)]*G[{0, 1}, yw])/48 + 
     (Pi^2*G[{1}, yw]*G[{0, 1}, yw])/96 - 
     (G[{0}, yu^(-1)]^2*G[{1}, yw]*G[{0, 1}, yw])/32 - 
     (G[{0}, yu^(-1)]*G[{0}, yv^(-1)]*G[{1}, yw]*G[{0, 1}, yw])/16 - 
     (G[{0}, yv^(-1)]^2*G[{1}, yw]*G[{0, 1}, yw])/32 + 
     (G[{0}, yu^(-1)]*G[{0}, yw]*G[{1}, yw]*G[{0, 1}, yw])/16 + 
     (G[{0}, yv^(-1)]*G[{0}, yw]*G[{1}, yw]*G[{0, 1}, yw])/16 - 
     (G[{0}, yw]^2*G[{1}, yw]*G[{0, 1}, yw])/32 + 
     (G[{0}, yu^(-1)]*G[{1}, yu^(-1)]*G[{1}, yw]*G[{0, 1}, yw])/8 + 
     (G[{0}, yv^(-1)]*G[{1}, yu^(-1)]*G[{1}, yw]*G[{0, 1}, yw])/8 - 
     (G[{0}, yw]*G[{1}, yu^(-1)]*G[{1}, yw]*G[{0, 1}, yw])/8 - 
     (3*G[{1}, yu^(-1)]^2*G[{1}, yw]*G[{0, 1}, yw])/32 - 
     (G[{0}, yu^(-1)]*G[{1}, yv^(-1)]*G[{1}, yw]*G[{0, 1}, yw])/16 - 
     (G[{0}, yv^(-1)]*G[{1}, yv^(-1)]*G[{1}, yw]*G[{0, 1}, yw])/16 + 
     (G[{0}, yw]*G[{1}, yv^(-1)]*G[{1}, yw]*G[{0, 1}, yw])/16 + 
     (G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*G[{1}, yw]*G[{0, 1}, yw])/16 + 
     (3*G[{1}, yv^(-1)]^2*G[{1}, yw]*G[{0, 1}, yw])/32 - 
     (G[{0}, yu^(-1)]*G[{1}, yw]^2*G[{0, 1}, yw])/16 - 
     (G[{0}, yv^(-1)]*G[{1}, yw]^2*G[{0, 1}, yw])/16 + 
     (G[{0}, yw]*G[{1}, yw]^2*G[{0, 1}, yw])/16 + 
     (G[{1}, yu^(-1)]*G[{1}, yw]^2*G[{0, 1}, yw])/16 + 
     (G[{1}, yv^(-1)]*G[{1}, yw]^2*G[{0, 1}, yw])/16 + 
     (Pi^2*G[{yu}, yv^(-1)]*G[{0, 1}, yw])/48 + 
     (G[{0}, yu^(-1)]*G[{1}, yw]*G[{yu}, yv^(-1)]*G[{0, 1}, yw])/16 + 
     (G[{0}, yv^(-1)]*G[{1}, yw]*G[{yu}, yv^(-1)]*G[{0, 1}, yw])/16 - 
     (G[{0}, yw]*G[{1}, yw]*G[{yu}, yv^(-1)]*G[{0, 1}, yw])/16 - 
     (G[{1}, yu^(-1)]*G[{1}, yw]*G[{yu}, yv^(-1)]*G[{0, 1}, yw])/8 - 
     (G[{1}, yv^(-1)]*G[{1}, yw]*G[{yu}, yv^(-1)]*G[{0, 1}, yw])/8 + 
     (G[{1}, yw]*G[{yu}, yv^(-1)]^2*G[{0, 1}, yw])/16 - 
     (Pi^2*G[{1/(yu*yv)}, yw]*G[{0, 1}, yw])/96 + 
     (G[{0}, yu^(-1)]^2*G[{1/(yu*yv)}, yw]*G[{0, 1}, yw])/32 + 
     (G[{0}, yu^(-1)]*G[{0}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, 1}, yw])/16 + 
     (G[{0}, yv^(-1)]^2*G[{1/(yu*yv)}, yw]*G[{0, 1}, yw])/32 - 
     (G[{0}, yu^(-1)]*G[{0}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1}, yw])/16 - 
     (G[{0}, yv^(-1)]*G[{0}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1}, yw])/16 + 
     (G[{0}, yw]^2*G[{1/(yu*yv)}, yw]*G[{0, 1}, yw])/32 - 
     (G[{0}, yu^(-1)]*G[{1}, yu^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, 1}, yw])/8 - 
     (G[{0}, yv^(-1)]*G[{1}, yu^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, 1}, yw])/8 + 
     (G[{0}, yw]*G[{1}, yu^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, 1}, yw])/8 + 
     (3*G[{1}, yu^(-1)]^2*G[{1/(yu*yv)}, yw]*G[{0, 1}, yw])/32 + 
     (G[{0}, yu^(-1)]*G[{1}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, 1}, yw])/16 + 
     (G[{0}, yv^(-1)]*G[{1}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, 1}, yw])/16 - 
     (G[{0}, yw]*G[{1}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, 1}, yw])/16 - 
     (G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, 1}, yw])/16 - 
     (3*G[{1}, yv^(-1)]^2*G[{1/(yu*yv)}, yw]*G[{0, 1}, yw])/32 + 
     (G[{0}, yu^(-1)]*G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1}, yw])/8 + 
     (G[{0}, yv^(-1)]*G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1}, yw])/8 - 
     (G[{0}, yw]*G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1}, yw])/8 - 
     (G[{1}, yu^(-1)]*G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1}, yw])/8 - 
     (G[{1}, yv^(-1)]*G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1}, yw])/8 - 
     (3*G[{0}, yu^(-1)]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1}, yw])/
      16 - (3*G[{0}, yv^(-1)]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*
       G[{0, 1}, yw])/16 + (3*G[{0}, yw]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*
       G[{0, 1}, yw])/16 + (G[{1}, yu^(-1)]*G[{yu^(-1)}, yw]*
       G[{1/(yu*yv)}, yw]*G[{0, 1}, yw])/4 - 
     (G[{1}, yw]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1}, yw])/16 + 
     (G[{yu^(-1)}, yw]^2*G[{1/(yu*yv)}, yw]*G[{0, 1}, yw])/8 - 
     (G[{0}, yu^(-1)]*G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, 1}, yw])/16 - 
     (G[{0}, yv^(-1)]*G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, 1}, yw])/16 + 
     (G[{0}, yw]*G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, 1}, yw])/16 + 
     (G[{1}, yu^(-1)]*G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, 1}, yw])/8 + 
     (G[{1}, yv^(-1)]*G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, 1}, yw])/8 + 
     (G[{yu^(-1)}, yw]*G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, 1}, yw])/8 - 
     (G[{yu}, yv^(-1)]^2*G[{1/(yu*yv)}, yw]*G[{0, 1}, yw])/16 - 
     (G[{1}, yv^(-1)]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1}, yw])/8 - 
     (G[{1}, yw]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1}, yw])/16 + 
     (G[{yu}, yv^(-1)]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1}, yw])/8 - 
     (G[{yv^(-1)}, yw]^2*G[{1/(yu*yv)}, yw]*G[{0, 1}, yw])/16 - 
     (G[{0}, yu^(-1)]*G[{0, 1}, yu^(-1)]*G[{0, 1}, yw])/16 - 
     (G[{0}, yv^(-1)]*G[{0, 1}, yu^(-1)]*G[{0, 1}, yw])/16 + 
     (G[{0}, yw]*G[{0, 1}, yu^(-1)]*G[{0, 1}, yw])/16 + 
     (G[{1}, yu^(-1)]*G[{0, 1}, yu^(-1)]*G[{0, 1}, yw])/16 - 
     (G[{1}, yv^(-1)]*G[{0, 1}, yu^(-1)]*G[{0, 1}, yw])/8 + 
     (G[{yu}, yv^(-1)]*G[{0, 1}, yu^(-1)]*G[{0, 1}, yw])/8 - 
     (G[{0}, yu^(-1)]*G[{0, 1}, yv^(-1)]*G[{0, 1}, yw])/16 - 
     (G[{0}, yv^(-1)]*G[{0, 1}, yv^(-1)]*G[{0, 1}, yw])/16 + 
     (G[{0}, yw]*G[{0, 1}, yv^(-1)]*G[{0, 1}, yw])/16 - 
     (G[{1}, yv^(-1)]*G[{0, 1}, yv^(-1)]*G[{0, 1}, yw])/8 + 
     (G[{yu}, yv^(-1)]*G[{0, 1}, yv^(-1)]*G[{0, 1}, yw])/8 - 
     (G[{1}, yu^(-1)]*G[{0, 1}, yw]^2)/32 + (G[{1}, yv^(-1)]*G[{0, 1}, yw]^2)/
      16 + (G[{1}, yw]*G[{0, 1}, yw]^2)/32 - 
     (G[{yu}, yv^(-1)]*G[{0, 1}, yw]^2)/32 - 
     (G[{1/(yu*yv)}, yw]*G[{0, 1}, yw]^2)/32 - 
     (Pi^2*G[{1}, yw]*G[{0, yu^(-1)}, yw])/96 + 
     (G[{0}, yu^(-1)]^2*G[{1}, yw]*G[{0, yu^(-1)}, yw])/32 + 
     (G[{0}, yu^(-1)]*G[{0}, yv^(-1)]*G[{1}, yw]*G[{0, yu^(-1)}, yw])/16 + 
     (G[{0}, yv^(-1)]^2*G[{1}, yw]*G[{0, yu^(-1)}, yw])/32 - 
     (G[{0}, yu^(-1)]*G[{0}, yw]*G[{1}, yw]*G[{0, yu^(-1)}, yw])/16 - 
     (G[{0}, yv^(-1)]*G[{0}, yw]*G[{1}, yw]*G[{0, yu^(-1)}, yw])/16 + 
     (G[{0}, yw]^2*G[{1}, yw]*G[{0, yu^(-1)}, yw])/32 - 
     (G[{0}, yu^(-1)]*G[{1}, yu^(-1)]*G[{1}, yw]*G[{0, yu^(-1)}, yw])/8 - 
     (G[{0}, yv^(-1)]*G[{1}, yu^(-1)]*G[{1}, yw]*G[{0, yu^(-1)}, yw])/8 + 
     (G[{0}, yw]*G[{1}, yu^(-1)]*G[{1}, yw]*G[{0, yu^(-1)}, yw])/8 + 
     (3*G[{1}, yu^(-1)]^2*G[{1}, yw]*G[{0, yu^(-1)}, yw])/32 + 
     (G[{0}, yu^(-1)]*G[{1}, yv^(-1)]*G[{1}, yw]*G[{0, yu^(-1)}, yw])/8 + 
     (G[{0}, yv^(-1)]*G[{1}, yv^(-1)]*G[{1}, yw]*G[{0, yu^(-1)}, yw])/8 - 
     (G[{0}, yw]*G[{1}, yv^(-1)]*G[{1}, yw]*G[{0, yu^(-1)}, yw])/8 - 
     (G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*G[{1}, yw]*G[{0, yu^(-1)}, yw])/16 - 
     (5*G[{1}, yv^(-1)]^2*G[{1}, yw]*G[{0, yu^(-1)}, yw])/32 + 
     (G[{0}, yu^(-1)]*G[{1}, yw]^2*G[{0, yu^(-1)}, yw])/16 + 
     (G[{0}, yv^(-1)]*G[{1}, yw]^2*G[{0, yu^(-1)}, yw])/16 - 
     (G[{0}, yw]*G[{1}, yw]^2*G[{0, yu^(-1)}, yw])/16 - 
     (G[{1}, yu^(-1)]*G[{1}, yw]^2*G[{0, yu^(-1)}, yw])/16 - 
     (G[{1}, yv^(-1)]*G[{1}, yw]^2*G[{0, yu^(-1)}, yw])/16 - 
     (G[{0}, yu^(-1)]*G[{1}, yw]*G[{yu}, yv^(-1)]*G[{0, yu^(-1)}, yw])/8 - 
     (G[{0}, yv^(-1)]*G[{1}, yw]*G[{yu}, yv^(-1)]*G[{0, yu^(-1)}, yw])/8 + 
     (G[{0}, yw]*G[{1}, yw]*G[{yu}, yv^(-1)]*G[{0, yu^(-1)}, yw])/8 + 
     (G[{1}, yu^(-1)]*G[{1}, yw]*G[{yu}, yv^(-1)]*G[{0, yu^(-1)}, yw])/8 + 
     (G[{1}, yv^(-1)]*G[{1}, yw]*G[{yu}, yv^(-1)]*G[{0, yu^(-1)}, yw])/8 + 
     (Pi^2*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1)}, yw])/96 - 
     (G[{0}, yu^(-1)]^2*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1)}, yw])/32 - 
     (G[{0}, yu^(-1)]*G[{0}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1)}, yw])/
      16 - (G[{0}, yv^(-1)]^2*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1)}, yw])/32 + 
     (G[{0}, yu^(-1)]*G[{0}, yw]*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1)}, yw])/16 + 
     (G[{0}, yv^(-1)]*G[{0}, yw]*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1)}, yw])/16 - 
     (G[{0}, yw]^2*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1)}, yw])/32 + 
     (G[{0}, yu^(-1)]*G[{1}, yu^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1)}, yw])/
      8 + (G[{0}, yv^(-1)]*G[{1}, yu^(-1)]*G[{1/(yu*yv)}, yw]*
       G[{0, yu^(-1)}, yw])/8 - (G[{0}, yw]*G[{1}, yu^(-1)]*
       G[{1/(yu*yv)}, yw]*G[{0, yu^(-1)}, yw])/8 - 
     (3*G[{1}, yu^(-1)]^2*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1)}, yw])/32 - 
     (G[{0}, yu^(-1)]*G[{1}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1)}, yw])/
      8 - (G[{0}, yv^(-1)]*G[{1}, yv^(-1)]*G[{1/(yu*yv)}, yw]*
       G[{0, yu^(-1)}, yw])/8 + (G[{0}, yw]*G[{1}, yv^(-1)]*
       G[{1/(yu*yv)}, yw]*G[{0, yu^(-1)}, yw])/8 + 
     (G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1)}, yw])/
      16 + (5*G[{1}, yv^(-1)]^2*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1)}, yw])/32 - 
     (G[{0}, yu^(-1)]*G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1)}, yw])/8 - 
     (G[{0}, yv^(-1)]*G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1)}, yw])/8 + 
     (G[{0}, yw]*G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1)}, yw])/8 + 
     (G[{1}, yu^(-1)]*G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1)}, yw])/8 + 
     (G[{1}, yv^(-1)]*G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1)}, yw])/8 + 
     (3*G[{0}, yu^(-1)]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*
       G[{0, yu^(-1)}, yw])/16 + (3*G[{0}, yv^(-1)]*G[{yu^(-1)}, yw]*
       G[{1/(yu*yv)}, yw]*G[{0, yu^(-1)}, yw])/16 - 
     (3*G[{0}, yw]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1)}, yw])/
      16 - (G[{1}, yu^(-1)]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*
       G[{0, yu^(-1)}, yw])/4 + (G[{1}, yw]*G[{yu^(-1)}, yw]*
       G[{1/(yu*yv)}, yw]*G[{0, yu^(-1)}, yw])/16 - 
     (G[{yu^(-1)}, yw]^2*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1)}, yw])/8 + 
     (G[{0}, yu^(-1)]*G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw]*
       G[{0, yu^(-1)}, yw])/8 + (G[{0}, yv^(-1)]*G[{yu}, yv^(-1)]*
       G[{1/(yu*yv)}, yw]*G[{0, yu^(-1)}, yw])/8 - 
     (G[{0}, yw]*G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1)}, yw])/8 - 
     (G[{1}, yu^(-1)]*G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw]*
       G[{0, yu^(-1)}, yw])/8 - (G[{1}, yv^(-1)]*G[{yu}, yv^(-1)]*
       G[{1/(yu*yv)}, yw]*G[{0, yu^(-1)}, yw])/8 - 
     (G[{yu^(-1)}, yw]*G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw]*
       G[{0, yu^(-1)}, yw])/8 + (G[{1}, yv^(-1)]*G[{yv^(-1)}, yw]*
       G[{1/(yu*yv)}, yw]*G[{0, yu^(-1)}, yw])/8 + 
     (G[{1}, yw]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1)}, yw])/
      16 - (G[{yu}, yv^(-1)]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*
       G[{0, yu^(-1)}, yw])/8 + (G[{yv^(-1)}, yw]^2*G[{1/(yu*yv)}, yw]*
       G[{0, yu^(-1)}, yw])/16 - (G[{1}, yw]*G[{0, 1}, yw]*
       G[{0, yu^(-1)}, yw])/16 + (G[{1/(yu*yv)}, yw]*G[{0, 1}, yw]*
       G[{0, yu^(-1)}, yw])/16 + (G[{1}, yw]*G[{0, yu^(-1)}, yw]^2)/32 - 
     (G[{1/(yu*yv)}, yw]*G[{0, yu^(-1)}, yw]^2)/32 + 
     (5*Pi^2*G[{1}, yv^(-1)]*G[{0, yu}, yv^(-1)])/768 + 
     (3*G[{1}, yu^(-1)]^2*G[{1}, yv^(-1)]*G[{0, yu}, yv^(-1)])/128 + 
     (3*G[{1}, yu^(-1)]*G[{1}, yv^(-1)]^2*G[{0, yu}, yv^(-1)])/64 - 
     (11*G[{1}, yv^(-1)]^3*G[{0, yu}, yv^(-1)])/384 - 
     (11*Pi^2*G[{1}, yw]*G[{0, yu}, yv^(-1)])/768 + 
     (G[{0}, yu^(-1)]^2*G[{1}, yw]*G[{0, yu}, yv^(-1)])/32 + 
     (G[{0}, yu^(-1)]*G[{0}, yv^(-1)]*G[{1}, yw]*G[{0, yu}, yv^(-1)])/16 + 
     (G[{0}, yv^(-1)]^2*G[{1}, yw]*G[{0, yu}, yv^(-1)])/32 - 
     (G[{0}, yu^(-1)]*G[{0}, yw]*G[{1}, yw]*G[{0, yu}, yv^(-1)])/16 - 
     (G[{0}, yv^(-1)]*G[{0}, yw]*G[{1}, yw]*G[{0, yu}, yv^(-1)])/16 + 
     (G[{0}, yw]^2*G[{1}, yw]*G[{0, yu}, yv^(-1)])/32 - 
     (G[{1}, yu^(-1)]^2*G[{1}, yw]*G[{0, yu}, yv^(-1)])/128 + 
     (G[{0}, yu^(-1)]*G[{1}, yv^(-1)]*G[{1}, yw]*G[{0, yu}, yv^(-1)])/8 + 
     (G[{0}, yv^(-1)]*G[{1}, yv^(-1)]*G[{1}, yw]*G[{0, yu}, yv^(-1)])/8 - 
     (G[{0}, yw]*G[{1}, yv^(-1)]*G[{1}, yw]*G[{0, yu}, yv^(-1)])/8 - 
     (G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*G[{1}, yw]*G[{0, yu}, yv^(-1)])/16 - 
     (11*G[{1}, yv^(-1)]^2*G[{1}, yw]*G[{0, yu}, yv^(-1)])/128 + 
     (3*G[{0}, yu^(-1)]*G[{1}, yw]^2*G[{0, yu}, yv^(-1)])/32 + 
     (3*G[{0}, yv^(-1)]*G[{1}, yw]^2*G[{0, yu}, yv^(-1)])/32 - 
     (3*G[{0}, yw]*G[{1}, yw]^2*G[{0, yu}, yv^(-1)])/32 - 
     (G[{1}, yu^(-1)]*G[{1}, yw]^2*G[{0, yu}, yv^(-1)])/64 + 
     (G[{1}, yv^(-1)]*G[{1}, yw]^2*G[{0, yu}, yv^(-1)])/32 + 
     (13*G[{1}, yw]^3*G[{0, yu}, yv^(-1)])/192 - 
     (G[{0}, yu^(-1)]*G[{1}, yw]*G[{yu}, yv^(-1)]*G[{0, yu}, yv^(-1)])/8 - 
     (G[{0}, yv^(-1)]*G[{1}, yw]*G[{yu}, yv^(-1)]*G[{0, yu}, yv^(-1)])/8 + 
     (G[{0}, yw]*G[{1}, yw]*G[{yu}, yv^(-1)]*G[{0, yu}, yv^(-1)])/8 + 
     (G[{1}, yu^(-1)]*G[{1}, yw]*G[{yu}, yv^(-1)]*G[{0, yu}, yv^(-1)])/16 - 
     (5*G[{1}, yv^(-1)]*G[{1}, yw]*G[{yu}, yv^(-1)]*G[{0, yu}, yv^(-1)])/64 - 
     (21*G[{1}, yw]^2*G[{yu}, yv^(-1)]*G[{0, yu}, yv^(-1)])/128 + 
     (3*G[{1}, yw]*G[{yu}, yv^(-1)]^2*G[{0, yu}, yv^(-1)])/32 + 
     (11*Pi^2*G[{1/(yu*yv)}, yw]*G[{0, yu}, yv^(-1)])/768 - 
     (G[{0}, yu^(-1)]^2*G[{1/(yu*yv)}, yw]*G[{0, yu}, yv^(-1)])/32 - 
     (G[{0}, yu^(-1)]*G[{0}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, yu}, yv^(-1)])/
      16 - (G[{0}, yv^(-1)]^2*G[{1/(yu*yv)}, yw]*G[{0, yu}, yv^(-1)])/32 + 
     (G[{0}, yu^(-1)]*G[{0}, yw]*G[{1/(yu*yv)}, yw]*G[{0, yu}, yv^(-1)])/16 + 
     (G[{0}, yv^(-1)]*G[{0}, yw]*G[{1/(yu*yv)}, yw]*G[{0, yu}, yv^(-1)])/16 - 
     (G[{0}, yw]^2*G[{1/(yu*yv)}, yw]*G[{0, yu}, yv^(-1)])/32 + 
     (G[{1}, yu^(-1)]^2*G[{1/(yu*yv)}, yw]*G[{0, yu}, yv^(-1)])/128 - 
     (G[{0}, yu^(-1)]*G[{1}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, yu}, yv^(-1)])/
      8 - (G[{0}, yv^(-1)]*G[{1}, yv^(-1)]*G[{1/(yu*yv)}, yw]*
       G[{0, yu}, yv^(-1)])/8 + (G[{0}, yw]*G[{1}, yv^(-1)]*
       G[{1/(yu*yv)}, yw]*G[{0, yu}, yv^(-1)])/8 + 
     (G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, yu}, yv^(-1)])/
      16 + (11*G[{1}, yv^(-1)]^2*G[{1/(yu*yv)}, yw]*G[{0, yu}, yv^(-1)])/
      128 - (3*G[{0}, yu^(-1)]*G[{1}, yw]*G[{1/(yu*yv)}, yw]*
       G[{0, yu}, yv^(-1)])/16 - (3*G[{0}, yv^(-1)]*G[{1}, yw]*
       G[{1/(yu*yv)}, yw]*G[{0, yu}, yv^(-1)])/16 + 
     (3*G[{0}, yw]*G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{0, yu}, yv^(-1)])/16 + 
     (G[{1}, yu^(-1)]*G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{0, yu}, yv^(-1)])/32 - 
     (G[{1}, yv^(-1)]*G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{0, yu}, yv^(-1)])/16 - 
     (13*G[{1}, yw]^2*G[{1/(yu*yv)}, yw]*G[{0, yu}, yv^(-1)])/64 + 
     (G[{0}, yu^(-1)]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*
       G[{0, yu}, yv^(-1)])/16 + (G[{0}, yv^(-1)]*G[{yu^(-1)}, yw]*
       G[{1/(yu*yv)}, yw]*G[{0, yu}, yv^(-1)])/16 - 
     (G[{0}, yw]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{0, yu}, yv^(-1)])/
      16 - (5*G[{1}, yv^(-1)]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*
       G[{0, yu}, yv^(-1)])/32 - (G[{1}, yw]*G[{yu^(-1)}, yw]*
       G[{1/(yu*yv)}, yw]*G[{0, yu}, yv^(-1)])/32 + 
     (G[{yu^(-1)}, yw]^2*G[{1/(yu*yv)}, yw]*G[{0, yu}, yv^(-1)])/16 + 
     (G[{0}, yu^(-1)]*G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw]*
       G[{0, yu}, yv^(-1)])/8 + (G[{0}, yv^(-1)]*G[{yu}, yv^(-1)]*
       G[{1/(yu*yv)}, yw]*G[{0, yu}, yv^(-1)])/8 - 
     (G[{0}, yw]*G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, yu}, yv^(-1)])/8 - 
     (G[{1}, yu^(-1)]*G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw]*
       G[{0, yu}, yv^(-1)])/16 + (5*G[{1}, yv^(-1)]*G[{yu}, yv^(-1)]*
       G[{1/(yu*yv)}, yw]*G[{0, yu}, yv^(-1)])/64 + 
     (21*G[{1}, yw]*G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, yu}, yv^(-1)])/
      64 - (3*G[{yu}, yv^(-1)]^2*G[{1/(yu*yv)}, yw]*G[{0, yu}, yv^(-1)])/32 - 
     (G[{1}, yu^(-1)]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*
       G[{0, yu}, yv^(-1)])/16 - (G[{1}, yv^(-1)]*G[{yv^(-1)}, yw]*
       G[{1/(yu*yv)}, yw]*G[{0, yu}, yv^(-1)])/64 - 
     (5*G[{1}, yw]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{0, yu}, yv^(-1)])/
      64 + (G[{yu}, yv^(-1)]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*
       G[{0, yu}, yv^(-1)])/16 + (G[{yv^(-1)}, yw]^2*G[{1/(yu*yv)}, yw]*
       G[{0, yu}, yv^(-1)])/32 + (G[{0}, yu^(-1)]*G[{1/(yu*yv)}, yw]^2*
       G[{0, yu}, yv^(-1)])/32 + (G[{0}, yv^(-1)]*G[{1/(yu*yv)}, yw]^2*
       G[{0, yu}, yv^(-1)])/32 - (G[{0}, yw]*G[{1/(yu*yv)}, yw]^2*
       G[{0, yu}, yv^(-1)])/32 + (G[{1}, yu^(-1)]*G[{1/(yu*yv)}, yw]^2*
       G[{0, yu}, yv^(-1)])/64 - (G[{1}, yv^(-1)]*G[{1/(yu*yv)}, yw]^2*
       G[{0, yu}, yv^(-1)])/128 + (9*G[{1}, yw]*G[{1/(yu*yv)}, yw]^2*
       G[{0, yu}, yv^(-1)])/128 + (G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2*
       G[{0, yu}, yv^(-1)])/128 - (9*G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw]^2*
       G[{0, yu}, yv^(-1)])/128 - (G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2*
       G[{0, yu}, yv^(-1)])/64 + (G[{1}, yu^(-1)]*G[{0, 1}, yu^(-1)]*
       G[{0, yu}, yv^(-1)])/16 + (G[{1}, yv^(-1)]*G[{0, 1}, yu^(-1)]*
       G[{0, yu}, yv^(-1)])/64 - (3*G[{1}, yw]*G[{0, 1}, yu^(-1)]*
       G[{0, yu}, yv^(-1)])/64 + (3*G[{1/(yu*yv)}, yw]*G[{0, 1}, yu^(-1)]*
       G[{0, yu}, yv^(-1)])/64 - (G[{1}, yv^(-1)]*G[{0, 1}, yv^(-1)]*
       G[{0, yu}, yv^(-1)])/64 - (G[{1}, yw]*G[{0, 1}, yv^(-1)]*
       G[{0, yu}, yv^(-1)])/64 + (G[{1/(yu*yv)}, yw]*G[{0, 1}, yv^(-1)]*
       G[{0, yu}, yv^(-1)])/64 + (G[{0}, yu^(-1)]*G[{0, 1}, yw]*
       G[{0, yu}, yv^(-1)])/16 + (G[{0}, yv^(-1)]*G[{0, 1}, yw]*
       G[{0, yu}, yv^(-1)])/16 - (G[{0}, yw]*G[{0, 1}, yw]*
       G[{0, yu}, yv^(-1)])/16 + (G[{1}, yv^(-1)]*G[{0, 1}, yw]*
       G[{0, yu}, yv^(-1)])/8 - (G[{yu}, yv^(-1)]*G[{0, 1}, yw]*
       G[{0, yu}, yv^(-1)])/8 + (G[{1}, yv^(-1)]*G[{0, yu}, yv^(-1)]^2)/128 + 
     (G[{1}, yw]*G[{0, yu}, yv^(-1)]^2)/128 - 
     (G[{1/(yu*yv)}, yw]*G[{0, yu}, yv^(-1)]^2)/128 - 
     (Pi^2*G[{1}, yw]*G[{0, yv^(-1)}, yw])/96 + 
     (G[{0}, yu^(-1)]^2*G[{1}, yw]*G[{0, yv^(-1)}, yw])/32 + 
     (G[{0}, yu^(-1)]*G[{0}, yv^(-1)]*G[{1}, yw]*G[{0, yv^(-1)}, yw])/16 + 
     (G[{0}, yv^(-1)]^2*G[{1}, yw]*G[{0, yv^(-1)}, yw])/32 - 
     (G[{0}, yu^(-1)]*G[{0}, yw]*G[{1}, yw]*G[{0, yv^(-1)}, yw])/16 - 
     (G[{0}, yv^(-1)]*G[{0}, yw]*G[{1}, yw]*G[{0, yv^(-1)}, yw])/16 + 
     (G[{0}, yw]^2*G[{1}, yw]*G[{0, yv^(-1)}, yw])/32 - 
     (G[{0}, yu^(-1)]*G[{1}, yu^(-1)]*G[{1}, yw]*G[{0, yv^(-1)}, yw])/16 - 
     (G[{0}, yv^(-1)]*G[{1}, yu^(-1)]*G[{1}, yw]*G[{0, yv^(-1)}, yw])/16 + 
     (G[{0}, yw]*G[{1}, yu^(-1)]*G[{1}, yw]*G[{0, yv^(-1)}, yw])/16 + 
     (G[{1}, yu^(-1)]^2*G[{1}, yw]*G[{0, yv^(-1)}, yw])/32 + 
     (G[{0}, yu^(-1)]*G[{1}, yv^(-1)]*G[{1}, yw]*G[{0, yv^(-1)}, yw])/16 + 
     (G[{0}, yv^(-1)]*G[{1}, yv^(-1)]*G[{1}, yw]*G[{0, yv^(-1)}, yw])/16 - 
     (G[{0}, yw]*G[{1}, yv^(-1)]*G[{1}, yw]*G[{0, yv^(-1)}, yw])/16 - 
     (G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*G[{1}, yw]*G[{0, yv^(-1)}, yw])/16 - 
     (3*G[{1}, yv^(-1)]^2*G[{1}, yw]*G[{0, yv^(-1)}, yw])/32 + 
     (G[{0}, yu^(-1)]*G[{1}, yw]^2*G[{0, yv^(-1)}, yw])/16 + 
     (G[{0}, yv^(-1)]*G[{1}, yw]^2*G[{0, yv^(-1)}, yw])/16 - 
     (G[{0}, yw]*G[{1}, yw]^2*G[{0, yv^(-1)}, yw])/16 - 
     (G[{1}, yu^(-1)]*G[{1}, yw]^2*G[{0, yv^(-1)}, yw])/16 - 
     (G[{1}, yv^(-1)]*G[{1}, yw]^2*G[{0, yv^(-1)}, yw])/16 - 
     (G[{0}, yu^(-1)]*G[{1}, yw]*G[{yu}, yv^(-1)]*G[{0, yv^(-1)}, yw])/8 - 
     (G[{0}, yv^(-1)]*G[{1}, yw]*G[{yu}, yv^(-1)]*G[{0, yv^(-1)}, yw])/8 + 
     (G[{0}, yw]*G[{1}, yw]*G[{yu}, yv^(-1)]*G[{0, yv^(-1)}, yw])/8 + 
     (G[{1}, yu^(-1)]*G[{1}, yw]*G[{yu}, yv^(-1)]*G[{0, yv^(-1)}, yw])/8 + 
     (G[{1}, yv^(-1)]*G[{1}, yw]*G[{yu}, yv^(-1)]*G[{0, yv^(-1)}, yw])/8 + 
     (Pi^2*G[{1/(yu*yv)}, yw]*G[{0, yv^(-1)}, yw])/96 - 
     (G[{0}, yu^(-1)]^2*G[{1/(yu*yv)}, yw]*G[{0, yv^(-1)}, yw])/32 - 
     (G[{0}, yu^(-1)]*G[{0}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, yv^(-1)}, yw])/
      16 - (G[{0}, yv^(-1)]^2*G[{1/(yu*yv)}, yw]*G[{0, yv^(-1)}, yw])/32 + 
     (G[{0}, yu^(-1)]*G[{0}, yw]*G[{1/(yu*yv)}, yw]*G[{0, yv^(-1)}, yw])/16 + 
     (G[{0}, yv^(-1)]*G[{0}, yw]*G[{1/(yu*yv)}, yw]*G[{0, yv^(-1)}, yw])/16 - 
     (G[{0}, yw]^2*G[{1/(yu*yv)}, yw]*G[{0, yv^(-1)}, yw])/32 + 
     (G[{0}, yu^(-1)]*G[{1}, yu^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, yv^(-1)}, yw])/
      16 + (G[{0}, yv^(-1)]*G[{1}, yu^(-1)]*G[{1/(yu*yv)}, yw]*
       G[{0, yv^(-1)}, yw])/16 - (G[{0}, yw]*G[{1}, yu^(-1)]*
       G[{1/(yu*yv)}, yw]*G[{0, yv^(-1)}, yw])/16 - 
     (G[{1}, yu^(-1)]^2*G[{1/(yu*yv)}, yw]*G[{0, yv^(-1)}, yw])/32 - 
     (G[{0}, yu^(-1)]*G[{1}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, yv^(-1)}, yw])/
      16 - (G[{0}, yv^(-1)]*G[{1}, yv^(-1)]*G[{1/(yu*yv)}, yw]*
       G[{0, yv^(-1)}, yw])/16 + (G[{0}, yw]*G[{1}, yv^(-1)]*
       G[{1/(yu*yv)}, yw]*G[{0, yv^(-1)}, yw])/16 + 
     (G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, yv^(-1)}, yw])/
      16 + (3*G[{1}, yv^(-1)]^2*G[{1/(yu*yv)}, yw]*G[{0, yv^(-1)}, yw])/32 - 
     (G[{0}, yu^(-1)]*G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{0, yv^(-1)}, yw])/8 - 
     (G[{0}, yv^(-1)]*G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{0, yv^(-1)}, yw])/8 + 
     (G[{0}, yw]*G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{0, yv^(-1)}, yw])/8 + 
     (G[{1}, yu^(-1)]*G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{0, yv^(-1)}, yw])/8 + 
     (G[{1}, yv^(-1)]*G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{0, yv^(-1)}, yw])/8 + 
     (3*G[{0}, yu^(-1)]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*
       G[{0, yv^(-1)}, yw])/16 + (3*G[{0}, yv^(-1)]*G[{yu^(-1)}, yw]*
       G[{1/(yu*yv)}, yw]*G[{0, yv^(-1)}, yw])/16 - 
     (3*G[{0}, yw]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{0, yv^(-1)}, yw])/
      16 - (G[{1}, yu^(-1)]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*
       G[{0, yv^(-1)}, yw])/4 + (G[{1}, yw]*G[{yu^(-1)}, yw]*
       G[{1/(yu*yv)}, yw]*G[{0, yv^(-1)}, yw])/16 - 
     (G[{yu^(-1)}, yw]^2*G[{1/(yu*yv)}, yw]*G[{0, yv^(-1)}, yw])/8 + 
     (G[{0}, yu^(-1)]*G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw]*
       G[{0, yv^(-1)}, yw])/8 + (G[{0}, yv^(-1)]*G[{yu}, yv^(-1)]*
       G[{1/(yu*yv)}, yw]*G[{0, yv^(-1)}, yw])/8 - 
     (G[{0}, yw]*G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, yv^(-1)}, yw])/8 - 
     (G[{1}, yu^(-1)]*G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw]*
       G[{0, yv^(-1)}, yw])/8 - (G[{1}, yv^(-1)]*G[{yu}, yv^(-1)]*
       G[{1/(yu*yv)}, yw]*G[{0, yv^(-1)}, yw])/8 - 
     (G[{yu^(-1)}, yw]*G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw]*
       G[{0, yv^(-1)}, yw])/8 + (G[{1}, yv^(-1)]*G[{yv^(-1)}, yw]*
       G[{1/(yu*yv)}, yw]*G[{0, yv^(-1)}, yw])/8 + 
     (G[{1}, yw]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{0, yv^(-1)}, yw])/
      16 - (G[{yu}, yv^(-1)]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*
       G[{0, yv^(-1)}, yw])/8 + (G[{yv^(-1)}, yw]^2*G[{1/(yu*yv)}, yw]*
       G[{0, yv^(-1)}, yw])/16 - (G[{1}, yw]*G[{0, 1}, yw]*
       G[{0, yv^(-1)}, yw])/16 + (G[{1/(yu*yv)}, yw]*G[{0, 1}, yw]*
       G[{0, yv^(-1)}, yw])/16 + (G[{1}, yw]*G[{0, yu^(-1)}, yw]*
       G[{0, yv^(-1)}, yw])/16 - (G[{1/(yu*yv)}, yw]*G[{0, yu^(-1)}, yw]*
       G[{0, yv^(-1)}, yw])/16 + (G[{1}, yw]*G[{0, yv^(-1)}, yw]^2)/32 - 
     (G[{1/(yu*yv)}, yw]*G[{0, yv^(-1)}, yw]^2)/32 + 
     (Pi^2*G[{0}, yu^(-1)]*G[{0, 1/(yu*yv)}, yw])/96 + 
     (Pi^2*G[{0}, yv^(-1)]*G[{0, 1/(yu*yv)}, yw])/96 - 
     (Pi^2*G[{0}, yw]*G[{0, 1/(yu*yv)}, yw])/96 - 
     (Pi^2*G[{1}, yu^(-1)]*G[{0, 1/(yu*yv)}, yw])/96 + 
     (Pi^2*G[{1}, yv^(-1)]*G[{0, 1/(yu*yv)}, yw])/48 + 
     (Pi^2*G[{1}, yw]*G[{0, 1/(yu*yv)}, yw])/96 - 
     (G[{0}, yu^(-1)]^2*G[{1}, yw]*G[{0, 1/(yu*yv)}, yw])/32 - 
     (G[{0}, yu^(-1)]*G[{0}, yv^(-1)]*G[{1}, yw]*G[{0, 1/(yu*yv)}, yw])/16 - 
     (G[{0}, yv^(-1)]^2*G[{1}, yw]*G[{0, 1/(yu*yv)}, yw])/32 + 
     (G[{0}, yu^(-1)]*G[{0}, yw]*G[{1}, yw]*G[{0, 1/(yu*yv)}, yw])/16 + 
     (G[{0}, yv^(-1)]*G[{0}, yw]*G[{1}, yw]*G[{0, 1/(yu*yv)}, yw])/16 - 
     (G[{0}, yw]^2*G[{1}, yw]*G[{0, 1/(yu*yv)}, yw])/32 + 
     (G[{0}, yu^(-1)]*G[{1}, yu^(-1)]*G[{1}, yw]*G[{0, 1/(yu*yv)}, yw])/16 + 
     (G[{0}, yv^(-1)]*G[{1}, yu^(-1)]*G[{1}, yw]*G[{0, 1/(yu*yv)}, yw])/16 - 
     (G[{0}, yw]*G[{1}, yu^(-1)]*G[{1}, yw]*G[{0, 1/(yu*yv)}, yw])/16 - 
     (G[{1}, yu^(-1)]^2*G[{1}, yw]*G[{0, 1/(yu*yv)}, yw])/32 - 
     (G[{0}, yu^(-1)]*G[{1}, yv^(-1)]*G[{1}, yw]*G[{0, 1/(yu*yv)}, yw])/8 - 
     (G[{0}, yv^(-1)]*G[{1}, yv^(-1)]*G[{1}, yw]*G[{0, 1/(yu*yv)}, yw])/8 + 
     (G[{0}, yw]*G[{1}, yv^(-1)]*G[{1}, yw]*G[{0, 1/(yu*yv)}, yw])/8 + 
     (G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*G[{1}, yw]*G[{0, 1/(yu*yv)}, yw])/16 + 
     (5*G[{1}, yv^(-1)]^2*G[{1}, yw]*G[{0, 1/(yu*yv)}, yw])/32 - 
     (G[{0}, yu^(-1)]*G[{1}, yw]^2*G[{0, 1/(yu*yv)}, yw])/16 - 
     (G[{0}, yv^(-1)]*G[{1}, yw]^2*G[{0, 1/(yu*yv)}, yw])/16 + 
     (G[{0}, yw]*G[{1}, yw]^2*G[{0, 1/(yu*yv)}, yw])/16 + 
     (G[{1}, yu^(-1)]*G[{1}, yw]^2*G[{0, 1/(yu*yv)}, yw])/16 + 
     (G[{1}, yv^(-1)]*G[{1}, yw]^2*G[{0, 1/(yu*yv)}, yw])/16 - 
     (Pi^2*G[{yu}, yv^(-1)]*G[{0, 1/(yu*yv)}, yw])/48 + 
     (3*G[{0}, yu^(-1)]*G[{1}, yw]*G[{yu}, yv^(-1)]*G[{0, 1/(yu*yv)}, yw])/
      16 + (3*G[{0}, yv^(-1)]*G[{1}, yw]*G[{yu}, yv^(-1)]*
       G[{0, 1/(yu*yv)}, yw])/16 - (3*G[{0}, yw]*G[{1}, yw]*G[{yu}, yv^(-1)]*
       G[{0, 1/(yu*yv)}, yw])/16 - (G[{1}, yu^(-1)]*G[{1}, yw]*
       G[{yu}, yv^(-1)]*G[{0, 1/(yu*yv)}, yw])/8 - 
     (G[{1}, yv^(-1)]*G[{1}, yw]*G[{yu}, yv^(-1)]*G[{0, 1/(yu*yv)}, yw])/8 - 
     (G[{1}, yw]*G[{yu}, yv^(-1)]^2*G[{0, 1/(yu*yv)}, yw])/16 - 
     (Pi^2*G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv)}, yw])/96 + 
     (G[{0}, yu^(-1)]^2*G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv)}, yw])/32 + 
     (G[{0}, yu^(-1)]*G[{0}, yv^(-1)]*G[{1/(yu*yv)}, yw]*
       G[{0, 1/(yu*yv)}, yw])/16 + (G[{0}, yv^(-1)]^2*G[{1/(yu*yv)}, yw]*
       G[{0, 1/(yu*yv)}, yw])/32 - (G[{0}, yu^(-1)]*G[{0}, yw]*
       G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv)}, yw])/16 - 
     (G[{0}, yv^(-1)]*G[{0}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv)}, yw])/
      16 + (G[{0}, yw]^2*G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv)}, yw])/32 - 
     (G[{0}, yu^(-1)]*G[{1}, yu^(-1)]*G[{1/(yu*yv)}, yw]*
       G[{0, 1/(yu*yv)}, yw])/16 - (G[{0}, yv^(-1)]*G[{1}, yu^(-1)]*
       G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv)}, yw])/16 + 
     (G[{0}, yw]*G[{1}, yu^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv)}, yw])/
      16 + (G[{1}, yu^(-1)]^2*G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv)}, yw])/32 + 
     (G[{0}, yu^(-1)]*G[{1}, yv^(-1)]*G[{1/(yu*yv)}, yw]*
       G[{0, 1/(yu*yv)}, yw])/8 + (G[{0}, yv^(-1)]*G[{1}, yv^(-1)]*
       G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv)}, yw])/8 - 
     (G[{0}, yw]*G[{1}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv)}, yw])/
      8 - (G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*G[{1/(yu*yv)}, yw]*
       G[{0, 1/(yu*yv)}, yw])/16 - (5*G[{1}, yv^(-1)]^2*G[{1/(yu*yv)}, yw]*
       G[{0, 1/(yu*yv)}, yw])/32 + (G[{0}, yu^(-1)]*G[{1}, yw]*
       G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv)}, yw])/8 + 
     (G[{0}, yv^(-1)]*G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv)}, yw])/
      8 - (G[{0}, yw]*G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv)}, yw])/
      8 - (G[{1}, yu^(-1)]*G[{1}, yw]*G[{1/(yu*yv)}, yw]*
       G[{0, 1/(yu*yv)}, yw])/8 - (G[{1}, yv^(-1)]*G[{1}, yw]*
       G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv)}, yw])/8 - 
     (3*G[{0}, yu^(-1)]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*
       G[{0, 1/(yu*yv)}, yw])/16 - (3*G[{0}, yv^(-1)]*G[{yu^(-1)}, yw]*
       G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv)}, yw])/16 + 
     (3*G[{0}, yw]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv)}, yw])/
      16 + (G[{1}, yu^(-1)]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*
       G[{0, 1/(yu*yv)}, yw])/4 - (G[{1}, yw]*G[{yu^(-1)}, yw]*
       G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv)}, yw])/16 + 
     (G[{yu^(-1)}, yw]^2*G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv)}, yw])/8 - 
     (3*G[{0}, yu^(-1)]*G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw]*
       G[{0, 1/(yu*yv)}, yw])/16 - (3*G[{0}, yv^(-1)]*G[{yu}, yv^(-1)]*
       G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv)}, yw])/16 + 
     (3*G[{0}, yw]*G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv)}, yw])/
      16 + (G[{1}, yu^(-1)]*G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw]*
       G[{0, 1/(yu*yv)}, yw])/8 + (G[{1}, yv^(-1)]*G[{yu}, yv^(-1)]*
       G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv)}, yw])/8 + 
     (G[{yu^(-1)}, yw]*G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw]*
       G[{0, 1/(yu*yv)}, yw])/8 + (G[{yu}, yv^(-1)]^2*G[{1/(yu*yv)}, yw]*
       G[{0, 1/(yu*yv)}, yw])/16 - (G[{1}, yv^(-1)]*G[{yv^(-1)}, yw]*
       G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv)}, yw])/8 - 
     (G[{1}, yw]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv)}, yw])/
      16 + (G[{yu}, yv^(-1)]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*
       G[{0, 1/(yu*yv)}, yw])/8 - (G[{yv^(-1)}, yw]^2*G[{1/(yu*yv)}, yw]*
       G[{0, 1/(yu*yv)}, yw])/16 + (G[{0}, yu^(-1)]*G[{0, 1}, yu^(-1)]*
       G[{0, 1/(yu*yv)}, yw])/16 + (G[{0}, yv^(-1)]*G[{0, 1}, yu^(-1)]*
       G[{0, 1/(yu*yv)}, yw])/16 - (G[{0}, yw]*G[{0, 1}, yu^(-1)]*
       G[{0, 1/(yu*yv)}, yw])/16 - (G[{1}, yu^(-1)]*G[{0, 1}, yu^(-1)]*
       G[{0, 1/(yu*yv)}, yw])/16 + (G[{1}, yv^(-1)]*G[{0, 1}, yu^(-1)]*
       G[{0, 1/(yu*yv)}, yw])/8 - (G[{yu}, yv^(-1)]*G[{0, 1}, yu^(-1)]*
       G[{0, 1/(yu*yv)}, yw])/8 + (G[{0}, yu^(-1)]*G[{0, 1}, yv^(-1)]*
       G[{0, 1/(yu*yv)}, yw])/16 + (G[{0}, yv^(-1)]*G[{0, 1}, yv^(-1)]*
       G[{0, 1/(yu*yv)}, yw])/16 - (G[{0}, yw]*G[{0, 1}, yv^(-1)]*
       G[{0, 1/(yu*yv)}, yw])/16 + (G[{1}, yv^(-1)]*G[{0, 1}, yv^(-1)]*
       G[{0, 1/(yu*yv)}, yw])/8 - (G[{yu}, yv^(-1)]*G[{0, 1}, yv^(-1)]*
       G[{0, 1/(yu*yv)}, yw])/8 + (G[{1}, yu^(-1)]*G[{0, 1}, yw]*
       G[{0, 1/(yu*yv)}, yw])/16 - (G[{1}, yv^(-1)]*G[{0, 1}, yw]*
       G[{0, 1/(yu*yv)}, yw])/8 + (G[{1}, yw]*G[{0, 1}, yw]*
       G[{0, 1/(yu*yv)}, yw])/16 + (G[{yu}, yv^(-1)]*G[{0, 1}, yw]*
       G[{0, 1/(yu*yv)}, yw])/16 - (G[{1/(yu*yv)}, yw]*G[{0, 1}, yw]*
       G[{0, 1/(yu*yv)}, yw])/16 - (G[{1}, yu^(-1)]*G[{0, yu^(-1)}, yw]*
       G[{0, 1/(yu*yv)}, yw])/16 + (3*G[{1}, yv^(-1)]*G[{0, yu^(-1)}, yw]*
       G[{0, 1/(yu*yv)}, yw])/16 - (G[{1}, yw]*G[{0, yu^(-1)}, yw]*
       G[{0, 1/(yu*yv)}, yw])/16 - (G[{yu}, yv^(-1)]*G[{0, yu^(-1)}, yw]*
       G[{0, 1/(yu*yv)}, yw])/8 + (G[{1/(yu*yv)}, yw]*G[{0, yu^(-1)}, yw]*
       G[{0, 1/(yu*yv)}, yw])/16 - (G[{0}, yu^(-1)]*G[{0, yu}, yv^(-1)]*
       G[{0, 1/(yu*yv)}, yw])/16 - (G[{0}, yv^(-1)]*G[{0, yu}, yv^(-1)]*
       G[{0, 1/(yu*yv)}, yw])/16 + (G[{0}, yw]*G[{0, yu}, yv^(-1)]*
       G[{0, 1/(yu*yv)}, yw])/16 - (G[{1}, yv^(-1)]*G[{0, yu}, yv^(-1)]*
       G[{0, 1/(yu*yv)}, yw])/8 + (G[{yu}, yv^(-1)]*G[{0, yu}, yv^(-1)]*
       G[{0, 1/(yu*yv)}, yw])/8 + (G[{1}, yv^(-1)]*G[{0, yv^(-1)}, yw]*
       G[{0, 1/(yu*yv)}, yw])/8 - (G[{1}, yw]*G[{0, yv^(-1)}, yw]*
       G[{0, 1/(yu*yv)}, yw])/16 - (G[{yu}, yv^(-1)]*G[{0, yv^(-1)}, yw]*
       G[{0, 1/(yu*yv)}, yw])/8 + (G[{1/(yu*yv)}, yw]*G[{0, yv^(-1)}, yw]*
       G[{0, 1/(yu*yv)}, yw])/16 - 
     (3*G[{1}, yv^(-1)]*G[{0, 1/(yu*yv)}, yw]^2)/32 + 
     (G[{1}, yw]*G[{0, 1/(yu*yv)}, yw]^2)/32 + 
     (3*G[{yu}, yv^(-1)]*G[{0, 1/(yu*yv)}, yw]^2)/32 - 
     (G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv)}, yw]^2)/32 + 
     (Pi^2*G[{0}, yu^(-1)]*G[{1, yu^(-1)}, yw])/48 + 
     (Pi^2*G[{0}, yv^(-1)]*G[{1, yu^(-1)}, yw])/48 - 
     (Pi^2*G[{0}, yw]*G[{1, yu^(-1)}, yw])/48 + 
     (Pi^2*G[{1}, yu^(-1)]*G[{1, yu^(-1)}, yw])/96 - 
     (G[{0}, yu^(-1)]^2*G[{1}, yu^(-1)]*G[{1, yu^(-1)}, yw])/32 - 
     (G[{0}, yu^(-1)]*G[{0}, yv^(-1)]*G[{1}, yu^(-1)]*G[{1, yu^(-1)}, yw])/
      16 - (G[{0}, yv^(-1)]^2*G[{1}, yu^(-1)]*G[{1, yu^(-1)}, yw])/32 + 
     (G[{0}, yu^(-1)]*G[{0}, yw]*G[{1}, yu^(-1)]*G[{1, yu^(-1)}, yw])/16 + 
     (G[{0}, yv^(-1)]*G[{0}, yw]*G[{1}, yu^(-1)]*G[{1, yu^(-1)}, yw])/16 - 
     (G[{0}, yw]^2*G[{1}, yu^(-1)]*G[{1, yu^(-1)}, yw])/32 + 
     (G[{0}, yu^(-1)]*G[{1}, yu^(-1)]^2*G[{1, yu^(-1)}, yw])/16 + 
     (G[{0}, yv^(-1)]*G[{1}, yu^(-1)]^2*G[{1, yu^(-1)}, yw])/16 - 
     (G[{0}, yw]*G[{1}, yu^(-1)]^2*G[{1, yu^(-1)}, yw])/16 - 
     (G[{1}, yu^(-1)]^3*G[{1, yu^(-1)}, yw])/32 - 
     (11*Pi^2*G[{1}, yv^(-1)]*G[{1, yu^(-1)}, yw])/256 + 
     (G[{0}, yu^(-1)]^2*G[{1}, yv^(-1)]*G[{1, yu^(-1)}, yw])/32 + 
     (G[{0}, yu^(-1)]*G[{0}, yv^(-1)]*G[{1}, yv^(-1)]*G[{1, yu^(-1)}, yw])/
      16 + (G[{0}, yv^(-1)]^2*G[{1}, yv^(-1)]*G[{1, yu^(-1)}, yw])/32 - 
     (G[{0}, yu^(-1)]*G[{0}, yw]*G[{1}, yv^(-1)]*G[{1, yu^(-1)}, yw])/16 - 
     (G[{0}, yv^(-1)]*G[{0}, yw]*G[{1}, yv^(-1)]*G[{1, yu^(-1)}, yw])/16 + 
     (G[{0}, yw]^2*G[{1}, yv^(-1)]*G[{1, yu^(-1)}, yw])/32 - 
     (G[{0}, yu^(-1)]*G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*G[{1, yu^(-1)}, yw])/
      8 - (G[{0}, yv^(-1)]*G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*
       G[{1, yu^(-1)}, yw])/8 + (G[{0}, yw]*G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*
       G[{1, yu^(-1)}, yw])/8 + (3*G[{1}, yu^(-1)]^2*G[{1}, yv^(-1)]*
       G[{1, yu^(-1)}, yw])/64 + (G[{0}, yu^(-1)]*G[{1}, yv^(-1)]^2*
       G[{1, yu^(-1)}, yw])/32 + (G[{0}, yv^(-1)]*G[{1}, yv^(-1)]^2*
       G[{1, yu^(-1)}, yw])/32 - (G[{0}, yw]*G[{1}, yv^(-1)]^2*
       G[{1, yu^(-1)}, yw])/32 + (3*G[{1}, yu^(-1)]*G[{1}, yv^(-1)]^2*
       G[{1, yu^(-1)}, yw])/32 - (G[{1}, yv^(-1)]^3*G[{1, yu^(-1)}, yw])/16 - 
     (Pi^2*G[{1}, yw]*G[{1, yu^(-1)}, yw])/768 + 
     (G[{0}, yu^(-1)]^2*G[{1}, yw]*G[{1, yu^(-1)}, yw])/32 + 
     (G[{0}, yu^(-1)]*G[{0}, yv^(-1)]*G[{1}, yw]*G[{1, yu^(-1)}, yw])/16 + 
     (G[{0}, yv^(-1)]^2*G[{1}, yw]*G[{1, yu^(-1)}, yw])/32 - 
     (G[{0}, yu^(-1)]*G[{0}, yw]*G[{1}, yw]*G[{1, yu^(-1)}, yw])/16 - 
     (G[{0}, yv^(-1)]*G[{0}, yw]*G[{1}, yw]*G[{1, yu^(-1)}, yw])/16 + 
     (G[{0}, yw]^2*G[{1}, yw]*G[{1, yu^(-1)}, yw])/32 - 
     (G[{0}, yu^(-1)]*G[{1}, yu^(-1)]*G[{1}, yw]*G[{1, yu^(-1)}, yw])/4 - 
     (G[{0}, yv^(-1)]*G[{1}, yu^(-1)]*G[{1}, yw]*G[{1, yu^(-1)}, yw])/4 + 
     (G[{0}, yw]*G[{1}, yu^(-1)]*G[{1}, yw]*G[{1, yu^(-1)}, yw])/4 + 
     (11*G[{1}, yu^(-1)]^2*G[{1}, yw]*G[{1, yu^(-1)}, yw])/64 + 
     (3*G[{0}, yu^(-1)]*G[{1}, yv^(-1)]*G[{1}, yw]*G[{1, yu^(-1)}, yw])/16 + 
     (3*G[{0}, yv^(-1)]*G[{1}, yv^(-1)]*G[{1}, yw]*G[{1, yu^(-1)}, yw])/16 - 
     (3*G[{0}, yw]*G[{1}, yv^(-1)]*G[{1}, yw]*G[{1, yu^(-1)}, yw])/16 + 
     (G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*G[{1}, yw]*G[{1, yu^(-1)}, yw])/8 - 
     (G[{1}, yv^(-1)]^2*G[{1}, yw]*G[{1, yu^(-1)}, yw])/8 + 
     (G[{0}, yu^(-1)]*G[{1}, yw]^2*G[{1, yu^(-1)}, yw])/16 + 
     (G[{0}, yv^(-1)]*G[{1}, yw]^2*G[{1, yu^(-1)}, yw])/16 - 
     (G[{0}, yw]*G[{1}, yw]^2*G[{1, yu^(-1)}, yw])/16 - 
     (G[{1}, yu^(-1)]*G[{1}, yw]^2*G[{1, yu^(-1)}, yw])/16 + 
     (5*G[{1}, yv^(-1)]*G[{1}, yw]^2*G[{1, yu^(-1)}, yw])/64 + 
     (3*G[{1}, yw]^3*G[{1, yu^(-1)}, yw])/64 - 
     (7*Pi^2*G[{yu}, yv^(-1)]*G[{1, yu^(-1)}, yw])/768 + 
     (G[{0}, yu^(-1)]*G[{1}, yu^(-1)]*G[{yu}, yv^(-1)]*G[{1, yu^(-1)}, yw])/
      8 + (G[{0}, yv^(-1)]*G[{1}, yu^(-1)]*G[{yu}, yv^(-1)]*
       G[{1, yu^(-1)}, yw])/8 - (G[{0}, yw]*G[{1}, yu^(-1)]*G[{yu}, yv^(-1)]*
       G[{1, yu^(-1)}, yw])/8 - (5*G[{1}, yu^(-1)]^2*G[{yu}, yv^(-1)]*
       G[{1, yu^(-1)}, yw])/64 - (G[{0}, yu^(-1)]*G[{1}, yv^(-1)]*
       G[{yu}, yv^(-1)]*G[{1, yu^(-1)}, yw])/8 - 
     (G[{0}, yv^(-1)]*G[{1}, yv^(-1)]*G[{yu}, yv^(-1)]*G[{1, yu^(-1)}, yw])/
      8 + (G[{0}, yw]*G[{1}, yv^(-1)]*G[{yu}, yv^(-1)]*G[{1, yu^(-1)}, yw])/
      8 - (3*G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*G[{yu}, yv^(-1)]*
       G[{1, yu^(-1)}, yw])/32 + (5*G[{1}, yv^(-1)]^2*G[{yu}, yv^(-1)]*
       G[{1, yu^(-1)}, yw])/64 - (G[{0}, yu^(-1)]*G[{1}, yw]*G[{yu}, yv^(-1)]*
       G[{1, yu^(-1)}, yw])/16 - (G[{0}, yv^(-1)]*G[{1}, yw]*G[{yu}, yv^(-1)]*
       G[{1, yu^(-1)}, yw])/16 + (G[{0}, yw]*G[{1}, yw]*G[{yu}, yv^(-1)]*
       G[{1, yu^(-1)}, yw])/16 + (G[{1}, yu^(-1)]*G[{1}, yw]*G[{yu}, yv^(-1)]*
       G[{1, yu^(-1)}, yw])/32 - (3*G[{1}, yv^(-1)]*G[{1}, yw]*
       G[{yu}, yv^(-1)]*G[{1, yu^(-1)}, yw])/16 - 
     (9*G[{1}, yw]^2*G[{yu}, yv^(-1)]*G[{1, yu^(-1)}, yw])/64 + 
     (7*G[{1}, yv^(-1)]*G[{yu}, yv^(-1)]^2*G[{1, yu^(-1)}, yw])/64 + 
     (9*G[{1}, yw]*G[{yu}, yv^(-1)]^2*G[{1, yu^(-1)}, yw])/64 - 
     (7*G[{yu}, yv^(-1)]^3*G[{1, yu^(-1)}, yw])/192 - 
     (19*Pi^2*G[{1/(yu*yv)}, yw]*G[{1, yu^(-1)}, yw])/768 + 
     (G[{0}, yu^(-1)]^2*G[{1/(yu*yv)}, yw]*G[{1, yu^(-1)}, yw])/16 + 
     (G[{0}, yu^(-1)]*G[{0}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{1, yu^(-1)}, yw])/
      8 + (G[{0}, yv^(-1)]^2*G[{1/(yu*yv)}, yw]*G[{1, yu^(-1)}, yw])/16 - 
     (G[{0}, yu^(-1)]*G[{0}, yw]*G[{1/(yu*yv)}, yw]*G[{1, yu^(-1)}, yw])/8 - 
     (G[{0}, yv^(-1)]*G[{0}, yw]*G[{1/(yu*yv)}, yw]*G[{1, yu^(-1)}, yw])/8 + 
     (G[{0}, yw]^2*G[{1/(yu*yv)}, yw]*G[{1, yu^(-1)}, yw])/16 - 
     (G[{0}, yu^(-1)]*G[{1}, yu^(-1)]*G[{1/(yu*yv)}, yw]*G[{1, yu^(-1)}, yw])/
      8 - (G[{0}, yv^(-1)]*G[{1}, yu^(-1)]*G[{1/(yu*yv)}, yw]*
       G[{1, yu^(-1)}, yw])/8 + (G[{0}, yw]*G[{1}, yu^(-1)]*
       G[{1/(yu*yv)}, yw]*G[{1, yu^(-1)}, yw])/8 + 
     (11*G[{1}, yu^(-1)]^2*G[{1/(yu*yv)}, yw]*G[{1, yu^(-1)}, yw])/128 + 
     (G[{0}, yu^(-1)]*G[{1}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{1, yu^(-1)}, yw])/
      16 + (G[{0}, yv^(-1)]*G[{1}, yv^(-1)]*G[{1/(yu*yv)}, yw]*
       G[{1, yu^(-1)}, yw])/16 - (G[{0}, yw]*G[{1}, yv^(-1)]*
       G[{1/(yu*yv)}, yw]*G[{1, yu^(-1)}, yw])/16 - 
     (9*G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*G[{1/(yu*yv)}, yw]*
       G[{1, yu^(-1)}, yw])/64 - (11*G[{1}, yv^(-1)]^2*G[{1/(yu*yv)}, yw]*
       G[{1, yu^(-1)}, yw])/64 + (G[{0}, yu^(-1)]*G[{1}, yw]*
       G[{1/(yu*yv)}, yw]*G[{1, yu^(-1)}, yw])/8 + 
     (G[{0}, yv^(-1)]*G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{1, yu^(-1)}, yw])/8 - 
     (G[{0}, yw]*G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{1, yu^(-1)}, yw])/8 - 
     (7*G[{1}, yu^(-1)]*G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{1, yu^(-1)}, yw])/
      64 - (G[{1}, yv^(-1)]*G[{1}, yw]*G[{1/(yu*yv)}, yw]*
       G[{1, yu^(-1)}, yw])/4 - (7*G[{1}, yw]^2*G[{1/(yu*yv)}, yw]*
       G[{1, yu^(-1)}, yw])/128 - (G[{0}, yu^(-1)]*G[{yu^(-1)}, yw]*
       G[{1/(yu*yv)}, yw]*G[{1, yu^(-1)}, yw])/4 - 
     (G[{0}, yv^(-1)]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*
       G[{1, yu^(-1)}, yw])/4 + (G[{0}, yw]*G[{yu^(-1)}, yw]*
       G[{1/(yu*yv)}, yw]*G[{1, yu^(-1)}, yw])/4 + 
     (G[{1}, yu^(-1)]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*
       G[{1, yu^(-1)}, yw])/4 + (G[{1}, yv^(-1)]*G[{yu^(-1)}, yw]*
       G[{1/(yu*yv)}, yw]*G[{1, yu^(-1)}, yw])/16 - 
     (3*G[{1}, yw]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{1, yu^(-1)}, yw])/
      16 + (G[{yu^(-1)}, yw]^2*G[{1/(yu*yv)}, yw]*G[{1, yu^(-1)}, yw])/16 - 
     (3*G[{0}, yu^(-1)]*G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw]*
       G[{1, yu^(-1)}, yw])/16 - (3*G[{0}, yv^(-1)]*G[{yu}, yv^(-1)]*
       G[{1/(yu*yv)}, yw]*G[{1, yu^(-1)}, yw])/16 + 
     (3*G[{0}, yw]*G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{1, yu^(-1)}, yw])/
      16 + (7*G[{1}, yu^(-1)]*G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw]*
       G[{1, yu^(-1)}, yw])/32 + (21*G[{1}, yv^(-1)]*G[{yu}, yv^(-1)]*
       G[{1/(yu*yv)}, yw]*G[{1, yu^(-1)}, yw])/64 + 
     (7*G[{1}, yw]*G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{1, yu^(-1)}, yw])/
      64 + (3*G[{yu^(-1)}, yw]*G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw]*
       G[{1, yu^(-1)}, yw])/16 - (11*G[{yu}, yv^(-1)]^2*G[{1/(yu*yv)}, yw]*
       G[{1, yu^(-1)}, yw])/128 + (G[{1}, yu^(-1)]*G[{yv^(-1)}, yw]*
       G[{1/(yu*yv)}, yw]*G[{1, yu^(-1)}, yw])/16 - 
     (3*G[{1}, yv^(-1)]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*
       G[{1, yu^(-1)}, yw])/32 - (G[{1}, yw]*G[{yv^(-1)}, yw]*
       G[{1/(yu*yv)}, yw]*G[{1, yu^(-1)}, yw])/32 + 
     (G[{yu}, yv^(-1)]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*
       G[{1, yu^(-1)}, yw])/32 - (3*G[{yv^(-1)}, yw]^2*G[{1/(yu*yv)}, yw]*
       G[{1, yu^(-1)}, yw])/32 - (G[{0}, yu^(-1)]*G[{1/(yu*yv)}, yw]^2*
       G[{1, yu^(-1)}, yw])/32 - (G[{0}, yv^(-1)]*G[{1/(yu*yv)}, yw]^2*
       G[{1, yu^(-1)}, yw])/32 + (G[{0}, yw]*G[{1/(yu*yv)}, yw]^2*
       G[{1, yu^(-1)}, yw])/32 - (G[{1}, yu^(-1)]*G[{1/(yu*yv)}, yw]^2*
       G[{1, yu^(-1)}, yw])/64 + (7*G[{1}, yv^(-1)]*G[{1/(yu*yv)}, yw]^2*
       G[{1, yu^(-1)}, yw])/128 - (3*G[{1}, yw]*G[{1/(yu*yv)}, yw]^2*
       G[{1, yu^(-1)}, yw])/128 - (G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2*
       G[{1, yu^(-1)}, yw])/128 + (3*G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw]^2*
       G[{1, yu^(-1)}, yw])/128 + (G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2*
       G[{1, yu^(-1)}, yw])/64 + (G[{1}, yu^(-1)]*G[{0, 1}, yu^(-1)]*
       G[{1, yu^(-1)}, yw])/16 - (3*G[{1}, yv^(-1)]*G[{0, 1}, yu^(-1)]*
       G[{1, yu^(-1)}, yw])/32 + (G[{1}, yw]*G[{0, 1}, yu^(-1)]*
       G[{1, yu^(-1)}, yw])/32 + (G[{yu}, yv^(-1)]*G[{0, 1}, yu^(-1)]*
       G[{1, yu^(-1)}, yw])/32 - (3*G[{1/(yu*yv)}, yw]*G[{0, 1}, yu^(-1)]*
       G[{1, yu^(-1)}, yw])/64 + (G[{0}, yu^(-1)]*G[{0, 1}, yv^(-1)]*
       G[{1, yu^(-1)}, yw])/16 + (G[{0}, yv^(-1)]*G[{0, 1}, yv^(-1)]*
       G[{1, yu^(-1)}, yw])/16 - (G[{0}, yw]*G[{0, 1}, yv^(-1)]*
       G[{1, yu^(-1)}, yw])/16 - (5*G[{1}, yv^(-1)]*G[{0, 1}, yv^(-1)]*
       G[{1, yu^(-1)}, yw])/32 - (G[{1}, yw]*G[{0, 1}, yv^(-1)]*
       G[{1, yu^(-1)}, yw])/32 - (G[{1/(yu*yv)}, yw]*G[{0, 1}, yv^(-1)]*
       G[{1, yu^(-1)}, yw])/64 + (3*G[{0}, yu^(-1)]*G[{0, 1}, yw]*
       G[{1, yu^(-1)}, yw])/16 + (3*G[{0}, yv^(-1)]*G[{0, 1}, yw]*
       G[{1, yu^(-1)}, yw])/16 - (3*G[{0}, yw]*G[{0, 1}, yw]*
       G[{1, yu^(-1)}, yw])/16 - (G[{1}, yu^(-1)]*G[{0, 1}, yw]*
       G[{1, yu^(-1)}, yw])/4 + (G[{1}, yw]*G[{0, 1}, yw]*
       G[{1, yu^(-1)}, yw])/16 - (G[{yu}, yv^(-1)]*G[{0, 1}, yw]*
       G[{1, yu^(-1)}, yw])/8 - (G[{1/(yu*yv)}, yw]*G[{0, 1}, yw]*
       G[{1, yu^(-1)}, yw])/16 - (3*G[{0}, yu^(-1)]*G[{0, yu^(-1)}, yw]*
       G[{1, yu^(-1)}, yw])/16 - (3*G[{0}, yv^(-1)]*G[{0, yu^(-1)}, yw]*
       G[{1, yu^(-1)}, yw])/16 + (3*G[{0}, yw]*G[{0, yu^(-1)}, yw]*
       G[{1, yu^(-1)}, yw])/16 + (G[{1}, yu^(-1)]*G[{0, yu^(-1)}, yw]*
       G[{1, yu^(-1)}, yw])/4 - (G[{1}, yw]*G[{0, yu^(-1)}, yw]*
       G[{1, yu^(-1)}, yw])/16 + (G[{yu}, yv^(-1)]*G[{0, yu^(-1)}, yw]*
       G[{1, yu^(-1)}, yw])/8 + (G[{1/(yu*yv)}, yw]*G[{0, yu^(-1)}, yw]*
       G[{1, yu^(-1)}, yw])/16 - (G[{0}, yu^(-1)]*G[{0, yu}, yv^(-1)]*
       G[{1, yu^(-1)}, yw])/16 - (G[{0}, yv^(-1)]*G[{0, yu}, yv^(-1)]*
       G[{1, yu^(-1)}, yw])/16 + (G[{0}, yw]*G[{0, yu}, yv^(-1)]*
       G[{1, yu^(-1)}, yw])/16 + (5*G[{1}, yv^(-1)]*G[{0, yu}, yv^(-1)]*
       G[{1, yu^(-1)}, yw])/32 + (G[{1}, yw]*G[{0, yu}, yv^(-1)]*
       G[{1, yu^(-1)}, yw])/32 + (G[{1/(yu*yv)}, yw]*G[{0, yu}, yv^(-1)]*
       G[{1, yu^(-1)}, yw])/64 - (3*G[{0}, yu^(-1)]*G[{0, yv^(-1)}, yw]*
       G[{1, yu^(-1)}, yw])/16 - (3*G[{0}, yv^(-1)]*G[{0, yv^(-1)}, yw]*
       G[{1, yu^(-1)}, yw])/16 + (3*G[{0}, yw]*G[{0, yv^(-1)}, yw]*
       G[{1, yu^(-1)}, yw])/16 + (G[{1}, yu^(-1)]*G[{0, yv^(-1)}, yw]*
       G[{1, yu^(-1)}, yw])/4 - (G[{1}, yw]*G[{0, yv^(-1)}, yw]*
       G[{1, yu^(-1)}, yw])/16 + (G[{yu}, yv^(-1)]*G[{0, yv^(-1)}, yw]*
       G[{1, yu^(-1)}, yw])/8 + (G[{1/(yu*yv)}, yw]*G[{0, yv^(-1)}, yw]*
       G[{1, yu^(-1)}, yw])/16 + (3*G[{0}, yu^(-1)]*G[{0, 1/(yu*yv)}, yw]*
       G[{1, yu^(-1)}, yw])/16 + (3*G[{0}, yv^(-1)]*G[{0, 1/(yu*yv)}, yw]*
       G[{1, yu^(-1)}, yw])/16 - (3*G[{0}, yw]*G[{0, 1/(yu*yv)}, yw]*
       G[{1, yu^(-1)}, yw])/16 - (G[{1}, yu^(-1)]*G[{0, 1/(yu*yv)}, yw]*
       G[{1, yu^(-1)}, yw])/4 + (G[{1}, yw]*G[{0, 1/(yu*yv)}, yw]*
       G[{1, yu^(-1)}, yw])/16 - (G[{yu}, yv^(-1)]*G[{0, 1/(yu*yv)}, yw]*
       G[{1, yu^(-1)}, yw])/8 - (G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv)}, yw]*
       G[{1, yu^(-1)}, yw])/16 + (G[{0}, yu^(-1)]*G[{1, yu^(-1)}, yw]^2)/8 + 
     (G[{0}, yv^(-1)]*G[{1, yu^(-1)}, yw]^2)/8 - 
     (G[{0}, yw]*G[{1, yu^(-1)}, yw]^2)/8 - 
     (G[{1}, yu^(-1)]*G[{1, yu^(-1)}, yw]^2)/8 - 
     (G[{1}, yv^(-1)]*G[{1, yu^(-1)}, yw]^2)/32 + 
     (3*G[{1}, yw]*G[{1, yu^(-1)}, yw]^2)/32 - 
     (3*G[{yu}, yv^(-1)]*G[{1, yu^(-1)}, yw]^2)/32 - 
     (5*G[{1/(yu*yv)}, yw]*G[{1, yu^(-1)}, yw]^2)/128 + 
     (Pi^2*G[{1}, yu^(-1)]*G[{1, yu}, yv^(-1)])/96 + 
     (7*Pi^2*G[{1}, yv^(-1)]*G[{1, yu}, yv^(-1)])/768 - 
     (3*G[{1}, yu^(-1)]^2*G[{1}, yv^(-1)]*G[{1, yu}, yv^(-1)])/64 + 
     (3*G[{1}, yv^(-1)]^3*G[{1, yu}, yv^(-1)])/128 + 
     (Pi^2*G[{1}, yw]*G[{1, yu}, yv^(-1)])/256 - 
     (3*G[{1}, yu^(-1)]^2*G[{1}, yw]*G[{1, yu}, yv^(-1)])/128 - 
     (3*G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*G[{1}, yw]*G[{1, yu}, yv^(-1)])/64 + 
     (11*G[{1}, yv^(-1)]^2*G[{1}, yw]*G[{1, yu}, yv^(-1)])/128 - 
     (3*G[{0}, yu^(-1)]*G[{1}, yw]^2*G[{1, yu}, yv^(-1)])/32 - 
     (3*G[{0}, yv^(-1)]*G[{1}, yw]^2*G[{1, yu}, yv^(-1)])/32 + 
     (3*G[{0}, yw]*G[{1}, yw]^2*G[{1, yu}, yv^(-1)])/32 + 
     (G[{1}, yu^(-1)]*G[{1}, yw]^2*G[{1, yu}, yv^(-1)])/64 + 
     (9*G[{1}, yv^(-1)]*G[{1}, yw]^2*G[{1, yu}, yv^(-1)])/64 - 
     (7*G[{1}, yw]^3*G[{1, yu}, yv^(-1)])/128 + 
     (G[{1}, yu^(-1)]*G[{1}, yw]*G[{yu}, yv^(-1)]*G[{1, yu}, yv^(-1)])/16 - 
     (G[{1}, yv^(-1)]*G[{1}, yw]*G[{yu}, yv^(-1)]*G[{1, yu}, yv^(-1)])/16 + 
     (G[{1}, yw]^2*G[{yu}, yv^(-1)]*G[{1, yu}, yv^(-1)])/16 + 
     (G[{1}, yw]*G[{yu}, yv^(-1)]^2*G[{1, yu}, yv^(-1)])/64 - 
     (Pi^2*G[{1/(yu*yv)}, yw]*G[{1, yu}, yv^(-1)])/256 + 
     (3*G[{1}, yu^(-1)]^2*G[{1/(yu*yv)}, yw]*G[{1, yu}, yv^(-1)])/128 + 
     (3*G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*G[{1/(yu*yv)}, yw]*
       G[{1, yu}, yv^(-1)])/64 - (11*G[{1}, yv^(-1)]^2*G[{1/(yu*yv)}, yw]*
       G[{1, yu}, yv^(-1)])/128 + (3*G[{0}, yu^(-1)]*G[{1}, yw]*
       G[{1/(yu*yv)}, yw]*G[{1, yu}, yv^(-1)])/16 + 
     (3*G[{0}, yv^(-1)]*G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{1, yu}, yv^(-1)])/
      16 - (3*G[{0}, yw]*G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{1, yu}, yv^(-1)])/
      16 - (G[{1}, yu^(-1)]*G[{1}, yw]*G[{1/(yu*yv)}, yw]*
       G[{1, yu}, yv^(-1)])/32 - (9*G[{1}, yv^(-1)]*G[{1}, yw]*
       G[{1/(yu*yv)}, yw]*G[{1, yu}, yv^(-1)])/32 + 
     (21*G[{1}, yw]^2*G[{1/(yu*yv)}, yw]*G[{1, yu}, yv^(-1)])/128 - 
     (G[{0}, yu^(-1)]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*
       G[{1, yu}, yv^(-1)])/16 - (G[{0}, yv^(-1)]*G[{yu^(-1)}, yw]*
       G[{1/(yu*yv)}, yw]*G[{1, yu}, yv^(-1)])/16 + 
     (G[{0}, yw]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{1, yu}, yv^(-1)])/
      16 - (G[{1}, yu^(-1)]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*
       G[{1, yu}, yv^(-1)])/16 + (G[{1}, yv^(-1)]*G[{yu^(-1)}, yw]*
       G[{1/(yu*yv)}, yw]*G[{1, yu}, yv^(-1)])/32 + 
     (G[{1}, yw]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{1, yu}, yv^(-1)])/
      16 - (3*G[{yu^(-1)}, yw]^2*G[{1/(yu*yv)}, yw]*G[{1, yu}, yv^(-1)])/64 - 
     (G[{1}, yu^(-1)]*G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw]*
       G[{1, yu}, yv^(-1)])/16 + (G[{1}, yv^(-1)]*G[{yu}, yv^(-1)]*
       G[{1/(yu*yv)}, yw]*G[{1, yu}, yv^(-1)])/16 - 
     (G[{1}, yw]*G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{1, yu}, yv^(-1)])/8 + 
     (G[{yu^(-1)}, yw]*G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw]*
       G[{1, yu}, yv^(-1)])/32 - (G[{yu}, yv^(-1)]^2*G[{1/(yu*yv)}, yw]*
       G[{1, yu}, yv^(-1)])/64 + (G[{0}, yu^(-1)]*G[{yv^(-1)}, yw]*
       G[{1/(yu*yv)}, yw]*G[{1, yu}, yv^(-1)])/16 + 
     (G[{0}, yv^(-1)]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*
       G[{1, yu}, yv^(-1)])/16 - (G[{0}, yw]*G[{yv^(-1)}, yw]*
       G[{1/(yu*yv)}, yw]*G[{1, yu}, yv^(-1)])/16 + 
     (G[{1}, yv^(-1)]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*
       G[{1, yu}, yv^(-1)])/32 + (9*G[{1}, yw]*G[{yv^(-1)}, yw]*
       G[{1/(yu*yv)}, yw]*G[{1, yu}, yv^(-1)])/64 - 
     (G[{yu}, yv^(-1)]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*
       G[{1, yu}, yv^(-1)])/16 + (G[{yv^(-1)}, yw]^2*G[{1/(yu*yv)}, yw]*
       G[{1, yu}, yv^(-1)])/32 - (3*G[{0}, yu^(-1)]*G[{1/(yu*yv)}, yw]^2*
       G[{1, yu}, yv^(-1)])/32 - (3*G[{0}, yv^(-1)]*G[{1/(yu*yv)}, yw]^2*
       G[{1, yu}, yv^(-1)])/32 + (3*G[{0}, yw]*G[{1/(yu*yv)}, yw]^2*
       G[{1, yu}, yv^(-1)])/32 + (3*G[{1}, yu^(-1)]*G[{1/(yu*yv)}, yw]^2*
       G[{1, yu}, yv^(-1)])/64 + (7*G[{1}, yv^(-1)]*G[{1/(yu*yv)}, yw]^2*
       G[{1, yu}, yv^(-1)])/64 - (5*G[{1}, yw]*G[{1/(yu*yv)}, yw]^2*
       G[{1, yu}, yv^(-1)])/64 - (G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2*
       G[{1, yu}, yv^(-1)])/16 + (5*G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw]^2*
       G[{1, yu}, yv^(-1)])/64 - (3*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2*
       G[{1, yu}, yv^(-1)])/64 - (G[{1}, yv^(-1)]*G[{0, 1}, yu^(-1)]*
       G[{1, yu}, yv^(-1)])/32 - (G[{1}, yw]*G[{0, 1}, yu^(-1)]*
       G[{1, yu}, yv^(-1)])/64 + (G[{1/(yu*yv)}, yw]*G[{0, 1}, yu^(-1)]*
       G[{1, yu}, yv^(-1)])/64 + (G[{1}, yu^(-1)]*G[{0, 1}, yv^(-1)]*
       G[{1, yu}, yv^(-1)])/16 - (G[{1}, yv^(-1)]*G[{0, 1}, yv^(-1)]*
       G[{1, yu}, yv^(-1)])/64 - (G[{1}, yw]*G[{0, 1}, yv^(-1)]*
       G[{1, yu}, yv^(-1)])/32 + (G[{1/(yu*yv)}, yw]*G[{0, 1}, yv^(-1)]*
       G[{1, yu}, yv^(-1)])/32 - (G[{1}, yu^(-1)]*G[{0, yu}, yv^(-1)]*
       G[{1, yu}, yv^(-1)])/16 + (G[{1}, yv^(-1)]*G[{0, yu}, yv^(-1)]*
       G[{1, yu}, yv^(-1)])/64 + (G[{1}, yw]*G[{0, yu}, yv^(-1)]*
       G[{1, yu}, yv^(-1)])/32 - (G[{1/(yu*yv)}, yw]*G[{0, yu}, yv^(-1)]*
       G[{1, yu}, yv^(-1)])/32 + (G[{0}, yu^(-1)]*G[{1, yu^(-1)}, yw]*
       G[{1, yu}, yv^(-1)])/16 + (G[{0}, yv^(-1)]*G[{1, yu^(-1)}, yw]*
       G[{1, yu}, yv^(-1)])/16 - (G[{0}, yw]*G[{1, yu^(-1)}, yw]*
       G[{1, yu}, yv^(-1)])/16 + (G[{1}, yu^(-1)]*G[{1, yu^(-1)}, yw]*
       G[{1, yu}, yv^(-1)])/16 - (G[{1}, yv^(-1)]*G[{1, yu^(-1)}, yw]*
       G[{1, yu}, yv^(-1)])/32 - (G[{1}, yw]*G[{1, yu^(-1)}, yw]*
       G[{1, yu}, yv^(-1)])/16 - (G[{yu}, yv^(-1)]*G[{1, yu^(-1)}, yw]*
       G[{1, yu}, yv^(-1)])/32 + (G[{1/(yu*yv)}, yw]*G[{1, yu^(-1)}, yw]*
       G[{1, yu}, yv^(-1)])/32 + (G[{1}, yu^(-1)]*G[{1, yu}, yv^(-1)]^2)/32 - 
     (G[{1}, yw]*G[{1, yu}, yv^(-1)]^2)/128 + 
     (G[{1/(yu*yv)}, yw]*G[{1, yu}, yv^(-1)]^2)/128 - 
     (Pi^2*G[{0}, yu^(-1)]*G[{1, yv^(-1)}, yw])/96 - 
     (Pi^2*G[{0}, yv^(-1)]*G[{1, yv^(-1)}, yw])/96 + 
     (Pi^2*G[{0}, yw]*G[{1, yv^(-1)}, yw])/96 + 
     (G[{0}, yu^(-1)]^2*G[{1}, yu^(-1)]*G[{1, yv^(-1)}, yw])/32 + 
     (G[{0}, yu^(-1)]*G[{0}, yv^(-1)]*G[{1}, yu^(-1)]*G[{1, yv^(-1)}, yw])/
      16 + (G[{0}, yv^(-1)]^2*G[{1}, yu^(-1)]*G[{1, yv^(-1)}, yw])/32 - 
     (G[{0}, yu^(-1)]*G[{0}, yw]*G[{1}, yu^(-1)]*G[{1, yv^(-1)}, yw])/16 - 
     (G[{0}, yv^(-1)]*G[{0}, yw]*G[{1}, yu^(-1)]*G[{1, yv^(-1)}, yw])/16 + 
     (G[{0}, yw]^2*G[{1}, yu^(-1)]*G[{1, yv^(-1)}, yw])/32 - 
     (G[{0}, yu^(-1)]*G[{1}, yu^(-1)]^2*G[{1, yv^(-1)}, yw])/16 - 
     (G[{0}, yv^(-1)]*G[{1}, yu^(-1)]^2*G[{1, yv^(-1)}, yw])/16 + 
     (G[{0}, yw]*G[{1}, yu^(-1)]^2*G[{1, yv^(-1)}, yw])/16 + 
     (G[{1}, yu^(-1)]^3*G[{1, yv^(-1)}, yw])/32 + 
     (Pi^2*G[{1}, yv^(-1)]*G[{1, yv^(-1)}, yw])/96 - 
     (G[{0}, yu^(-1)]^2*G[{1}, yv^(-1)]*G[{1, yv^(-1)}, yw])/32 - 
     (G[{0}, yu^(-1)]*G[{0}, yv^(-1)]*G[{1}, yv^(-1)]*G[{1, yv^(-1)}, yw])/
      16 - (G[{0}, yv^(-1)]^2*G[{1}, yv^(-1)]*G[{1, yv^(-1)}, yw])/32 + 
     (G[{0}, yu^(-1)]*G[{0}, yw]*G[{1}, yv^(-1)]*G[{1, yv^(-1)}, yw])/16 + 
     (G[{0}, yv^(-1)]*G[{0}, yw]*G[{1}, yv^(-1)]*G[{1, yv^(-1)}, yw])/16 - 
     (G[{0}, yw]^2*G[{1}, yv^(-1)]*G[{1, yv^(-1)}, yw])/32 + 
     (G[{0}, yu^(-1)]*G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*G[{1, yv^(-1)}, yw])/
      8 + (G[{0}, yv^(-1)]*G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*
       G[{1, yv^(-1)}, yw])/8 - (G[{0}, yw]*G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*
       G[{1, yv^(-1)}, yw])/8 - (3*G[{1}, yu^(-1)]^2*G[{1}, yv^(-1)]*
       G[{1, yv^(-1)}, yw])/32 - (G[{0}, yu^(-1)]*G[{1}, yv^(-1)]^2*
       G[{1, yv^(-1)}, yw])/32 - (G[{0}, yv^(-1)]*G[{1}, yv^(-1)]^2*
       G[{1, yv^(-1)}, yw])/32 + (G[{0}, yw]*G[{1}, yv^(-1)]^2*
       G[{1, yv^(-1)}, yw])/32 + (G[{1}, yu^(-1)]*G[{1}, yv^(-1)]^2*
       G[{1, yv^(-1)}, yw])/32 + (5*G[{1}, yv^(-1)]^3*G[{1, yv^(-1)}, yw])/
      128 - (Pi^2*G[{1}, yw]*G[{1, yv^(-1)}, yw])/48 + 
     (G[{0}, yu^(-1)]^2*G[{1}, yw]*G[{1, yv^(-1)}, yw])/32 + 
     (G[{0}, yu^(-1)]*G[{0}, yv^(-1)]*G[{1}, yw]*G[{1, yv^(-1)}, yw])/16 + 
     (G[{0}, yv^(-1)]^2*G[{1}, yw]*G[{1, yv^(-1)}, yw])/32 - 
     (G[{0}, yu^(-1)]*G[{0}, yw]*G[{1}, yw]*G[{1, yv^(-1)}, yw])/16 - 
     (G[{0}, yv^(-1)]*G[{0}, yw]*G[{1}, yw]*G[{1, yv^(-1)}, yw])/16 + 
     (G[{0}, yw]^2*G[{1}, yw]*G[{1, yv^(-1)}, yw])/32 - 
     (G[{1}, yu^(-1)]^2*G[{1}, yw]*G[{1, yv^(-1)}, yw])/32 - 
     (G[{0}, yu^(-1)]*G[{1}, yv^(-1)]*G[{1}, yw]*G[{1, yv^(-1)}, yw])/16 - 
     (G[{0}, yv^(-1)]*G[{1}, yv^(-1)]*G[{1}, yw]*G[{1, yv^(-1)}, yw])/16 + 
     (G[{0}, yw]*G[{1}, yv^(-1)]*G[{1}, yw]*G[{1, yv^(-1)}, yw])/16 + 
     (3*G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*G[{1}, yw]*G[{1, yv^(-1)}, yw])/16 + 
     (3*G[{1}, yv^(-1)]^2*G[{1}, yw]*G[{1, yv^(-1)}, yw])/128 + 
     (G[{0}, yu^(-1)]*G[{1}, yw]^2*G[{1, yv^(-1)}, yw])/16 + 
     (G[{0}, yv^(-1)]*G[{1}, yw]^2*G[{1, yv^(-1)}, yw])/16 - 
     (G[{0}, yw]*G[{1}, yw]^2*G[{1, yv^(-1)}, yw])/16 - 
     (G[{1}, yv^(-1)]*G[{1}, yw]^2*G[{1, yv^(-1)}, yw])/128 + 
     (5*G[{1}, yw]^3*G[{1, yv^(-1)}, yw])/128 + 
     (Pi^2*G[{yu}, yv^(-1)]*G[{1, yv^(-1)}, yw])/96 - 
     (G[{0}, yu^(-1)]*G[{1}, yu^(-1)]*G[{yu}, yv^(-1)]*G[{1, yv^(-1)}, yw])/
      8 - (G[{0}, yv^(-1)]*G[{1}, yu^(-1)]*G[{yu}, yv^(-1)]*
       G[{1, yv^(-1)}, yw])/8 + (G[{0}, yw]*G[{1}, yu^(-1)]*G[{yu}, yv^(-1)]*
       G[{1, yv^(-1)}, yw])/8 + (G[{1}, yu^(-1)]^2*G[{yu}, yv^(-1)]*
       G[{1, yv^(-1)}, yw])/8 + (G[{0}, yu^(-1)]*G[{1}, yv^(-1)]*
       G[{yu}, yv^(-1)]*G[{1, yv^(-1)}, yw])/8 + 
     (G[{0}, yv^(-1)]*G[{1}, yv^(-1)]*G[{yu}, yv^(-1)]*G[{1, yv^(-1)}, yw])/
      8 - (G[{0}, yw]*G[{1}, yv^(-1)]*G[{yu}, yv^(-1)]*G[{1, yv^(-1)}, yw])/
      8 - (G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*G[{yu}, yv^(-1)]*
       G[{1, yv^(-1)}, yw])/8 - (3*G[{1}, yv^(-1)]^2*G[{yu}, yv^(-1)]*
       G[{1, yv^(-1)}, yw])/32 - (G[{0}, yu^(-1)]*G[{1}, yw]*G[{yu}, yv^(-1)]*
       G[{1, yv^(-1)}, yw])/16 - (G[{0}, yv^(-1)]*G[{1}, yw]*G[{yu}, yv^(-1)]*
       G[{1, yv^(-1)}, yw])/16 + (G[{0}, yw]*G[{1}, yw]*G[{yu}, yv^(-1)]*
       G[{1, yv^(-1)}, yw])/16 - (G[{1}, yu^(-1)]*G[{1}, yw]*G[{yu}, yv^(-1)]*
       G[{1, yv^(-1)}, yw])/8 + (G[{1}, yv^(-1)]*G[{1}, yw]*G[{yu}, yv^(-1)]*
       G[{1, yv^(-1)}, yw])/32 - (15*G[{1}, yw]^2*G[{yu}, yv^(-1)]*
       G[{1, yv^(-1)}, yw])/128 + (G[{1}, yu^(-1)]*G[{yu}, yv^(-1)]^2*
       G[{1, yv^(-1)}, yw])/16 + (7*G[{1}, yw]*G[{yu}, yv^(-1)]^2*
       G[{1, yv^(-1)}, yw])/64 - (G[{yu}, yv^(-1)]^3*G[{1, yv^(-1)}, yw])/
      48 - (Pi^2*G[{1/(yu*yv)}, yw]*G[{1, yv^(-1)}, yw])/48 + 
     (G[{0}, yu^(-1)]^2*G[{1/(yu*yv)}, yw]*G[{1, yv^(-1)}, yw])/16 + 
     (G[{0}, yu^(-1)]*G[{0}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{1, yv^(-1)}, yw])/
      8 + (G[{0}, yv^(-1)]^2*G[{1/(yu*yv)}, yw]*G[{1, yv^(-1)}, yw])/16 - 
     (G[{0}, yu^(-1)]*G[{0}, yw]*G[{1/(yu*yv)}, yw]*G[{1, yv^(-1)}, yw])/8 - 
     (G[{0}, yv^(-1)]*G[{0}, yw]*G[{1/(yu*yv)}, yw]*G[{1, yv^(-1)}, yw])/8 + 
     (G[{0}, yw]^2*G[{1/(yu*yv)}, yw]*G[{1, yv^(-1)}, yw])/16 - 
     (G[{0}, yu^(-1)]*G[{1}, yu^(-1)]*G[{1/(yu*yv)}, yw]*G[{1, yv^(-1)}, yw])/
      8 - (G[{0}, yv^(-1)]*G[{1}, yu^(-1)]*G[{1/(yu*yv)}, yw]*
       G[{1, yv^(-1)}, yw])/8 + (G[{0}, yw]*G[{1}, yu^(-1)]*
       G[{1/(yu*yv)}, yw]*G[{1, yv^(-1)}, yw])/8 + 
     (G[{1}, yu^(-1)]^2*G[{1/(yu*yv)}, yw]*G[{1, yv^(-1)}, yw])/16 + 
     (G[{0}, yu^(-1)]*G[{1}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{1, yv^(-1)}, yw])/
      16 + (G[{0}, yv^(-1)]*G[{1}, yv^(-1)]*G[{1/(yu*yv)}, yw]*
       G[{1, yv^(-1)}, yw])/16 - (G[{0}, yw]*G[{1}, yv^(-1)]*
       G[{1/(yu*yv)}, yw]*G[{1, yv^(-1)}, yw])/16 - 
     (3*G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*G[{1/(yu*yv)}, yw]*
       G[{1, yv^(-1)}, yw])/16 - (11*G[{1}, yv^(-1)]^2*G[{1/(yu*yv)}, yw]*
       G[{1, yv^(-1)}, yw])/128 + (G[{0}, yu^(-1)]*G[{1}, yw]*
       G[{1/(yu*yv)}, yw]*G[{1, yv^(-1)}, yw])/8 + 
     (G[{0}, yv^(-1)]*G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{1, yv^(-1)}, yw])/8 - 
     (G[{0}, yw]*G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{1, yv^(-1)}, yw])/8 - 
     (3*G[{1}, yu^(-1)]*G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{1, yv^(-1)}, yw])/
      16 - (7*G[{1}, yv^(-1)]*G[{1}, yw]*G[{1/(yu*yv)}, yw]*
       G[{1, yv^(-1)}, yw])/64 - (3*G[{1}, yw]^2*G[{1/(yu*yv)}, yw]*
       G[{1, yv^(-1)}, yw])/128 - (3*G[{0}, yu^(-1)]*G[{yu^(-1)}, yw]*
       G[{1/(yu*yv)}, yw]*G[{1, yv^(-1)}, yw])/16 - 
     (3*G[{0}, yv^(-1)]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*
       G[{1, yv^(-1)}, yw])/16 + (3*G[{0}, yw]*G[{yu^(-1)}, yw]*
       G[{1/(yu*yv)}, yw]*G[{1, yv^(-1)}, yw])/16 + 
     (5*G[{1}, yu^(-1)]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*
       G[{1, yv^(-1)}, yw])/16 + (G[{1}, yv^(-1)]*G[{yu^(-1)}, yw]*
       G[{1/(yu*yv)}, yw]*G[{1, yv^(-1)}, yw])/32 - 
     (G[{1}, yw]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{1, yv^(-1)}, yw])/
      32 + (7*G[{yu^(-1)}, yw]^2*G[{1/(yu*yv)}, yw]*G[{1, yv^(-1)}, yw])/64 - 
     (3*G[{0}, yu^(-1)]*G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw]*
       G[{1, yv^(-1)}, yw])/16 - (3*G[{0}, yv^(-1)]*G[{yu}, yv^(-1)]*
       G[{1/(yu*yv)}, yw]*G[{1, yv^(-1)}, yw])/16 + 
     (3*G[{0}, yw]*G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{1, yv^(-1)}, yw])/
      16 + (5*G[{1}, yu^(-1)]*G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw]*
       G[{1, yv^(-1)}, yw])/16 + (7*G[{1}, yv^(-1)]*G[{yu}, yv^(-1)]*
       G[{1/(yu*yv)}, yw]*G[{1, yv^(-1)}, yw])/32 + 
     (3*G[{1}, yw]*G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{1, yv^(-1)}, yw])/
      64 + (G[{yu^(-1)}, yw]*G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw]*
       G[{1, yv^(-1)}, yw])/32 - (5*G[{yu}, yv^(-1)]^2*G[{1/(yu*yv)}, yw]*
       G[{1, yv^(-1)}, yw])/64 - (G[{0}, yu^(-1)]*G[{yv^(-1)}, yw]*
       G[{1/(yu*yv)}, yw]*G[{1, yv^(-1)}, yw])/16 - 
     (G[{0}, yv^(-1)]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*
       G[{1, yv^(-1)}, yw])/16 + (G[{0}, yw]*G[{yv^(-1)}, yw]*
       G[{1/(yu*yv)}, yw]*G[{1, yv^(-1)}, yw])/16 + 
     (G[{1}, yu^(-1)]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*
       G[{1, yv^(-1)}, yw])/16 - (G[{1}, yv^(-1)]*G[{yv^(-1)}, yw]*
       G[{1/(yu*yv)}, yw]*G[{1, yv^(-1)}, yw])/8 - 
     (3*G[{1}, yw]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{1, yv^(-1)}, yw])/
      16 + (3*G[{yu}, yv^(-1)]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*
       G[{1, yv^(-1)}, yw])/16 - (G[{yv^(-1)}, yw]^2*G[{1/(yu*yv)}, yw]*
       G[{1, yv^(-1)}, yw])/8 + (G[{0}, yu^(-1)]*G[{1/(yu*yv)}, yw]^2*
       G[{1, yv^(-1)}, yw])/16 + (G[{0}, yv^(-1)]*G[{1/(yu*yv)}, yw]^2*
       G[{1, yv^(-1)}, yw])/16 - (G[{0}, yw]*G[{1/(yu*yv)}, yw]^2*
       G[{1, yv^(-1)}, yw])/16 - (G[{1}, yu^(-1)]*G[{1/(yu*yv)}, yw]^2*
       G[{1, yv^(-1)}, yw])/16 - (7*G[{1}, yv^(-1)]*G[{1/(yu*yv)}, yw]^2*
       G[{1, yv^(-1)}, yw])/128 + (G[{1}, yw]*G[{1/(yu*yv)}, yw]^2*
       G[{1, yv^(-1)}, yw])/128 + (7*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2*
       G[{1, yv^(-1)}, yw])/128 - (G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw]^2*
       G[{1, yv^(-1)}, yw])/128 + (G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2*
       G[{1, yv^(-1)}, yw])/16 + (G[{0}, yu^(-1)]*G[{0, 1}, yu^(-1)]*
       G[{1, yv^(-1)}, yw])/16 + (G[{0}, yv^(-1)]*G[{0, 1}, yu^(-1)]*
       G[{1, yv^(-1)}, yw])/16 - (G[{0}, yw]*G[{0, 1}, yu^(-1)]*
       G[{1, yv^(-1)}, yw])/16 - (G[{1}, yu^(-1)]*G[{0, 1}, yu^(-1)]*
       G[{1, yv^(-1)}, yw])/16 - (G[{1}, yv^(-1)]*G[{0, 1}, yu^(-1)]*
       G[{1, yv^(-1)}, yw])/16 + (G[{1}, yw]*G[{0, 1}, yu^(-1)]*
       G[{1, yv^(-1)}, yw])/16 - (G[{1/(yu*yv)}, yw]*G[{0, 1}, yu^(-1)]*
       G[{1, yv^(-1)}, yw])/16 - (G[{1}, yu^(-1)]*G[{0, 1}, yv^(-1)]*
       G[{1, yv^(-1)}, yw])/16 - (G[{1}, yv^(-1)]*G[{0, 1}, yv^(-1)]*
       G[{1, yv^(-1)}, yw])/64 - (5*G[{1}, yw]*G[{0, 1}, yv^(-1)]*
       G[{1, yv^(-1)}, yw])/64 + (G[{yu}, yv^(-1)]*G[{0, 1}, yv^(-1)]*
       G[{1, yv^(-1)}, yw])/16 - (3*G[{1/(yu*yv)}, yw]*G[{0, 1}, yv^(-1)]*
       G[{1, yv^(-1)}, yw])/64 + (G[{1}, yv^(-1)]*G[{0, 1}, yw]*
       G[{1, yv^(-1)}, yw])/8 + (G[{1}, yw]*G[{0, 1}, yw]*
       G[{1, yv^(-1)}, yw])/16 - (G[{yu}, yv^(-1)]*G[{0, 1}, yw]*
       G[{1, yv^(-1)}, yw])/8 - (G[{1/(yu*yv)}, yw]*G[{0, 1}, yw]*
       G[{1, yv^(-1)}, yw])/16 - (G[{1}, yv^(-1)]*G[{0, yu^(-1)}, yw]*
       G[{1, yv^(-1)}, yw])/8 - (G[{1}, yw]*G[{0, yu^(-1)}, yw]*
       G[{1, yv^(-1)}, yw])/16 + (G[{yu}, yv^(-1)]*G[{0, yu^(-1)}, yw]*
       G[{1, yv^(-1)}, yw])/8 + (G[{1/(yu*yv)}, yw]*G[{0, yu^(-1)}, yw]*
       G[{1, yv^(-1)}, yw])/16 + (G[{1}, yu^(-1)]*G[{0, yu}, yv^(-1)]*
       G[{1, yv^(-1)}, yw])/16 + (G[{1}, yv^(-1)]*G[{0, yu}, yv^(-1)]*
       G[{1, yv^(-1)}, yw])/64 + (5*G[{1}, yw]*G[{0, yu}, yv^(-1)]*
       G[{1, yv^(-1)}, yw])/64 - (G[{yu}, yv^(-1)]*G[{0, yu}, yv^(-1)]*
       G[{1, yv^(-1)}, yw])/16 + (3*G[{1/(yu*yv)}, yw]*G[{0, yu}, yv^(-1)]*
       G[{1, yv^(-1)}, yw])/64 - (G[{1}, yv^(-1)]*G[{0, yv^(-1)}, yw]*
       G[{1, yv^(-1)}, yw])/8 - (G[{1}, yw]*G[{0, yv^(-1)}, yw]*
       G[{1, yv^(-1)}, yw])/16 + (G[{yu}, yv^(-1)]*G[{0, yv^(-1)}, yw]*
       G[{1, yv^(-1)}, yw])/8 + (G[{1/(yu*yv)}, yw]*G[{0, yv^(-1)}, yw]*
       G[{1, yv^(-1)}, yw])/16 + (G[{1}, yv^(-1)]*G[{0, 1/(yu*yv)}, yw]*
       G[{1, yv^(-1)}, yw])/8 + (G[{1}, yw]*G[{0, 1/(yu*yv)}, yw]*
       G[{1, yv^(-1)}, yw])/16 - (G[{yu}, yv^(-1)]*G[{0, 1/(yu*yv)}, yw]*
       G[{1, yv^(-1)}, yw])/8 - (G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv)}, yw]*
       G[{1, yv^(-1)}, yw])/16 - (G[{1}, yu^(-1)]*G[{1, yu^(-1)}, yw]*
       G[{1, yv^(-1)}, yw])/16 + (3*G[{1}, yv^(-1)]*G[{1, yu^(-1)}, yw]*
       G[{1, yv^(-1)}, yw])/32 + (G[{1}, yw]*G[{1, yu^(-1)}, yw]*
       G[{1, yv^(-1)}, yw])/32 - (G[{yu}, yv^(-1)]*G[{1, yu^(-1)}, yw]*
       G[{1, yv^(-1)}, yw])/32 - (7*G[{1/(yu*yv)}, yw]*G[{1, yu^(-1)}, yw]*
       G[{1, yv^(-1)}, yw])/64 - (G[{0}, yu^(-1)]*G[{1, yu}, yv^(-1)]*
       G[{1, yv^(-1)}, yw])/16 - (G[{0}, yv^(-1)]*G[{1, yu}, yv^(-1)]*
       G[{1, yv^(-1)}, yw])/16 + (G[{0}, yw]*G[{1, yu}, yv^(-1)]*
       G[{1, yv^(-1)}, yw])/16 - (G[{1}, yv^(-1)]*G[{1, yu}, yv^(-1)]*
       G[{1, yv^(-1)}, yw])/32 - (9*G[{1}, yw]*G[{1, yu}, yv^(-1)]*
       G[{1, yv^(-1)}, yw])/64 + (G[{yu}, yv^(-1)]*G[{1, yu}, yv^(-1)]*
       G[{1, yv^(-1)}, yw])/16 + (G[{1/(yu*yv)}, yw]*G[{1, yu}, yv^(-1)]*
       G[{1, yv^(-1)}, yw])/64 + (G[{0}, yu^(-1)]*G[{1, yv^(-1)}, yw]^2)/32 + 
     (G[{0}, yv^(-1)]*G[{1, yv^(-1)}, yw]^2)/32 - 
     (G[{0}, yw]*G[{1, yv^(-1)}, yw]^2)/32 - 
     (G[{1}, yu^(-1)]*G[{1, yv^(-1)}, yw]^2)/32 + 
     (G[{1}, yv^(-1)]*G[{1, yv^(-1)}, yw]^2)/16 + 
     (3*G[{1}, yw]*G[{1, yv^(-1)}, yw]^2)/32 - 
     (3*G[{yu}, yv^(-1)]*G[{1, yv^(-1)}, yw]^2)/32 - 
     (G[{1/(yu*yv)}, yw]*G[{1, yv^(-1)}, yw]^2)/16 - 
     (Pi^2*G[{0}, yu^(-1)]*G[{1, 1/(yu*yv)}, yw])/48 - 
     (Pi^2*G[{0}, yv^(-1)]*G[{1, 1/(yu*yv)}, yw])/48 + 
     (Pi^2*G[{0}, yw]*G[{1, 1/(yu*yv)}, yw])/48 + 
     (Pi^2*G[{1}, yu^(-1)]*G[{1, 1/(yu*yv)}, yw])/96 - 
     (7*Pi^2*G[{1}, yv^(-1)]*G[{1, 1/(yu*yv)}, yw])/768 + 
     (3*G[{1}, yu^(-1)]^2*G[{1}, yv^(-1)]*G[{1, 1/(yu*yv)}, yw])/64 - 
     (G[{1}, yu^(-1)]*G[{1}, yv^(-1)]^2*G[{1, 1/(yu*yv)}, yw])/8 + 
     (3*G[{1}, yv^(-1)]^3*G[{1, 1/(yu*yv)}, yw])/128 - 
     (31*Pi^2*G[{1}, yw]*G[{1, 1/(yu*yv)}, yw])/768 + 
     (G[{0}, yu^(-1)]*G[{1}, yu^(-1)]*G[{1}, yw]*G[{1, 1/(yu*yv)}, yw])/8 + 
     (G[{0}, yv^(-1)]*G[{1}, yu^(-1)]*G[{1}, yw]*G[{1, 1/(yu*yv)}, yw])/8 - 
     (G[{0}, yw]*G[{1}, yu^(-1)]*G[{1}, yw]*G[{1, 1/(yu*yv)}, yw])/8 - 
     (5*G[{1}, yu^(-1)]^2*G[{1}, yw]*G[{1, 1/(yu*yv)}, yw])/64 + 
     (G[{0}, yu^(-1)]*G[{1}, yv^(-1)]*G[{1}, yw]*G[{1, 1/(yu*yv)}, yw])/8 + 
     (G[{0}, yv^(-1)]*G[{1}, yv^(-1)]*G[{1}, yw]*G[{1, 1/(yu*yv)}, yw])/8 - 
     (G[{0}, yw]*G[{1}, yv^(-1)]*G[{1}, yw]*G[{1, 1/(yu*yv)}, yw])/8 - 
     (3*G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*G[{1}, yw]*G[{1, 1/(yu*yv)}, yw])/
      16 - (3*G[{1}, yv^(-1)]^2*G[{1}, yw]*G[{1, 1/(yu*yv)}, yw])/128 + 
     (G[{0}, yu^(-1)]*G[{1}, yw]^2*G[{1, 1/(yu*yv)}, yw])/8 + 
     (G[{0}, yv^(-1)]*G[{1}, yw]^2*G[{1, 1/(yu*yv)}, yw])/8 - 
     (G[{0}, yw]*G[{1}, yw]^2*G[{1, 1/(yu*yv)}, yw])/8 + 
     (7*G[{1}, yv^(-1)]*G[{1}, yw]^2*G[{1, 1/(yu*yv)}, yw])/128 + 
     (13*G[{1}, yw]^3*G[{1, 1/(yu*yv)}, yw])/128 + 
     (31*Pi^2*G[{yu}, yv^(-1)]*G[{1, 1/(yu*yv)}, yw])/768 - 
     (3*G[{1}, yu^(-1)]^2*G[{yu}, yv^(-1)]*G[{1, 1/(yu*yv)}, yw])/64 + 
     (7*G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*G[{yu}, yv^(-1)]*
       G[{1, 1/(yu*yv)}, yw])/32 + (G[{1}, yv^(-1)]^2*G[{yu}, yv^(-1)]*
       G[{1, 1/(yu*yv)}, yw])/64 - (G[{0}, yu^(-1)]*G[{1}, yw]*
       G[{yu}, yv^(-1)]*G[{1, 1/(yu*yv)}, yw])/4 - 
     (G[{0}, yv^(-1)]*G[{1}, yw]*G[{yu}, yv^(-1)]*G[{1, 1/(yu*yv)}, yw])/4 + 
     (G[{0}, yw]*G[{1}, yw]*G[{yu}, yv^(-1)]*G[{1, 1/(yu*yv)}, yw])/4 + 
     (3*G[{1}, yu^(-1)]*G[{1}, yw]*G[{yu}, yv^(-1)]*G[{1, 1/(yu*yv)}, yw])/
      32 + (5*G[{1}, yv^(-1)]*G[{1}, yw]*G[{yu}, yv^(-1)]*
       G[{1, 1/(yu*yv)}, yw])/32 - (39*G[{1}, yw]^2*G[{yu}, yv^(-1)]*
       G[{1, 1/(yu*yv)}, yw])/128 - (G[{1}, yu^(-1)]*G[{yu}, yv^(-1)]^2*
       G[{1, 1/(yu*yv)}, yw])/16 - (7*G[{1}, yv^(-1)]*G[{yu}, yv^(-1)]^2*
       G[{1, 1/(yu*yv)}, yw])/64 + (G[{1}, yw]*G[{yu}, yv^(-1)]^2*
       G[{1, 1/(yu*yv)}, yw])/8 + (11*G[{yu}, yv^(-1)]^3*
       G[{1, 1/(yu*yv)}, yw])/192 + (19*Pi^2*G[{1/(yu*yv)}, yw]*
       G[{1, 1/(yu*yv)}, yw])/768 - (G[{0}, yu^(-1)]^2*G[{1/(yu*yv)}, yw]*
       G[{1, 1/(yu*yv)}, yw])/16 - (G[{0}, yu^(-1)]*G[{0}, yv^(-1)]*
       G[{1/(yu*yv)}, yw]*G[{1, 1/(yu*yv)}, yw])/8 - 
     (G[{0}, yv^(-1)]^2*G[{1/(yu*yv)}, yw]*G[{1, 1/(yu*yv)}, yw])/16 + 
     (G[{0}, yu^(-1)]*G[{0}, yw]*G[{1/(yu*yv)}, yw]*G[{1, 1/(yu*yv)}, yw])/
      8 + (G[{0}, yv^(-1)]*G[{0}, yw]*G[{1/(yu*yv)}, yw]*
       G[{1, 1/(yu*yv)}, yw])/8 - (G[{0}, yw]^2*G[{1/(yu*yv)}, yw]*
       G[{1, 1/(yu*yv)}, yw])/16 + (5*G[{1}, yu^(-1)]^2*G[{1/(yu*yv)}, yw]*
       G[{1, 1/(yu*yv)}, yw])/128 + (13*G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*
       G[{1/(yu*yv)}, yw]*G[{1, 1/(yu*yv)}, yw])/64 + 
     (9*G[{1}, yv^(-1)]^2*G[{1/(yu*yv)}, yw]*G[{1, 1/(yu*yv)}, yw])/128 - 
     (G[{0}, yu^(-1)]*G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{1, 1/(yu*yv)}, yw])/
      4 - (G[{0}, yv^(-1)]*G[{1}, yw]*G[{1/(yu*yv)}, yw]*
       G[{1, 1/(yu*yv)}, yw])/4 + (G[{0}, yw]*G[{1}, yw]*G[{1/(yu*yv)}, yw]*
       G[{1, 1/(yu*yv)}, yw])/4 + (11*G[{1}, yu^(-1)]*G[{1}, yw]*
       G[{1/(yu*yv)}, yw]*G[{1, 1/(yu*yv)}, yw])/64 + 
     (15*G[{1}, yv^(-1)]*G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{1, 1/(yu*yv)}, yw])/
      64 - (3*G[{1}, yw]^2*G[{1/(yu*yv)}, yw]*G[{1, 1/(yu*yv)}, yw])/64 + 
     (G[{0}, yu^(-1)]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*
       G[{1, 1/(yu*yv)}, yw])/16 + (G[{0}, yv^(-1)]*G[{yu^(-1)}, yw]*
       G[{1/(yu*yv)}, yw]*G[{1, 1/(yu*yv)}, yw])/16 - 
     (G[{0}, yw]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{1, 1/(yu*yv)}, yw])/
      16 - (G[{1}, yu^(-1)]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*
       G[{1, 1/(yu*yv)}, yw])/16 - (3*G[{1}, yv^(-1)]*G[{yu^(-1)}, yw]*
       G[{1/(yu*yv)}, yw]*G[{1, 1/(yu*yv)}, yw])/32 - 
     (G[{1}, yw]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{1, 1/(yu*yv)}, yw])/
      32 + (5*G[{yu^(-1)}, yw]^2*G[{1/(yu*yv)}, yw]*G[{1, 1/(yu*yv)}, yw])/
      64 + (G[{0}, yu^(-1)]*G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw]*
       G[{1, 1/(yu*yv)}, yw])/4 + (G[{0}, yv^(-1)]*G[{yu}, yv^(-1)]*
       G[{1/(yu*yv)}, yw]*G[{1, 1/(yu*yv)}, yw])/4 - 
     (G[{0}, yw]*G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{1, 1/(yu*yv)}, yw])/
      4 - (9*G[{1}, yu^(-1)]*G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw]*
       G[{1, 1/(yu*yv)}, yw])/32 - (19*G[{1}, yv^(-1)]*G[{yu}, yv^(-1)]*
       G[{1/(yu*yv)}, yw]*G[{1, 1/(yu*yv)}, yw])/64 + 
     (3*G[{1}, yw]*G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{1, 1/(yu*yv)}, yw])/
      32 + (G[{yu^(-1)}, yw]*G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw]*
       G[{1, 1/(yu*yv)}, yw])/32 + (5*G[{yu}, yv^(-1)]^2*G[{1/(yu*yv)}, yw]*
       G[{1, 1/(yu*yv)}, yw])/128 + (G[{0}, yu^(-1)]*G[{yv^(-1)}, yw]*
       G[{1/(yu*yv)}, yw]*G[{1, 1/(yu*yv)}, yw])/16 + 
     (G[{0}, yv^(-1)]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*
       G[{1, 1/(yu*yv)}, yw])/16 - (G[{0}, yw]*G[{yv^(-1)}, yw]*
       G[{1/(yu*yv)}, yw]*G[{1, 1/(yu*yv)}, yw])/16 - 
     (G[{1}, yu^(-1)]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*
       G[{1, 1/(yu*yv)}, yw])/8 - (G[{1}, yv^(-1)]*G[{yv^(-1)}, yw]*
       G[{1/(yu*yv)}, yw]*G[{1, 1/(yu*yv)}, yw])/32 - 
     (G[{1}, yw]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{1, 1/(yu*yv)}, yw])/
      32 + (G[{yu}, yv^(-1)]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*
       G[{1, 1/(yu*yv)}, yw])/32 + (3*G[{yv^(-1)}, yw]^2*G[{1/(yu*yv)}, yw]*
       G[{1, 1/(yu*yv)}, yw])/32 - (G[{0}, yu^(-1)]*G[{1/(yu*yv)}, yw]^2*
       G[{1, 1/(yu*yv)}, yw])/32 - (G[{0}, yv^(-1)]*G[{1/(yu*yv)}, yw]^2*
       G[{1, 1/(yu*yv)}, yw])/32 + (G[{0}, yw]*G[{1/(yu*yv)}, yw]^2*
       G[{1, 1/(yu*yv)}, yw])/32 + (5*G[{1}, yu^(-1)]*G[{1/(yu*yv)}, yw]^2*
       G[{1, 1/(yu*yv)}, yw])/64 + (G[{1}, yw]*G[{1/(yu*yv)}, yw]^2*
       G[{1, 1/(yu*yv)}, yw])/64 - (3*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2*
       G[{1, 1/(yu*yv)}, yw])/64 - (G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw]^2*
       G[{1, 1/(yu*yv)}, yw])/64 - (5*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2*
       G[{1, 1/(yu*yv)}, yw])/64 - (G[{0}, yu^(-1)]*G[{0, 1}, yu^(-1)]*
       G[{1, 1/(yu*yv)}, yw])/8 - (G[{0}, yv^(-1)]*G[{0, 1}, yu^(-1)]*
       G[{1, 1/(yu*yv)}, yw])/8 + (G[{0}, yw]*G[{0, 1}, yu^(-1)]*
       G[{1, 1/(yu*yv)}, yw])/8 + (G[{1}, yu^(-1)]*G[{0, 1}, yu^(-1)]*
       G[{1, 1/(yu*yv)}, yw])/8 - (3*G[{1}, yv^(-1)]*G[{0, 1}, yu^(-1)]*
       G[{1, 1/(yu*yv)}, yw])/32 - (3*G[{1}, yw]*G[{0, 1}, yu^(-1)]*
       G[{1, 1/(yu*yv)}, yw])/32 + (7*G[{yu}, yv^(-1)]*G[{0, 1}, yu^(-1)]*
       G[{1, 1/(yu*yv)}, yw])/32 + (7*G[{1/(yu*yv)}, yw]*G[{0, 1}, yu^(-1)]*
       G[{1, 1/(yu*yv)}, yw])/64 - (G[{0}, yu^(-1)]*G[{0, 1}, yv^(-1)]*
       G[{1, 1/(yu*yv)}, yw])/8 - (G[{0}, yv^(-1)]*G[{0, 1}, yv^(-1)]*
       G[{1, 1/(yu*yv)}, yw])/8 + (G[{0}, yw]*G[{0, 1}, yv^(-1)]*
       G[{1, 1/(yu*yv)}, yw])/8 + (G[{1}, yu^(-1)]*G[{0, 1}, yv^(-1)]*
       G[{1, 1/(yu*yv)}, yw])/16 - (5*G[{1}, yv^(-1)]*G[{0, 1}, yv^(-1)]*
       G[{1, 1/(yu*yv)}, yw])/64 - (17*G[{1}, yw]*G[{0, 1}, yv^(-1)]*
       G[{1, 1/(yu*yv)}, yw])/64 + (3*G[{yu}, yv^(-1)]*G[{0, 1}, yv^(-1)]*
       G[{1, 1/(yu*yv)}, yw])/16 + (G[{1/(yu*yv)}, yw]*G[{0, 1}, yv^(-1)]*
       G[{1, 1/(yu*yv)}, yw])/16 - (G[{0}, yu^(-1)]*G[{0, 1}, yw]*
       G[{1, 1/(yu*yv)}, yw])/8 - (G[{0}, yv^(-1)]*G[{0, 1}, yw]*
       G[{1, 1/(yu*yv)}, yw])/8 + (G[{0}, yw]*G[{0, 1}, yw]*
       G[{1, 1/(yu*yv)}, yw])/8 + (G[{1}, yu^(-1)]*G[{0, 1}, yw]*
       G[{1, 1/(yu*yv)}, yw])/8 + (G[{1}, yv^(-1)]*G[{0, 1}, yw]*
       G[{1, 1/(yu*yv)}, yw])/8 + (G[{0}, yu^(-1)]*G[{0, yu^(-1)}, yw]*
       G[{1, 1/(yu*yv)}, yw])/8 + (G[{0}, yv^(-1)]*G[{0, yu^(-1)}, yw]*
       G[{1, 1/(yu*yv)}, yw])/8 - (G[{0}, yw]*G[{0, yu^(-1)}, yw]*
       G[{1, 1/(yu*yv)}, yw])/8 - (G[{1}, yu^(-1)]*G[{0, yu^(-1)}, yw]*
       G[{1, 1/(yu*yv)}, yw])/8 - (G[{1}, yv^(-1)]*G[{0, yu^(-1)}, yw]*
       G[{1, 1/(yu*yv)}, yw])/8 + (G[{0}, yu^(-1)]*G[{0, yu}, yv^(-1)]*
       G[{1, 1/(yu*yv)}, yw])/8 + (G[{0}, yv^(-1)]*G[{0, yu}, yv^(-1)]*
       G[{1, 1/(yu*yv)}, yw])/8 - (G[{0}, yw]*G[{0, yu}, yv^(-1)]*
       G[{1, 1/(yu*yv)}, yw])/8 - (G[{1}, yu^(-1)]*G[{0, yu}, yv^(-1)]*
       G[{1, 1/(yu*yv)}, yw])/16 + (5*G[{1}, yv^(-1)]*G[{0, yu}, yv^(-1)]*
       G[{1, 1/(yu*yv)}, yw])/64 + (17*G[{1}, yw]*G[{0, yu}, yv^(-1)]*
       G[{1, 1/(yu*yv)}, yw])/64 - (3*G[{yu}, yv^(-1)]*G[{0, yu}, yv^(-1)]*
       G[{1, 1/(yu*yv)}, yw])/16 - (G[{1/(yu*yv)}, yw]*G[{0, yu}, yv^(-1)]*
       G[{1, 1/(yu*yv)}, yw])/16 + (G[{0}, yu^(-1)]*G[{0, yv^(-1)}, yw]*
       G[{1, 1/(yu*yv)}, yw])/8 + (G[{0}, yv^(-1)]*G[{0, yv^(-1)}, yw]*
       G[{1, 1/(yu*yv)}, yw])/8 - (G[{0}, yw]*G[{0, yv^(-1)}, yw]*
       G[{1, 1/(yu*yv)}, yw])/8 - (G[{1}, yu^(-1)]*G[{0, yv^(-1)}, yw]*
       G[{1, 1/(yu*yv)}, yw])/8 - (G[{1}, yv^(-1)]*G[{0, yv^(-1)}, yw]*
       G[{1, 1/(yu*yv)}, yw])/8 - (G[{0}, yu^(-1)]*G[{0, 1/(yu*yv)}, yw]*
       G[{1, 1/(yu*yv)}, yw])/8 - (G[{0}, yv^(-1)]*G[{0, 1/(yu*yv)}, yw]*
       G[{1, 1/(yu*yv)}, yw])/8 + (G[{0}, yw]*G[{0, 1/(yu*yv)}, yw]*
       G[{1, 1/(yu*yv)}, yw])/8 + (G[{1}, yu^(-1)]*G[{0, 1/(yu*yv)}, yw]*
       G[{1, 1/(yu*yv)}, yw])/8 + (G[{1}, yv^(-1)]*G[{0, 1/(yu*yv)}, yw]*
       G[{1, 1/(yu*yv)}, yw])/8 - (G[{0}, yu^(-1)]*G[{1, yu^(-1)}, yw]*
       G[{1, 1/(yu*yv)}, yw])/4 - (G[{0}, yv^(-1)]*G[{1, yu^(-1)}, yw]*
       G[{1, 1/(yu*yv)}, yw])/4 + (G[{0}, yw]*G[{1, yu^(-1)}, yw]*
       G[{1, 1/(yu*yv)}, yw])/4 + (3*G[{1}, yu^(-1)]*G[{1, yu^(-1)}, yw]*
       G[{1, 1/(yu*yv)}, yw])/16 + (7*G[{1}, yv^(-1)]*G[{1, yu^(-1)}, yw]*
       G[{1, 1/(yu*yv)}, yw])/32 - (3*G[{1}, yw]*G[{1, yu^(-1)}, yw]*
       G[{1, 1/(yu*yv)}, yw])/32 + (3*G[{yu}, yv^(-1)]*G[{1, yu^(-1)}, yw]*
       G[{1, 1/(yu*yv)}, yw])/32 + (G[{1/(yu*yv)}, yw]*G[{1, yu^(-1)}, yw]*
       G[{1, 1/(yu*yv)}, yw])/16 - (G[{1}, yu^(-1)]*G[{1, yu}, yv^(-1)]*
       G[{1, 1/(yu*yv)}, yw])/16 + (G[{1}, yv^(-1)]*G[{1, yu}, yv^(-1)]*
       G[{1, 1/(yu*yv)}, yw])/16 - (11*G[{1}, yw]*G[{1, yu}, yv^(-1)]*
       G[{1, 1/(yu*yv)}, yw])/64 - (G[{yu}, yv^(-1)]*G[{1, yu}, yv^(-1)]*
       G[{1, 1/(yu*yv)}, yw])/32 - (3*G[{1/(yu*yv)}, yw]*G[{1, yu}, yv^(-1)]*
       G[{1, 1/(yu*yv)}, yw])/64 - (G[{0}, yu^(-1)]*G[{1, yv^(-1)}, yw]*
       G[{1, 1/(yu*yv)}, yw])/4 - (G[{0}, yv^(-1)]*G[{1, yv^(-1)}, yw]*
       G[{1, 1/(yu*yv)}, yw])/4 + (G[{0}, yw]*G[{1, yv^(-1)}, yw]*
       G[{1, 1/(yu*yv)}, yw])/4 + (G[{1}, yu^(-1)]*G[{1, yv^(-1)}, yw]*
       G[{1, 1/(yu*yv)}, yw])/4 + (5*G[{1}, yv^(-1)]*G[{1, yv^(-1)}, yw]*
       G[{1, 1/(yu*yv)}, yw])/32 - (3*G[{1}, yw]*G[{1, yv^(-1)}, yw]*
       G[{1, 1/(yu*yv)}, yw])/32 + (3*G[{yu}, yv^(-1)]*G[{1, yv^(-1)}, yw]*
       G[{1, 1/(yu*yv)}, yw])/32 + (7*G[{1/(yu*yv)}, yw]*G[{1, yv^(-1)}, yw]*
       G[{1, 1/(yu*yv)}, yw])/64 + (G[{0}, yu^(-1)]*G[{1, 1/(yu*yv)}, yw]^2)/
      8 + (G[{0}, yv^(-1)]*G[{1, 1/(yu*yv)}, yw]^2)/8 - 
     (G[{0}, yw]*G[{1, 1/(yu*yv)}, yw]^2)/8 - 
     (3*G[{1}, yu^(-1)]*G[{1, 1/(yu*yv)}, yw]^2)/32 - 
     (G[{1}, yv^(-1)]*G[{1, 1/(yu*yv)}, yw]^2)/16 + 
     (3*G[{1}, yw]*G[{1, 1/(yu*yv)}, yw]^2)/32 - 
     (3*G[{yu}, yv^(-1)]*G[{1, 1/(yu*yv)}, yw]^2)/32 - 
     (11*G[{1/(yu*yv)}, yw]*G[{1, 1/(yu*yv)}, yw]^2)/128 + 
     (Pi^2*G[{0}, yu^(-1)]*G[{yu^(-1), 1/(yu*yv)}, yw])/48 + 
     (Pi^2*G[{0}, yv^(-1)]*G[{yu^(-1), 1/(yu*yv)}, yw])/48 - 
     (Pi^2*G[{0}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw])/48 + 
     (Pi^2*G[{1}, yu^(-1)]*G[{yu^(-1), 1/(yu*yv)}, yw])/96 - 
     (G[{0}, yu^(-1)]^2*G[{1}, yu^(-1)]*G[{yu^(-1), 1/(yu*yv)}, yw])/32 - 
     (G[{0}, yu^(-1)]*G[{0}, yv^(-1)]*G[{1}, yu^(-1)]*G[{yu^(-1), 1/(yu*yv)}, 
        yw])/16 - (G[{0}, yv^(-1)]^2*G[{1}, yu^(-1)]*G[{yu^(-1), 1/(yu*yv)}, 
        yw])/32 + (G[{0}, yu^(-1)]*G[{0}, yw]*G[{1}, yu^(-1)]*
       G[{yu^(-1), 1/(yu*yv)}, yw])/16 + 
     (G[{0}, yv^(-1)]*G[{0}, yw]*G[{1}, yu^(-1)]*G[{yu^(-1), 1/(yu*yv)}, yw])/
      16 - (G[{0}, yw]^2*G[{1}, yu^(-1)]*G[{yu^(-1), 1/(yu*yv)}, yw])/32 + 
     (G[{0}, yu^(-1)]*G[{1}, yu^(-1)]^2*G[{yu^(-1), 1/(yu*yv)}, yw])/16 + 
     (G[{0}, yv^(-1)]*G[{1}, yu^(-1)]^2*G[{yu^(-1), 1/(yu*yv)}, yw])/16 - 
     (G[{0}, yw]*G[{1}, yu^(-1)]^2*G[{yu^(-1), 1/(yu*yv)}, yw])/16 - 
     (G[{1}, yu^(-1)]^3*G[{yu^(-1), 1/(yu*yv)}, yw])/32 - 
     (11*Pi^2*G[{1}, yv^(-1)]*G[{yu^(-1), 1/(yu*yv)}, yw])/256 + 
     (G[{0}, yu^(-1)]^2*G[{1}, yv^(-1)]*G[{yu^(-1), 1/(yu*yv)}, yw])/32 + 
     (G[{0}, yu^(-1)]*G[{0}, yv^(-1)]*G[{1}, yv^(-1)]*G[{yu^(-1), 1/(yu*yv)}, 
        yw])/16 + (G[{0}, yv^(-1)]^2*G[{1}, yv^(-1)]*G[{yu^(-1), 1/(yu*yv)}, 
        yw])/32 - (G[{0}, yu^(-1)]*G[{0}, yw]*G[{1}, yv^(-1)]*
       G[{yu^(-1), 1/(yu*yv)}, yw])/16 - 
     (G[{0}, yv^(-1)]*G[{0}, yw]*G[{1}, yv^(-1)]*G[{yu^(-1), 1/(yu*yv)}, yw])/
      16 + (G[{0}, yw]^2*G[{1}, yv^(-1)]*G[{yu^(-1), 1/(yu*yv)}, yw])/32 - 
     (G[{0}, yu^(-1)]*G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*G[{yu^(-1), 1/(yu*yv)}, 
        yw])/8 - (G[{0}, yv^(-1)]*G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*
       G[{yu^(-1), 1/(yu*yv)}, yw])/8 + (G[{0}, yw]*G[{1}, yu^(-1)]*
       G[{1}, yv^(-1)]*G[{yu^(-1), 1/(yu*yv)}, yw])/8 + 
     (3*G[{1}, yu^(-1)]^2*G[{1}, yv^(-1)]*G[{yu^(-1), 1/(yu*yv)}, yw])/64 + 
     (G[{0}, yu^(-1)]*G[{1}, yv^(-1)]^2*G[{yu^(-1), 1/(yu*yv)}, yw])/32 + 
     (G[{0}, yv^(-1)]*G[{1}, yv^(-1)]^2*G[{yu^(-1), 1/(yu*yv)}, yw])/32 - 
     (G[{0}, yw]*G[{1}, yv^(-1)]^2*G[{yu^(-1), 1/(yu*yv)}, yw])/32 + 
     (3*G[{1}, yu^(-1)]*G[{1}, yv^(-1)]^2*G[{yu^(-1), 1/(yu*yv)}, yw])/32 - 
     (G[{1}, yv^(-1)]^3*G[{yu^(-1), 1/(yu*yv)}, yw])/16 - 
     (Pi^2*G[{1}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw])/768 + 
     (G[{0}, yu^(-1)]^2*G[{1}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw])/32 + 
     (G[{0}, yu^(-1)]*G[{0}, yv^(-1)]*G[{1}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw])/
      16 + (G[{0}, yv^(-1)]^2*G[{1}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw])/32 - 
     (G[{0}, yu^(-1)]*G[{0}, yw]*G[{1}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw])/16 - 
     (G[{0}, yv^(-1)]*G[{0}, yw]*G[{1}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw])/16 + 
     (G[{0}, yw]^2*G[{1}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw])/32 - 
     (G[{0}, yu^(-1)]*G[{1}, yu^(-1)]*G[{1}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw])/
      4 - (G[{0}, yv^(-1)]*G[{1}, yu^(-1)]*G[{1}, yw]*G[{yu^(-1), 1/(yu*yv)}, 
        yw])/4 + (G[{0}, yw]*G[{1}, yu^(-1)]*G[{1}, yw]*
       G[{yu^(-1), 1/(yu*yv)}, yw])/4 + (11*G[{1}, yu^(-1)]^2*G[{1}, yw]*
       G[{yu^(-1), 1/(yu*yv)}, yw])/64 + (3*G[{0}, yu^(-1)]*G[{1}, yv^(-1)]*
       G[{1}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw])/16 + 
     (3*G[{0}, yv^(-1)]*G[{1}, yv^(-1)]*G[{1}, yw]*G[{yu^(-1), 1/(yu*yv)}, 
        yw])/16 - (3*G[{0}, yw]*G[{1}, yv^(-1)]*G[{1}, yw]*
       G[{yu^(-1), 1/(yu*yv)}, yw])/16 + (G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*
       G[{1}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw])/8 - 
     (G[{1}, yv^(-1)]^2*G[{1}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw])/8 + 
     (G[{0}, yu^(-1)]*G[{1}, yw]^2*G[{yu^(-1), 1/(yu*yv)}, yw])/16 + 
     (G[{0}, yv^(-1)]*G[{1}, yw]^2*G[{yu^(-1), 1/(yu*yv)}, yw])/16 - 
     (G[{0}, yw]*G[{1}, yw]^2*G[{yu^(-1), 1/(yu*yv)}, yw])/16 - 
     (G[{1}, yu^(-1)]*G[{1}, yw]^2*G[{yu^(-1), 1/(yu*yv)}, yw])/16 + 
     (5*G[{1}, yv^(-1)]*G[{1}, yw]^2*G[{yu^(-1), 1/(yu*yv)}, yw])/64 + 
     (3*G[{1}, yw]^3*G[{yu^(-1), 1/(yu*yv)}, yw])/64 + 
     (41*Pi^2*G[{yu^(-1)}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw])/768 - 
     (G[{0}, yu^(-1)]^2*G[{yu^(-1)}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw])/16 - 
     (G[{0}, yu^(-1)]*G[{0}, yv^(-1)]*G[{yu^(-1)}, yw]*
       G[{yu^(-1), 1/(yu*yv)}, yw])/8 - (G[{0}, yv^(-1)]^2*G[{yu^(-1)}, yw]*
       G[{yu^(-1), 1/(yu*yv)}, yw])/16 + 
     (G[{0}, yu^(-1)]*G[{0}, yw]*G[{yu^(-1)}, yw]*G[{yu^(-1), 1/(yu*yv)}, 
        yw])/8 + (G[{0}, yv^(-1)]*G[{0}, yw]*G[{yu^(-1)}, yw]*
       G[{yu^(-1), 1/(yu*yv)}, yw])/8 - (G[{0}, yw]^2*G[{yu^(-1)}, yw]*
       G[{yu^(-1), 1/(yu*yv)}, yw])/16 + (G[{0}, yu^(-1)]*G[{1}, yu^(-1)]*
       G[{yu^(-1)}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw])/4 + 
     (G[{0}, yv^(-1)]*G[{1}, yu^(-1)]*G[{yu^(-1)}, yw]*
       G[{yu^(-1), 1/(yu*yv)}, yw])/4 - (G[{0}, yw]*G[{1}, yu^(-1)]*
       G[{yu^(-1)}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw])/4 - 
     (9*G[{1}, yu^(-1)]^2*G[{yu^(-1)}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw])/64 - 
     (G[{0}, yu^(-1)]*G[{1}, yv^(-1)]*G[{yu^(-1)}, yw]*
       G[{yu^(-1), 1/(yu*yv)}, yw])/4 - (G[{0}, yv^(-1)]*G[{1}, yv^(-1)]*
       G[{yu^(-1)}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw])/4 + 
     (G[{0}, yw]*G[{1}, yv^(-1)]*G[{yu^(-1)}, yw]*G[{yu^(-1), 1/(yu*yv)}, 
        yw])/4 - (7*G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*G[{yu^(-1)}, yw]*
       G[{yu^(-1), 1/(yu*yv)}, yw])/32 + 
     (29*G[{1}, yv^(-1)]^2*G[{yu^(-1)}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw])/64 - 
     (G[{0}, yu^(-1)]*G[{1}, yw]*G[{yu^(-1)}, yw]*G[{yu^(-1), 1/(yu*yv)}, 
        yw])/2 - (G[{0}, yv^(-1)]*G[{1}, yw]*G[{yu^(-1)}, yw]*
       G[{yu^(-1), 1/(yu*yv)}, yw])/2 + 
     (G[{0}, yw]*G[{1}, yw]*G[{yu^(-1)}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw])/2 + 
     (7*G[{1}, yu^(-1)]*G[{1}, yw]*G[{yu^(-1)}, yw]*G[{yu^(-1), 1/(yu*yv)}, 
        yw])/32 + (13*G[{1}, yv^(-1)]*G[{1}, yw]*G[{yu^(-1)}, yw]*
       G[{yu^(-1), 1/(yu*yv)}, yw])/32 - (3*G[{1}, yw]^2*G[{yu^(-1)}, yw]*
       G[{yu^(-1), 1/(yu*yv)}, yw])/16 + (G[{0}, yu^(-1)]*G[{yu^(-1)}, yw]^2*
       G[{yu^(-1), 1/(yu*yv)}, yw])/4 + (G[{0}, yv^(-1)]*G[{yu^(-1)}, yw]^2*
       G[{yu^(-1), 1/(yu*yv)}, yw])/4 - (G[{0}, yw]*G[{yu^(-1)}, yw]^2*
       G[{yu^(-1), 1/(yu*yv)}, yw])/4 - 
     (41*G[{1}, yv^(-1)]*G[{yu^(-1)}, yw]^2*G[{yu^(-1), 1/(yu*yv)}, yw])/64 - 
     (9*G[{1}, yw]*G[{yu^(-1)}, yw]^2*G[{yu^(-1), 1/(yu*yv)}, yw])/64 + 
     (41*G[{yu^(-1)}, yw]^3*G[{yu^(-1), 1/(yu*yv)}, yw])/192 - 
     (7*Pi^2*G[{yu}, yv^(-1)]*G[{yu^(-1), 1/(yu*yv)}, yw])/768 + 
     (G[{0}, yu^(-1)]*G[{1}, yu^(-1)]*G[{yu}, yv^(-1)]*
       G[{yu^(-1), 1/(yu*yv)}, yw])/8 + (G[{0}, yv^(-1)]*G[{1}, yu^(-1)]*
       G[{yu}, yv^(-1)]*G[{yu^(-1), 1/(yu*yv)}, yw])/8 - 
     (G[{0}, yw]*G[{1}, yu^(-1)]*G[{yu}, yv^(-1)]*G[{yu^(-1), 1/(yu*yv)}, 
        yw])/8 - (5*G[{1}, yu^(-1)]^2*G[{yu}, yv^(-1)]*
       G[{yu^(-1), 1/(yu*yv)}, yw])/64 - (G[{0}, yu^(-1)]*G[{1}, yv^(-1)]*
       G[{yu}, yv^(-1)]*G[{yu^(-1), 1/(yu*yv)}, yw])/8 - 
     (G[{0}, yv^(-1)]*G[{1}, yv^(-1)]*G[{yu}, yv^(-1)]*
       G[{yu^(-1), 1/(yu*yv)}, yw])/8 + (G[{0}, yw]*G[{1}, yv^(-1)]*
       G[{yu}, yv^(-1)]*G[{yu^(-1), 1/(yu*yv)}, yw])/8 - 
     (3*G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*G[{yu}, yv^(-1)]*
       G[{yu^(-1), 1/(yu*yv)}, yw])/32 + 
     (5*G[{1}, yv^(-1)]^2*G[{yu}, yv^(-1)]*G[{yu^(-1), 1/(yu*yv)}, yw])/64 - 
     (G[{0}, yu^(-1)]*G[{1}, yw]*G[{yu}, yv^(-1)]*G[{yu^(-1), 1/(yu*yv)}, 
        yw])/16 - (G[{0}, yv^(-1)]*G[{1}, yw]*G[{yu}, yv^(-1)]*
       G[{yu^(-1), 1/(yu*yv)}, yw])/16 + 
     (G[{0}, yw]*G[{1}, yw]*G[{yu}, yv^(-1)]*G[{yu^(-1), 1/(yu*yv)}, yw])/
      16 + (G[{1}, yu^(-1)]*G[{1}, yw]*G[{yu}, yv^(-1)]*
       G[{yu^(-1), 1/(yu*yv)}, yw])/32 - (3*G[{1}, yv^(-1)]*G[{1}, yw]*
       G[{yu}, yv^(-1)]*G[{yu^(-1), 1/(yu*yv)}, yw])/16 - 
     (9*G[{1}, yw]^2*G[{yu}, yv^(-1)]*G[{yu^(-1), 1/(yu*yv)}, yw])/64 + 
     (G[{0}, yu^(-1)]*G[{yu^(-1)}, yw]*G[{yu}, yv^(-1)]*
       G[{yu^(-1), 1/(yu*yv)}, yw])/4 + (G[{0}, yv^(-1)]*G[{yu^(-1)}, yw]*
       G[{yu}, yv^(-1)]*G[{yu^(-1), 1/(yu*yv)}, yw])/4 - 
     (G[{0}, yw]*G[{yu^(-1)}, yw]*G[{yu}, yv^(-1)]*G[{yu^(-1), 1/(yu*yv)}, 
        yw])/4 - (9*G[{1}, yv^(-1)]*G[{yu^(-1)}, yw]*G[{yu}, yv^(-1)]*
       G[{yu^(-1), 1/(yu*yv)}, yw])/32 + (3*G[{1}, yw]*G[{yu^(-1)}, yw]*
       G[{yu}, yv^(-1)]*G[{yu^(-1), 1/(yu*yv)}, yw])/8 + 
     (9*G[{yu^(-1)}, yw]^2*G[{yu}, yv^(-1)]*G[{yu^(-1), 1/(yu*yv)}, yw])/64 + 
     (7*G[{1}, yv^(-1)]*G[{yu}, yv^(-1)]^2*G[{yu^(-1), 1/(yu*yv)}, yw])/64 + 
     (9*G[{1}, yw]*G[{yu}, yv^(-1)]^2*G[{yu^(-1), 1/(yu*yv)}, yw])/64 - 
     (7*G[{yu^(-1)}, yw]*G[{yu}, yv^(-1)]^2*G[{yu^(-1), 1/(yu*yv)}, yw])/64 - 
     (7*G[{yu}, yv^(-1)]^3*G[{yu^(-1), 1/(yu*yv)}, yw])/192 - 
     (Pi^2*G[{1/(yu*yv)}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw])/256 + 
     (G[{0}, yu^(-1)]*G[{1}, yu^(-1)]*G[{1/(yu*yv)}, yw]*
       G[{yu^(-1), 1/(yu*yv)}, yw])/8 + (G[{0}, yv^(-1)]*G[{1}, yu^(-1)]*
       G[{1/(yu*yv)}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw])/8 - 
     (G[{0}, yw]*G[{1}, yu^(-1)]*G[{1/(yu*yv)}, yw]*G[{yu^(-1), 1/(yu*yv)}, 
        yw])/8 - (13*G[{1}, yu^(-1)]^2*G[{1/(yu*yv)}, yw]*
       G[{yu^(-1), 1/(yu*yv)}, yw])/128 - 
     (3*G[{0}, yu^(-1)]*G[{1}, yv^(-1)]*G[{1/(yu*yv)}, yw]*
       G[{yu^(-1), 1/(yu*yv)}, yw])/16 - (3*G[{0}, yv^(-1)]*G[{1}, yv^(-1)]*
       G[{1/(yu*yv)}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw])/16 + 
     (3*G[{0}, yw]*G[{1}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{yu^(-1), 1/(yu*yv)}, 
        yw])/16 - (G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*G[{1/(yu*yv)}, yw]*
       G[{yu^(-1), 1/(yu*yv)}, yw])/64 + 
     (9*G[{1}, yv^(-1)]^2*G[{1/(yu*yv)}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw])/
      64 + (G[{1}, yu^(-1)]*G[{1}, yw]*G[{1/(yu*yv)}, yw]*
       G[{yu^(-1), 1/(yu*yv)}, yw])/64 - 
     (G[{1}, yv^(-1)]*G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{yu^(-1), 1/(yu*yv)}, 
        yw])/8 - (7*G[{1}, yw]^2*G[{1/(yu*yv)}, yw]*G[{yu^(-1), 1/(yu*yv)}, 
        yw])/128 + (G[{0}, yu^(-1)]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*
       G[{yu^(-1), 1/(yu*yv)}, yw])/8 + (G[{0}, yv^(-1)]*G[{yu^(-1)}, yw]*
       G[{1/(yu*yv)}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw])/8 - 
     (G[{0}, yw]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{yu^(-1), 1/(yu*yv)}, 
        yw])/8 + (G[{1}, yu^(-1)]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*
       G[{yu^(-1), 1/(yu*yv)}, yw])/32 - (13*G[{1}, yv^(-1)]*G[{yu^(-1)}, yw]*
       G[{1/(yu*yv)}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw])/64 + 
     (5*G[{1}, yw]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*
       G[{yu^(-1), 1/(yu*yv)}, yw])/64 + 
     (13*G[{yu^(-1)}, yw]^2*G[{1/(yu*yv)}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw])/
      128 + (G[{0}, yu^(-1)]*G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw]*
       G[{yu^(-1), 1/(yu*yv)}, yw])/16 + (G[{0}, yv^(-1)]*G[{yu}, yv^(-1)]*
       G[{1/(yu*yv)}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw])/16 - 
     (G[{0}, yw]*G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{yu^(-1), 1/(yu*yv)}, 
        yw])/16 - (G[{1}, yu^(-1)]*G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw]*
       G[{yu^(-1), 1/(yu*yv)}, yw])/32 + (5*G[{1}, yv^(-1)]*G[{yu}, yv^(-1)]*
       G[{1/(yu*yv)}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw])/64 + 
     (7*G[{1}, yw]*G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw]*
       G[{yu^(-1), 1/(yu*yv)}, yw])/64 - (5*G[{yu^(-1)}, yw]*G[{yu}, yv^(-1)]*
       G[{1/(yu*yv)}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw])/64 - 
     (11*G[{yu}, yv^(-1)]^2*G[{1/(yu*yv)}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw])/
      128 + (G[{1}, yu^(-1)]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*
       G[{yu^(-1), 1/(yu*yv)}, yw])/16 + (5*G[{1}, yv^(-1)]*G[{yv^(-1)}, yw]*
       G[{1/(yu*yv)}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw])/32 + 
     (7*G[{1}, yw]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*
       G[{yu^(-1), 1/(yu*yv)}, yw])/32 - (5*G[{yu^(-1)}, yw]*G[{yv^(-1)}, yw]*
       G[{1/(yu*yv)}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw])/32 - 
     (7*G[{yu}, yv^(-1)]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*
       G[{yu^(-1), 1/(yu*yv)}, yw])/32 + 
     (G[{yv^(-1)}, yw]^2*G[{1/(yu*yv)}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw])/32 - 
     (G[{0}, yu^(-1)]*G[{1/(yu*yv)}, yw]^2*G[{yu^(-1), 1/(yu*yv)}, yw])/32 - 
     (G[{0}, yv^(-1)]*G[{1/(yu*yv)}, yw]^2*G[{yu^(-1), 1/(yu*yv)}, yw])/32 + 
     (G[{0}, yw]*G[{1/(yu*yv)}, yw]^2*G[{yu^(-1), 1/(yu*yv)}, yw])/32 - 
     (G[{1}, yu^(-1)]*G[{1/(yu*yv)}, yw]^2*G[{yu^(-1), 1/(yu*yv)}, yw])/64 + 
     (7*G[{1}, yv^(-1)]*G[{1/(yu*yv)}, yw]^2*G[{yu^(-1), 1/(yu*yv)}, yw])/
      128 - (3*G[{1}, yw]*G[{1/(yu*yv)}, yw]^2*G[{yu^(-1), 1/(yu*yv)}, yw])/
      128 - (7*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2*G[{yu^(-1), 1/(yu*yv)}, 
        yw])/128 + (3*G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw]^2*
       G[{yu^(-1), 1/(yu*yv)}, yw])/128 + 
     (G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2*G[{yu^(-1), 1/(yu*yv)}, yw])/64 + 
     (G[{1}, yu^(-1)]*G[{0, 1}, yu^(-1)]*G[{yu^(-1), 1/(yu*yv)}, yw])/16 - 
     (3*G[{1}, yv^(-1)]*G[{0, 1}, yu^(-1)]*G[{yu^(-1), 1/(yu*yv)}, yw])/32 + 
     (G[{1}, yw]*G[{0, 1}, yu^(-1)]*G[{yu^(-1), 1/(yu*yv)}, yw])/32 + 
     (G[{yu^(-1)}, yw]*G[{0, 1}, yu^(-1)]*G[{yu^(-1), 1/(yu*yv)}, yw])/32 + 
     (G[{yu}, yv^(-1)]*G[{0, 1}, yu^(-1)]*G[{yu^(-1), 1/(yu*yv)}, yw])/32 - 
     (3*G[{1/(yu*yv)}, yw]*G[{0, 1}, yu^(-1)]*G[{yu^(-1), 1/(yu*yv)}, yw])/
      64 + (G[{0}, yu^(-1)]*G[{0, 1}, yv^(-1)]*G[{yu^(-1), 1/(yu*yv)}, yw])/
      16 + (G[{0}, yv^(-1)]*G[{0, 1}, yv^(-1)]*G[{yu^(-1), 1/(yu*yv)}, yw])/
      16 - (G[{0}, yw]*G[{0, 1}, yv^(-1)]*G[{yu^(-1), 1/(yu*yv)}, yw])/16 - 
     (5*G[{1}, yv^(-1)]*G[{0, 1}, yv^(-1)]*G[{yu^(-1), 1/(yu*yv)}, yw])/32 - 
     (G[{1}, yw]*G[{0, 1}, yv^(-1)]*G[{yu^(-1), 1/(yu*yv)}, yw])/32 + 
     (G[{yu^(-1)}, yw]*G[{0, 1}, yv^(-1)]*G[{yu^(-1), 1/(yu*yv)}, yw])/8 - 
     (G[{1/(yu*yv)}, yw]*G[{0, 1}, yv^(-1)]*G[{yu^(-1), 1/(yu*yv)}, yw])/64 + 
     (3*G[{0}, yu^(-1)]*G[{0, 1}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw])/16 + 
     (3*G[{0}, yv^(-1)]*G[{0, 1}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw])/16 - 
     (3*G[{0}, yw]*G[{0, 1}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw])/16 - 
     (G[{1}, yu^(-1)]*G[{0, 1}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw])/4 + 
     (G[{1}, yw]*G[{0, 1}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw])/16 - 
     (G[{yu^(-1)}, yw]*G[{0, 1}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw])/4 - 
     (G[{yu}, yv^(-1)]*G[{0, 1}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw])/8 + 
     (G[{1/(yu*yv)}, yw]*G[{0, 1}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw])/16 - 
     (3*G[{0}, yu^(-1)]*G[{0, yu^(-1)}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw])/16 - 
     (3*G[{0}, yv^(-1)]*G[{0, yu^(-1)}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw])/16 + 
     (3*G[{0}, yw]*G[{0, yu^(-1)}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw])/16 + 
     (G[{1}, yu^(-1)]*G[{0, yu^(-1)}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw])/4 - 
     (G[{1}, yw]*G[{0, yu^(-1)}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw])/16 + 
     (G[{yu^(-1)}, yw]*G[{0, yu^(-1)}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw])/4 + 
     (G[{yu}, yv^(-1)]*G[{0, yu^(-1)}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw])/8 - 
     (G[{1/(yu*yv)}, yw]*G[{0, yu^(-1)}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw])/
      16 - (G[{0}, yu^(-1)]*G[{0, yu}, yv^(-1)]*G[{yu^(-1), 1/(yu*yv)}, yw])/
      16 - (G[{0}, yv^(-1)]*G[{0, yu}, yv^(-1)]*G[{yu^(-1), 1/(yu*yv)}, yw])/
      16 + (G[{0}, yw]*G[{0, yu}, yv^(-1)]*G[{yu^(-1), 1/(yu*yv)}, yw])/16 + 
     (5*G[{1}, yv^(-1)]*G[{0, yu}, yv^(-1)]*G[{yu^(-1), 1/(yu*yv)}, yw])/32 + 
     (G[{1}, yw]*G[{0, yu}, yv^(-1)]*G[{yu^(-1), 1/(yu*yv)}, yw])/32 - 
     (G[{yu^(-1)}, yw]*G[{0, yu}, yv^(-1)]*G[{yu^(-1), 1/(yu*yv)}, yw])/8 + 
     (G[{1/(yu*yv)}, yw]*G[{0, yu}, yv^(-1)]*G[{yu^(-1), 1/(yu*yv)}, yw])/
      64 - (3*G[{0}, yu^(-1)]*G[{0, yv^(-1)}, yw]*G[{yu^(-1), 1/(yu*yv)}, 
        yw])/16 - (3*G[{0}, yv^(-1)]*G[{0, yv^(-1)}, yw]*
       G[{yu^(-1), 1/(yu*yv)}, yw])/16 + (3*G[{0}, yw]*G[{0, yv^(-1)}, yw]*
       G[{yu^(-1), 1/(yu*yv)}, yw])/16 + (G[{1}, yu^(-1)]*G[{0, yv^(-1)}, yw]*
       G[{yu^(-1), 1/(yu*yv)}, yw])/4 - (G[{1}, yw]*G[{0, yv^(-1)}, yw]*
       G[{yu^(-1), 1/(yu*yv)}, yw])/16 + 
     (G[{yu^(-1)}, yw]*G[{0, yv^(-1)}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw])/4 + 
     (G[{yu}, yv^(-1)]*G[{0, yv^(-1)}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw])/8 - 
     (G[{1/(yu*yv)}, yw]*G[{0, yv^(-1)}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw])/
      16 + (3*G[{0}, yu^(-1)]*G[{0, 1/(yu*yv)}, yw]*G[{yu^(-1), 1/(yu*yv)}, 
        yw])/16 + (3*G[{0}, yv^(-1)]*G[{0, 1/(yu*yv)}, yw]*
       G[{yu^(-1), 1/(yu*yv)}, yw])/16 - (3*G[{0}, yw]*G[{0, 1/(yu*yv)}, yw]*
       G[{yu^(-1), 1/(yu*yv)}, yw])/16 - 
     (G[{1}, yu^(-1)]*G[{0, 1/(yu*yv)}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw])/4 + 
     (G[{1}, yw]*G[{0, 1/(yu*yv)}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw])/16 - 
     (G[{yu^(-1)}, yw]*G[{0, 1/(yu*yv)}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw])/4 - 
     (G[{yu}, yv^(-1)]*G[{0, 1/(yu*yv)}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw])/8 + 
     (G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv)}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw])/
      16 + (G[{0}, yu^(-1)]*G[{1, yu^(-1)}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw])/
      4 + (G[{0}, yv^(-1)]*G[{1, yu^(-1)}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw])/
      4 - (G[{0}, yw]*G[{1, yu^(-1)}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw])/4 - 
     (G[{1}, yu^(-1)]*G[{1, yu^(-1)}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw])/4 - 
     (G[{1}, yv^(-1)]*G[{1, yu^(-1)}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw])/16 + 
     (3*G[{1}, yw]*G[{1, yu^(-1)}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw])/16 - 
     (G[{yu^(-1)}, yw]*G[{1, yu^(-1)}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw])/8 - 
     (3*G[{yu}, yv^(-1)]*G[{1, yu^(-1)}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw])/
      16 + (3*G[{1/(yu*yv)}, yw]*G[{1, yu^(-1)}, yw]*G[{yu^(-1), 1/(yu*yv)}, 
        yw])/64 + (G[{0}, yu^(-1)]*G[{1, yu}, yv^(-1)]*
       G[{yu^(-1), 1/(yu*yv)}, yw])/16 + (G[{0}, yv^(-1)]*G[{1, yu}, yv^(-1)]*
       G[{yu^(-1), 1/(yu*yv)}, yw])/16 - (G[{0}, yw]*G[{1, yu}, yv^(-1)]*
       G[{yu^(-1), 1/(yu*yv)}, yw])/16 + (G[{1}, yu^(-1)]*G[{1, yu}, yv^(-1)]*
       G[{yu^(-1), 1/(yu*yv)}, yw])/16 - (G[{1}, yv^(-1)]*G[{1, yu}, yv^(-1)]*
       G[{yu^(-1), 1/(yu*yv)}, yw])/32 - (G[{1}, yw]*G[{1, yu}, yv^(-1)]*
       G[{yu^(-1), 1/(yu*yv)}, yw])/16 + 
     (3*G[{yu^(-1)}, yw]*G[{1, yu}, yv^(-1)]*G[{yu^(-1), 1/(yu*yv)}, yw])/
      32 - (G[{yu}, yv^(-1)]*G[{1, yu}, yv^(-1)]*G[{yu^(-1), 1/(yu*yv)}, yw])/
      32 + (G[{1/(yu*yv)}, yw]*G[{1, yu}, yv^(-1)]*G[{yu^(-1), 1/(yu*yv)}, 
        yw])/32 + (3*G[{0}, yu^(-1)]*G[{1, yv^(-1)}, yw]*
       G[{yu^(-1), 1/(yu*yv)}, yw])/16 + 
     (3*G[{0}, yv^(-1)]*G[{1, yv^(-1)}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw])/16 - 
     (3*G[{0}, yw]*G[{1, yv^(-1)}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw])/16 - 
     (5*G[{1}, yu^(-1)]*G[{1, yv^(-1)}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw])/16 - 
     (G[{1}, yv^(-1)]*G[{1, yv^(-1)}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw])/32 + 
     (G[{1}, yw]*G[{1, yv^(-1)}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw])/32 - 
     (7*G[{yu^(-1)}, yw]*G[{1, yv^(-1)}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw])/
      32 - (G[{yu}, yv^(-1)]*G[{1, yv^(-1)}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw])/
      32 + (G[{1/(yu*yv)}, yw]*G[{1, yv^(-1)}, yw]*G[{yu^(-1), 1/(yu*yv)}, 
        yw])/64 - (G[{0}, yu^(-1)]*G[{1, 1/(yu*yv)}, yw]*
       G[{yu^(-1), 1/(yu*yv)}, yw])/16 - 
     (G[{0}, yv^(-1)]*G[{1, 1/(yu*yv)}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw])/16 + 
     (G[{0}, yw]*G[{1, 1/(yu*yv)}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw])/16 + 
     (G[{1}, yu^(-1)]*G[{1, 1/(yu*yv)}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw])/16 + 
     (3*G[{1}, yv^(-1)]*G[{1, 1/(yu*yv)}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw])/
      32 + (G[{1}, yw]*G[{1, 1/(yu*yv)}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw])/
      32 - (5*G[{yu^(-1)}, yw]*G[{1, 1/(yu*yv)}, yw]*G[{yu^(-1), 1/(yu*yv)}, 
        yw])/32 - (G[{yu}, yv^(-1)]*G[{1, 1/(yu*yv)}, yw]*
       G[{yu^(-1), 1/(yu*yv)}, yw])/32 + 
     (G[{1/(yu*yv)}, yw]*G[{1, 1/(yu*yv)}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw])/
      16 - (G[{0}, yu^(-1)]*G[{yu^(-1), 1/(yu*yv)}, yw]^2)/16 - 
     (G[{0}, yv^(-1)]*G[{yu^(-1), 1/(yu*yv)}, yw]^2)/16 + 
     (G[{0}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw]^2)/16 + 
     (G[{1}, yu^(-1)]*G[{yu^(-1), 1/(yu*yv)}, yw]^2)/8 - 
     (G[{1}, yv^(-1)]*G[{yu^(-1), 1/(yu*yv)}, yw]^2)/32 - 
     (G[{1}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw]^2)/32 + 
     (G[{yu^(-1)}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw]^2)/32 + 
     (G[{yu}, yv^(-1)]*G[{yu^(-1), 1/(yu*yv)}, yw]^2)/32 - 
     (5*G[{1/(yu*yv)}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw]^2)/128 - 
     (Pi^2*G[{0}, yu^(-1)]*G[{yv^(-1), 1/(yu*yv)}, yw])/96 - 
     (Pi^2*G[{0}, yv^(-1)]*G[{yv^(-1), 1/(yu*yv)}, yw])/96 + 
     (Pi^2*G[{0}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw])/96 + 
     (G[{0}, yu^(-1)]^2*G[{1}, yu^(-1)]*G[{yv^(-1), 1/(yu*yv)}, yw])/32 + 
     (G[{0}, yu^(-1)]*G[{0}, yv^(-1)]*G[{1}, yu^(-1)]*G[{yv^(-1), 1/(yu*yv)}, 
        yw])/16 + (G[{0}, yv^(-1)]^2*G[{1}, yu^(-1)]*G[{yv^(-1), 1/(yu*yv)}, 
        yw])/32 - (G[{0}, yu^(-1)]*G[{0}, yw]*G[{1}, yu^(-1)]*
       G[{yv^(-1), 1/(yu*yv)}, yw])/16 - 
     (G[{0}, yv^(-1)]*G[{0}, yw]*G[{1}, yu^(-1)]*G[{yv^(-1), 1/(yu*yv)}, yw])/
      16 + (G[{0}, yw]^2*G[{1}, yu^(-1)]*G[{yv^(-1), 1/(yu*yv)}, yw])/32 - 
     (G[{0}, yu^(-1)]*G[{1}, yu^(-1)]^2*G[{yv^(-1), 1/(yu*yv)}, yw])/16 - 
     (G[{0}, yv^(-1)]*G[{1}, yu^(-1)]^2*G[{yv^(-1), 1/(yu*yv)}, yw])/16 + 
     (G[{0}, yw]*G[{1}, yu^(-1)]^2*G[{yv^(-1), 1/(yu*yv)}, yw])/16 + 
     (G[{1}, yu^(-1)]^3*G[{yv^(-1), 1/(yu*yv)}, yw])/32 + 
     (Pi^2*G[{1}, yv^(-1)]*G[{yv^(-1), 1/(yu*yv)}, yw])/96 - 
     (G[{0}, yu^(-1)]^2*G[{1}, yv^(-1)]*G[{yv^(-1), 1/(yu*yv)}, yw])/32 - 
     (G[{0}, yu^(-1)]*G[{0}, yv^(-1)]*G[{1}, yv^(-1)]*G[{yv^(-1), 1/(yu*yv)}, 
        yw])/16 - (G[{0}, yv^(-1)]^2*G[{1}, yv^(-1)]*G[{yv^(-1), 1/(yu*yv)}, 
        yw])/32 + (G[{0}, yu^(-1)]*G[{0}, yw]*G[{1}, yv^(-1)]*
       G[{yv^(-1), 1/(yu*yv)}, yw])/16 + 
     (G[{0}, yv^(-1)]*G[{0}, yw]*G[{1}, yv^(-1)]*G[{yv^(-1), 1/(yu*yv)}, yw])/
      16 - (G[{0}, yw]^2*G[{1}, yv^(-1)]*G[{yv^(-1), 1/(yu*yv)}, yw])/32 + 
     (G[{0}, yu^(-1)]*G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*G[{yv^(-1), 1/(yu*yv)}, 
        yw])/8 + (G[{0}, yv^(-1)]*G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*
       G[{yv^(-1), 1/(yu*yv)}, yw])/8 - (G[{0}, yw]*G[{1}, yu^(-1)]*
       G[{1}, yv^(-1)]*G[{yv^(-1), 1/(yu*yv)}, yw])/8 - 
     (3*G[{1}, yu^(-1)]^2*G[{1}, yv^(-1)]*G[{yv^(-1), 1/(yu*yv)}, yw])/32 - 
     (G[{0}, yu^(-1)]*G[{1}, yv^(-1)]^2*G[{yv^(-1), 1/(yu*yv)}, yw])/32 - 
     (G[{0}, yv^(-1)]*G[{1}, yv^(-1)]^2*G[{yv^(-1), 1/(yu*yv)}, yw])/32 + 
     (G[{0}, yw]*G[{1}, yv^(-1)]^2*G[{yv^(-1), 1/(yu*yv)}, yw])/32 + 
     (G[{1}, yu^(-1)]*G[{1}, yv^(-1)]^2*G[{yv^(-1), 1/(yu*yv)}, yw])/32 + 
     (5*G[{1}, yv^(-1)]^3*G[{yv^(-1), 1/(yu*yv)}, yw])/128 - 
     (Pi^2*G[{1}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw])/48 + 
     (G[{0}, yu^(-1)]^2*G[{1}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw])/32 + 
     (G[{0}, yu^(-1)]*G[{0}, yv^(-1)]*G[{1}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw])/
      16 + (G[{0}, yv^(-1)]^2*G[{1}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw])/32 - 
     (G[{0}, yu^(-1)]*G[{0}, yw]*G[{1}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw])/16 - 
     (G[{0}, yv^(-1)]*G[{0}, yw]*G[{1}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw])/16 + 
     (G[{0}, yw]^2*G[{1}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw])/32 - 
     (G[{1}, yu^(-1)]^2*G[{1}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw])/32 - 
     (G[{0}, yu^(-1)]*G[{1}, yv^(-1)]*G[{1}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw])/
      16 - (G[{0}, yv^(-1)]*G[{1}, yv^(-1)]*G[{1}, yw]*
       G[{yv^(-1), 1/(yu*yv)}, yw])/16 + 
     (G[{0}, yw]*G[{1}, yv^(-1)]*G[{1}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw])/16 + 
     (3*G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*G[{1}, yw]*G[{yv^(-1), 1/(yu*yv)}, 
        yw])/16 + (3*G[{1}, yv^(-1)]^2*G[{1}, yw]*G[{yv^(-1), 1/(yu*yv)}, 
        yw])/128 + (G[{0}, yu^(-1)]*G[{1}, yw]^2*G[{yv^(-1), 1/(yu*yv)}, yw])/
      16 + (G[{0}, yv^(-1)]*G[{1}, yw]^2*G[{yv^(-1), 1/(yu*yv)}, yw])/16 - 
     (G[{0}, yw]*G[{1}, yw]^2*G[{yv^(-1), 1/(yu*yv)}, yw])/16 - 
     (G[{1}, yv^(-1)]*G[{1}, yw]^2*G[{yv^(-1), 1/(yu*yv)}, yw])/128 + 
     (5*G[{1}, yw]^3*G[{yv^(-1), 1/(yu*yv)}, yw])/128 + 
     (Pi^2*G[{yu}, yv^(-1)]*G[{yv^(-1), 1/(yu*yv)}, yw])/96 - 
     (G[{0}, yu^(-1)]*G[{1}, yu^(-1)]*G[{yu}, yv^(-1)]*
       G[{yv^(-1), 1/(yu*yv)}, yw])/8 - (G[{0}, yv^(-1)]*G[{1}, yu^(-1)]*
       G[{yu}, yv^(-1)]*G[{yv^(-1), 1/(yu*yv)}, yw])/8 + 
     (G[{0}, yw]*G[{1}, yu^(-1)]*G[{yu}, yv^(-1)]*G[{yv^(-1), 1/(yu*yv)}, 
        yw])/8 + (G[{1}, yu^(-1)]^2*G[{yu}, yv^(-1)]*G[{yv^(-1), 1/(yu*yv)}, 
        yw])/8 + (G[{0}, yu^(-1)]*G[{1}, yv^(-1)]*G[{yu}, yv^(-1)]*
       G[{yv^(-1), 1/(yu*yv)}, yw])/8 + (G[{0}, yv^(-1)]*G[{1}, yv^(-1)]*
       G[{yu}, yv^(-1)]*G[{yv^(-1), 1/(yu*yv)}, yw])/8 - 
     (G[{0}, yw]*G[{1}, yv^(-1)]*G[{yu}, yv^(-1)]*G[{yv^(-1), 1/(yu*yv)}, 
        yw])/8 - (G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*G[{yu}, yv^(-1)]*
       G[{yv^(-1), 1/(yu*yv)}, yw])/8 - (3*G[{1}, yv^(-1)]^2*G[{yu}, yv^(-1)]*
       G[{yv^(-1), 1/(yu*yv)}, yw])/32 - 
     (G[{0}, yu^(-1)]*G[{1}, yw]*G[{yu}, yv^(-1)]*G[{yv^(-1), 1/(yu*yv)}, 
        yw])/16 - (G[{0}, yv^(-1)]*G[{1}, yw]*G[{yu}, yv^(-1)]*
       G[{yv^(-1), 1/(yu*yv)}, yw])/16 + 
     (G[{0}, yw]*G[{1}, yw]*G[{yu}, yv^(-1)]*G[{yv^(-1), 1/(yu*yv)}, yw])/
      16 - (G[{1}, yu^(-1)]*G[{1}, yw]*G[{yu}, yv^(-1)]*
       G[{yv^(-1), 1/(yu*yv)}, yw])/8 + (G[{1}, yv^(-1)]*G[{1}, yw]*
       G[{yu}, yv^(-1)]*G[{yv^(-1), 1/(yu*yv)}, yw])/32 - 
     (15*G[{1}, yw]^2*G[{yu}, yv^(-1)]*G[{yv^(-1), 1/(yu*yv)}, yw])/128 + 
     (G[{1}, yu^(-1)]*G[{yu}, yv^(-1)]^2*G[{yv^(-1), 1/(yu*yv)}, yw])/16 + 
     (7*G[{1}, yw]*G[{yu}, yv^(-1)]^2*G[{yv^(-1), 1/(yu*yv)}, yw])/64 - 
     (G[{yu}, yv^(-1)]^3*G[{yv^(-1), 1/(yu*yv)}, yw])/48 + 
     (Pi^2*G[{yv^(-1)}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw])/96 - 
     (G[{0}, yu^(-1)]^2*G[{yv^(-1)}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw])/16 - 
     (G[{0}, yu^(-1)]*G[{0}, yv^(-1)]*G[{yv^(-1)}, yw]*
       G[{yv^(-1), 1/(yu*yv)}, yw])/8 - (G[{0}, yv^(-1)]^2*G[{yv^(-1)}, yw]*
       G[{yv^(-1), 1/(yu*yv)}, yw])/16 + 
     (G[{0}, yu^(-1)]*G[{0}, yw]*G[{yv^(-1)}, yw]*G[{yv^(-1), 1/(yu*yv)}, 
        yw])/8 + (G[{0}, yv^(-1)]*G[{0}, yw]*G[{yv^(-1)}, yw]*
       G[{yv^(-1), 1/(yu*yv)}, yw])/8 - (G[{0}, yw]^2*G[{yv^(-1)}, yw]*
       G[{yv^(-1), 1/(yu*yv)}, yw])/16 + (G[{0}, yu^(-1)]*G[{1}, yu^(-1)]*
       G[{yv^(-1)}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw])/8 + 
     (G[{0}, yv^(-1)]*G[{1}, yu^(-1)]*G[{yv^(-1)}, yw]*
       G[{yv^(-1), 1/(yu*yv)}, yw])/8 - (G[{0}, yw]*G[{1}, yu^(-1)]*
       G[{yv^(-1)}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw])/8 - 
     (G[{1}, yu^(-1)]^2*G[{yv^(-1)}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw])/16 - 
     (G[{0}, yu^(-1)]*G[{1}, yv^(-1)]*G[{yv^(-1)}, yw]*
       G[{yv^(-1), 1/(yu*yv)}, yw])/8 - (G[{0}, yv^(-1)]*G[{1}, yv^(-1)]*
       G[{yv^(-1)}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw])/8 + 
     (G[{0}, yw]*G[{1}, yv^(-1)]*G[{yv^(-1)}, yw]*G[{yv^(-1), 1/(yu*yv)}, 
        yw])/8 + (G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*G[{yv^(-1)}, yw]*
       G[{yv^(-1), 1/(yu*yv)}, yw])/4 + (G[{1}, yv^(-1)]^2*G[{yv^(-1)}, yw]*
       G[{yv^(-1), 1/(yu*yv)}, yw])/32 - 
     (G[{0}, yu^(-1)]*G[{1}, yw]*G[{yv^(-1)}, yw]*G[{yv^(-1), 1/(yu*yv)}, 
        yw])/8 - (G[{0}, yv^(-1)]*G[{1}, yw]*G[{yv^(-1)}, yw]*
       G[{yv^(-1), 1/(yu*yv)}, yw])/8 + 
     (G[{0}, yw]*G[{1}, yw]*G[{yv^(-1)}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw])/8 + 
     (G[{1}, yu^(-1)]*G[{1}, yw]*G[{yv^(-1)}, yw]*G[{yv^(-1), 1/(yu*yv)}, 
        yw])/8 - (3*G[{1}, yv^(-1)]*G[{1}, yw]*G[{yv^(-1)}, yw]*
       G[{yv^(-1), 1/(yu*yv)}, yw])/16 - (5*G[{1}, yw]^2*G[{yv^(-1)}, yw]*
       G[{yv^(-1), 1/(yu*yv)}, yw])/32 + (G[{0}, yu^(-1)]*G[{yu}, yv^(-1)]*
       G[{yv^(-1)}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw])/4 + 
     (G[{0}, yv^(-1)]*G[{yu}, yv^(-1)]*G[{yv^(-1)}, yw]*
       G[{yv^(-1), 1/(yu*yv)}, yw])/4 - (G[{0}, yw]*G[{yu}, yv^(-1)]*
       G[{yv^(-1)}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw])/4 - 
     (3*G[{1}, yu^(-1)]*G[{yu}, yv^(-1)]*G[{yv^(-1)}, yw]*
       G[{yv^(-1), 1/(yu*yv)}, yw])/8 + (5*G[{1}, yw]*G[{yu}, yv^(-1)]*
       G[{yv^(-1)}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw])/16 - 
     (G[{yu}, yv^(-1)]^2*G[{yv^(-1)}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw])/16 - 
     (G[{0}, yu^(-1)]*G[{yv^(-1)}, yw]^2*G[{yv^(-1), 1/(yu*yv)}, yw])/8 - 
     (G[{0}, yv^(-1)]*G[{yv^(-1)}, yw]^2*G[{yv^(-1), 1/(yu*yv)}, yw])/8 + 
     (G[{0}, yw]*G[{yv^(-1)}, yw]^2*G[{yv^(-1), 1/(yu*yv)}, yw])/8 + 
     (G[{1}, yu^(-1)]*G[{yv^(-1)}, yw]^2*G[{yv^(-1), 1/(yu*yv)}, yw])/16 - 
     (3*G[{1}, yw]*G[{yv^(-1)}, yw]^2*G[{yv^(-1), 1/(yu*yv)}, yw])/16 + 
     (3*G[{yu}, yv^(-1)]*G[{yv^(-1)}, yw]^2*G[{yv^(-1), 1/(yu*yv)}, yw])/16 - 
     (G[{yv^(-1)}, yw]^3*G[{yv^(-1), 1/(yu*yv)}, yw])/48 - 
     (G[{0}, yu^(-1)]*G[{1}, yv^(-1)]*G[{1/(yu*yv)}, yw]*
       G[{yv^(-1), 1/(yu*yv)}, yw])/16 - (G[{0}, yv^(-1)]*G[{1}, yv^(-1)]*
       G[{1/(yu*yv)}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw])/16 + 
     (G[{0}, yw]*G[{1}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{yv^(-1), 1/(yu*yv)}, 
        yw])/16 - (G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*G[{1/(yu*yv)}, yw]*
       G[{yv^(-1), 1/(yu*yv)}, yw])/16 + 
     (13*G[{1}, yv^(-1)]^2*G[{1/(yu*yv)}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw])/
      128 - (G[{1}, yu^(-1)]*G[{1}, yw]*G[{1/(yu*yv)}, yw]*
       G[{yv^(-1), 1/(yu*yv)}, yw])/16 + 
     (G[{1}, yv^(-1)]*G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{yv^(-1), 1/(yu*yv)}, 
        yw])/64 - (3*G[{1}, yw]^2*G[{1/(yu*yv)}, yw]*G[{yv^(-1), 1/(yu*yv)}, 
        yw])/128 + (G[{1}, yu^(-1)]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*
       G[{yv^(-1), 1/(yu*yv)}, yw])/16 - (3*G[{1}, yv^(-1)]*G[{yu^(-1)}, yw]*
       G[{1/(yu*yv)}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw])/32 - 
     (G[{1}, yw]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{yv^(-1), 1/(yu*yv)}, 
        yw])/32 + (3*G[{yu^(-1)}, yw]^2*G[{1/(yu*yv)}, yw]*
       G[{yv^(-1), 1/(yu*yv)}, yw])/64 + (G[{0}, yu^(-1)]*G[{yu}, yv^(-1)]*
       G[{1/(yu*yv)}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw])/16 + 
     (G[{0}, yv^(-1)]*G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw]*
       G[{yv^(-1), 1/(yu*yv)}, yw])/16 - 
     (G[{0}, yw]*G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{yv^(-1), 1/(yu*yv)}, 
        yw])/16 + (G[{1}, yu^(-1)]*G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw]*
       G[{yv^(-1), 1/(yu*yv)}, yw])/16 - (G[{1}, yv^(-1)]*G[{yu}, yv^(-1)]*
       G[{1/(yu*yv)}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw])/32 + 
     (3*G[{1}, yw]*G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw]*
       G[{yv^(-1), 1/(yu*yv)}, yw])/64 + (G[{yu^(-1)}, yw]*G[{yu}, yv^(-1)]*
       G[{1/(yu*yv)}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw])/32 - 
     (5*G[{yu}, yv^(-1)]^2*G[{1/(yu*yv)}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw])/
      64 - (G[{0}, yu^(-1)]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*
       G[{yv^(-1), 1/(yu*yv)}, yw])/16 - (G[{0}, yv^(-1)]*G[{yv^(-1)}, yw]*
       G[{1/(yu*yv)}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw])/16 + 
     (G[{0}, yw]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{yv^(-1), 1/(yu*yv)}, 
        yw])/16 + (G[{1}, yu^(-1)]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*
       G[{yv^(-1), 1/(yu*yv)}, yw])/8 + (G[{1}, yv^(-1)]*G[{yv^(-1)}, yw]*
       G[{1/(yu*yv)}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw])/16 + 
     (G[{1}, yw]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{yv^(-1), 1/(yu*yv)}, 
        yw])/16 - (G[{yu^(-1)}, yw]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*
       G[{yv^(-1), 1/(yu*yv)}, yw])/16 - (G[{yu}, yv^(-1)]*G[{yv^(-1)}, yw]*
       G[{1/(yu*yv)}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw])/16 - 
     (G[{yv^(-1)}, yw]^2*G[{1/(yu*yv)}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw])/16 + 
     (G[{0}, yu^(-1)]*G[{1/(yu*yv)}, yw]^2*G[{yv^(-1), 1/(yu*yv)}, yw])/16 + 
     (G[{0}, yv^(-1)]*G[{1/(yu*yv)}, yw]^2*G[{yv^(-1), 1/(yu*yv)}, yw])/16 - 
     (G[{0}, yw]*G[{1/(yu*yv)}, yw]^2*G[{yv^(-1), 1/(yu*yv)}, yw])/16 - 
     (G[{1}, yu^(-1)]*G[{1/(yu*yv)}, yw]^2*G[{yv^(-1), 1/(yu*yv)}, yw])/16 - 
     (7*G[{1}, yv^(-1)]*G[{1/(yu*yv)}, yw]^2*G[{yv^(-1), 1/(yu*yv)}, yw])/
      128 + (G[{1}, yw]*G[{1/(yu*yv)}, yw]^2*G[{yv^(-1), 1/(yu*yv)}, yw])/
      128 + (7*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2*G[{yv^(-1), 1/(yu*yv)}, 
        yw])/128 - (G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw]^2*
       G[{yv^(-1), 1/(yu*yv)}, yw])/128 + 
     (G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2*G[{yv^(-1), 1/(yu*yv)}, yw])/16 + 
     (G[{0}, yu^(-1)]*G[{0, 1}, yu^(-1)]*G[{yv^(-1), 1/(yu*yv)}, yw])/16 + 
     (G[{0}, yv^(-1)]*G[{0, 1}, yu^(-1)]*G[{yv^(-1), 1/(yu*yv)}, yw])/16 - 
     (G[{0}, yw]*G[{0, 1}, yu^(-1)]*G[{yv^(-1), 1/(yu*yv)}, yw])/16 - 
     (G[{1}, yu^(-1)]*G[{0, 1}, yu^(-1)]*G[{yv^(-1), 1/(yu*yv)}, yw])/16 - 
     (G[{1}, yv^(-1)]*G[{0, 1}, yu^(-1)]*G[{yv^(-1), 1/(yu*yv)}, yw])/16 + 
     (G[{1}, yw]*G[{0, 1}, yu^(-1)]*G[{yv^(-1), 1/(yu*yv)}, yw])/16 + 
     (G[{yv^(-1)}, yw]*G[{0, 1}, yu^(-1)]*G[{yv^(-1), 1/(yu*yv)}, yw])/8 - 
     (G[{1/(yu*yv)}, yw]*G[{0, 1}, yu^(-1)]*G[{yv^(-1), 1/(yu*yv)}, yw])/16 - 
     (G[{1}, yu^(-1)]*G[{0, 1}, yv^(-1)]*G[{yv^(-1), 1/(yu*yv)}, yw])/16 - 
     (G[{1}, yv^(-1)]*G[{0, 1}, yv^(-1)]*G[{yv^(-1), 1/(yu*yv)}, yw])/64 - 
     (5*G[{1}, yw]*G[{0, 1}, yv^(-1)]*G[{yv^(-1), 1/(yu*yv)}, yw])/64 + 
     (G[{yu}, yv^(-1)]*G[{0, 1}, yv^(-1)]*G[{yv^(-1), 1/(yu*yv)}, yw])/16 + 
     (G[{yv^(-1)}, yw]*G[{0, 1}, yv^(-1)]*G[{yv^(-1), 1/(yu*yv)}, yw])/16 - 
     (3*G[{1/(yu*yv)}, yw]*G[{0, 1}, yv^(-1)]*G[{yv^(-1), 1/(yu*yv)}, yw])/
      64 + (G[{1}, yv^(-1)]*G[{0, 1}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw])/8 + 
     (G[{1}, yw]*G[{0, 1}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw])/16 - 
     (G[{yu}, yv^(-1)]*G[{0, 1}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw])/8 + 
     (G[{yv^(-1)}, yw]*G[{0, 1}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw])/8 + 
     (G[{1/(yu*yv)}, yw]*G[{0, 1}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw])/16 - 
     (G[{1}, yv^(-1)]*G[{0, yu^(-1)}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw])/8 - 
     (G[{1}, yw]*G[{0, yu^(-1)}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw])/16 + 
     (G[{yu}, yv^(-1)]*G[{0, yu^(-1)}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw])/8 - 
     (G[{yv^(-1)}, yw]*G[{0, yu^(-1)}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw])/8 - 
     (G[{1/(yu*yv)}, yw]*G[{0, yu^(-1)}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw])/
      16 + (G[{1}, yu^(-1)]*G[{0, yu}, yv^(-1)]*G[{yv^(-1), 1/(yu*yv)}, yw])/
      16 + (G[{1}, yv^(-1)]*G[{0, yu}, yv^(-1)]*G[{yv^(-1), 1/(yu*yv)}, yw])/
      64 + (5*G[{1}, yw]*G[{0, yu}, yv^(-1)]*G[{yv^(-1), 1/(yu*yv)}, yw])/
      64 - (G[{yu}, yv^(-1)]*G[{0, yu}, yv^(-1)]*G[{yv^(-1), 1/(yu*yv)}, yw])/
      16 - (G[{yv^(-1)}, yw]*G[{0, yu}, yv^(-1)]*G[{yv^(-1), 1/(yu*yv)}, yw])/
      16 + (3*G[{1/(yu*yv)}, yw]*G[{0, yu}, yv^(-1)]*G[{yv^(-1), 1/(yu*yv)}, 
        yw])/64 - (G[{1}, yv^(-1)]*G[{0, yv^(-1)}, yw]*
       G[{yv^(-1), 1/(yu*yv)}, yw])/8 - (G[{1}, yw]*G[{0, yv^(-1)}, yw]*
       G[{yv^(-1), 1/(yu*yv)}, yw])/16 + 
     (G[{yu}, yv^(-1)]*G[{0, yv^(-1)}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw])/8 - 
     (G[{yv^(-1)}, yw]*G[{0, yv^(-1)}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw])/8 - 
     (G[{1/(yu*yv)}, yw]*G[{0, yv^(-1)}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw])/
      16 + (G[{1}, yv^(-1)]*G[{0, 1/(yu*yv)}, yw]*G[{yv^(-1), 1/(yu*yv)}, 
        yw])/8 + (G[{1}, yw]*G[{0, 1/(yu*yv)}, yw]*G[{yv^(-1), 1/(yu*yv)}, 
        yw])/16 - (G[{yu}, yv^(-1)]*G[{0, 1/(yu*yv)}, yw]*
       G[{yv^(-1), 1/(yu*yv)}, yw])/8 + 
     (G[{yv^(-1)}, yw]*G[{0, 1/(yu*yv)}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw])/8 + 
     (G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv)}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw])/
      16 - (G[{1}, yu^(-1)]*G[{1, yu^(-1)}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw])/
      16 + (3*G[{1}, yv^(-1)]*G[{1, yu^(-1)}, yw]*G[{yv^(-1), 1/(yu*yv)}, 
        yw])/32 + (G[{1}, yw]*G[{1, yu^(-1)}, yw]*G[{yv^(-1), 1/(yu*yv)}, 
        yw])/32 - (G[{yu}, yv^(-1)]*G[{1, yu^(-1)}, yw]*
       G[{yv^(-1), 1/(yu*yv)}, yw])/32 + 
     (3*G[{yv^(-1)}, yw]*G[{1, yu^(-1)}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw])/
      16 + (G[{1/(yu*yv)}, yw]*G[{1, yu^(-1)}, yw]*G[{yv^(-1), 1/(yu*yv)}, 
        yw])/64 - (G[{0}, yu^(-1)]*G[{1, yu}, yv^(-1)]*
       G[{yv^(-1), 1/(yu*yv)}, yw])/16 - (G[{0}, yv^(-1)]*G[{1, yu}, yv^(-1)]*
       G[{yv^(-1), 1/(yu*yv)}, yw])/16 + (G[{0}, yw]*G[{1, yu}, yv^(-1)]*
       G[{yv^(-1), 1/(yu*yv)}, yw])/16 - (G[{1}, yv^(-1)]*G[{1, yu}, yv^(-1)]*
       G[{yv^(-1), 1/(yu*yv)}, yw])/32 - (9*G[{1}, yw]*G[{1, yu}, yv^(-1)]*
       G[{yv^(-1), 1/(yu*yv)}, yw])/64 + 
     (G[{yu}, yv^(-1)]*G[{1, yu}, yv^(-1)]*G[{yv^(-1), 1/(yu*yv)}, yw])/16 - 
     (G[{yv^(-1)}, yw]*G[{1, yu}, yv^(-1)]*G[{yv^(-1), 1/(yu*yv)}, yw])/16 + 
     (G[{1/(yu*yv)}, yw]*G[{1, yu}, yv^(-1)]*G[{yv^(-1), 1/(yu*yv)}, yw])/
      64 + (G[{0}, yu^(-1)]*G[{1, yv^(-1)}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw])/
      16 + (G[{0}, yv^(-1)]*G[{1, yv^(-1)}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw])/
      16 - (G[{0}, yw]*G[{1, yv^(-1)}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw])/16 - 
     (G[{1}, yu^(-1)]*G[{1, yv^(-1)}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw])/16 + 
     (G[{1}, yv^(-1)]*G[{1, yv^(-1)}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw])/8 + 
     (3*G[{1}, yw]*G[{1, yv^(-1)}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw])/16 - 
     (3*G[{yu}, yv^(-1)]*G[{1, yv^(-1)}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw])/
      16 + (G[{yv^(-1)}, yw]*G[{1, yv^(-1)}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw])/
      4 - (G[{0}, yu^(-1)]*G[{1, 1/(yu*yv)}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw])/
      16 - (G[{0}, yv^(-1)]*G[{1, 1/(yu*yv)}, yw]*G[{yv^(-1), 1/(yu*yv)}, 
        yw])/16 + (G[{0}, yw]*G[{1, 1/(yu*yv)}, yw]*G[{yv^(-1), 1/(yu*yv)}, 
        yw])/16 + (G[{1}, yu^(-1)]*G[{1, 1/(yu*yv)}, yw]*
       G[{yv^(-1), 1/(yu*yv)}, yw])/8 + 
     (G[{1}, yv^(-1)]*G[{1, 1/(yu*yv)}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw])/32 + 
     (G[{1}, yw]*G[{1, 1/(yu*yv)}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw])/32 - 
     (G[{yu}, yv^(-1)]*G[{1, 1/(yu*yv)}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw])/
      32 - (3*G[{yv^(-1)}, yw]*G[{1, 1/(yu*yv)}, yw]*G[{yv^(-1), 1/(yu*yv)}, 
        yw])/16 + (7*G[{1/(yu*yv)}, yw]*G[{1, 1/(yu*yv)}, yw]*
       G[{yv^(-1), 1/(yu*yv)}, yw])/64 - 
     (G[{1}, yu^(-1)]*G[{yu^(-1), 1/(yu*yv)}, yw]*G[{yv^(-1), 1/(yu*yv)}, 
        yw])/16 - (5*G[{1}, yv^(-1)]*G[{yu^(-1), 1/(yu*yv)}, yw]*
       G[{yv^(-1), 1/(yu*yv)}, yw])/32 - 
     (7*G[{1}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw])/
      32 + (5*G[{yu^(-1)}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw]*
       G[{yv^(-1), 1/(yu*yv)}, yw])/32 + 
     (7*G[{yu}, yv^(-1)]*G[{yu^(-1), 1/(yu*yv)}, yw]*G[{yv^(-1), 1/(yu*yv)}, 
        yw])/32 - (G[{yv^(-1)}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw]*
       G[{yv^(-1), 1/(yu*yv)}, yw])/16 - 
     (7*G[{1/(yu*yv)}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw]*
       G[{yv^(-1), 1/(yu*yv)}, yw])/64 + 
     (G[{0}, yu^(-1)]*G[{yv^(-1), 1/(yu*yv)}, yw]^2)/32 + 
     (G[{0}, yv^(-1)]*G[{yv^(-1), 1/(yu*yv)}, yw]^2)/32 - 
     (G[{0}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw]^2)/32 - 
     (G[{1}, yu^(-1)]*G[{yv^(-1), 1/(yu*yv)}, yw]^2)/32 - 
     (G[{1}, yv^(-1)]*G[{yv^(-1), 1/(yu*yv)}, yw]^2)/16 - 
     (G[{1}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw]^2)/32 + 
     (G[{yu^(-1)}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw]^2)/16 + 
     (G[{yu}, yv^(-1)]*G[{yv^(-1), 1/(yu*yv)}, yw]^2)/32 + 
     (G[{yv^(-1)}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw]^2)/32 - 
     (G[{1/(yu*yv)}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw]^2)/16 - 
     (Pi^2*G[{0, 0, 1}, yu^(-1)])/96 + 
     (G[{1}, yu^(-1)]^2*G[{0, 0, 1}, yu^(-1)])/32 - 
     (G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*G[{0, 0, 1}, yu^(-1)])/16 + 
     (G[{1}, yv^(-1)]^2*G[{0, 0, 1}, yu^(-1)])/32 - 
     (G[{0}, yu^(-1)]*G[{1}, yw]*G[{0, 0, 1}, yu^(-1)])/8 - 
     (G[{0}, yv^(-1)]*G[{1}, yw]*G[{0, 0, 1}, yu^(-1)])/8 + 
     (G[{0}, yw]*G[{1}, yw]*G[{0, 0, 1}, yu^(-1)])/8 + 
     (G[{1}, yu^(-1)]*G[{1}, yw]*G[{0, 0, 1}, yu^(-1)])/16 + 
     (G[{1}, yv^(-1)]*G[{1}, yw]*G[{0, 0, 1}, yu^(-1)])/16 - 
     (G[{1}, yw]^2*G[{0, 0, 1}, yu^(-1)])/16 + 
     (G[{1}, yw]*G[{yu}, yv^(-1)]*G[{0, 0, 1}, yu^(-1)])/8 + 
     (G[{0}, yu^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, 0, 1}, yu^(-1)])/8 + 
     (G[{0}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, 0, 1}, yu^(-1)])/8 - 
     (G[{0}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 0, 1}, yu^(-1)])/8 - 
     (G[{1}, yu^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, 0, 1}, yu^(-1)])/16 - 
     (G[{1}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, 0, 1}, yu^(-1)])/16 + 
     (G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 0, 1}, yu^(-1)])/8 + 
     (G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 0, 1}, yu^(-1)])/16 - 
     (G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, 0, 1}, yu^(-1)])/8 + 
     (G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 0, 1}, yu^(-1)])/16 - 
     (G[{0, 1}, yu^(-1)]*G[{0, 0, 1}, yu^(-1)])/16 - 
     (G[{0, 1}, yv^(-1)]*G[{0, 0, 1}, yu^(-1)])/16 - 
     (G[{0, 1}, yw]*G[{0, 0, 1}, yu^(-1)])/8 - 
     (G[{0, yu}, yv^(-1)]*G[{0, 0, 1}, yu^(-1)])/16 + 
     (G[{0, 1/(yu*yv)}, yw]*G[{0, 0, 1}, yu^(-1)])/8 - 
     (G[{1, yu^(-1)}, yw]*G[{0, 0, 1}, yu^(-1)])/16 - 
     (G[{1, yv^(-1)}, yw]*G[{0, 0, 1}, yu^(-1)])/16 - 
     (G[{1, 1/(yu*yv)}, yw]*G[{0, 0, 1}, yu^(-1)])/8 - 
     (G[{yu^(-1), 1/(yu*yv)}, yw]*G[{0, 0, 1}, yu^(-1)])/16 - 
     (G[{yv^(-1), 1/(yu*yv)}, yw]*G[{0, 0, 1}, yu^(-1)])/16 + 
     (13*Pi^2*G[{0, 0, 1}, yv^(-1)])/768 + 
     (3*G[{1}, yu^(-1)]^2*G[{0, 0, 1}, yv^(-1)])/128 + 
     (G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*G[{0, 0, 1}, yv^(-1)])/64 - 
     (G[{1}, yv^(-1)]^2*G[{0, 0, 1}, yv^(-1)])/64 + 
     (G[{0}, yu^(-1)]*G[{1}, yw]*G[{0, 0, 1}, yv^(-1)])/16 + 
     (G[{0}, yv^(-1)]*G[{1}, yw]*G[{0, 0, 1}, yv^(-1)])/16 - 
     (G[{0}, yw]*G[{1}, yw]*G[{0, 0, 1}, yv^(-1)])/16 - 
     (G[{1}, yu^(-1)]*G[{1}, yw]*G[{0, 0, 1}, yv^(-1)])/64 - 
     (G[{1}, yv^(-1)]*G[{1}, yw]*G[{0, 0, 1}, yv^(-1)])/32 + 
     (5*G[{1}, yw]^2*G[{0, 0, 1}, yv^(-1)])/128 - 
     (5*G[{1}, yw]*G[{yu}, yv^(-1)]*G[{0, 0, 1}, yv^(-1)])/64 - 
     (G[{0}, yu^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, 0, 1}, yv^(-1)])/16 - 
     (G[{0}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, 0, 1}, yv^(-1)])/16 + 
     (G[{0}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 0, 1}, yv^(-1)])/16 + 
     (G[{1}, yu^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, 0, 1}, yv^(-1)])/64 + 
     (G[{1}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, 0, 1}, yv^(-1)])/32 - 
     (5*G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 0, 1}, yv^(-1)])/64 - 
     (G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 0, 1}, yv^(-1)])/32 + 
     (5*G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, 0, 1}, yv^(-1)])/64 - 
     (G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 0, 1}, yv^(-1)])/64 + 
     (G[{0, 1}, yu^(-1)]*G[{0, 0, 1}, yv^(-1)])/64 + 
     (G[{0, 1}, yv^(-1)]*G[{0, 0, 1}, yv^(-1)])/32 + 
     (G[{0, 1}, yw]*G[{0, 0, 1}, yv^(-1)])/16 + 
     (G[{0, yu}, yv^(-1)]*G[{0, 0, 1}, yv^(-1)])/32 - 
     (G[{0, 1/(yu*yv)}, yw]*G[{0, 0, 1}, yv^(-1)])/16 + 
     (G[{1, yu^(-1)}, yw]*G[{0, 0, 1}, yv^(-1)])/32 + 
     (G[{1, yu}, yv^(-1)]*G[{0, 0, 1}, yv^(-1)])/64 + 
     (G[{1, yv^(-1)}, yw]*G[{0, 0, 1}, yv^(-1)])/64 + 
     (5*G[{1, 1/(yu*yv)}, yw]*G[{0, 0, 1}, yv^(-1)])/64 + 
     (G[{yu^(-1), 1/(yu*yv)}, yw]*G[{0, 0, 1}, yv^(-1)])/32 + 
     (G[{yv^(-1), 1/(yu*yv)}, yw]*G[{0, 0, 1}, yv^(-1)])/64 - 
     (Pi^2*G[{0, 0, 1}, yw])/96 - (G[{0}, yu^(-1)]*G[{1}, yw]*
       G[{0, 0, 1}, yw])/16 - (G[{0}, yv^(-1)]*G[{1}, yw]*G[{0, 0, 1}, yw])/
      16 + (G[{0}, yw]*G[{1}, yw]*G[{0, 0, 1}, yw])/16 + 
     (3*G[{1}, yu^(-1)]*G[{1}, yw]*G[{0, 0, 1}, yw])/16 - 
     (3*G[{1}, yv^(-1)]*G[{1}, yw]*G[{0, 0, 1}, yw])/16 - 
     (G[{1}, yw]^2*G[{0, 0, 1}, yw])/8 + 
     (G[{1}, yw]*G[{yu}, yv^(-1)]*G[{0, 0, 1}, yw])/8 + 
     (G[{0}, yu^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, 0, 1}, yw])/16 + 
     (G[{0}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, 0, 1}, yw])/16 - 
     (G[{0}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 0, 1}, yw])/16 - 
     (3*G[{1}, yu^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, 0, 1}, yw])/16 + 
     (3*G[{1}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, 0, 1}, yw])/16 + 
     (G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 0, 1}, yw])/4 - 
     (5*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 0, 1}, yw])/16 - 
     (G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, 0, 1}, yw])/8 + 
     (G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 0, 1}, yw])/16 - 
     (G[{0, 1}, yu^(-1)]*G[{0, 0, 1}, yw])/16 - 
     (G[{0, 1}, yv^(-1)]*G[{0, 0, 1}, yw])/16 - 
     (G[{0, 1}, yw]*G[{0, 0, 1}, yw])/16 + 
     (G[{0, yu}, yv^(-1)]*G[{0, 0, 1}, yw])/16 + 
     (G[{0, 1/(yu*yv)}, yw]*G[{0, 0, 1}, yw])/16 + 
     (5*G[{1, yu^(-1)}, yw]*G[{0, 0, 1}, yw])/16 - 
     (G[{1, yv^(-1)}, yw]*G[{0, 0, 1}, yw])/16 - 
     (G[{1, 1/(yu*yv)}, yw]*G[{0, 0, 1}, yw])/4 + 
     (5*G[{yu^(-1), 1/(yu*yv)}, yw]*G[{0, 0, 1}, yw])/16 - 
     (G[{yv^(-1), 1/(yu*yv)}, yw]*G[{0, 0, 1}, yw])/16 + 
     (G[{0}, yu^(-1)]*G[{1}, yw]*G[{0, 0, yu^(-1)}, yw])/16 + 
     (G[{0}, yv^(-1)]*G[{1}, yw]*G[{0, 0, yu^(-1)}, yw])/16 - 
     (G[{0}, yw]*G[{1}, yw]*G[{0, 0, yu^(-1)}, yw])/16 - 
     (3*G[{1}, yu^(-1)]*G[{1}, yw]*G[{0, 0, yu^(-1)}, yw])/16 + 
     (5*G[{1}, yv^(-1)]*G[{1}, yw]*G[{0, 0, yu^(-1)}, yw])/16 + 
     (G[{1}, yw]^2*G[{0, 0, yu^(-1)}, yw])/8 - 
     (G[{1}, yw]*G[{yu}, yv^(-1)]*G[{0, 0, yu^(-1)}, yw])/4 - 
     (G[{0}, yu^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, 0, yu^(-1)}, yw])/16 - 
     (G[{0}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, 0, yu^(-1)}, yw])/16 + 
     (G[{0}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 0, yu^(-1)}, yw])/16 + 
     (3*G[{1}, yu^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, 0, yu^(-1)}, yw])/16 - 
     (5*G[{1}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, 0, yu^(-1)}, yw])/16 - 
     (G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 0, yu^(-1)}, yw])/4 + 
     (5*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 0, yu^(-1)}, yw])/16 + 
     (G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, 0, yu^(-1)}, yw])/4 - 
     (G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 0, yu^(-1)}, yw])/16 + 
     (G[{0, 1}, yw]*G[{0, 0, yu^(-1)}, yw])/16 - 
     (G[{0, 1/(yu*yv)}, yw]*G[{0, 0, yu^(-1)}, yw])/16 - 
     (5*G[{1, yu^(-1)}, yw]*G[{0, 0, yu^(-1)}, yw])/16 + 
     (G[{1, yv^(-1)}, yw]*G[{0, 0, yu^(-1)}, yw])/16 + 
     (G[{1, 1/(yu*yv)}, yw]*G[{0, 0, yu^(-1)}, yw])/4 - 
     (5*G[{yu^(-1), 1/(yu*yv)}, yw]*G[{0, 0, yu^(-1)}, yw])/16 + 
     (G[{yv^(-1), 1/(yu*yv)}, yw]*G[{0, 0, yu^(-1)}, yw])/16 - 
     (5*Pi^2*G[{0, 0, yu}, yv^(-1)])/768 - 
     (3*G[{1}, yu^(-1)]^2*G[{0, 0, yu}, yv^(-1)])/128 - 
     (G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*G[{0, 0, yu}, yv^(-1)])/64 + 
     (G[{1}, yv^(-1)]^2*G[{0, 0, yu}, yv^(-1)])/64 - 
     (G[{0}, yu^(-1)]*G[{1}, yw]*G[{0, 0, yu}, yv^(-1)])/16 - 
     (G[{0}, yv^(-1)]*G[{1}, yw]*G[{0, 0, yu}, yv^(-1)])/16 + 
     (G[{0}, yw]*G[{1}, yw]*G[{0, 0, yu}, yv^(-1)])/16 + 
     (G[{1}, yu^(-1)]*G[{1}, yw]*G[{0, 0, yu}, yv^(-1)])/64 + 
     (G[{1}, yv^(-1)]*G[{1}, yw]*G[{0, 0, yu}, yv^(-1)])/32 - 
     (5*G[{1}, yw]^2*G[{0, 0, yu}, yv^(-1)])/128 + 
     (5*G[{1}, yw]*G[{yu}, yv^(-1)]*G[{0, 0, yu}, yv^(-1)])/64 + 
     (G[{0}, yu^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, 0, yu}, yv^(-1)])/16 + 
     (G[{0}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, 0, yu}, yv^(-1)])/16 - 
     (G[{0}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 0, yu}, yv^(-1)])/16 - 
     (G[{1}, yu^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, 0, yu}, yv^(-1)])/64 - 
     (G[{1}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, 0, yu}, yv^(-1)])/32 + 
     (5*G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 0, yu}, yv^(-1)])/64 + 
     (G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 0, yu}, yv^(-1)])/32 - 
     (5*G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, 0, yu}, yv^(-1)])/64 + 
     (G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 0, yu}, yv^(-1)])/64 + 
     (3*G[{0, 1}, yu^(-1)]*G[{0, 0, yu}, yv^(-1)])/64 - 
     (G[{0, 1}, yv^(-1)]*G[{0, 0, yu}, yv^(-1)])/32 - 
     (G[{0, 1}, yw]*G[{0, 0, yu}, yv^(-1)])/16 - 
     (G[{0, yu}, yv^(-1)]*G[{0, 0, yu}, yv^(-1)])/32 + 
     (G[{0, 1/(yu*yv)}, yw]*G[{0, 0, yu}, yv^(-1)])/16 - 
     (G[{1, yu^(-1)}, yw]*G[{0, 0, yu}, yv^(-1)])/32 - 
     (G[{1, yu}, yv^(-1)]*G[{0, 0, yu}, yv^(-1)])/64 - 
     (G[{1, yv^(-1)}, yw]*G[{0, 0, yu}, yv^(-1)])/64 - 
     (5*G[{1, 1/(yu*yv)}, yw]*G[{0, 0, yu}, yv^(-1)])/64 - 
     (G[{yu^(-1), 1/(yu*yv)}, yw]*G[{0, 0, yu}, yv^(-1)])/32 - 
     (G[{yv^(-1), 1/(yu*yv)}, yw]*G[{0, 0, yu}, yv^(-1)])/64 + 
     (G[{0}, yu^(-1)]*G[{1}, yw]*G[{0, 0, yv^(-1)}, yw])/16 + 
     (G[{0}, yv^(-1)]*G[{1}, yw]*G[{0, 0, yv^(-1)}, yw])/16 - 
     (G[{0}, yw]*G[{1}, yw]*G[{0, 0, yv^(-1)}, yw])/16 - 
     (G[{1}, yu^(-1)]*G[{1}, yw]*G[{0, 0, yv^(-1)}, yw])/16 + 
     (3*G[{1}, yv^(-1)]*G[{1}, yw]*G[{0, 0, yv^(-1)}, yw])/16 + 
     (G[{1}, yw]^2*G[{0, 0, yv^(-1)}, yw])/8 - 
     (G[{1}, yw]*G[{yu}, yv^(-1)]*G[{0, 0, yv^(-1)}, yw])/4 - 
     (G[{0}, yu^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, 0, yv^(-1)}, yw])/16 - 
     (G[{0}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, 0, yv^(-1)}, yw])/16 + 
     (G[{0}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 0, yv^(-1)}, yw])/16 + 
     (G[{1}, yu^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, 0, yv^(-1)}, yw])/16 - 
     (3*G[{1}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, 0, yv^(-1)}, yw])/16 - 
     (G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 0, yv^(-1)}, yw])/4 + 
     (5*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 0, yv^(-1)}, yw])/16 + 
     (G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, 0, yv^(-1)}, yw])/4 - 
     (G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 0, yv^(-1)}, yw])/16 + 
     (G[{0, 1}, yw]*G[{0, 0, yv^(-1)}, yw])/16 - 
     (G[{0, 1/(yu*yv)}, yw]*G[{0, 0, yv^(-1)}, yw])/16 - 
     (5*G[{1, yu^(-1)}, yw]*G[{0, 0, yv^(-1)}, yw])/16 + 
     (G[{1, yv^(-1)}, yw]*G[{0, 0, yv^(-1)}, yw])/16 + 
     (G[{1, 1/(yu*yv)}, yw]*G[{0, 0, yv^(-1)}, yw])/4 - 
     (5*G[{yu^(-1), 1/(yu*yv)}, yw]*G[{0, 0, yv^(-1)}, yw])/16 + 
     (G[{yv^(-1), 1/(yu*yv)}, yw]*G[{0, 0, yv^(-1)}, yw])/16 + 
     (Pi^2*G[{0, 0, 1/(yu*yv)}, yw])/96 - 
     (G[{0}, yu^(-1)]*G[{1}, yw]*G[{0, 0, 1/(yu*yv)}, yw])/16 - 
     (G[{0}, yv^(-1)]*G[{1}, yw]*G[{0, 0, 1/(yu*yv)}, yw])/16 + 
     (G[{0}, yw]*G[{1}, yw]*G[{0, 0, 1/(yu*yv)}, yw])/16 + 
     (G[{1}, yu^(-1)]*G[{1}, yw]*G[{0, 0, 1/(yu*yv)}, yw])/16 - 
     (5*G[{1}, yv^(-1)]*G[{1}, yw]*G[{0, 0, 1/(yu*yv)}, yw])/16 - 
     (G[{1}, yw]^2*G[{0, 0, 1/(yu*yv)}, yw])/8 + 
     (3*G[{1}, yw]*G[{yu}, yv^(-1)]*G[{0, 0, 1/(yu*yv)}, yw])/8 + 
     (G[{0}, yu^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, 0, 1/(yu*yv)}, yw])/16 + 
     (G[{0}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, 0, 1/(yu*yv)}, yw])/16 - 
     (G[{0}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 0, 1/(yu*yv)}, yw])/16 - 
     (G[{1}, yu^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, 0, 1/(yu*yv)}, yw])/16 + 
     (5*G[{1}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, 0, 1/(yu*yv)}, yw])/16 + 
     (G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 0, 1/(yu*yv)}, yw])/4 - 
     (5*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 0, 1/(yu*yv)}, yw])/16 - 
     (3*G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, 0, 1/(yu*yv)}, yw])/8 + 
     (G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 0, 1/(yu*yv)}, yw])/16 + 
     (G[{0, 1}, yu^(-1)]*G[{0, 0, 1/(yu*yv)}, yw])/16 + 
     (G[{0, 1}, yv^(-1)]*G[{0, 0, 1/(yu*yv)}, yw])/16 - 
     (G[{0, 1}, yw]*G[{0, 0, 1/(yu*yv)}, yw])/16 - 
     (G[{0, yu}, yv^(-1)]*G[{0, 0, 1/(yu*yv)}, yw])/16 + 
     (G[{0, 1/(yu*yv)}, yw]*G[{0, 0, 1/(yu*yv)}, yw])/16 + 
     (5*G[{1, yu^(-1)}, yw]*G[{0, 0, 1/(yu*yv)}, yw])/16 - 
     (G[{1, yv^(-1)}, yw]*G[{0, 0, 1/(yu*yv)}, yw])/16 - 
     (G[{1, 1/(yu*yv)}, yw]*G[{0, 0, 1/(yu*yv)}, yw])/4 + 
     (5*G[{yu^(-1), 1/(yu*yv)}, yw]*G[{0, 0, 1/(yu*yv)}, yw])/16 - 
     (G[{yv^(-1), 1/(yu*yv)}, yw]*G[{0, 0, 1/(yu*yv)}, yw])/16 - 
     (Pi^2*G[{0, 1, 1}, yu^(-1)])/96 + 
     (G[{1}, yu^(-1)]^2*G[{0, 1, 1}, yu^(-1)])/16 - 
     (G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*G[{0, 1, 1}, yu^(-1)])/8 + 
     (G[{1}, yv^(-1)]^2*G[{0, 1, 1}, yu^(-1)])/16 + 
     (G[{1}, yv^(-1)]*G[{1}, yw]*G[{0, 1, 1}, yu^(-1)])/8 - 
     (G[{1}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, 1, 1}, yu^(-1)])/8 + 
     (G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1, 1}, yu^(-1)])/8 - 
     (G[{0, yu}, yv^(-1)]*G[{0, 1, 1}, yu^(-1)])/8 - 
     (G[{1, yu^(-1)}, yw]*G[{0, 1, 1}, yu^(-1)])/8 - 
     (G[{yu^(-1), 1/(yu*yv)}, yw]*G[{0, 1, 1}, yu^(-1)])/8 + 
     (Pi^2*G[{0, 1, 1}, yv^(-1)])/192 - 
     (3*G[{1}, yu^(-1)]^2*G[{0, 1, 1}, yv^(-1)])/128 + 
     (3*G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*G[{0, 1, 1}, yv^(-1)])/64 - 
     (G[{1}, yv^(-1)]^2*G[{0, 1, 1}, yv^(-1)])/8 + 
     (3*G[{0}, yu^(-1)]*G[{1}, yw]*G[{0, 1, 1}, yv^(-1)])/16 + 
     (3*G[{0}, yv^(-1)]*G[{1}, yw]*G[{0, 1, 1}, yv^(-1)])/16 - 
     (3*G[{0}, yw]*G[{1}, yw]*G[{0, 1, 1}, yv^(-1)])/16 + 
     (G[{1}, yu^(-1)]*G[{1}, yw]*G[{0, 1, 1}, yv^(-1)])/64 + 
     (17*G[{1}, yw]^2*G[{0, 1, 1}, yv^(-1)])/128 - 
     (11*G[{1}, yw]*G[{yu}, yv^(-1)]*G[{0, 1, 1}, yv^(-1)])/64 - 
     (3*G[{0}, yu^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, 1, 1}, yv^(-1)])/16 - 
     (3*G[{0}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, 1, 1}, yv^(-1)])/16 + 
     (3*G[{0}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1, 1}, yv^(-1)])/16 - 
     (G[{1}, yu^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, 1, 1}, yv^(-1)])/64 - 
     (17*G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1, 1}, yv^(-1)])/64 - 
     (3*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1, 1}, yv^(-1)])/32 + 
     (11*G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, 1, 1}, yv^(-1)])/64 + 
     (G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1, 1}, yv^(-1)])/64 + 
     (3*G[{1/(yu*yv)}, yw]^2*G[{0, 1, 1}, yv^(-1)])/64 - 
     (G[{0, 1}, yu^(-1)]*G[{0, 1, 1}, yv^(-1)])/64 - 
     (3*G[{0, 1}, yv^(-1)]*G[{0, 1, 1}, yv^(-1)])/64 + 
     (3*G[{0, 1}, yw]*G[{0, 1, 1}, yv^(-1)])/16 - 
     (G[{0, yu}, yv^(-1)]*G[{0, 1, 1}, yv^(-1)])/32 - 
     (3*G[{0, 1/(yu*yv)}, yw]*G[{0, 1, 1}, yv^(-1)])/16 + 
     (3*G[{1, yu^(-1)}, yw]*G[{0, 1, 1}, yv^(-1)])/32 - 
     (G[{1, yu}, yv^(-1)]*G[{0, 1, 1}, yv^(-1)])/64 - 
     (G[{1, yv^(-1)}, yw]*G[{0, 1, 1}, yv^(-1)])/64 + 
     (11*G[{1, 1/(yu*yv)}, yw]*G[{0, 1, 1}, yv^(-1)])/64 + 
     (3*G[{yu^(-1), 1/(yu*yv)}, yw]*G[{0, 1, 1}, yv^(-1)])/32 - 
     (G[{yv^(-1), 1/(yu*yv)}, yw]*G[{0, 1, 1}, yv^(-1)])/64 - 
     (Pi^2*G[{0, 1, 1}, yw])/24 + (G[{0}, yu^(-1)]^2*G[{0, 1, 1}, yw])/16 + 
     (G[{0}, yu^(-1)]*G[{0}, yv^(-1)]*G[{0, 1, 1}, yw])/8 + 
     (G[{0}, yv^(-1)]^2*G[{0, 1, 1}, yw])/16 - 
     (G[{0}, yu^(-1)]*G[{0}, yw]*G[{0, 1, 1}, yw])/8 - 
     (G[{0}, yv^(-1)]*G[{0}, yw]*G[{0, 1, 1}, yw])/8 + 
     (G[{0}, yw]^2*G[{0, 1, 1}, yw])/16 - 
     (3*G[{0}, yu^(-1)]*G[{1}, yu^(-1)]*G[{0, 1, 1}, yw])/16 - 
     (3*G[{0}, yv^(-1)]*G[{1}, yu^(-1)]*G[{0, 1, 1}, yw])/16 + 
     (3*G[{0}, yw]*G[{1}, yu^(-1)]*G[{0, 1, 1}, yw])/16 + 
     (G[{1}, yu^(-1)]^2*G[{0, 1, 1}, yw])/8 + 
     (3*G[{0}, yu^(-1)]*G[{1}, yv^(-1)]*G[{0, 1, 1}, yw])/16 + 
     (3*G[{0}, yv^(-1)]*G[{1}, yv^(-1)]*G[{0, 1, 1}, yw])/16 - 
     (3*G[{0}, yw]*G[{1}, yv^(-1)]*G[{0, 1, 1}, yw])/16 - 
     (5*G[{1}, yv^(-1)]^2*G[{0, 1, 1}, yw])/32 + 
     (G[{0}, yu^(-1)]*G[{1}, yw]*G[{0, 1, 1}, yw])/8 + 
     (G[{0}, yv^(-1)]*G[{1}, yw]*G[{0, 1, 1}, yw])/8 - 
     (G[{0}, yw]*G[{1}, yw]*G[{0, 1, 1}, yw])/8 - 
     (G[{1}, yu^(-1)]*G[{1}, yw]*G[{0, 1, 1}, yw])/16 - 
     (G[{1}, yv^(-1)]*G[{1}, yw]*G[{0, 1, 1}, yw])/16 - 
     (G[{0}, yu^(-1)]*G[{yu}, yv^(-1)]*G[{0, 1, 1}, yw])/4 - 
     (G[{0}, yv^(-1)]*G[{yu}, yv^(-1)]*G[{0, 1, 1}, yw])/4 + 
     (G[{0}, yw]*G[{yu}, yv^(-1)]*G[{0, 1, 1}, yw])/4 + 
     (G[{1}, yu^(-1)]*G[{yu}, yv^(-1)]*G[{0, 1, 1}, yw])/8 + 
     (G[{1}, yv^(-1)]*G[{yu}, yv^(-1)]*G[{0, 1, 1}, yw])/8 - 
     (G[{1}, yw]*G[{yu}, yv^(-1)]*G[{0, 1, 1}, yw])/8 + 
     (G[{yu}, yv^(-1)]^2*G[{0, 1, 1}, yw])/8 - 
     (G[{0}, yu^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, 1, 1}, yw])/8 - 
     (G[{0}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, 1, 1}, yw])/8 + 
     (G[{0}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1, 1}, yw])/8 + 
     (G[{1}, yu^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, 1, 1}, yw])/16 + 
     (G[{1}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, 1, 1}, yw])/16 - 
     (G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1, 1}, yw])/16 + 
     (G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, 1, 1}, yw])/8 - 
     (G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1, 1}, yw])/16 - 
     (3*G[{0, 1}, yv^(-1)]*G[{0, 1, 1}, yw])/16 + 
     (3*G[{0, yu}, yv^(-1)]*G[{0, 1, 1}, yw])/16 + 
     (G[{1, yu^(-1)}, yw]*G[{0, 1, 1}, yw])/16 - 
     (3*G[{1, yu}, yv^(-1)]*G[{0, 1, 1}, yw])/16 + 
     (G[{1, yv^(-1)}, yw]*G[{0, 1, 1}, yw])/16 + 
     (G[{yu^(-1), 1/(yu*yv)}, yw]*G[{0, 1, 1}, yw])/16 + 
     (G[{yv^(-1), 1/(yu*yv)}, yw]*G[{0, 1, 1}, yw])/16 + 
     (Pi^2*G[{0, 1, yu^(-1)}, yw])/32 - 
     (G[{0}, yu^(-1)]^2*G[{0, 1, yu^(-1)}, yw])/32 - 
     (G[{0}, yu^(-1)]*G[{0}, yv^(-1)]*G[{0, 1, yu^(-1)}, yw])/16 - 
     (G[{0}, yv^(-1)]^2*G[{0, 1, yu^(-1)}, yw])/32 + 
     (G[{0}, yu^(-1)]*G[{0}, yw]*G[{0, 1, yu^(-1)}, yw])/16 + 
     (G[{0}, yv^(-1)]*G[{0}, yw]*G[{0, 1, yu^(-1)}, yw])/16 - 
     (G[{0}, yw]^2*G[{0, 1, yu^(-1)}, yw])/32 + 
     (G[{0}, yu^(-1)]*G[{1}, yu^(-1)]*G[{0, 1, yu^(-1)}, yw])/16 + 
     (G[{0}, yv^(-1)]*G[{1}, yu^(-1)]*G[{0, 1, yu^(-1)}, yw])/16 - 
     (G[{0}, yw]*G[{1}, yu^(-1)]*G[{0, 1, yu^(-1)}, yw])/16 - 
     (G[{1}, yu^(-1)]^2*G[{0, 1, yu^(-1)}, yw])/32 - 
     (G[{0}, yu^(-1)]*G[{1}, yv^(-1)]*G[{0, 1, yu^(-1)}, yw])/16 - 
     (G[{0}, yv^(-1)]*G[{1}, yv^(-1)]*G[{0, 1, yu^(-1)}, yw])/16 + 
     (G[{0}, yw]*G[{1}, yv^(-1)]*G[{0, 1, yu^(-1)}, yw])/16 - 
     (G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*G[{0, 1, yu^(-1)}, yw])/16 + 
     (3*G[{1}, yv^(-1)]^2*G[{0, 1, yu^(-1)}, yw])/16 - 
     (3*G[{0}, yu^(-1)]*G[{1}, yw]*G[{0, 1, yu^(-1)}, yw])/16 - 
     (3*G[{0}, yv^(-1)]*G[{1}, yw]*G[{0, 1, yu^(-1)}, yw])/16 + 
     (3*G[{0}, yw]*G[{1}, yw]*G[{0, 1, yu^(-1)}, yw])/16 + 
     (G[{1}, yu^(-1)]*G[{1}, yw]*G[{0, 1, yu^(-1)}, yw])/4 - 
     (G[{1}, yv^(-1)]*G[{1}, yw]*G[{0, 1, yu^(-1)}, yw])/8 - 
     (G[{1}, yw]^2*G[{0, 1, yu^(-1)}, yw])/8 + 
     (G[{0}, yu^(-1)]*G[{yu}, yv^(-1)]*G[{0, 1, yu^(-1)}, yw])/8 + 
     (G[{0}, yv^(-1)]*G[{yu}, yv^(-1)]*G[{0, 1, yu^(-1)}, yw])/8 - 
     (G[{0}, yw]*G[{yu}, yv^(-1)]*G[{0, 1, yu^(-1)}, yw])/8 - 
     (G[{1}, yv^(-1)]*G[{yu}, yv^(-1)]*G[{0, 1, yu^(-1)}, yw])/4 + 
     (G[{1}, yw]*G[{yu}, yv^(-1)]*G[{0, 1, yu^(-1)}, yw])/4 + 
     (3*G[{0}, yu^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, 1, yu^(-1)}, yw])/16 + 
     (3*G[{0}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, 1, yu^(-1)}, yw])/16 - 
     (3*G[{0}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1, yu^(-1)}, yw])/16 - 
     (G[{1}, yu^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, 1, yu^(-1)}, yw])/4 + 
     (G[{1}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, 1, yu^(-1)}, yw])/8 + 
     (G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1, yu^(-1)}, yw])/4 - 
     (G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1, yu^(-1)}, yw])/4 - 
     (G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, 1, yu^(-1)}, yw])/4 + 
     (G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1, yu^(-1)}, yw])/8 + 
     (G[{0, 1}, yv^(-1)]*G[{0, 1, yu^(-1)}, yw])/16 - 
     (G[{0, 1}, yw]*G[{0, 1, yu^(-1)}, yw])/16 - 
     (G[{0, yu}, yv^(-1)]*G[{0, 1, yu^(-1)}, yw])/16 + 
     (G[{0, 1/(yu*yv)}, yw]*G[{0, 1, yu^(-1)}, yw])/16 + 
     (G[{1, yu^(-1)}, yw]*G[{0, 1, yu^(-1)}, yw])/4 + 
     (G[{1, yu}, yv^(-1)]*G[{0, 1, yu^(-1)}, yw])/16 - 
     (G[{1, yv^(-1)}, yw]*G[{0, 1, yu^(-1)}, yw])/8 - 
     (G[{1, 1/(yu*yv)}, yw]*G[{0, 1, yu^(-1)}, yw])/4 + 
     (G[{yu^(-1), 1/(yu*yv)}, yw]*G[{0, 1, yu^(-1)}, yw])/4 - 
     (G[{yv^(-1), 1/(yu*yv)}, yw]*G[{0, 1, yu^(-1)}, yw])/8 - 
     (7*Pi^2*G[{0, 1, yu}, yv^(-1)])/768 + 
     (3*G[{1}, yu^(-1)]^2*G[{0, 1, yu}, yv^(-1)])/64 + 
     (G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*G[{0, 1, yu}, yv^(-1)])/32 + 
     (7*G[{1}, yv^(-1)]^2*G[{0, 1, yu}, yv^(-1)])/64 - 
     (G[{0}, yu^(-1)]*G[{1}, yw]*G[{0, 1, yu}, yv^(-1)])/16 - 
     (G[{0}, yv^(-1)]*G[{1}, yw]*G[{0, 1, yu}, yv^(-1)])/16 + 
     (G[{0}, yw]*G[{1}, yw]*G[{0, 1, yu}, yv^(-1)])/16 - 
     (G[{1}, yu^(-1)]*G[{1}, yw]*G[{0, 1, yu}, yv^(-1)])/32 - 
     (G[{1}, yv^(-1)]*G[{1}, yw]*G[{0, 1, yu}, yv^(-1)])/32 - 
     (3*G[{1}, yw]^2*G[{0, 1, yu}, yv^(-1)])/32 + 
     (3*G[{1}, yw]*G[{yu}, yv^(-1)]*G[{0, 1, yu}, yv^(-1)])/32 + 
     (G[{0}, yu^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, 1, yu}, yv^(-1)])/16 + 
     (G[{0}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, 1, yu}, yv^(-1)])/16 - 
     (G[{0}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1, yu}, yv^(-1)])/16 + 
     (G[{1}, yu^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, 1, yu}, yv^(-1)])/32 + 
     (G[{1}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, 1, yu}, yv^(-1)])/32 + 
     (3*G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1, yu}, yv^(-1)])/16 + 
     (G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1, yu}, yv^(-1)])/16 - 
     (3*G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, 1, yu}, yv^(-1)])/32 - 
     (G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1, yu}, yv^(-1)])/32 - 
     (3*G[{1/(yu*yv)}, yw]^2*G[{0, 1, yu}, yv^(-1)])/64 + 
     (G[{0, 1}, yu^(-1)]*G[{0, 1, yu}, yv^(-1)])/32 - 
     (G[{0, 1}, yw]*G[{0, 1, yu}, yv^(-1)])/16 - 
     (G[{0, yu}, yv^(-1)]*G[{0, 1, yu}, yv^(-1)])/16 + 
     (G[{0, 1/(yu*yv)}, yw]*G[{0, 1, yu}, yv^(-1)])/16 - 
     (G[{1, yu^(-1)}, yw]*G[{0, 1, yu}, yv^(-1)])/16 + 
     (G[{1, yu}, yv^(-1)]*G[{0, 1, yu}, yv^(-1)])/32 + 
     (G[{1, yv^(-1)}, yw]*G[{0, 1, yu}, yv^(-1)])/32 - 
     (3*G[{1, 1/(yu*yv)}, yw]*G[{0, 1, yu}, yv^(-1)])/32 - 
     (G[{yu^(-1), 1/(yu*yv)}, yw]*G[{0, 1, yu}, yv^(-1)])/16 + 
     (G[{yv^(-1), 1/(yu*yv)}, yw]*G[{0, 1, yu}, yv^(-1)])/32 - 
     (G[{0}, yu^(-1)]^2*G[{0, 1, yv^(-1)}, yw])/32 - 
     (G[{0}, yu^(-1)]*G[{0}, yv^(-1)]*G[{0, 1, yv^(-1)}, yw])/16 - 
     (G[{0}, yv^(-1)]^2*G[{0, 1, yv^(-1)}, yw])/32 + 
     (G[{0}, yu^(-1)]*G[{0}, yw]*G[{0, 1, yv^(-1)}, yw])/16 + 
     (G[{0}, yv^(-1)]*G[{0}, yw]*G[{0, 1, yv^(-1)}, yw])/16 - 
     (G[{0}, yw]^2*G[{0, 1, yv^(-1)}, yw])/32 + 
     (G[{0}, yu^(-1)]*G[{1}, yu^(-1)]*G[{0, 1, yv^(-1)}, yw])/8 + 
     (G[{0}, yv^(-1)]*G[{1}, yu^(-1)]*G[{0, 1, yv^(-1)}, yw])/8 - 
     (G[{0}, yw]*G[{1}, yu^(-1)]*G[{0, 1, yv^(-1)}, yw])/8 - 
     (3*G[{1}, yu^(-1)]^2*G[{0, 1, yv^(-1)}, yw])/32 - 
     (G[{0}, yu^(-1)]*G[{1}, yv^(-1)]*G[{0, 1, yv^(-1)}, yw])/8 - 
     (G[{0}, yv^(-1)]*G[{1}, yv^(-1)]*G[{0, 1, yv^(-1)}, yw])/8 + 
     (G[{0}, yw]*G[{1}, yv^(-1)]*G[{0, 1, yv^(-1)}, yw])/8 + 
     (3*G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*G[{0, 1, yv^(-1)}, yw])/16 + 
     (G[{1}, yv^(-1)]^2*G[{0, 1, yv^(-1)}, yw])/16 - 
     (3*G[{0}, yu^(-1)]*G[{1}, yw]*G[{0, 1, yv^(-1)}, yw])/16 - 
     (3*G[{0}, yv^(-1)]*G[{1}, yw]*G[{0, 1, yv^(-1)}, yw])/16 + 
     (3*G[{0}, yw]*G[{1}, yw]*G[{0, 1, yv^(-1)}, yw])/16 + 
     (G[{1}, yu^(-1)]*G[{1}, yw]*G[{0, 1, yv^(-1)}, yw])/4 - 
     (G[{1}, yv^(-1)]*G[{1}, yw]*G[{0, 1, yv^(-1)}, yw])/8 - 
     (G[{1}, yw]^2*G[{0, 1, yv^(-1)}, yw])/8 + 
     (G[{0}, yu^(-1)]*G[{yu}, yv^(-1)]*G[{0, 1, yv^(-1)}, yw])/8 + 
     (G[{0}, yv^(-1)]*G[{yu}, yv^(-1)]*G[{0, 1, yv^(-1)}, yw])/8 - 
     (G[{0}, yw]*G[{yu}, yv^(-1)]*G[{0, 1, yv^(-1)}, yw])/8 - 
     (G[{1}, yu^(-1)]*G[{yu}, yv^(-1)]*G[{0, 1, yv^(-1)}, yw])/4 + 
     (G[{1}, yw]*G[{yu}, yv^(-1)]*G[{0, 1, yv^(-1)}, yw])/4 + 
     (3*G[{0}, yu^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, 1, yv^(-1)}, yw])/16 + 
     (3*G[{0}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, 1, yv^(-1)}, yw])/16 - 
     (3*G[{0}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1, yv^(-1)}, yw])/16 - 
     (G[{1}, yu^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, 1, yv^(-1)}, yw])/4 + 
     (G[{1}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, 1, yv^(-1)}, yw])/8 + 
     (G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1, yv^(-1)}, yw])/4 - 
     (G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1, yv^(-1)}, yw])/4 - 
     (G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, 1, yv^(-1)}, yw])/4 + 
     (G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1, yv^(-1)}, yw])/8 + 
     (G[{0, 1}, yu^(-1)]*G[{0, 1, yv^(-1)}, yw])/16 + 
     (G[{0, 1}, yw]*G[{0, 1, yv^(-1)}, yw])/8 - 
     (G[{0, yu^(-1)}, yw]*G[{0, 1, yv^(-1)}, yw])/16 + 
     (G[{0, 1/(yu*yv)}, yw]*G[{0, 1, yv^(-1)}, yw])/16 + 
     (G[{1, yu^(-1)}, yw]*G[{0, 1, yv^(-1)}, yw])/4 - 
     (G[{1, yu}, yv^(-1)]*G[{0, 1, yv^(-1)}, yw])/16 - 
     (G[{1, yv^(-1)}, yw]*G[{0, 1, yv^(-1)}, yw])/8 - 
     (G[{1, 1/(yu*yv)}, yw]*G[{0, 1, yv^(-1)}, yw])/4 + 
     (G[{yu^(-1), 1/(yu*yv)}, yw]*G[{0, 1, yv^(-1)}, yw])/4 - 
     (G[{yv^(-1), 1/(yu*yv)}, yw]*G[{0, 1, yv^(-1)}, yw])/8 - 
     (G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*G[{0, 1, 1/(yu*yv)}, yw])/8 - 
     (3*G[{1}, yv^(-1)]^2*G[{0, 1, 1/(yu*yv)}, yw])/32 + 
     (G[{0}, yu^(-1)]*G[{1}, yw]*G[{0, 1, 1/(yu*yv)}, yw])/16 + 
     (G[{0}, yv^(-1)]*G[{1}, yw]*G[{0, 1, 1/(yu*yv)}, yw])/16 - 
     (G[{0}, yw]*G[{1}, yw]*G[{0, 1, 1/(yu*yv)}, yw])/16 - 
     (G[{1}, yu^(-1)]*G[{1}, yw]*G[{0, 1, 1/(yu*yv)}, yw])/16 - 
     (G[{1}, yv^(-1)]*G[{1}, yw]*G[{0, 1, 1/(yu*yv)}, yw])/16 + 
     (G[{1}, yu^(-1)]*G[{yu}, yv^(-1)]*G[{0, 1, 1/(yu*yv)}, yw])/8 + 
     (G[{1}, yv^(-1)]*G[{yu}, yv^(-1)]*G[{0, 1, 1/(yu*yv)}, yw])/8 - 
     (G[{yu}, yv^(-1)]^2*G[{0, 1, 1/(yu*yv)}, yw])/8 - 
     (G[{0}, yu^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, 1, 1/(yu*yv)}, yw])/16 - 
     (G[{0}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, 1, 1/(yu*yv)}, yw])/16 + 
     (G[{0}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1, 1/(yu*yv)}, yw])/16 + 
     (G[{1}, yu^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, 1, 1/(yu*yv)}, yw])/16 + 
     (G[{1}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, 1, 1/(yu*yv)}, yw])/16 - 
     (G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1, 1/(yu*yv)}, yw])/16 - 
     (G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1, 1/(yu*yv)}, yw])/16 - 
     (G[{0, 1}, yu^(-1)]*G[{0, 1, 1/(yu*yv)}, yw])/8 + 
     (G[{0, 1}, yv^(-1)]*G[{0, 1, 1/(yu*yv)}, yw])/16 - 
     (G[{0, yu}, yv^(-1)]*G[{0, 1, 1/(yu*yv)}, yw])/16 - 
     (G[{0, 1/(yu*yv)}, yw]*G[{0, 1, 1/(yu*yv)}, yw])/16 + 
     (G[{1, yu^(-1)}, yw]*G[{0, 1, 1/(yu*yv)}, yw])/16 + 
     (3*G[{1, yu}, yv^(-1)]*G[{0, 1, 1/(yu*yv)}, yw])/16 + 
     (G[{1, yv^(-1)}, yw]*G[{0, 1, 1/(yu*yv)}, yw])/16 + 
     (G[{yu^(-1), 1/(yu*yv)}, yw]*G[{0, 1, 1/(yu*yv)}, yw])/16 + 
     (G[{yv^(-1), 1/(yu*yv)}, yw]*G[{0, 1, 1/(yu*yv)}, yw])/16 + 
     (Pi^2*G[{0, yu^(-1), 1}, yw])/96 - 
     (G[{0}, yu^(-1)]^2*G[{0, yu^(-1), 1}, yw])/32 - 
     (G[{0}, yu^(-1)]*G[{0}, yv^(-1)]*G[{0, yu^(-1), 1}, yw])/16 - 
     (G[{0}, yv^(-1)]^2*G[{0, yu^(-1), 1}, yw])/32 + 
     (G[{0}, yu^(-1)]*G[{0}, yw]*G[{0, yu^(-1), 1}, yw])/16 + 
     (G[{0}, yv^(-1)]*G[{0}, yw]*G[{0, yu^(-1), 1}, yw])/16 - 
     (G[{0}, yw]^2*G[{0, yu^(-1), 1}, yw])/32 + 
     (G[{0}, yu^(-1)]*G[{1}, yu^(-1)]*G[{0, yu^(-1), 1}, yw])/8 + 
     (G[{0}, yv^(-1)]*G[{1}, yu^(-1)]*G[{0, yu^(-1), 1}, yw])/8 - 
     (G[{0}, yw]*G[{1}, yu^(-1)]*G[{0, yu^(-1), 1}, yw])/8 - 
     (3*G[{1}, yu^(-1)]^2*G[{0, yu^(-1), 1}, yw])/32 - 
     (G[{0}, yu^(-1)]*G[{1}, yv^(-1)]*G[{0, yu^(-1), 1}, yw])/8 - 
     (G[{0}, yv^(-1)]*G[{1}, yv^(-1)]*G[{0, yu^(-1), 1}, yw])/8 + 
     (G[{0}, yw]*G[{1}, yv^(-1)]*G[{0, yu^(-1), 1}, yw])/8 + 
     (G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*G[{0, yu^(-1), 1}, yw])/16 + 
     (5*G[{1}, yv^(-1)]^2*G[{0, yu^(-1), 1}, yw])/32 - 
     (G[{0}, yu^(-1)]*G[{1}, yw]*G[{0, yu^(-1), 1}, yw])/16 - 
     (G[{0}, yv^(-1)]*G[{1}, yw]*G[{0, yu^(-1), 1}, yw])/16 + 
     (G[{0}, yw]*G[{1}, yw]*G[{0, yu^(-1), 1}, yw])/16 + 
     (G[{1}, yu^(-1)]*G[{1}, yw]*G[{0, yu^(-1), 1}, yw])/16 + 
     (G[{1}, yv^(-1)]*G[{1}, yw]*G[{0, yu^(-1), 1}, yw])/16 + 
     (G[{0}, yu^(-1)]*G[{yu}, yv^(-1)]*G[{0, yu^(-1), 1}, yw])/8 + 
     (G[{0}, yv^(-1)]*G[{yu}, yv^(-1)]*G[{0, yu^(-1), 1}, yw])/8 - 
     (G[{0}, yw]*G[{yu}, yv^(-1)]*G[{0, yu^(-1), 1}, yw])/8 - 
     (G[{1}, yu^(-1)]*G[{yu}, yv^(-1)]*G[{0, yu^(-1), 1}, yw])/8 - 
     (G[{1}, yv^(-1)]*G[{yu}, yv^(-1)]*G[{0, yu^(-1), 1}, yw])/8 + 
     (G[{0}, yu^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1), 1}, yw])/16 + 
     (G[{0}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1), 1}, yw])/16 - 
     (G[{0}, yw]*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1), 1}, yw])/16 - 
     (G[{1}, yu^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1), 1}, yw])/16 - 
     (G[{1}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1), 1}, yw])/16 + 
     (G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1), 1}, yw])/16 + 
     (G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1), 1}, yw])/16 + 
     (G[{0, 1}, yw]*G[{0, yu^(-1), 1}, yw])/16 - 
     (G[{0, yu^(-1)}, yw]*G[{0, yu^(-1), 1}, yw])/16 + 
     (G[{0, 1/(yu*yv)}, yw]*G[{0, yu^(-1), 1}, yw])/16 - 
     (G[{1, yu^(-1)}, yw]*G[{0, yu^(-1), 1}, yw])/16 - 
     (G[{1, yv^(-1)}, yw]*G[{0, yu^(-1), 1}, yw])/16 - 
     (G[{yu^(-1), 1/(yu*yv)}, yw]*G[{0, yu^(-1), 1}, yw])/16 - 
     (G[{yv^(-1), 1/(yu*yv)}, yw]*G[{0, yu^(-1), 1}, yw])/16 + 
     (G[{0}, yu^(-1)]*G[{1}, yw]*G[{0, yu^(-1), yu^(-1)}, yw])/8 + 
     (G[{0}, yv^(-1)]*G[{1}, yw]*G[{0, yu^(-1), yu^(-1)}, yw])/8 - 
     (G[{0}, yw]*G[{1}, yw]*G[{0, yu^(-1), yu^(-1)}, yw])/8 - 
     (G[{1}, yu^(-1)]*G[{1}, yw]*G[{0, yu^(-1), yu^(-1)}, yw])/4 + 
     (G[{1}, yv^(-1)]*G[{1}, yw]*G[{0, yu^(-1), yu^(-1)}, yw])/4 + 
     (G[{1}, yw]^2*G[{0, yu^(-1), yu^(-1)}, yw])/8 - 
     (G[{1}, yw]*G[{yu}, yv^(-1)]*G[{0, yu^(-1), yu^(-1)}, yw])/4 - 
     (G[{0}, yu^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1), yu^(-1)}, yw])/8 - 
     (G[{0}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1), yu^(-1)}, yw])/8 + 
     (G[{0}, yw]*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1), yu^(-1)}, yw])/8 + 
     (G[{1}, yu^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1), yu^(-1)}, yw])/4 - 
     (G[{1}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1), yu^(-1)}, yw])/4 - 
     (G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1), yu^(-1)}, yw])/4 + 
     (G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1), yu^(-1)}, yw])/4 + 
     (G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1), yu^(-1)}, yw])/4 - 
     (G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1), yu^(-1)}, yw])/8 - 
     (G[{0, 1/(yu*yv)}, yw]*G[{0, yu^(-1), yu^(-1)}, yw])/8 - 
     (G[{1, yu^(-1)}, yw]*G[{0, yu^(-1), yu^(-1)}, yw])/4 + 
     (G[{1, yv^(-1)}, yw]*G[{0, yu^(-1), yu^(-1)}, yw])/8 + 
     (G[{1, 1/(yu*yv)}, yw]*G[{0, yu^(-1), yu^(-1)}, yw])/4 - 
     (G[{yu^(-1), 1/(yu*yv)}, yw]*G[{0, yu^(-1), yu^(-1)}, yw])/4 + 
     (G[{yv^(-1), 1/(yu*yv)}, yw]*G[{0, yu^(-1), yu^(-1)}, yw])/8 + 
     (3*G[{0}, yu^(-1)]*G[{1}, yw]*G[{0, yu^(-1), yv^(-1)}, yw])/16 + 
     (3*G[{0}, yv^(-1)]*G[{1}, yw]*G[{0, yu^(-1), yv^(-1)}, yw])/16 - 
     (3*G[{0}, yw]*G[{1}, yw]*G[{0, yu^(-1), yv^(-1)}, yw])/16 - 
     (G[{1}, yu^(-1)]*G[{1}, yw]*G[{0, yu^(-1), yv^(-1)}, yw])/4 + 
     (G[{1}, yv^(-1)]*G[{1}, yw]*G[{0, yu^(-1), yv^(-1)}, yw])/8 + 
     (G[{1}, yw]^2*G[{0, yu^(-1), yv^(-1)}, yw])/8 - 
     (G[{1}, yw]*G[{yu}, yv^(-1)]*G[{0, yu^(-1), yv^(-1)}, yw])/4 - 
     (3*G[{0}, yu^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1), yv^(-1)}, yw])/16 - 
     (3*G[{0}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1), yv^(-1)}, yw])/16 + 
     (3*G[{0}, yw]*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1), yv^(-1)}, yw])/16 + 
     (G[{1}, yu^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1), yv^(-1)}, yw])/4 - 
     (G[{1}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1), yv^(-1)}, yw])/8 - 
     (G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1), yv^(-1)}, yw])/4 + 
     (G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1), yv^(-1)}, yw])/4 + 
     (G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1), yv^(-1)}, yw])/4 - 
     (G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1), yv^(-1)}, yw])/8 - 
     (G[{0, 1/(yu*yv)}, yw]*G[{0, yu^(-1), yv^(-1)}, yw])/16 - 
     (G[{1, yu^(-1)}, yw]*G[{0, yu^(-1), yv^(-1)}, yw])/4 + 
     (G[{1, yv^(-1)}, yw]*G[{0, yu^(-1), yv^(-1)}, yw])/8 + 
     (G[{1, 1/(yu*yv)}, yw]*G[{0, yu^(-1), yv^(-1)}, yw])/4 - 
     (G[{yu^(-1), 1/(yu*yv)}, yw]*G[{0, yu^(-1), yv^(-1)}, yw])/4 + 
     (G[{yv^(-1), 1/(yu*yv)}, yw]*G[{0, yu^(-1), yv^(-1)}, yw])/8 - 
     (Pi^2*G[{0, yu^(-1), 1/(yu*yv)}, yw])/96 + 
     (G[{0}, yu^(-1)]^2*G[{0, yu^(-1), 1/(yu*yv)}, yw])/32 + 
     (G[{0}, yu^(-1)]*G[{0}, yv^(-1)]*G[{0, yu^(-1), 1/(yu*yv)}, yw])/16 + 
     (G[{0}, yv^(-1)]^2*G[{0, yu^(-1), 1/(yu*yv)}, yw])/32 - 
     (G[{0}, yu^(-1)]*G[{0}, yw]*G[{0, yu^(-1), 1/(yu*yv)}, yw])/16 - 
     (G[{0}, yv^(-1)]*G[{0}, yw]*G[{0, yu^(-1), 1/(yu*yv)}, yw])/16 + 
     (G[{0}, yw]^2*G[{0, yu^(-1), 1/(yu*yv)}, yw])/32 - 
     (G[{0}, yu^(-1)]*G[{1}, yu^(-1)]*G[{0, yu^(-1), 1/(yu*yv)}, yw])/8 - 
     (G[{0}, yv^(-1)]*G[{1}, yu^(-1)]*G[{0, yu^(-1), 1/(yu*yv)}, yw])/8 + 
     (G[{0}, yw]*G[{1}, yu^(-1)]*G[{0, yu^(-1), 1/(yu*yv)}, yw])/8 + 
     (3*G[{1}, yu^(-1)]^2*G[{0, yu^(-1), 1/(yu*yv)}, yw])/32 + 
     (G[{0}, yu^(-1)]*G[{1}, yv^(-1)]*G[{0, yu^(-1), 1/(yu*yv)}, yw])/8 + 
     (G[{0}, yv^(-1)]*G[{1}, yv^(-1)]*G[{0, yu^(-1), 1/(yu*yv)}, yw])/8 - 
     (G[{0}, yw]*G[{1}, yv^(-1)]*G[{0, yu^(-1), 1/(yu*yv)}, yw])/8 - 
     (G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*G[{0, yu^(-1), 1/(yu*yv)}, yw])/16 - 
     (5*G[{1}, yv^(-1)]^2*G[{0, yu^(-1), 1/(yu*yv)}, yw])/32 - 
     (G[{0}, yu^(-1)]*G[{1}, yw]*G[{0, yu^(-1), 1/(yu*yv)}, yw])/16 - 
     (G[{0}, yv^(-1)]*G[{1}, yw]*G[{0, yu^(-1), 1/(yu*yv)}, yw])/16 + 
     (G[{0}, yw]*G[{1}, yw]*G[{0, yu^(-1), 1/(yu*yv)}, yw])/16 + 
     (G[{1}, yu^(-1)]*G[{1}, yw]*G[{0, yu^(-1), 1/(yu*yv)}, yw])/16 + 
     (G[{1}, yv^(-1)]*G[{1}, yw]*G[{0, yu^(-1), 1/(yu*yv)}, yw])/16 - 
     (G[{0}, yu^(-1)]*G[{yu}, yv^(-1)]*G[{0, yu^(-1), 1/(yu*yv)}, yw])/8 - 
     (G[{0}, yv^(-1)]*G[{yu}, yv^(-1)]*G[{0, yu^(-1), 1/(yu*yv)}, yw])/8 + 
     (G[{0}, yw]*G[{yu}, yv^(-1)]*G[{0, yu^(-1), 1/(yu*yv)}, yw])/8 + 
     (G[{1}, yu^(-1)]*G[{yu}, yv^(-1)]*G[{0, yu^(-1), 1/(yu*yv)}, yw])/8 + 
     (G[{1}, yv^(-1)]*G[{yu}, yv^(-1)]*G[{0, yu^(-1), 1/(yu*yv)}, yw])/8 + 
     (G[{0}, yu^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1), 1/(yu*yv)}, yw])/16 + 
     (G[{0}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1), 1/(yu*yv)}, yw])/16 - 
     (G[{0}, yw]*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1), 1/(yu*yv)}, yw])/16 - 
     (G[{1}, yu^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1), 1/(yu*yv)}, yw])/16 - 
     (G[{1}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1), 1/(yu*yv)}, yw])/16 + 
     (G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1), 1/(yu*yv)}, yw])/
      16 + (G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1), 1/(yu*yv)}, 
        yw])/16 - (G[{0, 1}, yw]*G[{0, yu^(-1), 1/(yu*yv)}, yw])/16 + 
     (G[{0, yu^(-1)}, yw]*G[{0, yu^(-1), 1/(yu*yv)}, yw])/16 + 
     (G[{0, yv^(-1)}, yw]*G[{0, yu^(-1), 1/(yu*yv)}, yw])/16 + 
     (G[{0, 1/(yu*yv)}, yw]*G[{0, yu^(-1), 1/(yu*yv)}, yw])/16 - 
     (G[{1, yu^(-1)}, yw]*G[{0, yu^(-1), 1/(yu*yv)}, yw])/16 - 
     (G[{1, yv^(-1)}, yw]*G[{0, yu^(-1), 1/(yu*yv)}, yw])/16 - 
     (G[{yu^(-1), 1/(yu*yv)}, yw]*G[{0, yu^(-1), 1/(yu*yv)}, yw])/16 - 
     (G[{yv^(-1), 1/(yu*yv)}, yw]*G[{0, yu^(-1), 1/(yu*yv)}, yw])/16 - 
     (Pi^2*G[{0, yu, 1}, yv^(-1)])/64 + 
     (3*G[{1}, yu^(-1)]^2*G[{0, yu, 1}, yv^(-1)])/128 - 
     (3*G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*G[{0, yu, 1}, yv^(-1)])/64 + 
     (G[{1}, yv^(-1)]^2*G[{0, yu, 1}, yv^(-1)])/8 - 
     (G[{0}, yu^(-1)]*G[{1}, yw]*G[{0, yu, 1}, yv^(-1)])/8 - 
     (G[{0}, yv^(-1)]*G[{1}, yw]*G[{0, yu, 1}, yv^(-1)])/8 + 
     (G[{0}, yw]*G[{1}, yw]*G[{0, yu, 1}, yv^(-1)])/8 - 
     (G[{1}, yu^(-1)]*G[{1}, yw]*G[{0, yu, 1}, yv^(-1)])/64 - 
     (17*G[{1}, yw]^2*G[{0, yu, 1}, yv^(-1)])/128 + 
     (11*G[{1}, yw]*G[{yu}, yv^(-1)]*G[{0, yu, 1}, yv^(-1)])/64 + 
     (G[{0}, yu^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, yu, 1}, yv^(-1)])/8 + 
     (G[{0}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, yu, 1}, yv^(-1)])/8 - 
     (G[{0}, yw]*G[{1/(yu*yv)}, yw]*G[{0, yu, 1}, yv^(-1)])/8 + 
     (G[{1}, yu^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, yu, 1}, yv^(-1)])/64 + 
     (17*G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{0, yu, 1}, yv^(-1)])/64 + 
     (3*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{0, yu, 1}, yv^(-1)])/32 - 
     (11*G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, yu, 1}, yv^(-1)])/64 - 
     (G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{0, yu, 1}, yv^(-1)])/64 - 
     (3*G[{1/(yu*yv)}, yw]^2*G[{0, yu, 1}, yv^(-1)])/64 - 
     (3*G[{0, 1}, yu^(-1)]*G[{0, yu, 1}, yv^(-1)])/64 - 
     (G[{0, 1}, yv^(-1)]*G[{0, yu, 1}, yv^(-1)])/64 - 
     (G[{0, 1}, yw]*G[{0, yu, 1}, yv^(-1)])/8 + 
     (G[{0, yu}, yv^(-1)]*G[{0, yu, 1}, yv^(-1)])/64 + 
     (G[{0, 1/(yu*yv)}, yw]*G[{0, yu, 1}, yv^(-1)])/8 - 
     (3*G[{1, yu^(-1)}, yw]*G[{0, yu, 1}, yv^(-1)])/32 + 
     (G[{1, yu}, yv^(-1)]*G[{0, yu, 1}, yv^(-1)])/64 + 
     (G[{1, yv^(-1)}, yw]*G[{0, yu, 1}, yv^(-1)])/64 - 
     (11*G[{1, 1/(yu*yv)}, yw]*G[{0, yu, 1}, yv^(-1)])/64 - 
     (3*G[{yu^(-1), 1/(yu*yv)}, yw]*G[{0, yu, 1}, yv^(-1)])/32 + 
     (G[{yv^(-1), 1/(yu*yv)}, yw]*G[{0, yu, 1}, yv^(-1)])/64 + 
     (23*Pi^2*G[{0, yu, yu}, yv^(-1)])/768 - 
     (3*G[{1}, yu^(-1)]^2*G[{0, yu, yu}, yv^(-1)])/64 - 
     (G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*G[{0, yu, yu}, yv^(-1)])/32 - 
     (7*G[{1}, yv^(-1)]^2*G[{0, yu, yu}, yv^(-1)])/64 + 
     (G[{1}, yu^(-1)]*G[{1}, yw]*G[{0, yu, yu}, yv^(-1)])/32 + 
     (G[{1}, yv^(-1)]*G[{1}, yw]*G[{0, yu, yu}, yv^(-1)])/32 + 
     (3*G[{1}, yw]^2*G[{0, yu, yu}, yv^(-1)])/32 - 
     (3*G[{1}, yw]*G[{yu}, yv^(-1)]*G[{0, yu, yu}, yv^(-1)])/32 - 
     (G[{1}, yu^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, yu, yu}, yv^(-1)])/32 - 
     (G[{1}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, yu, yu}, yv^(-1)])/32 - 
     (3*G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{0, yu, yu}, yv^(-1)])/16 - 
     (G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{0, yu, yu}, yv^(-1)])/16 + 
     (3*G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, yu, yu}, yv^(-1)])/32 + 
     (G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{0, yu, yu}, yv^(-1)])/32 + 
     (3*G[{1/(yu*yv)}, yw]^2*G[{0, yu, yu}, yv^(-1)])/64 + 
     (3*G[{0, 1}, yu^(-1)]*G[{0, yu, yu}, yv^(-1)])/32 + 
     (G[{0, 1}, yv^(-1)]*G[{0, yu, yu}, yv^(-1)])/8 - 
     (G[{0, yu}, yv^(-1)]*G[{0, yu, yu}, yv^(-1)])/8 + 
     (G[{1, yu^(-1)}, yw]*G[{0, yu, yu}, yv^(-1)])/16 - 
     (G[{1, yu}, yv^(-1)]*G[{0, yu, yu}, yv^(-1)])/32 - 
     (G[{1, yv^(-1)}, yw]*G[{0, yu, yu}, yv^(-1)])/32 + 
     (3*G[{1, 1/(yu*yv)}, yw]*G[{0, yu, yu}, yv^(-1)])/32 + 
     (G[{yu^(-1), 1/(yu*yv)}, yw]*G[{0, yu, yu}, yv^(-1)])/16 - 
     (G[{yv^(-1), 1/(yu*yv)}, yw]*G[{0, yu, yu}, yv^(-1)])/32 + 
     (Pi^2*G[{0, yv^(-1), 1}, yw])/96 - 
     (G[{0}, yu^(-1)]^2*G[{0, yv^(-1), 1}, yw])/32 - 
     (G[{0}, yu^(-1)]*G[{0}, yv^(-1)]*G[{0, yv^(-1), 1}, yw])/16 - 
     (G[{0}, yv^(-1)]^2*G[{0, yv^(-1), 1}, yw])/32 + 
     (G[{0}, yu^(-1)]*G[{0}, yw]*G[{0, yv^(-1), 1}, yw])/16 + 
     (G[{0}, yv^(-1)]*G[{0}, yw]*G[{0, yv^(-1), 1}, yw])/16 - 
     (G[{0}, yw]^2*G[{0, yv^(-1), 1}, yw])/32 + 
     (G[{0}, yu^(-1)]*G[{1}, yu^(-1)]*G[{0, yv^(-1), 1}, yw])/16 + 
     (G[{0}, yv^(-1)]*G[{1}, yu^(-1)]*G[{0, yv^(-1), 1}, yw])/16 - 
     (G[{0}, yw]*G[{1}, yu^(-1)]*G[{0, yv^(-1), 1}, yw])/16 - 
     (G[{1}, yu^(-1)]^2*G[{0, yv^(-1), 1}, yw])/32 - 
     (G[{0}, yu^(-1)]*G[{1}, yv^(-1)]*G[{0, yv^(-1), 1}, yw])/16 - 
     (G[{0}, yv^(-1)]*G[{1}, yv^(-1)]*G[{0, yv^(-1), 1}, yw])/16 + 
     (G[{0}, yw]*G[{1}, yv^(-1)]*G[{0, yv^(-1), 1}, yw])/16 + 
     (G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*G[{0, yv^(-1), 1}, yw])/16 + 
     (3*G[{1}, yv^(-1)]^2*G[{0, yv^(-1), 1}, yw])/32 - 
     (G[{0}, yu^(-1)]*G[{1}, yw]*G[{0, yv^(-1), 1}, yw])/16 - 
     (G[{0}, yv^(-1)]*G[{1}, yw]*G[{0, yv^(-1), 1}, yw])/16 + 
     (G[{0}, yw]*G[{1}, yw]*G[{0, yv^(-1), 1}, yw])/16 + 
     (G[{1}, yu^(-1)]*G[{1}, yw]*G[{0, yv^(-1), 1}, yw])/16 + 
     (G[{1}, yv^(-1)]*G[{1}, yw]*G[{0, yv^(-1), 1}, yw])/16 + 
     (G[{0}, yu^(-1)]*G[{yu}, yv^(-1)]*G[{0, yv^(-1), 1}, yw])/8 + 
     (G[{0}, yv^(-1)]*G[{yu}, yv^(-1)]*G[{0, yv^(-1), 1}, yw])/8 - 
     (G[{0}, yw]*G[{yu}, yv^(-1)]*G[{0, yv^(-1), 1}, yw])/8 - 
     (G[{1}, yu^(-1)]*G[{yu}, yv^(-1)]*G[{0, yv^(-1), 1}, yw])/8 - 
     (G[{1}, yv^(-1)]*G[{yu}, yv^(-1)]*G[{0, yv^(-1), 1}, yw])/8 + 
     (G[{0}, yu^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, yv^(-1), 1}, yw])/16 + 
     (G[{0}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, yv^(-1), 1}, yw])/16 - 
     (G[{0}, yw]*G[{1/(yu*yv)}, yw]*G[{0, yv^(-1), 1}, yw])/16 - 
     (G[{1}, yu^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, yv^(-1), 1}, yw])/16 - 
     (G[{1}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, yv^(-1), 1}, yw])/16 + 
     (G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{0, yv^(-1), 1}, yw])/16 + 
     (G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{0, yv^(-1), 1}, yw])/16 + 
     (G[{0, 1}, yw]*G[{0, yv^(-1), 1}, yw])/16 - 
     (G[{0, yu^(-1)}, yw]*G[{0, yv^(-1), 1}, yw])/16 - 
     (G[{0, yv^(-1)}, yw]*G[{0, yv^(-1), 1}, yw])/16 + 
     (G[{0, 1/(yu*yv)}, yw]*G[{0, yv^(-1), 1}, yw])/16 - 
     (G[{1, yu^(-1)}, yw]*G[{0, yv^(-1), 1}, yw])/16 - 
     (G[{1, yv^(-1)}, yw]*G[{0, yv^(-1), 1}, yw])/16 - 
     (G[{yu^(-1), 1/(yu*yv)}, yw]*G[{0, yv^(-1), 1}, yw])/16 - 
     (G[{yv^(-1), 1/(yu*yv)}, yw]*G[{0, yv^(-1), 1}, yw])/16 + 
     (3*G[{0}, yu^(-1)]*G[{1}, yw]*G[{0, yv^(-1), yu^(-1)}, yw])/16 + 
     (3*G[{0}, yv^(-1)]*G[{1}, yw]*G[{0, yv^(-1), yu^(-1)}, yw])/16 - 
     (3*G[{0}, yw]*G[{1}, yw]*G[{0, yv^(-1), yu^(-1)}, yw])/16 - 
     (G[{1}, yu^(-1)]*G[{1}, yw]*G[{0, yv^(-1), yu^(-1)}, yw])/4 + 
     (G[{1}, yv^(-1)]*G[{1}, yw]*G[{0, yv^(-1), yu^(-1)}, yw])/8 + 
     (G[{1}, yw]^2*G[{0, yv^(-1), yu^(-1)}, yw])/8 - 
     (G[{1}, yw]*G[{yu}, yv^(-1)]*G[{0, yv^(-1), yu^(-1)}, yw])/4 - 
     (3*G[{0}, yu^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, yv^(-1), yu^(-1)}, yw])/16 - 
     (3*G[{0}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, yv^(-1), yu^(-1)}, yw])/16 + 
     (3*G[{0}, yw]*G[{1/(yu*yv)}, yw]*G[{0, yv^(-1), yu^(-1)}, yw])/16 + 
     (G[{1}, yu^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, yv^(-1), yu^(-1)}, yw])/4 - 
     (G[{1}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, yv^(-1), yu^(-1)}, yw])/8 - 
     (G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{0, yv^(-1), yu^(-1)}, yw])/4 + 
     (G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{0, yv^(-1), yu^(-1)}, yw])/4 + 
     (G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, yv^(-1), yu^(-1)}, yw])/4 - 
     (G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{0, yv^(-1), yu^(-1)}, yw])/8 - 
     (G[{0, 1/(yu*yv)}, yw]*G[{0, yv^(-1), yu^(-1)}, yw])/16 - 
     (G[{1, yu^(-1)}, yw]*G[{0, yv^(-1), yu^(-1)}, yw])/4 + 
     (G[{1, yv^(-1)}, yw]*G[{0, yv^(-1), yu^(-1)}, yw])/8 + 
     (G[{1, 1/(yu*yv)}, yw]*G[{0, yv^(-1), yu^(-1)}, yw])/4 - 
     (G[{yu^(-1), 1/(yu*yv)}, yw]*G[{0, yv^(-1), yu^(-1)}, yw])/4 + 
     (G[{yv^(-1), 1/(yu*yv)}, yw]*G[{0, yv^(-1), yu^(-1)}, yw])/8 + 
     (G[{0}, yu^(-1)]*G[{1}, yw]*G[{0, yv^(-1), yv^(-1)}, yw])/8 + 
     (G[{0}, yv^(-1)]*G[{1}, yw]*G[{0, yv^(-1), yv^(-1)}, yw])/8 - 
     (G[{0}, yw]*G[{1}, yw]*G[{0, yv^(-1), yv^(-1)}, yw])/8 - 
     (G[{1}, yu^(-1)]*G[{1}, yw]*G[{0, yv^(-1), yv^(-1)}, yw])/8 + 
     (G[{1}, yv^(-1)]*G[{1}, yw]*G[{0, yv^(-1), yv^(-1)}, yw])/8 + 
     (G[{1}, yw]^2*G[{0, yv^(-1), yv^(-1)}, yw])/8 - 
     (G[{1}, yw]*G[{yu}, yv^(-1)]*G[{0, yv^(-1), yv^(-1)}, yw])/4 - 
     (G[{0}, yu^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, yv^(-1), yv^(-1)}, yw])/8 - 
     (G[{0}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, yv^(-1), yv^(-1)}, yw])/8 + 
     (G[{0}, yw]*G[{1/(yu*yv)}, yw]*G[{0, yv^(-1), yv^(-1)}, yw])/8 + 
     (G[{1}, yu^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, yv^(-1), yv^(-1)}, yw])/8 - 
     (G[{1}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, yv^(-1), yv^(-1)}, yw])/8 - 
     (G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{0, yv^(-1), yv^(-1)}, yw])/4 + 
     (G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{0, yv^(-1), yv^(-1)}, yw])/4 + 
     (G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, yv^(-1), yv^(-1)}, yw])/4 - 
     (G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{0, yv^(-1), yv^(-1)}, yw])/8 - 
     (G[{0, 1/(yu*yv)}, yw]*G[{0, yv^(-1), yv^(-1)}, yw])/8 - 
     (G[{1, yu^(-1)}, yw]*G[{0, yv^(-1), yv^(-1)}, yw])/4 + 
     (G[{1, yv^(-1)}, yw]*G[{0, yv^(-1), yv^(-1)}, yw])/8 + 
     (G[{1, 1/(yu*yv)}, yw]*G[{0, yv^(-1), yv^(-1)}, yw])/4 - 
     (G[{yu^(-1), 1/(yu*yv)}, yw]*G[{0, yv^(-1), yv^(-1)}, yw])/4 + 
     (G[{yv^(-1), 1/(yu*yv)}, yw]*G[{0, yv^(-1), yv^(-1)}, yw])/8 - 
     (Pi^2*G[{0, yv^(-1), 1/(yu*yv)}, yw])/96 + 
     (G[{0}, yu^(-1)]^2*G[{0, yv^(-1), 1/(yu*yv)}, yw])/32 + 
     (G[{0}, yu^(-1)]*G[{0}, yv^(-1)]*G[{0, yv^(-1), 1/(yu*yv)}, yw])/16 + 
     (G[{0}, yv^(-1)]^2*G[{0, yv^(-1), 1/(yu*yv)}, yw])/32 - 
     (G[{0}, yu^(-1)]*G[{0}, yw]*G[{0, yv^(-1), 1/(yu*yv)}, yw])/16 - 
     (G[{0}, yv^(-1)]*G[{0}, yw]*G[{0, yv^(-1), 1/(yu*yv)}, yw])/16 + 
     (G[{0}, yw]^2*G[{0, yv^(-1), 1/(yu*yv)}, yw])/32 - 
     (G[{0}, yu^(-1)]*G[{1}, yu^(-1)]*G[{0, yv^(-1), 1/(yu*yv)}, yw])/16 - 
     (G[{0}, yv^(-1)]*G[{1}, yu^(-1)]*G[{0, yv^(-1), 1/(yu*yv)}, yw])/16 + 
     (G[{0}, yw]*G[{1}, yu^(-1)]*G[{0, yv^(-1), 1/(yu*yv)}, yw])/16 + 
     (G[{1}, yu^(-1)]^2*G[{0, yv^(-1), 1/(yu*yv)}, yw])/32 + 
     (G[{0}, yu^(-1)]*G[{1}, yv^(-1)]*G[{0, yv^(-1), 1/(yu*yv)}, yw])/16 + 
     (G[{0}, yv^(-1)]*G[{1}, yv^(-1)]*G[{0, yv^(-1), 1/(yu*yv)}, yw])/16 - 
     (G[{0}, yw]*G[{1}, yv^(-1)]*G[{0, yv^(-1), 1/(yu*yv)}, yw])/16 - 
     (G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*G[{0, yv^(-1), 1/(yu*yv)}, yw])/16 - 
     (3*G[{1}, yv^(-1)]^2*G[{0, yv^(-1), 1/(yu*yv)}, yw])/32 - 
     (G[{0}, yu^(-1)]*G[{1}, yw]*G[{0, yv^(-1), 1/(yu*yv)}, yw])/16 - 
     (G[{0}, yv^(-1)]*G[{1}, yw]*G[{0, yv^(-1), 1/(yu*yv)}, yw])/16 + 
     (G[{0}, yw]*G[{1}, yw]*G[{0, yv^(-1), 1/(yu*yv)}, yw])/16 + 
     (G[{1}, yu^(-1)]*G[{1}, yw]*G[{0, yv^(-1), 1/(yu*yv)}, yw])/16 + 
     (G[{1}, yv^(-1)]*G[{1}, yw]*G[{0, yv^(-1), 1/(yu*yv)}, yw])/16 - 
     (G[{0}, yu^(-1)]*G[{yu}, yv^(-1)]*G[{0, yv^(-1), 1/(yu*yv)}, yw])/8 - 
     (G[{0}, yv^(-1)]*G[{yu}, yv^(-1)]*G[{0, yv^(-1), 1/(yu*yv)}, yw])/8 + 
     (G[{0}, yw]*G[{yu}, yv^(-1)]*G[{0, yv^(-1), 1/(yu*yv)}, yw])/8 + 
     (G[{1}, yu^(-1)]*G[{yu}, yv^(-1)]*G[{0, yv^(-1), 1/(yu*yv)}, yw])/8 + 
     (G[{1}, yv^(-1)]*G[{yu}, yv^(-1)]*G[{0, yv^(-1), 1/(yu*yv)}, yw])/8 + 
     (G[{0}, yu^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, yv^(-1), 1/(yu*yv)}, yw])/16 + 
     (G[{0}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, yv^(-1), 1/(yu*yv)}, yw])/16 - 
     (G[{0}, yw]*G[{1/(yu*yv)}, yw]*G[{0, yv^(-1), 1/(yu*yv)}, yw])/16 - 
     (G[{1}, yu^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, yv^(-1), 1/(yu*yv)}, yw])/16 - 
     (G[{1}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, yv^(-1), 1/(yu*yv)}, yw])/16 + 
     (G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{0, yv^(-1), 1/(yu*yv)}, yw])/
      16 + (G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{0, yv^(-1), 1/(yu*yv)}, 
        yw])/16 - (G[{0, 1}, yw]*G[{0, yv^(-1), 1/(yu*yv)}, yw])/16 + 
     (G[{0, yu^(-1)}, yw]*G[{0, yv^(-1), 1/(yu*yv)}, yw])/16 + 
     (G[{0, yv^(-1)}, yw]*G[{0, yv^(-1), 1/(yu*yv)}, yw])/16 + 
     (G[{0, 1/(yu*yv)}, yw]*G[{0, yv^(-1), 1/(yu*yv)}, yw])/16 - 
     (G[{1, yu^(-1)}, yw]*G[{0, yv^(-1), 1/(yu*yv)}, yw])/16 - 
     (G[{1, yv^(-1)}, yw]*G[{0, yv^(-1), 1/(yu*yv)}, yw])/16 - 
     (G[{yu^(-1), 1/(yu*yv)}, yw]*G[{0, yv^(-1), 1/(yu*yv)}, yw])/16 - 
     (G[{yv^(-1), 1/(yu*yv)}, yw]*G[{0, yv^(-1), 1/(yu*yv)}, yw])/16 + 
     (Pi^2*G[{0, 1/(yu*yv), 1}, yw])/48 - 
     (G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*G[{0, 1/(yu*yv), 1}, yw])/8 - 
     (3*G[{1}, yv^(-1)]^2*G[{0, 1/(yu*yv), 1}, yw])/32 - 
     (G[{1}, yu^(-1)]*G[{1}, yw]*G[{0, 1/(yu*yv), 1}, yw])/16 - 
     (G[{1}, yv^(-1)]*G[{1}, yw]*G[{0, 1/(yu*yv), 1}, yw])/16 + 
     (G[{1}, yu^(-1)]*G[{yu}, yv^(-1)]*G[{0, 1/(yu*yv), 1}, yw])/8 + 
     (G[{1}, yv^(-1)]*G[{yu}, yv^(-1)]*G[{0, 1/(yu*yv), 1}, yw])/8 + 
     (G[{1}, yw]*G[{yu}, yv^(-1)]*G[{0, 1/(yu*yv), 1}, yw])/8 - 
     (G[{yu}, yv^(-1)]^2*G[{0, 1/(yu*yv), 1}, yw])/8 + 
     (G[{1}, yu^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv), 1}, yw])/16 + 
     (G[{1}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv), 1}, yw])/16 - 
     (G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv), 1}, yw])/16 - 
     (G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv), 1}, yw])/8 - 
     (G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv), 1}, yw])/16 + 
     (3*G[{0, 1}, yv^(-1)]*G[{0, 1/(yu*yv), 1}, yw])/16 - 
     (G[{0, 1}, yw]*G[{0, 1/(yu*yv), 1}, yw])/8 + 
     (G[{0, yu^(-1)}, yw]*G[{0, 1/(yu*yv), 1}, yw])/8 - 
     (3*G[{0, yu}, yv^(-1)]*G[{0, 1/(yu*yv), 1}, yw])/16 + 
     (G[{0, yv^(-1)}, yw]*G[{0, 1/(yu*yv), 1}, yw])/8 - 
     (G[{0, 1/(yu*yv)}, yw]*G[{0, 1/(yu*yv), 1}, yw])/8 + 
     (G[{1, yu^(-1)}, yw]*G[{0, 1/(yu*yv), 1}, yw])/16 + 
     (3*G[{1, yu}, yv^(-1)]*G[{0, 1/(yu*yv), 1}, yw])/16 + 
     (G[{1, yv^(-1)}, yw]*G[{0, 1/(yu*yv), 1}, yw])/16 + 
     (G[{yu^(-1), 1/(yu*yv)}, yw]*G[{0, 1/(yu*yv), 1}, yw])/16 + 
     (G[{yv^(-1), 1/(yu*yv)}, yw]*G[{0, 1/(yu*yv), 1}, yw])/16 - 
     (Pi^2*G[{0, 1/(yu*yv), yu^(-1)}, yw])/32 + 
     (G[{0}, yu^(-1)]^2*G[{0, 1/(yu*yv), yu^(-1)}, yw])/32 + 
     (G[{0}, yu^(-1)]*G[{0}, yv^(-1)]*G[{0, 1/(yu*yv), yu^(-1)}, yw])/16 + 
     (G[{0}, yv^(-1)]^2*G[{0, 1/(yu*yv), yu^(-1)}, yw])/32 - 
     (G[{0}, yu^(-1)]*G[{0}, yw]*G[{0, 1/(yu*yv), yu^(-1)}, yw])/16 - 
     (G[{0}, yv^(-1)]*G[{0}, yw]*G[{0, 1/(yu*yv), yu^(-1)}, yw])/16 + 
     (G[{0}, yw]^2*G[{0, 1/(yu*yv), yu^(-1)}, yw])/32 - 
     (G[{0}, yu^(-1)]*G[{1}, yu^(-1)]*G[{0, 1/(yu*yv), yu^(-1)}, yw])/16 - 
     (G[{0}, yv^(-1)]*G[{1}, yu^(-1)]*G[{0, 1/(yu*yv), yu^(-1)}, yw])/16 + 
     (G[{0}, yw]*G[{1}, yu^(-1)]*G[{0, 1/(yu*yv), yu^(-1)}, yw])/16 + 
     (G[{1}, yu^(-1)]^2*G[{0, 1/(yu*yv), yu^(-1)}, yw])/32 + 
     (G[{0}, yu^(-1)]*G[{1}, yv^(-1)]*G[{0, 1/(yu*yv), yu^(-1)}, yw])/16 + 
     (G[{0}, yv^(-1)]*G[{1}, yv^(-1)]*G[{0, 1/(yu*yv), yu^(-1)}, yw])/16 - 
     (G[{0}, yw]*G[{1}, yv^(-1)]*G[{0, 1/(yu*yv), yu^(-1)}, yw])/16 + 
     (G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*G[{0, 1/(yu*yv), yu^(-1)}, yw])/16 - 
     (3*G[{1}, yv^(-1)]^2*G[{0, 1/(yu*yv), yu^(-1)}, yw])/16 - 
     (G[{0}, yu^(-1)]*G[{1}, yw]*G[{0, 1/(yu*yv), yu^(-1)}, yw])/8 - 
     (G[{0}, yv^(-1)]*G[{1}, yw]*G[{0, 1/(yu*yv), yu^(-1)}, yw])/8 + 
     (G[{0}, yw]*G[{1}, yw]*G[{0, 1/(yu*yv), yu^(-1)}, yw])/8 + 
     (G[{1}, yu^(-1)]*G[{1}, yw]*G[{0, 1/(yu*yv), yu^(-1)}, yw])/4 - 
     (G[{1}, yv^(-1)]*G[{1}, yw]*G[{0, 1/(yu*yv), yu^(-1)}, yw])/4 - 
     (G[{1}, yw]^2*G[{0, 1/(yu*yv), yu^(-1)}, yw])/8 - 
     (G[{0}, yu^(-1)]*G[{yu}, yv^(-1)]*G[{0, 1/(yu*yv), yu^(-1)}, yw])/8 - 
     (G[{0}, yv^(-1)]*G[{yu}, yv^(-1)]*G[{0, 1/(yu*yv), yu^(-1)}, yw])/8 + 
     (G[{0}, yw]*G[{yu}, yv^(-1)]*G[{0, 1/(yu*yv), yu^(-1)}, yw])/8 + 
     (G[{1}, yv^(-1)]*G[{yu}, yv^(-1)]*G[{0, 1/(yu*yv), yu^(-1)}, yw])/4 + 
     (G[{1}, yw]*G[{yu}, yv^(-1)]*G[{0, 1/(yu*yv), yu^(-1)}, yw])/4 + 
     (G[{0}, yu^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv), yu^(-1)}, yw])/8 + 
     (G[{0}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv), yu^(-1)}, yw])/8 - 
     (G[{0}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv), yu^(-1)}, yw])/8 - 
     (G[{1}, yu^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv), yu^(-1)}, yw])/4 + 
     (G[{1}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv), yu^(-1)}, yw])/4 + 
     (G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv), yu^(-1)}, yw])/4 - 
     (G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv), yu^(-1)}, yw])/4 - 
     (G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv), yu^(-1)}, yw])/4 + 
     (G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv), yu^(-1)}, yw])/8 - 
     (G[{0, 1}, yv^(-1)]*G[{0, 1/(yu*yv), yu^(-1)}, yw])/16 + 
     (G[{0, 1}, yw]*G[{0, 1/(yu*yv), yu^(-1)}, yw])/16 - 
     (G[{0, yu^(-1)}, yw]*G[{0, 1/(yu*yv), yu^(-1)}, yw])/16 + 
     (G[{0, yu}, yv^(-1)]*G[{0, 1/(yu*yv), yu^(-1)}, yw])/16 - 
     (G[{0, yv^(-1)}, yw]*G[{0, 1/(yu*yv), yu^(-1)}, yw])/16 + 
     (G[{0, 1/(yu*yv)}, yw]*G[{0, 1/(yu*yv), yu^(-1)}, yw])/16 + 
     (G[{1, yu^(-1)}, yw]*G[{0, 1/(yu*yv), yu^(-1)}, yw])/4 - 
     (G[{1, yu}, yv^(-1)]*G[{0, 1/(yu*yv), yu^(-1)}, yw])/16 - 
     (G[{1, yv^(-1)}, yw]*G[{0, 1/(yu*yv), yu^(-1)}, yw])/8 - 
     (G[{1, 1/(yu*yv)}, yw]*G[{0, 1/(yu*yv), yu^(-1)}, yw])/4 + 
     (G[{yu^(-1), 1/(yu*yv)}, yw]*G[{0, 1/(yu*yv), yu^(-1)}, yw])/4 - 
     (G[{yv^(-1), 1/(yu*yv)}, yw]*G[{0, 1/(yu*yv), yu^(-1)}, yw])/8 + 
     (G[{0}, yu^(-1)]^2*G[{0, 1/(yu*yv), yv^(-1)}, yw])/32 + 
     (G[{0}, yu^(-1)]*G[{0}, yv^(-1)]*G[{0, 1/(yu*yv), yv^(-1)}, yw])/16 + 
     (G[{0}, yv^(-1)]^2*G[{0, 1/(yu*yv), yv^(-1)}, yw])/32 - 
     (G[{0}, yu^(-1)]*G[{0}, yw]*G[{0, 1/(yu*yv), yv^(-1)}, yw])/16 - 
     (G[{0}, yv^(-1)]*G[{0}, yw]*G[{0, 1/(yu*yv), yv^(-1)}, yw])/16 + 
     (G[{0}, yw]^2*G[{0, 1/(yu*yv), yv^(-1)}, yw])/32 - 
     (G[{0}, yu^(-1)]*G[{1}, yu^(-1)]*G[{0, 1/(yu*yv), yv^(-1)}, yw])/8 - 
     (G[{0}, yv^(-1)]*G[{1}, yu^(-1)]*G[{0, 1/(yu*yv), yv^(-1)}, yw])/8 + 
     (G[{0}, yw]*G[{1}, yu^(-1)]*G[{0, 1/(yu*yv), yv^(-1)}, yw])/8 + 
     (3*G[{1}, yu^(-1)]^2*G[{0, 1/(yu*yv), yv^(-1)}, yw])/32 + 
     (G[{0}, yu^(-1)]*G[{1}, yv^(-1)]*G[{0, 1/(yu*yv), yv^(-1)}, yw])/8 + 
     (G[{0}, yv^(-1)]*G[{1}, yv^(-1)]*G[{0, 1/(yu*yv), yv^(-1)}, yw])/8 - 
     (G[{0}, yw]*G[{1}, yv^(-1)]*G[{0, 1/(yu*yv), yv^(-1)}, yw])/8 - 
     (3*G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*G[{0, 1/(yu*yv), yv^(-1)}, yw])/16 - 
     (G[{1}, yv^(-1)]^2*G[{0, 1/(yu*yv), yv^(-1)}, yw])/16 - 
     (G[{0}, yu^(-1)]*G[{1}, yw]*G[{0, 1/(yu*yv), yv^(-1)}, yw])/8 - 
     (G[{0}, yv^(-1)]*G[{1}, yw]*G[{0, 1/(yu*yv), yv^(-1)}, yw])/8 + 
     (G[{0}, yw]*G[{1}, yw]*G[{0, 1/(yu*yv), yv^(-1)}, yw])/8 + 
     (G[{1}, yu^(-1)]*G[{1}, yw]*G[{0, 1/(yu*yv), yv^(-1)}, yw])/8 - 
     (G[{1}, yv^(-1)]*G[{1}, yw]*G[{0, 1/(yu*yv), yv^(-1)}, yw])/8 - 
     (G[{1}, yw]^2*G[{0, 1/(yu*yv), yv^(-1)}, yw])/8 - 
     (G[{0}, yu^(-1)]*G[{yu}, yv^(-1)]*G[{0, 1/(yu*yv), yv^(-1)}, yw])/8 - 
     (G[{0}, yv^(-1)]*G[{yu}, yv^(-1)]*G[{0, 1/(yu*yv), yv^(-1)}, yw])/8 + 
     (G[{0}, yw]*G[{yu}, yv^(-1)]*G[{0, 1/(yu*yv), yv^(-1)}, yw])/8 + 
     (G[{1}, yu^(-1)]*G[{yu}, yv^(-1)]*G[{0, 1/(yu*yv), yv^(-1)}, yw])/4 + 
     (G[{1}, yw]*G[{yu}, yv^(-1)]*G[{0, 1/(yu*yv), yv^(-1)}, yw])/4 + 
     (G[{0}, yu^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv), yv^(-1)}, yw])/8 + 
     (G[{0}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv), yv^(-1)}, yw])/8 - 
     (G[{0}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv), yv^(-1)}, yw])/8 - 
     (G[{1}, yu^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv), yv^(-1)}, yw])/8 + 
     (G[{1}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv), yv^(-1)}, yw])/8 + 
     (G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv), yv^(-1)}, yw])/4 - 
     (G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv), yv^(-1)}, yw])/4 - 
     (G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv), yv^(-1)}, yw])/4 + 
     (G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv), yv^(-1)}, yw])/8 - 
     (G[{0, 1}, yu^(-1)]*G[{0, 1/(yu*yv), yv^(-1)}, yw])/16 - 
     (G[{0, 1}, yw]*G[{0, 1/(yu*yv), yv^(-1)}, yw])/8 + 
     (G[{0, yu^(-1)}, yw]*G[{0, 1/(yu*yv), yv^(-1)}, yw])/8 + 
     (G[{0, yv^(-1)}, yw]*G[{0, 1/(yu*yv), yv^(-1)}, yw])/8 - 
     (G[{0, 1/(yu*yv)}, yw]*G[{0, 1/(yu*yv), yv^(-1)}, yw])/8 + 
     (G[{1, yu^(-1)}, yw]*G[{0, 1/(yu*yv), yv^(-1)}, yw])/4 + 
     (G[{1, yu}, yv^(-1)]*G[{0, 1/(yu*yv), yv^(-1)}, yw])/16 - 
     (G[{1, yv^(-1)}, yw]*G[{0, 1/(yu*yv), yv^(-1)}, yw])/8 - 
     (G[{1, 1/(yu*yv)}, yw]*G[{0, 1/(yu*yv), yv^(-1)}, yw])/4 + 
     (G[{yu^(-1), 1/(yu*yv)}, yw]*G[{0, 1/(yu*yv), yv^(-1)}, yw])/4 - 
     (G[{yv^(-1), 1/(yu*yv)}, yw]*G[{0, 1/(yu*yv), yv^(-1)}, yw])/8 + 
     (Pi^2*G[{0, 1/(yu*yv), 1/(yu*yv)}, yw])/48 - 
     (G[{0}, yu^(-1)]^2*G[{0, 1/(yu*yv), 1/(yu*yv)}, yw])/16 - 
     (G[{0}, yu^(-1)]*G[{0}, yv^(-1)]*G[{0, 1/(yu*yv), 1/(yu*yv)}, yw])/8 - 
     (G[{0}, yv^(-1)]^2*G[{0, 1/(yu*yv), 1/(yu*yv)}, yw])/16 + 
     (G[{0}, yu^(-1)]*G[{0}, yw]*G[{0, 1/(yu*yv), 1/(yu*yv)}, yw])/8 + 
     (G[{0}, yv^(-1)]*G[{0}, yw]*G[{0, 1/(yu*yv), 1/(yu*yv)}, yw])/8 - 
     (G[{0}, yw]^2*G[{0, 1/(yu*yv), 1/(yu*yv)}, yw])/16 + 
     (3*G[{0}, yu^(-1)]*G[{1}, yu^(-1)]*G[{0, 1/(yu*yv), 1/(yu*yv)}, yw])/
      16 + (3*G[{0}, yv^(-1)]*G[{1}, yu^(-1)]*G[{0, 1/(yu*yv), 1/(yu*yv)}, 
        yw])/16 - (3*G[{0}, yw]*G[{1}, yu^(-1)]*G[{0, 1/(yu*yv), 1/(yu*yv)}, 
        yw])/16 - (G[{1}, yu^(-1)]^2*G[{0, 1/(yu*yv), 1/(yu*yv)}, yw])/8 - 
     (3*G[{0}, yu^(-1)]*G[{1}, yv^(-1)]*G[{0, 1/(yu*yv), 1/(yu*yv)}, yw])/
      16 - (3*G[{0}, yv^(-1)]*G[{1}, yv^(-1)]*G[{0, 1/(yu*yv), 1/(yu*yv)}, 
        yw])/16 + (3*G[{0}, yw]*G[{1}, yv^(-1)]*G[{0, 1/(yu*yv), 1/(yu*yv)}, 
        yw])/16 + (G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*
       G[{0, 1/(yu*yv), 1/(yu*yv)}, yw])/4 + 
     (11*G[{1}, yv^(-1)]^2*G[{0, 1/(yu*yv), 1/(yu*yv)}, yw])/32 + 
     (G[{0}, yu^(-1)]*G[{1}, yw]*G[{0, 1/(yu*yv), 1/(yu*yv)}, yw])/16 + 
     (G[{0}, yv^(-1)]*G[{1}, yw]*G[{0, 1/(yu*yv), 1/(yu*yv)}, yw])/16 - 
     (G[{0}, yw]*G[{1}, yw]*G[{0, 1/(yu*yv), 1/(yu*yv)}, yw])/16 - 
     (G[{1}, yu^(-1)]*G[{1}, yw]*G[{0, 1/(yu*yv), 1/(yu*yv)}, yw])/16 - 
     (G[{1}, yv^(-1)]*G[{1}, yw]*G[{0, 1/(yu*yv), 1/(yu*yv)}, yw])/16 + 
     (G[{0}, yu^(-1)]*G[{yu}, yv^(-1)]*G[{0, 1/(yu*yv), 1/(yu*yv)}, yw])/4 + 
     (G[{0}, yv^(-1)]*G[{yu}, yv^(-1)]*G[{0, 1/(yu*yv), 1/(yu*yv)}, yw])/4 - 
     (G[{0}, yw]*G[{yu}, yv^(-1)]*G[{0, 1/(yu*yv), 1/(yu*yv)}, yw])/4 - 
     (3*G[{1}, yu^(-1)]*G[{yu}, yv^(-1)]*G[{0, 1/(yu*yv), 1/(yu*yv)}, yw])/
      8 - (3*G[{1}, yv^(-1)]*G[{yu}, yv^(-1)]*G[{0, 1/(yu*yv), 1/(yu*yv)}, 
        yw])/8 + (G[{yu}, yv^(-1)]^2*G[{0, 1/(yu*yv), 1/(yu*yv)}, yw])/8 - 
     (G[{0}, yu^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv), 1/(yu*yv)}, yw])/
      16 - (G[{0}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv), 1/(yu*yv)}, 
        yw])/16 + (G[{0}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv), 1/(yu*yv)}, 
        yw])/16 + (G[{1}, yu^(-1)]*G[{1/(yu*yv)}, yw]*
       G[{0, 1/(yu*yv), 1/(yu*yv)}, yw])/16 + 
     (G[{1}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv), 1/(yu*yv)}, yw])/
      16 - (G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv), 1/(yu*yv)}, 
        yw])/16 - (G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*
       G[{0, 1/(yu*yv), 1/(yu*yv)}, yw])/16 + 
     (G[{0, 1}, yu^(-1)]*G[{0, 1/(yu*yv), 1/(yu*yv)}, yw])/8 - 
     (G[{0, 1}, yv^(-1)]*G[{0, 1/(yu*yv), 1/(yu*yv)}, yw])/16 + 
     (G[{0, 1}, yw]*G[{0, 1/(yu*yv), 1/(yu*yv)}, yw])/8 - 
     (G[{0, yu^(-1)}, yw]*G[{0, 1/(yu*yv), 1/(yu*yv)}, yw])/8 + 
     (G[{0, yu}, yv^(-1)]*G[{0, 1/(yu*yv), 1/(yu*yv)}, yw])/16 - 
     (G[{0, yv^(-1)}, yw]*G[{0, 1/(yu*yv), 1/(yu*yv)}, yw])/8 + 
     (G[{0, 1/(yu*yv)}, yw]*G[{0, 1/(yu*yv), 1/(yu*yv)}, yw])/8 + 
     (G[{1, yu^(-1)}, yw]*G[{0, 1/(yu*yv), 1/(yu*yv)}, yw])/16 - 
     (3*G[{1, yu}, yv^(-1)]*G[{0, 1/(yu*yv), 1/(yu*yv)}, yw])/16 + 
     (G[{1, yv^(-1)}, yw]*G[{0, 1/(yu*yv), 1/(yu*yv)}, yw])/16 + 
     (G[{yu^(-1), 1/(yu*yv)}, yw]*G[{0, 1/(yu*yv), 1/(yu*yv)}, yw])/16 + 
     (G[{yv^(-1), 1/(yu*yv)}, yw]*G[{0, 1/(yu*yv), 1/(yu*yv)}, yw])/16 + 
     (5*Pi^2*G[{1, 1, yu^(-1)}, yw])/192 - 
     (3*G[{0}, yu^(-1)]^2*G[{1, 1, yu^(-1)}, yw])/32 - 
     (3*G[{0}, yu^(-1)]*G[{0}, yv^(-1)]*G[{1, 1, yu^(-1)}, yw])/16 - 
     (3*G[{0}, yv^(-1)]^2*G[{1, 1, yu^(-1)}, yw])/32 + 
     (3*G[{0}, yu^(-1)]*G[{0}, yw]*G[{1, 1, yu^(-1)}, yw])/16 + 
     (3*G[{0}, yv^(-1)]*G[{0}, yw]*G[{1, 1, yu^(-1)}, yw])/16 - 
     (3*G[{0}, yw]^2*G[{1, 1, yu^(-1)}, yw])/32 + 
     (3*G[{0}, yu^(-1)]*G[{1}, yu^(-1)]*G[{1, 1, yu^(-1)}, yw])/8 + 
     (3*G[{0}, yv^(-1)]*G[{1}, yu^(-1)]*G[{1, 1, yu^(-1)}, yw])/8 - 
     (3*G[{0}, yw]*G[{1}, yu^(-1)]*G[{1, 1, yu^(-1)}, yw])/8 - 
     (33*G[{1}, yu^(-1)]^2*G[{1, 1, yu^(-1)}, yw])/128 - 
     (G[{0}, yu^(-1)]*G[{1}, yv^(-1)]*G[{1, 1, yu^(-1)}, yw])/4 - 
     (G[{0}, yv^(-1)]*G[{1}, yv^(-1)]*G[{1, 1, yu^(-1)}, yw])/4 + 
     (G[{0}, yw]*G[{1}, yv^(-1)]*G[{1, 1, yu^(-1)}, yw])/4 + 
     (G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*G[{1, 1, yu^(-1)}, yw])/64 + 
     (19*G[{1}, yv^(-1)]^2*G[{1, 1, yu^(-1)}, yw])/64 - 
     (G[{0}, yu^(-1)]*G[{1}, yw]*G[{1, 1, yu^(-1)}, yw])/4 - 
     (G[{0}, yv^(-1)]*G[{1}, yw]*G[{1, 1, yu^(-1)}, yw])/4 + 
     (G[{0}, yw]*G[{1}, yw]*G[{1, 1, yu^(-1)}, yw])/4 + 
     (15*G[{1}, yu^(-1)]*G[{1}, yw]*G[{1, 1, yu^(-1)}, yw])/64 + 
     (3*G[{1}, yv^(-1)]*G[{1}, yw]*G[{1, 1, yu^(-1)}, yw])/32 - 
     (11*G[{1}, yw]^2*G[{1, 1, yu^(-1)}, yw])/128 + 
     (G[{0}, yu^(-1)]*G[{yu}, yv^(-1)]*G[{1, 1, yu^(-1)}, yw])/4 + 
     (G[{0}, yv^(-1)]*G[{yu}, yv^(-1)]*G[{1, 1, yu^(-1)}, yw])/4 - 
     (G[{0}, yw]*G[{yu}, yv^(-1)]*G[{1, 1, yu^(-1)}, yw])/4 - 
     (G[{1}, yu^(-1)]*G[{yu}, yv^(-1)]*G[{1, 1, yu^(-1)}, yw])/4 - 
     (9*G[{1}, yv^(-1)]*G[{yu}, yv^(-1)]*G[{1, 1, yu^(-1)}, yw])/64 + 
     (11*G[{1}, yw]*G[{yu}, yv^(-1)]*G[{1, 1, yu^(-1)}, yw])/64 - 
     (7*G[{yu}, yv^(-1)]^2*G[{1, 1, yu^(-1)}, yw])/128 + 
     (3*G[{0}, yu^(-1)]*G[{1/(yu*yv)}, yw]*G[{1, 1, yu^(-1)}, yw])/16 + 
     (3*G[{0}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{1, 1, yu^(-1)}, yw])/16 - 
     (3*G[{0}, yw]*G[{1/(yu*yv)}, yw]*G[{1, 1, yu^(-1)}, yw])/16 - 
     (3*G[{1}, yu^(-1)]*G[{1/(yu*yv)}, yw]*G[{1, 1, yu^(-1)}, yw])/64 - 
     (5*G[{1}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{1, 1, yu^(-1)}, yw])/64 + 
     (G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{1, 1, yu^(-1)}, yw])/4 + 
     (5*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{1, 1, yu^(-1)}, yw])/32 - 
     (G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{1, 1, yu^(-1)}, yw])/4 + 
     (3*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{1, 1, yu^(-1)}, yw])/64 - 
     (3*G[{1/(yu*yv)}, yw]^2*G[{1, 1, yu^(-1)}, yw])/64 + 
     (G[{0, 1}, yu^(-1)]*G[{1, 1, yu^(-1)}, yw])/64 + 
     (3*G[{0, 1}, yv^(-1)]*G[{1, 1, yu^(-1)}, yw])/64 - 
     (3*G[{0, yu}, yv^(-1)]*G[{1, 1, yu^(-1)}, yw])/64 - 
     (5*G[{1, yu^(-1)}, yw]*G[{1, 1, yu^(-1)}, yw])/32 + 
     (G[{1, yu}, yv^(-1)]*G[{1, 1, yu^(-1)}, yw])/32 - 
     (3*G[{1, yv^(-1)}, yw]*G[{1, 1, yu^(-1)}, yw])/64 - 
     (11*G[{1, 1/(yu*yv)}, yw]*G[{1, 1, yu^(-1)}, yw])/64 - 
     (5*G[{yu^(-1), 1/(yu*yv)}, yw]*G[{1, 1, yu^(-1)}, yw])/32 - 
     (3*G[{yv^(-1), 1/(yu*yv)}, yw]*G[{1, 1, yu^(-1)}, yw])/64 - 
     (5*Pi^2*G[{1, 1, yu}, yv^(-1)])/192 + 
     (3*G[{1}, yu^(-1)]^2*G[{1, 1, yu}, yv^(-1)])/128 - 
     (15*G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*G[{1, 1, yu}, yv^(-1)])/64 - 
     (7*G[{1}, yv^(-1)]^2*G[{1, 1, yu}, yv^(-1)])/64 - 
     (5*G[{1}, yu^(-1)]*G[{1}, yw]*G[{1, 1, yu}, yv^(-1)])/64 - 
     (3*G[{1}, yv^(-1)]*G[{1}, yw]*G[{1, 1, yu}, yv^(-1)])/64 - 
     (9*G[{1}, yw]^2*G[{1, 1, yu}, yv^(-1)])/128 + 
     (3*G[{1}, yw]*G[{yu}, yv^(-1)]*G[{1, 1, yu}, yv^(-1)])/64 + 
     (5*G[{1}, yu^(-1)]*G[{1/(yu*yv)}, yw]*G[{1, 1, yu}, yv^(-1)])/64 + 
     (3*G[{1}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{1, 1, yu}, yv^(-1)])/64 + 
     (9*G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{1, 1, yu}, yv^(-1)])/64 + 
     (G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{1, 1, yu}, yv^(-1)])/32 - 
     (3*G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{1, 1, yu}, yv^(-1)])/64 - 
     (5*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{1, 1, yu}, yv^(-1)])/64 - 
     (3*G[{1/(yu*yv)}, yw]^2*G[{1, 1, yu}, yv^(-1)])/64 - 
     (7*G[{0, 1}, yu^(-1)]*G[{1, 1, yu}, yv^(-1)])/64 - 
     (G[{0, 1}, yv^(-1)]*G[{1, 1, yu}, yv^(-1)])/64 + 
     (G[{0, yu}, yv^(-1)]*G[{1, 1, yu}, yv^(-1)])/64 - 
     (G[{1, yu^(-1)}, yw]*G[{1, 1, yu}, yv^(-1)])/32 + 
     (G[{1, yu}, yv^(-1)]*G[{1, 1, yu}, yv^(-1)])/64 + 
     (5*G[{1, yv^(-1)}, yw]*G[{1, 1, yu}, yv^(-1)])/64 - 
     (3*G[{1, 1/(yu*yv)}, yw]*G[{1, 1, yu}, yv^(-1)])/64 - 
     (G[{yu^(-1), 1/(yu*yv)}, yw]*G[{1, 1, yu}, yv^(-1)])/32 + 
     (5*G[{yv^(-1), 1/(yu*yv)}, yw]*G[{1, 1, yu}, yv^(-1)])/64 + 
     (Pi^2*G[{1, 1, yv^(-1)}, yw])/24 - 
     (3*G[{0}, yu^(-1)]^2*G[{1, 1, yv^(-1)}, yw])/32 - 
     (3*G[{0}, yu^(-1)]*G[{0}, yv^(-1)]*G[{1, 1, yv^(-1)}, yw])/16 - 
     (3*G[{0}, yv^(-1)]^2*G[{1, 1, yv^(-1)}, yw])/32 + 
     (3*G[{0}, yu^(-1)]*G[{0}, yw]*G[{1, 1, yv^(-1)}, yw])/16 + 
     (3*G[{0}, yv^(-1)]*G[{0}, yw]*G[{1, 1, yv^(-1)}, yw])/16 - 
     (3*G[{0}, yw]^2*G[{1, 1, yv^(-1)}, yw])/32 + 
     (G[{0}, yu^(-1)]*G[{1}, yu^(-1)]*G[{1, 1, yv^(-1)}, yw])/8 + 
     (G[{0}, yv^(-1)]*G[{1}, yu^(-1)]*G[{1, 1, yv^(-1)}, yw])/8 - 
     (G[{0}, yw]*G[{1}, yu^(-1)]*G[{1, 1, yv^(-1)}, yw])/8 - 
     (G[{1}, yu^(-1)]^2*G[{1, 1, yv^(-1)}, yw])/32 + 
     (G[{1}, yv^(-1)]^2*G[{1, 1, yv^(-1)}, yw])/16 - 
     (G[{0}, yu^(-1)]*G[{1}, yw]*G[{1, 1, yv^(-1)}, yw])/4 - 
     (G[{0}, yv^(-1)]*G[{1}, yw]*G[{1, 1, yv^(-1)}, yw])/4 + 
     (G[{0}, yw]*G[{1}, yw]*G[{1, 1, yv^(-1)}, yw])/4 + 
     (3*G[{1}, yu^(-1)]*G[{1}, yw]*G[{1, 1, yv^(-1)}, yw])/16 + 
     (G[{1}, yv^(-1)]*G[{1}, yw]*G[{1, 1, yv^(-1)}, yw])/8 - 
     (3*G[{1}, yw]^2*G[{1, 1, yv^(-1)}, yw])/32 + 
     (G[{0}, yu^(-1)]*G[{yu}, yv^(-1)]*G[{1, 1, yv^(-1)}, yw])/4 + 
     (G[{0}, yv^(-1)]*G[{yu}, yv^(-1)]*G[{1, 1, yv^(-1)}, yw])/4 - 
     (G[{0}, yw]*G[{yu}, yv^(-1)]*G[{1, 1, yv^(-1)}, yw])/4 - 
     (3*G[{1}, yu^(-1)]*G[{yu}, yv^(-1)]*G[{1, 1, yv^(-1)}, yw])/16 - 
     (G[{1}, yv^(-1)]*G[{yu}, yv^(-1)]*G[{1, 1, yv^(-1)}, yw])/4 + 
     (3*G[{1}, yw]*G[{yu}, yv^(-1)]*G[{1, 1, yv^(-1)}, yw])/16 - 
     (G[{yu}, yv^(-1)]^2*G[{1, 1, yv^(-1)}, yw])/32 + 
     (G[{1}, yu^(-1)]*G[{1/(yu*yv)}, yw]*G[{1, 1, yv^(-1)}, yw])/16 + 
     (G[{1}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{1, 1, yv^(-1)}, yw])/16 + 
     (G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{1, 1, yv^(-1)}, yw])/8 - 
     (G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{1, 1, yv^(-1)}, yw])/16 - 
     (G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{1, 1, yv^(-1)}, yw])/8 + 
     (G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{1, 1, yv^(-1)}, yw])/16 + 
     (G[{0, 1}, yv^(-1)]*G[{1, 1, yv^(-1)}, yw])/8 - 
     (G[{0, yu}, yv^(-1)]*G[{1, 1, yv^(-1)}, yw])/8 + 
     (G[{1, yu^(-1)}, yw]*G[{1, 1, yv^(-1)}, yw])/16 + 
     (G[{1, yu}, yv^(-1)]*G[{1, 1, yv^(-1)}, yw])/8 - 
     (G[{1, yv^(-1)}, yw]*G[{1, 1, yv^(-1)}, yw])/16 + 
     (G[{yu^(-1), 1/(yu*yv)}, yw]*G[{1, 1, yv^(-1)}, yw])/16 - 
     (G[{yv^(-1), 1/(yu*yv)}, yw]*G[{1, 1, yv^(-1)}, yw])/16 + 
     (Pi^2*G[{1, 1, 1/(yu*yv)}, yw])/64 + 
     (G[{0}, yu^(-1)]^2*G[{1, 1, 1/(yu*yv)}, yw])/16 + 
     (G[{0}, yu^(-1)]*G[{0}, yv^(-1)]*G[{1, 1, 1/(yu*yv)}, yw])/8 + 
     (G[{0}, yv^(-1)]^2*G[{1, 1, 1/(yu*yv)}, yw])/16 - 
     (G[{0}, yu^(-1)]*G[{0}, yw]*G[{1, 1, 1/(yu*yv)}, yw])/8 - 
     (G[{0}, yv^(-1)]*G[{0}, yw]*G[{1, 1, 1/(yu*yv)}, yw])/8 + 
     (G[{0}, yw]^2*G[{1, 1, 1/(yu*yv)}, yw])/16 - 
     (G[{0}, yu^(-1)]*G[{1}, yu^(-1)]*G[{1, 1, 1/(yu*yv)}, yw])/8 - 
     (G[{0}, yv^(-1)]*G[{1}, yu^(-1)]*G[{1, 1, 1/(yu*yv)}, yw])/8 + 
     (G[{0}, yw]*G[{1}, yu^(-1)]*G[{1, 1, 1/(yu*yv)}, yw])/8 + 
     (5*G[{1}, yu^(-1)]^2*G[{1, 1, 1/(yu*yv)}, yw])/128 - 
     (G[{0}, yu^(-1)]*G[{1}, yv^(-1)]*G[{1, 1, 1/(yu*yv)}, yw])/8 - 
     (G[{0}, yv^(-1)]*G[{1}, yv^(-1)]*G[{1, 1, 1/(yu*yv)}, yw])/8 + 
     (G[{0}, yw]*G[{1}, yv^(-1)]*G[{1, 1, 1/(yu*yv)}, yw])/8 - 
     (G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*G[{1, 1, 1/(yu*yv)}, yw])/64 - 
     (3*G[{1}, yv^(-1)]^2*G[{1, 1, 1/(yu*yv)}, yw])/64 - 
     (11*G[{1}, yu^(-1)]*G[{1}, yw]*G[{1, 1, 1/(yu*yv)}, yw])/64 - 
     (11*G[{1}, yv^(-1)]*G[{1}, yw]*G[{1, 1, 1/(yu*yv)}, yw])/32 - 
     (33*G[{1}, yw]^2*G[{1, 1, 1/(yu*yv)}, yw])/128 + 
     (3*G[{1}, yu^(-1)]*G[{yu}, yv^(-1)]*G[{1, 1, 1/(yu*yv)}, yw])/16 + 
     (9*G[{1}, yv^(-1)]*G[{yu}, yv^(-1)]*G[{1, 1, 1/(yu*yv)}, yw])/64 + 
     (33*G[{1}, yw]*G[{yu}, yv^(-1)]*G[{1, 1, 1/(yu*yv)}, yw])/64 - 
     (21*G[{yu}, yv^(-1)]^2*G[{1, 1, 1/(yu*yv)}, yw])/128 + 
     (G[{0}, yu^(-1)]*G[{1/(yu*yv)}, yw]*G[{1, 1, 1/(yu*yv)}, yw])/16 + 
     (G[{0}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{1, 1, 1/(yu*yv)}, yw])/16 - 
     (G[{0}, yw]*G[{1/(yu*yv)}, yw]*G[{1, 1, 1/(yu*yv)}, yw])/16 - 
     (9*G[{1}, yu^(-1)]*G[{1/(yu*yv)}, yw]*G[{1, 1, 1/(yu*yv)}, yw])/64 - 
     (7*G[{1}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{1, 1, 1/(yu*yv)}, yw])/64 - 
     (G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{1, 1, 1/(yu*yv)}, yw])/8 + 
     (G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{1, 1, 1/(yu*yv)}, yw])/32 + 
     (G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{1, 1, 1/(yu*yv)}, yw])/8 + 
     (G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{1, 1, 1/(yu*yv)}, yw])/64 + 
     (3*G[{1/(yu*yv)}, yw]^2*G[{1, 1, 1/(yu*yv)}, yw])/64 - 
     (G[{0, 1}, yu^(-1)]*G[{1, 1, 1/(yu*yv)}, yw])/64 + 
     (13*G[{0, 1}, yv^(-1)]*G[{1, 1, 1/(yu*yv)}, yw])/64 - 
     (13*G[{0, yu}, yv^(-1)]*G[{1, 1, 1/(yu*yv)}, yw])/64 - 
     (G[{1, yu^(-1)}, yw]*G[{1, 1, 1/(yu*yv)}, yw])/32 + 
     (7*G[{1, yu}, yv^(-1)]*G[{1, 1, 1/(yu*yv)}, yw])/32 - 
     (G[{1, yv^(-1)}, yw]*G[{1, 1, 1/(yu*yv)}, yw])/64 + 
     (11*G[{1, 1/(yu*yv)}, yw]*G[{1, 1, 1/(yu*yv)}, yw])/64 - 
     (G[{yu^(-1), 1/(yu*yv)}, yw]*G[{1, 1, 1/(yu*yv)}, yw])/32 - 
     (G[{yv^(-1), 1/(yu*yv)}, yw]*G[{1, 1, 1/(yu*yv)}, yw])/64 + 
     (41*Pi^2*G[{1, yu^(-1), yu^(-1)}, yw])/768 - 
     (G[{0}, yu^(-1)]^2*G[{1, yu^(-1), yu^(-1)}, yw])/16 - 
     (G[{0}, yu^(-1)]*G[{0}, yv^(-1)]*G[{1, yu^(-1), yu^(-1)}, yw])/8 - 
     (G[{0}, yv^(-1)]^2*G[{1, yu^(-1), yu^(-1)}, yw])/16 + 
     (G[{0}, yu^(-1)]*G[{0}, yw]*G[{1, yu^(-1), yu^(-1)}, yw])/8 + 
     (G[{0}, yv^(-1)]*G[{0}, yw]*G[{1, yu^(-1), yu^(-1)}, yw])/8 - 
     (G[{0}, yw]^2*G[{1, yu^(-1), yu^(-1)}, yw])/16 + 
     (G[{0}, yu^(-1)]*G[{1}, yu^(-1)]*G[{1, yu^(-1), yu^(-1)}, yw])/4 + 
     (G[{0}, yv^(-1)]*G[{1}, yu^(-1)]*G[{1, yu^(-1), yu^(-1)}, yw])/4 - 
     (G[{0}, yw]*G[{1}, yu^(-1)]*G[{1, yu^(-1), yu^(-1)}, yw])/4 - 
     (9*G[{1}, yu^(-1)]^2*G[{1, yu^(-1), yu^(-1)}, yw])/64 - 
     (G[{0}, yu^(-1)]*G[{1}, yv^(-1)]*G[{1, yu^(-1), yu^(-1)}, yw])/4 - 
     (G[{0}, yv^(-1)]*G[{1}, yv^(-1)]*G[{1, yu^(-1), yu^(-1)}, yw])/4 + 
     (G[{0}, yw]*G[{1}, yv^(-1)]*G[{1, yu^(-1), yu^(-1)}, yw])/4 - 
     (7*G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*G[{1, yu^(-1), yu^(-1)}, yw])/32 + 
     (29*G[{1}, yv^(-1)]^2*G[{1, yu^(-1), yu^(-1)}, yw])/64 - 
     (G[{0}, yu^(-1)]*G[{1}, yw]*G[{1, yu^(-1), yu^(-1)}, yw])/2 - 
     (G[{0}, yv^(-1)]*G[{1}, yw]*G[{1, yu^(-1), yu^(-1)}, yw])/2 + 
     (G[{0}, yw]*G[{1}, yw]*G[{1, yu^(-1), yu^(-1)}, yw])/2 + 
     (7*G[{1}, yu^(-1)]*G[{1}, yw]*G[{1, yu^(-1), yu^(-1)}, yw])/32 + 
     (13*G[{1}, yv^(-1)]*G[{1}, yw]*G[{1, yu^(-1), yu^(-1)}, yw])/32 - 
     (3*G[{1}, yw]^2*G[{1, yu^(-1), yu^(-1)}, yw])/16 + 
     (G[{0}, yu^(-1)]*G[{yu}, yv^(-1)]*G[{1, yu^(-1), yu^(-1)}, yw])/4 + 
     (G[{0}, yv^(-1)]*G[{yu}, yv^(-1)]*G[{1, yu^(-1), yu^(-1)}, yw])/4 - 
     (G[{0}, yw]*G[{yu}, yv^(-1)]*G[{1, yu^(-1), yu^(-1)}, yw])/4 - 
     (9*G[{1}, yv^(-1)]*G[{yu}, yv^(-1)]*G[{1, yu^(-1), yu^(-1)}, yw])/32 + 
     (3*G[{1}, yw]*G[{yu}, yv^(-1)]*G[{1, yu^(-1), yu^(-1)}, yw])/8 - 
     (7*G[{yu}, yv^(-1)]^2*G[{1, yu^(-1), yu^(-1)}, yw])/64 + 
     (G[{0}, yu^(-1)]*G[{1/(yu*yv)}, yw]*G[{1, yu^(-1), yu^(-1)}, yw])/4 + 
     (G[{0}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{1, yu^(-1), yu^(-1)}, yw])/4 - 
     (G[{0}, yw]*G[{1/(yu*yv)}, yw]*G[{1, yu^(-1), yu^(-1)}, yw])/4 - 
     (7*G[{1}, yu^(-1)]*G[{1/(yu*yv)}, yw]*G[{1, yu^(-1), yu^(-1)}, yw])/32 + 
     (15*G[{1}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{1, yu^(-1), yu^(-1)}, yw])/
      64 + (33*G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{1, yu^(-1), yu^(-1)}, yw])/
      64 - (3*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{1, yu^(-1), yu^(-1)}, 
        yw])/16 - (33*G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw]*
       G[{1, yu^(-1), yu^(-1)}, yw])/64 + 
     (3*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{1, yu^(-1), yu^(-1)}, yw])/
      32 - (3*G[{1/(yu*yv)}, yw]^2*G[{1, yu^(-1), yu^(-1)}, yw])/64 + 
     (G[{0, 1}, yu^(-1)]*G[{1, yu^(-1), yu^(-1)}, yw])/32 + 
     (G[{0, 1}, yv^(-1)]*G[{1, yu^(-1), yu^(-1)}, yw])/8 - 
     (G[{0, 1}, yw]*G[{1, yu^(-1), yu^(-1)}, yw])/4 + 
     (G[{0, yu^(-1)}, yw]*G[{1, yu^(-1), yu^(-1)}, yw])/4 - 
     (G[{0, yu}, yv^(-1)]*G[{1, yu^(-1), yu^(-1)}, yw])/8 + 
     (G[{0, yv^(-1)}, yw]*G[{1, yu^(-1), yu^(-1)}, yw])/4 - 
     (G[{0, 1/(yu*yv)}, yw]*G[{1, yu^(-1), yu^(-1)}, yw])/4 - 
     (G[{1, yu^(-1)}, yw]*G[{1, yu^(-1), yu^(-1)}, yw])/8 + 
     (3*G[{1, yu}, yv^(-1)]*G[{1, yu^(-1), yu^(-1)}, yw])/32 - 
     (3*G[{1, yv^(-1)}, yw]*G[{1, yu^(-1), yu^(-1)}, yw])/32 - 
     (11*G[{1, 1/(yu*yv)}, yw]*G[{1, yu^(-1), yu^(-1)}, yw])/32 + 
     (3*G[{yu^(-1), 1/(yu*yv)}, yw]*G[{1, yu^(-1), yu^(-1)}, yw])/16 - 
     (3*G[{yv^(-1), 1/(yu*yv)}, yw]*G[{1, yu^(-1), yu^(-1)}, yw])/32 + 
     (3*G[{0}, yu^(-1)]*G[{1/(yu*yv)}, yw]*G[{1, yu^(-1), yv^(-1)}, yw])/16 + 
     (3*G[{0}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{1, yu^(-1), yv^(-1)}, yw])/16 - 
     (3*G[{0}, yw]*G[{1/(yu*yv)}, yw]*G[{1, yu^(-1), yv^(-1)}, yw])/16 - 
     (G[{1}, yu^(-1)]*G[{1/(yu*yv)}, yw]*G[{1, yu^(-1), yv^(-1)}, yw])/4 + 
     (G[{1}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{1, yu^(-1), yv^(-1)}, yw])/8 + 
     (G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{1, yu^(-1), yv^(-1)}, yw])/4 - 
     (G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{1, yu^(-1), yv^(-1)}, yw])/4 - 
     (G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{1, yu^(-1), yv^(-1)}, yw])/4 + 
     (G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{1, yu^(-1), yv^(-1)}, yw])/8 - 
     (G[{1, yv^(-1)}, yw]*G[{1, yu^(-1), yv^(-1)}, yw])/8 - 
     (G[{1, 1/(yu*yv)}, yw]*G[{1, yu^(-1), yv^(-1)}, yw])/4 + 
     (G[{yu^(-1), 1/(yu*yv)}, yw]*G[{1, yu^(-1), yv^(-1)}, yw])/4 - 
     (G[{yv^(-1), 1/(yu*yv)}, yw]*G[{1, yu^(-1), yv^(-1)}, yw])/8 + 
     (11*Pi^2*G[{1, yu^(-1), 1/(yu*yv)}, yw])/768 - 
     (G[{0}, yu^(-1)]^2*G[{1, yu^(-1), 1/(yu*yv)}, yw])/32 - 
     (G[{0}, yu^(-1)]*G[{0}, yv^(-1)]*G[{1, yu^(-1), 1/(yu*yv)}, yw])/16 - 
     (G[{0}, yv^(-1)]^2*G[{1, yu^(-1), 1/(yu*yv)}, yw])/32 + 
     (G[{0}, yu^(-1)]*G[{0}, yw]*G[{1, yu^(-1), 1/(yu*yv)}, yw])/16 + 
     (G[{0}, yv^(-1)]*G[{0}, yw]*G[{1, yu^(-1), 1/(yu*yv)}, yw])/16 - 
     (G[{0}, yw]^2*G[{1, yu^(-1), 1/(yu*yv)}, yw])/32 + 
     (G[{1}, yu^(-1)]^2*G[{1, yu^(-1), 1/(yu*yv)}, yw])/128 + 
     (G[{0}, yu^(-1)]*G[{1}, yv^(-1)]*G[{1, yu^(-1), 1/(yu*yv)}, yw])/8 + 
     (G[{0}, yv^(-1)]*G[{1}, yv^(-1)]*G[{1, yu^(-1), 1/(yu*yv)}, yw])/8 - 
     (G[{0}, yw]*G[{1}, yv^(-1)]*G[{1, yu^(-1), 1/(yu*yv)}, yw])/8 - 
     (G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*G[{1, yu^(-1), 1/(yu*yv)}, yw])/64 - 
     (3*G[{1}, yv^(-1)]^2*G[{1, yu^(-1), 1/(yu*yv)}, yw])/32 + 
     (G[{1}, yu^(-1)]*G[{1}, yw]*G[{1, yu^(-1), 1/(yu*yv)}, yw])/64 + 
     (G[{1}, yv^(-1)]*G[{1}, yw]*G[{1, yu^(-1), 1/(yu*yv)}, yw])/16 + 
     (5*G[{1}, yw]^2*G[{1, yu^(-1), 1/(yu*yv)}, yw])/128 - 
     (7*G[{1}, yv^(-1)]*G[{yu}, yv^(-1)]*G[{1, yu^(-1), 1/(yu*yv)}, yw])/64 - 
     (5*G[{1}, yw]*G[{yu}, yv^(-1)]*G[{1, yu^(-1), 1/(yu*yv)}, yw])/64 + 
     (7*G[{yu}, yv^(-1)]^2*G[{1, yu^(-1), 1/(yu*yv)}, yw])/128 + 
     (3*G[{1}, yu^(-1)]*G[{1/(yu*yv)}, yw]*G[{1, yu^(-1), 1/(yu*yv)}, yw])/
      64 - (G[{1}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{1, yu^(-1), 1/(yu*yv)}, 
        yw])/16 - (G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{1, yu^(-1), 1/(yu*yv)}, 
        yw])/64 - (G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*
       G[{1, yu^(-1), 1/(yu*yv)}, yw])/32 + 
     (G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{1, yu^(-1), 1/(yu*yv)}, yw])/
      64 - (3*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{1, yu^(-1), 1/(yu*yv)}, 
        yw])/64 - (G[{0, 1}, yu^(-1)]*G[{1, yu^(-1), 1/(yu*yv)}, yw])/64 + 
     (3*G[{0, 1}, yv^(-1)]*G[{1, yu^(-1), 1/(yu*yv)}, yw])/64 - 
     (3*G[{0, yu}, yv^(-1)]*G[{1, yu^(-1), 1/(yu*yv)}, yw])/64 + 
     (3*G[{1, yu^(-1)}, yw]*G[{1, yu^(-1), 1/(yu*yv)}, yw])/64 + 
     (G[{1, yu}, yv^(-1)]*G[{1, yu^(-1), 1/(yu*yv)}, yw])/16 + 
     (19*G[{1, yv^(-1)}, yw]*G[{1, yu^(-1), 1/(yu*yv)}, yw])/64 - 
     (5*G[{1, 1/(yu*yv)}, yw]*G[{1, yu^(-1), 1/(yu*yv)}, yw])/64 + 
     (G[{yu^(-1), 1/(yu*yv)}, yw]*G[{1, yu^(-1), 1/(yu*yv)}, yw])/32 + 
     (3*G[{yv^(-1), 1/(yu*yv)}, yw]*G[{1, yu^(-1), 1/(yu*yv)}, yw])/64 - 
     (5*Pi^2*G[{1, yu, yu}, yv^(-1)])/256 + 
     (3*G[{1}, yu^(-1)]^2*G[{1, yu, yu}, yv^(-1)])/64 + 
     (G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*G[{1, yu, yu}, yv^(-1)])/32 - 
     (5*G[{1}, yv^(-1)]^2*G[{1, yu, yu}, yv^(-1)])/64 + 
     (G[{1}, yu^(-1)]*G[{1}, yw]*G[{1, yu, yu}, yv^(-1)])/32 - 
     (3*G[{1}, yv^(-1)]*G[{1}, yw]*G[{1, yu, yu}, yv^(-1)])/64 - 
     (G[{1}, yw]^2*G[{1, yu, yu}, yv^(-1)])/32 - 
     (G[{1}, yw]*G[{yu}, yv^(-1)]*G[{1, yu, yu}, yv^(-1)])/32 - 
     (G[{1}, yu^(-1)]*G[{1/(yu*yv)}, yw]*G[{1, yu, yu}, yv^(-1)])/32 + 
     (3*G[{1}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{1, yu, yu}, yv^(-1)])/64 + 
     (G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{1, yu, yu}, yv^(-1)])/16 + 
     (G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{1, yu, yu}, yv^(-1)])/8 + 
     (G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{1, yu, yu}, yv^(-1)])/32 - 
     (3*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{1, yu, yu}, yv^(-1)])/32 - 
     (3*G[{1/(yu*yv)}, yw]^2*G[{1, yu, yu}, yv^(-1)])/64 + 
     (G[{0, 1}, yu^(-1)]*G[{1, yu, yu}, yv^(-1)])/32 - 
     (G[{0, 1}, yv^(-1)]*G[{1, yu, yu}, yv^(-1)])/16 + 
     (G[{0, yu}, yv^(-1)]*G[{1, yu, yu}, yv^(-1)])/16 - 
     (G[{1, yu^(-1)}, yw]*G[{1, yu, yu}, yv^(-1)])/8 - 
     (3*G[{1, yu}, yv^(-1)]*G[{1, yu, yu}, yv^(-1)])/32 + 
     (3*G[{1, yv^(-1)}, yw]*G[{1, yu, yu}, yv^(-1)])/32 + 
     (G[{1, 1/(yu*yv)}, yw]*G[{1, yu, yu}, yv^(-1)])/32 - 
     (G[{yu^(-1), 1/(yu*yv)}, yw]*G[{1, yu, yu}, yv^(-1)])/8 + 
     (3*G[{yv^(-1), 1/(yu*yv)}, yw]*G[{1, yu, yu}, yv^(-1)])/32 + 
     (3*G[{0}, yu^(-1)]*G[{1/(yu*yv)}, yw]*G[{1, yv^(-1), yu^(-1)}, yw])/16 + 
     (3*G[{0}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{1, yv^(-1), yu^(-1)}, yw])/16 - 
     (3*G[{0}, yw]*G[{1/(yu*yv)}, yw]*G[{1, yv^(-1), yu^(-1)}, yw])/16 - 
     (G[{1}, yu^(-1)]*G[{1/(yu*yv)}, yw]*G[{1, yv^(-1), yu^(-1)}, yw])/4 + 
     (G[{1}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{1, yv^(-1), yu^(-1)}, yw])/8 + 
     (G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{1, yv^(-1), yu^(-1)}, yw])/4 - 
     (G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{1, yv^(-1), yu^(-1)}, yw])/4 - 
     (G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{1, yv^(-1), yu^(-1)}, yw])/4 + 
     (G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{1, yv^(-1), yu^(-1)}, yw])/8 - 
     (G[{1, 1/(yu*yv)}, yw]*G[{1, yv^(-1), yu^(-1)}, yw])/4 + 
     (G[{yu^(-1), 1/(yu*yv)}, yw]*G[{1, yv^(-1), yu^(-1)}, yw])/4 - 
     (G[{yv^(-1), 1/(yu*yv)}, yw]*G[{1, yv^(-1), yu^(-1)}, yw])/8 + 
     (Pi^2*G[{1, yv^(-1), yv^(-1)}, yw])/96 - 
     (G[{0}, yu^(-1)]^2*G[{1, yv^(-1), yv^(-1)}, yw])/16 - 
     (G[{0}, yu^(-1)]*G[{0}, yv^(-1)]*G[{1, yv^(-1), yv^(-1)}, yw])/8 - 
     (G[{0}, yv^(-1)]^2*G[{1, yv^(-1), yv^(-1)}, yw])/16 + 
     (G[{0}, yu^(-1)]*G[{0}, yw]*G[{1, yv^(-1), yv^(-1)}, yw])/8 + 
     (G[{0}, yv^(-1)]*G[{0}, yw]*G[{1, yv^(-1), yv^(-1)}, yw])/8 - 
     (G[{0}, yw]^2*G[{1, yv^(-1), yv^(-1)}, yw])/16 + 
     (G[{0}, yu^(-1)]*G[{1}, yu^(-1)]*G[{1, yv^(-1), yv^(-1)}, yw])/8 + 
     (G[{0}, yv^(-1)]*G[{1}, yu^(-1)]*G[{1, yv^(-1), yv^(-1)}, yw])/8 - 
     (G[{0}, yw]*G[{1}, yu^(-1)]*G[{1, yv^(-1), yv^(-1)}, yw])/8 - 
     (G[{1}, yu^(-1)]^2*G[{1, yv^(-1), yv^(-1)}, yw])/16 - 
     (G[{0}, yu^(-1)]*G[{1}, yv^(-1)]*G[{1, yv^(-1), yv^(-1)}, yw])/8 - 
     (G[{0}, yv^(-1)]*G[{1}, yv^(-1)]*G[{1, yv^(-1), yv^(-1)}, yw])/8 + 
     (G[{0}, yw]*G[{1}, yv^(-1)]*G[{1, yv^(-1), yv^(-1)}, yw])/8 + 
     (G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*G[{1, yv^(-1), yv^(-1)}, yw])/4 + 
     (G[{1}, yv^(-1)]^2*G[{1, yv^(-1), yv^(-1)}, yw])/32 - 
     (G[{0}, yu^(-1)]*G[{1}, yw]*G[{1, yv^(-1), yv^(-1)}, yw])/8 - 
     (G[{0}, yv^(-1)]*G[{1}, yw]*G[{1, yv^(-1), yv^(-1)}, yw])/8 + 
     (G[{0}, yw]*G[{1}, yw]*G[{1, yv^(-1), yv^(-1)}, yw])/8 + 
     (G[{1}, yu^(-1)]*G[{1}, yw]*G[{1, yv^(-1), yv^(-1)}, yw])/8 - 
     (3*G[{1}, yv^(-1)]*G[{1}, yw]*G[{1, yv^(-1), yv^(-1)}, yw])/16 - 
     (5*G[{1}, yw]^2*G[{1, yv^(-1), yv^(-1)}, yw])/32 + 
     (G[{0}, yu^(-1)]*G[{yu}, yv^(-1)]*G[{1, yv^(-1), yv^(-1)}, yw])/4 + 
     (G[{0}, yv^(-1)]*G[{yu}, yv^(-1)]*G[{1, yv^(-1), yv^(-1)}, yw])/4 - 
     (G[{0}, yw]*G[{yu}, yv^(-1)]*G[{1, yv^(-1), yv^(-1)}, yw])/4 - 
     (3*G[{1}, yu^(-1)]*G[{yu}, yv^(-1)]*G[{1, yv^(-1), yv^(-1)}, yw])/8 + 
     (5*G[{1}, yw]*G[{yu}, yv^(-1)]*G[{1, yv^(-1), yv^(-1)}, yw])/16 - 
     (G[{yu}, yv^(-1)]^2*G[{1, yv^(-1), yv^(-1)}, yw])/16 + 
     (G[{0}, yu^(-1)]*G[{1/(yu*yv)}, yw]*G[{1, yv^(-1), yv^(-1)}, yw])/4 + 
     (G[{0}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{1, yv^(-1), yv^(-1)}, yw])/4 - 
     (G[{0}, yw]*G[{1/(yu*yv)}, yw]*G[{1, yv^(-1), yv^(-1)}, yw])/4 - 
     (3*G[{1}, yu^(-1)]*G[{1/(yu*yv)}, yw]*G[{1, yv^(-1), yv^(-1)}, yw])/16 + 
     (3*G[{1}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{1, yv^(-1), yv^(-1)}, yw])/16 + 
     (G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{1, yv^(-1), yv^(-1)}, yw])/2 - 
     (5*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{1, yv^(-1), yv^(-1)}, yw])/
      16 - (G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{1, yv^(-1), yv^(-1)}, yw])/
      2 + (3*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{1, yv^(-1), yv^(-1)}, 
        yw])/16 + (G[{0, 1}, yu^(-1)]*G[{1, yv^(-1), yv^(-1)}, yw])/8 + 
     (G[{0, 1}, yv^(-1)]*G[{1, yv^(-1), yv^(-1)}, yw])/16 + 
     (G[{0, 1}, yw]*G[{1, yv^(-1), yv^(-1)}, yw])/8 - 
     (G[{0, yu^(-1)}, yw]*G[{1, yv^(-1), yv^(-1)}, yw])/8 - 
     (G[{0, yu}, yv^(-1)]*G[{1, yv^(-1), yv^(-1)}, yw])/16 - 
     (G[{0, yv^(-1)}, yw]*G[{1, yv^(-1), yv^(-1)}, yw])/8 + 
     (G[{0, 1/(yu*yv)}, yw]*G[{1, yv^(-1), yv^(-1)}, yw])/8 + 
     (3*G[{1, yu^(-1)}, yw]*G[{1, yv^(-1), yv^(-1)}, yw])/16 - 
     (G[{1, yu}, yv^(-1)]*G[{1, yv^(-1), yv^(-1)}, yw])/16 + 
     (G[{1, yv^(-1)}, yw]*G[{1, yv^(-1), yv^(-1)}, yw])/4 - 
     (3*G[{1, 1/(yu*yv)}, yw]*G[{1, yv^(-1), yv^(-1)}, yw])/8 + 
     (5*G[{yu^(-1), 1/(yu*yv)}, yw]*G[{1, yv^(-1), yv^(-1)}, yw])/16 - 
     (3*G[{yv^(-1), 1/(yu*yv)}, yw]*G[{1, yv^(-1), yv^(-1)}, yw])/16 + 
     (Pi^2*G[{1, yv^(-1), 1/(yu*yv)}, yw])/96 - 
     (G[{0}, yu^(-1)]^2*G[{1, yv^(-1), 1/(yu*yv)}, yw])/32 - 
     (G[{0}, yu^(-1)]*G[{0}, yv^(-1)]*G[{1, yv^(-1), 1/(yu*yv)}, yw])/16 - 
     (G[{0}, yv^(-1)]^2*G[{1, yv^(-1), 1/(yu*yv)}, yw])/32 + 
     (G[{0}, yu^(-1)]*G[{0}, yw]*G[{1, yv^(-1), 1/(yu*yv)}, yw])/16 + 
     (G[{0}, yv^(-1)]*G[{0}, yw]*G[{1, yv^(-1), 1/(yu*yv)}, yw])/16 - 
     (G[{0}, yw]^2*G[{1, yv^(-1), 1/(yu*yv)}, yw])/32 + 
     (G[{0}, yu^(-1)]*G[{1}, yu^(-1)]*G[{1, yv^(-1), 1/(yu*yv)}, yw])/8 + 
     (G[{0}, yv^(-1)]*G[{1}, yu^(-1)]*G[{1, yv^(-1), 1/(yu*yv)}, yw])/8 - 
     (G[{0}, yw]*G[{1}, yu^(-1)]*G[{1, yv^(-1), 1/(yu*yv)}, yw])/8 - 
     (3*G[{1}, yu^(-1)]^2*G[{1, yv^(-1), 1/(yu*yv)}, yw])/32 - 
     (G[{1}, yv^(-1)]^2*G[{1, yv^(-1), 1/(yu*yv)}, yw])/32 + 
     (G[{1}, yu^(-1)]*G[{1}, yw]*G[{1, yv^(-1), 1/(yu*yv)}, yw])/16 - 
     (G[{1}, yv^(-1)]*G[{1}, yw]*G[{1, yv^(-1), 1/(yu*yv)}, yw])/16 - 
     (G[{1}, yu^(-1)]*G[{yu}, yv^(-1)]*G[{1, yv^(-1), 1/(yu*yv)}, yw])/16 + 
     (G[{yu}, yv^(-1)]^2*G[{1, yv^(-1), 1/(yu*yv)}, yw])/32 - 
     (3*G[{0}, yu^(-1)]*G[{1/(yu*yv)}, yw]*G[{1, yv^(-1), 1/(yu*yv)}, yw])/
      16 - (3*G[{0}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{1, yv^(-1), 1/(yu*yv)}, 
        yw])/16 + (3*G[{0}, yw]*G[{1/(yu*yv)}, yw]*G[{1, yv^(-1), 1/(yu*yv)}, 
        yw])/16 + (G[{1}, yu^(-1)]*G[{1/(yu*yv)}, yw]*
       G[{1, yv^(-1), 1/(yu*yv)}, yw])/8 + 
     (G[{1}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{1, yv^(-1), 1/(yu*yv)}, yw])/8 - 
     (G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{1, yv^(-1), 1/(yu*yv)}, yw])/8 - 
     (G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{1, yv^(-1), 1/(yu*yv)}, yw])/8 + 
     (G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{1, yv^(-1), 1/(yu*yv)}, yw])/8 - 
     (G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{1, yv^(-1), 1/(yu*yv)}, yw])/8 + 
     (G[{0, 1}, yv^(-1)]*G[{1, yv^(-1), 1/(yu*yv)}, yw])/16 - 
     (G[{0, yu}, yv^(-1)]*G[{1, yv^(-1), 1/(yu*yv)}, yw])/16 + 
     (G[{1, yu^(-1)}, yw]*G[{1, yv^(-1), 1/(yu*yv)}, yw])/16 + 
     (G[{1, yu}, yv^(-1)]*G[{1, yv^(-1), 1/(yu*yv)}, yw])/16 + 
     (G[{1, 1/(yu*yv)}, yw]*G[{1, yv^(-1), 1/(yu*yv)}, yw])/8 + 
     (G[{yu^(-1), 1/(yu*yv)}, yw]*G[{1, yv^(-1), 1/(yu*yv)}, yw])/8 + 
     (G[{yv^(-1), 1/(yu*yv)}, yw]*G[{1, yv^(-1), 1/(yu*yv)}, yw])/8 + 
     (7*Pi^2*G[{1, 1/(yu*yv), yu^(-1)}, yw])/768 - 
     (G[{0}, yu^(-1)]*G[{1}, yu^(-1)]*G[{1, 1/(yu*yv), yu^(-1)}, yw])/8 - 
     (G[{0}, yv^(-1)]*G[{1}, yu^(-1)]*G[{1, 1/(yu*yv), yu^(-1)}, yw])/8 + 
     (G[{0}, yw]*G[{1}, yu^(-1)]*G[{1, 1/(yu*yv), yu^(-1)}, yw])/8 + 
     (5*G[{1}, yu^(-1)]^2*G[{1, 1/(yu*yv), yu^(-1)}, yw])/64 + 
     (G[{0}, yu^(-1)]*G[{1}, yv^(-1)]*G[{1, 1/(yu*yv), yu^(-1)}, yw])/8 + 
     (G[{0}, yv^(-1)]*G[{1}, yv^(-1)]*G[{1, 1/(yu*yv), yu^(-1)}, yw])/8 - 
     (G[{0}, yw]*G[{1}, yv^(-1)]*G[{1, 1/(yu*yv), yu^(-1)}, yw])/8 + 
     (3*G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*G[{1, 1/(yu*yv), yu^(-1)}, yw])/32 - 
     (5*G[{1}, yv^(-1)]^2*G[{1, 1/(yu*yv), yu^(-1)}, yw])/64 + 
     (G[{0}, yu^(-1)]*G[{1}, yw]*G[{1, 1/(yu*yv), yu^(-1)}, yw])/8 + 
     (G[{0}, yv^(-1)]*G[{1}, yw]*G[{1, 1/(yu*yv), yu^(-1)}, yw])/8 - 
     (G[{0}, yw]*G[{1}, yw]*G[{1, 1/(yu*yv), yu^(-1)}, yw])/8 - 
     (3*G[{1}, yu^(-1)]*G[{1}, yw]*G[{1, 1/(yu*yv), yu^(-1)}, yw])/32 + 
     (3*G[{1}, yv^(-1)]*G[{1}, yw]*G[{1, 1/(yu*yv), yu^(-1)}, yw])/32 + 
     (G[{1}, yw]^2*G[{1, 1/(yu*yv), yu^(-1)}, yw])/8 - 
     (7*G[{1}, yv^(-1)]*G[{yu}, yv^(-1)]*G[{1, 1/(yu*yv), yu^(-1)}, yw])/32 - 
     (G[{1}, yw]*G[{yu}, yv^(-1)]*G[{1, 1/(yu*yv), yu^(-1)}, yw])/4 + 
     (7*G[{yu}, yv^(-1)]^2*G[{1, 1/(yu*yv), yu^(-1)}, yw])/64 - 
     (G[{0}, yu^(-1)]*G[{1/(yu*yv)}, yw]*G[{1, 1/(yu*yv), yu^(-1)}, yw])/16 - 
     (G[{0}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{1, 1/(yu*yv), yu^(-1)}, yw])/16 + 
     (G[{0}, yw]*G[{1/(yu*yv)}, yw]*G[{1, 1/(yu*yv), yu^(-1)}, yw])/16 - 
     (G[{1}, yu^(-1)]*G[{1/(yu*yv)}, yw]*G[{1, 1/(yu*yv), yu^(-1)}, yw])/32 - 
     (7*G[{1}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{1, 1/(yu*yv), yu^(-1)}, yw])/
      64 - (17*G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{1, 1/(yu*yv), yu^(-1)}, yw])/
      64 - (G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{1, 1/(yu*yv), yu^(-1)}, 
        yw])/16 + (17*G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw]*
       G[{1, 1/(yu*yv), yu^(-1)}, yw])/64 + 
     (G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{1, 1/(yu*yv), yu^(-1)}, yw])/
      32 + (3*G[{1/(yu*yv)}, yw]^2*G[{1, 1/(yu*yv), yu^(-1)}, yw])/64 - 
     (G[{0, 1}, yu^(-1)]*G[{1, 1/(yu*yv), yu^(-1)}, yw])/32 + 
     (G[{0, 1}, yw]*G[{1, 1/(yu*yv), yu^(-1)}, yw])/8 - 
     (G[{0, yu^(-1)}, yw]*G[{1, 1/(yu*yv), yu^(-1)}, yw])/8 - 
     (G[{0, yv^(-1)}, yw]*G[{1, 1/(yu*yv), yu^(-1)}, yw])/8 + 
     (G[{0, 1/(yu*yv)}, yw]*G[{1, 1/(yu*yv), yu^(-1)}, yw])/8 + 
     (G[{1, yu^(-1)}, yw]*G[{1, 1/(yu*yv), yu^(-1)}, yw])/8 + 
     (G[{1, yu}, yv^(-1)]*G[{1, 1/(yu*yv), yu^(-1)}, yw])/32 + 
     (3*G[{1, yv^(-1)}, yw]*G[{1, 1/(yu*yv), yu^(-1)}, yw])/32 + 
     (G[{1, 1/(yu*yv)}, yw]*G[{1, 1/(yu*yv), yu^(-1)}, yw])/32 + 
     (G[{yu^(-1), 1/(yu*yv)}, yw]*G[{1, 1/(yu*yv), yu^(-1)}, yw])/16 - 
     (G[{yv^(-1), 1/(yu*yv)}, yw]*G[{1, 1/(yu*yv), yu^(-1)}, yw])/32 - 
     (Pi^2*G[{1, 1/(yu*yv), yv^(-1)}, yw])/96 + 
     (G[{0}, yu^(-1)]*G[{1}, yu^(-1)]*G[{1, 1/(yu*yv), yv^(-1)}, yw])/8 + 
     (G[{0}, yv^(-1)]*G[{1}, yu^(-1)]*G[{1, 1/(yu*yv), yv^(-1)}, yw])/8 - 
     (G[{0}, yw]*G[{1}, yu^(-1)]*G[{1, 1/(yu*yv), yv^(-1)}, yw])/8 - 
     (G[{1}, yu^(-1)]^2*G[{1, 1/(yu*yv), yv^(-1)}, yw])/8 - 
     (G[{0}, yu^(-1)]*G[{1}, yv^(-1)]*G[{1, 1/(yu*yv), yv^(-1)}, yw])/8 - 
     (G[{0}, yv^(-1)]*G[{1}, yv^(-1)]*G[{1, 1/(yu*yv), yv^(-1)}, yw])/8 + 
     (G[{0}, yw]*G[{1}, yv^(-1)]*G[{1, 1/(yu*yv), yv^(-1)}, yw])/8 + 
     (G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*G[{1, 1/(yu*yv), yv^(-1)}, yw])/8 + 
     (3*G[{1}, yv^(-1)]^2*G[{1, 1/(yu*yv), yv^(-1)}, yw])/32 + 
     (G[{0}, yu^(-1)]*G[{1}, yw]*G[{1, 1/(yu*yv), yv^(-1)}, yw])/8 + 
     (G[{0}, yv^(-1)]*G[{1}, yw]*G[{1, 1/(yu*yv), yv^(-1)}, yw])/8 - 
     (G[{0}, yw]*G[{1}, yw]*G[{1, 1/(yu*yv), yv^(-1)}, yw])/8 - 
     (G[{1}, yv^(-1)]*G[{1}, yw]*G[{1, 1/(yu*yv), yv^(-1)}, yw])/16 + 
     (3*G[{1}, yw]^2*G[{1, 1/(yu*yv), yv^(-1)}, yw])/32 - 
     (G[{1}, yu^(-1)]*G[{yu}, yv^(-1)]*G[{1, 1/(yu*yv), yv^(-1)}, yw])/8 - 
     (3*G[{1}, yw]*G[{yu}, yv^(-1)]*G[{1, 1/(yu*yv), yv^(-1)}, yw])/16 + 
     (G[{yu}, yv^(-1)]^2*G[{1, 1/(yu*yv), yv^(-1)}, yw])/16 - 
     (G[{0}, yu^(-1)]*G[{1/(yu*yv)}, yw]*G[{1, 1/(yu*yv), yv^(-1)}, yw])/16 - 
     (G[{0}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{1, 1/(yu*yv), yv^(-1)}, yw])/16 + 
     (G[{0}, yw]*G[{1/(yu*yv)}, yw]*G[{1, 1/(yu*yv), yv^(-1)}, yw])/16 - 
     (G[{1}, yu^(-1)]*G[{1/(yu*yv)}, yw]*G[{1, 1/(yu*yv), yv^(-1)}, yw])/16 - 
     (G[{1}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{1, 1/(yu*yv), yv^(-1)}, yw])/16 - 
     (G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{1, 1/(yu*yv), yv^(-1)}, yw])/4 + 
     (G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{1, 1/(yu*yv), yv^(-1)}, yw])/
      16 + (G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{1, 1/(yu*yv), yv^(-1)}, 
        yw])/4 - (G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*
       G[{1, 1/(yu*yv), yv^(-1)}, yw])/16 - 
     (G[{0, 1}, yv^(-1)]*G[{1, 1/(yu*yv), yv^(-1)}, yw])/16 + 
     (G[{0, 1}, yw]*G[{1, 1/(yu*yv), yv^(-1)}, yw])/8 - 
     (G[{0, yu^(-1)}, yw]*G[{1, 1/(yu*yv), yv^(-1)}, yw])/8 + 
     (G[{0, yu}, yv^(-1)]*G[{1, 1/(yu*yv), yv^(-1)}, yw])/16 - 
     (G[{0, yv^(-1)}, yw]*G[{1, 1/(yu*yv), yv^(-1)}, yw])/8 + 
     (G[{0, 1/(yu*yv)}, yw]*G[{1, 1/(yu*yv), yv^(-1)}, yw])/8 + 
     (G[{1, yu^(-1)}, yw]*G[{1, 1/(yu*yv), yv^(-1)}, yw])/16 - 
     (G[{1, yu}, yv^(-1)]*G[{1, 1/(yu*yv), yv^(-1)}, yw])/16 + 
     (G[{1, yv^(-1)}, yw]*G[{1, 1/(yu*yv), yv^(-1)}, yw])/8 + 
     (G[{1, 1/(yu*yv)}, yw]*G[{1, 1/(yu*yv), yv^(-1)}, yw])/16 - 
     (G[{yu^(-1), 1/(yu*yv)}, yw]*G[{1, 1/(yu*yv), yv^(-1)}, yw])/16 + 
     (G[{yv^(-1), 1/(yu*yv)}, yw]*G[{1, 1/(yu*yv), yv^(-1)}, yw])/16 - 
     (19*Pi^2*G[{1, 1/(yu*yv), 1/(yu*yv)}, yw])/768 + 
     (G[{0}, yu^(-1)]^2*G[{1, 1/(yu*yv), 1/(yu*yv)}, yw])/16 + 
     (G[{0}, yu^(-1)]*G[{0}, yv^(-1)]*G[{1, 1/(yu*yv), 1/(yu*yv)}, yw])/8 + 
     (G[{0}, yv^(-1)]^2*G[{1, 1/(yu*yv), 1/(yu*yv)}, yw])/16 - 
     (G[{0}, yu^(-1)]*G[{0}, yw]*G[{1, 1/(yu*yv), 1/(yu*yv)}, yw])/8 - 
     (G[{0}, yv^(-1)]*G[{0}, yw]*G[{1, 1/(yu*yv), 1/(yu*yv)}, yw])/8 + 
     (G[{0}, yw]^2*G[{1, 1/(yu*yv), 1/(yu*yv)}, yw])/16 - 
     (G[{0}, yu^(-1)]*G[{1}, yu^(-1)]*G[{1, 1/(yu*yv), 1/(yu*yv)}, yw])/8 - 
     (G[{0}, yv^(-1)]*G[{1}, yu^(-1)]*G[{1, 1/(yu*yv), 1/(yu*yv)}, yw])/8 + 
     (G[{0}, yw]*G[{1}, yu^(-1)]*G[{1, 1/(yu*yv), 1/(yu*yv)}, yw])/8 + 
     (11*G[{1}, yu^(-1)]^2*G[{1, 1/(yu*yv), 1/(yu*yv)}, yw])/128 - 
     (G[{0}, yu^(-1)]*G[{1}, yv^(-1)]*G[{1, 1/(yu*yv), 1/(yu*yv)}, yw])/8 - 
     (G[{0}, yv^(-1)]*G[{1}, yv^(-1)]*G[{1, 1/(yu*yv), 1/(yu*yv)}, yw])/8 + 
     (G[{0}, yw]*G[{1}, yv^(-1)]*G[{1, 1/(yu*yv), 1/(yu*yv)}, yw])/8 - 
     (15*G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*G[{1, 1/(yu*yv), 1/(yu*yv)}, yw])/
      64 - (G[{1}, yv^(-1)]^2*G[{1, 1/(yu*yv), 1/(yu*yv)}, yw])/16 - 
     (5*G[{1}, yu^(-1)]*G[{1}, yw]*G[{1, 1/(yu*yv), 1/(yu*yv)}, yw])/64 - 
     (3*G[{1}, yv^(-1)]*G[{1}, yw]*G[{1, 1/(yu*yv), 1/(yu*yv)}, yw])/8 - 
     (29*G[{1}, yw]^2*G[{1, 1/(yu*yv), 1/(yu*yv)}, yw])/128 + 
     (5*G[{1}, yu^(-1)]*G[{yu}, yv^(-1)]*G[{1, 1/(yu*yv), 1/(yu*yv)}, yw])/
      16 + (23*G[{1}, yv^(-1)]*G[{yu}, yv^(-1)]*G[{1, 1/(yu*yv), 1/(yu*yv)}, 
        yw])/64 + (29*G[{1}, yw]*G[{yu}, yv^(-1)]*
       G[{1, 1/(yu*yv), 1/(yu*yv)}, yw])/64 - 
     (43*G[{yu}, yv^(-1)]^2*G[{1, 1/(yu*yv), 1/(yu*yv)}, yw])/128 + 
     (G[{0}, yu^(-1)]*G[{1/(yu*yv)}, yw]*G[{1, 1/(yu*yv), 1/(yu*yv)}, yw])/
      16 + (G[{0}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{1, 1/(yu*yv), 1/(yu*yv)}, 
        yw])/16 - (G[{0}, yw]*G[{1/(yu*yv)}, yw]*G[{1, 1/(yu*yv), 1/(yu*yv)}, 
        yw])/16 - (3*G[{1}, yu^(-1)]*G[{1/(yu*yv)}, yw]*
       G[{1, 1/(yu*yv), 1/(yu*yv)}, yw])/64 + 
     (G[{1}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{1, 1/(yu*yv), 1/(yu*yv)}, yw])/
      16 + (9*G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{1, 1/(yu*yv), 1/(yu*yv)}, yw])/
      64 + (G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{1, 1/(yu*yv), 1/(yu*yv)}, 
        yw])/32 - (9*G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw]*
       G[{1, 1/(yu*yv), 1/(yu*yv)}, yw])/64 + 
     (3*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{1, 1/(yu*yv), 1/(yu*yv)}, yw])/
      64 - (15*G[{0, 1}, yu^(-1)]*G[{1, 1/(yu*yv), 1/(yu*yv)}, yw])/64 + 
     (G[{0, 1}, yv^(-1)]*G[{1, 1/(yu*yv), 1/(yu*yv)}, yw])/64 - 
     (G[{0, yu}, yv^(-1)]*G[{1, 1/(yu*yv), 1/(yu*yv)}, yw])/64 + 
     (G[{1, yu^(-1)}, yw]*G[{1, 1/(yu*yv), 1/(yu*yv)}, yw])/64 + 
     (G[{1, yu}, yv^(-1)]*G[{1, 1/(yu*yv), 1/(yu*yv)}, yw])/4 - 
     (15*G[{1, yv^(-1)}, yw]*G[{1, 1/(yu*yv), 1/(yu*yv)}, yw])/64 + 
     (7*G[{1, 1/(yu*yv)}, yw]*G[{1, 1/(yu*yv), 1/(yu*yv)}, yw])/32 - 
     (G[{yu^(-1), 1/(yu*yv)}, yw]*G[{1, 1/(yu*yv), 1/(yu*yv)}, yw])/32 - 
     (3*G[{yv^(-1), 1/(yu*yv)}, yw]*G[{1, 1/(yu*yv), 1/(yu*yv)}, yw])/64 - 
     (41*Pi^2*G[{yu^(-1), yu^(-1), 1/(yu*yv)}, yw])/768 + 
     (G[{0}, yu^(-1)]^2*G[{yu^(-1), yu^(-1), 1/(yu*yv)}, yw])/16 + 
     (G[{0}, yu^(-1)]*G[{0}, yv^(-1)]*G[{yu^(-1), yu^(-1), 1/(yu*yv)}, yw])/
      8 + (G[{0}, yv^(-1)]^2*G[{yu^(-1), yu^(-1), 1/(yu*yv)}, yw])/16 - 
     (G[{0}, yu^(-1)]*G[{0}, yw]*G[{yu^(-1), yu^(-1), 1/(yu*yv)}, yw])/8 - 
     (G[{0}, yv^(-1)]*G[{0}, yw]*G[{yu^(-1), yu^(-1), 1/(yu*yv)}, yw])/8 + 
     (G[{0}, yw]^2*G[{yu^(-1), yu^(-1), 1/(yu*yv)}, yw])/16 - 
     (G[{0}, yu^(-1)]*G[{1}, yu^(-1)]*G[{yu^(-1), yu^(-1), 1/(yu*yv)}, yw])/
      4 - (G[{0}, yv^(-1)]*G[{1}, yu^(-1)]*G[{yu^(-1), yu^(-1), 1/(yu*yv)}, 
        yw])/4 + (G[{0}, yw]*G[{1}, yu^(-1)]*G[{yu^(-1), yu^(-1), 1/(yu*yv)}, 
        yw])/4 + (9*G[{1}, yu^(-1)]^2*G[{yu^(-1), yu^(-1), 1/(yu*yv)}, yw])/
      64 + (G[{0}, yu^(-1)]*G[{1}, yv^(-1)]*G[{yu^(-1), yu^(-1), 1/(yu*yv)}, 
        yw])/4 + (G[{0}, yv^(-1)]*G[{1}, yv^(-1)]*
       G[{yu^(-1), yu^(-1), 1/(yu*yv)}, yw])/4 - 
     (G[{0}, yw]*G[{1}, yv^(-1)]*G[{yu^(-1), yu^(-1), 1/(yu*yv)}, yw])/4 + 
     (7*G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*G[{yu^(-1), yu^(-1), 1/(yu*yv)}, yw])/
      32 - (29*G[{1}, yv^(-1)]^2*G[{yu^(-1), yu^(-1), 1/(yu*yv)}, yw])/64 + 
     (G[{0}, yu^(-1)]*G[{1}, yw]*G[{yu^(-1), yu^(-1), 1/(yu*yv)}, yw])/2 + 
     (G[{0}, yv^(-1)]*G[{1}, yw]*G[{yu^(-1), yu^(-1), 1/(yu*yv)}, yw])/2 - 
     (G[{0}, yw]*G[{1}, yw]*G[{yu^(-1), yu^(-1), 1/(yu*yv)}, yw])/2 - 
     (7*G[{1}, yu^(-1)]*G[{1}, yw]*G[{yu^(-1), yu^(-1), 1/(yu*yv)}, yw])/32 - 
     (13*G[{1}, yv^(-1)]*G[{1}, yw]*G[{yu^(-1), yu^(-1), 1/(yu*yv)}, yw])/
      32 + (3*G[{1}, yw]^2*G[{yu^(-1), yu^(-1), 1/(yu*yv)}, yw])/16 - 
     (G[{0}, yu^(-1)]*G[{yu^(-1)}, yw]*G[{yu^(-1), yu^(-1), 1/(yu*yv)}, yw])/
      2 - (G[{0}, yv^(-1)]*G[{yu^(-1)}, yw]*G[{yu^(-1), yu^(-1), 1/(yu*yv)}, 
        yw])/2 + (G[{0}, yw]*G[{yu^(-1)}, yw]*
       G[{yu^(-1), yu^(-1), 1/(yu*yv)}, yw])/2 + 
     (41*G[{1}, yv^(-1)]*G[{yu^(-1)}, yw]*G[{yu^(-1), yu^(-1), 1/(yu*yv)}, 
        yw])/32 + (9*G[{1}, yw]*G[{yu^(-1)}, yw]*
       G[{yu^(-1), yu^(-1), 1/(yu*yv)}, yw])/32 - 
     (41*G[{yu^(-1)}, yw]^2*G[{yu^(-1), yu^(-1), 1/(yu*yv)}, yw])/64 - 
     (G[{0}, yu^(-1)]*G[{yu}, yv^(-1)]*G[{yu^(-1), yu^(-1), 1/(yu*yv)}, yw])/
      4 - (G[{0}, yv^(-1)]*G[{yu}, yv^(-1)]*G[{yu^(-1), yu^(-1), 1/(yu*yv)}, 
        yw])/4 + (G[{0}, yw]*G[{yu}, yv^(-1)]*
       G[{yu^(-1), yu^(-1), 1/(yu*yv)}, yw])/4 + 
     (9*G[{1}, yv^(-1)]*G[{yu}, yv^(-1)]*G[{yu^(-1), yu^(-1), 1/(yu*yv)}, 
        yw])/32 - (3*G[{1}, yw]*G[{yu}, yv^(-1)]*
       G[{yu^(-1), yu^(-1), 1/(yu*yv)}, yw])/8 - 
     (9*G[{yu^(-1)}, yw]*G[{yu}, yv^(-1)]*G[{yu^(-1), yu^(-1), 1/(yu*yv)}, 
        yw])/32 + (7*G[{yu}, yv^(-1)]^2*G[{yu^(-1), yu^(-1), 1/(yu*yv)}, yw])/
      64 - (9*G[{1}, yu^(-1)]*G[{1/(yu*yv)}, yw]*
       G[{yu^(-1), yu^(-1), 1/(yu*yv)}, yw])/32 + 
     (17*G[{1}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{yu^(-1), yu^(-1), 1/(yu*yv)}, 
        yw])/64 - (G[{1}, yw]*G[{1/(yu*yv)}, yw]*
       G[{yu^(-1), yu^(-1), 1/(yu*yv)}, yw])/64 - 
     (17*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{yu^(-1), yu^(-1), 1/(yu*yv)}, 
        yw])/64 + (G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw]*
       G[{yu^(-1), yu^(-1), 1/(yu*yv)}, yw])/64 + 
     (5*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{yu^(-1), yu^(-1), 1/(yu*yv)}, 
        yw])/32 + (3*G[{1/(yu*yv)}, yw]^2*G[{yu^(-1), yu^(-1), 1/(yu*yv)}, 
        yw])/64 - (G[{0, 1}, yu^(-1)]*G[{yu^(-1), yu^(-1), 1/(yu*yv)}, yw])/
      32 - (G[{0, 1}, yv^(-1)]*G[{yu^(-1), yu^(-1), 1/(yu*yv)}, yw])/8 + 
     (G[{0, 1}, yw]*G[{yu^(-1), yu^(-1), 1/(yu*yv)}, yw])/4 - 
     (G[{0, yu^(-1)}, yw]*G[{yu^(-1), yu^(-1), 1/(yu*yv)}, yw])/4 + 
     (G[{0, yu}, yv^(-1)]*G[{yu^(-1), yu^(-1), 1/(yu*yv)}, yw])/8 - 
     (G[{0, yv^(-1)}, yw]*G[{yu^(-1), yu^(-1), 1/(yu*yv)}, yw])/4 + 
     (G[{0, 1/(yu*yv)}, yw]*G[{yu^(-1), yu^(-1), 1/(yu*yv)}, yw])/4 + 
     (G[{1, yu^(-1)}, yw]*G[{yu^(-1), yu^(-1), 1/(yu*yv)}, yw])/8 - 
     (3*G[{1, yu}, yv^(-1)]*G[{yu^(-1), yu^(-1), 1/(yu*yv)}, yw])/32 + 
     (7*G[{1, yv^(-1)}, yw]*G[{yu^(-1), yu^(-1), 1/(yu*yv)}, yw])/32 + 
     (5*G[{1, 1/(yu*yv)}, yw]*G[{yu^(-1), yu^(-1), 1/(yu*yv)}, yw])/32 + 
     (5*G[{yu^(-1), 1/(yu*yv)}, yw]*G[{yu^(-1), yu^(-1), 1/(yu*yv)}, yw])/
      16 - (5*G[{yv^(-1), 1/(yu*yv)}, yw]*G[{yu^(-1), yu^(-1), 1/(yu*yv)}, 
        yw])/32 - (3*G[{0}, yu^(-1)]*G[{1/(yu*yv)}, yw]*
       G[{yu^(-1), 1/(yu*yv), yv^(-1)}, yw])/16 - 
     (3*G[{0}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{yu^(-1), 1/(yu*yv), yv^(-1)}, 
        yw])/16 + (3*G[{0}, yw]*G[{1/(yu*yv)}, yw]*
       G[{yu^(-1), 1/(yu*yv), yv^(-1)}, yw])/16 + 
     (G[{1}, yu^(-1)]*G[{1/(yu*yv)}, yw]*G[{yu^(-1), 1/(yu*yv), yv^(-1)}, 
        yw])/4 - (G[{1}, yv^(-1)]*G[{1/(yu*yv)}, yw]*
       G[{yu^(-1), 1/(yu*yv), yv^(-1)}, yw])/8 - 
     (G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{yu^(-1), 1/(yu*yv), yv^(-1)}, yw])/4 + 
     (G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{yu^(-1), 1/(yu*yv), yv^(-1)}, 
        yw])/8 + (G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw]*
       G[{yu^(-1), 1/(yu*yv), yv^(-1)}, yw])/4 - 
     (G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{yu^(-1), 1/(yu*yv), yv^(-1)}, 
        yw])/8 + (G[{yv^(-1), 1/(yu*yv)}, yw]*
       G[{yu^(-1), 1/(yu*yv), yv^(-1)}, yw])/8 - 
     (5*Pi^2*G[{yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/768 + 
     (G[{0}, yu^(-1)]^2*G[{yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/32 + 
     (G[{0}, yu^(-1)]*G[{0}, yv^(-1)]*G[{yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/
      16 + (G[{0}, yv^(-1)]^2*G[{yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/32 - 
     (G[{0}, yu^(-1)]*G[{0}, yw]*G[{yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/16 - 
     (G[{0}, yv^(-1)]*G[{0}, yw]*G[{yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/16 + 
     (G[{0}, yw]^2*G[{yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/32 - 
     (G[{0}, yu^(-1)]*G[{1}, yu^(-1)]*G[{yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/
      4 - (G[{0}, yv^(-1)]*G[{1}, yu^(-1)]*G[{yu^(-1), 1/(yu*yv), 1/(yu*yv)}, 
        yw])/4 + (G[{0}, yw]*G[{1}, yu^(-1)]*
       G[{yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/4 + 
     (25*G[{1}, yu^(-1)]^2*G[{yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/128 + 
     (3*G[{0}, yu^(-1)]*G[{1}, yv^(-1)]*G[{yu^(-1), 1/(yu*yv), 1/(yu*yv)}, 
        yw])/8 + (3*G[{0}, yv^(-1)]*G[{1}, yv^(-1)]*
       G[{yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/8 - 
     (3*G[{0}, yw]*G[{1}, yv^(-1)]*G[{yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/
      8 - (9*G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*
       G[{yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/64 - 
     (13*G[{1}, yv^(-1)]^2*G[{yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/32 + 
     (G[{0}, yu^(-1)]*G[{1}, yw]*G[{yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/8 + 
     (G[{0}, yv^(-1)]*G[{1}, yw]*G[{yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/8 - 
     (G[{0}, yw]*G[{1}, yw]*G[{yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/8 - 
     (7*G[{1}, yu^(-1)]*G[{1}, yw]*G[{yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/
      64 - (G[{1}, yv^(-1)]*G[{1}, yw]*G[{yu^(-1), 1/(yu*yv), 1/(yu*yv)}, 
        yw])/16 + (5*G[{1}, yw]^2*G[{yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/
      128 - (G[{0}, yu^(-1)]*G[{yu^(-1)}, yw]*
       G[{yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/4 - 
     (G[{0}, yv^(-1)]*G[{yu^(-1)}, yw]*G[{yu^(-1), 1/(yu*yv), 1/(yu*yv)}, 
        yw])/4 + (G[{0}, yw]*G[{yu^(-1)}, yw]*
       G[{yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/4 + 
     (41*G[{1}, yv^(-1)]*G[{yu^(-1)}, yw]*G[{yu^(-1), 1/(yu*yv), 1/(yu*yv)}, 
        yw])/64 + (9*G[{1}, yw]*G[{yu^(-1)}, yw]*
       G[{yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/64 - 
     (41*G[{yu^(-1)}, yw]^2*G[{yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/128 - 
     (G[{0}, yu^(-1)]*G[{yu}, yv^(-1)]*G[{yu^(-1), 1/(yu*yv), 1/(yu*yv)}, 
        yw])/4 - (G[{0}, yv^(-1)]*G[{yu}, yv^(-1)]*
       G[{yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/4 + 
     (G[{0}, yw]*G[{yu}, yv^(-1)]*G[{yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/4 + 
     (G[{1}, yu^(-1)]*G[{yu}, yv^(-1)]*G[{yu^(-1), 1/(yu*yv), 1/(yu*yv)}, 
        yw])/4 + (9*G[{1}, yv^(-1)]*G[{yu}, yv^(-1)]*
       G[{yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/64 - 
     (5*G[{1}, yw]*G[{yu}, yv^(-1)]*G[{yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/
      64 - (9*G[{yu^(-1)}, yw]*G[{yu}, yv^(-1)]*
       G[{yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/64 + 
     (7*G[{yu}, yv^(-1)]^2*G[{yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/128 + 
     (G[{0}, yu^(-1)]*G[{1/(yu*yv)}, yw]*G[{yu^(-1), 1/(yu*yv), 1/(yu*yv)}, 
        yw])/8 + (G[{0}, yv^(-1)]*G[{1/(yu*yv)}, yw]*
       G[{yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/8 - 
     (G[{0}, yw]*G[{1/(yu*yv)}, yw]*G[{yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/
      8 - (5*G[{1}, yu^(-1)]*G[{1/(yu*yv)}, yw]*
       G[{yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/64 - 
     (3*G[{1}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{yu^(-1), 1/(yu*yv), 1/(yu*yv)}, 
        yw])/16 - (G[{1}, yw]*G[{1/(yu*yv)}, yw]*
       G[{yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/64 + 
     (3*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*
       G[{yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/16 + 
     (G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{yu^(-1), 1/(yu*yv), 1/(yu*yv)}, 
        yw])/64 + (5*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*
       G[{yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/64 - 
     (G[{0, 1}, yu^(-1)]*G[{yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/64 + 
     (3*G[{0, 1}, yv^(-1)]*G[{yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/64 - 
     (G[{0, 1}, yw]*G[{yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/8 + 
     (G[{0, yu^(-1)}, yw]*G[{yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/8 - 
     (3*G[{0, yu}, yv^(-1)]*G[{yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/64 + 
     (G[{0, yv^(-1)}, yw]*G[{yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/8 - 
     (G[{0, 1/(yu*yv)}, yw]*G[{yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/8 - 
     (5*G[{1, yu^(-1)}, yw]*G[{yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/64 + 
     (G[{1, yu}, yv^(-1)]*G[{yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/16 - 
     (9*G[{1, yv^(-1)}, yw]*G[{yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/64 - 
     (G[{1, 1/(yu*yv)}, yw]*G[{yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/32 + 
     (11*G[{yu^(-1), 1/(yu*yv)}, yw]*G[{yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/
      64 - (5*G[{yv^(-1), 1/(yu*yv)}, yw]*G[{yu^(-1), 1/(yu*yv), 1/(yu*yv)}, 
        yw])/64 - (Pi^2*G[{yv^(-1), yv^(-1), 1/(yu*yv)}, yw])/96 + 
     (G[{0}, yu^(-1)]^2*G[{yv^(-1), yv^(-1), 1/(yu*yv)}, yw])/16 + 
     (G[{0}, yu^(-1)]*G[{0}, yv^(-1)]*G[{yv^(-1), yv^(-1), 1/(yu*yv)}, yw])/
      8 + (G[{0}, yv^(-1)]^2*G[{yv^(-1), yv^(-1), 1/(yu*yv)}, yw])/16 - 
     (G[{0}, yu^(-1)]*G[{0}, yw]*G[{yv^(-1), yv^(-1), 1/(yu*yv)}, yw])/8 - 
     (G[{0}, yv^(-1)]*G[{0}, yw]*G[{yv^(-1), yv^(-1), 1/(yu*yv)}, yw])/8 + 
     (G[{0}, yw]^2*G[{yv^(-1), yv^(-1), 1/(yu*yv)}, yw])/16 - 
     (G[{0}, yu^(-1)]*G[{1}, yu^(-1)]*G[{yv^(-1), yv^(-1), 1/(yu*yv)}, yw])/
      8 - (G[{0}, yv^(-1)]*G[{1}, yu^(-1)]*G[{yv^(-1), yv^(-1), 1/(yu*yv)}, 
        yw])/8 + (G[{0}, yw]*G[{1}, yu^(-1)]*G[{yv^(-1), yv^(-1), 1/(yu*yv)}, 
        yw])/8 + (G[{1}, yu^(-1)]^2*G[{yv^(-1), yv^(-1), 1/(yu*yv)}, yw])/
      16 + (G[{0}, yu^(-1)]*G[{1}, yv^(-1)]*G[{yv^(-1), yv^(-1), 1/(yu*yv)}, 
        yw])/8 + (G[{0}, yv^(-1)]*G[{1}, yv^(-1)]*
       G[{yv^(-1), yv^(-1), 1/(yu*yv)}, yw])/8 - 
     (G[{0}, yw]*G[{1}, yv^(-1)]*G[{yv^(-1), yv^(-1), 1/(yu*yv)}, yw])/8 - 
     (G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*G[{yv^(-1), yv^(-1), 1/(yu*yv)}, yw])/
      4 - (G[{1}, yv^(-1)]^2*G[{yv^(-1), yv^(-1), 1/(yu*yv)}, yw])/32 + 
     (G[{0}, yu^(-1)]*G[{1}, yw]*G[{yv^(-1), yv^(-1), 1/(yu*yv)}, yw])/8 + 
     (G[{0}, yv^(-1)]*G[{1}, yw]*G[{yv^(-1), yv^(-1), 1/(yu*yv)}, yw])/8 - 
     (G[{0}, yw]*G[{1}, yw]*G[{yv^(-1), yv^(-1), 1/(yu*yv)}, yw])/8 - 
     (G[{1}, yu^(-1)]*G[{1}, yw]*G[{yv^(-1), yv^(-1), 1/(yu*yv)}, yw])/8 + 
     (3*G[{1}, yv^(-1)]*G[{1}, yw]*G[{yv^(-1), yv^(-1), 1/(yu*yv)}, yw])/16 + 
     (5*G[{1}, yw]^2*G[{yv^(-1), yv^(-1), 1/(yu*yv)}, yw])/32 - 
     (G[{0}, yu^(-1)]*G[{yu}, yv^(-1)]*G[{yv^(-1), yv^(-1), 1/(yu*yv)}, yw])/
      4 - (G[{0}, yv^(-1)]*G[{yu}, yv^(-1)]*G[{yv^(-1), yv^(-1), 1/(yu*yv)}, 
        yw])/4 + (G[{0}, yw]*G[{yu}, yv^(-1)]*
       G[{yv^(-1), yv^(-1), 1/(yu*yv)}, yw])/4 + 
     (3*G[{1}, yu^(-1)]*G[{yu}, yv^(-1)]*G[{yv^(-1), yv^(-1), 1/(yu*yv)}, 
        yw])/8 - (5*G[{1}, yw]*G[{yu}, yv^(-1)]*
       G[{yv^(-1), yv^(-1), 1/(yu*yv)}, yw])/16 + 
     (G[{yu}, yv^(-1)]^2*G[{yv^(-1), yv^(-1), 1/(yu*yv)}, yw])/16 + 
     (G[{0}, yu^(-1)]*G[{yv^(-1)}, yw]*G[{yv^(-1), yv^(-1), 1/(yu*yv)}, yw])/
      4 + (G[{0}, yv^(-1)]*G[{yv^(-1)}, yw]*G[{yv^(-1), yv^(-1), 1/(yu*yv)}, 
        yw])/4 - (G[{0}, yw]*G[{yv^(-1)}, yw]*
       G[{yv^(-1), yv^(-1), 1/(yu*yv)}, yw])/4 - 
     (G[{1}, yu^(-1)]*G[{yv^(-1)}, yw]*G[{yv^(-1), yv^(-1), 1/(yu*yv)}, yw])/
      8 + (3*G[{1}, yw]*G[{yv^(-1)}, yw]*G[{yv^(-1), yv^(-1), 1/(yu*yv)}, 
        yw])/8 - (3*G[{yu}, yv^(-1)]*G[{yv^(-1)}, yw]*
       G[{yv^(-1), yv^(-1), 1/(yu*yv)}, yw])/8 + 
     (G[{yv^(-1)}, yw]^2*G[{yv^(-1), yv^(-1), 1/(yu*yv)}, yw])/16 - 
     (G[{1}, yu^(-1)]*G[{1/(yu*yv)}, yw]*G[{yv^(-1), yv^(-1), 1/(yu*yv)}, 
        yw])/16 + (G[{1}, yv^(-1)]*G[{1/(yu*yv)}, yw]*
       G[{yv^(-1), yv^(-1), 1/(yu*yv)}, yw])/16 - 
     (G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{yv^(-1), yv^(-1), 1/(yu*yv)}, 
        yw])/16 + (G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*
       G[{yv^(-1), yv^(-1), 1/(yu*yv)}, yw])/16 - 
     (G[{0, 1}, yu^(-1)]*G[{yv^(-1), yv^(-1), 1/(yu*yv)}, yw])/8 - 
     (G[{0, 1}, yv^(-1)]*G[{yv^(-1), yv^(-1), 1/(yu*yv)}, yw])/16 - 
     (G[{0, 1}, yw]*G[{yv^(-1), yv^(-1), 1/(yu*yv)}, yw])/8 + 
     (G[{0, yu^(-1)}, yw]*G[{yv^(-1), yv^(-1), 1/(yu*yv)}, yw])/8 + 
     (G[{0, yu}, yv^(-1)]*G[{yv^(-1), yv^(-1), 1/(yu*yv)}, yw])/16 + 
     (G[{0, yv^(-1)}, yw]*G[{yv^(-1), yv^(-1), 1/(yu*yv)}, yw])/8 - 
     (G[{0, 1/(yu*yv)}, yw]*G[{yv^(-1), yv^(-1), 1/(yu*yv)}, yw])/8 - 
     (3*G[{1, yu^(-1)}, yw]*G[{yv^(-1), yv^(-1), 1/(yu*yv)}, yw])/16 + 
     (G[{1, yu}, yv^(-1)]*G[{yv^(-1), yv^(-1), 1/(yu*yv)}, yw])/16 - 
     (G[{1, yv^(-1)}, yw]*G[{yv^(-1), yv^(-1), 1/(yu*yv)}, yw])/4 + 
     (3*G[{1, 1/(yu*yv)}, yw]*G[{yv^(-1), yv^(-1), 1/(yu*yv)}, yw])/16 + 
     (G[{yu^(-1), 1/(yu*yv)}, yw]*G[{yv^(-1), yv^(-1), 1/(yu*yv)}, yw])/16 - 
     (G[{yv^(-1), 1/(yu*yv)}, yw]*G[{yv^(-1), yv^(-1), 1/(yu*yv)}, yw])/16 - 
     (Pi^2*G[{yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/96 + 
     (G[{0}, yu^(-1)]^2*G[{yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/32 + 
     (G[{0}, yu^(-1)]*G[{0}, yv^(-1)]*G[{yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/
      16 + (G[{0}, yv^(-1)]^2*G[{yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/32 - 
     (G[{0}, yu^(-1)]*G[{0}, yw]*G[{yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/16 - 
     (G[{0}, yv^(-1)]*G[{0}, yw]*G[{yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/16 + 
     (G[{0}, yw]^2*G[{yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/32 - 
     (G[{1}, yu^(-1)]^2*G[{yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/32 + 
     (G[{0}, yu^(-1)]*G[{1}, yv^(-1)]*G[{yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/
      8 + (G[{0}, yv^(-1)]*G[{1}, yv^(-1)]*G[{yv^(-1), 1/(yu*yv), 1/(yu*yv)}, 
        yw])/8 - (G[{0}, yw]*G[{1}, yv^(-1)]*
       G[{yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/8 - 
     (G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*G[{yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/
      8 - (7*G[{1}, yv^(-1)]^2*G[{yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/32 + 
     (G[{0}, yu^(-1)]*G[{1}, yw]*G[{yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/8 + 
     (G[{0}, yv^(-1)]*G[{1}, yw]*G[{yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/8 - 
     (G[{0}, yw]*G[{1}, yw]*G[{yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/8 - 
     (G[{1}, yu^(-1)]*G[{1}, yw]*G[{yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/16 - 
     (3*G[{1}, yv^(-1)]*G[{1}, yw]*G[{yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/
      16 + (G[{1}, yv^(-1)]*G[{yu^(-1)}, yw]*
       G[{yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/4 + 
     (G[{1}, yw]*G[{yu^(-1)}, yw]*G[{yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/4 - 
     (G[{yu^(-1)}, yw]^2*G[{yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/8 - 
     (G[{0}, yu^(-1)]*G[{yu}, yv^(-1)]*G[{yv^(-1), 1/(yu*yv), 1/(yu*yv)}, 
        yw])/4 - (G[{0}, yv^(-1)]*G[{yu}, yv^(-1)]*
       G[{yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/4 + 
     (G[{0}, yw]*G[{yu}, yv^(-1)]*G[{yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/4 + 
     (3*G[{1}, yu^(-1)]*G[{yu}, yv^(-1)]*G[{yv^(-1), 1/(yu*yv), 1/(yu*yv)}, 
        yw])/16 + (G[{1}, yv^(-1)]*G[{yu}, yv^(-1)]*
       G[{yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/4 - 
     (G[{yu^(-1)}, yw]*G[{yu}, yv^(-1)]*G[{yv^(-1), 1/(yu*yv), 1/(yu*yv)}, 
        yw])/4 + (G[{yu}, yv^(-1)]^2*G[{yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/
      32 + (G[{0}, yu^(-1)]*G[{yv^(-1)}, yw]*
       G[{yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/8 + 
     (G[{0}, yv^(-1)]*G[{yv^(-1)}, yw]*G[{yv^(-1), 1/(yu*yv), 1/(yu*yv)}, 
        yw])/8 - (G[{0}, yw]*G[{yv^(-1)}, yw]*
       G[{yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/8 - 
     (G[{1}, yu^(-1)]*G[{yv^(-1)}, yw]*G[{yv^(-1), 1/(yu*yv), 1/(yu*yv)}, 
        yw])/16 + (3*G[{1}, yw]*G[{yv^(-1)}, yw]*
       G[{yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/16 - 
     (3*G[{yu}, yv^(-1)]*G[{yv^(-1)}, yw]*G[{yv^(-1), 1/(yu*yv), 1/(yu*yv)}, 
        yw])/16 + (G[{yv^(-1)}, yw]^2*G[{yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/
      32 - (G[{0}, yu^(-1)]*G[{1/(yu*yv)}, yw]*
       G[{yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/16 - 
     (G[{0}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{yv^(-1), 1/(yu*yv), 1/(yu*yv)}, 
        yw])/16 + (G[{0}, yw]*G[{1/(yu*yv)}, yw]*
       G[{yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/16 - 
     (G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/
      8 + (G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw]*
       G[{yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/8 + 
     (G[{0, 1}, yv^(-1)]*G[{yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/16 - 
     (G[{0, 1}, yw]*G[{yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/8 + 
     (G[{0, yu^(-1)}, yw]*G[{yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/8 - 
     (G[{0, yu}, yv^(-1)]*G[{yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/16 + 
     (G[{0, yv^(-1)}, yw]*G[{yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/8 - 
     (G[{0, 1/(yu*yv)}, yw]*G[{yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/8 - 
     (G[{1, yu^(-1)}, yw]*G[{yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/16 + 
     (G[{1, yu}, yv^(-1)]*G[{yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/16 - 
     (G[{1, yv^(-1)}, yw]*G[{yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/8 - 
     (G[{1, 1/(yu*yv)}, yw]*G[{yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/16 + 
     (3*G[{yu^(-1), 1/(yu*yv)}, yw]*G[{yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/
      16 + (G[{yv^(-1), 1/(yu*yv)}, yw]*G[{yv^(-1), 1/(yu*yv), 1/(yu*yv)}, 
        yw])/8 - (G[{1}, yu^(-1)]*G[{0, 0, 1, 1}, yu^(-1)])/8 + 
     (G[{1}, yv^(-1)]*G[{0, 0, 1, 1}, yu^(-1)])/8 - 
     (G[{1}, yu^(-1)]*G[{0, 0, 1, 1}, yv^(-1)])/16 + 
     (5*G[{1}, yv^(-1)]*G[{0, 0, 1, 1}, yv^(-1)])/32 - 
     (3*G[{1}, yw]*G[{0, 0, 1, 1}, yv^(-1)])/32 + 
     (3*G[{1/(yu*yv)}, yw]*G[{0, 0, 1, 1}, yv^(-1)])/32 + 
     (G[{0}, yu^(-1)]*G[{0, 0, 1, 1}, yw])/8 + 
     (G[{0}, yv^(-1)]*G[{0, 0, 1, 1}, yw])/8 - 
     (G[{0}, yw]*G[{0, 0, 1, 1}, yw])/8 - 
     (3*G[{1}, yu^(-1)]*G[{0, 0, 1, 1}, yw])/16 + 
     (3*G[{1}, yv^(-1)]*G[{0, 0, 1, 1}, yw])/16 + 
     (G[{1}, yw]*G[{0, 0, 1, 1}, yw])/8 - 
     (G[{yu}, yv^(-1)]*G[{0, 0, 1, 1}, yw])/4 - 
     (G[{1/(yu*yv)}, yw]*G[{0, 0, 1, 1}, yw])/8 - 
     (G[{0}, yu^(-1)]*G[{0, 0, 1, yu^(-1)}, yw])/16 - 
     (G[{0}, yv^(-1)]*G[{0, 0, 1, yu^(-1)}, yw])/16 + 
     (G[{0}, yw]*G[{0, 0, 1, yu^(-1)}, yw])/16 + 
     (G[{1}, yu^(-1)]*G[{0, 0, 1, yu^(-1)}, yw])/8 - 
     (G[{1}, yv^(-1)]*G[{0, 0, 1, yu^(-1)}, yw])/4 - 
     (G[{1}, yw]*G[{0, 0, 1, yu^(-1)}, yw])/8 + 
     (G[{yu}, yv^(-1)]*G[{0, 0, 1, yu^(-1)}, yw])/4 + 
     (G[{1/(yu*yv)}, yw]*G[{0, 0, 1, yu^(-1)}, yw])/8 - 
     (G[{1}, yv^(-1)]*G[{0, 0, 1, yu}, yv^(-1)])/32 + 
     (3*G[{1}, yw]*G[{0, 0, 1, yu}, yv^(-1)])/32 - 
     (3*G[{1/(yu*yv)}, yw]*G[{0, 0, 1, yu}, yv^(-1)])/32 - 
     (G[{0}, yu^(-1)]*G[{0, 0, 1, yv^(-1)}, yw])/16 - 
     (G[{0}, yv^(-1)]*G[{0, 0, 1, yv^(-1)}, yw])/16 + 
     (G[{0}, yw]*G[{0, 0, 1, yv^(-1)}, yw])/16 + 
     (G[{1}, yu^(-1)]*G[{0, 0, 1, yv^(-1)}, yw])/8 - 
     (G[{1}, yv^(-1)]*G[{0, 0, 1, yv^(-1)}, yw])/4 - 
     (G[{1}, yw]*G[{0, 0, 1, yv^(-1)}, yw])/8 + 
     (G[{yu}, yv^(-1)]*G[{0, 0, 1, yv^(-1)}, yw])/4 + 
     (G[{1/(yu*yv)}, yw]*G[{0, 0, 1, yv^(-1)}, yw])/8 - 
     (G[{1}, yu^(-1)]*G[{0, 0, 1, 1/(yu*yv)}, yw])/16 + 
     (5*G[{1}, yv^(-1)]*G[{0, 0, 1, 1/(yu*yv)}, yw])/16 - 
     (G[{yu}, yv^(-1)]*G[{0, 0, 1, 1/(yu*yv)}, yw])/4 - 
     (G[{0}, yu^(-1)]*G[{0, 0, yu^(-1), 1}, yw])/16 - 
     (G[{0}, yv^(-1)]*G[{0, 0, yu^(-1), 1}, yw])/16 + 
     (G[{0}, yw]*G[{0, 0, yu^(-1), 1}, yw])/16 + 
     (3*G[{1}, yu^(-1)]*G[{0, 0, yu^(-1), 1}, yw])/16 - 
     (5*G[{1}, yv^(-1)]*G[{0, 0, yu^(-1), 1}, yw])/16 + 
     (G[{yu}, yv^(-1)]*G[{0, 0, yu^(-1), 1}, yw])/4 + 
     (G[{1}, yw]*G[{0, 0, yu^(-1), yv^(-1)}, yw])/8 - 
     (G[{1/(yu*yv)}, yw]*G[{0, 0, yu^(-1), yv^(-1)}, yw])/8 + 
     (G[{0}, yu^(-1)]*G[{0, 0, yu^(-1), 1/(yu*yv)}, yw])/16 + 
     (G[{0}, yv^(-1)]*G[{0, 0, yu^(-1), 1/(yu*yv)}, yw])/16 - 
     (G[{0}, yw]*G[{0, 0, yu^(-1), 1/(yu*yv)}, yw])/16 - 
     (G[{1}, yu^(-1)]*G[{0, 0, yu^(-1), 1/(yu*yv)}, yw])/16 - 
     (G[{1}, yv^(-1)]*G[{0, 0, yu^(-1), 1/(yu*yv)}, yw])/16 + 
     (G[{1}, yu^(-1)]*G[{0, 0, yu, 1}, yv^(-1)])/16 - 
     (G[{1}, yv^(-1)]*G[{0, 0, yu, 1}, yv^(-1)])/32 + 
     (3*G[{1}, yw]*G[{0, 0, yu, 1}, yv^(-1)])/32 - 
     (3*G[{1/(yu*yv)}, yw]*G[{0, 0, yu, 1}, yv^(-1)])/32 + 
     (G[{1}, yv^(-1)]*G[{0, 0, yu, yu}, yv^(-1)])/32 - 
     (3*G[{1}, yw]*G[{0, 0, yu, yu}, yv^(-1)])/32 + 
     (3*G[{1/(yu*yv)}, yw]*G[{0, 0, yu, yu}, yv^(-1)])/32 - 
     (G[{0}, yu^(-1)]*G[{0, 0, yv^(-1), 1}, yw])/16 - 
     (G[{0}, yv^(-1)]*G[{0, 0, yv^(-1), 1}, yw])/16 + 
     (G[{0}, yw]*G[{0, 0, yv^(-1), 1}, yw])/16 + 
     (G[{1}, yu^(-1)]*G[{0, 0, yv^(-1), 1}, yw])/16 - 
     (3*G[{1}, yv^(-1)]*G[{0, 0, yv^(-1), 1}, yw])/16 + 
     (G[{yu}, yv^(-1)]*G[{0, 0, yv^(-1), 1}, yw])/4 + 
     (G[{1}, yw]*G[{0, 0, yv^(-1), yu^(-1)}, yw])/8 - 
     (G[{1/(yu*yv)}, yw]*G[{0, 0, yv^(-1), yu^(-1)}, yw])/8 + 
     (G[{0}, yu^(-1)]*G[{0, 0, yv^(-1), 1/(yu*yv)}, yw])/16 + 
     (G[{0}, yv^(-1)]*G[{0, 0, yv^(-1), 1/(yu*yv)}, yw])/16 - 
     (G[{0}, yw]*G[{0, 0, yv^(-1), 1/(yu*yv)}, yw])/16 - 
     (G[{1}, yu^(-1)]*G[{0, 0, yv^(-1), 1/(yu*yv)}, yw])/16 - 
     (G[{1}, yv^(-1)]*G[{0, 0, yv^(-1), 1/(yu*yv)}, yw])/16 - 
     (G[{1}, yu^(-1)]*G[{0, 0, 1/(yu*yv), 1}, yw])/16 + 
     (5*G[{1}, yv^(-1)]*G[{0, 0, 1/(yu*yv), 1}, yw])/16 - 
     (G[{1}, yw]*G[{0, 0, 1/(yu*yv), 1}, yw])/8 - 
     (G[{yu}, yv^(-1)]*G[{0, 0, 1/(yu*yv), 1}, yw])/4 + 
     (G[{1/(yu*yv)}, yw]*G[{0, 0, 1/(yu*yv), 1}, yw])/8 + 
     (G[{0}, yu^(-1)]*G[{0, 0, 1/(yu*yv), yu^(-1)}, yw])/16 + 
     (G[{0}, yv^(-1)]*G[{0, 0, 1/(yu*yv), yu^(-1)}, yw])/16 - 
     (G[{0}, yw]*G[{0, 0, 1/(yu*yv), yu^(-1)}, yw])/16 - 
     (G[{1}, yv^(-1)]*G[{0, 0, 1/(yu*yv), yu^(-1)}, yw])/8 + 
     (G[{0}, yu^(-1)]*G[{0, 0, 1/(yu*yv), yv^(-1)}, yw])/16 + 
     (G[{0}, yv^(-1)]*G[{0, 0, 1/(yu*yv), yv^(-1)}, yw])/16 - 
     (G[{0}, yw]*G[{0, 0, 1/(yu*yv), yv^(-1)}, yw])/16 - 
     (G[{1}, yu^(-1)]*G[{0, 0, 1/(yu*yv), yv^(-1)}, yw])/8 - 
     (G[{0}, yu^(-1)]*G[{0, 0, 1/(yu*yv), 1/(yu*yv)}, yw])/8 - 
     (G[{0}, yv^(-1)]*G[{0, 0, 1/(yu*yv), 1/(yu*yv)}, yw])/8 + 
     (G[{0}, yw]*G[{0, 0, 1/(yu*yv), 1/(yu*yv)}, yw])/8 + 
     (3*G[{1}, yu^(-1)]*G[{0, 0, 1/(yu*yv), 1/(yu*yv)}, yw])/16 - 
     (3*G[{1}, yv^(-1)]*G[{0, 0, 1/(yu*yv), 1/(yu*yv)}, yw])/16 + 
     (G[{yu}, yv^(-1)]*G[{0, 0, 1/(yu*yv), 1/(yu*yv)}, yw])/4 + 
     (G[{1}, yu^(-1)]*G[{0, 1, 0, yu^(-1)}, yw])/16 - 
     (3*G[{1}, yv^(-1)]*G[{0, 1, 0, yu^(-1)}, yw])/16 + 
     (G[{yu}, yv^(-1)]*G[{0, 1, 0, yu^(-1)}, yw])/8 + 
     (G[{1}, yv^(-1)]*G[{0, 1, 0, yu}, yv^(-1)])/16 - 
     (G[{1}, yv^(-1)]*G[{0, 1, 0, yv^(-1)}, yw])/8 + 
     (G[{yu}, yv^(-1)]*G[{0, 1, 0, yv^(-1)}, yw])/8 - 
     (G[{1}, yu^(-1)]*G[{0, 1, 0, 1/(yu*yv)}, yw])/16 + 
     (5*G[{1}, yv^(-1)]*G[{0, 1, 0, 1/(yu*yv)}, yw])/16 - 
     (G[{yu}, yv^(-1)]*G[{0, 1, 0, 1/(yu*yv)}, yw])/4 - 
     (3*G[{1}, yu^(-1)]*G[{0, 1, 1, 1}, yu^(-1)])/16 + 
     (3*G[{1}, yv^(-1)]*G[{0, 1, 1, 1}, yu^(-1)])/16 + 
     (G[{1}, yu^(-1)]*G[{0, 1, 1, 1}, yv^(-1)])/8 + 
     (15*G[{1}, yv^(-1)]*G[{0, 1, 1, 1}, yv^(-1)])/64 - 
     (9*G[{1}, yw]*G[{0, 1, 1, 1}, yv^(-1)])/64 + 
     (9*G[{1/(yu*yv)}, yw]*G[{0, 1, 1, 1}, yv^(-1)])/64 + 
     (G[{0}, yu^(-1)]*G[{0, 1, 1, 1}, yw])/8 + 
     (G[{0}, yv^(-1)]*G[{0, 1, 1, 1}, yw])/8 - 
     (G[{0}, yw]*G[{0, 1, 1, 1}, yw])/8 - 
     (G[{1}, yu^(-1)]*G[{0, 1, 1, 1}, yw])/16 + 
     (G[{1}, yv^(-1)]*G[{0, 1, 1, 1}, yw])/8 + 
     (G[{1}, yw]*G[{0, 1, 1, 1}, yw])/8 - 
     (5*G[{yu}, yv^(-1)]*G[{0, 1, 1, 1}, yw])/16 - 
     (G[{1/(yu*yv)}, yw]*G[{0, 1, 1, 1}, yw])/8 - 
     (3*G[{0}, yu^(-1)]*G[{0, 1, 1, yu^(-1)}, yw])/16 - 
     (3*G[{0}, yv^(-1)]*G[{0, 1, 1, yu^(-1)}, yw])/16 + 
     (3*G[{0}, yw]*G[{0, 1, 1, yu^(-1)}, yw])/16 + 
     (G[{1}, yv^(-1)]*G[{0, 1, 1, yu^(-1)}, yw])/2 - 
     (G[{yu}, yv^(-1)]*G[{0, 1, 1, yu^(-1)}, yw])/8 - 
     (G[{1}, yu^(-1)]*G[{0, 1, 1, yu}, yv^(-1)])/8 - 
     (G[{1}, yv^(-1)]*G[{0, 1, 1, yu}, yv^(-1)])/64 - 
     (5*G[{1}, yw]*G[{0, 1, 1, yu}, yv^(-1)])/64 + 
     (5*G[{1/(yu*yv)}, yw]*G[{0, 1, 1, yu}, yv^(-1)])/64 + 
     (3*G[{0}, yu^(-1)]*G[{0, 1, 1, yv^(-1)}, yw])/16 + 
     (3*G[{0}, yv^(-1)]*G[{0, 1, 1, yv^(-1)}, yw])/16 - 
     (3*G[{0}, yw]*G[{0, 1, 1, yv^(-1)}, yw])/16 - 
     (G[{1}, yu^(-1)]*G[{0, 1, 1, yv^(-1)}, yw])/4 - 
     (G[{yu}, yv^(-1)]*G[{0, 1, 1, yv^(-1)}, yw])/8 + 
     (G[{0}, yu^(-1)]*G[{0, 1, 1, 1/(yu*yv)}, yw])/8 + 
     (G[{0}, yv^(-1)]*G[{0, 1, 1, 1/(yu*yv)}, yw])/8 - 
     (G[{0}, yw]*G[{0, 1, 1, 1/(yu*yv)}, yw])/8 - 
     (G[{1}, yu^(-1)]*G[{0, 1, 1, 1/(yu*yv)}, yw])/16 - 
     (G[{1}, yv^(-1)]*G[{0, 1, 1, 1/(yu*yv)}, yw])/4 + 
     (G[{yu}, yv^(-1)]*G[{0, 1, 1, 1/(yu*yv)}, yw])/16 - 
     (3*G[{1}, yu^(-1)]*G[{0, 1, yu^(-1), 1}, yw])/16 + 
     (3*G[{1}, yv^(-1)]*G[{0, 1, yu^(-1), 1}, yw])/8 - 
     (3*G[{yu}, yv^(-1)]*G[{0, 1, yu^(-1), 1}, yw])/16 + 
     (G[{0}, yu^(-1)]*G[{0, 1, yu^(-1), yu^(-1)}, yw])/8 + 
     (G[{0}, yv^(-1)]*G[{0, 1, yu^(-1), yu^(-1)}, yw])/8 - 
     (G[{0}, yw]*G[{0, 1, yu^(-1), yu^(-1)}, yw])/8 - 
     (G[{1}, yv^(-1)]*G[{0, 1, yu^(-1), yu^(-1)}, yw])/2 - 
     (G[{1}, yw]*G[{0, 1, yu^(-1), yu^(-1)}, yw])/8 + 
     (G[{yu}, yv^(-1)]*G[{0, 1, yu^(-1), yu^(-1)}, yw])/4 + 
     (G[{1/(yu*yv)}, yw]*G[{0, 1, yu^(-1), yu^(-1)}, yw])/8 - 
     (G[{1}, yw]*G[{0, 1, yu^(-1), yv^(-1)}, yw])/8 + 
     (G[{1/(yu*yv)}, yw]*G[{0, 1, yu^(-1), yv^(-1)}, yw])/8 - 
     (G[{0}, yu^(-1)]*G[{0, 1, yu^(-1), 1/(yu*yv)}, yw])/4 - 
     (G[{0}, yv^(-1)]*G[{0, 1, yu^(-1), 1/(yu*yv)}, yw])/4 + 
     (G[{0}, yw]*G[{0, 1, yu^(-1), 1/(yu*yv)}, yw])/4 + 
     (5*G[{1}, yu^(-1)]*G[{0, 1, yu^(-1), 1/(yu*yv)}, yw])/16 + 
     (3*G[{yu}, yv^(-1)]*G[{0, 1, yu^(-1), 1/(yu*yv)}, yw])/16 - 
     (G[{1}, yu^(-1)]*G[{0, 1, yu, 1}, yv^(-1)])/8 - 
     (5*G[{1}, yv^(-1)]*G[{0, 1, yu, 1}, yv^(-1)])/64 - 
     (5*G[{1}, yw]*G[{0, 1, yu, 1}, yv^(-1)])/64 + 
     (5*G[{1/(yu*yv)}, yw]*G[{0, 1, yu, 1}, yv^(-1)])/64 - 
     (13*G[{1}, yv^(-1)]*G[{0, 1, yu, yu}, yv^(-1)])/64 + 
     (11*G[{1}, yw]*G[{0, 1, yu, yu}, yv^(-1)])/64 - 
     (11*G[{1/(yu*yv)}, yw]*G[{0, 1, yu, yu}, yv^(-1)])/64 + 
     (3*G[{0}, yu^(-1)]*G[{0, 1, yv^(-1), 1}, yw])/16 + 
     (3*G[{0}, yv^(-1)]*G[{0, 1, yv^(-1), 1}, yw])/16 - 
     (3*G[{0}, yw]*G[{0, 1, yv^(-1), 1}, yw])/16 - 
     (3*G[{1}, yu^(-1)]*G[{0, 1, yv^(-1), 1}, yw])/16 - 
     (3*G[{yu}, yv^(-1)]*G[{0, 1, yv^(-1), 1}, yw])/16 - 
     (G[{1}, yw]*G[{0, 1, yv^(-1), yu^(-1)}, yw])/8 + 
     (G[{1/(yu*yv)}, yw]*G[{0, 1, yv^(-1), yu^(-1)}, yw])/8 - 
     (G[{0}, yu^(-1)]*G[{0, 1, yv^(-1), yv^(-1)}, yw])/4 - 
     (G[{0}, yv^(-1)]*G[{0, 1, yv^(-1), yv^(-1)}, yw])/4 + 
     (G[{0}, yw]*G[{0, 1, yv^(-1), yv^(-1)}, yw])/4 + 
     (G[{1}, yu^(-1)]*G[{0, 1, yv^(-1), yv^(-1)}, yw])/4 - 
     (G[{1}, yw]*G[{0, 1, yv^(-1), yv^(-1)}, yw])/8 + 
     (G[{yu}, yv^(-1)]*G[{0, 1, yv^(-1), yv^(-1)}, yw])/4 + 
     (G[{1/(yu*yv)}, yw]*G[{0, 1, yv^(-1), yv^(-1)}, yw])/8 - 
     (G[{0}, yu^(-1)]*G[{0, 1, yv^(-1), 1/(yu*yv)}, yw])/16 - 
     (G[{0}, yv^(-1)]*G[{0, 1, yv^(-1), 1/(yu*yv)}, yw])/16 + 
     (G[{0}, yw]*G[{0, 1, yv^(-1), 1/(yu*yv)}, yw])/16 + 
     (3*G[{1}, yu^(-1)]*G[{0, 1, yv^(-1), 1/(yu*yv)}, yw])/16 - 
     (G[{1}, yv^(-1)]*G[{0, 1, yv^(-1), 1/(yu*yv)}, yw])/4 + 
     (3*G[{yu}, yv^(-1)]*G[{0, 1, yv^(-1), 1/(yu*yv)}, yw])/16 - 
     (G[{0}, yu^(-1)]*G[{0, 1, 1/(yu*yv), 1}, yw])/16 - 
     (G[{0}, yv^(-1)]*G[{0, 1, 1/(yu*yv), 1}, yw])/16 + 
     (G[{0}, yw]*G[{0, 1, 1/(yu*yv), 1}, yw])/16 + 
     (G[{1}, yu^(-1)]*G[{0, 1, 1/(yu*yv), 1}, yw])/16 - 
     (G[{1}, yv^(-1)]*G[{0, 1, 1/(yu*yv), 1}, yw])/8 + 
     (3*G[{yu}, yv^(-1)]*G[{0, 1, 1/(yu*yv), 1}, yw])/16 + 
     (G[{1}, yv^(-1)]*G[{0, 1, 1/(yu*yv), yu^(-1)}, yw])/8 - 
     (G[{yu}, yv^(-1)]*G[{0, 1, 1/(yu*yv), yu^(-1)}, yw])/8 + 
     (G[{1}, yu^(-1)]*G[{0, 1, 1/(yu*yv), yv^(-1)}, yw])/8 - 
     (G[{yu}, yv^(-1)]*G[{0, 1, 1/(yu*yv), yv^(-1)}, yw])/8 + 
     (G[{0}, yu^(-1)]*G[{0, 1, 1/(yu*yv), 1/(yu*yv)}, yw])/16 + 
     (G[{0}, yv^(-1)]*G[{0, 1, 1/(yu*yv), 1/(yu*yv)}, yw])/16 - 
     (G[{0}, yw]*G[{0, 1, 1/(yu*yv), 1/(yu*yv)}, yw])/16 - 
     (3*G[{1}, yu^(-1)]*G[{0, 1, 1/(yu*yv), 1/(yu*yv)}, yw])/16 + 
     (G[{yu}, yv^(-1)]*G[{0, 1, 1/(yu*yv), 1/(yu*yv)}, yw])/16 + 
     (G[{1}, yu^(-1)]*G[{0, yu^(-1), 0, 1/(yu*yv)}, yw])/16 - 
     (3*G[{1}, yv^(-1)]*G[{0, yu^(-1), 0, 1/(yu*yv)}, yw])/16 + 
     (G[{yu}, yv^(-1)]*G[{0, yu^(-1), 0, 1/(yu*yv)}, yw])/8 + 
     (G[{0}, yu^(-1)]*G[{0, yu^(-1), 1, yu^(-1)}, yw])/16 + 
     (G[{0}, yv^(-1)]*G[{0, yu^(-1), 1, yu^(-1)}, yw])/16 - 
     (G[{0}, yw]*G[{0, yu^(-1), 1, yu^(-1)}, yw])/16 - 
     (G[{1}, yv^(-1)]*G[{0, yu^(-1), 1, yu^(-1)}, yw])/4 + 
     (G[{yu}, yv^(-1)]*G[{0, yu^(-1), 1, yu^(-1)}, yw])/8 - 
     (3*G[{0}, yu^(-1)]*G[{0, yu^(-1), 1, yv^(-1)}, yw])/16 - 
     (3*G[{0}, yv^(-1)]*G[{0, yu^(-1), 1, yv^(-1)}, yw])/16 + 
     (3*G[{0}, yw]*G[{0, yu^(-1), 1, yv^(-1)}, yw])/16 + 
     (G[{1}, yu^(-1)]*G[{0, yu^(-1), 1, yv^(-1)}, yw])/4 + 
     (G[{yu}, yv^(-1)]*G[{0, yu^(-1), 1, yv^(-1)}, yw])/8 - 
     (G[{0}, yu^(-1)]*G[{0, yu^(-1), yu^(-1), 1}, yw])/8 - 
     (G[{0}, yv^(-1)]*G[{0, yu^(-1), yu^(-1), 1}, yw])/8 + 
     (G[{0}, yw]*G[{0, yu^(-1), yu^(-1), 1}, yw])/8 + 
     (G[{1}, yu^(-1)]*G[{0, yu^(-1), yu^(-1), 1}, yw])/4 - 
     (G[{1}, yv^(-1)]*G[{0, yu^(-1), yu^(-1), 1}, yw])/4 + 
     (G[{yu}, yv^(-1)]*G[{0, yu^(-1), yu^(-1), 1}, yw])/4 + 
     (G[{1}, yw]*G[{0, yu^(-1), yu^(-1), yv^(-1)}, yw])/8 - 
     (G[{1/(yu*yv)}, yw]*G[{0, yu^(-1), yu^(-1), yv^(-1)}, yw])/8 + 
     (G[{0}, yu^(-1)]*G[{0, yu^(-1), yu^(-1), 1/(yu*yv)}, yw])/8 + 
     (G[{0}, yv^(-1)]*G[{0, yu^(-1), yu^(-1), 1/(yu*yv)}, yw])/8 - 
     (G[{0}, yw]*G[{0, yu^(-1), yu^(-1), 1/(yu*yv)}, yw])/8 - 
     (G[{1}, yu^(-1)]*G[{0, yu^(-1), yu^(-1), 1/(yu*yv)}, yw])/4 + 
     (G[{1}, yv^(-1)]*G[{0, yu^(-1), yu^(-1), 1/(yu*yv)}, yw])/4 - 
     (G[{yu}, yv^(-1)]*G[{0, yu^(-1), yu^(-1), 1/(yu*yv)}, yw])/4 - 
     (3*G[{0}, yu^(-1)]*G[{0, yu^(-1), yv^(-1), 1}, yw])/16 - 
     (3*G[{0}, yv^(-1)]*G[{0, yu^(-1), yv^(-1), 1}, yw])/16 + 
     (3*G[{0}, yw]*G[{0, yu^(-1), yv^(-1), 1}, yw])/16 + 
     (G[{1}, yu^(-1)]*G[{0, yu^(-1), yv^(-1), 1}, yw])/4 - 
     (G[{1}, yv^(-1)]*G[{0, yu^(-1), yv^(-1), 1}, yw])/8 + 
     (G[{yu}, yv^(-1)]*G[{0, yu^(-1), yv^(-1), 1}, yw])/4 + 
     (G[{1}, yw]*G[{0, yu^(-1), yv^(-1), yu^(-1)}, yw])/8 - 
     (G[{1/(yu*yv)}, yw]*G[{0, yu^(-1), yv^(-1), yu^(-1)}, yw])/8 + 
     (G[{1}, yw]*G[{0, yu^(-1), yv^(-1), yv^(-1)}, yw])/8 - 
     (G[{1/(yu*yv)}, yw]*G[{0, yu^(-1), yv^(-1), yv^(-1)}, yw])/8 + 
     (3*G[{0}, yu^(-1)]*G[{0, yu^(-1), yv^(-1), 1/(yu*yv)}, yw])/16 + 
     (3*G[{0}, yv^(-1)]*G[{0, yu^(-1), yv^(-1), 1/(yu*yv)}, yw])/16 - 
     (3*G[{0}, yw]*G[{0, yu^(-1), yv^(-1), 1/(yu*yv)}, yw])/16 - 
     (G[{1}, yu^(-1)]*G[{0, yu^(-1), yv^(-1), 1/(yu*yv)}, yw])/4 + 
     (G[{1}, yv^(-1)]*G[{0, yu^(-1), yv^(-1), 1/(yu*yv)}, yw])/8 - 
     (G[{yu}, yv^(-1)]*G[{0, yu^(-1), yv^(-1), 1/(yu*yv)}, yw])/4 + 
     (G[{0}, yu^(-1)]*G[{0, yu^(-1), 1/(yu*yv), 1}, yw])/8 + 
     (G[{0}, yv^(-1)]*G[{0, yu^(-1), 1/(yu*yv), 1}, yw])/8 - 
     (G[{0}, yw]*G[{0, yu^(-1), 1/(yu*yv), 1}, yw])/8 - 
     (G[{1}, yu^(-1)]*G[{0, yu^(-1), 1/(yu*yv), 1}, yw])/8 - 
     (G[{1}, yv^(-1)]*G[{0, yu^(-1), 1/(yu*yv), 1}, yw])/8 - 
     (G[{0}, yu^(-1)]*G[{0, yu^(-1), 1/(yu*yv), yu^(-1)}, yw])/16 - 
     (G[{0}, yv^(-1)]*G[{0, yu^(-1), 1/(yu*yv), yu^(-1)}, yw])/16 + 
     (G[{0}, yw]*G[{0, yu^(-1), 1/(yu*yv), yu^(-1)}, yw])/16 + 
     (G[{1}, yv^(-1)]*G[{0, yu^(-1), 1/(yu*yv), yu^(-1)}, yw])/4 - 
     (G[{yu}, yv^(-1)]*G[{0, yu^(-1), 1/(yu*yv), yu^(-1)}, yw])/8 + 
     (3*G[{0}, yu^(-1)]*G[{0, yu^(-1), 1/(yu*yv), yv^(-1)}, yw])/16 + 
     (3*G[{0}, yv^(-1)]*G[{0, yu^(-1), 1/(yu*yv), yv^(-1)}, yw])/16 - 
     (3*G[{0}, yw]*G[{0, yu^(-1), 1/(yu*yv), yv^(-1)}, yw])/16 - 
     (G[{1}, yu^(-1)]*G[{0, yu^(-1), 1/(yu*yv), yv^(-1)}, yw])/4 - 
     (G[{yu}, yv^(-1)]*G[{0, yu^(-1), 1/(yu*yv), yv^(-1)}, yw])/8 - 
     (G[{0}, yu^(-1)]*G[{0, yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/8 - 
     (G[{0}, yv^(-1)]*G[{0, yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/8 + 
     (G[{0}, yw]*G[{0, yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/8 + 
     (G[{1}, yu^(-1)]*G[{0, yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/8 + 
     (G[{1}, yv^(-1)]*G[{0, yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/8 - 
     (G[{1}, yu^(-1)]*G[{0, yu, 1, 1}, yv^(-1)])/8 - 
     (15*G[{1}, yv^(-1)]*G[{0, yu, 1, 1}, yv^(-1)])/64 + 
     (G[{1}, yw]*G[{0, yu, 1, 1}, yv^(-1)])/64 - 
     (G[{1/(yu*yv)}, yw]*G[{0, yu, 1, 1}, yv^(-1)])/64 + 
     (G[{1}, yu^(-1)]*G[{0, yu, 1, yu}, yv^(-1)])/8 + 
     (G[{1}, yv^(-1)]*G[{0, yu, 1, yu}, yv^(-1)])/64 + 
     (5*G[{1}, yw]*G[{0, yu, 1, yu}, yv^(-1)])/64 - 
     (5*G[{1/(yu*yv)}, yw]*G[{0, yu, 1, yu}, yv^(-1)])/64 + 
     (G[{1}, yu^(-1)]*G[{0, yu, yu, 1}, yv^(-1)])/8 + 
     (5*G[{1}, yv^(-1)]*G[{0, yu, yu, 1}, yv^(-1)])/64 + 
     (5*G[{1}, yw]*G[{0, yu, yu, 1}, yv^(-1)])/64 - 
     (5*G[{1/(yu*yv)}, yw]*G[{0, yu, yu, 1}, yv^(-1)])/64 + 
     (13*G[{1}, yv^(-1)]*G[{0, yu, yu, yu}, yv^(-1)])/64 - 
     (3*G[{1}, yw]*G[{0, yu, yu, yu}, yv^(-1)])/64 + 
     (3*G[{1/(yu*yv)}, yw]*G[{0, yu, yu, yu}, yv^(-1)])/64 - 
     (G[{1}, yv^(-1)]*G[{0, yv^(-1), 0, 1/(yu*yv)}, yw])/8 + 
     (G[{yu}, yv^(-1)]*G[{0, yv^(-1), 0, 1/(yu*yv)}, yw])/8 - 
     (G[{1}, yv^(-1)]*G[{0, yv^(-1), 1, yu^(-1)}, yw])/8 + 
     (G[{yu}, yv^(-1)]*G[{0, yv^(-1), 1, yu^(-1)}, yw])/8 - 
     (G[{0}, yu^(-1)]*G[{0, yv^(-1), 1, yv^(-1)}, yw])/8 - 
     (G[{0}, yv^(-1)]*G[{0, yv^(-1), 1, yv^(-1)}, yw])/8 + 
     (G[{0}, yw]*G[{0, yv^(-1), 1, yv^(-1)}, yw])/8 + 
     (G[{1}, yu^(-1)]*G[{0, yv^(-1), 1, yv^(-1)}, yw])/8 + 
     (G[{yu}, yv^(-1)]*G[{0, yv^(-1), 1, yv^(-1)}, yw])/8 - 
     (3*G[{0}, yu^(-1)]*G[{0, yv^(-1), yu^(-1), 1}, yw])/16 - 
     (3*G[{0}, yv^(-1)]*G[{0, yv^(-1), yu^(-1), 1}, yw])/16 + 
     (3*G[{0}, yw]*G[{0, yv^(-1), yu^(-1), 1}, yw])/16 + 
     (G[{1}, yu^(-1)]*G[{0, yv^(-1), yu^(-1), 1}, yw])/4 - 
     (G[{1}, yv^(-1)]*G[{0, yv^(-1), yu^(-1), 1}, yw])/8 + 
     (G[{yu}, yv^(-1)]*G[{0, yv^(-1), yu^(-1), 1}, yw])/4 + 
     (G[{1}, yw]*G[{0, yv^(-1), yu^(-1), yu^(-1)}, yw])/8 - 
     (G[{1/(yu*yv)}, yw]*G[{0, yv^(-1), yu^(-1), yu^(-1)}, yw])/8 + 
     (G[{1}, yw]*G[{0, yv^(-1), yu^(-1), yv^(-1)}, yw])/8 - 
     (G[{1/(yu*yv)}, yw]*G[{0, yv^(-1), yu^(-1), yv^(-1)}, yw])/8 + 
     (3*G[{0}, yu^(-1)]*G[{0, yv^(-1), yu^(-1), 1/(yu*yv)}, yw])/16 + 
     (3*G[{0}, yv^(-1)]*G[{0, yv^(-1), yu^(-1), 1/(yu*yv)}, yw])/16 - 
     (3*G[{0}, yw]*G[{0, yv^(-1), yu^(-1), 1/(yu*yv)}, yw])/16 - 
     (G[{1}, yu^(-1)]*G[{0, yv^(-1), yu^(-1), 1/(yu*yv)}, yw])/4 + 
     (G[{1}, yv^(-1)]*G[{0, yv^(-1), yu^(-1), 1/(yu*yv)}, yw])/8 - 
     (G[{yu}, yv^(-1)]*G[{0, yv^(-1), yu^(-1), 1/(yu*yv)}, yw])/4 - 
     (G[{0}, yu^(-1)]*G[{0, yv^(-1), yv^(-1), 1}, yw])/8 - 
     (G[{0}, yv^(-1)]*G[{0, yv^(-1), yv^(-1), 1}, yw])/8 + 
     (G[{0}, yw]*G[{0, yv^(-1), yv^(-1), 1}, yw])/8 + 
     (G[{1}, yu^(-1)]*G[{0, yv^(-1), yv^(-1), 1}, yw])/8 - 
     (G[{1}, yv^(-1)]*G[{0, yv^(-1), yv^(-1), 1}, yw])/8 + 
     (G[{yu}, yv^(-1)]*G[{0, yv^(-1), yv^(-1), 1}, yw])/4 + 
     (G[{1}, yw]*G[{0, yv^(-1), yv^(-1), yu^(-1)}, yw])/8 - 
     (G[{1/(yu*yv)}, yw]*G[{0, yv^(-1), yv^(-1), yu^(-1)}, yw])/8 + 
     (G[{0}, yu^(-1)]*G[{0, yv^(-1), yv^(-1), 1/(yu*yv)}, yw])/8 + 
     (G[{0}, yv^(-1)]*G[{0, yv^(-1), yv^(-1), 1/(yu*yv)}, yw])/8 - 
     (G[{0}, yw]*G[{0, yv^(-1), yv^(-1), 1/(yu*yv)}, yw])/8 - 
     (G[{1}, yu^(-1)]*G[{0, yv^(-1), yv^(-1), 1/(yu*yv)}, yw])/8 + 
     (G[{1}, yv^(-1)]*G[{0, yv^(-1), yv^(-1), 1/(yu*yv)}, yw])/8 - 
     (G[{yu}, yv^(-1)]*G[{0, yv^(-1), yv^(-1), 1/(yu*yv)}, yw])/4 + 
     (G[{0}, yu^(-1)]*G[{0, yv^(-1), 1/(yu*yv), 1}, yw])/8 + 
     (G[{0}, yv^(-1)]*G[{0, yv^(-1), 1/(yu*yv), 1}, yw])/8 - 
     (G[{0}, yw]*G[{0, yv^(-1), 1/(yu*yv), 1}, yw])/8 - 
     (G[{1}, yu^(-1)]*G[{0, yv^(-1), 1/(yu*yv), 1}, yw])/8 - 
     (G[{1}, yv^(-1)]*G[{0, yv^(-1), 1/(yu*yv), 1}, yw])/8 + 
     (G[{1}, yv^(-1)]*G[{0, yv^(-1), 1/(yu*yv), yu^(-1)}, yw])/8 - 
     (G[{yu}, yv^(-1)]*G[{0, yv^(-1), 1/(yu*yv), yu^(-1)}, yw])/8 + 
     (G[{0}, yu^(-1)]*G[{0, yv^(-1), 1/(yu*yv), yv^(-1)}, yw])/8 + 
     (G[{0}, yv^(-1)]*G[{0, yv^(-1), 1/(yu*yv), yv^(-1)}, yw])/8 - 
     (G[{0}, yw]*G[{0, yv^(-1), 1/(yu*yv), yv^(-1)}, yw])/8 - 
     (G[{1}, yu^(-1)]*G[{0, yv^(-1), 1/(yu*yv), yv^(-1)}, yw])/8 - 
     (G[{yu}, yv^(-1)]*G[{0, yv^(-1), 1/(yu*yv), yv^(-1)}, yw])/8 - 
     (G[{0}, yu^(-1)]*G[{0, yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/8 - 
     (G[{0}, yv^(-1)]*G[{0, yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/8 + 
     (G[{0}, yw]*G[{0, yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/8 + 
     (G[{1}, yu^(-1)]*G[{0, yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/8 + 
     (G[{1}, yv^(-1)]*G[{0, yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/8 - 
     (G[{0}, yu^(-1)]*G[{0, 1/(yu*yv), 1, 1}, yw])/8 - 
     (G[{0}, yv^(-1)]*G[{0, 1/(yu*yv), 1, 1}, yw])/8 + 
     (G[{0}, yw]*G[{0, 1/(yu*yv), 1, 1}, yw])/8 + 
     (G[{1}, yu^(-1)]*G[{0, 1/(yu*yv), 1, 1}, yw])/16 - 
     (G[{1}, yv^(-1)]*G[{0, 1/(yu*yv), 1, 1}, yw])/8 - 
     (G[{1}, yw]*G[{0, 1/(yu*yv), 1, 1}, yw])/8 + 
     (5*G[{yu}, yv^(-1)]*G[{0, 1/(yu*yv), 1, 1}, yw])/16 + 
     (G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv), 1, 1}, yw])/8 + 
     (G[{0}, yu^(-1)]*G[{0, 1/(yu*yv), 1, yu^(-1)}, yw])/8 + 
     (G[{0}, yv^(-1)]*G[{0, 1/(yu*yv), 1, yu^(-1)}, yw])/8 - 
     (G[{0}, yw]*G[{0, 1/(yu*yv), 1, yu^(-1)}, yw])/8 - 
     (G[{1}, yv^(-1)]*G[{0, 1/(yu*yv), 1, yu^(-1)}, yw])/8 - 
     (G[{yu}, yv^(-1)]*G[{0, 1/(yu*yv), 1, yu^(-1)}, yw])/8 + 
     (G[{0}, yu^(-1)]*G[{0, 1/(yu*yv), 1, yv^(-1)}, yw])/8 + 
     (G[{0}, yv^(-1)]*G[{0, 1/(yu*yv), 1, yv^(-1)}, yw])/8 - 
     (G[{0}, yw]*G[{0, 1/(yu*yv), 1, yv^(-1)}, yw])/8 - 
     (G[{1}, yu^(-1)]*G[{0, 1/(yu*yv), 1, yv^(-1)}, yw])/8 - 
     (G[{yu}, yv^(-1)]*G[{0, 1/(yu*yv), 1, yv^(-1)}, yw])/8 - 
     (G[{0}, yu^(-1)]*G[{0, 1/(yu*yv), 1, 1/(yu*yv)}, yw])/8 - 
     (G[{0}, yv^(-1)]*G[{0, 1/(yu*yv), 1, 1/(yu*yv)}, yw])/8 + 
     (G[{0}, yw]*G[{0, 1/(yu*yv), 1, 1/(yu*yv)}, yw])/8 + 
     (G[{1}, yu^(-1)]*G[{0, 1/(yu*yv), 1, 1/(yu*yv)}, yw])/16 + 
     (G[{1}, yv^(-1)]*G[{0, 1/(yu*yv), 1, 1/(yu*yv)}, yw])/4 - 
     (G[{yu}, yv^(-1)]*G[{0, 1/(yu*yv), 1, 1/(yu*yv)}, yw])/16 + 
     (5*G[{0}, yu^(-1)]*G[{0, 1/(yu*yv), yu^(-1), 1}, yw])/16 + 
     (5*G[{0}, yv^(-1)]*G[{0, 1/(yu*yv), yu^(-1), 1}, yw])/16 - 
     (5*G[{0}, yw]*G[{0, 1/(yu*yv), yu^(-1), 1}, yw])/16 - 
     (5*G[{1}, yu^(-1)]*G[{0, 1/(yu*yv), yu^(-1), 1}, yw])/16 - 
     (5*G[{yu}, yv^(-1)]*G[{0, 1/(yu*yv), yu^(-1), 1}, yw])/16 - 
     (G[{0}, yu^(-1)]*G[{0, 1/(yu*yv), yu^(-1), yu^(-1)}, yw])/8 - 
     (G[{0}, yv^(-1)]*G[{0, 1/(yu*yv), yu^(-1), yu^(-1)}, yw])/8 + 
     (G[{0}, yw]*G[{0, 1/(yu*yv), yu^(-1), yu^(-1)}, yw])/8 + 
     (G[{1}, yv^(-1)]*G[{0, 1/(yu*yv), yu^(-1), yu^(-1)}, yw])/2 - 
     (G[{yu}, yv^(-1)]*G[{0, 1/(yu*yv), yu^(-1), yu^(-1)}, yw])/4 - 
     (G[{1}, yw]*G[{0, 1/(yu*yv), yu^(-1), yv^(-1)}, yw])/8 + 
     (G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv), yu^(-1), yv^(-1)}, yw])/8 - 
     (G[{0}, yu^(-1)]*G[{0, 1/(yu*yv), yu^(-1), 1/(yu*yv)}, yw])/16 - 
     (G[{0}, yv^(-1)]*G[{0, 1/(yu*yv), yu^(-1), 1/(yu*yv)}, yw])/16 + 
     (G[{0}, yw]*G[{0, 1/(yu*yv), yu^(-1), 1/(yu*yv)}, yw])/16 + 
     (3*G[{1}, yu^(-1)]*G[{0, 1/(yu*yv), yu^(-1), 1/(yu*yv)}, yw])/16 - 
     (3*G[{1}, yv^(-1)]*G[{0, 1/(yu*yv), yu^(-1), 1/(yu*yv)}, yw])/8 + 
     (5*G[{yu}, yv^(-1)]*G[{0, 1/(yu*yv), yu^(-1), 1/(yu*yv)}, yw])/16 + 
     (G[{0}, yu^(-1)]*G[{0, 1/(yu*yv), yv^(-1), 1}, yw])/8 + 
     (G[{0}, yv^(-1)]*G[{0, 1/(yu*yv), yv^(-1), 1}, yw])/8 - 
     (G[{0}, yw]*G[{0, 1/(yu*yv), yv^(-1), 1}, yw])/8 - 
     (3*G[{1}, yu^(-1)]*G[{0, 1/(yu*yv), yv^(-1), 1}, yw])/16 + 
     (G[{1}, yv^(-1)]*G[{0, 1/(yu*yv), yv^(-1), 1}, yw])/4 - 
     (5*G[{yu}, yv^(-1)]*G[{0, 1/(yu*yv), yv^(-1), 1}, yw])/16 - 
     (G[{1}, yw]*G[{0, 1/(yu*yv), yv^(-1), yu^(-1)}, yw])/8 + 
     (G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv), yv^(-1), yu^(-1)}, yw])/8 + 
     (G[{0}, yu^(-1)]*G[{0, 1/(yu*yv), yv^(-1), yv^(-1)}, yw])/4 + 
     (G[{0}, yv^(-1)]*G[{0, 1/(yu*yv), yv^(-1), yv^(-1)}, yw])/4 - 
     (G[{0}, yw]*G[{0, 1/(yu*yv), yv^(-1), yv^(-1)}, yw])/4 - 
     (G[{1}, yu^(-1)]*G[{0, 1/(yu*yv), yv^(-1), yv^(-1)}, yw])/4 - 
     (G[{yu}, yv^(-1)]*G[{0, 1/(yu*yv), yv^(-1), yv^(-1)}, yw])/4 - 
     (G[{0}, yu^(-1)]*G[{0, 1/(yu*yv), yv^(-1), 1/(yu*yv)}, yw])/4 - 
     (G[{0}, yv^(-1)]*G[{0, 1/(yu*yv), yv^(-1), 1/(yu*yv)}, yw])/4 + 
     (G[{0}, yw]*G[{0, 1/(yu*yv), yv^(-1), 1/(yu*yv)}, yw])/4 + 
     (3*G[{1}, yu^(-1)]*G[{0, 1/(yu*yv), yv^(-1), 1/(yu*yv)}, yw])/16 + 
     (5*G[{yu}, yv^(-1)]*G[{0, 1/(yu*yv), yv^(-1), 1/(yu*yv)}, yw])/16 - 
     (3*G[{0}, yu^(-1)]*G[{0, 1/(yu*yv), 1/(yu*yv), 1}, yw])/16 - 
     (3*G[{0}, yv^(-1)]*G[{0, 1/(yu*yv), 1/(yu*yv), 1}, yw])/16 + 
     (3*G[{0}, yw]*G[{0, 1/(yu*yv), 1/(yu*yv), 1}, yw])/16 + 
     (3*G[{1}, yu^(-1)]*G[{0, 1/(yu*yv), 1/(yu*yv), 1}, yw])/16 + 
     (3*G[{1}, yv^(-1)]*G[{0, 1/(yu*yv), 1/(yu*yv), 1}, yw])/8 - 
     (3*G[{yu}, yv^(-1)]*G[{0, 1/(yu*yv), 1/(yu*yv), 1}, yw])/16 + 
     (G[{0}, yu^(-1)]*G[{0, 1/(yu*yv), 1/(yu*yv), yu^(-1)}, yw])/16 + 
     (G[{0}, yv^(-1)]*G[{0, 1/(yu*yv), 1/(yu*yv), yu^(-1)}, yw])/16 - 
     (G[{0}, yw]*G[{0, 1/(yu*yv), 1/(yu*yv), yu^(-1)}, yw])/16 - 
     (G[{1}, yv^(-1)]*G[{0, 1/(yu*yv), 1/(yu*yv), yu^(-1)}, yw])/2 + 
     (3*G[{yu}, yv^(-1)]*G[{0, 1/(yu*yv), 1/(yu*yv), yu^(-1)}, yw])/8 - 
     (5*G[{0}, yu^(-1)]*G[{0, 1/(yu*yv), 1/(yu*yv), yv^(-1)}, yw])/16 - 
     (5*G[{0}, yv^(-1)]*G[{0, 1/(yu*yv), 1/(yu*yv), yv^(-1)}, yw])/16 + 
     (5*G[{0}, yw]*G[{0, 1/(yu*yv), 1/(yu*yv), yv^(-1)}, yw])/16 + 
     (G[{1}, yu^(-1)]*G[{0, 1/(yu*yv), 1/(yu*yv), yv^(-1)}, yw])/4 + 
     (3*G[{yu}, yv^(-1)]*G[{0, 1/(yu*yv), 1/(yu*yv), yv^(-1)}, yw])/8 + 
     (3*G[{0}, yu^(-1)]*G[{0, 1/(yu*yv), 1/(yu*yv), 1/(yu*yv)}, yw])/16 + 
     (3*G[{0}, yv^(-1)]*G[{0, 1/(yu*yv), 1/(yu*yv), 1/(yu*yv)}, yw])/16 - 
     (3*G[{0}, yw]*G[{0, 1/(yu*yv), 1/(yu*yv), 1/(yu*yv)}, yw])/16 - 
     (G[{1}, yu^(-1)]*G[{0, 1/(yu*yv), 1/(yu*yv), 1/(yu*yv)}, yw])/16 - 
     (G[{1}, yv^(-1)]*G[{0, 1/(yu*yv), 1/(yu*yv), 1/(yu*yv)}, yw])/4 - 
     (G[{yu}, yv^(-1)]*G[{0, 1/(yu*yv), 1/(yu*yv), 1/(yu*yv)}, yw])/16 + 
     (G[{0}, yu^(-1)]*G[{1, 1, 1, yu^(-1)}, yw])/16 + 
     (G[{0}, yv^(-1)]*G[{1, 1, 1, yu^(-1)}, yw])/16 - 
     (G[{0}, yw]*G[{1, 1, 1, yu^(-1)}, yw])/16 - 
     (3*G[{1}, yu^(-1)]*G[{1, 1, 1, yu^(-1)}, yw])/16 - 
     (G[{1}, yv^(-1)]*G[{1, 1, 1, yu^(-1)}, yw])/64 - 
     (5*G[{1}, yw]*G[{1, 1, 1, yu^(-1)}, yw])/64 + 
     (5*G[{yu}, yv^(-1)]*G[{1, 1, 1, yu^(-1)}, yw])/64 + 
     (G[{1/(yu*yv)}, yw]*G[{1, 1, 1, yu^(-1)}, yw])/64 + 
     (5*G[{1}, yu^(-1)]*G[{1, 1, 1, yu}, yv^(-1)])/16 + 
     (3*G[{1}, yv^(-1)]*G[{1, 1, 1, yu}, yv^(-1)])/64 - 
     (G[{1}, yw]*G[{1, 1, 1, yu}, yv^(-1)])/64 + 
     (G[{1/(yu*yv)}, yw]*G[{1, 1, 1, yu}, yv^(-1)])/64 + 
     (G[{0}, yu^(-1)]*G[{1, 1, 1, yv^(-1)}, yw])/4 + 
     (G[{0}, yv^(-1)]*G[{1, 1, 1, yv^(-1)}, yw])/4 - 
     (G[{0}, yw]*G[{1, 1, 1, yv^(-1)}, yw])/4 - 
     (G[{1}, yu^(-1)]*G[{1, 1, 1, yv^(-1)}, yw])/4 - 
     (3*G[{1}, yv^(-1)]*G[{1, 1, 1, yv^(-1)}, yw])/16 + 
     (G[{1}, yw]*G[{1, 1, 1, yv^(-1)}, yw])/16 - 
     (G[{yu}, yv^(-1)]*G[{1, 1, 1, yv^(-1)}, yw])/16 - 
     (G[{1/(yu*yv)}, yw]*G[{1, 1, 1, yv^(-1)}, yw])/8 - 
     (G[{0}, yu^(-1)]*G[{1, 1, 1, 1/(yu*yv)}, yw])/16 - 
     (G[{0}, yv^(-1)]*G[{1, 1, 1, 1/(yu*yv)}, yw])/16 + 
     (G[{0}, yw]*G[{1, 1, 1, 1/(yu*yv)}, yw])/16 + 
     (5*G[{1}, yu^(-1)]*G[{1, 1, 1, 1/(yu*yv)}, yw])/16 + 
     (29*G[{1}, yv^(-1)]*G[{1, 1, 1, 1/(yu*yv)}, yw])/64 + 
     (41*G[{1}, yw]*G[{1, 1, 1, 1/(yu*yv)}, yw])/64 - 
     (41*G[{yu}, yv^(-1)]*G[{1, 1, 1, 1/(yu*yv)}, yw])/64 - 
     (9*G[{1/(yu*yv)}, yw]*G[{1, 1, 1, 1/(yu*yv)}, yw])/64 + 
     (G[{0}, yu^(-1)]*G[{1, 1, yu^(-1), yu^(-1)}, yw])/4 + 
     (G[{0}, yv^(-1)]*G[{1, 1, yu^(-1), yu^(-1)}, yw])/4 - 
     (G[{0}, yw]*G[{1, 1, yu^(-1), yu^(-1)}, yw])/4 - 
     (41*G[{1}, yv^(-1)]*G[{1, 1, yu^(-1), yu^(-1)}, yw])/64 - 
     (9*G[{1}, yw]*G[{1, 1, yu^(-1), yu^(-1)}, yw])/64 + 
     (9*G[{yu}, yv^(-1)]*G[{1, 1, yu^(-1), yu^(-1)}, yw])/64 - 
     (5*G[{1/(yu*yv)}, yw]*G[{1, 1, yu^(-1), yu^(-1)}, yw])/64 - 
     (G[{1}, yv^(-1)]*G[{1, 1, yu^(-1), yv^(-1)}, yw])/4 - 
     (G[{1}, yw]*G[{1, 1, yu^(-1), yv^(-1)}, yw])/4 + 
     (G[{yu}, yv^(-1)]*G[{1, 1, yu^(-1), yv^(-1)}, yw])/4 + 
     (3*G[{0}, yu^(-1)]*G[{1, 1, yu^(-1), 1/(yu*yv)}, yw])/16 + 
     (3*G[{0}, yv^(-1)]*G[{1, 1, yu^(-1), 1/(yu*yv)}, yw])/16 - 
     (3*G[{0}, yw]*G[{1, 1, yu^(-1), 1/(yu*yv)}, yw])/16 - 
     (3*G[{1}, yu^(-1)]*G[{1, 1, yu^(-1), 1/(yu*yv)}, yw])/16 - 
     (G[{1}, yv^(-1)]*G[{1, 1, yu^(-1), 1/(yu*yv)}, yw])/8 + 
     (G[{1}, yw]*G[{1, 1, yu^(-1), 1/(yu*yv)}, yw])/16 - 
     (G[{yu}, yv^(-1)]*G[{1, 1, yu^(-1), 1/(yu*yv)}, yw])/16 + 
     (3*G[{1/(yu*yv)}, yw]*G[{1, 1, yu^(-1), 1/(yu*yv)}, yw])/32 + 
     (3*G[{1}, yu^(-1)]*G[{1, 1, yu, yu}, yv^(-1)])/16 + 
     (23*G[{1}, yv^(-1)]*G[{1, 1, yu, yu}, yv^(-1)])/64 + 
     (5*G[{1}, yw]*G[{1, 1, yu, yu}, yv^(-1)])/64 - 
     (5*G[{1/(yu*yv)}, yw]*G[{1, 1, yu, yu}, yv^(-1)])/64 - 
     (G[{1}, yv^(-1)]*G[{1, 1, yv^(-1), yu^(-1)}, yw])/4 - 
     (G[{1}, yw]*G[{1, 1, yv^(-1), yu^(-1)}, yw])/4 + 
     (G[{yu}, yv^(-1)]*G[{1, 1, yv^(-1), yu^(-1)}, yw])/4 - 
     (G[{0}, yu^(-1)]*G[{1, 1, yv^(-1), yv^(-1)}, yw])/8 - 
     (G[{0}, yv^(-1)]*G[{1, 1, yv^(-1), yv^(-1)}, yw])/8 + 
     (G[{0}, yw]*G[{1, 1, yv^(-1), yv^(-1)}, yw])/8 + 
     (G[{1}, yu^(-1)]*G[{1, 1, yv^(-1), yv^(-1)}, yw])/16 - 
     (3*G[{1}, yw]*G[{1, 1, yv^(-1), yv^(-1)}, yw])/16 + 
     (3*G[{yu}, yv^(-1)]*G[{1, 1, yv^(-1), yv^(-1)}, yw])/16 - 
     (G[{1/(yu*yv)}, yw]*G[{1, 1, yv^(-1), yv^(-1)}, yw])/8 + 
     (3*G[{0}, yu^(-1)]*G[{1, 1, yv^(-1), 1/(yu*yv)}, yw])/8 + 
     (3*G[{0}, yv^(-1)]*G[{1, 1, yv^(-1), 1/(yu*yv)}, yw])/8 - 
     (3*G[{0}, yw]*G[{1, 1, yv^(-1), 1/(yu*yv)}, yw])/8 - 
     (5*G[{1}, yu^(-1)]*G[{1, 1, yv^(-1), 1/(yu*yv)}, yw])/16 - 
     (3*G[{1}, yv^(-1)]*G[{1, 1, yv^(-1), 1/(yu*yv)}, yw])/16 + 
     (G[{1}, yw]*G[{1, 1, yv^(-1), 1/(yu*yv)}, yw])/4 - 
     (G[{yu}, yv^(-1)]*G[{1, 1, yv^(-1), 1/(yu*yv)}, yw])/4 + 
     (G[{0}, yu^(-1)]*G[{1, 1, 1/(yu*yv), yu^(-1)}, yw])/8 + 
     (G[{0}, yv^(-1)]*G[{1, 1, 1/(yu*yv), yu^(-1)}, yw])/8 - 
     (G[{0}, yw]*G[{1, 1, 1/(yu*yv), yu^(-1)}, yw])/8 - 
     (7*G[{1}, yv^(-1)]*G[{1, 1, 1/(yu*yv), yu^(-1)}, yw])/64 + 
     (9*G[{1}, yw]*G[{1, 1, 1/(yu*yv), yu^(-1)}, yw])/64 - 
     (9*G[{yu}, yv^(-1)]*G[{1, 1, 1/(yu*yv), yu^(-1)}, yw])/64 + 
     (5*G[{1/(yu*yv)}, yw]*G[{1, 1, 1/(yu*yv), yu^(-1)}, yw])/64 + 
     (G[{0}, yu^(-1)]*G[{1, 1, 1/(yu*yv), yv^(-1)}, yw])/8 + 
     (G[{0}, yv^(-1)]*G[{1, 1, 1/(yu*yv), yv^(-1)}, yw])/8 - 
     (G[{0}, yw]*G[{1, 1, 1/(yu*yv), yv^(-1)}, yw])/8 - 
     (G[{1}, yu^(-1)]*G[{1, 1, 1/(yu*yv), yv^(-1)}, yw])/16 + 
     (3*G[{1}, yw]*G[{1, 1, 1/(yu*yv), yv^(-1)}, yw])/16 - 
     (3*G[{yu}, yv^(-1)]*G[{1, 1, 1/(yu*yv), yv^(-1)}, yw])/16 + 
     (G[{1/(yu*yv)}, yw]*G[{1, 1, 1/(yu*yv), yv^(-1)}, yw])/8 - 
     (G[{0}, yu^(-1)]*G[{1, 1, 1/(yu*yv), 1/(yu*yv)}, yw])/16 - 
     (G[{0}, yv^(-1)]*G[{1, 1, 1/(yu*yv), 1/(yu*yv)}, yw])/16 + 
     (G[{0}, yw]*G[{1, 1, 1/(yu*yv), 1/(yu*yv)}, yw])/16 + 
     (G[{1}, yu^(-1)]*G[{1, 1, 1/(yu*yv), 1/(yu*yv)}, yw])/8 + 
     (5*G[{1}, yv^(-1)]*G[{1, 1, 1/(yu*yv), 1/(yu*yv)}, yw])/16 + 
     (5*G[{1}, yw]*G[{1, 1, 1/(yu*yv), 1/(yu*yv)}, yw])/16 - 
     (5*G[{yu}, yv^(-1)]*G[{1, 1, 1/(yu*yv), 1/(yu*yv)}, yw])/16 - 
     (3*G[{1/(yu*yv)}, yw]*G[{1, 1, 1/(yu*yv), 1/(yu*yv)}, yw])/32 + 
     (3*G[{0}, yu^(-1)]*G[{1, yu^(-1), 1, yv^(-1)}, yw])/16 + 
     (3*G[{0}, yv^(-1)]*G[{1, yu^(-1), 1, yv^(-1)}, yw])/16 - 
     (3*G[{0}, yw]*G[{1, yu^(-1), 1, yv^(-1)}, yw])/16 - 
     (G[{1}, yu^(-1)]*G[{1, yu^(-1), 1, yv^(-1)}, yw])/4 - 
     (G[{1}, yv^(-1)]*G[{1, yu^(-1), 1, yv^(-1)}, yw])/8 + 
     (3*G[{0}, yu^(-1)]*G[{1, yu^(-1), 1, 1/(yu*yv)}, yw])/16 + 
     (3*G[{0}, yv^(-1)]*G[{1, yu^(-1), 1, 1/(yu*yv)}, yw])/16 - 
     (3*G[{0}, yw]*G[{1, yu^(-1), 1, 1/(yu*yv)}, yw])/16 - 
     (G[{1}, yu^(-1)]*G[{1, yu^(-1), 1, 1/(yu*yv)}, yw])/8 - 
     (G[{1}, yv^(-1)]*G[{1, yu^(-1), 1, 1/(yu*yv)}, yw])/8 + 
     (G[{1}, yw]*G[{1, yu^(-1), 1, 1/(yu*yv)}, yw])/8 - 
     (G[{yu}, yv^(-1)]*G[{1, yu^(-1), 1, 1/(yu*yv)}, yw])/8 + 
     (G[{0}, yu^(-1)]*G[{1, yu^(-1), yu^(-1), yu^(-1)}, yw])/2 + 
     (G[{0}, yv^(-1)]*G[{1, yu^(-1), yu^(-1), yu^(-1)}, yw])/2 - 
     (G[{0}, yw]*G[{1, yu^(-1), yu^(-1), yu^(-1)}, yw])/2 - 
     (41*G[{1}, yv^(-1)]*G[{1, yu^(-1), yu^(-1), yu^(-1)}, yw])/32 - 
     (9*G[{1}, yw]*G[{1, yu^(-1), yu^(-1), yu^(-1)}, yw])/32 + 
     (9*G[{yu}, yv^(-1)]*G[{1, yu^(-1), yu^(-1), yu^(-1)}, yw])/32 - 
     (3*G[{1/(yu*yv)}, yw]*G[{1, yu^(-1), yu^(-1), yu^(-1)}, yw])/64 + 
     (G[{1/(yu*yv)}, yw]*G[{1, yu^(-1), yu^(-1), yv^(-1)}, yw])/8 - 
     (G[{0}, yu^(-1)]*G[{1, yu^(-1), yu^(-1), 1/(yu*yv)}, yw])/2 - 
     (G[{0}, yv^(-1)]*G[{1, yu^(-1), yu^(-1), 1/(yu*yv)}, yw])/2 + 
     (G[{0}, yw]*G[{1, yu^(-1), yu^(-1), 1/(yu*yv)}, yw])/2 + 
     (G[{1}, yu^(-1)]*G[{1, yu^(-1), yu^(-1), 1/(yu*yv)}, yw])/2 + 
     (9*G[{1}, yv^(-1)]*G[{1, yu^(-1), yu^(-1), 1/(yu*yv)}, yw])/64 - 
     (23*G[{1}, yw]*G[{1, yu^(-1), yu^(-1), 1/(yu*yv)}, yw])/64 + 
     (23*G[{yu}, yv^(-1)]*G[{1, yu^(-1), yu^(-1), 1/(yu*yv)}, yw])/64 + 
     (3*G[{1/(yu*yv)}, yw]*G[{1, yu^(-1), yu^(-1), 1/(yu*yv)}, yw])/32 + 
     (G[{1/(yu*yv)}, yw]*G[{1, yu^(-1), yv^(-1), yu^(-1)}, yw])/8 + 
     (G[{1/(yu*yv)}, yw]*G[{1, yu^(-1), yv^(-1), yv^(-1)}, yw])/8 - 
     (3*G[{0}, yu^(-1)]*G[{1, yu^(-1), yv^(-1), 1/(yu*yv)}, yw])/16 - 
     (3*G[{0}, yv^(-1)]*G[{1, yu^(-1), yv^(-1), 1/(yu*yv)}, yw])/16 + 
     (3*G[{0}, yw]*G[{1, yu^(-1), yv^(-1), 1/(yu*yv)}, yw])/16 + 
     (G[{1}, yu^(-1)]*G[{1, yu^(-1), yv^(-1), 1/(yu*yv)}, yw])/4 - 
     (G[{1}, yv^(-1)]*G[{1, yu^(-1), yv^(-1), 1/(yu*yv)}, yw])/8 - 
     (G[{1}, yw]*G[{1, yu^(-1), yv^(-1), 1/(yu*yv)}, yw])/4 + 
     (G[{yu}, yv^(-1)]*G[{1, yu^(-1), yv^(-1), 1/(yu*yv)}, yw])/4 - 
     (G[{0}, yu^(-1)]*G[{1, yu^(-1), 1/(yu*yv), yu^(-1)}, yw])/8 - 
     (G[{0}, yv^(-1)]*G[{1, yu^(-1), 1/(yu*yv), yu^(-1)}, yw])/8 + 
     (G[{0}, yw]*G[{1, yu^(-1), 1/(yu*yv), yu^(-1)}, yw])/8 + 
     (9*G[{1}, yv^(-1)]*G[{1, yu^(-1), 1/(yu*yv), yu^(-1)}, yw])/64 - 
     (7*G[{1}, yw]*G[{1, yu^(-1), 1/(yu*yv), yu^(-1)}, yw])/64 + 
     (7*G[{yu}, yv^(-1)]*G[{1, yu^(-1), 1/(yu*yv), yu^(-1)}, yw])/64 + 
     (3*G[{1/(yu*yv)}, yw]*G[{1, yu^(-1), 1/(yu*yv), yu^(-1)}, yw])/32 - 
     (G[{1}, yu^(-1)]*G[{1, yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/16 + 
     (7*G[{1}, yv^(-1)]*G[{1, yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/64 + 
     (3*G[{1}, yw]*G[{1, yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/64 - 
     (3*G[{yu}, yv^(-1)]*G[{1, yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/64 - 
     (G[{1}, yu^(-1)]*G[{1, yu, yu, yu}, yv^(-1)])/8 + 
     (7*G[{1}, yv^(-1)]*G[{1, yu, yu, yu}, yv^(-1)])/32 + 
     (3*G[{1}, yw]*G[{1, yu, yu, yu}, yv^(-1)])/64 - 
     (3*G[{1/(yu*yv)}, yw]*G[{1, yu, yu, yu}, yv^(-1)])/64 + 
     (3*G[{0}, yu^(-1)]*G[{1, yv^(-1), 1, 1/(yu*yv)}, yw])/16 + 
     (3*G[{0}, yv^(-1)]*G[{1, yv^(-1), 1, 1/(yu*yv)}, yw])/16 - 
     (3*G[{0}, yw]*G[{1, yv^(-1), 1, 1/(yu*yv)}, yw])/16 - 
     (G[{1}, yu^(-1)]*G[{1, yv^(-1), 1, 1/(yu*yv)}, yw])/8 - 
     (G[{1}, yv^(-1)]*G[{1, yv^(-1), 1, 1/(yu*yv)}, yw])/8 + 
     (G[{1}, yw]*G[{1, yv^(-1), 1, 1/(yu*yv)}, yw])/8 - 
     (G[{yu}, yv^(-1)]*G[{1, yv^(-1), 1, 1/(yu*yv)}, yw])/8 + 
     (G[{1/(yu*yv)}, yw]*G[{1, yv^(-1), yu^(-1), yu^(-1)}, yw])/8 + 
     (G[{1/(yu*yv)}, yw]*G[{1, yv^(-1), yu^(-1), yv^(-1)}, yw])/8 - 
     (3*G[{0}, yu^(-1)]*G[{1, yv^(-1), yu^(-1), 1/(yu*yv)}, yw])/16 - 
     (3*G[{0}, yv^(-1)]*G[{1, yv^(-1), yu^(-1), 1/(yu*yv)}, yw])/16 + 
     (3*G[{0}, yw]*G[{1, yv^(-1), yu^(-1), 1/(yu*yv)}, yw])/16 + 
     (G[{1}, yu^(-1)]*G[{1, yv^(-1), yu^(-1), 1/(yu*yv)}, yw])/4 - 
     (G[{1}, yv^(-1)]*G[{1, yv^(-1), yu^(-1), 1/(yu*yv)}, yw])/8 - 
     (G[{1}, yw]*G[{1, yv^(-1), yu^(-1), 1/(yu*yv)}, yw])/4 + 
     (G[{yu}, yv^(-1)]*G[{1, yv^(-1), yu^(-1), 1/(yu*yv)}, yw])/4 + 
     (G[{1/(yu*yv)}, yw]*G[{1, yv^(-1), yv^(-1), yu^(-1)}, yw])/8 - 
     (G[{0}, yu^(-1)]*G[{1, yv^(-1), yv^(-1), yv^(-1)}, yw])/4 - 
     (G[{0}, yv^(-1)]*G[{1, yv^(-1), yv^(-1), yv^(-1)}, yw])/4 + 
     (G[{0}, yw]*G[{1, yv^(-1), yv^(-1), yv^(-1)}, yw])/4 + 
     (G[{1}, yu^(-1)]*G[{1, yv^(-1), yv^(-1), yv^(-1)}, yw])/8 - 
     (3*G[{1}, yw]*G[{1, yv^(-1), yv^(-1), yv^(-1)}, yw])/8 + 
     (3*G[{yu}, yv^(-1)]*G[{1, yv^(-1), yv^(-1), yv^(-1)}, yw])/8 - 
     (G[{0}, yu^(-1)]*G[{1, yv^(-1), yv^(-1), 1/(yu*yv)}, yw])/8 - 
     (G[{0}, yv^(-1)]*G[{1, yv^(-1), yv^(-1), 1/(yu*yv)}, yw])/8 + 
     (G[{0}, yw]*G[{1, yv^(-1), yv^(-1), 1/(yu*yv)}, yw])/8 + 
     (3*G[{1}, yu^(-1)]*G[{1, yv^(-1), yv^(-1), 1/(yu*yv)}, yw])/16 - 
     (G[{1}, yv^(-1)]*G[{1, yv^(-1), yv^(-1), 1/(yu*yv)}, yw])/4 - 
     (5*G[{1}, yw]*G[{1, yv^(-1), yv^(-1), 1/(yu*yv)}, yw])/16 + 
     (5*G[{yu}, yv^(-1)]*G[{1, yv^(-1), yv^(-1), 1/(yu*yv)}, yw])/16 - 
     (G[{0}, yu^(-1)]*G[{1, yv^(-1), 1/(yu*yv), yv^(-1)}, yw])/8 - 
     (G[{0}, yv^(-1)]*G[{1, yv^(-1), 1/(yu*yv), yv^(-1)}, yw])/8 + 
     (G[{0}, yw]*G[{1, yv^(-1), 1/(yu*yv), yv^(-1)}, yw])/8 + 
     (3*G[{1}, yu^(-1)]*G[{1, yv^(-1), 1/(yu*yv), yv^(-1)}, yw])/16 - 
     (G[{1}, yw]*G[{1, yv^(-1), 1/(yu*yv), yv^(-1)}, yw])/16 + 
     (G[{yu}, yv^(-1)]*G[{1, yv^(-1), 1/(yu*yv), yv^(-1)}, yw])/16 + 
     (3*G[{0}, yu^(-1)]*G[{1, yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/16 + 
     (3*G[{0}, yv^(-1)]*G[{1, yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/16 - 
     (3*G[{0}, yw]*G[{1, yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/16 - 
     (G[{1}, yu^(-1)]*G[{1, yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/8 - 
     (G[{1}, yv^(-1)]*G[{1, yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/16 + 
     (3*G[{1}, yw]*G[{1, yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/16 - 
     (3*G[{yu}, yv^(-1)]*G[{1, yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/16 - 
     (G[{0}, yu^(-1)]*G[{1, 1/(yu*yv), yu^(-1), yu^(-1)}, yw])/4 - 
     (G[{0}, yv^(-1)]*G[{1, 1/(yu*yv), yu^(-1), yu^(-1)}, yw])/4 + 
     (G[{0}, yw]*G[{1, 1/(yu*yv), yu^(-1), yu^(-1)}, yw])/4 + 
     (9*G[{1}, yv^(-1)]*G[{1, 1/(yu*yv), yu^(-1), yu^(-1)}, yw])/32 - 
     (7*G[{1}, yw]*G[{1, 1/(yu*yv), yu^(-1), yu^(-1)}, yw])/32 + 
     (7*G[{yu}, yv^(-1)]*G[{1, 1/(yu*yv), yu^(-1), yu^(-1)}, yw])/32 + 
     (11*G[{1/(yu*yv)}, yw]*G[{1, 1/(yu*yv), yu^(-1), yu^(-1)}, yw])/64 + 
     (3*G[{0}, yu^(-1)]*G[{1, 1/(yu*yv), yu^(-1), 1/(yu*yv)}, yw])/16 + 
     (3*G[{0}, yv^(-1)]*G[{1, 1/(yu*yv), yu^(-1), 1/(yu*yv)}, yw])/16 - 
     (3*G[{0}, yw]*G[{1, 1/(yu*yv), yu^(-1), 1/(yu*yv)}, yw])/16 - 
     (G[{1}, yu^(-1)]*G[{1, 1/(yu*yv), yu^(-1), 1/(yu*yv)}, yw])/8 - 
     (G[{1}, yv^(-1)]*G[{1, 1/(yu*yv), yu^(-1), 1/(yu*yv)}, yw])/64 + 
     (15*G[{1}, yw]*G[{1, 1/(yu*yv), yu^(-1), 1/(yu*yv)}, yw])/64 - 
     (15*G[{yu}, yv^(-1)]*G[{1, 1/(yu*yv), yu^(-1), 1/(yu*yv)}, yw])/64 - 
     (3*G[{1/(yu*yv)}, yw]*G[{1, 1/(yu*yv), yu^(-1), 1/(yu*yv)}, yw])/32 - 
     (G[{0}, yu^(-1)]*G[{1, 1/(yu*yv), yv^(-1), yv^(-1)}, yw])/4 - 
     (G[{0}, yv^(-1)]*G[{1, 1/(yu*yv), yv^(-1), yv^(-1)}, yw])/4 + 
     (G[{0}, yw]*G[{1, 1/(yu*yv), yv^(-1), yv^(-1)}, yw])/4 + 
     (3*G[{1}, yu^(-1)]*G[{1, 1/(yu*yv), yv^(-1), yv^(-1)}, yw])/8 - 
     (G[{1}, yw]*G[{1, 1/(yu*yv), yv^(-1), yv^(-1)}, yw])/8 + 
     (G[{yu}, yv^(-1)]*G[{1, 1/(yu*yv), yv^(-1), yv^(-1)}, yw])/8 + 
     (G[{1/(yu*yv)}, yw]*G[{1, 1/(yu*yv), yv^(-1), yv^(-1)}, yw])/8 + 
     (3*G[{0}, yu^(-1)]*G[{1, 1/(yu*yv), yv^(-1), 1/(yu*yv)}, yw])/16 + 
     (3*G[{0}, yv^(-1)]*G[{1, 1/(yu*yv), yv^(-1), 1/(yu*yv)}, yw])/16 - 
     (3*G[{0}, yw]*G[{1, 1/(yu*yv), yv^(-1), 1/(yu*yv)}, yw])/16 - 
     (G[{1}, yu^(-1)]*G[{1, 1/(yu*yv), yv^(-1), 1/(yu*yv)}, yw])/16 - 
     (G[{1}, yv^(-1)]*G[{1, 1/(yu*yv), yv^(-1), 1/(yu*yv)}, yw])/8 + 
     (3*G[{1}, yw]*G[{1, 1/(yu*yv), yv^(-1), 1/(yu*yv)}, yw])/16 - 
     (3*G[{yu}, yv^(-1)]*G[{1, 1/(yu*yv), yv^(-1), 1/(yu*yv)}, yw])/16 + 
     (G[{0}, yu^(-1)]*G[{1, 1/(yu*yv), 1/(yu*yv), yu^(-1)}, yw])/8 + 
     (G[{0}, yv^(-1)]*G[{1, 1/(yu*yv), 1/(yu*yv), yu^(-1)}, yw])/8 - 
     (G[{0}, yw]*G[{1, 1/(yu*yv), 1/(yu*yv), yu^(-1)}, yw])/8 + 
     (7*G[{1}, yv^(-1)]*G[{1, 1/(yu*yv), 1/(yu*yv), yu^(-1)}, yw])/64 + 
     (23*G[{1}, yw]*G[{1, 1/(yu*yv), 1/(yu*yv), yu^(-1)}, yw])/64 - 
     (23*G[{yu}, yv^(-1)]*G[{1, 1/(yu*yv), 1/(yu*yv), yu^(-1)}, yw])/64 - 
     (3*G[{1/(yu*yv)}, yw]*G[{1, 1/(yu*yv), 1/(yu*yv), yu^(-1)}, yw])/32 + 
     (G[{0}, yu^(-1)]*G[{1, 1/(yu*yv), 1/(yu*yv), yv^(-1)}, yw])/8 + 
     (G[{0}, yv^(-1)]*G[{1, 1/(yu*yv), 1/(yu*yv), yv^(-1)}, yw])/8 - 
     (G[{0}, yw]*G[{1, 1/(yu*yv), 1/(yu*yv), yv^(-1)}, yw])/8 + 
     (G[{1}, yu^(-1)]*G[{1, 1/(yu*yv), 1/(yu*yv), yv^(-1)}, yw])/16 + 
     (5*G[{1}, yw]*G[{1, 1/(yu*yv), 1/(yu*yv), yv^(-1)}, yw])/16 - 
     (5*G[{yu}, yv^(-1)]*G[{1, 1/(yu*yv), 1/(yu*yv), yv^(-1)}, yw])/16 - 
     (G[{0}, yu^(-1)]*G[{1, 1/(yu*yv), 1/(yu*yv), 1/(yu*yv)}, yw])/16 - 
     (G[{0}, yv^(-1)]*G[{1, 1/(yu*yv), 1/(yu*yv), 1/(yu*yv)}, yw])/16 + 
     (G[{0}, yw]*G[{1, 1/(yu*yv), 1/(yu*yv), 1/(yu*yv)}, yw])/16 - 
     (3*G[{1}, yu^(-1)]*G[{1, 1/(yu*yv), 1/(yu*yv), 1/(yu*yv)}, yw])/16 - 
     (3*G[{1}, yv^(-1)]*G[{1, 1/(yu*yv), 1/(yu*yv), 1/(yu*yv)}, yw])/64 - 
     (23*G[{1}, yw]*G[{1, 1/(yu*yv), 1/(yu*yv), 1/(yu*yv)}, yw])/64 + 
     (23*G[{yu}, yv^(-1)]*G[{1, 1/(yu*yv), 1/(yu*yv), 1/(yu*yv)}, yw])/64 + 
     (G[{0}, yu^(-1)]*G[{yu^(-1), yu^(-1), yu^(-1), 1/(yu*yv)}, yw])/2 + 
     (G[{0}, yv^(-1)]*G[{yu^(-1), yu^(-1), yu^(-1), 1/(yu*yv)}, yw])/2 - 
     (G[{0}, yw]*G[{yu^(-1), yu^(-1), yu^(-1), 1/(yu*yv)}, yw])/2 - 
     (41*G[{1}, yv^(-1)]*G[{yu^(-1), yu^(-1), yu^(-1), 1/(yu*yv)}, yw])/32 - 
     (9*G[{1}, yw]*G[{yu^(-1), yu^(-1), yu^(-1), 1/(yu*yv)}, yw])/32 + 
     (41*G[{yu^(-1)}, yw]*G[{yu^(-1), yu^(-1), yu^(-1), 1/(yu*yv)}, yw])/32 + 
     (9*G[{yu}, yv^(-1)]*G[{yu^(-1), yu^(-1), yu^(-1), 1/(yu*yv)}, yw])/32 - 
     (3*G[{1/(yu*yv)}, yw]*G[{yu^(-1), yu^(-1), yu^(-1), 1/(yu*yv)}, yw])/
      64 + (G[{1/(yu*yv)}, yw]*G[{yu^(-1), yu^(-1), 1/(yu*yv), yv^(-1)}, yw])/
      8 + (G[{0}, yu^(-1)]*G[{yu^(-1), yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/
      4 + (G[{0}, yv^(-1)]*G[{yu^(-1), yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/
      4 - (G[{0}, yw]*G[{yu^(-1), yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/4 - 
     (41*G[{1}, yv^(-1)]*G[{yu^(-1), yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/
      64 - (9*G[{1}, yw]*G[{yu^(-1), yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/
      64 + (41*G[{yu^(-1)}, yw]*G[{yu^(-1), yu^(-1), 1/(yu*yv), 1/(yu*yv)}, 
        yw])/64 + (9*G[{yu}, yv^(-1)]*G[{yu^(-1), yu^(-1), 1/(yu*yv), 
         1/(yu*yv)}, yw])/64 - (3*G[{1/(yu*yv)}, yw]*
       G[{yu^(-1), yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/32 - 
     (G[{1/(yu*yv)}, yw]*G[{yu^(-1), 1/(yu*yv), yv^(-1), yv^(-1)}, yw])/8 + 
     (3*G[{0}, yu^(-1)]*G[{yu^(-1), 1/(yu*yv), yv^(-1), 1/(yu*yv)}, yw])/16 + 
     (3*G[{0}, yv^(-1)]*G[{yu^(-1), 1/(yu*yv), yv^(-1), 1/(yu*yv)}, yw])/16 - 
     (3*G[{0}, yw]*G[{yu^(-1), 1/(yu*yv), yv^(-1), 1/(yu*yv)}, yw])/16 - 
     (G[{1}, yu^(-1)]*G[{yu^(-1), 1/(yu*yv), yv^(-1), 1/(yu*yv)}, yw])/4 + 
     (G[{1}, yv^(-1)]*G[{yu^(-1), 1/(yu*yv), yv^(-1), 1/(yu*yv)}, yw])/8 + 
     (G[{1}, yw]*G[{yu^(-1), 1/(yu*yv), yv^(-1), 1/(yu*yv)}, yw])/4 - 
     (G[{yu^(-1)}, yw]*G[{yu^(-1), 1/(yu*yv), yv^(-1), 1/(yu*yv)}, yw])/8 - 
     (G[{yu}, yv^(-1)]*G[{yu^(-1), 1/(yu*yv), yv^(-1), 1/(yu*yv)}, yw])/4 + 
     (3*G[{0}, yu^(-1)]*G[{yu^(-1), 1/(yu*yv), 1/(yu*yv), yv^(-1)}, yw])/8 + 
     (3*G[{0}, yv^(-1)]*G[{yu^(-1), 1/(yu*yv), 1/(yu*yv), yv^(-1)}, yw])/8 - 
     (3*G[{0}, yw]*G[{yu^(-1), 1/(yu*yv), 1/(yu*yv), yv^(-1)}, yw])/8 - 
     (G[{1}, yu^(-1)]*G[{yu^(-1), 1/(yu*yv), 1/(yu*yv), yv^(-1)}, yw])/2 + 
     (G[{1}, yw]*G[{yu^(-1), 1/(yu*yv), 1/(yu*yv), yv^(-1)}, yw])/4 - 
     (G[{yu}, yv^(-1)]*G[{yu^(-1), 1/(yu*yv), 1/(yu*yv), yv^(-1)}, yw])/4 - 
     (G[{0}, yu^(-1)]*G[{yu^(-1), 1/(yu*yv), 1/(yu*yv), 1/(yu*yv)}, yw])/4 - 
     (G[{0}, yv^(-1)]*G[{yu^(-1), 1/(yu*yv), 1/(yu*yv), 1/(yu*yv)}, yw])/4 + 
     (G[{0}, yw]*G[{yu^(-1), 1/(yu*yv), 1/(yu*yv), 1/(yu*yv)}, yw])/4 + 
     (3*G[{1}, yu^(-1)]*G[{yu^(-1), 1/(yu*yv), 1/(yu*yv), 1/(yu*yv)}, yw])/
      16 + (23*G[{1}, yv^(-1)]*G[{yu^(-1), 1/(yu*yv), 1/(yu*yv), 1/(yu*yv)}, 
        yw])/64 + (3*G[{1}, yw]*G[{yu^(-1), 1/(yu*yv), 1/(yu*yv), 1/(yu*yv)}, 
        yw])/64 - (23*G[{yu^(-1)}, yw]*G[{yu^(-1), 1/(yu*yv), 1/(yu*yv), 
         1/(yu*yv)}, yw])/64 - (3*G[{yu}, yv^(-1)]*
       G[{yu^(-1), 1/(yu*yv), 1/(yu*yv), 1/(yu*yv)}, yw])/64 - 
     (G[{0}, yu^(-1)]*G[{yv^(-1), yv^(-1), yv^(-1), 1/(yu*yv)}, yw])/4 - 
     (G[{0}, yv^(-1)]*G[{yv^(-1), yv^(-1), yv^(-1), 1/(yu*yv)}, yw])/4 + 
     (G[{0}, yw]*G[{yv^(-1), yv^(-1), yv^(-1), 1/(yu*yv)}, yw])/4 + 
     (G[{1}, yu^(-1)]*G[{yv^(-1), yv^(-1), yv^(-1), 1/(yu*yv)}, yw])/8 - 
     (3*G[{1}, yw]*G[{yv^(-1), yv^(-1), yv^(-1), 1/(yu*yv)}, yw])/8 + 
     (3*G[{yu}, yv^(-1)]*G[{yv^(-1), yv^(-1), yv^(-1), 1/(yu*yv)}, yw])/8 - 
     (G[{yv^(-1)}, yw]*G[{yv^(-1), yv^(-1), yv^(-1), 1/(yu*yv)}, yw])/8 - 
     (G[{0}, yu^(-1)]*G[{yv^(-1), yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/8 - 
     (G[{0}, yv^(-1)]*G[{yv^(-1), yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/8 + 
     (G[{0}, yw]*G[{yv^(-1), yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/8 + 
     (G[{1}, yu^(-1)]*G[{yv^(-1), yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/16 - 
     (3*G[{1}, yw]*G[{yv^(-1), yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/16 + 
     (3*G[{yu}, yv^(-1)]*G[{yv^(-1), yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/
      16 - (G[{yv^(-1)}, yw]*G[{yv^(-1), yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/
      16 - (G[{0}, yu^(-1)]*G[{yv^(-1), 1/(yu*yv), 1/(yu*yv), 1/(yu*yv)}, 
        yw])/16 - (G[{0}, yv^(-1)]*G[{yv^(-1), 1/(yu*yv), 1/(yu*yv), 
         1/(yu*yv)}, yw])/16 + 
     (G[{0}, yw]*G[{yv^(-1), 1/(yu*yv), 1/(yu*yv), 1/(yu*yv)}, yw])/16 + 
     (G[{1}, yu^(-1)]*G[{yv^(-1), 1/(yu*yv), 1/(yu*yv), 1/(yu*yv)}, yw])/8 + 
     (3*G[{1}, yv^(-1)]*G[{yv^(-1), 1/(yu*yv), 1/(yu*yv), 1/(yu*yv)}, yw])/
      16 + (3*G[{1}, yw]*G[{yv^(-1), 1/(yu*yv), 1/(yu*yv), 1/(yu*yv)}, yw])/
      16 - (3*G[{yu^(-1)}, yw]*G[{yv^(-1), 1/(yu*yv), 1/(yu*yv), 1/(yu*yv)}, 
        yw])/16 - (3*G[{yu}, yv^(-1)]*G[{yv^(-1), 1/(yu*yv), 1/(yu*yv), 
         1/(yu*yv)}, yw])/16 - (G[{yv^(-1)}, yw]*
       G[{yv^(-1), 1/(yu*yv), 1/(yu*yv), 1/(yu*yv)}, yw])/8 + 
     (3*G[{0, 0, 0, 1, 1}, yu^(-1)])/8 - (3*G[{0, 0, 0, 1, 1}, yv^(-1)])/16 + 
     (3*G[{0, 0, 0, 1, 1}, yw])/8 - (3*G[{0, 0, 0, 1, yu^(-1)}, yw])/16 - 
     (3*G[{0, 0, 0, 1, yv^(-1)}, yw])/16 - (3*G[{0, 0, 0, yu^(-1), 1}, yw])/
      16 + (3*G[{0, 0, 0, yu^(-1), 1/(yu*yv)}, yw])/16 + 
     (3*G[{0, 0, 0, yu, yu}, yv^(-1)])/16 - (3*G[{0, 0, 0, yv^(-1), 1}, yw])/
      16 + (3*G[{0, 0, 0, yv^(-1), 1/(yu*yv)}, yw])/16 + 
     (3*G[{0, 0, 0, 1/(yu*yv), yu^(-1)}, yw])/16 + 
     (3*G[{0, 0, 0, 1/(yu*yv), yv^(-1)}, yw])/16 - 
     (3*G[{0, 0, 0, 1/(yu*yv), 1/(yu*yv)}, yw])/8 + 
     G[{0, 0, 1, 0, 1}, yu^(-1)]/8 - G[{0, 0, 1, 0, 1}, yv^(-1)]/64 + 
     G[{0, 0, 1, 0, 1}, yw]/8 - G[{0, 0, 1, 0, yu^(-1)}, yw]/16 - 
     (3*G[{0, 0, 1, 0, yu}, yv^(-1)])/64 - G[{0, 0, 1, 0, yv^(-1)}, yw]/16 + 
     (3*G[{0, 0, 1, 1, 1}, yu^(-1)])/16 + (3*G[{0, 0, 1, 1, 1}, yv^(-1)])/
      16 + G[{0, 0, 1, 1, 1}, yw]/8 - (3*G[{0, 0, 1, 1, yu^(-1)}, yw])/16 + 
     (5*G[{0, 0, 1, 1, yu}, yv^(-1)])/32 - (3*G[{0, 0, 1, 1, yv^(-1)}, yw])/
      16 + G[{0, 0, 1, 1, 1/(yu*yv)}, yw]/4 - G[{0, 0, 1, yu^(-1), 1}, yw]/
      8 + (3*G[{0, 0, 1, yu^(-1), yu^(-1)}, yw])/8 + 
     G[{0, 0, 1, yu^(-1), yv^(-1)}, yw]/8 - 
     (3*G[{0, 0, 1, yu^(-1), 1/(yu*yv)}, yw])/8 + 
     (9*G[{0, 0, 1, yu, 1}, yv^(-1)])/64 + G[{0, 0, 1, yu, yu}, yv^(-1)]/64 - 
     G[{0, 0, 1, yv^(-1), 1}, yw]/8 + G[{0, 0, 1, yv^(-1), yu^(-1)}, yw]/8 - 
     (3*G[{0, 0, 1, yv^(-1), yv^(-1)}, yw])/8 + 
     G[{0, 0, 1, 1/(yu*yv), 1}, yw]/4 - 
     (5*G[{0, 0, 1, 1/(yu*yv), yu^(-1)}, yw])/16 + 
     G[{0, 0, 1, 1/(yu*yv), yv^(-1)}, yw]/16 + 
     G[{0, 0, 1, 1/(yu*yv), 1/(yu*yv)}, yw]/8 - G[{0, 0, yu^(-1), 0, 1}, yw]/
      16 + G[{0, 0, yu^(-1), 0, 1/(yu*yv)}, yw]/16 - 
     G[{0, 0, yu^(-1), 1, 1}, yw]/4 + (5*G[{0, 0, yu^(-1), 1, yu^(-1)}, yw])/
      16 - (3*G[{0, 0, yu^(-1), 1, yv^(-1)}, yw])/16 + 
     G[{0, 0, yu^(-1), yu^(-1), 1}, yw]/8 + 
     G[{0, 0, yu^(-1), yu^(-1), 1/(yu*yv)}, yw]/8 - 
     G[{0, 0, yu^(-1), yv^(-1), 1}, yw]/8 + 
     G[{0, 0, yu^(-1), yv^(-1), 1/(yu*yv)}, yw]/8 + 
     G[{0, 0, yu^(-1), 1/(yu*yv), yu^(-1)}, yw]/16 + 
     G[{0, 0, yu^(-1), 1/(yu*yv), yv^(-1)}, yw]/16 - 
     G[{0, 0, yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw]/4 - 
     (3*G[{0, 0, yu, 0, 1}, yv^(-1)])/64 + (7*G[{0, 0, yu, 0, yu}, yv^(-1)])/
      64 + (7*G[{0, 0, yu, 1, 1}, yv^(-1)])/32 - 
     G[{0, 0, yu, 1, yu}, yv^(-1)]/4 - (23*G[{0, 0, yu, yu, 1}, yv^(-1)])/
      64 + (47*G[{0, 0, yu, yu, yu}, yv^(-1)])/64 - 
     G[{0, 0, yv^(-1), 0, 1}, yw]/16 + G[{0, 0, yv^(-1), 0, 1/(yu*yv)}, yw]/
      16 - G[{0, 0, yv^(-1), 1, 1}, yw]/4 + 
     (3*G[{0, 0, yv^(-1), 1, yu^(-1)}, yw])/16 - 
     G[{0, 0, yv^(-1), 1, yv^(-1)}, yw]/16 - 
     G[{0, 0, yv^(-1), yu^(-1), 1}, yw]/8 + 
     G[{0, 0, yv^(-1), yu^(-1), 1/(yu*yv)}, yw]/8 + 
     G[{0, 0, yv^(-1), yv^(-1), 1}, yw]/8 + 
     G[{0, 0, yv^(-1), yv^(-1), 1/(yu*yv)}, yw]/8 + 
     G[{0, 0, yv^(-1), 1/(yu*yv), yu^(-1)}, yw]/16 + 
     G[{0, 0, yv^(-1), 1/(yu*yv), yv^(-1)}, yw]/16 - 
     G[{0, 0, yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw]/4 + 
     G[{0, 0, 1/(yu*yv), 0, yu^(-1)}, yw]/16 + 
     G[{0, 0, 1/(yu*yv), 0, yv^(-1)}, yw]/16 - 
     G[{0, 0, 1/(yu*yv), 0, 1/(yu*yv)}, yw]/8 + 
     (3*G[{0, 0, 1/(yu*yv), 1, 1}, yw])/8 - 
     (5*G[{0, 0, 1/(yu*yv), 1, yu^(-1)}, yw])/16 + 
     G[{0, 0, 1/(yu*yv), 1, yv^(-1)}, yw]/16 - 
     G[{0, 0, 1/(yu*yv), 1, 1/(yu*yv)}, yw]/8 + 
     G[{0, 0, 1/(yu*yv), yu^(-1), yu^(-1)}, yw]/8 + 
     G[{0, 0, 1/(yu*yv), yv^(-1), yv^(-1)}, yw]/8 - 
     G[{0, 0, 1/(yu*yv), 1/(yu*yv), 1}, yw]/4 + 
     (5*G[{0, 0, 1/(yu*yv), 1/(yu*yv), yu^(-1)}, yw])/16 + 
     (5*G[{0, 0, 1/(yu*yv), 1/(yu*yv), yv^(-1)}, yw])/16 - 
     (3*G[{0, 0, 1/(yu*yv), 1/(yu*yv), 1/(yu*yv)}, yw])/8 + 
     (9*G[{0, 1, 0, 1, 1}, yv^(-1)])/64 + (5*G[{0, 1, 0, 1, yu}, yv^(-1)])/
      64 - (3*G[{0, 1, 0, 1, yv^(-1)}, yw])/16 + 
     G[{0, 1, 0, 1, 1/(yu*yv)}, yw]/16 - G[{0, 1, 0, yu^(-1), 1}, yw]/8 + 
     G[{0, 1, 0, yu^(-1), yu^(-1)}, yw]/4 + 
     G[{0, 1, 0, yu^(-1), yv^(-1)}, yw]/16 - 
     G[{0, 1, 0, yu^(-1), 1/(yu*yv)}, yw]/8 + G[{0, 1, 0, yu, 1}, yv^(-1)]/
      16 - G[{0, 1, 0, yu, yu}, yv^(-1)]/16 - G[{0, 1, 0, yv^(-1), 1}, yw]/
      8 + G[{0, 1, 0, yv^(-1), yu^(-1)}, yw]/16 - 
     G[{0, 1, 0, yv^(-1), yv^(-1)}, yw]/8 + 
     G[{0, 1, 0, yv^(-1), 1/(yu*yv)}, yw]/16 + G[{0, 1, 0, 1/(yu*yv), 1}, yw]/
      4 - (5*G[{0, 1, 0, 1/(yu*yv), yu^(-1)}, yw])/16 + 
     G[{0, 1, 0, 1/(yu*yv), yv^(-1)}, yw]/16 + 
     G[{0, 1, 0, 1/(yu*yv), 1/(yu*yv)}, yw]/16 + 
     (5*G[{0, 1, 1, 0, yu}, yv^(-1)])/64 + G[{0, 1, 1, 1, 1}, yu^(-1)]/4 - 
     G[{0, 1, 1, 1, 1}, yv^(-1)]/8 + (3*G[{0, 1, 1, 1, 1}, yw])/16 - 
     G[{0, 1, 1, 1, yu^(-1)}, yw]/8 - (15*G[{0, 1, 1, 1, yu}, yv^(-1)])/64 + 
     G[{0, 1, 1, 1, yv^(-1)}, yw]/16 + G[{0, 1, 1, 1, 1/(yu*yv)}, yw]/8 + 
     G[{0, 1, 1, yu^(-1), 1}, yw]/8 - G[{0, 1, 1, yu^(-1), yu^(-1)}, yw]/2 - 
     (7*G[{0, 1, 1, yu, 1}, yv^(-1)])/32 + (23*G[{0, 1, 1, yu, yu}, yv^(-1)])/
      64 + G[{0, 1, 1, yv^(-1), 1}, yw]/8 + 
     G[{0, 1, 1, yv^(-1), yv^(-1)}, yw]/4 - G[{0, 1, 1, 1/(yu*yv), 1}, yw]/
      16 + G[{0, 1, 1, 1/(yu*yv), yu^(-1)}, yw]/4 + 
     G[{0, 1, 1, 1/(yu*yv), yv^(-1)}, yw]/16 + 
     G[{0, 1, yu^(-1), 0, yu^(-1)}, yw]/16 + 
     G[{0, 1, yu^(-1), 0, yv^(-1)}, yw]/16 - 
     G[{0, 1, yu^(-1), 0, 1/(yu*yv)}, yw]/8 + 
     (3*G[{0, 1, yu^(-1), 1, 1}, yw])/16 - 
     (3*G[{0, 1, yu^(-1), 1, yu^(-1)}, yw])/8 + 
     (3*G[{0, 1, yu^(-1), 1, yv^(-1)}, yw])/16 - 
     G[{0, 1, yu^(-1), yu^(-1), 1}, yw]/8 + 
     G[{0, 1, yu^(-1), yu^(-1), yu^(-1)}, yw]/2 - 
     G[{0, 1, yu^(-1), yu^(-1), 1/(yu*yv)}, yw]/8 + 
     G[{0, 1, yu^(-1), yv^(-1), 1}, yw]/8 - 
     G[{0, 1, yu^(-1), yv^(-1), 1/(yu*yv)}, yw]/8 - 
     (3*G[{0, 1, yu^(-1), 1/(yu*yv), 1}, yw])/16 - 
     (5*G[{0, 1, yu^(-1), 1/(yu*yv), yv^(-1)}, yw])/16 + 
     G[{0, 1, yu, 0, yu}, yv^(-1)]/16 - (5*G[{0, 1, yu, 1, 1}, yv^(-1)])/32 + 
     (23*G[{0, 1, yu, 1, yu}, yv^(-1)])/64 + 
     (27*G[{0, 1, yu, yu, 1}, yv^(-1)])/64 - 
     (7*G[{0, 1, yu, yu, yu}, yv^(-1)])/32 - 
     G[{0, 1, yv^(-1), 0, yu^(-1)}, yw]/16 - 
     G[{0, 1, yv^(-1), 0, yv^(-1)}, yw]/8 + 
     G[{0, 1, yv^(-1), 0, 1/(yu*yv)}, yw]/16 + 
     (3*G[{0, 1, yv^(-1), 1, 1}, yw])/16 + 
     (3*G[{0, 1, yv^(-1), 1, yv^(-1)}, yw])/16 + 
     G[{0, 1, yv^(-1), yu^(-1), 1}, yw]/8 - 
     G[{0, 1, yv^(-1), yu^(-1), 1/(yu*yv)}, yw]/8 - 
     G[{0, 1, yv^(-1), yv^(-1), 1}, yw]/8 - 
     G[{0, 1, yv^(-1), yv^(-1), yv^(-1)}, yw]/4 - 
     G[{0, 1, yv^(-1), yv^(-1), 1/(yu*yv)}, yw]/8 - 
     (3*G[{0, 1, yv^(-1), 1/(yu*yv), 1}, yw])/16 + 
     G[{0, 1, yv^(-1), 1/(yu*yv), yu^(-1)}, yw]/4 - 
     (3*G[{0, 1, yv^(-1), 1/(yu*yv), yv^(-1)}, yw])/16 + 
     G[{0, 1, 1/(yu*yv), 0, 1/(yu*yv)}, yw]/16 - 
     (3*G[{0, 1, 1/(yu*yv), 1, 1}, yw])/16 + 
     G[{0, 1, 1/(yu*yv), 1, yu^(-1)}, yw]/8 - 
     G[{0, 1, 1/(yu*yv), 1, yv^(-1)}, yw]/16 + 
     G[{0, 1, 1/(yu*yv), yu^(-1), 1}, yw]/8 - 
     G[{0, 1, 1/(yu*yv), yu^(-1), yu^(-1)}, yw]/8 + 
     G[{0, 1, 1/(yu*yv), yv^(-1), 1}, yw]/8 - 
     G[{0, 1, 1/(yu*yv), yv^(-1), yv^(-1)}, yw]/8 - 
     G[{0, 1, 1/(yu*yv), 1/(yu*yv), 1}, yw]/16 + 
     (3*G[{0, 1, 1/(yu*yv), 1/(yu*yv), yv^(-1)}, yw])/16 + 
     G[{0, yu^(-1), 0, yu^(-1), 1}, yw]/16 + 
     G[{0, yu^(-1), 0, yu^(-1), 1/(yu*yv)}, yw]/16 - 
     G[{0, yu^(-1), 0, 1/(yu*yv), 1}, yw]/8 + 
     (3*G[{0, yu^(-1), 0, 1/(yu*yv), yu^(-1)}, yw])/16 - 
     G[{0, yu^(-1), 0, 1/(yu*yv), yv^(-1)}, yw]/16 - 
     G[{0, yu^(-1), 0, 1/(yu*yv), 1/(yu*yv)}, yw]/8 - 
     G[{0, yu^(-1), 1, 0, yv^(-1)}, yw]/16 - 
     G[{0, yu^(-1), 1, yu^(-1), 1}, yw]/8 + 
     G[{0, yu^(-1), 1, yu^(-1), yu^(-1)}, yw]/4 - 
     G[{0, yu^(-1), 1, yv^(-1), 1}, yw]/8 - 
     G[{0, yu^(-1), 1, yv^(-1), yv^(-1)}, yw]/4 + 
     G[{0, yu^(-1), yu^(-1), 0, 1/(yu*yv)}, yw]/8 - 
     G[{0, yu^(-1), yu^(-1), 1, 1}, yw]/4 + 
     G[{0, yu^(-1), yu^(-1), 1, yu^(-1)}, yw]/4 - 
     G[{0, yu^(-1), yu^(-1), 1, yv^(-1)}, yw]/4 - 
     G[{0, yu^(-1), yu^(-1), yv^(-1), 1}, yw]/8 + 
     G[{0, yu^(-1), yu^(-1), yv^(-1), 1/(yu*yv)}, yw]/8 + 
     G[{0, yu^(-1), yu^(-1), 1/(yu*yv), 1}, yw]/4 - 
     G[{0, yu^(-1), yu^(-1), 1/(yu*yv), yu^(-1)}, yw]/4 + 
     G[{0, yu^(-1), yu^(-1), 1/(yu*yv), yv^(-1)}, yw]/4 + 
     G[{0, yu^(-1), yv^(-1), 0, 1/(yu*yv)}, yw]/16 - 
     G[{0, yu^(-1), yv^(-1), 1, 1}, yw]/4 + 
     G[{0, yu^(-1), yv^(-1), 1, yu^(-1)}, yw]/8 - 
     G[{0, yu^(-1), yv^(-1), 1, yv^(-1)}, yw]/4 - 
     G[{0, yu^(-1), yv^(-1), yu^(-1), 1}, yw]/8 + 
     G[{0, yu^(-1), yv^(-1), yu^(-1), 1/(yu*yv)}, yw]/8 - 
     G[{0, yu^(-1), yv^(-1), yv^(-1), 1}, yw]/8 + 
     G[{0, yu^(-1), yv^(-1), yv^(-1), 1/(yu*yv)}, yw]/8 + 
     G[{0, yu^(-1), yv^(-1), 1/(yu*yv), 1}, yw]/4 - 
     G[{0, yu^(-1), yv^(-1), 1/(yu*yv), yu^(-1)}, yw]/8 + 
     G[{0, yu^(-1), yv^(-1), 1/(yu*yv), yv^(-1)}, yw]/4 - 
     G[{0, yu^(-1), 1/(yu*yv), 0, 1/(yu*yv)}, yw]/8 + 
     G[{0, yu^(-1), 1/(yu*yv), 1, yu^(-1)}, yw]/8 + 
     G[{0, yu^(-1), 1/(yu*yv), 1, yv^(-1)}, yw]/8 + 
     G[{0, yu^(-1), 1/(yu*yv), yu^(-1), 1}, yw]/8 - 
     G[{0, yu^(-1), 1/(yu*yv), yu^(-1), yu^(-1)}, yw]/4 + 
     G[{0, yu^(-1), 1/(yu*yv), yv^(-1), 1}, yw]/8 + 
     G[{0, yu^(-1), 1/(yu*yv), yv^(-1), yv^(-1)}, yw]/4 - 
     G[{0, yu^(-1), 1/(yu*yv), 1/(yu*yv), yu^(-1)}, yw]/8 - 
     G[{0, yu^(-1), 1/(yu*yv), 1/(yu*yv), yv^(-1)}, yw]/8 - 
     (7*G[{0, yu, 0, yu, 1}, yv^(-1)])/64 + 
     (5*G[{0, yu, 0, yu, yu}, yv^(-1)])/16 + G[{0, yu, 1, 1, 1}, yv^(-1)]/8 + 
     (15*G[{0, yu, 1, 1, yu}, yv^(-1)])/64 + 
     (7*G[{0, yu, 1, yu, 1}, yv^(-1)])/32 - 
     (23*G[{0, yu, 1, yu, yu}, yv^(-1)])/64 + 
     (5*G[{0, yu, yu, 1, 1}, yv^(-1)])/32 - 
     (23*G[{0, yu, yu, 1, yu}, yv^(-1)])/64 - 
     (27*G[{0, yu, yu, yu, 1}, yv^(-1)])/64 + 
     (7*G[{0, yu, yu, yu, yu}, yv^(-1)])/32 + 
     G[{0, yv^(-1), 0, yv^(-1), 1}, yw]/16 + 
     G[{0, yv^(-1), 0, yv^(-1), 1/(yu*yv)}, yw]/16 - 
     G[{0, yv^(-1), 0, 1/(yu*yv), 1}, yw]/8 + 
     G[{0, yv^(-1), 0, 1/(yu*yv), yu^(-1)}, yw]/8 - 
     G[{0, yv^(-1), 0, 1/(yu*yv), 1/(yu*yv)}, yw]/8 - 
     G[{0, yv^(-1), 1, yu^(-1), 1}, yw]/8 + 
     G[{0, yv^(-1), 1, yu^(-1), yu^(-1)}, yw]/8 - 
     G[{0, yv^(-1), 1, yv^(-1), 1}, yw]/8 - 
     G[{0, yv^(-1), 1, yv^(-1), yv^(-1)}, yw]/8 + 
     G[{0, yv^(-1), yu^(-1), 0, 1/(yu*yv)}, yw]/16 - 
     G[{0, yv^(-1), yu^(-1), 1, 1}, yw]/4 + 
     G[{0, yv^(-1), yu^(-1), 1, yu^(-1)}, yw]/8 - 
     G[{0, yv^(-1), yu^(-1), 1, yv^(-1)}, yw]/4 - 
     G[{0, yv^(-1), yu^(-1), yu^(-1), 1}, yw]/8 + 
     G[{0, yv^(-1), yu^(-1), yu^(-1), 1/(yu*yv)}, yw]/8 - 
     G[{0, yv^(-1), yu^(-1), yv^(-1), 1}, yw]/8 + 
     G[{0, yv^(-1), yu^(-1), yv^(-1), 1/(yu*yv)}, yw]/8 + 
     G[{0, yv^(-1), yu^(-1), 1/(yu*yv), 1}, yw]/4 - 
     G[{0, yv^(-1), yu^(-1), 1/(yu*yv), yu^(-1)}, yw]/8 + 
     G[{0, yv^(-1), yu^(-1), 1/(yu*yv), yv^(-1)}, yw]/4 + 
     G[{0, yv^(-1), yv^(-1), 0, 1/(yu*yv)}, yw]/8 - 
     G[{0, yv^(-1), yv^(-1), 1, 1}, yw]/4 + 
     G[{0, yv^(-1), yv^(-1), 1, yu^(-1)}, yw]/8 - 
     G[{0, yv^(-1), yv^(-1), 1, yv^(-1)}, yw]/8 - 
     G[{0, yv^(-1), yv^(-1), yu^(-1), 1}, yw]/8 + 
     G[{0, yv^(-1), yv^(-1), yu^(-1), 1/(yu*yv)}, yw]/8 + 
     G[{0, yv^(-1), yv^(-1), 1/(yu*yv), 1}, yw]/4 - 
     G[{0, yv^(-1), yv^(-1), 1/(yu*yv), yu^(-1)}, yw]/8 + 
     G[{0, yv^(-1), yv^(-1), 1/(yu*yv), yv^(-1)}, yw]/8 - 
     G[{0, yv^(-1), 1/(yu*yv), 0, 1/(yu*yv)}, yw]/8 + 
     G[{0, yv^(-1), 1/(yu*yv), 1, yu^(-1)}, yw]/8 + 
     G[{0, yv^(-1), 1/(yu*yv), 1, yv^(-1)}, yw]/8 + 
     G[{0, yv^(-1), 1/(yu*yv), yu^(-1), 1}, yw]/8 - 
     G[{0, yv^(-1), 1/(yu*yv), yu^(-1), yu^(-1)}, yw]/8 + 
     G[{0, yv^(-1), 1/(yu*yv), yv^(-1), 1}, yw]/8 + 
     G[{0, yv^(-1), 1/(yu*yv), yv^(-1), yv^(-1)}, yw]/8 - 
     G[{0, yv^(-1), 1/(yu*yv), 1/(yu*yv), yu^(-1)}, yw]/8 - 
     G[{0, yv^(-1), 1/(yu*yv), 1/(yu*yv), yv^(-1)}, yw]/8 + 
     G[{0, 1/(yu*yv), 0, 1/(yu*yv), yu^(-1)}, yw]/16 + 
     G[{0, 1/(yu*yv), 0, 1/(yu*yv), yv^(-1)}, yw]/4 - 
     (3*G[{0, 1/(yu*yv), 0, 1/(yu*yv), 1/(yu*yv)}, yw])/16 - 
     (3*G[{0, 1/(yu*yv), 1, 1, 1}, yw])/16 + 
     G[{0, 1/(yu*yv), 1, 1, yu^(-1)}, yw]/8 - 
     G[{0, 1/(yu*yv), 1, 1, yv^(-1)}, yw]/16 - 
     G[{0, 1/(yu*yv), 1, 1, 1/(yu*yv)}, yw]/8 + 
     G[{0, 1/(yu*yv), 1, yu^(-1), 1}, yw]/8 + 
     G[{0, 1/(yu*yv), 1, yu^(-1), yu^(-1)}, yw]/8 + 
     G[{0, 1/(yu*yv), 1, yv^(-1), 1}, yw]/8 + 
     G[{0, 1/(yu*yv), 1, yv^(-1), yv^(-1)}, yw]/8 + 
     G[{0, 1/(yu*yv), 1, 1/(yu*yv), 1}, yw]/16 - 
     G[{0, 1/(yu*yv), 1, 1/(yu*yv), yu^(-1)}, yw]/4 - 
     G[{0, 1/(yu*yv), 1, 1/(yu*yv), yv^(-1)}, yw]/16 + 
     (5*G[{0, 1/(yu*yv), yu^(-1), 1, 1}, yw])/16 + 
     (5*G[{0, 1/(yu*yv), yu^(-1), 1, yv^(-1)}, yw])/16 + 
     G[{0, 1/(yu*yv), yu^(-1), yu^(-1), 1}, yw]/4 - 
     G[{0, 1/(yu*yv), yu^(-1), yu^(-1), yu^(-1)}, yw]/2 + 
     G[{0, 1/(yu*yv), yu^(-1), yv^(-1), 1}, yw]/8 - 
     G[{0, 1/(yu*yv), yu^(-1), yv^(-1), 1/(yu*yv)}, yw]/8 - 
     (5*G[{0, 1/(yu*yv), yu^(-1), 1/(yu*yv), 1}, yw])/16 + 
     (3*G[{0, 1/(yu*yv), yu^(-1), 1/(yu*yv), yu^(-1)}, yw])/8 - 
     (3*G[{0, 1/(yu*yv), yu^(-1), 1/(yu*yv), yv^(-1)}, yw])/16 + 
     (5*G[{0, 1/(yu*yv), yv^(-1), 1, 1}, yw])/16 - 
     G[{0, 1/(yu*yv), yv^(-1), 1, yu^(-1)}, yw]/4 + 
     (3*G[{0, 1/(yu*yv), yv^(-1), 1, yv^(-1)}, yw])/16 + 
     G[{0, 1/(yu*yv), yv^(-1), yu^(-1), 1}, yw]/8 - 
     G[{0, 1/(yu*yv), yv^(-1), yu^(-1), 1/(yu*yv)}, yw]/8 + 
     G[{0, 1/(yu*yv), yv^(-1), yv^(-1), 1}, yw]/4 + 
     G[{0, 1/(yu*yv), yv^(-1), yv^(-1), yv^(-1)}, yw]/4 - 
     (5*G[{0, 1/(yu*yv), yv^(-1), 1/(yu*yv), 1}, yw])/16 - 
     (3*G[{0, 1/(yu*yv), yv^(-1), 1/(yu*yv), yv^(-1)}, yw])/16 + 
     (3*G[{0, 1/(yu*yv), 1/(yu*yv), 1, 1}, yw])/16 - 
     (3*G[{0, 1/(yu*yv), 1/(yu*yv), 1, yu^(-1)}, yw])/8 - 
     (3*G[{0, 1/(yu*yv), 1/(yu*yv), 1, yv^(-1)}, yw])/16 - 
     (3*G[{0, 1/(yu*yv), 1/(yu*yv), yu^(-1), 1}, yw])/8 + 
     G[{0, 1/(yu*yv), 1/(yu*yv), yu^(-1), yu^(-1)}, yw]/2 - 
     (3*G[{0, 1/(yu*yv), 1/(yu*yv), yv^(-1), 1}, yw])/8 - 
     G[{0, 1/(yu*yv), 1/(yu*yv), yv^(-1), yv^(-1)}, yw]/4 + 
     G[{0, 1/(yu*yv), 1/(yu*yv), 1/(yu*yv), 1}, yw]/16 + 
     G[{0, 1/(yu*yv), 1/(yu*yv), 1/(yu*yv), yu^(-1)}, yw]/4 + 
     G[{0, 1/(yu*yv), 1/(yu*yv), 1/(yu*yv), yv^(-1)}, yw]/16 + 
     G[{1, 1, 1, 1, yu^(-1)}, yw]/16 + (5*G[{1, 1, 1, 1, yu}, yv^(-1)])/16 + 
     G[{1, 1, 1, 1, yv^(-1)}, yw]/16 - G[{1, 1, 1, 1, 1/(yu*yv)}, yw]/2 + 
     (5*G[{1, 1, 1, yu^(-1), yu^(-1)}, yw])/8 + 
     (3*G[{1, 1, 1, yu^(-1), yv^(-1)}, yw])/8 + 
     (5*G[{1, 1, 1, yu^(-1), 1/(yu*yv)}, yw])/16 - 
     G[{1, 1, 1, yu, yu}, yv^(-1)]/8 + (3*G[{1, 1, 1, yv^(-1), yu^(-1)}, yw])/
      8 + (7*G[{1, 1, 1, yv^(-1), yv^(-1)}, yw])/16 - 
     G[{1, 1, 1, yv^(-1), 1/(yu*yv)}, yw]/4 + 
     G[{1, 1, 1, 1/(yu*yv), yu^(-1)}, yw]/4 - 
     (5*G[{1, 1, 1, 1/(yu*yv), yv^(-1)}, yw])/16 - 
     (15*G[{1, 1, 1, 1/(yu*yv), 1/(yu*yv)}, yw])/16 + 
     (13*G[{1, 1, yu^(-1), 1, yu^(-1)}, yw])/64 + 
     G[{1, 1, yu^(-1), 1, yv^(-1)}, yw]/16 + 
     (7*G[{1, 1, yu^(-1), 1, 1/(yu*yv)}, yw])/64 + 
     (81*G[{1, 1, yu^(-1), yu^(-1), yu^(-1)}, yw])/64 + 
     G[{1, 1, yu^(-1), yu^(-1), yv^(-1)}, yw]/4 + 
     (27*G[{1, 1, yu^(-1), yu^(-1), 1/(yu*yv)}, yw])/64 + 
     G[{1, 1, yu^(-1), yv^(-1), yu^(-1)}, yw]/4 + 
     G[{1, 1, yu^(-1), yv^(-1), yv^(-1)}, yw]/4 + 
     G[{1, 1, yu^(-1), 1/(yu*yv), yu^(-1)}, yw]/8 - 
     (7*G[{1, 1, yu^(-1), 1/(yu*yv), yv^(-1)}, yw])/16 + 
     (5*G[{1, 1, yu, 1, yu}, yv^(-1)])/64 - 
     (19*G[{1, 1, yu, yu, yu}, yv^(-1)])/64 + 
     G[{1, 1, yv^(-1), 1, yu^(-1)}, yw]/16 + 
     G[{1, 1, yv^(-1), 1, yv^(-1)}, yw]/16 - 
     G[{1, 1, yv^(-1), 1, 1/(yu*yv)}, yw]/8 + 
     G[{1, 1, yv^(-1), yu^(-1), yu^(-1)}, yw]/4 - 
     G[{1, 1, yv^(-1), yv^(-1), yu^(-1)}, yw]/4 - 
     (15*G[{1, 1, yv^(-1), yv^(-1), yv^(-1)}, yw])/16 + 
     (3*G[{1, 1, yv^(-1), yv^(-1), 1/(yu*yv)}, yw])/4 + 
     (3*G[{1, 1, yv^(-1), 1/(yu*yv), yu^(-1)}, yw])/16 + 
     (5*G[{1, 1, yv^(-1), 1/(yu*yv), yv^(-1)}, yw])/16 - 
     (3*G[{1, 1, yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/8 + 
     (15*G[{1, 1, 1/(yu*yv), 1, yu^(-1)}, yw])/64 - 
     (23*G[{1, 1, 1/(yu*yv), 1, 1/(yu*yv)}, yw])/64 + 
     (7*G[{1, 1, 1/(yu*yv), yu^(-1), yu^(-1)}, yw])/64 - 
     (5*G[{1, 1, 1/(yu*yv), yu^(-1), 1/(yu*yv)}, yw])/64 + 
     G[{1, 1, 1/(yu*yv), yv^(-1), yv^(-1)}, yw]/16 - 
     G[{1, 1, 1/(yu*yv), yv^(-1), 1/(yu*yv)}, yw]/8 - 
     (3*G[{1, 1, 1/(yu*yv), 1/(yu*yv), yu^(-1)}, yw])/16 - 
     (7*G[{1, 1, 1/(yu*yv), 1/(yu*yv), 1/(yu*yv)}, yw])/16 + 
     (5*G[{1, yu^(-1), 1, yu^(-1), yu^(-1)}, yw])/16 + 
     G[{1, yu^(-1), 1, yu^(-1), yv^(-1)}, yw]/8 + 
     (11*G[{1, yu^(-1), 1, yu^(-1), 1/(yu*yv)}, yw])/64 + 
     G[{1, yu^(-1), 1, yv^(-1), yu^(-1)}, yw]/8 + 
     (3*G[{1, yu^(-1), 1, yv^(-1), yv^(-1)}, yw])/8 + 
     G[{1, yu^(-1), 1, 1/(yu*yv), yu^(-1)}, yw]/8 - 
     (3*G[{1, yu^(-1), 1, 1/(yu*yv), yv^(-1)}, yw])/16 + 
     (3*G[{1, yu^(-1), 1, 1/(yu*yv), 1/(yu*yv)}, yw])/64 - 
     G[{1, yu^(-1), yu^(-1), 1, yv^(-1)}, yw]/8 + 
     (3*G[{1, yu^(-1), yu^(-1), 1, 1/(yu*yv)}, yw])/16 + 
     (41*G[{1, yu^(-1), yu^(-1), yu^(-1), yu^(-1)}, yw])/32 + 
     (3*G[{1, yu^(-1), yu^(-1), yu^(-1), 1/(yu*yv)}, yw])/64 - 
     G[{1, yu^(-1), yu^(-1), yv^(-1), 1/(yu*yv)}, yw]/8 - 
     (9*G[{1, yu^(-1), yu^(-1), 1/(yu*yv), yu^(-1)}, yw])/64 - 
     G[{1, yu^(-1), yu^(-1), 1/(yu*yv), yv^(-1)}, yw]/2 - 
     (3*G[{1, yu^(-1), yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/32 + 
     G[{1, yu^(-1), yv^(-1), 1, yv^(-1)}, yw]/8 + 
     G[{1, yu^(-1), yv^(-1), 1, 1/(yu*yv)}, yw]/4 - 
     G[{1, yu^(-1), yv^(-1), yu^(-1), 1/(yu*yv)}, yw]/8 - 
     G[{1, yu^(-1), yv^(-1), yv^(-1), 1/(yu*yv)}, yw]/8 + 
     G[{1, yu^(-1), yv^(-1), 1/(yu*yv), yu^(-1)}, yw]/8 - 
     G[{1, yu^(-1), yv^(-1), 1/(yu*yv), yv^(-1)}, yw]/4 - 
     (5*G[{1, yu^(-1), 1/(yu*yv), 1, yv^(-1)}, yw])/16 + 
     (3*G[{1, yu^(-1), 1/(yu*yv), 1, 1/(yu*yv)}, yw])/64 - 
     (9*G[{1, yu^(-1), 1/(yu*yv), yu^(-1), yu^(-1)}, yw])/64 - 
     (3*G[{1, yu^(-1), 1/(yu*yv), yu^(-1), 1/(yu*yv)}, yw])/32 - 
     (7*G[{1, yu^(-1), 1/(yu*yv), 1/(yu*yv), yu^(-1)}, yw])/64 + 
     G[{1, yu^(-1), 1/(yu*yv), 1/(yu*yv), yv^(-1)}, yw]/16 + 
     G[{1, yu, 1, yu, yu}, yv^(-1)]/8 - (3*G[{1, yu, yu, yu, yu}, yv^(-1)])/
      32 - G[{1, yv^(-1), 1, yv^(-1), yu^(-1)}, yw]/8 - 
     (7*G[{1, yv^(-1), 1, yv^(-1), yv^(-1)}, yw])/16 + 
     (5*G[{1, yv^(-1), 1, yv^(-1), 1/(yu*yv)}, yw])/16 + 
     G[{1, yv^(-1), 1, 1/(yu*yv), yu^(-1)}, yw]/8 + 
     G[{1, yv^(-1), 1, 1/(yu*yv), yv^(-1)}, yw]/8 - 
     (3*G[{1, yv^(-1), 1, 1/(yu*yv), 1/(yu*yv)}, yw])/16 + 
     G[{1, yv^(-1), yu^(-1), 1, 1/(yu*yv)}, yw]/4 - 
     G[{1, yv^(-1), yu^(-1), yu^(-1), 1/(yu*yv)}, yw]/8 - 
     G[{1, yv^(-1), yu^(-1), yv^(-1), 1/(yu*yv)}, yw]/8 + 
     G[{1, yv^(-1), yu^(-1), 1/(yu*yv), yu^(-1)}, yw]/8 - 
     G[{1, yv^(-1), yu^(-1), 1/(yu*yv), yv^(-1)}, yw]/4 + 
     (3*G[{1, yv^(-1), yv^(-1), 1, 1/(yu*yv)}, yw])/16 - 
     G[{1, yv^(-1), yv^(-1), yu^(-1), 1/(yu*yv)}, yw]/8 - 
     G[{1, yv^(-1), yv^(-1), yv^(-1), yv^(-1)}, yw]/8 + 
     G[{1, yv^(-1), yv^(-1), 1/(yu*yv), yu^(-1)}, yw]/4 - 
     (3*G[{1, yv^(-1), yv^(-1), 1/(yu*yv), yv^(-1)}, yw])/16 - 
     (3*G[{1, yv^(-1), 1/(yu*yv), 1, 1/(yu*yv)}, yw])/16 - 
     (3*G[{1, yv^(-1), 1/(yu*yv), yv^(-1), yv^(-1)}, yw])/16 + 
     G[{1, yv^(-1), 1/(yu*yv), 1/(yu*yv), yu^(-1)}, yw]/16 + 
     G[{1, yv^(-1), 1/(yu*yv), 1/(yu*yv), yv^(-1)}, yw]/8 + 
     G[{1, 1/(yu*yv), 1, 1/(yu*yv), yu^(-1)}, yw]/16 + 
     G[{1, 1/(yu*yv), 1, 1/(yu*yv), yv^(-1)}, yw]/16 - 
     (17*G[{1, 1/(yu*yv), 1, 1/(yu*yv), 1/(yu*yv)}, yw])/64 - 
     (9*G[{1, 1/(yu*yv), yu^(-1), yu^(-1), yu^(-1)}, yw])/32 - 
     (11*G[{1, 1/(yu*yv), yu^(-1), yu^(-1), 1/(yu*yv)}, yw])/64 + 
     G[{1, 1/(yu*yv), yu^(-1), 1/(yu*yv), yu^(-1)}, yw]/64 + 
     G[{1, 1/(yu*yv), yu^(-1), 1/(yu*yv), yv^(-1)}, yw]/8 + 
     (3*G[{1, 1/(yu*yv), yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/32 - 
     (3*G[{1, 1/(yu*yv), yv^(-1), yv^(-1), yv^(-1)}, yw])/8 - 
     G[{1, 1/(yu*yv), yv^(-1), yv^(-1), 1/(yu*yv)}, yw]/8 + 
     G[{1, 1/(yu*yv), yv^(-1), 1/(yu*yv), yu^(-1)}, yw]/8 + 
     G[{1, 1/(yu*yv), yv^(-1), 1/(yu*yv), yv^(-1)}, yw]/16 - 
     (7*G[{1, 1/(yu*yv), 1/(yu*yv), yu^(-1), yu^(-1)}, yw])/64 + 
     (3*G[{1, 1/(yu*yv), 1/(yu*yv), yu^(-1), 1/(yu*yv)}, yw])/32 - 
     G[{1, 1/(yu*yv), 1/(yu*yv), yv^(-1), yv^(-1)}, yw]/16 + 
     (3*G[{1, 1/(yu*yv), 1/(yu*yv), 1/(yu*yv), yu^(-1)}, yw])/64 + 
     (3*G[{1, 1/(yu*yv), 1/(yu*yv), 1/(yu*yv), yv^(-1)}, yw])/16 - 
     (41*G[{yu^(-1), yu^(-1), yu^(-1), yu^(-1), 1/(yu*yv)}, yw])/32 - 
     (129*G[{yu^(-1), yu^(-1), yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/64 - 
     (11*G[{yu^(-1), yu^(-1), 1/(yu*yv), yu^(-1), 1/(yu*yv)}, yw])/16 - 
     G[{yu^(-1), yu^(-1), 1/(yu*yv), yv^(-1), 1/(yu*yv)}, yw]/8 - 
     G[{yu^(-1), yu^(-1), 1/(yu*yv), 1/(yu*yv), yv^(-1)}, yw]/2 - 
     (7*G[{yu^(-1), yu^(-1), 1/(yu*yv), 1/(yu*yv), 1/(yu*yv)}, yw])/16 - 
     G[{yu^(-1), 1/(yu*yv), yu^(-1), 1/(yu*yv), yv^(-1)}, yw]/4 - 
     (17*G[{yu^(-1), 1/(yu*yv), yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/64 + 
     G[{yu^(-1), 1/(yu*yv), yv^(-1), yv^(-1), 1/(yu*yv)}, yw]/8 + 
     G[{yu^(-1), 1/(yu*yv), yv^(-1), 1/(yu*yv), yv^(-1)}, yw]/4 + 
     G[{yu^(-1), 1/(yu*yv), 1/(yu*yv), yv^(-1), yv^(-1)}, yw]/2 - 
     (3*G[{yu^(-1), 1/(yu*yv), 1/(yu*yv), 1/(yu*yv), yv^(-1)}, yw])/16 + 
     G[{yv^(-1), yv^(-1), yv^(-1), yv^(-1), 1/(yu*yv)}, yw]/8 + 
     (3*G[{yv^(-1), yv^(-1), yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/16 + 
     G[{yv^(-1), yv^(-1), 1/(yu*yv), yv^(-1), 1/(yu*yv)}, yw]/16 - 
     G[{yv^(-1), yv^(-1), 1/(yu*yv), 1/(yu*yv), 1/(yu*yv)}, yw]/4 - 
     G[{yv^(-1), 1/(yu*yv), yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw]/8 - 
     (Pi^2*Zeta[3])/96 - (G[{1}, yu^(-1)]^2*Zeta[3])/32 + 
     (G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*Zeta[3])/16 + 
     (7*G[{1}, yv^(-1)]^2*Zeta[3])/64 - (G[{0}, yu^(-1)]*G[{1}, yw]*Zeta[3])/
      8 - (G[{0}, yv^(-1)]*G[{1}, yw]*Zeta[3])/8 + 
     (G[{0}, yw]*G[{1}, yw]*Zeta[3])/8 + (G[{1}, yu^(-1)]*G[{1}, yw]*Zeta[3])/
      16 - (G[{1}, yv^(-1)]*G[{1}, yw]*Zeta[3])/32 - 
     (3*G[{1}, yw]^2*Zeta[3])/64 + (3*G[{1}, yw]*G[{yu}, yv^(-1)]*Zeta[3])/
      32 + (G[{0}, yu^(-1)]*G[{1/(yu*yv)}, yw]*Zeta[3])/8 + 
     (G[{0}, yv^(-1)]*G[{1/(yu*yv)}, yw]*Zeta[3])/8 - 
     (G[{0}, yw]*G[{1/(yu*yv)}, yw]*Zeta[3])/8 - 
     (G[{1}, yu^(-1)]*G[{1/(yu*yv)}, yw]*Zeta[3])/16 + 
     (G[{1}, yv^(-1)]*G[{1/(yu*yv)}, yw]*Zeta[3])/32 + 
     (3*G[{1}, yw]*G[{1/(yu*yv)}, yw]*Zeta[3])/32 - 
     (G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*Zeta[3])/32 - 
     (3*G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw]*Zeta[3])/32 + 
     (G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*Zeta[3])/16 + 
     (G[{0, 1}, yu^(-1)]*Zeta[3])/16 - (7*G[{0, 1}, yv^(-1)]*Zeta[3])/32 - 
     (G[{0, 1}, yw]*Zeta[3])/8 + (7*G[{0, yu}, yv^(-1)]*Zeta[3])/32 + 
     (G[{0, 1/(yu*yv)}, yw]*Zeta[3])/8 + (G[{1, yu^(-1)}, yw]*Zeta[3])/32 - 
     (9*G[{1, yu}, yv^(-1)]*Zeta[3])/32 - (G[{1, yv^(-1)}, yw]*Zeta[3])/16 - 
     (3*G[{1, 1/(yu*yv)}, yw]*Zeta[3])/32 + 
     (G[{yu^(-1), 1/(yu*yv)}, yw]*Zeta[3])/32 - 
     (G[{yv^(-1), 1/(yu*yv)}, yw]*Zeta[3])/16 + (11*Zeta[5])/32
 
QepwvuRegII = (11*Pi^2*G[{1}, yu^(-1)]^3)/2304 - 
     (11*Pi^2*G[{1}, yu^(-1)]^2*G[{1}, yv^(-1)])/768 + 
     (29*Pi^2*G[{1}, yu^(-1)]*G[{1}, yv^(-1)]^2)/1536 + 
     (3*G[{1}, yu^(-1)]^3*G[{1}, yv^(-1)]^2)/256 - (Pi^2*G[{1}, yv^(-1)]^3)/
      576 - (G[{1}, yu^(-1)]^2*G[{1}, yv^(-1)]^3)/256 - 
     (G[{1}, yu^(-1)]*G[{1}, yv^(-1)]^4)/768 + (Pi^4*G[{1}, yw])/1152 - 
     (Pi^2*G[{0}, yu^(-1)]^2*G[{1}, yw])/192 - 
     (Pi^2*G[{0}, yu^(-1)]*G[{0}, yv^(-1)]*G[{1}, yw])/96 - 
     (Pi^2*G[{0}, yv^(-1)]^2*G[{1}, yw])/192 + 
     (Pi^2*G[{0}, yu^(-1)]*G[{0}, yw]*G[{1}, yw])/96 + 
     (Pi^2*G[{0}, yv^(-1)]*G[{0}, yw]*G[{1}, yw])/96 - 
     (Pi^2*G[{0}, yw]^2*G[{1}, yw])/192 - 
     (Pi^2*G[{0}, yu^(-1)]*G[{1}, yu^(-1)]*G[{1}, yw])/48 - 
     (Pi^2*G[{0}, yv^(-1)]*G[{1}, yu^(-1)]*G[{1}, yw])/48 + 
     (Pi^2*G[{0}, yw]*G[{1}, yu^(-1)]*G[{1}, yw])/48 + 
     (11*Pi^2*G[{1}, yu^(-1)]^2*G[{1}, yw])/768 + 
     (Pi^2*G[{0}, yu^(-1)]*G[{1}, yv^(-1)]*G[{1}, yw])/96 + 
     (Pi^2*G[{0}, yv^(-1)]*G[{1}, yv^(-1)]*G[{1}, yw])/96 - 
     (Pi^2*G[{0}, yw]*G[{1}, yv^(-1)]*G[{1}, yw])/96 + 
     (Pi^2*G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*G[{1}, yw])/256 + 
     (3*G[{1}, yu^(-1)]^3*G[{1}, yv^(-1)]*G[{1}, yw])/128 - 
     (Pi^2*G[{1}, yv^(-1)]^2*G[{1}, yw])/192 - 
     (9*G[{1}, yu^(-1)]^2*G[{1}, yv^(-1)]^2*G[{1}, yw])/256 + 
     (G[{1}, yu^(-1)]*G[{1}, yv^(-1)]^3*G[{1}, yw])/96 - 
     (Pi^2*G[{0}, yu^(-1)]*G[{1}, yw]^2)/96 - 
     (Pi^2*G[{0}, yv^(-1)]*G[{1}, yw]^2)/96 + (Pi^2*G[{0}, yw]*G[{1}, yw]^2)/
      96 - (3*Pi^2*G[{1}, yu^(-1)]*G[{1}, yw]^2)/256 + 
     (G[{0}, yu^(-1)]^2*G[{1}, yu^(-1)]*G[{1}, yw]^2)/64 + 
     (G[{0}, yu^(-1)]*G[{0}, yv^(-1)]*G[{1}, yu^(-1)]*G[{1}, yw]^2)/32 + 
     (G[{0}, yv^(-1)]^2*G[{1}, yu^(-1)]*G[{1}, yw]^2)/64 - 
     (G[{0}, yu^(-1)]*G[{0}, yw]*G[{1}, yu^(-1)]*G[{1}, yw]^2)/32 - 
     (G[{0}, yv^(-1)]*G[{0}, yw]*G[{1}, yu^(-1)]*G[{1}, yw]^2)/32 + 
     (G[{0}, yw]^2*G[{1}, yu^(-1)]*G[{1}, yw]^2)/64 + 
     (G[{0}, yu^(-1)]*G[{1}, yu^(-1)]^2*G[{1}, yw]^2)/64 + 
     (G[{0}, yv^(-1)]*G[{1}, yu^(-1)]^2*G[{1}, yw]^2)/64 - 
     (G[{0}, yw]*G[{1}, yu^(-1)]^2*G[{1}, yw]^2)/64 - 
     (5*G[{1}, yu^(-1)]^3*G[{1}, yw]^2)/256 + 
     (G[{0}, yu^(-1)]^2*G[{1}, yv^(-1)]*G[{1}, yw]^2)/64 + 
     (G[{0}, yu^(-1)]*G[{0}, yv^(-1)]*G[{1}, yv^(-1)]*G[{1}, yw]^2)/32 + 
     (G[{0}, yv^(-1)]^2*G[{1}, yv^(-1)]*G[{1}, yw]^2)/64 - 
     (G[{0}, yu^(-1)]*G[{0}, yw]*G[{1}, yv^(-1)]*G[{1}, yw]^2)/32 - 
     (G[{0}, yv^(-1)]*G[{0}, yw]*G[{1}, yv^(-1)]*G[{1}, yw]^2)/32 + 
     (G[{0}, yw]^2*G[{1}, yv^(-1)]*G[{1}, yw]^2)/64 - 
     (G[{0}, yu^(-1)]*G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*G[{1}, yw]^2)/32 - 
     (G[{0}, yv^(-1)]*G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*G[{1}, yw]^2)/32 + 
     (G[{0}, yw]*G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*G[{1}, yw]^2)/32 - 
     (5*G[{1}, yu^(-1)]^2*G[{1}, yv^(-1)]*G[{1}, yw]^2)/256 - 
     (G[{0}, yu^(-1)]*G[{1}, yv^(-1)]^2*G[{1}, yw]^2)/32 - 
     (G[{0}, yv^(-1)]*G[{1}, yv^(-1)]^2*G[{1}, yw]^2)/32 + 
     (G[{0}, yw]*G[{1}, yv^(-1)]^2*G[{1}, yw]^2)/32 - 
     (G[{1}, yu^(-1)]*G[{1}, yv^(-1)]^2*G[{1}, yw]^2)/128 + 
     (G[{1}, yv^(-1)]^3*G[{1}, yw]^2)/64 - (25*Pi^2*G[{1}, yw]^3)/2304 + 
     (G[{0}, yu^(-1)]^2*G[{1}, yw]^3)/96 + 
     (G[{0}, yu^(-1)]*G[{0}, yv^(-1)]*G[{1}, yw]^3)/48 + 
     (G[{0}, yv^(-1)]^2*G[{1}, yw]^3)/96 - 
     (G[{0}, yu^(-1)]*G[{0}, yw]*G[{1}, yw]^3)/48 - 
     (G[{0}, yv^(-1)]*G[{0}, yw]*G[{1}, yw]^3)/48 + 
     (G[{0}, yw]^2*G[{1}, yw]^3)/96 + (5*G[{0}, yu^(-1)]*G[{1}, yu^(-1)]*
       G[{1}, yw]^3)/96 + (5*G[{0}, yv^(-1)]*G[{1}, yu^(-1)]*G[{1}, yw]^3)/
      96 - (5*G[{0}, yw]*G[{1}, yu^(-1)]*G[{1}, yw]^3)/96 - 
     (7*G[{1}, yu^(-1)]^2*G[{1}, yw]^3)/256 + 
     (G[{0}, yu^(-1)]*G[{1}, yv^(-1)]*G[{1}, yw]^3)/48 + 
     (G[{0}, yv^(-1)]*G[{1}, yv^(-1)]*G[{1}, yw]^3)/48 - 
     (G[{0}, yw]*G[{1}, yv^(-1)]*G[{1}, yw]^3)/48 - 
     (35*G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*G[{1}, yw]^3)/384 - 
     (5*G[{1}, yv^(-1)]^2*G[{1}, yw]^3)/256 + 
     (11*G[{0}, yu^(-1)]*G[{1}, yw]^4)/384 + 
     (11*G[{0}, yv^(-1)]*G[{1}, yw]^4)/384 - (11*G[{0}, yw]*G[{1}, yw]^4)/
      384 + (5*G[{1}, yu^(-1)]*G[{1}, yw]^4)/768 - 
     (G[{1}, yv^(-1)]*G[{1}, yw]^4)/192 + (3*G[{1}, yw]^5)/256 + 
     (Pi^2*G[{0}, yu^(-1)]*G[{1}, yw]*G[{yu}, yv^(-1)])/48 + 
     (Pi^2*G[{0}, yv^(-1)]*G[{1}, yw]*G[{yu}, yv^(-1)])/48 - 
     (Pi^2*G[{0}, yw]*G[{1}, yw]*G[{yu}, yv^(-1)])/48 + 
     (7*Pi^2*G[{1}, yu^(-1)]*G[{1}, yw]*G[{yu}, yv^(-1)])/768 - 
     (3*G[{1}, yu^(-1)]^3*G[{1}, yw]*G[{yu}, yv^(-1)])/128 - 
     (Pi^2*G[{1}, yv^(-1)]*G[{1}, yw]*G[{yu}, yv^(-1)])/96 + 
     (11*G[{1}, yu^(-1)]^2*G[{1}, yv^(-1)]*G[{1}, yw]*G[{yu}, yv^(-1)])/128 - 
     (3*G[{1}, yu^(-1)]*G[{1}, yv^(-1)]^2*G[{1}, yw]*G[{yu}, yv^(-1)])/128 + 
     (25*Pi^2*G[{1}, yw]^2*G[{yu}, yv^(-1)])/768 - 
     (G[{0}, yu^(-1)]^2*G[{1}, yw]^2*G[{yu}, yv^(-1)])/32 - 
     (G[{0}, yu^(-1)]*G[{0}, yv^(-1)]*G[{1}, yw]^2*G[{yu}, yv^(-1)])/16 - 
     (G[{0}, yv^(-1)]^2*G[{1}, yw]^2*G[{yu}, yv^(-1)])/32 + 
     (G[{0}, yu^(-1)]*G[{0}, yw]*G[{1}, yw]^2*G[{yu}, yv^(-1)])/16 + 
     (G[{0}, yv^(-1)]*G[{0}, yw]*G[{1}, yw]^2*G[{yu}, yv^(-1)])/16 - 
     (G[{0}, yw]^2*G[{1}, yw]^2*G[{yu}, yv^(-1)])/32 - 
     (G[{0}, yu^(-1)]*G[{1}, yu^(-1)]*G[{1}, yw]^2*G[{yu}, yv^(-1)])/16 - 
     (G[{0}, yv^(-1)]*G[{1}, yu^(-1)]*G[{1}, yw]^2*G[{yu}, yv^(-1)])/16 + 
     (G[{0}, yw]*G[{1}, yu^(-1)]*G[{1}, yw]^2*G[{yu}, yv^(-1)])/16 + 
     (3*G[{1}, yu^(-1)]^2*G[{1}, yw]^2*G[{yu}, yv^(-1)])/64 - 
     (G[{0}, yu^(-1)]*G[{1}, yv^(-1)]*G[{1}, yw]^2*G[{yu}, yv^(-1)])/16 - 
     (G[{0}, yv^(-1)]*G[{1}, yv^(-1)]*G[{1}, yw]^2*G[{yu}, yv^(-1)])/16 + 
     (G[{0}, yw]*G[{1}, yv^(-1)]*G[{1}, yw]^2*G[{yu}, yv^(-1)])/16 + 
     (33*G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*G[{1}, yw]^2*G[{yu}, yv^(-1)])/128 + 
     (15*G[{1}, yv^(-1)]^2*G[{1}, yw]^2*G[{yu}, yv^(-1)])/256 - 
     (11*G[{0}, yu^(-1)]*G[{1}, yw]^3*G[{yu}, yv^(-1)])/96 - 
     (11*G[{0}, yv^(-1)]*G[{1}, yw]^3*G[{yu}, yv^(-1)])/96 + 
     (11*G[{0}, yw]*G[{1}, yw]^3*G[{yu}, yv^(-1)])/96 + 
     (G[{1}, yu^(-1)]*G[{1}, yw]^3*G[{yu}, yv^(-1)])/24 + 
     (13*G[{1}, yv^(-1)]*G[{1}, yw]^3*G[{yu}, yv^(-1)])/384 - 
     (15*G[{1}, yw]^4*G[{yu}, yv^(-1)])/256 - 
     (31*Pi^2*G[{1}, yw]*G[{yu}, yv^(-1)]^2)/1536 - 
     (G[{1}, yu^(-1)]^2*G[{1}, yw]*G[{yu}, yv^(-1)]^2)/128 - 
     (3*G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*G[{1}, yw]*G[{yu}, yv^(-1)]^2)/32 + 
     (3*G[{1}, yv^(-1)]^2*G[{1}, yw]*G[{yu}, yv^(-1)]^2)/128 + 
     (G[{0}, yu^(-1)]*G[{1}, yw]^2*G[{yu}, yv^(-1)]^2)/8 + 
     (G[{0}, yv^(-1)]*G[{1}, yw]^2*G[{yu}, yv^(-1)]^2)/8 - 
     (G[{0}, yw]*G[{1}, yw]^2*G[{yu}, yv^(-1)]^2)/8 - 
     (29*G[{1}, yu^(-1)]*G[{1}, yw]^2*G[{yu}, yv^(-1)]^2)/256 - 
     (3*G[{1}, yv^(-1)]*G[{1}, yw]^2*G[{yu}, yv^(-1)]^2)/32 + 
     (59*G[{1}, yw]^3*G[{yu}, yv^(-1)]^2)/768 + 
     (7*G[{1}, yu^(-1)]*G[{1}, yw]*G[{yu}, yv^(-1)]^3)/192 + 
     (G[{1}, yv^(-1)]*G[{1}, yw]*G[{yu}, yv^(-1)]^3)/48 - 
     (11*G[{1}, yw]^2*G[{yu}, yv^(-1)]^3)/768 - 
     (11*G[{1}, yw]*G[{yu}, yv^(-1)]^4)/768 - (Pi^4*G[{1/(yu*yv)}, yw])/
      1152 + (Pi^2*G[{0}, yu^(-1)]^2*G[{1/(yu*yv)}, yw])/192 + 
     (Pi^2*G[{0}, yu^(-1)]*G[{0}, yv^(-1)]*G[{1/(yu*yv)}, yw])/96 + 
     (Pi^2*G[{0}, yv^(-1)]^2*G[{1/(yu*yv)}, yw])/192 - 
     (Pi^2*G[{0}, yu^(-1)]*G[{0}, yw]*G[{1/(yu*yv)}, yw])/96 - 
     (Pi^2*G[{0}, yv^(-1)]*G[{0}, yw]*G[{1/(yu*yv)}, yw])/96 + 
     (Pi^2*G[{0}, yw]^2*G[{1/(yu*yv)}, yw])/192 + 
     (Pi^2*G[{0}, yu^(-1)]*G[{1}, yu^(-1)]*G[{1/(yu*yv)}, yw])/48 + 
     (Pi^2*G[{0}, yv^(-1)]*G[{1}, yu^(-1)]*G[{1/(yu*yv)}, yw])/48 - 
     (Pi^2*G[{0}, yw]*G[{1}, yu^(-1)]*G[{1/(yu*yv)}, yw])/48 - 
     (11*Pi^2*G[{1}, yu^(-1)]^2*G[{1/(yu*yv)}, yw])/768 - 
     (Pi^2*G[{0}, yu^(-1)]*G[{1}, yv^(-1)]*G[{1/(yu*yv)}, yw])/96 - 
     (Pi^2*G[{0}, yv^(-1)]*G[{1}, yv^(-1)]*G[{1/(yu*yv)}, yw])/96 + 
     (Pi^2*G[{0}, yw]*G[{1}, yv^(-1)]*G[{1/(yu*yv)}, yw])/96 - 
     (Pi^2*G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*G[{1/(yu*yv)}, yw])/256 - 
     (3*G[{1}, yu^(-1)]^3*G[{1}, yv^(-1)]*G[{1/(yu*yv)}, yw])/128 + 
     (Pi^2*G[{1}, yv^(-1)]^2*G[{1/(yu*yv)}, yw])/192 + 
     (9*G[{1}, yu^(-1)]^2*G[{1}, yv^(-1)]^2*G[{1/(yu*yv)}, yw])/256 - 
     (G[{1}, yu^(-1)]*G[{1}, yv^(-1)]^3*G[{1/(yu*yv)}, yw])/96 + 
     (Pi^2*G[{0}, yu^(-1)]*G[{1}, yw]*G[{1/(yu*yv)}, yw])/48 + 
     (Pi^2*G[{0}, yv^(-1)]*G[{1}, yw]*G[{1/(yu*yv)}, yw])/48 - 
     (Pi^2*G[{0}, yw]*G[{1}, yw]*G[{1/(yu*yv)}, yw])/48 + 
     (3*Pi^2*G[{1}, yu^(-1)]*G[{1}, yw]*G[{1/(yu*yv)}, yw])/128 - 
     (G[{0}, yu^(-1)]^2*G[{1}, yu^(-1)]*G[{1}, yw]*G[{1/(yu*yv)}, yw])/32 - 
     (G[{0}, yu^(-1)]*G[{0}, yv^(-1)]*G[{1}, yu^(-1)]*G[{1}, yw]*
       G[{1/(yu*yv)}, yw])/16 - (G[{0}, yv^(-1)]^2*G[{1}, yu^(-1)]*G[{1}, yw]*
       G[{1/(yu*yv)}, yw])/32 + (G[{0}, yu^(-1)]*G[{0}, yw]*G[{1}, yu^(-1)]*
       G[{1}, yw]*G[{1/(yu*yv)}, yw])/16 + 
     (G[{0}, yv^(-1)]*G[{0}, yw]*G[{1}, yu^(-1)]*G[{1}, yw]*
       G[{1/(yu*yv)}, yw])/16 - (G[{0}, yw]^2*G[{1}, yu^(-1)]*G[{1}, yw]*
       G[{1/(yu*yv)}, yw])/32 - (G[{0}, yu^(-1)]*G[{1}, yu^(-1)]^2*G[{1}, yw]*
       G[{1/(yu*yv)}, yw])/32 - (G[{0}, yv^(-1)]*G[{1}, yu^(-1)]^2*G[{1}, yw]*
       G[{1/(yu*yv)}, yw])/32 + (G[{0}, yw]*G[{1}, yu^(-1)]^2*G[{1}, yw]*
       G[{1/(yu*yv)}, yw])/32 + (5*G[{1}, yu^(-1)]^3*G[{1}, yw]*
       G[{1/(yu*yv)}, yw])/128 - (G[{0}, yu^(-1)]^2*G[{1}, yv^(-1)]*
       G[{1}, yw]*G[{1/(yu*yv)}, yw])/32 - 
     (G[{0}, yu^(-1)]*G[{0}, yv^(-1)]*G[{1}, yv^(-1)]*G[{1}, yw]*
       G[{1/(yu*yv)}, yw])/16 - (G[{0}, yv^(-1)]^2*G[{1}, yv^(-1)]*G[{1}, yw]*
       G[{1/(yu*yv)}, yw])/32 + (G[{0}, yu^(-1)]*G[{0}, yw]*G[{1}, yv^(-1)]*
       G[{1}, yw]*G[{1/(yu*yv)}, yw])/16 + 
     (G[{0}, yv^(-1)]*G[{0}, yw]*G[{1}, yv^(-1)]*G[{1}, yw]*
       G[{1/(yu*yv)}, yw])/16 - (G[{0}, yw]^2*G[{1}, yv^(-1)]*G[{1}, yw]*
       G[{1/(yu*yv)}, yw])/32 + (G[{0}, yu^(-1)]*G[{1}, yu^(-1)]*
       G[{1}, yv^(-1)]*G[{1}, yw]*G[{1/(yu*yv)}, yw])/16 + 
     (G[{0}, yv^(-1)]*G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*G[{1}, yw]*
       G[{1/(yu*yv)}, yw])/16 - (G[{0}, yw]*G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*
       G[{1}, yw]*G[{1/(yu*yv)}, yw])/16 + 
     (5*G[{1}, yu^(-1)]^2*G[{1}, yv^(-1)]*G[{1}, yw]*G[{1/(yu*yv)}, yw])/
      128 + (G[{0}, yu^(-1)]*G[{1}, yv^(-1)]^2*G[{1}, yw]*G[{1/(yu*yv)}, yw])/
      16 + (G[{0}, yv^(-1)]*G[{1}, yv^(-1)]^2*G[{1}, yw]*G[{1/(yu*yv)}, yw])/
      16 - (G[{0}, yw]*G[{1}, yv^(-1)]^2*G[{1}, yw]*G[{1/(yu*yv)}, yw])/16 + 
     (G[{1}, yu^(-1)]*G[{1}, yv^(-1)]^2*G[{1}, yw]*G[{1/(yu*yv)}, yw])/64 - 
     (G[{1}, yv^(-1)]^3*G[{1}, yw]*G[{1/(yu*yv)}, yw])/32 + 
     (25*Pi^2*G[{1}, yw]^2*G[{1/(yu*yv)}, yw])/768 - 
     (G[{0}, yu^(-1)]^2*G[{1}, yw]^2*G[{1/(yu*yv)}, yw])/32 - 
     (G[{0}, yu^(-1)]*G[{0}, yv^(-1)]*G[{1}, yw]^2*G[{1/(yu*yv)}, yw])/16 - 
     (G[{0}, yv^(-1)]^2*G[{1}, yw]^2*G[{1/(yu*yv)}, yw])/32 + 
     (G[{0}, yu^(-1)]*G[{0}, yw]*G[{1}, yw]^2*G[{1/(yu*yv)}, yw])/16 + 
     (G[{0}, yv^(-1)]*G[{0}, yw]*G[{1}, yw]^2*G[{1/(yu*yv)}, yw])/16 - 
     (G[{0}, yw]^2*G[{1}, yw]^2*G[{1/(yu*yv)}, yw])/32 - 
     (5*G[{0}, yu^(-1)]*G[{1}, yu^(-1)]*G[{1}, yw]^2*G[{1/(yu*yv)}, yw])/32 - 
     (5*G[{0}, yv^(-1)]*G[{1}, yu^(-1)]*G[{1}, yw]^2*G[{1/(yu*yv)}, yw])/32 + 
     (5*G[{0}, yw]*G[{1}, yu^(-1)]*G[{1}, yw]^2*G[{1/(yu*yv)}, yw])/32 + 
     (21*G[{1}, yu^(-1)]^2*G[{1}, yw]^2*G[{1/(yu*yv)}, yw])/256 - 
     (G[{0}, yu^(-1)]*G[{1}, yv^(-1)]*G[{1}, yw]^2*G[{1/(yu*yv)}, yw])/16 - 
     (G[{0}, yv^(-1)]*G[{1}, yv^(-1)]*G[{1}, yw]^2*G[{1/(yu*yv)}, yw])/16 + 
     (G[{0}, yw]*G[{1}, yv^(-1)]*G[{1}, yw]^2*G[{1/(yu*yv)}, yw])/16 + 
     (35*G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*G[{1}, yw]^2*G[{1/(yu*yv)}, yw])/
      128 + (15*G[{1}, yv^(-1)]^2*G[{1}, yw]^2*G[{1/(yu*yv)}, yw])/256 - 
     (11*G[{0}, yu^(-1)]*G[{1}, yw]^3*G[{1/(yu*yv)}, yw])/96 - 
     (11*G[{0}, yv^(-1)]*G[{1}, yw]^3*G[{1/(yu*yv)}, yw])/96 + 
     (11*G[{0}, yw]*G[{1}, yw]^3*G[{1/(yu*yv)}, yw])/96 - 
     (5*G[{1}, yu^(-1)]*G[{1}, yw]^3*G[{1/(yu*yv)}, yw])/192 + 
     (G[{1}, yv^(-1)]*G[{1}, yw]^3*G[{1/(yu*yv)}, yw])/48 - 
     (15*G[{1}, yw]^4*G[{1/(yu*yv)}, yw])/256 + 
     (Pi^2*G[{0}, yu^(-1)]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw])/96 + 
     (Pi^2*G[{0}, yv^(-1)]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw])/96 - 
     (Pi^2*G[{0}, yw]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw])/96 - 
     (Pi^2*G[{1}, yu^(-1)]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw])/96 + 
     (G[{0}, yu^(-1)]^2*G[{1}, yu^(-1)]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw])/
      32 + (G[{0}, yu^(-1)]*G[{0}, yv^(-1)]*G[{1}, yu^(-1)]*G[{yu^(-1)}, yw]*
       G[{1/(yu*yv)}, yw])/16 + (G[{0}, yv^(-1)]^2*G[{1}, yu^(-1)]*
       G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw])/32 - 
     (G[{0}, yu^(-1)]*G[{0}, yw]*G[{1}, yu^(-1)]*G[{yu^(-1)}, yw]*
       G[{1/(yu*yv)}, yw])/16 - (G[{0}, yv^(-1)]*G[{0}, yw]*G[{1}, yu^(-1)]*
       G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw])/16 + 
     (G[{0}, yw]^2*G[{1}, yu^(-1)]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw])/32 + 
     (G[{0}, yu^(-1)]*G[{1}, yu^(-1)]^2*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw])/
      32 + (G[{0}, yv^(-1)]*G[{1}, yu^(-1)]^2*G[{yu^(-1)}, yw]*
       G[{1/(yu*yv)}, yw])/32 - (G[{0}, yw]*G[{1}, yu^(-1)]^2*
       G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw])/32 - 
     (5*G[{1}, yu^(-1)]^3*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw])/128 - 
     (G[{0}, yu^(-1)]^2*G[{1}, yv^(-1)]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw])/
      32 - (G[{0}, yu^(-1)]*G[{0}, yv^(-1)]*G[{1}, yv^(-1)]*G[{yu^(-1)}, yw]*
       G[{1/(yu*yv)}, yw])/16 - (G[{0}, yv^(-1)]^2*G[{1}, yv^(-1)]*
       G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw])/32 + 
     (G[{0}, yu^(-1)]*G[{0}, yw]*G[{1}, yv^(-1)]*G[{yu^(-1)}, yw]*
       G[{1/(yu*yv)}, yw])/16 + (G[{0}, yv^(-1)]*G[{0}, yw]*G[{1}, yv^(-1)]*
       G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw])/16 - 
     (G[{0}, yw]^2*G[{1}, yv^(-1)]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw])/32 - 
     (G[{0}, yu^(-1)]*G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*G[{yu^(-1)}, yw]*
       G[{1/(yu*yv)}, yw])/16 - (G[{0}, yv^(-1)]*G[{1}, yu^(-1)]*
       G[{1}, yv^(-1)]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw])/16 + 
     (G[{0}, yw]*G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*G[{yu^(-1)}, yw]*
       G[{1/(yu*yv)}, yw])/16 - (5*G[{1}, yu^(-1)]^2*G[{1}, yv^(-1)]*
       G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw])/128 + 
     (G[{0}, yu^(-1)]*G[{1}, yv^(-1)]^2*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw])/
      16 + (G[{0}, yv^(-1)]*G[{1}, yv^(-1)]^2*G[{yu^(-1)}, yw]*
       G[{1/(yu*yv)}, yw])/16 - (G[{0}, yw]*G[{1}, yv^(-1)]^2*
       G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw])/16 + 
     (11*G[{1}, yu^(-1)]*G[{1}, yv^(-1)]^2*G[{yu^(-1)}, yw]*
       G[{1/(yu*yv)}, yw])/128 - (G[{1}, yv^(-1)]^3*G[{yu^(-1)}, yw]*
       G[{1/(yu*yv)}, yw])/32 + (Pi^2*G[{1}, yw]*G[{yu^(-1)}, yw]*
       G[{1/(yu*yv)}, yw])/48 - (G[{0}, yu^(-1)]^2*G[{1}, yw]*
       G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw])/32 - 
     (G[{0}, yu^(-1)]*G[{0}, yv^(-1)]*G[{1}, yw]*G[{yu^(-1)}, yw]*
       G[{1/(yu*yv)}, yw])/16 - (G[{0}, yv^(-1)]^2*G[{1}, yw]*
       G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw])/32 + 
     (G[{0}, yu^(-1)]*G[{0}, yw]*G[{1}, yw]*G[{yu^(-1)}, yw]*
       G[{1/(yu*yv)}, yw])/16 + (G[{0}, yv^(-1)]*G[{0}, yw]*G[{1}, yw]*
       G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw])/16 - 
     (G[{0}, yw]^2*G[{1}, yw]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw])/32 + 
     (G[{0}, yu^(-1)]*G[{1}, yu^(-1)]*G[{1}, yw]*G[{yu^(-1)}, yw]*
       G[{1/(yu*yv)}, yw])/16 + (G[{0}, yv^(-1)]*G[{1}, yu^(-1)]*G[{1}, yw]*
       G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw])/16 - 
     (G[{0}, yw]*G[{1}, yu^(-1)]*G[{1}, yw]*G[{yu^(-1)}, yw]*
       G[{1/(yu*yv)}, yw])/16 - (3*G[{1}, yu^(-1)]^2*G[{1}, yw]*
       G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw])/128 - 
     (3*G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*G[{1}, yw]*G[{yu^(-1)}, yw]*
       G[{1/(yu*yv)}, yw])/64 + (G[{1}, yv^(-1)]^2*G[{1}, yw]*
       G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw])/32 - 
     (G[{0}, yu^(-1)]*G[{1}, yw]^2*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw])/16 - 
     (G[{0}, yv^(-1)]*G[{1}, yw]^2*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw])/16 + 
     (G[{0}, yw]*G[{1}, yw]^2*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw])/16 + 
     (G[{1}, yu^(-1)]*G[{1}, yw]^2*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw])/128 - 
     (5*G[{1}, yw]^3*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw])/128 - 
     (Pi^2*G[{yu^(-1)}, yw]^2*G[{1/(yu*yv)}, yw])/192 + 
     (G[{0}, yu^(-1)]^2*G[{yu^(-1)}, yw]^2*G[{1/(yu*yv)}, yw])/32 + 
     (G[{0}, yu^(-1)]*G[{0}, yv^(-1)]*G[{yu^(-1)}, yw]^2*G[{1/(yu*yv)}, yw])/
      16 + (G[{0}, yv^(-1)]^2*G[{yu^(-1)}, yw]^2*G[{1/(yu*yv)}, yw])/32 - 
     (G[{0}, yu^(-1)]*G[{0}, yw]*G[{yu^(-1)}, yw]^2*G[{1/(yu*yv)}, yw])/16 - 
     (G[{0}, yv^(-1)]*G[{0}, yw]*G[{yu^(-1)}, yw]^2*G[{1/(yu*yv)}, yw])/16 + 
     (G[{0}, yw]^2*G[{yu^(-1)}, yw]^2*G[{1/(yu*yv)}, yw])/32 + 
     (G[{0}, yu^(-1)]*G[{1}, yu^(-1)]*G[{yu^(-1)}, yw]^2*G[{1/(yu*yv)}, yw])/
      16 + (G[{0}, yv^(-1)]*G[{1}, yu^(-1)]*G[{yu^(-1)}, yw]^2*
       G[{1/(yu*yv)}, yw])/16 - (G[{0}, yw]*G[{1}, yu^(-1)]*
       G[{yu^(-1)}, yw]^2*G[{1/(yu*yv)}, yw])/16 - 
     (G[{1}, yu^(-1)]^2*G[{yu^(-1)}, yw]^2*G[{1/(yu*yv)}, yw])/64 - 
     (G[{0}, yu^(-1)]*G[{1}, yv^(-1)]*G[{yu^(-1)}, yw]^2*G[{1/(yu*yv)}, yw])/
      16 - (G[{0}, yv^(-1)]*G[{1}, yv^(-1)]*G[{yu^(-1)}, yw]^2*
       G[{1/(yu*yv)}, yw])/16 + (G[{0}, yw]*G[{1}, yv^(-1)]*
       G[{yu^(-1)}, yw]^2*G[{1/(yu*yv)}, yw])/16 - 
     (3*G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*G[{yu^(-1)}, yw]^2*
       G[{1/(yu*yv)}, yw])/32 + (G[{1}, yv^(-1)]^2*G[{yu^(-1)}, yw]^2*
       G[{1/(yu*yv)}, yw])/32 + (G[{0}, yu^(-1)]*G[{1}, yw]*
       G[{yu^(-1)}, yw]^2*G[{1/(yu*yv)}, yw])/16 + 
     (G[{0}, yv^(-1)]*G[{1}, yw]*G[{yu^(-1)}, yw]^2*G[{1/(yu*yv)}, yw])/16 - 
     (G[{0}, yw]*G[{1}, yw]*G[{yu^(-1)}, yw]^2*G[{1/(yu*yv)}, yw])/16 + 
     (3*G[{1}, yu^(-1)]*G[{1}, yw]*G[{yu^(-1)}, yw]^2*G[{1/(yu*yv)}, yw])/
      32 - (G[{1}, yv^(-1)]*G[{1}, yw]*G[{yu^(-1)}, yw]^2*G[{1/(yu*yv)}, yw])/
      16 + (5*G[{1}, yw]^2*G[{yu^(-1)}, yw]^2*G[{1/(yu*yv)}, yw])/64 + 
     (G[{0}, yu^(-1)]*G[{yu^(-1)}, yw]^3*G[{1/(yu*yv)}, yw])/24 + 
     (G[{0}, yv^(-1)]*G[{yu^(-1)}, yw]^3*G[{1/(yu*yv)}, yw])/24 - 
     (G[{0}, yw]*G[{yu^(-1)}, yw]^3*G[{1/(yu*yv)}, yw])/24 - 
     (G[{1}, yv^(-1)]*G[{yu^(-1)}, yw]^3*G[{1/(yu*yv)}, yw])/48 + 
     (G[{1}, yw]*G[{yu^(-1)}, yw]^3*G[{1/(yu*yv)}, yw])/16 + 
     (G[{yu^(-1)}, yw]^4*G[{1/(yu*yv)}, yw])/192 - 
     (Pi^2*G[{0}, yu^(-1)]*G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw])/48 - 
     (Pi^2*G[{0}, yv^(-1)]*G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw])/48 + 
     (Pi^2*G[{0}, yw]*G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw])/48 - 
     (7*Pi^2*G[{1}, yu^(-1)]*G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw])/768 + 
     (3*G[{1}, yu^(-1)]^3*G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw])/128 + 
     (Pi^2*G[{1}, yv^(-1)]*G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw])/96 - 
     (11*G[{1}, yu^(-1)]^2*G[{1}, yv^(-1)]*G[{yu}, yv^(-1)]*
       G[{1/(yu*yv)}, yw])/128 + (3*G[{1}, yu^(-1)]*G[{1}, yv^(-1)]^2*
       G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw])/128 - 
     (25*Pi^2*G[{1}, yw]*G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw])/384 + 
     (G[{0}, yu^(-1)]^2*G[{1}, yw]*G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw])/16 + 
     (G[{0}, yu^(-1)]*G[{0}, yv^(-1)]*G[{1}, yw]*G[{yu}, yv^(-1)]*
       G[{1/(yu*yv)}, yw])/8 + (G[{0}, yv^(-1)]^2*G[{1}, yw]*G[{yu}, yv^(-1)]*
       G[{1/(yu*yv)}, yw])/16 - (G[{0}, yu^(-1)]*G[{0}, yw]*G[{1}, yw]*
       G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw])/8 - 
     (G[{0}, yv^(-1)]*G[{0}, yw]*G[{1}, yw]*G[{yu}, yv^(-1)]*
       G[{1/(yu*yv)}, yw])/8 + (G[{0}, yw]^2*G[{1}, yw]*G[{yu}, yv^(-1)]*
       G[{1/(yu*yv)}, yw])/16 + (G[{0}, yu^(-1)]*G[{1}, yu^(-1)]*G[{1}, yw]*
       G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw])/8 + 
     (G[{0}, yv^(-1)]*G[{1}, yu^(-1)]*G[{1}, yw]*G[{yu}, yv^(-1)]*
       G[{1/(yu*yv)}, yw])/8 - (G[{0}, yw]*G[{1}, yu^(-1)]*G[{1}, yw]*
       G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw])/8 - 
     (3*G[{1}, yu^(-1)]^2*G[{1}, yw]*G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw])/
      32 + (G[{0}, yu^(-1)]*G[{1}, yv^(-1)]*G[{1}, yw]*G[{yu}, yv^(-1)]*
       G[{1/(yu*yv)}, yw])/8 + (G[{0}, yv^(-1)]*G[{1}, yv^(-1)]*G[{1}, yw]*
       G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw])/8 - 
     (G[{0}, yw]*G[{1}, yv^(-1)]*G[{1}, yw]*G[{yu}, yv^(-1)]*
       G[{1/(yu*yv)}, yw])/8 - (33*G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*G[{1}, yw]*
       G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw])/64 - 
     (15*G[{1}, yv^(-1)]^2*G[{1}, yw]*G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw])/
      128 + (11*G[{0}, yu^(-1)]*G[{1}, yw]^2*G[{yu}, yv^(-1)]*
       G[{1/(yu*yv)}, yw])/32 + (11*G[{0}, yv^(-1)]*G[{1}, yw]^2*
       G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw])/32 - 
     (11*G[{0}, yw]*G[{1}, yw]^2*G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw])/32 - 
     (G[{1}, yu^(-1)]*G[{1}, yw]^2*G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw])/8 - 
     (13*G[{1}, yv^(-1)]*G[{1}, yw]^2*G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw])/
      128 + (15*G[{1}, yw]^3*G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw])/64 - 
     (Pi^2*G[{yu^(-1)}, yw]*G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw])/96 - 
     (G[{0}, yu^(-1)]*G[{1}, yu^(-1)]*G[{yu^(-1)}, yw]*G[{yu}, yv^(-1)]*
       G[{1/(yu*yv)}, yw])/8 - (G[{0}, yv^(-1)]*G[{1}, yu^(-1)]*
       G[{yu^(-1)}, yw]*G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw])/8 + 
     (G[{0}, yw]*G[{1}, yu^(-1)]*G[{yu^(-1)}, yw]*G[{yu}, yv^(-1)]*
       G[{1/(yu*yv)}, yw])/8 + (3*G[{1}, yu^(-1)]^2*G[{yu^(-1)}, yw]*
       G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw])/32 + 
     (G[{0}, yu^(-1)]*G[{1}, yv^(-1)]*G[{yu^(-1)}, yw]*G[{yu}, yv^(-1)]*
       G[{1/(yu*yv)}, yw])/8 + (G[{0}, yv^(-1)]*G[{1}, yv^(-1)]*
       G[{yu^(-1)}, yw]*G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw])/8 - 
     (G[{0}, yw]*G[{1}, yv^(-1)]*G[{yu^(-1)}, yw]*G[{yu}, yv^(-1)]*
       G[{1/(yu*yv)}, yw])/8 + (G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*
       G[{yu^(-1)}, yw]*G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw])/16 - 
     (G[{1}, yv^(-1)]^2*G[{yu^(-1)}, yw]*G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw])/
      8 + (G[{0}, yu^(-1)]*G[{1}, yw]*G[{yu^(-1)}, yw]*G[{yu}, yv^(-1)]*
       G[{1/(yu*yv)}, yw])/16 + (G[{0}, yv^(-1)]*G[{1}, yw]*G[{yu^(-1)}, yw]*
       G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw])/16 - 
     (G[{0}, yw]*G[{1}, yw]*G[{yu^(-1)}, yw]*G[{yu}, yv^(-1)]*
       G[{1/(yu*yv)}, yw])/16 - (G[{1}, yu^(-1)]*G[{1}, yw]*G[{yu^(-1)}, yw]*
       G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw])/32 + 
     (G[{1}, yv^(-1)]*G[{1}, yw]*G[{yu^(-1)}, yw]*G[{yu}, yv^(-1)]*
       G[{1/(yu*yv)}, yw])/8 + (15*G[{1}, yw]^2*G[{yu^(-1)}, yw]*
       G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw])/128 - 
     (G[{0}, yu^(-1)]*G[{yu^(-1)}, yw]^2*G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw])/
      8 - (G[{0}, yv^(-1)]*G[{yu^(-1)}, yw]^2*G[{yu}, yv^(-1)]*
       G[{1/(yu*yv)}, yw])/8 + (G[{0}, yw]*G[{yu^(-1)}, yw]^2*
       G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw])/8 + 
     (3*G[{1}, yv^(-1)]*G[{yu^(-1)}, yw]^2*G[{yu}, yv^(-1)]*
       G[{1/(yu*yv)}, yw])/16 - (5*G[{1}, yw]*G[{yu^(-1)}, yw]^2*
       G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw])/32 - 
     (G[{yu^(-1)}, yw]^3*G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw])/16 + 
     (31*Pi^2*G[{yu}, yv^(-1)]^2*G[{1/(yu*yv)}, yw])/1536 + 
     (G[{1}, yu^(-1)]^2*G[{yu}, yv^(-1)]^2*G[{1/(yu*yv)}, yw])/128 + 
     (3*G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*G[{yu}, yv^(-1)]^2*
       G[{1/(yu*yv)}, yw])/32 - (3*G[{1}, yv^(-1)]^2*G[{yu}, yv^(-1)]^2*
       G[{1/(yu*yv)}, yw])/128 - (G[{0}, yu^(-1)]*G[{1}, yw]*
       G[{yu}, yv^(-1)]^2*G[{1/(yu*yv)}, yw])/4 - 
     (G[{0}, yv^(-1)]*G[{1}, yw]*G[{yu}, yv^(-1)]^2*G[{1/(yu*yv)}, yw])/4 + 
     (G[{0}, yw]*G[{1}, yw]*G[{yu}, yv^(-1)]^2*G[{1/(yu*yv)}, yw])/4 + 
     (29*G[{1}, yu^(-1)]*G[{1}, yw]*G[{yu}, yv^(-1)]^2*G[{1/(yu*yv)}, yw])/
      128 + (3*G[{1}, yv^(-1)]*G[{1}, yw]*G[{yu}, yv^(-1)]^2*
       G[{1/(yu*yv)}, yw])/16 - (59*G[{1}, yw]^2*G[{yu}, yv^(-1)]^2*
       G[{1/(yu*yv)}, yw])/256 - (G[{1}, yv^(-1)]*G[{yu^(-1)}, yw]*
       G[{yu}, yv^(-1)]^2*G[{1/(yu*yv)}, yw])/16 - 
     (7*G[{1}, yw]*G[{yu^(-1)}, yw]*G[{yu}, yv^(-1)]^2*G[{1/(yu*yv)}, yw])/
      64 + (G[{yu^(-1)}, yw]^2*G[{yu}, yv^(-1)]^2*G[{1/(yu*yv)}, yw])/32 - 
     (7*G[{1}, yu^(-1)]*G[{yu}, yv^(-1)]^3*G[{1/(yu*yv)}, yw])/192 - 
     (G[{1}, yv^(-1)]*G[{yu}, yv^(-1)]^3*G[{1/(yu*yv)}, yw])/48 + 
     (11*G[{1}, yw]*G[{yu}, yv^(-1)]^3*G[{1/(yu*yv)}, yw])/384 + 
     (G[{yu^(-1)}, yw]*G[{yu}, yv^(-1)]^3*G[{1/(yu*yv)}, yw])/48 + 
     (11*G[{yu}, yv^(-1)]^4*G[{1/(yu*yv)}, yw])/768 - 
     (Pi^2*G[{0}, yu^(-1)]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw])/48 - 
     (Pi^2*G[{0}, yv^(-1)]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw])/48 + 
     (Pi^2*G[{0}, yw]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw])/48 + 
     (11*Pi^2*G[{1}, yu^(-1)]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw])/256 - 
     (G[{0}, yu^(-1)]^2*G[{1}, yu^(-1)]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw])/
      32 - (G[{0}, yu^(-1)]*G[{0}, yv^(-1)]*G[{1}, yu^(-1)]*G[{yv^(-1)}, yw]*
       G[{1/(yu*yv)}, yw])/16 - (G[{0}, yv^(-1)]^2*G[{1}, yu^(-1)]*
       G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw])/32 + 
     (G[{0}, yu^(-1)]*G[{0}, yw]*G[{1}, yu^(-1)]*G[{yv^(-1)}, yw]*
       G[{1/(yu*yv)}, yw])/16 + (G[{0}, yv^(-1)]*G[{0}, yw]*G[{1}, yu^(-1)]*
       G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw])/16 - 
     (G[{0}, yw]^2*G[{1}, yu^(-1)]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw])/32 - 
     (G[{0}, yu^(-1)]*G[{1}, yu^(-1)]^2*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw])/
      32 - (G[{0}, yv^(-1)]*G[{1}, yu^(-1)]^2*G[{yv^(-1)}, yw]*
       G[{1/(yu*yv)}, yw])/32 + (G[{0}, yw]*G[{1}, yu^(-1)]^2*
       G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw])/32 + 
     (G[{1}, yu^(-1)]^3*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw])/16 - 
     (Pi^2*G[{1}, yv^(-1)]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw])/96 + 
     (G[{0}, yu^(-1)]^2*G[{1}, yv^(-1)]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw])/
      32 + (G[{0}, yu^(-1)]*G[{0}, yv^(-1)]*G[{1}, yv^(-1)]*G[{yv^(-1)}, yw]*
       G[{1/(yu*yv)}, yw])/16 + (G[{0}, yv^(-1)]^2*G[{1}, yv^(-1)]*
       G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw])/32 - 
     (G[{0}, yu^(-1)]*G[{0}, yw]*G[{1}, yv^(-1)]*G[{yv^(-1)}, yw]*
       G[{1/(yu*yv)}, yw])/16 - (G[{0}, yv^(-1)]*G[{0}, yw]*G[{1}, yv^(-1)]*
       G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw])/16 + 
     (G[{0}, yw]^2*G[{1}, yv^(-1)]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw])/32 + 
     (G[{0}, yu^(-1)]*G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*G[{yv^(-1)}, yw]*
       G[{1/(yu*yv)}, yw])/16 + (G[{0}, yv^(-1)]*G[{1}, yu^(-1)]*
       G[{1}, yv^(-1)]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw])/16 - 
     (G[{0}, yw]*G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*G[{yv^(-1)}, yw]*
       G[{1/(yu*yv)}, yw])/16 - (3*G[{1}, yu^(-1)]^2*G[{1}, yv^(-1)]*
       G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw])/64 - 
     (G[{0}, yu^(-1)]*G[{1}, yv^(-1)]^2*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw])/
      16 - (G[{0}, yv^(-1)]*G[{1}, yv^(-1)]^2*G[{yv^(-1)}, yw]*
       G[{1/(yu*yv)}, yw])/16 + (G[{0}, yw]*G[{1}, yv^(-1)]^2*
       G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw])/16 - 
     (G[{1}, yu^(-1)]*G[{1}, yv^(-1)]^2*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw])/
      16 + (G[{1}, yv^(-1)]^3*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw])/32 + 
     (Pi^2*G[{1}, yw]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw])/768 - 
     (G[{0}, yu^(-1)]^2*G[{1}, yw]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw])/32 - 
     (G[{0}, yu^(-1)]*G[{0}, yv^(-1)]*G[{1}, yw]*G[{yv^(-1)}, yw]*
       G[{1/(yu*yv)}, yw])/16 - (G[{0}, yv^(-1)]^2*G[{1}, yw]*
       G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw])/32 + 
     (G[{0}, yu^(-1)]*G[{0}, yw]*G[{1}, yw]*G[{yv^(-1)}, yw]*
       G[{1/(yu*yv)}, yw])/16 + (G[{0}, yv^(-1)]*G[{0}, yw]*G[{1}, yw]*
       G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw])/16 - 
     (G[{0}, yw]^2*G[{1}, yw]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw])/32 - 
     (3*G[{0}, yu^(-1)]*G[{1}, yu^(-1)]*G[{1}, yw]*G[{yv^(-1)}, yw]*
       G[{1/(yu*yv)}, yw])/16 - (3*G[{0}, yv^(-1)]*G[{1}, yu^(-1)]*G[{1}, yw]*
       G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw])/16 + 
     (3*G[{0}, yw]*G[{1}, yu^(-1)]*G[{1}, yw]*G[{yv^(-1)}, yw]*
       G[{1/(yu*yv)}, yw])/16 + (G[{1}, yu^(-1)]^2*G[{1}, yw]*
       G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw])/8 + 
     (G[{0}, yu^(-1)]*G[{1}, yv^(-1)]*G[{1}, yw]*G[{yv^(-1)}, yw]*
       G[{1/(yu*yv)}, yw])/4 + (G[{0}, yv^(-1)]*G[{1}, yv^(-1)]*G[{1}, yw]*
       G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw])/4 - 
     (G[{0}, yw]*G[{1}, yv^(-1)]*G[{1}, yw]*G[{yv^(-1)}, yw]*
       G[{1/(yu*yv)}, yw])/4 - (G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*G[{1}, yw]*
       G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw])/16 - 
     (11*G[{1}, yv^(-1)]^2*G[{1}, yw]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw])/
      64 - (G[{0}, yu^(-1)]*G[{1}, yw]^2*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw])/
      16 - (G[{0}, yv^(-1)]*G[{1}, yw]^2*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw])/
      16 + (G[{0}, yw]*G[{1}, yw]^2*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw])/16 - 
     (5*G[{1}, yu^(-1)]*G[{1}, yw]^2*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw])/
      64 + (G[{1}, yv^(-1)]*G[{1}, yw]^2*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw])/
      16 - (3*G[{1}, yw]^3*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw])/64 + 
     (7*Pi^2*G[{yu}, yv^(-1)]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw])/768 + 
     (G[{0}, yu^(-1)]*G[{1}, yu^(-1)]*G[{yu}, yv^(-1)]*G[{yv^(-1)}, yw]*
       G[{1/(yu*yv)}, yw])/8 + (G[{0}, yv^(-1)]*G[{1}, yu^(-1)]*
       G[{yu}, yv^(-1)]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw])/8 - 
     (G[{0}, yw]*G[{1}, yu^(-1)]*G[{yu}, yv^(-1)]*G[{yv^(-1)}, yw]*
       G[{1/(yu*yv)}, yw])/8 - (5*G[{1}, yu^(-1)]^2*G[{yu}, yv^(-1)]*
       G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw])/64 - 
     (G[{0}, yu^(-1)]*G[{1}, yv^(-1)]*G[{yu}, yv^(-1)]*G[{yv^(-1)}, yw]*
       G[{1/(yu*yv)}, yw])/8 - (G[{0}, yv^(-1)]*G[{1}, yv^(-1)]*
       G[{yu}, yv^(-1)]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw])/8 + 
     (G[{0}, yw]*G[{1}, yv^(-1)]*G[{yu}, yv^(-1)]*G[{yv^(-1)}, yw]*
       G[{1/(yu*yv)}, yw])/8 + (G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*
       G[{yu}, yv^(-1)]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw])/8 + 
     (5*G[{1}, yv^(-1)]^2*G[{yu}, yv^(-1)]*G[{yv^(-1)}, yw]*
       G[{1/(yu*yv)}, yw])/64 + (G[{0}, yu^(-1)]*G[{1}, yw]*G[{yu}, yv^(-1)]*
       G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw])/16 + 
     (G[{0}, yv^(-1)]*G[{1}, yw]*G[{yu}, yv^(-1)]*G[{yv^(-1)}, yw]*
       G[{1/(yu*yv)}, yw])/16 - (G[{0}, yw]*G[{1}, yw]*G[{yu}, yv^(-1)]*
       G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw])/16 + 
     (3*G[{1}, yu^(-1)]*G[{1}, yw]*G[{yu}, yv^(-1)]*G[{yv^(-1)}, yw]*
       G[{1/(yu*yv)}, yw])/16 - (G[{1}, yv^(-1)]*G[{1}, yw]*G[{yu}, yv^(-1)]*
       G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw])/32 + 
     (9*G[{1}, yw]^2*G[{yu}, yv^(-1)]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw])/
      64 - (7*G[{1}, yu^(-1)]*G[{yu}, yv^(-1)]^2*G[{yv^(-1)}, yw]*
       G[{1/(yu*yv)}, yw])/64 - (9*G[{1}, yw]*G[{yu}, yv^(-1)]^2*
       G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw])/64 + 
     (7*G[{yu}, yv^(-1)]^3*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw])/192 - 
     (41*Pi^2*G[{yv^(-1)}, yw]^2*G[{1/(yu*yv)}, yw])/1536 + 
     (G[{0}, yu^(-1)]^2*G[{yv^(-1)}, yw]^2*G[{1/(yu*yv)}, yw])/32 + 
     (G[{0}, yu^(-1)]*G[{0}, yv^(-1)]*G[{yv^(-1)}, yw]^2*G[{1/(yu*yv)}, yw])/
      16 + (G[{0}, yv^(-1)]^2*G[{yv^(-1)}, yw]^2*G[{1/(yu*yv)}, yw])/32 - 
     (G[{0}, yu^(-1)]*G[{0}, yw]*G[{yv^(-1)}, yw]^2*G[{1/(yu*yv)}, yw])/16 - 
     (G[{0}, yv^(-1)]*G[{0}, yw]*G[{yv^(-1)}, yw]^2*G[{1/(yu*yv)}, yw])/16 + 
     (G[{0}, yw]^2*G[{yv^(-1)}, yw]^2*G[{1/(yu*yv)}, yw])/32 + 
     (G[{0}, yu^(-1)]*G[{1}, yu^(-1)]*G[{yv^(-1)}, yw]^2*G[{1/(yu*yv)}, yw])/
      8 + (G[{0}, yv^(-1)]*G[{1}, yu^(-1)]*G[{yv^(-1)}, yw]^2*
       G[{1/(yu*yv)}, yw])/8 - (G[{0}, yw]*G[{1}, yu^(-1)]*G[{yv^(-1)}, yw]^2*
       G[{1/(yu*yv)}, yw])/8 - (29*G[{1}, yu^(-1)]^2*G[{yv^(-1)}, yw]^2*
       G[{1/(yu*yv)}, yw])/128 - (G[{0}, yu^(-1)]*G[{1}, yv^(-1)]*
       G[{yv^(-1)}, yw]^2*G[{1/(yu*yv)}, yw])/8 - 
     (G[{0}, yv^(-1)]*G[{1}, yv^(-1)]*G[{yv^(-1)}, yw]^2*G[{1/(yu*yv)}, yw])/
      8 + (G[{0}, yw]*G[{1}, yv^(-1)]*G[{yv^(-1)}, yw]^2*G[{1/(yu*yv)}, yw])/
      8 + (G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*G[{yv^(-1)}, yw]^2*
       G[{1/(yu*yv)}, yw])/16 + (9*G[{1}, yv^(-1)]^2*G[{yv^(-1)}, yw]^2*
       G[{1/(yu*yv)}, yw])/128 + (G[{0}, yu^(-1)]*G[{1}, yw]*
       G[{yv^(-1)}, yw]^2*G[{1/(yu*yv)}, yw])/4 + 
     (G[{0}, yv^(-1)]*G[{1}, yw]*G[{yv^(-1)}, yw]^2*G[{1/(yu*yv)}, yw])/4 - 
     (G[{0}, yw]*G[{1}, yw]*G[{yv^(-1)}, yw]^2*G[{1/(yu*yv)}, yw])/4 - 
     (13*G[{1}, yu^(-1)]*G[{1}, yw]*G[{yv^(-1)}, yw]^2*G[{1/(yu*yv)}, yw])/
      64 - (7*G[{1}, yv^(-1)]*G[{1}, yw]*G[{yv^(-1)}, yw]^2*
       G[{1/(yu*yv)}, yw])/64 + (3*G[{1}, yw]^2*G[{yv^(-1)}, yw]^2*
       G[{1/(yu*yv)}, yw])/32 - (G[{0}, yu^(-1)]*G[{yu}, yv^(-1)]*
       G[{yv^(-1)}, yw]^2*G[{1/(yu*yv)}, yw])/8 - 
     (G[{0}, yv^(-1)]*G[{yu}, yv^(-1)]*G[{yv^(-1)}, yw]^2*G[{1/(yu*yv)}, yw])/
      8 + (G[{0}, yw]*G[{yu}, yv^(-1)]*G[{yv^(-1)}, yw]^2*G[{1/(yu*yv)}, yw])/
      8 + (9*G[{1}, yu^(-1)]*G[{yu}, yv^(-1)]*G[{yv^(-1)}, yw]^2*
       G[{1/(yu*yv)}, yw])/64 - (3*G[{1}, yw]*G[{yu}, yv^(-1)]*
       G[{yv^(-1)}, yw]^2*G[{1/(yu*yv)}, yw])/16 + 
     (7*G[{yu}, yv^(-1)]^2*G[{yv^(-1)}, yw]^2*G[{1/(yu*yv)}, yw])/128 - 
     (G[{0}, yu^(-1)]*G[{yv^(-1)}, yw]^3*G[{1/(yu*yv)}, yw])/12 - 
     (G[{0}, yv^(-1)]*G[{yv^(-1)}, yw]^3*G[{1/(yu*yv)}, yw])/12 + 
     (G[{0}, yw]*G[{yv^(-1)}, yw]^3*G[{1/(yu*yv)}, yw])/12 + 
     (41*G[{1}, yu^(-1)]*G[{yv^(-1)}, yw]^3*G[{1/(yu*yv)}, yw])/192 + 
     (3*G[{1}, yw]*G[{yv^(-1)}, yw]^3*G[{1/(yu*yv)}, yw])/64 - 
     (3*G[{yu}, yv^(-1)]*G[{yv^(-1)}, yw]^3*G[{1/(yu*yv)}, yw])/64 - 
     (41*G[{yv^(-1)}, yw]^4*G[{1/(yu*yv)}, yw])/768 - 
     (11*Pi^2*G[{1}, yu^(-1)]*G[{1/(yu*yv)}, yw]^2)/1536 + 
     (G[{0}, yu^(-1)]^2*G[{1}, yu^(-1)]*G[{1/(yu*yv)}, yw]^2)/64 + 
     (G[{0}, yu^(-1)]*G[{0}, yv^(-1)]*G[{1}, yu^(-1)]*G[{1/(yu*yv)}, yw]^2)/
      32 + (G[{0}, yv^(-1)]^2*G[{1}, yu^(-1)]*G[{1/(yu*yv)}, yw]^2)/64 - 
     (G[{0}, yu^(-1)]*G[{0}, yw]*G[{1}, yu^(-1)]*G[{1/(yu*yv)}, yw]^2)/32 - 
     (G[{0}, yv^(-1)]*G[{0}, yw]*G[{1}, yu^(-1)]*G[{1/(yu*yv)}, yw]^2)/32 + 
     (G[{0}, yw]^2*G[{1}, yu^(-1)]*G[{1/(yu*yv)}, yw]^2)/64 + 
     (G[{0}, yu^(-1)]*G[{1}, yu^(-1)]^2*G[{1/(yu*yv)}, yw]^2)/64 + 
     (G[{0}, yv^(-1)]*G[{1}, yu^(-1)]^2*G[{1/(yu*yv)}, yw]^2)/64 - 
     (G[{0}, yw]*G[{1}, yu^(-1)]^2*G[{1/(yu*yv)}, yw]^2)/64 - 
     (G[{1}, yu^(-1)]^3*G[{1/(yu*yv)}, yw]^2)/32 - 
     (Pi^2*G[{1}, yv^(-1)]*G[{1/(yu*yv)}, yw]^2)/192 + 
     (G[{0}, yu^(-1)]^2*G[{1}, yv^(-1)]*G[{1/(yu*yv)}, yw]^2)/64 + 
     (G[{0}, yu^(-1)]*G[{0}, yv^(-1)]*G[{1}, yv^(-1)]*G[{1/(yu*yv)}, yw]^2)/
      32 + (G[{0}, yv^(-1)]^2*G[{1}, yv^(-1)]*G[{1/(yu*yv)}, yw]^2)/64 - 
     (G[{0}, yu^(-1)]*G[{0}, yw]*G[{1}, yv^(-1)]*G[{1/(yu*yv)}, yw]^2)/32 - 
     (G[{0}, yv^(-1)]*G[{0}, yw]*G[{1}, yv^(-1)]*G[{1/(yu*yv)}, yw]^2)/32 + 
     (G[{0}, yw]^2*G[{1}, yv^(-1)]*G[{1/(yu*yv)}, yw]^2)/64 - 
     (G[{0}, yu^(-1)]*G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*G[{1/(yu*yv)}, yw]^2)/
      32 - (G[{0}, yv^(-1)]*G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*
       G[{1/(yu*yv)}, yw]^2)/32 + (G[{0}, yw]*G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*
       G[{1/(yu*yv)}, yw]^2)/32 + (3*G[{1}, yu^(-1)]^2*G[{1}, yv^(-1)]*
       G[{1/(yu*yv)}, yw]^2)/128 - (G[{0}, yu^(-1)]*G[{1}, yv^(-1)]^2*
       G[{1/(yu*yv)}, yw]^2)/32 - (G[{0}, yv^(-1)]*G[{1}, yv^(-1)]^2*
       G[{1/(yu*yv)}, yw]^2)/32 + (G[{0}, yw]*G[{1}, yv^(-1)]^2*
       G[{1/(yu*yv)}, yw]^2)/32 - (5*G[{1}, yu^(-1)]*G[{1}, yv^(-1)]^2*
       G[{1/(yu*yv)}, yw]^2)/256 + (G[{1}, yv^(-1)]^3*G[{1/(yu*yv)}, yw]^2)/
      64 - (19*Pi^2*G[{1}, yw]*G[{1/(yu*yv)}, yw]^2)/1536 + 
     (G[{0}, yu^(-1)]^2*G[{1}, yw]*G[{1/(yu*yv)}, yw]^2)/32 + 
     (G[{0}, yu^(-1)]*G[{0}, yv^(-1)]*G[{1}, yw]*G[{1/(yu*yv)}, yw]^2)/16 + 
     (G[{0}, yv^(-1)]^2*G[{1}, yw]*G[{1/(yu*yv)}, yw]^2)/32 - 
     (G[{0}, yu^(-1)]*G[{0}, yw]*G[{1}, yw]*G[{1/(yu*yv)}, yw]^2)/16 - 
     (G[{0}, yv^(-1)]*G[{0}, yw]*G[{1}, yw]*G[{1/(yu*yv)}, yw]^2)/16 + 
     (G[{0}, yw]^2*G[{1}, yw]*G[{1/(yu*yv)}, yw]^2)/32 + 
     (3*G[{0}, yu^(-1)]*G[{1}, yu^(-1)]*G[{1}, yw]*G[{1/(yu*yv)}, yw]^2)/32 + 
     (3*G[{0}, yv^(-1)]*G[{1}, yu^(-1)]*G[{1}, yw]*G[{1/(yu*yv)}, yw]^2)/32 - 
     (3*G[{0}, yw]*G[{1}, yu^(-1)]*G[{1}, yw]*G[{1/(yu*yv)}, yw]^2)/32 - 
     (9*G[{1}, yu^(-1)]^2*G[{1}, yw]*G[{1/(yu*yv)}, yw]^2)/128 - 
     (3*G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*G[{1}, yw]*G[{1/(yu*yv)}, yw]^2)/32 - 
     (5*G[{1}, yv^(-1)]^2*G[{1}, yw]*G[{1/(yu*yv)}, yw]^2)/256 + 
     (7*G[{0}, yu^(-1)]*G[{1}, yw]^2*G[{1/(yu*yv)}, yw]^2)/64 + 
     (7*G[{0}, yv^(-1)]*G[{1}, yw]^2*G[{1/(yu*yv)}, yw]^2)/64 - 
     (7*G[{0}, yw]*G[{1}, yw]^2*G[{1/(yu*yv)}, yw]^2)/64 + 
     (3*G[{1}, yu^(-1)]*G[{1}, yw]^2*G[{1/(yu*yv)}, yw]^2)/256 - 
     (G[{1}, yv^(-1)]*G[{1}, yw]^2*G[{1/(yu*yv)}, yw]^2)/32 + 
     (17*G[{1}, yw]^3*G[{1/(yu*yv)}, yw]^2)/256 + 
     (Pi^2*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2)/192 - 
     (G[{0}, yu^(-1)]^2*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2)/64 - 
     (G[{0}, yu^(-1)]*G[{0}, yv^(-1)]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2)/
      32 - (G[{0}, yv^(-1)]^2*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2)/64 + 
     (G[{0}, yu^(-1)]*G[{0}, yw]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2)/32 + 
     (G[{0}, yv^(-1)]*G[{0}, yw]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2)/32 - 
     (G[{0}, yw]^2*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2)/64 + 
     (G[{1}, yu^(-1)]^2*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2)/128 + 
     (5*G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*G[{yu^(-1)}, yw]*
       G[{1/(yu*yv)}, yw]^2)/64 + (G[{1}, yv^(-1)]^2*G[{yu^(-1)}, yw]*
       G[{1/(yu*yv)}, yw]^2)/64 - (G[{0}, yu^(-1)]*G[{1}, yw]*
       G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2)/16 - 
     (G[{0}, yv^(-1)]*G[{1}, yw]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2)/16 + 
     (G[{0}, yw]*G[{1}, yw]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2)/16 + 
     (5*G[{1}, yu^(-1)]*G[{1}, yw]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2)/
      64 + (3*G[{1}, yv^(-1)]*G[{1}, yw]*G[{yu^(-1)}, yw]*
       G[{1/(yu*yv)}, yw]^2)/32 + (3*G[{1}, yw]^2*G[{yu^(-1)}, yw]*
       G[{1/(yu*yv)}, yw]^2)/128 - (G[{1}, yu^(-1)]*G[{yu^(-1)}, yw]^2*
       G[{1/(yu*yv)}, yw]^2)/32 - (3*G[{1}, yv^(-1)]*G[{yu^(-1)}, yw]^2*
       G[{1/(yu*yv)}, yw]^2)/64 - (5*G[{1}, yw]*G[{yu^(-1)}, yw]^2*
       G[{1/(yu*yv)}, yw]^2)/64 + (G[{yu^(-1)}, yw]^3*G[{1/(yu*yv)}, yw]^2)/
      64 + (19*Pi^2*G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw]^2)/1536 - 
     (G[{0}, yu^(-1)]^2*G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw]^2)/32 - 
     (G[{0}, yu^(-1)]*G[{0}, yv^(-1)]*G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw]^2)/
      16 - (G[{0}, yv^(-1)]^2*G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw]^2)/32 + 
     (G[{0}, yu^(-1)]*G[{0}, yw]*G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw]^2)/16 + 
     (G[{0}, yv^(-1)]*G[{0}, yw]*G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw]^2)/16 - 
     (G[{0}, yw]^2*G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw]^2)/32 - 
     (G[{0}, yu^(-1)]*G[{1}, yu^(-1)]*G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw]^2)/
      16 - (G[{0}, yv^(-1)]*G[{1}, yu^(-1)]*G[{yu}, yv^(-1)]*
       G[{1/(yu*yv)}, yw]^2)/16 + (G[{0}, yw]*G[{1}, yu^(-1)]*
       G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw]^2)/16 + 
     (5*G[{1}, yu^(-1)]^2*G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw]^2)/128 - 
     (G[{0}, yu^(-1)]*G[{1}, yv^(-1)]*G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw]^2)/
      16 - (G[{0}, yv^(-1)]*G[{1}, yv^(-1)]*G[{yu}, yv^(-1)]*
       G[{1/(yu*yv)}, yw]^2)/16 + (G[{0}, yw]*G[{1}, yv^(-1)]*
       G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw]^2)/16 + 
     (21*G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*G[{yu}, yv^(-1)]*
       G[{1/(yu*yv)}, yw]^2)/128 + (21*G[{1}, yv^(-1)]^2*G[{yu}, yv^(-1)]*
       G[{1/(yu*yv)}, yw]^2)/256 - (7*G[{0}, yu^(-1)]*G[{1}, yw]*
       G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw]^2)/32 - 
     (7*G[{0}, yv^(-1)]*G[{1}, yw]*G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw]^2)/
      32 + (7*G[{0}, yw]*G[{1}, yw]*G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw]^2)/
      32 + (3*G[{1}, yu^(-1)]*G[{1}, yw]*G[{yu}, yv^(-1)]*
       G[{1/(yu*yv)}, yw]^2)/64 + (7*G[{1}, yv^(-1)]*G[{1}, yw]*
       G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw]^2)/128 - 
     (51*G[{1}, yw]^2*G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw]^2)/256 + 
     (G[{0}, yu^(-1)]*G[{yu^(-1)}, yw]*G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw]^2)/
      16 + (G[{0}, yv^(-1)]*G[{yu^(-1)}, yw]*G[{yu}, yv^(-1)]*
       G[{1/(yu*yv)}, yw]^2)/16 - (G[{0}, yw]*G[{yu^(-1)}, yw]*
       G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw]^2)/16 - 
     (3*G[{1}, yu^(-1)]*G[{yu^(-1)}, yw]*G[{yu}, yv^(-1)]*
       G[{1/(yu*yv)}, yw]^2)/32 - (5*G[{1}, yv^(-1)]*G[{yu^(-1)}, yw]*
       G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw]^2)/32 - 
     (3*G[{1}, yw]*G[{yu^(-1)}, yw]*G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw]^2)/
      64 + (5*G[{yu^(-1)}, yw]^2*G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw]^2)/64 + 
     (G[{0}, yu^(-1)]*G[{yu}, yv^(-1)]^2*G[{1/(yu*yv)}, yw]^2)/8 + 
     (G[{0}, yv^(-1)]*G[{yu}, yv^(-1)]^2*G[{1/(yu*yv)}, yw]^2)/8 - 
     (G[{0}, yw]*G[{yu}, yv^(-1)]^2*G[{1/(yu*yv)}, yw]^2)/8 - 
     (15*G[{1}, yu^(-1)]*G[{yu}, yv^(-1)]^2*G[{1/(yu*yv)}, yw]^2)/256 - 
     (G[{1}, yv^(-1)]*G[{yu}, yv^(-1)]^2*G[{1/(yu*yv)}, yw]^2)/16 + 
     (43*G[{1}, yw]*G[{yu}, yv^(-1)]^2*G[{1/(yu*yv)}, yw]^2)/256 + 
     (G[{yu^(-1)}, yw]*G[{yu}, yv^(-1)]^2*G[{1/(yu*yv)}, yw]^2)/16 - 
     (11*G[{yu}, yv^(-1)]^3*G[{1/(yu*yv)}, yw]^2)/256 + 
     (11*Pi^2*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2)/1536 - 
     (G[{0}, yu^(-1)]^2*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2)/64 - 
     (G[{0}, yu^(-1)]*G[{0}, yv^(-1)]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2)/
      32 - (G[{0}, yv^(-1)]^2*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2)/64 + 
     (G[{0}, yu^(-1)]*G[{0}, yw]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2)/32 + 
     (G[{0}, yv^(-1)]*G[{0}, yw]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2)/32 - 
     (G[{0}, yw]^2*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2)/64 + 
     (G[{1}, yu^(-1)]^2*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2)/16 + 
     (3*G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*G[{yv^(-1)}, yw]*
       G[{1/(yu*yv)}, yw]^2)/128 + (G[{1}, yv^(-1)]^2*G[{yv^(-1)}, yw]*
       G[{1/(yu*yv)}, yw]^2)/256 - (G[{0}, yu^(-1)]*G[{1}, yw]*
       G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2)/16 - 
     (G[{0}, yv^(-1)]*G[{1}, yw]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2)/16 + 
     (G[{0}, yw]*G[{1}, yw]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2)/16 + 
     (5*G[{1}, yu^(-1)]*G[{1}, yw]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2)/
      32 + (5*G[{1}, yv^(-1)]*G[{1}, yw]*G[{yv^(-1)}, yw]*
       G[{1/(yu*yv)}, yw]^2)/128 + (9*G[{1}, yw]^2*G[{yv^(-1)}, yw]*
       G[{1/(yu*yv)}, yw]^2)/256 - (G[{1}, yu^(-1)]*G[{yu^(-1)}, yw]*
       G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2)/32 - 
     (G[{1}, yv^(-1)]*G[{yu^(-1)}, yw]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2)/
      16 - (3*G[{1}, yw]*G[{yu^(-1)}, yw]*G[{yv^(-1)}, yw]*
       G[{1/(yu*yv)}, yw]^2)/32 + (G[{yu^(-1)}, yw]^2*G[{yv^(-1)}, yw]*
       G[{1/(yu*yv)}, yw]^2)/32 + (G[{0}, yu^(-1)]*G[{yu}, yv^(-1)]*
       G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2)/16 + 
     (G[{0}, yv^(-1)]*G[{yu}, yv^(-1)]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2)/
      16 - (G[{0}, yw]*G[{yu}, yv^(-1)]*G[{yv^(-1)}, yw]*
       G[{1/(yu*yv)}, yw]^2)/16 - (19*G[{1}, yu^(-1)]*G[{yu}, yv^(-1)]*
       G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2)/128 - 
     (3*G[{1}, yv^(-1)]*G[{yu}, yv^(-1)]*G[{yv^(-1)}, yw]*
       G[{1/(yu*yv)}, yw]^2)/32 - (9*G[{1}, yw]*G[{yu}, yv^(-1)]*
       G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2)/128 + 
     (3*G[{yu^(-1)}, yw]*G[{yu}, yv^(-1)]*G[{yv^(-1)}, yw]*
       G[{1/(yu*yv)}, yw]^2)/32 + (15*G[{yu}, yv^(-1)]^2*G[{yv^(-1)}, yw]*
       G[{1/(yu*yv)}, yw]^2)/256 - (15*G[{1}, yu^(-1)]*G[{yv^(-1)}, yw]^2*
       G[{1/(yu*yv)}, yw]^2)/256 - (G[{1}, yv^(-1)]*G[{yv^(-1)}, yw]^2*
       G[{1/(yu*yv)}, yw]^2)/64 - (19*G[{1}, yw]*G[{yv^(-1)}, yw]^2*
       G[{1/(yu*yv)}, yw]^2)/256 + (G[{yu^(-1)}, yw]*G[{yv^(-1)}, yw]^2*
       G[{1/(yu*yv)}, yw]^2)/64 + (19*G[{yu}, yv^(-1)]*G[{yv^(-1)}, yw]^2*
       G[{1/(yu*yv)}, yw]^2)/256 + (5*G[{yv^(-1)}, yw]^3*
       G[{1/(yu*yv)}, yw]^2)/256 - (G[{0}, yu^(-1)]*G[{1}, yu^(-1)]*
       G[{1/(yu*yv)}, yw]^3)/96 - (G[{0}, yv^(-1)]*G[{1}, yu^(-1)]*
       G[{1/(yu*yv)}, yw]^3)/96 + (G[{0}, yw]*G[{1}, yu^(-1)]*
       G[{1/(yu*yv)}, yw]^3)/96 + (G[{1}, yu^(-1)]^2*G[{1/(yu*yv)}, yw]^3)/
      96 + (G[{0}, yu^(-1)]*G[{1}, yv^(-1)]*G[{1/(yu*yv)}, yw]^3)/48 + 
     (G[{0}, yv^(-1)]*G[{1}, yv^(-1)]*G[{1/(yu*yv)}, yw]^3)/48 - 
     (G[{0}, yw]*G[{1}, yv^(-1)]*G[{1/(yu*yv)}, yw]^3)/48 - 
     (3*G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*G[{1/(yu*yv)}, yw]^3)/128 - 
     (G[{1}, yv^(-1)]^2*G[{1/(yu*yv)}, yw]^3)/48 + 
     (G[{0}, yu^(-1)]*G[{1}, yw]*G[{1/(yu*yv)}, yw]^3)/96 + 
     (G[{0}, yv^(-1)]*G[{1}, yw]*G[{1/(yu*yv)}, yw]^3)/96 - 
     (G[{0}, yw]*G[{1}, yw]*G[{1/(yu*yv)}, yw]^3)/96 - 
     (3*G[{1}, yu^(-1)]*G[{1}, yw]*G[{1/(yu*yv)}, yw]^3)/128 - 
     (3*G[{1}, yv^(-1)]*G[{1}, yw]*G[{1/(yu*yv)}, yw]^3)/128 - 
     (5*G[{1}, yw]^2*G[{1/(yu*yv)}, yw]^3)/384 - 
     (G[{0}, yu^(-1)]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]^3)/48 - 
     (G[{0}, yv^(-1)]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]^3)/48 + 
     (G[{0}, yw]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]^3)/48 + 
     (3*G[{1}, yu^(-1)]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]^3)/128 + 
     (G[{1}, yv^(-1)]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]^3)/24 + 
     (3*G[{1}, yw]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]^3)/128 - 
     (G[{yu^(-1)}, yw]^2*G[{1/(yu*yv)}, yw]^3)/48 - 
     (G[{0}, yu^(-1)]*G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw]^3)/96 - 
     (G[{0}, yv^(-1)]*G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw]^3)/96 + 
     (G[{0}, yw]*G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw]^3)/96 + 
     (3*G[{1}, yu^(-1)]*G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw]^3)/128 + 
     (3*G[{1}, yv^(-1)]*G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw]^3)/128 + 
     (5*G[{1}, yw]*G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw]^3)/192 - 
     (3*G[{yu^(-1)}, yw]*G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw]^3)/128 - 
     (5*G[{yu}, yv^(-1)]^2*G[{1/(yu*yv)}, yw]^3)/384 + 
     (G[{0}, yu^(-1)]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]^3)/96 + 
     (G[{0}, yv^(-1)]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]^3)/96 - 
     (G[{0}, yw]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]^3)/96 - 
     (G[{1}, yu^(-1)]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]^3)/48 + 
     (3*G[{1}, yv^(-1)]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]^3)/128 + 
     (3*G[{1}, yw]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]^3)/128 - 
     (3*G[{yu^(-1)}, yw]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]^3)/128 - 
     (3*G[{yu}, yv^(-1)]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]^3)/128 + 
     (G[{yv^(-1)}, yw]^2*G[{1/(yu*yv)}, yw]^3)/96 - 
     (13*Pi^2*G[{1}, yu^(-1)]*G[{0, 1}, yu^(-1)])/768 + 
     (11*G[{1}, yu^(-1)]^3*G[{0, 1}, yu^(-1)])/384 + 
     (13*Pi^2*G[{1}, yv^(-1)]*G[{0, 1}, yu^(-1)])/768 - 
     (11*G[{1}, yu^(-1)]^2*G[{1}, yv^(-1)]*G[{0, 1}, yu^(-1)])/128 + 
     (5*G[{1}, yu^(-1)]*G[{1}, yv^(-1)]^2*G[{0, 1}, yu^(-1)])/64 - 
     (G[{1}, yv^(-1)]^3*G[{0, 1}, yu^(-1)])/128 + 
     (11*Pi^2*G[{1}, yw]*G[{0, 1}, yu^(-1)])/768 - 
     (G[{0}, yu^(-1)]^2*G[{1}, yw]*G[{0, 1}, yu^(-1)])/32 - 
     (G[{0}, yu^(-1)]*G[{0}, yv^(-1)]*G[{1}, yw]*G[{0, 1}, yu^(-1)])/16 - 
     (G[{0}, yv^(-1)]^2*G[{1}, yw]*G[{0, 1}, yu^(-1)])/32 + 
     (G[{0}, yu^(-1)]*G[{0}, yw]*G[{1}, yw]*G[{0, 1}, yu^(-1)])/16 + 
     (G[{0}, yv^(-1)]*G[{0}, yw]*G[{1}, yw]*G[{0, 1}, yu^(-1)])/16 - 
     (G[{0}, yw]^2*G[{1}, yw]*G[{0, 1}, yu^(-1)])/32 - 
     (G[{0}, yu^(-1)]*G[{1}, yu^(-1)]*G[{1}, yw]*G[{0, 1}, yu^(-1)])/8 - 
     (G[{0}, yv^(-1)]*G[{1}, yu^(-1)]*G[{1}, yw]*G[{0, 1}, yu^(-1)])/8 + 
     (G[{0}, yw]*G[{1}, yu^(-1)]*G[{1}, yw]*G[{0, 1}, yu^(-1)])/8 + 
     (11*G[{1}, yu^(-1)]^2*G[{1}, yw]*G[{0, 1}, yu^(-1)])/128 + 
     (G[{0}, yu^(-1)]*G[{1}, yv^(-1)]*G[{1}, yw]*G[{0, 1}, yu^(-1)])/16 + 
     (G[{0}, yv^(-1)]*G[{1}, yv^(-1)]*G[{1}, yw]*G[{0, 1}, yu^(-1)])/16 - 
     (G[{0}, yw]*G[{1}, yv^(-1)]*G[{1}, yw]*G[{0, 1}, yu^(-1)])/16 - 
     (G[{1}, yv^(-1)]^2*G[{1}, yw]*G[{0, 1}, yu^(-1)])/128 - 
     (3*G[{0}, yu^(-1)]*G[{1}, yw]^2*G[{0, 1}, yu^(-1)])/32 - 
     (3*G[{0}, yv^(-1)]*G[{1}, yw]^2*G[{0, 1}, yu^(-1)])/32 + 
     (3*G[{0}, yw]*G[{1}, yw]^2*G[{0, 1}, yu^(-1)])/32 - 
     (G[{1}, yu^(-1)]*G[{1}, yw]^2*G[{0, 1}, yu^(-1)])/32 + 
     (7*G[{1}, yv^(-1)]*G[{1}, yw]^2*G[{0, 1}, yu^(-1)])/128 - 
     (13*G[{1}, yw]^3*G[{0, 1}, yu^(-1)])/192 + 
     (G[{0}, yu^(-1)]*G[{1}, yw]*G[{yu}, yv^(-1)]*G[{0, 1}, yu^(-1)])/8 + 
     (G[{0}, yv^(-1)]*G[{1}, yw]*G[{yu}, yv^(-1)]*G[{0, 1}, yu^(-1)])/8 - 
     (G[{0}, yw]*G[{1}, yw]*G[{yu}, yv^(-1)]*G[{0, 1}, yu^(-1)])/8 + 
     (5*G[{1}, yu^(-1)]*G[{1}, yw]*G[{yu}, yv^(-1)]*G[{0, 1}, yu^(-1)])/64 - 
     (9*G[{1}, yv^(-1)]*G[{1}, yw]*G[{yu}, yv^(-1)]*G[{0, 1}, yu^(-1)])/64 + 
     (21*G[{1}, yw]^2*G[{yu}, yv^(-1)]*G[{0, 1}, yu^(-1)])/128 - 
     (3*G[{1}, yw]*G[{yu}, yv^(-1)]^2*G[{0, 1}, yu^(-1)])/32 - 
     (11*Pi^2*G[{1/(yu*yv)}, yw]*G[{0, 1}, yu^(-1)])/768 + 
     (G[{0}, yu^(-1)]^2*G[{1/(yu*yv)}, yw]*G[{0, 1}, yu^(-1)])/32 + 
     (G[{0}, yu^(-1)]*G[{0}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, 1}, yu^(-1)])/
      16 + (G[{0}, yv^(-1)]^2*G[{1/(yu*yv)}, yw]*G[{0, 1}, yu^(-1)])/32 - 
     (G[{0}, yu^(-1)]*G[{0}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1}, yu^(-1)])/16 - 
     (G[{0}, yv^(-1)]*G[{0}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1}, yu^(-1)])/16 + 
     (G[{0}, yw]^2*G[{1/(yu*yv)}, yw]*G[{0, 1}, yu^(-1)])/32 + 
     (G[{0}, yu^(-1)]*G[{1}, yu^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, 1}, yu^(-1)])/
      8 + (G[{0}, yv^(-1)]*G[{1}, yu^(-1)]*G[{1/(yu*yv)}, yw]*
       G[{0, 1}, yu^(-1)])/8 - (G[{0}, yw]*G[{1}, yu^(-1)]*G[{1/(yu*yv)}, yw]*
       G[{0, 1}, yu^(-1)])/8 - (11*G[{1}, yu^(-1)]^2*G[{1/(yu*yv)}, yw]*
       G[{0, 1}, yu^(-1)])/128 - (G[{0}, yu^(-1)]*G[{1}, yv^(-1)]*
       G[{1/(yu*yv)}, yw]*G[{0, 1}, yu^(-1)])/16 - 
     (G[{0}, yv^(-1)]*G[{1}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, 1}, yu^(-1)])/
      16 + (G[{0}, yw]*G[{1}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, 1}, yu^(-1)])/
      16 + (G[{1}, yv^(-1)]^2*G[{1/(yu*yv)}, yw]*G[{0, 1}, yu^(-1)])/128 + 
     (3*G[{0}, yu^(-1)]*G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1}, yu^(-1)])/
      16 + (3*G[{0}, yv^(-1)]*G[{1}, yw]*G[{1/(yu*yv)}, yw]*
       G[{0, 1}, yu^(-1)])/16 - (3*G[{0}, yw]*G[{1}, yw]*G[{1/(yu*yv)}, yw]*
       G[{0, 1}, yu^(-1)])/16 + (G[{1}, yu^(-1)]*G[{1}, yw]*
       G[{1/(yu*yv)}, yw]*G[{0, 1}, yu^(-1)])/16 - 
     (7*G[{1}, yv^(-1)]*G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1}, yu^(-1)])/
      64 + (13*G[{1}, yw]^2*G[{1/(yu*yv)}, yw]*G[{0, 1}, yu^(-1)])/64 + 
     (G[{1}, yu^(-1)]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1}, yu^(-1)])/
      64 + (3*G[{1}, yv^(-1)]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*
       G[{0, 1}, yu^(-1)])/64 + (5*G[{1}, yw]*G[{yu^(-1)}, yw]*
       G[{1/(yu*yv)}, yw]*G[{0, 1}, yu^(-1)])/64 - 
     (G[{yu^(-1)}, yw]^2*G[{1/(yu*yv)}, yw]*G[{0, 1}, yu^(-1)])/32 - 
     (G[{0}, yu^(-1)]*G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, 1}, yu^(-1)])/
      8 - (G[{0}, yv^(-1)]*G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw]*
       G[{0, 1}, yu^(-1)])/8 + (G[{0}, yw]*G[{yu}, yv^(-1)]*
       G[{1/(yu*yv)}, yw]*G[{0, 1}, yu^(-1)])/8 - 
     (5*G[{1}, yu^(-1)]*G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw]*
       G[{0, 1}, yu^(-1)])/64 + (9*G[{1}, yv^(-1)]*G[{yu}, yv^(-1)]*
       G[{1/(yu*yv)}, yw]*G[{0, 1}, yu^(-1)])/64 - 
     (21*G[{1}, yw]*G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, 1}, yu^(-1)])/
      64 - (G[{yu^(-1)}, yw]*G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw]*
       G[{0, 1}, yu^(-1)])/16 + (3*G[{yu}, yv^(-1)]^2*G[{1/(yu*yv)}, yw]*
       G[{0, 1}, yu^(-1)])/32 - (G[{0}, yu^(-1)]*G[{yv^(-1)}, yw]*
       G[{1/(yu*yv)}, yw]*G[{0, 1}, yu^(-1)])/16 - 
     (G[{0}, yv^(-1)]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1}, yu^(-1)])/
      16 + (G[{0}, yw]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*
       G[{0, 1}, yu^(-1)])/16 + (5*G[{1}, yu^(-1)]*G[{yv^(-1)}, yw]*
       G[{1/(yu*yv)}, yw]*G[{0, 1}, yu^(-1)])/32 - 
     (G[{1}, yv^(-1)]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1}, yu^(-1)])/
      32 + (G[{1}, yw]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*
       G[{0, 1}, yu^(-1)])/32 - (G[{yv^(-1)}, yw]^2*G[{1/(yu*yv)}, yw]*
       G[{0, 1}, yu^(-1)])/16 - (G[{0}, yu^(-1)]*G[{1/(yu*yv)}, yw]^2*
       G[{0, 1}, yu^(-1)])/32 - (G[{0}, yv^(-1)]*G[{1/(yu*yv)}, yw]^2*
       G[{0, 1}, yu^(-1)])/32 + (G[{0}, yw]*G[{1/(yu*yv)}, yw]^2*
       G[{0, 1}, yu^(-1)])/32 + (G[{1}, yu^(-1)]*G[{1/(yu*yv)}, yw]^2*
       G[{0, 1}, yu^(-1)])/128 - (G[{1}, yv^(-1)]*G[{1/(yu*yv)}, yw]^2*
       G[{0, 1}, yu^(-1)])/64 - (9*G[{1}, yw]*G[{1/(yu*yv)}, yw]^2*
       G[{0, 1}, yu^(-1)])/128 + (G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2*
       G[{0, 1}, yu^(-1)])/64 + (9*G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw]^2*
       G[{0, 1}, yu^(-1)])/128 - (G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2*
       G[{0, 1}, yu^(-1)])/128 - (3*G[{1}, yu^(-1)]*G[{0, 1}, yu^(-1)]^2)/
      128 + (3*G[{1}, yv^(-1)]*G[{0, 1}, yu^(-1)]^2)/128 + 
     (G[{1}, yw]*G[{0, 1}, yu^(-1)]^2)/128 - 
     (G[{1/(yu*yv)}, yw]*G[{0, 1}, yu^(-1)]^2)/128 - 
     (Pi^2*G[{1}, yu^(-1)]*G[{0, 1}, yv^(-1)])/48 - 
     (3*G[{1}, yu^(-1)]^3*G[{0, 1}, yv^(-1)])/128 + 
     (Pi^2*G[{1}, yv^(-1)]*G[{0, 1}, yv^(-1)])/96 + 
     (G[{1}, yu^(-1)]^2*G[{1}, yv^(-1)]*G[{0, 1}, yv^(-1)])/128 + 
     (9*G[{1}, yu^(-1)]*G[{1}, yv^(-1)]^2*G[{0, 1}, yv^(-1)])/128 - 
     (G[{1}, yv^(-1)]^3*G[{0, 1}, yv^(-1)])/96 + 
     (Pi^2*G[{1}, yw]*G[{0, 1}, yv^(-1)])/96 - 
     (G[{0}, yu^(-1)]^2*G[{1}, yw]*G[{0, 1}, yv^(-1)])/32 - 
     (G[{0}, yu^(-1)]*G[{0}, yv^(-1)]*G[{1}, yw]*G[{0, 1}, yv^(-1)])/16 - 
     (G[{0}, yv^(-1)]^2*G[{1}, yw]*G[{0, 1}, yv^(-1)])/32 + 
     (G[{0}, yu^(-1)]*G[{0}, yw]*G[{1}, yw]*G[{0, 1}, yv^(-1)])/16 + 
     (G[{0}, yv^(-1)]*G[{0}, yw]*G[{1}, yw]*G[{0, 1}, yv^(-1)])/16 - 
     (G[{0}, yw]^2*G[{1}, yw]*G[{0, 1}, yv^(-1)])/32 - 
     (G[{1}, yu^(-1)]^2*G[{1}, yw]*G[{0, 1}, yv^(-1)])/128 + 
     (G[{0}, yu^(-1)]*G[{1}, yv^(-1)]*G[{1}, yw]*G[{0, 1}, yv^(-1)])/16 + 
     (G[{0}, yv^(-1)]*G[{1}, yv^(-1)]*G[{1}, yw]*G[{0, 1}, yv^(-1)])/16 - 
     (G[{0}, yw]*G[{1}, yv^(-1)]*G[{1}, yw]*G[{0, 1}, yv^(-1)])/16 - 
     (G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*G[{1}, yw]*G[{0, 1}, yv^(-1)])/64 - 
     (G[{1}, yv^(-1)]^2*G[{1}, yw]*G[{0, 1}, yv^(-1)])/32 - 
     (5*G[{1}, yu^(-1)]*G[{1}, yw]^2*G[{0, 1}, yv^(-1)])/128 - 
     (5*G[{1}, yw]^3*G[{0, 1}, yv^(-1)])/384 + 
     (G[{0}, yu^(-1)]*G[{1}, yw]*G[{yu}, yv^(-1)]*G[{0, 1}, yv^(-1)])/8 + 
     (G[{0}, yv^(-1)]*G[{1}, yw]*G[{yu}, yv^(-1)]*G[{0, 1}, yv^(-1)])/8 - 
     (G[{0}, yw]*G[{1}, yw]*G[{yu}, yv^(-1)]*G[{0, 1}, yv^(-1)])/8 - 
     (G[{1}, yu^(-1)]*G[{1}, yw]*G[{yu}, yv^(-1)]*G[{0, 1}, yv^(-1)])/32 - 
     (G[{1}, yv^(-1)]*G[{1}, yw]*G[{yu}, yv^(-1)]*G[{0, 1}, yv^(-1)])/8 + 
     (13*G[{1}, yw]^2*G[{yu}, yv^(-1)]*G[{0, 1}, yv^(-1)])/128 - 
     (7*G[{1}, yw]*G[{yu}, yv^(-1)]^2*G[{0, 1}, yv^(-1)])/64 - 
     (Pi^2*G[{1/(yu*yv)}, yw]*G[{0, 1}, yv^(-1)])/96 + 
     (G[{0}, yu^(-1)]^2*G[{1/(yu*yv)}, yw]*G[{0, 1}, yv^(-1)])/32 + 
     (G[{0}, yu^(-1)]*G[{0}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, 1}, yv^(-1)])/
      16 + (G[{0}, yv^(-1)]^2*G[{1/(yu*yv)}, yw]*G[{0, 1}, yv^(-1)])/32 - 
     (G[{0}, yu^(-1)]*G[{0}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1}, yv^(-1)])/16 - 
     (G[{0}, yv^(-1)]*G[{0}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1}, yv^(-1)])/16 + 
     (G[{0}, yw]^2*G[{1/(yu*yv)}, yw]*G[{0, 1}, yv^(-1)])/32 + 
     (G[{1}, yu^(-1)]^2*G[{1/(yu*yv)}, yw]*G[{0, 1}, yv^(-1)])/128 - 
     (G[{0}, yu^(-1)]*G[{1}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, 1}, yv^(-1)])/
      16 - (G[{0}, yv^(-1)]*G[{1}, yv^(-1)]*G[{1/(yu*yv)}, yw]*
       G[{0, 1}, yv^(-1)])/16 + (G[{0}, yw]*G[{1}, yv^(-1)]*
       G[{1/(yu*yv)}, yw]*G[{0, 1}, yv^(-1)])/16 + 
     (G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, 1}, yv^(-1)])/
      64 + (G[{1}, yv^(-1)]^2*G[{1/(yu*yv)}, yw]*G[{0, 1}, yv^(-1)])/32 + 
     (5*G[{1}, yu^(-1)]*G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1}, yv^(-1)])/
      64 + (5*G[{1}, yw]^2*G[{1/(yu*yv)}, yw]*G[{0, 1}, yv^(-1)])/128 - 
     (G[{0}, yu^(-1)]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1}, yv^(-1)])/
      16 - (G[{0}, yv^(-1)]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*
       G[{0, 1}, yv^(-1)])/16 + (G[{0}, yw]*G[{yu^(-1)}, yw]*
       G[{1/(yu*yv)}, yw]*G[{0, 1}, yv^(-1)])/16 + 
     (G[{1}, yv^(-1)]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1}, yv^(-1)])/
      16 - (G[{1}, yw]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*
       G[{0, 1}, yv^(-1)])/16 - (G[{yu^(-1)}, yw]^2*G[{1/(yu*yv)}, yw]*
       G[{0, 1}, yv^(-1)])/16 - (G[{0}, yu^(-1)]*G[{yu}, yv^(-1)]*
       G[{1/(yu*yv)}, yw]*G[{0, 1}, yv^(-1)])/8 - 
     (G[{0}, yv^(-1)]*G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, 1}, yv^(-1)])/
      8 + (G[{0}, yw]*G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, 1}, yv^(-1)])/
      8 + (G[{1}, yu^(-1)]*G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw]*
       G[{0, 1}, yv^(-1)])/32 + (G[{1}, yv^(-1)]*G[{yu}, yv^(-1)]*
       G[{1/(yu*yv)}, yw]*G[{0, 1}, yv^(-1)])/8 - 
     (13*G[{1}, yw]*G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, 1}, yv^(-1)])/
      64 + (7*G[{yu}, yv^(-1)]^2*G[{1/(yu*yv)}, yw]*G[{0, 1}, yv^(-1)])/64 + 
     (G[{1}, yu^(-1)]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1}, yv^(-1)])/
      32 - (G[{1}, yv^(-1)]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*
       G[{0, 1}, yv^(-1)])/16 - (G[{1}, yw]*G[{yv^(-1)}, yw]*
       G[{1/(yu*yv)}, yw]*G[{0, 1}, yv^(-1)])/32 - 
     (G[{yu}, yv^(-1)]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*
       G[{0, 1}, yv^(-1)])/32 - (G[{yv^(-1)}, yw]^2*G[{1/(yu*yv)}, yw]*
       G[{0, 1}, yv^(-1)])/64 + (G[{0}, yu^(-1)]*G[{1/(yu*yv)}, yw]^2*
       G[{0, 1}, yv^(-1)])/16 + (G[{0}, yv^(-1)]*G[{1/(yu*yv)}, yw]^2*
       G[{0, 1}, yv^(-1)])/16 - (G[{0}, yw]*G[{1/(yu*yv)}, yw]^2*
       G[{0, 1}, yv^(-1)])/16 - (7*G[{1}, yu^(-1)]*G[{1/(yu*yv)}, yw]^2*
       G[{0, 1}, yv^(-1)])/128 - (G[{1}, yv^(-1)]*G[{1/(yu*yv)}, yw]^2*
       G[{0, 1}, yv^(-1)])/16 + (G[{1}, yw]*G[{1/(yu*yv)}, yw]^2*
       G[{0, 1}, yv^(-1)])/128 + (G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2*
       G[{0, 1}, yv^(-1)])/16 - (G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw]^2*
       G[{0, 1}, yv^(-1)])/128 + (7*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2*
       G[{0, 1}, yv^(-1)])/128 - (5*G[{1}, yu^(-1)]*G[{0, 1}, yu^(-1)]*
       G[{0, 1}, yv^(-1)])/64 + (5*G[{1}, yv^(-1)]*G[{0, 1}, yu^(-1)]*
       G[{0, 1}, yv^(-1)])/64 + (3*G[{1}, yw]*G[{0, 1}, yu^(-1)]*
       G[{0, 1}, yv^(-1)])/64 - (3*G[{1/(yu*yv)}, yw]*G[{0, 1}, yu^(-1)]*
       G[{0, 1}, yv^(-1)])/64 + (G[{1}, yw]*G[{0, 1}, yv^(-1)]^2)/32 - 
     (G[{1/(yu*yv)}, yw]*G[{0, 1}, yv^(-1)]^2)/32 - 
     (Pi^2*G[{0}, yu^(-1)]*G[{0, 1}, yw])/96 - 
     (Pi^2*G[{0}, yv^(-1)]*G[{0, 1}, yw])/96 + 
     (Pi^2*G[{0}, yw]*G[{0, 1}, yw])/96 - 
     (Pi^2*G[{1}, yu^(-1)]*G[{0, 1}, yw])/48 + 
     (Pi^2*G[{1}, yv^(-1)]*G[{0, 1}, yw])/96 + 
     (Pi^2*G[{1}, yw]*G[{0, 1}, yw])/96 - 
     (G[{0}, yu^(-1)]^2*G[{1}, yw]*G[{0, 1}, yw])/32 - 
     (G[{0}, yu^(-1)]*G[{0}, yv^(-1)]*G[{1}, yw]*G[{0, 1}, yw])/16 - 
     (G[{0}, yv^(-1)]^2*G[{1}, yw]*G[{0, 1}, yw])/32 + 
     (G[{0}, yu^(-1)]*G[{0}, yw]*G[{1}, yw]*G[{0, 1}, yw])/16 + 
     (G[{0}, yv^(-1)]*G[{0}, yw]*G[{1}, yw]*G[{0, 1}, yw])/16 - 
     (G[{0}, yw]^2*G[{1}, yw]*G[{0, 1}, yw])/32 - 
     (G[{0}, yu^(-1)]*G[{1}, yu^(-1)]*G[{1}, yw]*G[{0, 1}, yw])/16 - 
     (G[{0}, yv^(-1)]*G[{1}, yu^(-1)]*G[{1}, yw]*G[{0, 1}, yw])/16 + 
     (G[{0}, yw]*G[{1}, yu^(-1)]*G[{1}, yw]*G[{0, 1}, yw])/16 + 
     (3*G[{1}, yu^(-1)]^2*G[{1}, yw]*G[{0, 1}, yw])/32 + 
     (G[{0}, yu^(-1)]*G[{1}, yv^(-1)]*G[{1}, yw]*G[{0, 1}, yw])/8 + 
     (G[{0}, yv^(-1)]*G[{1}, yv^(-1)]*G[{1}, yw]*G[{0, 1}, yw])/8 - 
     (G[{0}, yw]*G[{1}, yv^(-1)]*G[{1}, yw]*G[{0, 1}, yw])/8 + 
     (G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*G[{1}, yw]*G[{0, 1}, yw])/16 - 
     (3*G[{1}, yv^(-1)]^2*G[{1}, yw]*G[{0, 1}, yw])/32 - 
     (G[{0}, yu^(-1)]*G[{1}, yw]^2*G[{0, 1}, yw])/16 - 
     (G[{0}, yv^(-1)]*G[{1}, yw]^2*G[{0, 1}, yw])/16 + 
     (G[{0}, yw]*G[{1}, yw]^2*G[{0, 1}, yw])/16 + 
     (G[{1}, yu^(-1)]*G[{1}, yw]^2*G[{0, 1}, yw])/16 + 
     (G[{1}, yv^(-1)]*G[{1}, yw]^2*G[{0, 1}, yw])/16 + 
     (Pi^2*G[{yu}, yv^(-1)]*G[{0, 1}, yw])/48 + 
     (G[{0}, yu^(-1)]*G[{1}, yw]*G[{yu}, yv^(-1)]*G[{0, 1}, yw])/16 + 
     (G[{0}, yv^(-1)]*G[{1}, yw]*G[{yu}, yv^(-1)]*G[{0, 1}, yw])/16 - 
     (G[{0}, yw]*G[{1}, yw]*G[{yu}, yv^(-1)]*G[{0, 1}, yw])/16 - 
     (G[{1}, yu^(-1)]*G[{1}, yw]*G[{yu}, yv^(-1)]*G[{0, 1}, yw])/8 - 
     (G[{1}, yv^(-1)]*G[{1}, yw]*G[{yu}, yv^(-1)]*G[{0, 1}, yw])/8 + 
     (G[{1}, yw]*G[{yu}, yv^(-1)]^2*G[{0, 1}, yw])/16 - 
     (Pi^2*G[{1/(yu*yv)}, yw]*G[{0, 1}, yw])/96 + 
     (G[{0}, yu^(-1)]^2*G[{1/(yu*yv)}, yw]*G[{0, 1}, yw])/32 + 
     (G[{0}, yu^(-1)]*G[{0}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, 1}, yw])/16 + 
     (G[{0}, yv^(-1)]^2*G[{1/(yu*yv)}, yw]*G[{0, 1}, yw])/32 - 
     (G[{0}, yu^(-1)]*G[{0}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1}, yw])/16 - 
     (G[{0}, yv^(-1)]*G[{0}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1}, yw])/16 + 
     (G[{0}, yw]^2*G[{1/(yu*yv)}, yw]*G[{0, 1}, yw])/32 + 
     (G[{0}, yu^(-1)]*G[{1}, yu^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, 1}, yw])/16 + 
     (G[{0}, yv^(-1)]*G[{1}, yu^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, 1}, yw])/16 - 
     (G[{0}, yw]*G[{1}, yu^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, 1}, yw])/16 - 
     (3*G[{1}, yu^(-1)]^2*G[{1/(yu*yv)}, yw]*G[{0, 1}, yw])/32 - 
     (G[{0}, yu^(-1)]*G[{1}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, 1}, yw])/8 - 
     (G[{0}, yv^(-1)]*G[{1}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, 1}, yw])/8 + 
     (G[{0}, yw]*G[{1}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, 1}, yw])/8 - 
     (G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, 1}, yw])/16 + 
     (3*G[{1}, yv^(-1)]^2*G[{1/(yu*yv)}, yw]*G[{0, 1}, yw])/32 + 
     (G[{0}, yu^(-1)]*G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1}, yw])/8 + 
     (G[{0}, yv^(-1)]*G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1}, yw])/8 - 
     (G[{0}, yw]*G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1}, yw])/8 - 
     (G[{1}, yu^(-1)]*G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1}, yw])/8 - 
     (G[{1}, yv^(-1)]*G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1}, yw])/8 - 
     (G[{1}, yu^(-1)]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1}, yw])/8 - 
     (G[{1}, yw]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1}, yw])/16 - 
     (G[{yu^(-1)}, yw]^2*G[{1/(yu*yv)}, yw]*G[{0, 1}, yw])/16 - 
     (G[{0}, yu^(-1)]*G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, 1}, yw])/16 - 
     (G[{0}, yv^(-1)]*G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, 1}, yw])/16 + 
     (G[{0}, yw]*G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, 1}, yw])/16 + 
     (G[{1}, yu^(-1)]*G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, 1}, yw])/8 + 
     (G[{1}, yv^(-1)]*G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, 1}, yw])/8 + 
     (G[{yu^(-1)}, yw]*G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, 1}, yw])/8 - 
     (G[{yu}, yv^(-1)]^2*G[{1/(yu*yv)}, yw]*G[{0, 1}, yw])/16 - 
     (3*G[{0}, yu^(-1)]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1}, yw])/
      16 - (3*G[{0}, yv^(-1)]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*
       G[{0, 1}, yw])/16 + (3*G[{0}, yw]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*
       G[{0, 1}, yw])/16 + (G[{1}, yv^(-1)]*G[{yv^(-1)}, yw]*
       G[{1/(yu*yv)}, yw]*G[{0, 1}, yw])/4 - 
     (G[{1}, yw]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1}, yw])/16 + 
     (G[{yu}, yv^(-1)]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1}, yw])/8 + 
     (G[{yv^(-1)}, yw]^2*G[{1/(yu*yv)}, yw]*G[{0, 1}, yw])/8 - 
     (G[{0}, yu^(-1)]*G[{0, 1}, yu^(-1)]*G[{0, 1}, yw])/16 - 
     (G[{0}, yv^(-1)]*G[{0, 1}, yu^(-1)]*G[{0, 1}, yw])/16 + 
     (G[{0}, yw]*G[{0, 1}, yu^(-1)]*G[{0, 1}, yw])/16 - 
     (G[{1}, yu^(-1)]*G[{0, 1}, yu^(-1)]*G[{0, 1}, yw])/8 + 
     (G[{1}, yv^(-1)]*G[{0, 1}, yu^(-1)]*G[{0, 1}, yw])/16 + 
     (G[{yu}, yv^(-1)]*G[{0, 1}, yu^(-1)]*G[{0, 1}, yw])/8 - 
     (G[{0}, yu^(-1)]*G[{0, 1}, yv^(-1)]*G[{0, 1}, yw])/16 - 
     (G[{0}, yv^(-1)]*G[{0, 1}, yv^(-1)]*G[{0, 1}, yw])/16 + 
     (G[{0}, yw]*G[{0, 1}, yv^(-1)]*G[{0, 1}, yw])/16 + 
     (G[{1}, yv^(-1)]*G[{0, 1}, yv^(-1)]*G[{0, 1}, yw])/16 + 
     (G[{yu}, yv^(-1)]*G[{0, 1}, yv^(-1)]*G[{0, 1}, yw])/8 + 
     (G[{1}, yu^(-1)]*G[{0, 1}, yw]^2)/16 - (G[{1}, yv^(-1)]*G[{0, 1}, yw]^2)/
      32 + (G[{1}, yw]*G[{0, 1}, yw]^2)/32 - 
     (G[{yu}, yv^(-1)]*G[{0, 1}, yw]^2)/32 - 
     (G[{1/(yu*yv)}, yw]*G[{0, 1}, yw]^2)/32 - 
     (Pi^2*G[{1}, yw]*G[{0, yu^(-1)}, yw])/96 + 
     (G[{0}, yu^(-1)]^2*G[{1}, yw]*G[{0, yu^(-1)}, yw])/32 + 
     (G[{0}, yu^(-1)]*G[{0}, yv^(-1)]*G[{1}, yw]*G[{0, yu^(-1)}, yw])/16 + 
     (G[{0}, yv^(-1)]^2*G[{1}, yw]*G[{0, yu^(-1)}, yw])/32 - 
     (G[{0}, yu^(-1)]*G[{0}, yw]*G[{1}, yw]*G[{0, yu^(-1)}, yw])/16 - 
     (G[{0}, yv^(-1)]*G[{0}, yw]*G[{1}, yw]*G[{0, yu^(-1)}, yw])/16 + 
     (G[{0}, yw]^2*G[{1}, yw]*G[{0, yu^(-1)}, yw])/32 + 
     (G[{0}, yu^(-1)]*G[{1}, yu^(-1)]*G[{1}, yw]*G[{0, yu^(-1)}, yw])/16 + 
     (G[{0}, yv^(-1)]*G[{1}, yu^(-1)]*G[{1}, yw]*G[{0, yu^(-1)}, yw])/16 - 
     (G[{0}, yw]*G[{1}, yu^(-1)]*G[{1}, yw]*G[{0, yu^(-1)}, yw])/16 - 
     (3*G[{1}, yu^(-1)]^2*G[{1}, yw]*G[{0, yu^(-1)}, yw])/32 - 
     (G[{0}, yu^(-1)]*G[{1}, yv^(-1)]*G[{1}, yw]*G[{0, yu^(-1)}, yw])/16 - 
     (G[{0}, yv^(-1)]*G[{1}, yv^(-1)]*G[{1}, yw]*G[{0, yu^(-1)}, yw])/16 + 
     (G[{0}, yw]*G[{1}, yv^(-1)]*G[{1}, yw]*G[{0, yu^(-1)}, yw])/16 - 
     (G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*G[{1}, yw]*G[{0, yu^(-1)}, yw])/16 + 
     (G[{1}, yv^(-1)]^2*G[{1}, yw]*G[{0, yu^(-1)}, yw])/32 + 
     (G[{0}, yu^(-1)]*G[{1}, yw]^2*G[{0, yu^(-1)}, yw])/16 + 
     (G[{0}, yv^(-1)]*G[{1}, yw]^2*G[{0, yu^(-1)}, yw])/16 - 
     (G[{0}, yw]*G[{1}, yw]^2*G[{0, yu^(-1)}, yw])/16 - 
     (G[{1}, yu^(-1)]*G[{1}, yw]^2*G[{0, yu^(-1)}, yw])/16 - 
     (G[{1}, yv^(-1)]*G[{1}, yw]^2*G[{0, yu^(-1)}, yw])/16 - 
     (G[{0}, yu^(-1)]*G[{1}, yw]*G[{yu}, yv^(-1)]*G[{0, yu^(-1)}, yw])/8 - 
     (G[{0}, yv^(-1)]*G[{1}, yw]*G[{yu}, yv^(-1)]*G[{0, yu^(-1)}, yw])/8 + 
     (G[{0}, yw]*G[{1}, yw]*G[{yu}, yv^(-1)]*G[{0, yu^(-1)}, yw])/8 + 
     (G[{1}, yu^(-1)]*G[{1}, yw]*G[{yu}, yv^(-1)]*G[{0, yu^(-1)}, yw])/8 + 
     (G[{1}, yv^(-1)]*G[{1}, yw]*G[{yu}, yv^(-1)]*G[{0, yu^(-1)}, yw])/8 + 
     (Pi^2*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1)}, yw])/96 - 
     (G[{0}, yu^(-1)]^2*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1)}, yw])/32 - 
     (G[{0}, yu^(-1)]*G[{0}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1)}, yw])/
      16 - (G[{0}, yv^(-1)]^2*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1)}, yw])/32 + 
     (G[{0}, yu^(-1)]*G[{0}, yw]*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1)}, yw])/16 + 
     (G[{0}, yv^(-1)]*G[{0}, yw]*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1)}, yw])/16 - 
     (G[{0}, yw]^2*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1)}, yw])/32 - 
     (G[{0}, yu^(-1)]*G[{1}, yu^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1)}, yw])/
      16 - (G[{0}, yv^(-1)]*G[{1}, yu^(-1)]*G[{1/(yu*yv)}, yw]*
       G[{0, yu^(-1)}, yw])/16 + (G[{0}, yw]*G[{1}, yu^(-1)]*
       G[{1/(yu*yv)}, yw]*G[{0, yu^(-1)}, yw])/16 + 
     (3*G[{1}, yu^(-1)]^2*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1)}, yw])/32 + 
     (G[{0}, yu^(-1)]*G[{1}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1)}, yw])/
      16 + (G[{0}, yv^(-1)]*G[{1}, yv^(-1)]*G[{1/(yu*yv)}, yw]*
       G[{0, yu^(-1)}, yw])/16 - (G[{0}, yw]*G[{1}, yv^(-1)]*
       G[{1/(yu*yv)}, yw]*G[{0, yu^(-1)}, yw])/16 + 
     (G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1)}, yw])/
      16 - (G[{1}, yv^(-1)]^2*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1)}, yw])/32 - 
     (G[{0}, yu^(-1)]*G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1)}, yw])/8 - 
     (G[{0}, yv^(-1)]*G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1)}, yw])/8 + 
     (G[{0}, yw]*G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1)}, yw])/8 + 
     (G[{1}, yu^(-1)]*G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1)}, yw])/8 + 
     (G[{1}, yv^(-1)]*G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1)}, yw])/8 + 
     (G[{1}, yu^(-1)]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*
       G[{0, yu^(-1)}, yw])/8 + (G[{1}, yw]*G[{yu^(-1)}, yw]*
       G[{1/(yu*yv)}, yw]*G[{0, yu^(-1)}, yw])/16 + 
     (G[{yu^(-1)}, yw]^2*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1)}, yw])/16 + 
     (G[{0}, yu^(-1)]*G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw]*
       G[{0, yu^(-1)}, yw])/8 + (G[{0}, yv^(-1)]*G[{yu}, yv^(-1)]*
       G[{1/(yu*yv)}, yw]*G[{0, yu^(-1)}, yw])/8 - 
     (G[{0}, yw]*G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1)}, yw])/8 - 
     (G[{1}, yu^(-1)]*G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw]*
       G[{0, yu^(-1)}, yw])/8 - (G[{1}, yv^(-1)]*G[{yu}, yv^(-1)]*
       G[{1/(yu*yv)}, yw]*G[{0, yu^(-1)}, yw])/8 - 
     (G[{yu^(-1)}, yw]*G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw]*
       G[{0, yu^(-1)}, yw])/8 + (3*G[{0}, yu^(-1)]*G[{yv^(-1)}, yw]*
       G[{1/(yu*yv)}, yw]*G[{0, yu^(-1)}, yw])/16 + 
     (3*G[{0}, yv^(-1)]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*
       G[{0, yu^(-1)}, yw])/16 - (3*G[{0}, yw]*G[{yv^(-1)}, yw]*
       G[{1/(yu*yv)}, yw]*G[{0, yu^(-1)}, yw])/16 - 
     (G[{1}, yv^(-1)]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*
       G[{0, yu^(-1)}, yw])/4 + (G[{1}, yw]*G[{yv^(-1)}, yw]*
       G[{1/(yu*yv)}, yw]*G[{0, yu^(-1)}, yw])/16 - 
     (G[{yu}, yv^(-1)]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*
       G[{0, yu^(-1)}, yw])/8 - (G[{yv^(-1)}, yw]^2*G[{1/(yu*yv)}, yw]*
       G[{0, yu^(-1)}, yw])/8 - (G[{1}, yw]*G[{0, 1}, yw]*
       G[{0, yu^(-1)}, yw])/16 + (G[{1/(yu*yv)}, yw]*G[{0, 1}, yw]*
       G[{0, yu^(-1)}, yw])/16 + (G[{1}, yw]*G[{0, yu^(-1)}, yw]^2)/32 - 
     (G[{1/(yu*yv)}, yw]*G[{0, yu^(-1)}, yw]^2)/32 + 
     (3*G[{1}, yu^(-1)]^3*G[{0, yu}, yv^(-1)])/128 + 
     (Pi^2*G[{1}, yv^(-1)]*G[{0, yu}, yv^(-1)])/96 - 
     (G[{1}, yu^(-1)]^2*G[{1}, yv^(-1)]*G[{0, yu}, yv^(-1)])/128 - 
     (9*G[{1}, yu^(-1)]*G[{1}, yv^(-1)]^2*G[{0, yu}, yv^(-1)])/128 + 
     (G[{1}, yv^(-1)]^3*G[{0, yu}, yv^(-1)])/96 - 
     (Pi^2*G[{1}, yw]*G[{0, yu}, yv^(-1)])/96 + 
     (G[{0}, yu^(-1)]^2*G[{1}, yw]*G[{0, yu}, yv^(-1)])/32 + 
     (G[{0}, yu^(-1)]*G[{0}, yv^(-1)]*G[{1}, yw]*G[{0, yu}, yv^(-1)])/16 + 
     (G[{0}, yv^(-1)]^2*G[{1}, yw]*G[{0, yu}, yv^(-1)])/32 - 
     (G[{0}, yu^(-1)]*G[{0}, yw]*G[{1}, yw]*G[{0, yu}, yv^(-1)])/16 - 
     (G[{0}, yv^(-1)]*G[{0}, yw]*G[{1}, yw]*G[{0, yu}, yv^(-1)])/16 + 
     (G[{0}, yw]^2*G[{1}, yw]*G[{0, yu}, yv^(-1)])/32 + 
     (G[{1}, yu^(-1)]^2*G[{1}, yw]*G[{0, yu}, yv^(-1)])/128 - 
     (G[{0}, yu^(-1)]*G[{1}, yv^(-1)]*G[{1}, yw]*G[{0, yu}, yv^(-1)])/16 - 
     (G[{0}, yv^(-1)]*G[{1}, yv^(-1)]*G[{1}, yw]*G[{0, yu}, yv^(-1)])/16 + 
     (G[{0}, yw]*G[{1}, yv^(-1)]*G[{1}, yw]*G[{0, yu}, yv^(-1)])/16 + 
     (G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*G[{1}, yw]*G[{0, yu}, yv^(-1)])/64 + 
     (G[{1}, yv^(-1)]^2*G[{1}, yw]*G[{0, yu}, yv^(-1)])/32 + 
     (5*G[{1}, yu^(-1)]*G[{1}, yw]^2*G[{0, yu}, yv^(-1)])/128 + 
     (5*G[{1}, yw]^3*G[{0, yu}, yv^(-1)])/384 - 
     (G[{0}, yu^(-1)]*G[{1}, yw]*G[{yu}, yv^(-1)]*G[{0, yu}, yv^(-1)])/8 - 
     (G[{0}, yv^(-1)]*G[{1}, yw]*G[{yu}, yv^(-1)]*G[{0, yu}, yv^(-1)])/8 + 
     (G[{0}, yw]*G[{1}, yw]*G[{yu}, yv^(-1)]*G[{0, yu}, yv^(-1)])/8 + 
     (G[{1}, yu^(-1)]*G[{1}, yw]*G[{yu}, yv^(-1)]*G[{0, yu}, yv^(-1)])/32 + 
     (G[{1}, yv^(-1)]*G[{1}, yw]*G[{yu}, yv^(-1)]*G[{0, yu}, yv^(-1)])/8 - 
     (13*G[{1}, yw]^2*G[{yu}, yv^(-1)]*G[{0, yu}, yv^(-1)])/128 + 
     (7*G[{1}, yw]*G[{yu}, yv^(-1)]^2*G[{0, yu}, yv^(-1)])/64 + 
     (Pi^2*G[{1/(yu*yv)}, yw]*G[{0, yu}, yv^(-1)])/96 - 
     (G[{0}, yu^(-1)]^2*G[{1/(yu*yv)}, yw]*G[{0, yu}, yv^(-1)])/32 - 
     (G[{0}, yu^(-1)]*G[{0}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, yu}, yv^(-1)])/
      16 - (G[{0}, yv^(-1)]^2*G[{1/(yu*yv)}, yw]*G[{0, yu}, yv^(-1)])/32 + 
     (G[{0}, yu^(-1)]*G[{0}, yw]*G[{1/(yu*yv)}, yw]*G[{0, yu}, yv^(-1)])/16 + 
     (G[{0}, yv^(-1)]*G[{0}, yw]*G[{1/(yu*yv)}, yw]*G[{0, yu}, yv^(-1)])/16 - 
     (G[{0}, yw]^2*G[{1/(yu*yv)}, yw]*G[{0, yu}, yv^(-1)])/32 - 
     (G[{1}, yu^(-1)]^2*G[{1/(yu*yv)}, yw]*G[{0, yu}, yv^(-1)])/128 + 
     (G[{0}, yu^(-1)]*G[{1}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, yu}, yv^(-1)])/
      16 + (G[{0}, yv^(-1)]*G[{1}, yv^(-1)]*G[{1/(yu*yv)}, yw]*
       G[{0, yu}, yv^(-1)])/16 - (G[{0}, yw]*G[{1}, yv^(-1)]*
       G[{1/(yu*yv)}, yw]*G[{0, yu}, yv^(-1)])/16 - 
     (G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, yu}, yv^(-1)])/
      64 - (G[{1}, yv^(-1)]^2*G[{1/(yu*yv)}, yw]*G[{0, yu}, yv^(-1)])/32 - 
     (5*G[{1}, yu^(-1)]*G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{0, yu}, yv^(-1)])/
      64 - (5*G[{1}, yw]^2*G[{1/(yu*yv)}, yw]*G[{0, yu}, yv^(-1)])/128 + 
     (G[{0}, yu^(-1)]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*
       G[{0, yu}, yv^(-1)])/16 + (G[{0}, yv^(-1)]*G[{yu^(-1)}, yw]*
       G[{1/(yu*yv)}, yw]*G[{0, yu}, yv^(-1)])/16 - 
     (G[{0}, yw]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{0, yu}, yv^(-1)])/
      16 - (G[{1}, yv^(-1)]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*
       G[{0, yu}, yv^(-1)])/16 + (G[{1}, yw]*G[{yu^(-1)}, yw]*
       G[{1/(yu*yv)}, yw]*G[{0, yu}, yv^(-1)])/16 + 
     (G[{yu^(-1)}, yw]^2*G[{1/(yu*yv)}, yw]*G[{0, yu}, yv^(-1)])/16 + 
     (G[{0}, yu^(-1)]*G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw]*
       G[{0, yu}, yv^(-1)])/8 + (G[{0}, yv^(-1)]*G[{yu}, yv^(-1)]*
       G[{1/(yu*yv)}, yw]*G[{0, yu}, yv^(-1)])/8 - 
     (G[{0}, yw]*G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, yu}, yv^(-1)])/8 - 
     (G[{1}, yu^(-1)]*G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw]*
       G[{0, yu}, yv^(-1)])/32 - (G[{1}, yv^(-1)]*G[{yu}, yv^(-1)]*
       G[{1/(yu*yv)}, yw]*G[{0, yu}, yv^(-1)])/8 + 
     (13*G[{1}, yw]*G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, yu}, yv^(-1)])/
      64 - (7*G[{yu}, yv^(-1)]^2*G[{1/(yu*yv)}, yw]*G[{0, yu}, yv^(-1)])/64 - 
     (G[{1}, yu^(-1)]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*
       G[{0, yu}, yv^(-1)])/32 + (G[{1}, yv^(-1)]*G[{yv^(-1)}, yw]*
       G[{1/(yu*yv)}, yw]*G[{0, yu}, yv^(-1)])/16 + 
     (G[{1}, yw]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{0, yu}, yv^(-1)])/
      32 + (G[{yu}, yv^(-1)]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*
       G[{0, yu}, yv^(-1)])/32 + (G[{yv^(-1)}, yw]^2*G[{1/(yu*yv)}, yw]*
       G[{0, yu}, yv^(-1)])/64 - (G[{0}, yu^(-1)]*G[{1/(yu*yv)}, yw]^2*
       G[{0, yu}, yv^(-1)])/16 - (G[{0}, yv^(-1)]*G[{1/(yu*yv)}, yw]^2*
       G[{0, yu}, yv^(-1)])/16 + (G[{0}, yw]*G[{1/(yu*yv)}, yw]^2*
       G[{0, yu}, yv^(-1)])/16 + (7*G[{1}, yu^(-1)]*G[{1/(yu*yv)}, yw]^2*
       G[{0, yu}, yv^(-1)])/128 + (G[{1}, yv^(-1)]*G[{1/(yu*yv)}, yw]^2*
       G[{0, yu}, yv^(-1)])/16 - (G[{1}, yw]*G[{1/(yu*yv)}, yw]^2*
       G[{0, yu}, yv^(-1)])/128 - (G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2*
       G[{0, yu}, yv^(-1)])/16 + (G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw]^2*
       G[{0, yu}, yv^(-1)])/128 - (7*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2*
       G[{0, yu}, yv^(-1)])/128 - (3*G[{1}, yu^(-1)]*G[{0, 1}, yu^(-1)]*
       G[{0, yu}, yv^(-1)])/64 + (3*G[{1}, yv^(-1)]*G[{0, 1}, yu^(-1)]*
       G[{0, yu}, yv^(-1)])/64 - (3*G[{1}, yw]*G[{0, 1}, yu^(-1)]*
       G[{0, yu}, yv^(-1)])/64 + (3*G[{1/(yu*yv)}, yw]*G[{0, 1}, yu^(-1)]*
       G[{0, yu}, yv^(-1)])/64 + (G[{1}, yv^(-1)]*G[{0, 1}, yv^(-1)]*
       G[{0, yu}, yv^(-1)])/8 - (G[{1}, yw]*G[{0, 1}, yv^(-1)]*
       G[{0, yu}, yv^(-1)])/16 + (G[{1/(yu*yv)}, yw]*G[{0, 1}, yv^(-1)]*
       G[{0, yu}, yv^(-1)])/16 + (G[{0}, yu^(-1)]*G[{0, 1}, yw]*
       G[{0, yu}, yv^(-1)])/16 + (G[{0}, yv^(-1)]*G[{0, 1}, yw]*
       G[{0, yu}, yv^(-1)])/16 - (G[{0}, yw]*G[{0, 1}, yw]*
       G[{0, yu}, yv^(-1)])/16 - (G[{1}, yv^(-1)]*G[{0, 1}, yw]*
       G[{0, yu}, yv^(-1)])/16 - (G[{yu}, yv^(-1)]*G[{0, 1}, yw]*
       G[{0, yu}, yv^(-1)])/8 - (G[{1}, yv^(-1)]*G[{0, yu}, yv^(-1)]^2)/16 + 
     (G[{1}, yw]*G[{0, yu}, yv^(-1)]^2)/32 - 
     (G[{1/(yu*yv)}, yw]*G[{0, yu}, yv^(-1)]^2)/32 - 
     (Pi^2*G[{1}, yw]*G[{0, yv^(-1)}, yw])/96 + 
     (G[{0}, yu^(-1)]^2*G[{1}, yw]*G[{0, yv^(-1)}, yw])/32 + 
     (G[{0}, yu^(-1)]*G[{0}, yv^(-1)]*G[{1}, yw]*G[{0, yv^(-1)}, yw])/16 + 
     (G[{0}, yv^(-1)]^2*G[{1}, yw]*G[{0, yv^(-1)}, yw])/32 - 
     (G[{0}, yu^(-1)]*G[{0}, yw]*G[{1}, yw]*G[{0, yv^(-1)}, yw])/16 - 
     (G[{0}, yv^(-1)]*G[{0}, yw]*G[{1}, yw]*G[{0, yv^(-1)}, yw])/16 + 
     (G[{0}, yw]^2*G[{1}, yw]*G[{0, yv^(-1)}, yw])/32 + 
     (G[{0}, yu^(-1)]*G[{1}, yu^(-1)]*G[{1}, yw]*G[{0, yv^(-1)}, yw])/8 + 
     (G[{0}, yv^(-1)]*G[{1}, yu^(-1)]*G[{1}, yw]*G[{0, yv^(-1)}, yw])/8 - 
     (G[{0}, yw]*G[{1}, yu^(-1)]*G[{1}, yw]*G[{0, yv^(-1)}, yw])/8 - 
     (5*G[{1}, yu^(-1)]^2*G[{1}, yw]*G[{0, yv^(-1)}, yw])/32 - 
     (G[{0}, yu^(-1)]*G[{1}, yv^(-1)]*G[{1}, yw]*G[{0, yv^(-1)}, yw])/8 - 
     (G[{0}, yv^(-1)]*G[{1}, yv^(-1)]*G[{1}, yw]*G[{0, yv^(-1)}, yw])/8 + 
     (G[{0}, yw]*G[{1}, yv^(-1)]*G[{1}, yw]*G[{0, yv^(-1)}, yw])/8 - 
     (G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*G[{1}, yw]*G[{0, yv^(-1)}, yw])/16 + 
     (3*G[{1}, yv^(-1)]^2*G[{1}, yw]*G[{0, yv^(-1)}, yw])/32 + 
     (G[{0}, yu^(-1)]*G[{1}, yw]^2*G[{0, yv^(-1)}, yw])/16 + 
     (G[{0}, yv^(-1)]*G[{1}, yw]^2*G[{0, yv^(-1)}, yw])/16 - 
     (G[{0}, yw]*G[{1}, yw]^2*G[{0, yv^(-1)}, yw])/16 - 
     (G[{1}, yu^(-1)]*G[{1}, yw]^2*G[{0, yv^(-1)}, yw])/16 - 
     (G[{1}, yv^(-1)]*G[{1}, yw]^2*G[{0, yv^(-1)}, yw])/16 - 
     (G[{0}, yu^(-1)]*G[{1}, yw]*G[{yu}, yv^(-1)]*G[{0, yv^(-1)}, yw])/8 - 
     (G[{0}, yv^(-1)]*G[{1}, yw]*G[{yu}, yv^(-1)]*G[{0, yv^(-1)}, yw])/8 + 
     (G[{0}, yw]*G[{1}, yw]*G[{yu}, yv^(-1)]*G[{0, yv^(-1)}, yw])/8 + 
     (G[{1}, yu^(-1)]*G[{1}, yw]*G[{yu}, yv^(-1)]*G[{0, yv^(-1)}, yw])/8 + 
     (G[{1}, yv^(-1)]*G[{1}, yw]*G[{yu}, yv^(-1)]*G[{0, yv^(-1)}, yw])/8 + 
     (Pi^2*G[{1/(yu*yv)}, yw]*G[{0, yv^(-1)}, yw])/96 - 
     (G[{0}, yu^(-1)]^2*G[{1/(yu*yv)}, yw]*G[{0, yv^(-1)}, yw])/32 - 
     (G[{0}, yu^(-1)]*G[{0}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, yv^(-1)}, yw])/
      16 - (G[{0}, yv^(-1)]^2*G[{1/(yu*yv)}, yw]*G[{0, yv^(-1)}, yw])/32 + 
     (G[{0}, yu^(-1)]*G[{0}, yw]*G[{1/(yu*yv)}, yw]*G[{0, yv^(-1)}, yw])/16 + 
     (G[{0}, yv^(-1)]*G[{0}, yw]*G[{1/(yu*yv)}, yw]*G[{0, yv^(-1)}, yw])/16 - 
     (G[{0}, yw]^2*G[{1/(yu*yv)}, yw]*G[{0, yv^(-1)}, yw])/32 - 
     (G[{0}, yu^(-1)]*G[{1}, yu^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, yv^(-1)}, yw])/
      8 - (G[{0}, yv^(-1)]*G[{1}, yu^(-1)]*G[{1/(yu*yv)}, yw]*
       G[{0, yv^(-1)}, yw])/8 + (G[{0}, yw]*G[{1}, yu^(-1)]*
       G[{1/(yu*yv)}, yw]*G[{0, yv^(-1)}, yw])/8 + 
     (5*G[{1}, yu^(-1)]^2*G[{1/(yu*yv)}, yw]*G[{0, yv^(-1)}, yw])/32 + 
     (G[{0}, yu^(-1)]*G[{1}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, yv^(-1)}, yw])/
      8 + (G[{0}, yv^(-1)]*G[{1}, yv^(-1)]*G[{1/(yu*yv)}, yw]*
       G[{0, yv^(-1)}, yw])/8 - (G[{0}, yw]*G[{1}, yv^(-1)]*
       G[{1/(yu*yv)}, yw]*G[{0, yv^(-1)}, yw])/8 + 
     (G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, yv^(-1)}, yw])/
      16 - (3*G[{1}, yv^(-1)]^2*G[{1/(yu*yv)}, yw]*G[{0, yv^(-1)}, yw])/32 - 
     (G[{0}, yu^(-1)]*G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{0, yv^(-1)}, yw])/8 - 
     (G[{0}, yv^(-1)]*G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{0, yv^(-1)}, yw])/8 + 
     (G[{0}, yw]*G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{0, yv^(-1)}, yw])/8 + 
     (G[{1}, yu^(-1)]*G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{0, yv^(-1)}, yw])/8 + 
     (G[{1}, yv^(-1)]*G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{0, yv^(-1)}, yw])/8 + 
     (G[{1}, yu^(-1)]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*
       G[{0, yv^(-1)}, yw])/8 + (G[{1}, yw]*G[{yu^(-1)}, yw]*
       G[{1/(yu*yv)}, yw]*G[{0, yv^(-1)}, yw])/16 + 
     (G[{yu^(-1)}, yw]^2*G[{1/(yu*yv)}, yw]*G[{0, yv^(-1)}, yw])/16 + 
     (G[{0}, yu^(-1)]*G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw]*
       G[{0, yv^(-1)}, yw])/8 + (G[{0}, yv^(-1)]*G[{yu}, yv^(-1)]*
       G[{1/(yu*yv)}, yw]*G[{0, yv^(-1)}, yw])/8 - 
     (G[{0}, yw]*G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, yv^(-1)}, yw])/8 - 
     (G[{1}, yu^(-1)]*G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw]*
       G[{0, yv^(-1)}, yw])/8 - (G[{1}, yv^(-1)]*G[{yu}, yv^(-1)]*
       G[{1/(yu*yv)}, yw]*G[{0, yv^(-1)}, yw])/8 - 
     (G[{yu^(-1)}, yw]*G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw]*
       G[{0, yv^(-1)}, yw])/8 + (3*G[{0}, yu^(-1)]*G[{yv^(-1)}, yw]*
       G[{1/(yu*yv)}, yw]*G[{0, yv^(-1)}, yw])/16 + 
     (3*G[{0}, yv^(-1)]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*
       G[{0, yv^(-1)}, yw])/16 - (3*G[{0}, yw]*G[{yv^(-1)}, yw]*
       G[{1/(yu*yv)}, yw]*G[{0, yv^(-1)}, yw])/16 - 
     (G[{1}, yv^(-1)]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*
       G[{0, yv^(-1)}, yw])/4 + (G[{1}, yw]*G[{yv^(-1)}, yw]*
       G[{1/(yu*yv)}, yw]*G[{0, yv^(-1)}, yw])/16 - 
     (G[{yu}, yv^(-1)]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*
       G[{0, yv^(-1)}, yw])/8 - (G[{yv^(-1)}, yw]^2*G[{1/(yu*yv)}, yw]*
       G[{0, yv^(-1)}, yw])/8 - (G[{1}, yw]*G[{0, 1}, yw]*
       G[{0, yv^(-1)}, yw])/16 + (G[{1/(yu*yv)}, yw]*G[{0, 1}, yw]*
       G[{0, yv^(-1)}, yw])/16 + (G[{1}, yw]*G[{0, yu^(-1)}, yw]*
       G[{0, yv^(-1)}, yw])/16 - (G[{1/(yu*yv)}, yw]*G[{0, yu^(-1)}, yw]*
       G[{0, yv^(-1)}, yw])/16 + (G[{1}, yw]*G[{0, yv^(-1)}, yw]^2)/32 - 
     (G[{1/(yu*yv)}, yw]*G[{0, yv^(-1)}, yw]^2)/32 + 
     (Pi^2*G[{0}, yu^(-1)]*G[{0, 1/(yu*yv)}, yw])/96 + 
     (Pi^2*G[{0}, yv^(-1)]*G[{0, 1/(yu*yv)}, yw])/96 - 
     (Pi^2*G[{0}, yw]*G[{0, 1/(yu*yv)}, yw])/96 + 
     (Pi^2*G[{1}, yu^(-1)]*G[{0, 1/(yu*yv)}, yw])/48 - 
     (Pi^2*G[{1}, yv^(-1)]*G[{0, 1/(yu*yv)}, yw])/96 + 
     (Pi^2*G[{1}, yw]*G[{0, 1/(yu*yv)}, yw])/96 - 
     (G[{0}, yu^(-1)]^2*G[{1}, yw]*G[{0, 1/(yu*yv)}, yw])/32 - 
     (G[{0}, yu^(-1)]*G[{0}, yv^(-1)]*G[{1}, yw]*G[{0, 1/(yu*yv)}, yw])/16 - 
     (G[{0}, yv^(-1)]^2*G[{1}, yw]*G[{0, 1/(yu*yv)}, yw])/32 + 
     (G[{0}, yu^(-1)]*G[{0}, yw]*G[{1}, yw]*G[{0, 1/(yu*yv)}, yw])/16 + 
     (G[{0}, yv^(-1)]*G[{0}, yw]*G[{1}, yw]*G[{0, 1/(yu*yv)}, yw])/16 - 
     (G[{0}, yw]^2*G[{1}, yw]*G[{0, 1/(yu*yv)}, yw])/32 - 
     (G[{0}, yu^(-1)]*G[{1}, yu^(-1)]*G[{1}, yw]*G[{0, 1/(yu*yv)}, yw])/8 - 
     (G[{0}, yv^(-1)]*G[{1}, yu^(-1)]*G[{1}, yw]*G[{0, 1/(yu*yv)}, yw])/8 + 
     (G[{0}, yw]*G[{1}, yu^(-1)]*G[{1}, yw]*G[{0, 1/(yu*yv)}, yw])/8 + 
     (5*G[{1}, yu^(-1)]^2*G[{1}, yw]*G[{0, 1/(yu*yv)}, yw])/32 + 
     (G[{0}, yu^(-1)]*G[{1}, yv^(-1)]*G[{1}, yw]*G[{0, 1/(yu*yv)}, yw])/16 + 
     (G[{0}, yv^(-1)]*G[{1}, yv^(-1)]*G[{1}, yw]*G[{0, 1/(yu*yv)}, yw])/16 - 
     (G[{0}, yw]*G[{1}, yv^(-1)]*G[{1}, yw]*G[{0, 1/(yu*yv)}, yw])/16 + 
     (G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*G[{1}, yw]*G[{0, 1/(yu*yv)}, yw])/16 - 
     (G[{1}, yv^(-1)]^2*G[{1}, yw]*G[{0, 1/(yu*yv)}, yw])/32 - 
     (G[{0}, yu^(-1)]*G[{1}, yw]^2*G[{0, 1/(yu*yv)}, yw])/16 - 
     (G[{0}, yv^(-1)]*G[{1}, yw]^2*G[{0, 1/(yu*yv)}, yw])/16 + 
     (G[{0}, yw]*G[{1}, yw]^2*G[{0, 1/(yu*yv)}, yw])/16 + 
     (G[{1}, yu^(-1)]*G[{1}, yw]^2*G[{0, 1/(yu*yv)}, yw])/16 + 
     (G[{1}, yv^(-1)]*G[{1}, yw]^2*G[{0, 1/(yu*yv)}, yw])/16 - 
     (Pi^2*G[{yu}, yv^(-1)]*G[{0, 1/(yu*yv)}, yw])/48 + 
     (3*G[{0}, yu^(-1)]*G[{1}, yw]*G[{yu}, yv^(-1)]*G[{0, 1/(yu*yv)}, yw])/
      16 + (3*G[{0}, yv^(-1)]*G[{1}, yw]*G[{yu}, yv^(-1)]*
       G[{0, 1/(yu*yv)}, yw])/16 - (3*G[{0}, yw]*G[{1}, yw]*G[{yu}, yv^(-1)]*
       G[{0, 1/(yu*yv)}, yw])/16 - (G[{1}, yu^(-1)]*G[{1}, yw]*
       G[{yu}, yv^(-1)]*G[{0, 1/(yu*yv)}, yw])/8 - 
     (G[{1}, yv^(-1)]*G[{1}, yw]*G[{yu}, yv^(-1)]*G[{0, 1/(yu*yv)}, yw])/8 - 
     (G[{1}, yw]*G[{yu}, yv^(-1)]^2*G[{0, 1/(yu*yv)}, yw])/16 - 
     (Pi^2*G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv)}, yw])/96 + 
     (G[{0}, yu^(-1)]^2*G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv)}, yw])/32 + 
     (G[{0}, yu^(-1)]*G[{0}, yv^(-1)]*G[{1/(yu*yv)}, yw]*
       G[{0, 1/(yu*yv)}, yw])/16 + (G[{0}, yv^(-1)]^2*G[{1/(yu*yv)}, yw]*
       G[{0, 1/(yu*yv)}, yw])/32 - (G[{0}, yu^(-1)]*G[{0}, yw]*
       G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv)}, yw])/16 - 
     (G[{0}, yv^(-1)]*G[{0}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv)}, yw])/
      16 + (G[{0}, yw]^2*G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv)}, yw])/32 + 
     (G[{0}, yu^(-1)]*G[{1}, yu^(-1)]*G[{1/(yu*yv)}, yw]*
       G[{0, 1/(yu*yv)}, yw])/8 + (G[{0}, yv^(-1)]*G[{1}, yu^(-1)]*
       G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv)}, yw])/8 - 
     (G[{0}, yw]*G[{1}, yu^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv)}, yw])/
      8 - (5*G[{1}, yu^(-1)]^2*G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv)}, yw])/32 - 
     (G[{0}, yu^(-1)]*G[{1}, yv^(-1)]*G[{1/(yu*yv)}, yw]*
       G[{0, 1/(yu*yv)}, yw])/16 - (G[{0}, yv^(-1)]*G[{1}, yv^(-1)]*
       G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv)}, yw])/16 + 
     (G[{0}, yw]*G[{1}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv)}, yw])/
      16 - (G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*G[{1/(yu*yv)}, yw]*
       G[{0, 1/(yu*yv)}, yw])/16 + (G[{1}, yv^(-1)]^2*G[{1/(yu*yv)}, yw]*
       G[{0, 1/(yu*yv)}, yw])/32 + (G[{0}, yu^(-1)]*G[{1}, yw]*
       G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv)}, yw])/8 + 
     (G[{0}, yv^(-1)]*G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv)}, yw])/
      8 - (G[{0}, yw]*G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv)}, yw])/
      8 - (G[{1}, yu^(-1)]*G[{1}, yw]*G[{1/(yu*yv)}, yw]*
       G[{0, 1/(yu*yv)}, yw])/8 - (G[{1}, yv^(-1)]*G[{1}, yw]*
       G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv)}, yw])/8 - 
     (G[{1}, yu^(-1)]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*
       G[{0, 1/(yu*yv)}, yw])/8 - (G[{1}, yw]*G[{yu^(-1)}, yw]*
       G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv)}, yw])/16 - 
     (G[{yu^(-1)}, yw]^2*G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv)}, yw])/16 - 
     (3*G[{0}, yu^(-1)]*G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw]*
       G[{0, 1/(yu*yv)}, yw])/16 - (3*G[{0}, yv^(-1)]*G[{yu}, yv^(-1)]*
       G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv)}, yw])/16 + 
     (3*G[{0}, yw]*G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv)}, yw])/
      16 + (G[{1}, yu^(-1)]*G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw]*
       G[{0, 1/(yu*yv)}, yw])/8 + (G[{1}, yv^(-1)]*G[{yu}, yv^(-1)]*
       G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv)}, yw])/8 + 
     (G[{yu^(-1)}, yw]*G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw]*
       G[{0, 1/(yu*yv)}, yw])/8 + (G[{yu}, yv^(-1)]^2*G[{1/(yu*yv)}, yw]*
       G[{0, 1/(yu*yv)}, yw])/16 - (3*G[{0}, yu^(-1)]*G[{yv^(-1)}, yw]*
       G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv)}, yw])/16 - 
     (3*G[{0}, yv^(-1)]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*
       G[{0, 1/(yu*yv)}, yw])/16 + (3*G[{0}, yw]*G[{yv^(-1)}, yw]*
       G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv)}, yw])/16 + 
     (G[{1}, yv^(-1)]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*
       G[{0, 1/(yu*yv)}, yw])/4 - (G[{1}, yw]*G[{yv^(-1)}, yw]*
       G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv)}, yw])/16 + 
     (G[{yu}, yv^(-1)]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*
       G[{0, 1/(yu*yv)}, yw])/8 + (G[{yv^(-1)}, yw]^2*G[{1/(yu*yv)}, yw]*
       G[{0, 1/(yu*yv)}, yw])/8 + (G[{0}, yu^(-1)]*G[{0, 1}, yu^(-1)]*
       G[{0, 1/(yu*yv)}, yw])/16 + (G[{0}, yv^(-1)]*G[{0, 1}, yu^(-1)]*
       G[{0, 1/(yu*yv)}, yw])/16 - (G[{0}, yw]*G[{0, 1}, yu^(-1)]*
       G[{0, 1/(yu*yv)}, yw])/16 + (G[{1}, yu^(-1)]*G[{0, 1}, yu^(-1)]*
       G[{0, 1/(yu*yv)}, yw])/8 - (G[{1}, yv^(-1)]*G[{0, 1}, yu^(-1)]*
       G[{0, 1/(yu*yv)}, yw])/16 - (G[{yu}, yv^(-1)]*G[{0, 1}, yu^(-1)]*
       G[{0, 1/(yu*yv)}, yw])/8 + (G[{0}, yu^(-1)]*G[{0, 1}, yv^(-1)]*
       G[{0, 1/(yu*yv)}, yw])/16 + (G[{0}, yv^(-1)]*G[{0, 1}, yv^(-1)]*
       G[{0, 1/(yu*yv)}, yw])/16 - (G[{0}, yw]*G[{0, 1}, yv^(-1)]*
       G[{0, 1/(yu*yv)}, yw])/16 - (G[{1}, yv^(-1)]*G[{0, 1}, yv^(-1)]*
       G[{0, 1/(yu*yv)}, yw])/16 - (G[{yu}, yv^(-1)]*G[{0, 1}, yv^(-1)]*
       G[{0, 1/(yu*yv)}, yw])/8 - (G[{1}, yu^(-1)]*G[{0, 1}, yw]*
       G[{0, 1/(yu*yv)}, yw])/8 + (G[{1}, yv^(-1)]*G[{0, 1}, yw]*
       G[{0, 1/(yu*yv)}, yw])/16 + (G[{1}, yw]*G[{0, 1}, yw]*
       G[{0, 1/(yu*yv)}, yw])/16 + (G[{yu}, yv^(-1)]*G[{0, 1}, yw]*
       G[{0, 1/(yu*yv)}, yw])/16 - (G[{1/(yu*yv)}, yw]*G[{0, 1}, yw]*
       G[{0, 1/(yu*yv)}, yw])/16 + (G[{1}, yu^(-1)]*G[{0, yu^(-1)}, yw]*
       G[{0, 1/(yu*yv)}, yw])/8 - (G[{1}, yw]*G[{0, yu^(-1)}, yw]*
       G[{0, 1/(yu*yv)}, yw])/16 - (G[{yu}, yv^(-1)]*G[{0, yu^(-1)}, yw]*
       G[{0, 1/(yu*yv)}, yw])/8 + (G[{1/(yu*yv)}, yw]*G[{0, yu^(-1)}, yw]*
       G[{0, 1/(yu*yv)}, yw])/16 - (G[{0}, yu^(-1)]*G[{0, yu}, yv^(-1)]*
       G[{0, 1/(yu*yv)}, yw])/16 - (G[{0}, yv^(-1)]*G[{0, yu}, yv^(-1)]*
       G[{0, 1/(yu*yv)}, yw])/16 + (G[{0}, yw]*G[{0, yu}, yv^(-1)]*
       G[{0, 1/(yu*yv)}, yw])/16 + (G[{1}, yv^(-1)]*G[{0, yu}, yv^(-1)]*
       G[{0, 1/(yu*yv)}, yw])/16 + (G[{yu}, yv^(-1)]*G[{0, yu}, yv^(-1)]*
       G[{0, 1/(yu*yv)}, yw])/8 + (3*G[{1}, yu^(-1)]*G[{0, yv^(-1)}, yw]*
       G[{0, 1/(yu*yv)}, yw])/16 - (G[{1}, yv^(-1)]*G[{0, yv^(-1)}, yw]*
       G[{0, 1/(yu*yv)}, yw])/16 - (G[{1}, yw]*G[{0, yv^(-1)}, yw]*
       G[{0, 1/(yu*yv)}, yw])/16 - (G[{yu}, yv^(-1)]*G[{0, yv^(-1)}, yw]*
       G[{0, 1/(yu*yv)}, yw])/8 + (G[{1/(yu*yv)}, yw]*G[{0, yv^(-1)}, yw]*
       G[{0, 1/(yu*yv)}, yw])/16 - 
     (3*G[{1}, yu^(-1)]*G[{0, 1/(yu*yv)}, yw]^2)/32 + 
     (G[{1}, yw]*G[{0, 1/(yu*yv)}, yw]^2)/32 + 
     (3*G[{yu}, yv^(-1)]*G[{0, 1/(yu*yv)}, yw]^2)/32 - 
     (G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv)}, yw]^2)/32 - 
     (Pi^2*G[{0}, yu^(-1)]*G[{1, yu^(-1)}, yw])/96 - 
     (Pi^2*G[{0}, yv^(-1)]*G[{1, yu^(-1)}, yw])/96 + 
     (Pi^2*G[{0}, yw]*G[{1, yu^(-1)}, yw])/96 + 
     (Pi^2*G[{1}, yu^(-1)]*G[{1, yu^(-1)}, yw])/96 - 
     (G[{0}, yu^(-1)]^2*G[{1}, yu^(-1)]*G[{1, yu^(-1)}, yw])/32 - 
     (G[{0}, yu^(-1)]*G[{0}, yv^(-1)]*G[{1}, yu^(-1)]*G[{1, yu^(-1)}, yw])/
      16 - (G[{0}, yv^(-1)]^2*G[{1}, yu^(-1)]*G[{1, yu^(-1)}, yw])/32 + 
     (G[{0}, yu^(-1)]*G[{0}, yw]*G[{1}, yu^(-1)]*G[{1, yu^(-1)}, yw])/16 + 
     (G[{0}, yv^(-1)]*G[{0}, yw]*G[{1}, yu^(-1)]*G[{1, yu^(-1)}, yw])/16 - 
     (G[{0}, yw]^2*G[{1}, yu^(-1)]*G[{1, yu^(-1)}, yw])/32 - 
     (G[{0}, yu^(-1)]*G[{1}, yu^(-1)]^2*G[{1, yu^(-1)}, yw])/32 - 
     (G[{0}, yv^(-1)]*G[{1}, yu^(-1)]^2*G[{1, yu^(-1)}, yw])/32 + 
     (G[{0}, yw]*G[{1}, yu^(-1)]^2*G[{1, yu^(-1)}, yw])/32 + 
     (5*G[{1}, yu^(-1)]^3*G[{1, yu^(-1)}, yw])/128 + 
     (G[{0}, yu^(-1)]^2*G[{1}, yv^(-1)]*G[{1, yu^(-1)}, yw])/32 + 
     (G[{0}, yu^(-1)]*G[{0}, yv^(-1)]*G[{1}, yv^(-1)]*G[{1, yu^(-1)}, yw])/
      16 + (G[{0}, yv^(-1)]^2*G[{1}, yv^(-1)]*G[{1, yu^(-1)}, yw])/32 - 
     (G[{0}, yu^(-1)]*G[{0}, yw]*G[{1}, yv^(-1)]*G[{1, yu^(-1)}, yw])/16 - 
     (G[{0}, yv^(-1)]*G[{0}, yw]*G[{1}, yv^(-1)]*G[{1, yu^(-1)}, yw])/16 + 
     (G[{0}, yw]^2*G[{1}, yv^(-1)]*G[{1, yu^(-1)}, yw])/32 + 
     (G[{0}, yu^(-1)]*G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*G[{1, yu^(-1)}, yw])/
      16 + (G[{0}, yv^(-1)]*G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*
       G[{1, yu^(-1)}, yw])/16 - (G[{0}, yw]*G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*
       G[{1, yu^(-1)}, yw])/16 + (5*G[{1}, yu^(-1)]^2*G[{1}, yv^(-1)]*
       G[{1, yu^(-1)}, yw])/128 - (G[{0}, yu^(-1)]*G[{1}, yv^(-1)]^2*
       G[{1, yu^(-1)}, yw])/16 - (G[{0}, yv^(-1)]*G[{1}, yv^(-1)]^2*
       G[{1, yu^(-1)}, yw])/16 + (G[{0}, yw]*G[{1}, yv^(-1)]^2*
       G[{1, yu^(-1)}, yw])/16 - (11*G[{1}, yu^(-1)]*G[{1}, yv^(-1)]^2*
       G[{1, yu^(-1)}, yw])/128 + (G[{1}, yv^(-1)]^3*G[{1, yu^(-1)}, yw])/
      32 - (Pi^2*G[{1}, yw]*G[{1, yu^(-1)}, yw])/48 + 
     (G[{0}, yu^(-1)]^2*G[{1}, yw]*G[{1, yu^(-1)}, yw])/32 + 
     (G[{0}, yu^(-1)]*G[{0}, yv^(-1)]*G[{1}, yw]*G[{1, yu^(-1)}, yw])/16 + 
     (G[{0}, yv^(-1)]^2*G[{1}, yw]*G[{1, yu^(-1)}, yw])/32 - 
     (G[{0}, yu^(-1)]*G[{0}, yw]*G[{1}, yw]*G[{1, yu^(-1)}, yw])/16 - 
     (G[{0}, yv^(-1)]*G[{0}, yw]*G[{1}, yw]*G[{1, yu^(-1)}, yw])/16 + 
     (G[{0}, yw]^2*G[{1}, yw]*G[{1, yu^(-1)}, yw])/32 - 
     (G[{0}, yu^(-1)]*G[{1}, yu^(-1)]*G[{1}, yw]*G[{1, yu^(-1)}, yw])/16 - 
     (G[{0}, yv^(-1)]*G[{1}, yu^(-1)]*G[{1}, yw]*G[{1, yu^(-1)}, yw])/16 + 
     (G[{0}, yw]*G[{1}, yu^(-1)]*G[{1}, yw]*G[{1, yu^(-1)}, yw])/16 + 
     (3*G[{1}, yu^(-1)]^2*G[{1}, yw]*G[{1, yu^(-1)}, yw])/128 + 
     (3*G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*G[{1}, yw]*G[{1, yu^(-1)}, yw])/64 - 
     (G[{1}, yv^(-1)]^2*G[{1}, yw]*G[{1, yu^(-1)}, yw])/32 + 
     (G[{0}, yu^(-1)]*G[{1}, yw]^2*G[{1, yu^(-1)}, yw])/16 + 
     (G[{0}, yv^(-1)]*G[{1}, yw]^2*G[{1, yu^(-1)}, yw])/16 - 
     (G[{0}, yw]*G[{1}, yw]^2*G[{1, yu^(-1)}, yw])/16 - 
     (G[{1}, yu^(-1)]*G[{1}, yw]^2*G[{1, yu^(-1)}, yw])/128 + 
     (5*G[{1}, yw]^3*G[{1, yu^(-1)}, yw])/128 + 
     (Pi^2*G[{yu}, yv^(-1)]*G[{1, yu^(-1)}, yw])/96 + 
     (G[{0}, yu^(-1)]*G[{1}, yu^(-1)]*G[{yu}, yv^(-1)]*G[{1, yu^(-1)}, yw])/
      8 + (G[{0}, yv^(-1)]*G[{1}, yu^(-1)]*G[{yu}, yv^(-1)]*
       G[{1, yu^(-1)}, yw])/8 - (G[{0}, yw]*G[{1}, yu^(-1)]*G[{yu}, yv^(-1)]*
       G[{1, yu^(-1)}, yw])/8 - (3*G[{1}, yu^(-1)]^2*G[{yu}, yv^(-1)]*
       G[{1, yu^(-1)}, yw])/32 - (G[{0}, yu^(-1)]*G[{1}, yv^(-1)]*
       G[{yu}, yv^(-1)]*G[{1, yu^(-1)}, yw])/8 - 
     (G[{0}, yv^(-1)]*G[{1}, yv^(-1)]*G[{yu}, yv^(-1)]*G[{1, yu^(-1)}, yw])/
      8 + (G[{0}, yw]*G[{1}, yv^(-1)]*G[{yu}, yv^(-1)]*G[{1, yu^(-1)}, yw])/
      8 - (G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*G[{yu}, yv^(-1)]*
       G[{1, yu^(-1)}, yw])/16 + (G[{1}, yv^(-1)]^2*G[{yu}, yv^(-1)]*
       G[{1, yu^(-1)}, yw])/8 - (G[{0}, yu^(-1)]*G[{1}, yw]*G[{yu}, yv^(-1)]*
       G[{1, yu^(-1)}, yw])/16 - (G[{0}, yv^(-1)]*G[{1}, yw]*G[{yu}, yv^(-1)]*
       G[{1, yu^(-1)}, yw])/16 + (G[{0}, yw]*G[{1}, yw]*G[{yu}, yv^(-1)]*
       G[{1, yu^(-1)}, yw])/16 + (G[{1}, yu^(-1)]*G[{1}, yw]*G[{yu}, yv^(-1)]*
       G[{1, yu^(-1)}, yw])/32 - (G[{1}, yv^(-1)]*G[{1}, yw]*G[{yu}, yv^(-1)]*
       G[{1, yu^(-1)}, yw])/8 - (15*G[{1}, yw]^2*G[{yu}, yv^(-1)]*
       G[{1, yu^(-1)}, yw])/128 + (G[{1}, yv^(-1)]*G[{yu}, yv^(-1)]^2*
       G[{1, yu^(-1)}, yw])/16 + (7*G[{1}, yw]*G[{yu}, yv^(-1)]^2*
       G[{1, yu^(-1)}, yw])/64 - (G[{yu}, yv^(-1)]^3*G[{1, yu^(-1)}, yw])/
      48 - (Pi^2*G[{1/(yu*yv)}, yw]*G[{1, yu^(-1)}, yw])/48 + 
     (G[{0}, yu^(-1)]^2*G[{1/(yu*yv)}, yw]*G[{1, yu^(-1)}, yw])/16 + 
     (G[{0}, yu^(-1)]*G[{0}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{1, yu^(-1)}, yw])/
      8 + (G[{0}, yv^(-1)]^2*G[{1/(yu*yv)}, yw]*G[{1, yu^(-1)}, yw])/16 - 
     (G[{0}, yu^(-1)]*G[{0}, yw]*G[{1/(yu*yv)}, yw]*G[{1, yu^(-1)}, yw])/8 - 
     (G[{0}, yv^(-1)]*G[{0}, yw]*G[{1/(yu*yv)}, yw]*G[{1, yu^(-1)}, yw])/8 + 
     (G[{0}, yw]^2*G[{1/(yu*yv)}, yw]*G[{1, yu^(-1)}, yw])/16 + 
     (G[{0}, yu^(-1)]*G[{1}, yu^(-1)]*G[{1/(yu*yv)}, yw]*G[{1, yu^(-1)}, yw])/
      16 + (G[{0}, yv^(-1)]*G[{1}, yu^(-1)]*G[{1/(yu*yv)}, yw]*
       G[{1, yu^(-1)}, yw])/16 - (G[{0}, yw]*G[{1}, yu^(-1)]*
       G[{1/(yu*yv)}, yw]*G[{1, yu^(-1)}, yw])/16 - 
     (11*G[{1}, yu^(-1)]^2*G[{1/(yu*yv)}, yw]*G[{1, yu^(-1)}, yw])/128 - 
     (G[{0}, yu^(-1)]*G[{1}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{1, yu^(-1)}, yw])/
      8 - (G[{0}, yv^(-1)]*G[{1}, yv^(-1)]*G[{1/(yu*yv)}, yw]*
       G[{1, yu^(-1)}, yw])/8 + (G[{0}, yw]*G[{1}, yv^(-1)]*
       G[{1/(yu*yv)}, yw]*G[{1, yu^(-1)}, yw])/8 - 
     (11*G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*G[{1/(yu*yv)}, yw]*
       G[{1, yu^(-1)}, yw])/64 + (G[{1}, yv^(-1)]^2*G[{1/(yu*yv)}, yw]*
       G[{1, yu^(-1)}, yw])/16 + (G[{0}, yu^(-1)]*G[{1}, yw]*
       G[{1/(yu*yv)}, yw]*G[{1, yu^(-1)}, yw])/8 + 
     (G[{0}, yv^(-1)]*G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{1, yu^(-1)}, yw])/8 - 
     (G[{0}, yw]*G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{1, yu^(-1)}, yw])/8 - 
     (7*G[{1}, yu^(-1)]*G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{1, yu^(-1)}, yw])/
      64 - (3*G[{1}, yv^(-1)]*G[{1}, yw]*G[{1/(yu*yv)}, yw]*
       G[{1, yu^(-1)}, yw])/16 - (3*G[{1}, yw]^2*G[{1/(yu*yv)}, yw]*
       G[{1, yu^(-1)}, yw])/128 - (G[{0}, yu^(-1)]*G[{yu^(-1)}, yw]*
       G[{1/(yu*yv)}, yw]*G[{1, yu^(-1)}, yw])/16 - 
     (G[{0}, yv^(-1)]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*
       G[{1, yu^(-1)}, yw])/16 + (G[{0}, yw]*G[{yu^(-1)}, yw]*
       G[{1/(yu*yv)}, yw]*G[{1, yu^(-1)}, yw])/16 - 
     (G[{1}, yu^(-1)]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*
       G[{1, yu^(-1)}, yw])/8 + (G[{1}, yv^(-1)]*G[{yu^(-1)}, yw]*
       G[{1/(yu*yv)}, yw]*G[{1, yu^(-1)}, yw])/16 - 
     (3*G[{1}, yw]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{1, yu^(-1)}, yw])/
      16 - (G[{yu^(-1)}, yw]^2*G[{1/(yu*yv)}, yw]*G[{1, yu^(-1)}, yw])/8 - 
     (3*G[{0}, yu^(-1)]*G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw]*
       G[{1, yu^(-1)}, yw])/16 - (3*G[{0}, yv^(-1)]*G[{yu}, yv^(-1)]*
       G[{1/(yu*yv)}, yw]*G[{1, yu^(-1)}, yw])/16 + 
     (3*G[{0}, yw]*G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{1, yu^(-1)}, yw])/
      16 + (7*G[{1}, yu^(-1)]*G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw]*
       G[{1, yu^(-1)}, yw])/32 + (5*G[{1}, yv^(-1)]*G[{yu}, yv^(-1)]*
       G[{1/(yu*yv)}, yw]*G[{1, yu^(-1)}, yw])/16 + 
     (3*G[{1}, yw]*G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{1, yu^(-1)}, yw])/
      64 + (3*G[{yu^(-1)}, yw]*G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw]*
       G[{1, yu^(-1)}, yw])/16 - (5*G[{yu}, yv^(-1)]^2*G[{1/(yu*yv)}, yw]*
       G[{1, yu^(-1)}, yw])/64 - (3*G[{0}, yu^(-1)]*G[{yv^(-1)}, yw]*
       G[{1/(yu*yv)}, yw]*G[{1, yu^(-1)}, yw])/16 - 
     (3*G[{0}, yv^(-1)]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*
       G[{1, yu^(-1)}, yw])/16 + (3*G[{0}, yw]*G[{yv^(-1)}, yw]*
       G[{1/(yu*yv)}, yw]*G[{1, yu^(-1)}, yw])/16 + 
     (G[{1}, yu^(-1)]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*
       G[{1, yu^(-1)}, yw])/32 + (5*G[{1}, yv^(-1)]*G[{yv^(-1)}, yw]*
       G[{1/(yu*yv)}, yw]*G[{1, yu^(-1)}, yw])/16 - 
     (G[{1}, yw]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{1, yu^(-1)}, yw])/
      32 + (G[{yu}, yv^(-1)]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*
       G[{1, yu^(-1)}, yw])/32 + (7*G[{yv^(-1)}, yw]^2*G[{1/(yu*yv)}, yw]*
       G[{1, yu^(-1)}, yw])/64 + (G[{0}, yu^(-1)]*G[{1/(yu*yv)}, yw]^2*
       G[{1, yu^(-1)}, yw])/16 + (G[{0}, yv^(-1)]*G[{1/(yu*yv)}, yw]^2*
       G[{1, yu^(-1)}, yw])/16 - (G[{0}, yw]*G[{1/(yu*yv)}, yw]^2*
       G[{1, yu^(-1)}, yw])/16 - (7*G[{1}, yu^(-1)]*G[{1/(yu*yv)}, yw]^2*
       G[{1, yu^(-1)}, yw])/128 - (G[{1}, yv^(-1)]*G[{1/(yu*yv)}, yw]^2*
       G[{1, yu^(-1)}, yw])/16 + (G[{1}, yw]*G[{1/(yu*yv)}, yw]^2*
       G[{1, yu^(-1)}, yw])/128 + (G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2*
       G[{1, yu^(-1)}, yw])/16 - (G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw]^2*
       G[{1, yu^(-1)}, yw])/128 + (7*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2*
       G[{1, yu^(-1)}, yw])/128 - (G[{1}, yu^(-1)]*G[{0, 1}, yu^(-1)]*
       G[{1, yu^(-1)}, yw])/64 - (3*G[{1}, yv^(-1)]*G[{0, 1}, yu^(-1)]*
       G[{1, yu^(-1)}, yw])/64 - (5*G[{1}, yw]*G[{0, 1}, yu^(-1)]*
       G[{1, yu^(-1)}, yw])/64 + (G[{yu}, yv^(-1)]*G[{0, 1}, yu^(-1)]*
       G[{1, yu^(-1)}, yw])/16 - (3*G[{1/(yu*yv)}, yw]*G[{0, 1}, yu^(-1)]*
       G[{1, yu^(-1)}, yw])/64 + (G[{0}, yu^(-1)]*G[{0, 1}, yv^(-1)]*
       G[{1, yu^(-1)}, yw])/16 + (G[{0}, yv^(-1)]*G[{0, 1}, yv^(-1)]*
       G[{1, yu^(-1)}, yw])/16 - (G[{0}, yw]*G[{0, 1}, yv^(-1)]*
       G[{1, yu^(-1)}, yw])/16 - (G[{1}, yv^(-1)]*G[{0, 1}, yv^(-1)]*
       G[{1, yu^(-1)}, yw])/16 + (G[{1}, yw]*G[{0, 1}, yv^(-1)]*
       G[{1, yu^(-1)}, yw])/16 - (G[{1/(yu*yv)}, yw]*G[{0, 1}, yv^(-1)]*
       G[{1, yu^(-1)}, yw])/16 + (G[{1}, yu^(-1)]*G[{0, 1}, yw]*
       G[{1, yu^(-1)}, yw])/8 + (G[{1}, yw]*G[{0, 1}, yw]*
       G[{1, yu^(-1)}, yw])/16 - (G[{yu}, yv^(-1)]*G[{0, 1}, yw]*
       G[{1, yu^(-1)}, yw])/8 - (G[{1/(yu*yv)}, yw]*G[{0, 1}, yw]*
       G[{1, yu^(-1)}, yw])/16 - (G[{1}, yu^(-1)]*G[{0, yu^(-1)}, yw]*
       G[{1, yu^(-1)}, yw])/8 - (G[{1}, yw]*G[{0, yu^(-1)}, yw]*
       G[{1, yu^(-1)}, yw])/16 + (G[{yu}, yv^(-1)]*G[{0, yu^(-1)}, yw]*
       G[{1, yu^(-1)}, yw])/8 + (G[{1/(yu*yv)}, yw]*G[{0, yu^(-1)}, yw]*
       G[{1, yu^(-1)}, yw])/16 - (G[{0}, yu^(-1)]*G[{0, yu}, yv^(-1)]*
       G[{1, yu^(-1)}, yw])/16 - (G[{0}, yv^(-1)]*G[{0, yu}, yv^(-1)]*
       G[{1, yu^(-1)}, yw])/16 + (G[{0}, yw]*G[{0, yu}, yv^(-1)]*
       G[{1, yu^(-1)}, yw])/16 + (G[{1}, yv^(-1)]*G[{0, yu}, yv^(-1)]*
       G[{1, yu^(-1)}, yw])/16 - (G[{1}, yw]*G[{0, yu}, yv^(-1)]*
       G[{1, yu^(-1)}, yw])/16 + (G[{1/(yu*yv)}, yw]*G[{0, yu}, yv^(-1)]*
       G[{1, yu^(-1)}, yw])/16 - (G[{1}, yu^(-1)]*G[{0, yv^(-1)}, yw]*
       G[{1, yu^(-1)}, yw])/8 - (G[{1}, yw]*G[{0, yv^(-1)}, yw]*
       G[{1, yu^(-1)}, yw])/16 + (G[{yu}, yv^(-1)]*G[{0, yv^(-1)}, yw]*
       G[{1, yu^(-1)}, yw])/8 + (G[{1/(yu*yv)}, yw]*G[{0, yv^(-1)}, yw]*
       G[{1, yu^(-1)}, yw])/16 + (G[{1}, yu^(-1)]*G[{0, 1/(yu*yv)}, yw]*
       G[{1, yu^(-1)}, yw])/8 + (G[{1}, yw]*G[{0, 1/(yu*yv)}, yw]*
       G[{1, yu^(-1)}, yw])/16 - (G[{yu}, yv^(-1)]*G[{0, 1/(yu*yv)}, yw]*
       G[{1, yu^(-1)}, yw])/8 - (G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv)}, yw]*
       G[{1, yu^(-1)}, yw])/16 + (G[{0}, yu^(-1)]*G[{1, yu^(-1)}, yw]^2)/32 + 
     (G[{0}, yv^(-1)]*G[{1, yu^(-1)}, yw]^2)/32 - 
     (G[{0}, yw]*G[{1, yu^(-1)}, yw]^2)/32 + 
     (G[{1}, yu^(-1)]*G[{1, yu^(-1)}, yw]^2)/16 - 
     (G[{1}, yv^(-1)]*G[{1, yu^(-1)}, yw]^2)/32 + 
     (3*G[{1}, yw]*G[{1, yu^(-1)}, yw]^2)/32 - 
     (3*G[{yu}, yv^(-1)]*G[{1, yu^(-1)}, yw]^2)/32 - 
     (G[{1/(yu*yv)}, yw]*G[{1, yu^(-1)}, yw]^2)/16 - 
     (7*Pi^2*G[{1}, yu^(-1)]*G[{1, yu}, yv^(-1)])/768 - 
     (3*G[{1}, yu^(-1)]^3*G[{1, yu}, yv^(-1)])/128 - 
     (Pi^2*G[{1}, yv^(-1)]*G[{1, yu}, yv^(-1)])/96 - 
     (G[{1}, yu^(-1)]^2*G[{1}, yv^(-1)]*G[{1, yu}, yv^(-1)])/128 - 
     (3*G[{1}, yu^(-1)]*G[{1}, yv^(-1)]^2*G[{1, yu}, yv^(-1)])/128 - 
     (Pi^2*G[{1}, yw]*G[{1, yu}, yv^(-1)])/256 - 
     (11*G[{1}, yu^(-1)]^2*G[{1}, yw]*G[{1, yu}, yv^(-1)])/128 + 
     (G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*G[{1}, yw]*G[{1, yu}, yv^(-1)])/16 + 
     (3*G[{1}, yv^(-1)]^2*G[{1}, yw]*G[{1, yu}, yv^(-1)])/128 + 
     (3*G[{0}, yu^(-1)]*G[{1}, yw]^2*G[{1, yu}, yv^(-1)])/32 + 
     (3*G[{0}, yv^(-1)]*G[{1}, yw]^2*G[{1, yu}, yv^(-1)])/32 - 
     (3*G[{0}, yw]*G[{1}, yw]^2*G[{1, yu}, yv^(-1)])/32 - 
     (9*G[{1}, yu^(-1)]*G[{1}, yw]^2*G[{1, yu}, yv^(-1)])/64 - 
     (G[{1}, yv^(-1)]*G[{1}, yw]^2*G[{1, yu}, yv^(-1)])/64 + 
     (7*G[{1}, yw]^3*G[{1, yu}, yv^(-1)])/128 + 
     (G[{1}, yu^(-1)]*G[{1}, yw]*G[{yu}, yv^(-1)]*G[{1, yu}, yv^(-1)])/16 - 
     (G[{1}, yv^(-1)]*G[{1}, yw]*G[{yu}, yv^(-1)]*G[{1, yu}, yv^(-1)])/16 - 
     (G[{1}, yw]^2*G[{yu}, yv^(-1)]*G[{1, yu}, yv^(-1)])/16 - 
     (G[{1}, yw]*G[{yu}, yv^(-1)]^2*G[{1, yu}, yv^(-1)])/64 + 
     (Pi^2*G[{1/(yu*yv)}, yw]*G[{1, yu}, yv^(-1)])/256 + 
     (11*G[{1}, yu^(-1)]^2*G[{1/(yu*yv)}, yw]*G[{1, yu}, yv^(-1)])/128 - 
     (G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{1, yu}, yv^(-1)])/
      16 - (3*G[{1}, yv^(-1)]^2*G[{1/(yu*yv)}, yw]*G[{1, yu}, yv^(-1)])/128 - 
     (3*G[{0}, yu^(-1)]*G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{1, yu}, yv^(-1)])/
      16 - (3*G[{0}, yv^(-1)]*G[{1}, yw]*G[{1/(yu*yv)}, yw]*
       G[{1, yu}, yv^(-1)])/16 + (3*G[{0}, yw]*G[{1}, yw]*G[{1/(yu*yv)}, yw]*
       G[{1, yu}, yv^(-1)])/16 + (9*G[{1}, yu^(-1)]*G[{1}, yw]*
       G[{1/(yu*yv)}, yw]*G[{1, yu}, yv^(-1)])/32 + 
     (G[{1}, yv^(-1)]*G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{1, yu}, yv^(-1)])/32 - 
     (21*G[{1}, yw]^2*G[{1/(yu*yv)}, yw]*G[{1, yu}, yv^(-1)])/128 - 
     (G[{0}, yu^(-1)]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*
       G[{1, yu}, yv^(-1)])/16 - (G[{0}, yv^(-1)]*G[{yu^(-1)}, yw]*
       G[{1/(yu*yv)}, yw]*G[{1, yu}, yv^(-1)])/16 + 
     (G[{0}, yw]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{1, yu}, yv^(-1)])/
      16 - (G[{1}, yu^(-1)]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*
       G[{1, yu}, yv^(-1)])/32 - (9*G[{1}, yw]*G[{yu^(-1)}, yw]*
       G[{1/(yu*yv)}, yw]*G[{1, yu}, yv^(-1)])/64 - 
     (G[{yu^(-1)}, yw]^2*G[{1/(yu*yv)}, yw]*G[{1, yu}, yv^(-1)])/32 - 
     (G[{1}, yu^(-1)]*G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw]*
       G[{1, yu}, yv^(-1)])/16 + (G[{1}, yv^(-1)]*G[{yu}, yv^(-1)]*
       G[{1/(yu*yv)}, yw]*G[{1, yu}, yv^(-1)])/16 + 
     (G[{1}, yw]*G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{1, yu}, yv^(-1)])/8 + 
     (G[{yu^(-1)}, yw]*G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw]*
       G[{1, yu}, yv^(-1)])/16 + (G[{yu}, yv^(-1)]^2*G[{1/(yu*yv)}, yw]*
       G[{1, yu}, yv^(-1)])/64 + (G[{0}, yu^(-1)]*G[{yv^(-1)}, yw]*
       G[{1/(yu*yv)}, yw]*G[{1, yu}, yv^(-1)])/16 + 
     (G[{0}, yv^(-1)]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*
       G[{1, yu}, yv^(-1)])/16 - (G[{0}, yw]*G[{yv^(-1)}, yw]*
       G[{1/(yu*yv)}, yw]*G[{1, yu}, yv^(-1)])/16 - 
     (G[{1}, yu^(-1)]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*
       G[{1, yu}, yv^(-1)])/32 + (G[{1}, yv^(-1)]*G[{yv^(-1)}, yw]*
       G[{1/(yu*yv)}, yw]*G[{1, yu}, yv^(-1)])/16 - 
     (G[{1}, yw]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{1, yu}, yv^(-1)])/
      16 - (G[{yu}, yv^(-1)]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*
       G[{1, yu}, yv^(-1)])/32 + (3*G[{yv^(-1)}, yw]^2*G[{1/(yu*yv)}, yw]*
       G[{1, yu}, yv^(-1)])/64 + (3*G[{0}, yu^(-1)]*G[{1/(yu*yv)}, yw]^2*
       G[{1, yu}, yv^(-1)])/32 + (3*G[{0}, yv^(-1)]*G[{1/(yu*yv)}, yw]^2*
       G[{1, yu}, yv^(-1)])/32 - (3*G[{0}, yw]*G[{1/(yu*yv)}, yw]^2*
       G[{1, yu}, yv^(-1)])/32 - (7*G[{1}, yu^(-1)]*G[{1/(yu*yv)}, yw]^2*
       G[{1, yu}, yv^(-1)])/64 - (3*G[{1}, yv^(-1)]*G[{1/(yu*yv)}, yw]^2*
       G[{1, yu}, yv^(-1)])/64 + (5*G[{1}, yw]*G[{1/(yu*yv)}, yw]^2*
       G[{1, yu}, yv^(-1)])/64 + (3*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2*
       G[{1, yu}, yv^(-1)])/64 - (5*G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw]^2*
       G[{1, yu}, yv^(-1)])/64 + (G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2*
       G[{1, yu}, yv^(-1)])/16 + (G[{1}, yu^(-1)]*G[{0, 1}, yu^(-1)]*
       G[{1, yu}, yv^(-1)])/64 - (5*G[{1}, yv^(-1)]*G[{0, 1}, yu^(-1)]*
       G[{1, yu}, yv^(-1)])/64 + (G[{1}, yw]*G[{0, 1}, yu^(-1)]*
       G[{1, yu}, yv^(-1)])/32 - (G[{1/(yu*yv)}, yw]*G[{0, 1}, yu^(-1)]*
       G[{1, yu}, yv^(-1)])/32 + (G[{1}, yu^(-1)]*G[{0, 1}, yv^(-1)]*
       G[{1, yu}, yv^(-1)])/32 + (G[{1}, yw]*G[{0, 1}, yv^(-1)]*
       G[{1, yu}, yv^(-1)])/64 - (G[{1/(yu*yv)}, yw]*G[{0, 1}, yv^(-1)]*
       G[{1, yu}, yv^(-1)])/64 - (G[{1}, yu^(-1)]*G[{0, yu}, yv^(-1)]*
       G[{1, yu}, yv^(-1)])/32 - (G[{1}, yw]*G[{0, yu}, yv^(-1)]*
       G[{1, yu}, yv^(-1)])/64 + (G[{1/(yu*yv)}, yw]*G[{0, yu}, yv^(-1)]*
       G[{1, yu}, yv^(-1)])/64 + (G[{0}, yu^(-1)]*G[{1, yu^(-1)}, yw]*
       G[{1, yu}, yv^(-1)])/16 + (G[{0}, yv^(-1)]*G[{1, yu^(-1)}, yw]*
       G[{1, yu}, yv^(-1)])/16 - (G[{0}, yw]*G[{1, yu^(-1)}, yw]*
       G[{1, yu}, yv^(-1)])/16 + (G[{1}, yu^(-1)]*G[{1, yu^(-1)}, yw]*
       G[{1, yu}, yv^(-1)])/32 + (9*G[{1}, yw]*G[{1, yu^(-1)}, yw]*
       G[{1, yu}, yv^(-1)])/64 - (G[{yu}, yv^(-1)]*G[{1, yu^(-1)}, yw]*
       G[{1, yu}, yv^(-1)])/16 - (G[{1/(yu*yv)}, yw]*G[{1, yu^(-1)}, yw]*
       G[{1, yu}, yv^(-1)])/64 + (G[{1}, yv^(-1)]*G[{1, yu}, yv^(-1)]^2)/32 - 
     (G[{1}, yw]*G[{1, yu}, yv^(-1)]^2)/128 + 
     (G[{1/(yu*yv)}, yw]*G[{1, yu}, yv^(-1)]^2)/128 + 
     (Pi^2*G[{0}, yu^(-1)]*G[{1, yv^(-1)}, yw])/48 + 
     (Pi^2*G[{0}, yv^(-1)]*G[{1, yv^(-1)}, yw])/48 - 
     (Pi^2*G[{0}, yw]*G[{1, yv^(-1)}, yw])/48 - 
     (11*Pi^2*G[{1}, yu^(-1)]*G[{1, yv^(-1)}, yw])/256 + 
     (G[{0}, yu^(-1)]^2*G[{1}, yu^(-1)]*G[{1, yv^(-1)}, yw])/32 + 
     (G[{0}, yu^(-1)]*G[{0}, yv^(-1)]*G[{1}, yu^(-1)]*G[{1, yv^(-1)}, yw])/
      16 + (G[{0}, yv^(-1)]^2*G[{1}, yu^(-1)]*G[{1, yv^(-1)}, yw])/32 - 
     (G[{0}, yu^(-1)]*G[{0}, yw]*G[{1}, yu^(-1)]*G[{1, yv^(-1)}, yw])/16 - 
     (G[{0}, yv^(-1)]*G[{0}, yw]*G[{1}, yu^(-1)]*G[{1, yv^(-1)}, yw])/16 + 
     (G[{0}, yw]^2*G[{1}, yu^(-1)]*G[{1, yv^(-1)}, yw])/32 + 
     (G[{0}, yu^(-1)]*G[{1}, yu^(-1)]^2*G[{1, yv^(-1)}, yw])/32 + 
     (G[{0}, yv^(-1)]*G[{1}, yu^(-1)]^2*G[{1, yv^(-1)}, yw])/32 - 
     (G[{0}, yw]*G[{1}, yu^(-1)]^2*G[{1, yv^(-1)}, yw])/32 - 
     (G[{1}, yu^(-1)]^3*G[{1, yv^(-1)}, yw])/16 + 
     (Pi^2*G[{1}, yv^(-1)]*G[{1, yv^(-1)}, yw])/96 - 
     (G[{0}, yu^(-1)]^2*G[{1}, yv^(-1)]*G[{1, yv^(-1)}, yw])/32 - 
     (G[{0}, yu^(-1)]*G[{0}, yv^(-1)]*G[{1}, yv^(-1)]*G[{1, yv^(-1)}, yw])/
      16 - (G[{0}, yv^(-1)]^2*G[{1}, yv^(-1)]*G[{1, yv^(-1)}, yw])/32 + 
     (G[{0}, yu^(-1)]*G[{0}, yw]*G[{1}, yv^(-1)]*G[{1, yv^(-1)}, yw])/16 + 
     (G[{0}, yv^(-1)]*G[{0}, yw]*G[{1}, yv^(-1)]*G[{1, yv^(-1)}, yw])/16 - 
     (G[{0}, yw]^2*G[{1}, yv^(-1)]*G[{1, yv^(-1)}, yw])/32 - 
     (G[{0}, yu^(-1)]*G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*G[{1, yv^(-1)}, yw])/
      16 - (G[{0}, yv^(-1)]*G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*
       G[{1, yv^(-1)}, yw])/16 + (G[{0}, yw]*G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*
       G[{1, yv^(-1)}, yw])/16 + (3*G[{1}, yu^(-1)]^2*G[{1}, yv^(-1)]*
       G[{1, yv^(-1)}, yw])/64 + (G[{0}, yu^(-1)]*G[{1}, yv^(-1)]^2*
       G[{1, yv^(-1)}, yw])/16 + (G[{0}, yv^(-1)]*G[{1}, yv^(-1)]^2*
       G[{1, yv^(-1)}, yw])/16 - (G[{0}, yw]*G[{1}, yv^(-1)]^2*
       G[{1, yv^(-1)}, yw])/16 + (G[{1}, yu^(-1)]*G[{1}, yv^(-1)]^2*
       G[{1, yv^(-1)}, yw])/16 - (G[{1}, yv^(-1)]^3*G[{1, yv^(-1)}, yw])/32 - 
     (Pi^2*G[{1}, yw]*G[{1, yv^(-1)}, yw])/768 + 
     (G[{0}, yu^(-1)]^2*G[{1}, yw]*G[{1, yv^(-1)}, yw])/32 + 
     (G[{0}, yu^(-1)]*G[{0}, yv^(-1)]*G[{1}, yw]*G[{1, yv^(-1)}, yw])/16 + 
     (G[{0}, yv^(-1)]^2*G[{1}, yw]*G[{1, yv^(-1)}, yw])/32 - 
     (G[{0}, yu^(-1)]*G[{0}, yw]*G[{1}, yw]*G[{1, yv^(-1)}, yw])/16 - 
     (G[{0}, yv^(-1)]*G[{0}, yw]*G[{1}, yw]*G[{1, yv^(-1)}, yw])/16 + 
     (G[{0}, yw]^2*G[{1}, yw]*G[{1, yv^(-1)}, yw])/32 + 
     (3*G[{0}, yu^(-1)]*G[{1}, yu^(-1)]*G[{1}, yw]*G[{1, yv^(-1)}, yw])/16 + 
     (3*G[{0}, yv^(-1)]*G[{1}, yu^(-1)]*G[{1}, yw]*G[{1, yv^(-1)}, yw])/16 - 
     (3*G[{0}, yw]*G[{1}, yu^(-1)]*G[{1}, yw]*G[{1, yv^(-1)}, yw])/16 - 
     (G[{1}, yu^(-1)]^2*G[{1}, yw]*G[{1, yv^(-1)}, yw])/8 - 
     (G[{0}, yu^(-1)]*G[{1}, yv^(-1)]*G[{1}, yw]*G[{1, yv^(-1)}, yw])/4 - 
     (G[{0}, yv^(-1)]*G[{1}, yv^(-1)]*G[{1}, yw]*G[{1, yv^(-1)}, yw])/4 + 
     (G[{0}, yw]*G[{1}, yv^(-1)]*G[{1}, yw]*G[{1, yv^(-1)}, yw])/4 + 
     (G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*G[{1}, yw]*G[{1, yv^(-1)}, yw])/16 + 
     (11*G[{1}, yv^(-1)]^2*G[{1}, yw]*G[{1, yv^(-1)}, yw])/64 + 
     (G[{0}, yu^(-1)]*G[{1}, yw]^2*G[{1, yv^(-1)}, yw])/16 + 
     (G[{0}, yv^(-1)]*G[{1}, yw]^2*G[{1, yv^(-1)}, yw])/16 - 
     (G[{0}, yw]*G[{1}, yw]^2*G[{1, yv^(-1)}, yw])/16 + 
     (5*G[{1}, yu^(-1)]*G[{1}, yw]^2*G[{1, yv^(-1)}, yw])/64 - 
     (G[{1}, yv^(-1)]*G[{1}, yw]^2*G[{1, yv^(-1)}, yw])/16 + 
     (3*G[{1}, yw]^3*G[{1, yv^(-1)}, yw])/64 - 
     (7*Pi^2*G[{yu}, yv^(-1)]*G[{1, yv^(-1)}, yw])/768 - 
     (G[{0}, yu^(-1)]*G[{1}, yu^(-1)]*G[{yu}, yv^(-1)]*G[{1, yv^(-1)}, yw])/
      8 - (G[{0}, yv^(-1)]*G[{1}, yu^(-1)]*G[{yu}, yv^(-1)]*
       G[{1, yv^(-1)}, yw])/8 + (G[{0}, yw]*G[{1}, yu^(-1)]*G[{yu}, yv^(-1)]*
       G[{1, yv^(-1)}, yw])/8 + (5*G[{1}, yu^(-1)]^2*G[{yu}, yv^(-1)]*
       G[{1, yv^(-1)}, yw])/64 + (G[{0}, yu^(-1)]*G[{1}, yv^(-1)]*
       G[{yu}, yv^(-1)]*G[{1, yv^(-1)}, yw])/8 + 
     (G[{0}, yv^(-1)]*G[{1}, yv^(-1)]*G[{yu}, yv^(-1)]*G[{1, yv^(-1)}, yw])/
      8 - (G[{0}, yw]*G[{1}, yv^(-1)]*G[{yu}, yv^(-1)]*G[{1, yv^(-1)}, yw])/
      8 - (G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*G[{yu}, yv^(-1)]*
       G[{1, yv^(-1)}, yw])/8 - (5*G[{1}, yv^(-1)]^2*G[{yu}, yv^(-1)]*
       G[{1, yv^(-1)}, yw])/64 - (G[{0}, yu^(-1)]*G[{1}, yw]*G[{yu}, yv^(-1)]*
       G[{1, yv^(-1)}, yw])/16 - (G[{0}, yv^(-1)]*G[{1}, yw]*G[{yu}, yv^(-1)]*
       G[{1, yv^(-1)}, yw])/16 + (G[{0}, yw]*G[{1}, yw]*G[{yu}, yv^(-1)]*
       G[{1, yv^(-1)}, yw])/16 - (3*G[{1}, yu^(-1)]*G[{1}, yw]*
       G[{yu}, yv^(-1)]*G[{1, yv^(-1)}, yw])/16 + 
     (G[{1}, yv^(-1)]*G[{1}, yw]*G[{yu}, yv^(-1)]*G[{1, yv^(-1)}, yw])/32 - 
     (9*G[{1}, yw]^2*G[{yu}, yv^(-1)]*G[{1, yv^(-1)}, yw])/64 + 
     (7*G[{1}, yu^(-1)]*G[{yu}, yv^(-1)]^2*G[{1, yv^(-1)}, yw])/64 + 
     (9*G[{1}, yw]*G[{yu}, yv^(-1)]^2*G[{1, yv^(-1)}, yw])/64 - 
     (7*G[{yu}, yv^(-1)]^3*G[{1, yv^(-1)}, yw])/192 - 
     (19*Pi^2*G[{1/(yu*yv)}, yw]*G[{1, yv^(-1)}, yw])/768 + 
     (G[{0}, yu^(-1)]^2*G[{1/(yu*yv)}, yw]*G[{1, yv^(-1)}, yw])/16 + 
     (G[{0}, yu^(-1)]*G[{0}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{1, yv^(-1)}, yw])/
      8 + (G[{0}, yv^(-1)]^2*G[{1/(yu*yv)}, yw]*G[{1, yv^(-1)}, yw])/16 - 
     (G[{0}, yu^(-1)]*G[{0}, yw]*G[{1/(yu*yv)}, yw]*G[{1, yv^(-1)}, yw])/8 - 
     (G[{0}, yv^(-1)]*G[{0}, yw]*G[{1/(yu*yv)}, yw]*G[{1, yv^(-1)}, yw])/8 + 
     (G[{0}, yw]^2*G[{1/(yu*yv)}, yw]*G[{1, yv^(-1)}, yw])/16 + 
     (G[{0}, yu^(-1)]*G[{1}, yu^(-1)]*G[{1/(yu*yv)}, yw]*G[{1, yv^(-1)}, yw])/
      16 + (G[{0}, yv^(-1)]*G[{1}, yu^(-1)]*G[{1/(yu*yv)}, yw]*
       G[{1, yv^(-1)}, yw])/16 - (G[{0}, yw]*G[{1}, yu^(-1)]*
       G[{1/(yu*yv)}, yw]*G[{1, yv^(-1)}, yw])/16 - 
     (11*G[{1}, yu^(-1)]^2*G[{1/(yu*yv)}, yw]*G[{1, yv^(-1)}, yw])/64 - 
     (G[{0}, yu^(-1)]*G[{1}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{1, yv^(-1)}, yw])/
      8 - (G[{0}, yv^(-1)]*G[{1}, yv^(-1)]*G[{1/(yu*yv)}, yw]*
       G[{1, yv^(-1)}, yw])/8 + (G[{0}, yw]*G[{1}, yv^(-1)]*
       G[{1/(yu*yv)}, yw]*G[{1, yv^(-1)}, yw])/8 - 
     (7*G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*G[{1/(yu*yv)}, yw]*
       G[{1, yv^(-1)}, yw])/64 + (11*G[{1}, yv^(-1)]^2*G[{1/(yu*yv)}, yw]*
       G[{1, yv^(-1)}, yw])/128 + (G[{0}, yu^(-1)]*G[{1}, yw]*
       G[{1/(yu*yv)}, yw]*G[{1, yv^(-1)}, yw])/8 + 
     (G[{0}, yv^(-1)]*G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{1, yv^(-1)}, yw])/8 - 
     (G[{0}, yw]*G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{1, yv^(-1)}, yw])/8 - 
     (G[{1}, yu^(-1)]*G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{1, yv^(-1)}, yw])/4 - 
     (7*G[{1}, yv^(-1)]*G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{1, yv^(-1)}, yw])/
      64 - (7*G[{1}, yw]^2*G[{1/(yu*yv)}, yw]*G[{1, yv^(-1)}, yw])/128 - 
     (3*G[{1}, yu^(-1)]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*
       G[{1, yv^(-1)}, yw])/32 + (G[{1}, yv^(-1)]*G[{yu^(-1)}, yw]*
       G[{1/(yu*yv)}, yw]*G[{1, yv^(-1)}, yw])/16 - 
     (G[{1}, yw]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{1, yv^(-1)}, yw])/
      32 - (3*G[{yu^(-1)}, yw]^2*G[{1/(yu*yv)}, yw]*G[{1, yv^(-1)}, yw])/32 - 
     (3*G[{0}, yu^(-1)]*G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw]*
       G[{1, yv^(-1)}, yw])/16 - (3*G[{0}, yv^(-1)]*G[{yu}, yv^(-1)]*
       G[{1/(yu*yv)}, yw]*G[{1, yv^(-1)}, yw])/16 + 
     (3*G[{0}, yw]*G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{1, yv^(-1)}, yw])/
      16 + (21*G[{1}, yu^(-1)]*G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw]*
       G[{1, yv^(-1)}, yw])/64 + (7*G[{1}, yv^(-1)]*G[{yu}, yv^(-1)]*
       G[{1/(yu*yv)}, yw]*G[{1, yv^(-1)}, yw])/32 + 
     (7*G[{1}, yw]*G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{1, yv^(-1)}, yw])/
      64 + (G[{yu^(-1)}, yw]*G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw]*
       G[{1, yv^(-1)}, yw])/32 - (11*G[{yu}, yv^(-1)]^2*G[{1/(yu*yv)}, yw]*
       G[{1, yv^(-1)}, yw])/128 - (G[{0}, yu^(-1)]*G[{yv^(-1)}, yw]*
       G[{1/(yu*yv)}, yw]*G[{1, yv^(-1)}, yw])/4 - 
     (G[{0}, yv^(-1)]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*
       G[{1, yv^(-1)}, yw])/4 + (G[{0}, yw]*G[{yv^(-1)}, yw]*
       G[{1/(yu*yv)}, yw]*G[{1, yv^(-1)}, yw])/4 + 
     (G[{1}, yu^(-1)]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*
       G[{1, yv^(-1)}, yw])/16 + (G[{1}, yv^(-1)]*G[{yv^(-1)}, yw]*
       G[{1/(yu*yv)}, yw]*G[{1, yv^(-1)}, yw])/4 - 
     (3*G[{1}, yw]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{1, yv^(-1)}, yw])/
      16 + (3*G[{yu}, yv^(-1)]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*
       G[{1, yv^(-1)}, yw])/16 + (G[{yv^(-1)}, yw]^2*G[{1/(yu*yv)}, yw]*
       G[{1, yv^(-1)}, yw])/16 - (G[{0}, yu^(-1)]*G[{1/(yu*yv)}, yw]^2*
       G[{1, yv^(-1)}, yw])/32 - (G[{0}, yv^(-1)]*G[{1/(yu*yv)}, yw]^2*
       G[{1, yv^(-1)}, yw])/32 + (G[{0}, yw]*G[{1/(yu*yv)}, yw]^2*
       G[{1, yv^(-1)}, yw])/32 + (7*G[{1}, yu^(-1)]*G[{1/(yu*yv)}, yw]^2*
       G[{1, yv^(-1)}, yw])/128 - (G[{1}, yv^(-1)]*G[{1/(yu*yv)}, yw]^2*
       G[{1, yv^(-1)}, yw])/64 - (3*G[{1}, yw]*G[{1/(yu*yv)}, yw]^2*
       G[{1, yv^(-1)}, yw])/128 + (G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2*
       G[{1, yv^(-1)}, yw])/64 + (3*G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw]^2*
       G[{1, yv^(-1)}, yw])/128 - (G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2*
       G[{1, yv^(-1)}, yw])/128 + (G[{0}, yu^(-1)]*G[{0, 1}, yu^(-1)]*
       G[{1, yv^(-1)}, yw])/16 + (G[{0}, yv^(-1)]*G[{0, 1}, yu^(-1)]*
       G[{1, yv^(-1)}, yw])/16 - (G[{0}, yw]*G[{0, 1}, yu^(-1)]*
       G[{1, yv^(-1)}, yw])/16 - (5*G[{1}, yu^(-1)]*G[{0, 1}, yu^(-1)]*
       G[{1, yv^(-1)}, yw])/32 + (G[{1}, yv^(-1)]*G[{0, 1}, yu^(-1)]*
       G[{1, yv^(-1)}, yw])/32 - (G[{1}, yw]*G[{0, 1}, yu^(-1)]*
       G[{1, yv^(-1)}, yw])/32 - (G[{1/(yu*yv)}, yw]*G[{0, 1}, yu^(-1)]*
       G[{1, yv^(-1)}, yw])/64 - (G[{1}, yu^(-1)]*G[{0, 1}, yv^(-1)]*
       G[{1, yv^(-1)}, yw])/32 + (G[{1}, yv^(-1)]*G[{0, 1}, yv^(-1)]*
       G[{1, yv^(-1)}, yw])/16 + (G[{1}, yw]*G[{0, 1}, yv^(-1)]*
       G[{1, yv^(-1)}, yw])/32 + (G[{yu}, yv^(-1)]*G[{0, 1}, yv^(-1)]*
       G[{1, yv^(-1)}, yw])/32 - (3*G[{1/(yu*yv)}, yw]*G[{0, 1}, yv^(-1)]*
       G[{1, yv^(-1)}, yw])/64 + (3*G[{0}, yu^(-1)]*G[{0, 1}, yw]*
       G[{1, yv^(-1)}, yw])/16 + (3*G[{0}, yv^(-1)]*G[{0, 1}, yw]*
       G[{1, yv^(-1)}, yw])/16 - (3*G[{0}, yw]*G[{0, 1}, yw]*
       G[{1, yv^(-1)}, yw])/16 - (G[{1}, yv^(-1)]*G[{0, 1}, yw]*
       G[{1, yv^(-1)}, yw])/4 + (G[{1}, yw]*G[{0, 1}, yw]*
       G[{1, yv^(-1)}, yw])/16 - (G[{yu}, yv^(-1)]*G[{0, 1}, yw]*
       G[{1, yv^(-1)}, yw])/8 - (G[{1/(yu*yv)}, yw]*G[{0, 1}, yw]*
       G[{1, yv^(-1)}, yw])/16 - (3*G[{0}, yu^(-1)]*G[{0, yu^(-1)}, yw]*
       G[{1, yv^(-1)}, yw])/16 - (3*G[{0}, yv^(-1)]*G[{0, yu^(-1)}, yw]*
       G[{1, yv^(-1)}, yw])/16 + (3*G[{0}, yw]*G[{0, yu^(-1)}, yw]*
       G[{1, yv^(-1)}, yw])/16 + (G[{1}, yv^(-1)]*G[{0, yu^(-1)}, yw]*
       G[{1, yv^(-1)}, yw])/4 - (G[{1}, yw]*G[{0, yu^(-1)}, yw]*
       G[{1, yv^(-1)}, yw])/16 + (G[{yu}, yv^(-1)]*G[{0, yu^(-1)}, yw]*
       G[{1, yv^(-1)}, yw])/8 + (G[{1/(yu*yv)}, yw]*G[{0, yu^(-1)}, yw]*
       G[{1, yv^(-1)}, yw])/16 + (G[{1}, yu^(-1)]*G[{0, yu}, yv^(-1)]*
       G[{1, yv^(-1)}, yw])/32 - (G[{1}, yv^(-1)]*G[{0, yu}, yv^(-1)]*
       G[{1, yv^(-1)}, yw])/16 - (G[{1}, yw]*G[{0, yu}, yv^(-1)]*
       G[{1, yv^(-1)}, yw])/32 - (G[{yu}, yv^(-1)]*G[{0, yu}, yv^(-1)]*
       G[{1, yv^(-1)}, yw])/32 + (3*G[{1/(yu*yv)}, yw]*G[{0, yu}, yv^(-1)]*
       G[{1, yv^(-1)}, yw])/64 - (3*G[{0}, yu^(-1)]*G[{0, yv^(-1)}, yw]*
       G[{1, yv^(-1)}, yw])/16 - (3*G[{0}, yv^(-1)]*G[{0, yv^(-1)}, yw]*
       G[{1, yv^(-1)}, yw])/16 + (3*G[{0}, yw]*G[{0, yv^(-1)}, yw]*
       G[{1, yv^(-1)}, yw])/16 + (G[{1}, yv^(-1)]*G[{0, yv^(-1)}, yw]*
       G[{1, yv^(-1)}, yw])/4 - (G[{1}, yw]*G[{0, yv^(-1)}, yw]*
       G[{1, yv^(-1)}, yw])/16 + (G[{yu}, yv^(-1)]*G[{0, yv^(-1)}, yw]*
       G[{1, yv^(-1)}, yw])/8 + (G[{1/(yu*yv)}, yw]*G[{0, yv^(-1)}, yw]*
       G[{1, yv^(-1)}, yw])/16 + (3*G[{0}, yu^(-1)]*G[{0, 1/(yu*yv)}, yw]*
       G[{1, yv^(-1)}, yw])/16 + (3*G[{0}, yv^(-1)]*G[{0, 1/(yu*yv)}, yw]*
       G[{1, yv^(-1)}, yw])/16 - (3*G[{0}, yw]*G[{0, 1/(yu*yv)}, yw]*
       G[{1, yv^(-1)}, yw])/16 - (G[{1}, yv^(-1)]*G[{0, 1/(yu*yv)}, yw]*
       G[{1, yv^(-1)}, yw])/4 + (G[{1}, yw]*G[{0, 1/(yu*yv)}, yw]*
       G[{1, yv^(-1)}, yw])/16 - (G[{yu}, yv^(-1)]*G[{0, 1/(yu*yv)}, yw]*
       G[{1, yv^(-1)}, yw])/8 - (G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv)}, yw]*
       G[{1, yv^(-1)}, yw])/16 + (3*G[{0}, yu^(-1)]*G[{1, yu^(-1)}, yw]*
       G[{1, yv^(-1)}, yw])/16 + (3*G[{0}, yv^(-1)]*G[{1, yu^(-1)}, yw]*
       G[{1, yv^(-1)}, yw])/16 - (3*G[{0}, yw]*G[{1, yu^(-1)}, yw]*
       G[{1, yv^(-1)}, yw])/16 - (G[{1}, yu^(-1)]*G[{1, yu^(-1)}, yw]*
       G[{1, yv^(-1)}, yw])/32 - (5*G[{1}, yv^(-1)]*G[{1, yu^(-1)}, yw]*
       G[{1, yv^(-1)}, yw])/16 + (G[{1}, yw]*G[{1, yu^(-1)}, yw]*
       G[{1, yv^(-1)}, yw])/32 - (G[{yu}, yv^(-1)]*G[{1, yu^(-1)}, yw]*
       G[{1, yv^(-1)}, yw])/32 - (7*G[{1/(yu*yv)}, yw]*G[{1, yu^(-1)}, yw]*
       G[{1, yv^(-1)}, yw])/64 - (G[{0}, yu^(-1)]*G[{1, yu}, yv^(-1)]*
       G[{1, yv^(-1)}, yw])/16 - (G[{0}, yv^(-1)]*G[{1, yu}, yv^(-1)]*
       G[{1, yv^(-1)}, yw])/16 + (G[{0}, yw]*G[{1, yu}, yv^(-1)]*
       G[{1, yv^(-1)}, yw])/16 + (G[{1}, yu^(-1)]*G[{1, yu}, yv^(-1)]*
       G[{1, yv^(-1)}, yw])/32 - (G[{1}, yv^(-1)]*G[{1, yu}, yv^(-1)]*
       G[{1, yv^(-1)}, yw])/16 + (G[{1}, yw]*G[{1, yu}, yv^(-1)]*
       G[{1, yv^(-1)}, yw])/16 + (G[{yu}, yv^(-1)]*G[{1, yu}, yv^(-1)]*
       G[{1, yv^(-1)}, yw])/32 - (G[{1/(yu*yv)}, yw]*G[{1, yu}, yv^(-1)]*
       G[{1, yv^(-1)}, yw])/32 + (G[{0}, yu^(-1)]*G[{1, yv^(-1)}, yw]^2)/8 + 
     (G[{0}, yv^(-1)]*G[{1, yv^(-1)}, yw]^2)/8 - 
     (G[{0}, yw]*G[{1, yv^(-1)}, yw]^2)/8 - 
     (G[{1}, yu^(-1)]*G[{1, yv^(-1)}, yw]^2)/32 - 
     (G[{1}, yv^(-1)]*G[{1, yv^(-1)}, yw]^2)/8 + 
     (3*G[{1}, yw]*G[{1, yv^(-1)}, yw]^2)/32 - 
     (3*G[{yu}, yv^(-1)]*G[{1, yv^(-1)}, yw]^2)/32 - 
     (5*G[{1/(yu*yv)}, yw]*G[{1, yv^(-1)}, yw]^2)/128 - 
     (Pi^2*G[{0}, yu^(-1)]*G[{1, 1/(yu*yv)}, yw])/48 - 
     (Pi^2*G[{0}, yv^(-1)]*G[{1, 1/(yu*yv)}, yw])/48 + 
     (Pi^2*G[{0}, yw]*G[{1, 1/(yu*yv)}, yw])/48 - 
     (7*Pi^2*G[{1}, yu^(-1)]*G[{1, 1/(yu*yv)}, yw])/768 + 
     (3*G[{1}, yu^(-1)]^3*G[{1, 1/(yu*yv)}, yw])/128 + 
     (Pi^2*G[{1}, yv^(-1)]*G[{1, 1/(yu*yv)}, yw])/96 - 
     (11*G[{1}, yu^(-1)]^2*G[{1}, yv^(-1)]*G[{1, 1/(yu*yv)}, yw])/128 + 
     (3*G[{1}, yu^(-1)]*G[{1}, yv^(-1)]^2*G[{1, 1/(yu*yv)}, yw])/128 - 
     (31*Pi^2*G[{1}, yw]*G[{1, 1/(yu*yv)}, yw])/768 + 
     (G[{0}, yu^(-1)]*G[{1}, yu^(-1)]*G[{1}, yw]*G[{1, 1/(yu*yv)}, yw])/8 + 
     (G[{0}, yv^(-1)]*G[{1}, yu^(-1)]*G[{1}, yw]*G[{1, 1/(yu*yv)}, yw])/8 - 
     (G[{0}, yw]*G[{1}, yu^(-1)]*G[{1}, yw]*G[{1, 1/(yu*yv)}, yw])/8 - 
     (3*G[{1}, yu^(-1)]^2*G[{1}, yw]*G[{1, 1/(yu*yv)}, yw])/128 + 
     (G[{0}, yu^(-1)]*G[{1}, yv^(-1)]*G[{1}, yw]*G[{1, 1/(yu*yv)}, yw])/8 + 
     (G[{0}, yv^(-1)]*G[{1}, yv^(-1)]*G[{1}, yw]*G[{1, 1/(yu*yv)}, yw])/8 - 
     (G[{0}, yw]*G[{1}, yv^(-1)]*G[{1}, yw]*G[{1, 1/(yu*yv)}, yw])/8 - 
     (23*G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*G[{1}, yw]*G[{1, 1/(yu*yv)}, yw])/
      64 - (5*G[{1}, yv^(-1)]^2*G[{1}, yw]*G[{1, 1/(yu*yv)}, yw])/64 + 
     (G[{0}, yu^(-1)]*G[{1}, yw]^2*G[{1, 1/(yu*yv)}, yw])/8 + 
     (G[{0}, yv^(-1)]*G[{1}, yw]^2*G[{1, 1/(yu*yv)}, yw])/8 - 
     (G[{0}, yw]*G[{1}, yw]^2*G[{1, 1/(yu*yv)}, yw])/8 + 
     (7*G[{1}, yu^(-1)]*G[{1}, yw]^2*G[{1, 1/(yu*yv)}, yw])/128 + 
     (13*G[{1}, yw]^3*G[{1, 1/(yu*yv)}, yw])/128 + 
     (31*Pi^2*G[{yu}, yv^(-1)]*G[{1, 1/(yu*yv)}, yw])/768 + 
     (G[{1}, yu^(-1)]^2*G[{yu}, yv^(-1)]*G[{1, 1/(yu*yv)}, yw])/64 + 
     (3*G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*G[{yu}, yv^(-1)]*
       G[{1, 1/(yu*yv)}, yw])/16 - (3*G[{1}, yv^(-1)]^2*G[{yu}, yv^(-1)]*
       G[{1, 1/(yu*yv)}, yw])/64 - (G[{0}, yu^(-1)]*G[{1}, yw]*
       G[{yu}, yv^(-1)]*G[{1, 1/(yu*yv)}, yw])/4 - 
     (G[{0}, yv^(-1)]*G[{1}, yw]*G[{yu}, yv^(-1)]*G[{1, 1/(yu*yv)}, yw])/4 + 
     (G[{0}, yw]*G[{1}, yw]*G[{yu}, yv^(-1)]*G[{1, 1/(yu*yv)}, yw])/4 + 
     (5*G[{1}, yu^(-1)]*G[{1}, yw]*G[{yu}, yv^(-1)]*G[{1, 1/(yu*yv)}, yw])/
      32 + (3*G[{1}, yv^(-1)]*G[{1}, yw]*G[{yu}, yv^(-1)]*
       G[{1, 1/(yu*yv)}, yw])/32 - (39*G[{1}, yw]^2*G[{yu}, yv^(-1)]*
       G[{1, 1/(yu*yv)}, yw])/128 - (7*G[{1}, yu^(-1)]*G[{yu}, yv^(-1)]^2*
       G[{1, 1/(yu*yv)}, yw])/64 - (G[{1}, yv^(-1)]*G[{yu}, yv^(-1)]^2*
       G[{1, 1/(yu*yv)}, yw])/16 + (G[{1}, yw]*G[{yu}, yv^(-1)]^2*
       G[{1, 1/(yu*yv)}, yw])/8 + (11*G[{yu}, yv^(-1)]^3*
       G[{1, 1/(yu*yv)}, yw])/192 + (19*Pi^2*G[{1/(yu*yv)}, yw]*
       G[{1, 1/(yu*yv)}, yw])/768 - (G[{0}, yu^(-1)]^2*G[{1/(yu*yv)}, yw]*
       G[{1, 1/(yu*yv)}, yw])/16 - (G[{0}, yu^(-1)]*G[{0}, yv^(-1)]*
       G[{1/(yu*yv)}, yw]*G[{1, 1/(yu*yv)}, yw])/8 - 
     (G[{0}, yv^(-1)]^2*G[{1/(yu*yv)}, yw]*G[{1, 1/(yu*yv)}, yw])/16 + 
     (G[{0}, yu^(-1)]*G[{0}, yw]*G[{1/(yu*yv)}, yw]*G[{1, 1/(yu*yv)}, yw])/
      8 + (G[{0}, yv^(-1)]*G[{0}, yw]*G[{1/(yu*yv)}, yw]*
       G[{1, 1/(yu*yv)}, yw])/8 - (G[{0}, yw]^2*G[{1/(yu*yv)}, yw]*
       G[{1, 1/(yu*yv)}, yw])/16 + (9*G[{1}, yu^(-1)]^2*G[{1/(yu*yv)}, yw]*
       G[{1, 1/(yu*yv)}, yw])/128 + (5*G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*
       G[{1/(yu*yv)}, yw]*G[{1, 1/(yu*yv)}, yw])/32 + 
     (5*G[{1}, yv^(-1)]^2*G[{1/(yu*yv)}, yw]*G[{1, 1/(yu*yv)}, yw])/128 - 
     (G[{0}, yu^(-1)]*G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{1, 1/(yu*yv)}, yw])/
      4 - (G[{0}, yv^(-1)]*G[{1}, yw]*G[{1/(yu*yv)}, yw]*
       G[{1, 1/(yu*yv)}, yw])/4 + (G[{0}, yw]*G[{1}, yw]*G[{1/(yu*yv)}, yw]*
       G[{1, 1/(yu*yv)}, yw])/4 + (15*G[{1}, yu^(-1)]*G[{1}, yw]*
       G[{1/(yu*yv)}, yw]*G[{1, 1/(yu*yv)}, yw])/64 + 
     (11*G[{1}, yv^(-1)]*G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{1, 1/(yu*yv)}, yw])/
      64 - (3*G[{1}, yw]^2*G[{1/(yu*yv)}, yw]*G[{1, 1/(yu*yv)}, yw])/64 + 
     (G[{0}, yu^(-1)]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*
       G[{1, 1/(yu*yv)}, yw])/16 + (G[{0}, yv^(-1)]*G[{yu^(-1)}, yw]*
       G[{1/(yu*yv)}, yw]*G[{1, 1/(yu*yv)}, yw])/16 - 
     (G[{0}, yw]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{1, 1/(yu*yv)}, yw])/
      16 - (G[{1}, yu^(-1)]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*
       G[{1, 1/(yu*yv)}, yw])/32 - (G[{1}, yv^(-1)]*G[{yu^(-1)}, yw]*
       G[{1/(yu*yv)}, yw]*G[{1, 1/(yu*yv)}, yw])/8 - 
     (G[{1}, yw]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{1, 1/(yu*yv)}, yw])/
      32 + (3*G[{yu^(-1)}, yw]^2*G[{1/(yu*yv)}, yw]*G[{1, 1/(yu*yv)}, yw])/
      32 + (G[{0}, yu^(-1)]*G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw]*
       G[{1, 1/(yu*yv)}, yw])/4 + (G[{0}, yv^(-1)]*G[{yu}, yv^(-1)]*
       G[{1/(yu*yv)}, yw]*G[{1, 1/(yu*yv)}, yw])/4 - 
     (G[{0}, yw]*G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{1, 1/(yu*yv)}, yw])/
      4 - (19*G[{1}, yu^(-1)]*G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw]*
       G[{1, 1/(yu*yv)}, yw])/64 - (9*G[{1}, yv^(-1)]*G[{yu}, yv^(-1)]*
       G[{1/(yu*yv)}, yw]*G[{1, 1/(yu*yv)}, yw])/32 + 
     (3*G[{1}, yw]*G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{1, 1/(yu*yv)}, yw])/
      32 + (G[{yu^(-1)}, yw]*G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw]*
       G[{1, 1/(yu*yv)}, yw])/32 + (5*G[{yu}, yv^(-1)]^2*G[{1/(yu*yv)}, yw]*
       G[{1, 1/(yu*yv)}, yw])/128 + (G[{0}, yu^(-1)]*G[{yv^(-1)}, yw]*
       G[{1/(yu*yv)}, yw]*G[{1, 1/(yu*yv)}, yw])/16 + 
     (G[{0}, yv^(-1)]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*
       G[{1, 1/(yu*yv)}, yw])/16 - (G[{0}, yw]*G[{yv^(-1)}, yw]*
       G[{1/(yu*yv)}, yw]*G[{1, 1/(yu*yv)}, yw])/16 - 
     (3*G[{1}, yu^(-1)]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*
       G[{1, 1/(yu*yv)}, yw])/32 - (G[{1}, yv^(-1)]*G[{yv^(-1)}, yw]*
       G[{1/(yu*yv)}, yw]*G[{1, 1/(yu*yv)}, yw])/16 - 
     (G[{1}, yw]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{1, 1/(yu*yv)}, yw])/
      32 + (G[{yu}, yv^(-1)]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*
       G[{1, 1/(yu*yv)}, yw])/32 + (5*G[{yv^(-1)}, yw]^2*G[{1/(yu*yv)}, yw]*
       G[{1, 1/(yu*yv)}, yw])/64 - (G[{0}, yu^(-1)]*G[{1/(yu*yv)}, yw]^2*
       G[{1, 1/(yu*yv)}, yw])/32 - (G[{0}, yv^(-1)]*G[{1/(yu*yv)}, yw]^2*
       G[{1, 1/(yu*yv)}, yw])/32 + (G[{0}, yw]*G[{1/(yu*yv)}, yw]^2*
       G[{1, 1/(yu*yv)}, yw])/32 + (5*G[{1}, yv^(-1)]*G[{1/(yu*yv)}, yw]^2*
       G[{1, 1/(yu*yv)}, yw])/64 + (G[{1}, yw]*G[{1/(yu*yv)}, yw]^2*
       G[{1, 1/(yu*yv)}, yw])/64 - (5*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2*
       G[{1, 1/(yu*yv)}, yw])/64 - (G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw]^2*
       G[{1, 1/(yu*yv)}, yw])/64 - (3*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2*
       G[{1, 1/(yu*yv)}, yw])/64 - (G[{0}, yu^(-1)]*G[{0, 1}, yu^(-1)]*
       G[{1, 1/(yu*yv)}, yw])/8 - (G[{0}, yv^(-1)]*G[{0, 1}, yu^(-1)]*
       G[{1, 1/(yu*yv)}, yw])/8 + (G[{0}, yw]*G[{0, 1}, yu^(-1)]*
       G[{1, 1/(yu*yv)}, yw])/8 - (5*G[{1}, yu^(-1)]*G[{0, 1}, yu^(-1)]*
       G[{1, 1/(yu*yv)}, yw])/64 + (9*G[{1}, yv^(-1)]*G[{0, 1}, yu^(-1)]*
       G[{1, 1/(yu*yv)}, yw])/64 - (17*G[{1}, yw]*G[{0, 1}, yu^(-1)]*
       G[{1, 1/(yu*yv)}, yw])/64 + (3*G[{yu}, yv^(-1)]*G[{0, 1}, yu^(-1)]*
       G[{1, 1/(yu*yv)}, yw])/16 + (G[{1/(yu*yv)}, yw]*G[{0, 1}, yu^(-1)]*
       G[{1, 1/(yu*yv)}, yw])/16 - (G[{0}, yu^(-1)]*G[{0, 1}, yv^(-1)]*
       G[{1, 1/(yu*yv)}, yw])/8 - (G[{0}, yv^(-1)]*G[{0, 1}, yv^(-1)]*
       G[{1, 1/(yu*yv)}, yw])/8 + (G[{0}, yw]*G[{0, 1}, yv^(-1)]*
       G[{1, 1/(yu*yv)}, yw])/8 + (G[{1}, yu^(-1)]*G[{0, 1}, yv^(-1)]*
       G[{1, 1/(yu*yv)}, yw])/32 + (G[{1}, yv^(-1)]*G[{0, 1}, yv^(-1)]*
       G[{1, 1/(yu*yv)}, yw])/8 - (3*G[{1}, yw]*G[{0, 1}, yv^(-1)]*
       G[{1, 1/(yu*yv)}, yw])/32 + (7*G[{yu}, yv^(-1)]*G[{0, 1}, yv^(-1)]*
       G[{1, 1/(yu*yv)}, yw])/32 + (7*G[{1/(yu*yv)}, yw]*G[{0, 1}, yv^(-1)]*
       G[{1, 1/(yu*yv)}, yw])/64 - (G[{0}, yu^(-1)]*G[{0, 1}, yw]*
       G[{1, 1/(yu*yv)}, yw])/8 - (G[{0}, yv^(-1)]*G[{0, 1}, yw]*
       G[{1, 1/(yu*yv)}, yw])/8 + (G[{0}, yw]*G[{0, 1}, yw]*
       G[{1, 1/(yu*yv)}, yw])/8 + (G[{1}, yu^(-1)]*G[{0, 1}, yw]*
       G[{1, 1/(yu*yv)}, yw])/8 + (G[{1}, yv^(-1)]*G[{0, 1}, yw]*
       G[{1, 1/(yu*yv)}, yw])/8 + (G[{0}, yu^(-1)]*G[{0, yu^(-1)}, yw]*
       G[{1, 1/(yu*yv)}, yw])/8 + (G[{0}, yv^(-1)]*G[{0, yu^(-1)}, yw]*
       G[{1, 1/(yu*yv)}, yw])/8 - (G[{0}, yw]*G[{0, yu^(-1)}, yw]*
       G[{1, 1/(yu*yv)}, yw])/8 - (G[{1}, yu^(-1)]*G[{0, yu^(-1)}, yw]*
       G[{1, 1/(yu*yv)}, yw])/8 - (G[{1}, yv^(-1)]*G[{0, yu^(-1)}, yw]*
       G[{1, 1/(yu*yv)}, yw])/8 + (G[{0}, yu^(-1)]*G[{0, yu}, yv^(-1)]*
       G[{1, 1/(yu*yv)}, yw])/8 + (G[{0}, yv^(-1)]*G[{0, yu}, yv^(-1)]*
       G[{1, 1/(yu*yv)}, yw])/8 - (G[{0}, yw]*G[{0, yu}, yv^(-1)]*
       G[{1, 1/(yu*yv)}, yw])/8 - (G[{1}, yu^(-1)]*G[{0, yu}, yv^(-1)]*
       G[{1, 1/(yu*yv)}, yw])/32 - (G[{1}, yv^(-1)]*G[{0, yu}, yv^(-1)]*
       G[{1, 1/(yu*yv)}, yw])/8 + (3*G[{1}, yw]*G[{0, yu}, yv^(-1)]*
       G[{1, 1/(yu*yv)}, yw])/32 - (7*G[{yu}, yv^(-1)]*G[{0, yu}, yv^(-1)]*
       G[{1, 1/(yu*yv)}, yw])/32 - (7*G[{1/(yu*yv)}, yw]*G[{0, yu}, yv^(-1)]*
       G[{1, 1/(yu*yv)}, yw])/64 + (G[{0}, yu^(-1)]*G[{0, yv^(-1)}, yw]*
       G[{1, 1/(yu*yv)}, yw])/8 + (G[{0}, yv^(-1)]*G[{0, yv^(-1)}, yw]*
       G[{1, 1/(yu*yv)}, yw])/8 - (G[{0}, yw]*G[{0, yv^(-1)}, yw]*
       G[{1, 1/(yu*yv)}, yw])/8 - (G[{1}, yu^(-1)]*G[{0, yv^(-1)}, yw]*
       G[{1, 1/(yu*yv)}, yw])/8 - (G[{1}, yv^(-1)]*G[{0, yv^(-1)}, yw]*
       G[{1, 1/(yu*yv)}, yw])/8 - (G[{0}, yu^(-1)]*G[{0, 1/(yu*yv)}, yw]*
       G[{1, 1/(yu*yv)}, yw])/8 - (G[{0}, yv^(-1)]*G[{0, 1/(yu*yv)}, yw]*
       G[{1, 1/(yu*yv)}, yw])/8 + (G[{0}, yw]*G[{0, 1/(yu*yv)}, yw]*
       G[{1, 1/(yu*yv)}, yw])/8 + (G[{1}, yu^(-1)]*G[{0, 1/(yu*yv)}, yw]*
       G[{1, 1/(yu*yv)}, yw])/8 + (G[{1}, yv^(-1)]*G[{0, 1/(yu*yv)}, yw]*
       G[{1, 1/(yu*yv)}, yw])/8 - (G[{0}, yu^(-1)]*G[{1, yu^(-1)}, yw]*
       G[{1, 1/(yu*yv)}, yw])/4 - (G[{0}, yv^(-1)]*G[{1, yu^(-1)}, yw]*
       G[{1, 1/(yu*yv)}, yw])/4 + (G[{0}, yw]*G[{1, yu^(-1)}, yw]*
       G[{1, 1/(yu*yv)}, yw])/4 + (5*G[{1}, yu^(-1)]*G[{1, yu^(-1)}, yw]*
       G[{1, 1/(yu*yv)}, yw])/32 + (G[{1}, yv^(-1)]*G[{1, yu^(-1)}, yw]*
       G[{1, 1/(yu*yv)}, yw])/4 - (3*G[{1}, yw]*G[{1, yu^(-1)}, yw]*
       G[{1, 1/(yu*yv)}, yw])/32 + (3*G[{yu}, yv^(-1)]*G[{1, yu^(-1)}, yw]*
       G[{1, 1/(yu*yv)}, yw])/32 + (7*G[{1/(yu*yv)}, yw]*G[{1, yu^(-1)}, yw]*
       G[{1, 1/(yu*yv)}, yw])/64 - (G[{1}, yu^(-1)]*G[{1, yu}, yv^(-1)]*
       G[{1, 1/(yu*yv)}, yw])/16 + (G[{1}, yv^(-1)]*G[{1, yu}, yv^(-1)]*
       G[{1, 1/(yu*yv)}, yw])/16 + (11*G[{1}, yw]*G[{1, yu}, yv^(-1)]*
       G[{1, 1/(yu*yv)}, yw])/64 + (G[{yu}, yv^(-1)]*G[{1, yu}, yv^(-1)]*
       G[{1, 1/(yu*yv)}, yw])/32 + (3*G[{1/(yu*yv)}, yw]*G[{1, yu}, yv^(-1)]*
       G[{1, 1/(yu*yv)}, yw])/64 - (G[{0}, yu^(-1)]*G[{1, yv^(-1)}, yw]*
       G[{1, 1/(yu*yv)}, yw])/4 - (G[{0}, yv^(-1)]*G[{1, yv^(-1)}, yw]*
       G[{1, 1/(yu*yv)}, yw])/4 + (G[{0}, yw]*G[{1, yv^(-1)}, yw]*
       G[{1, 1/(yu*yv)}, yw])/4 + (7*G[{1}, yu^(-1)]*G[{1, yv^(-1)}, yw]*
       G[{1, 1/(yu*yv)}, yw])/32 + (3*G[{1}, yv^(-1)]*G[{1, yv^(-1)}, yw]*
       G[{1, 1/(yu*yv)}, yw])/16 - (3*G[{1}, yw]*G[{1, yv^(-1)}, yw]*
       G[{1, 1/(yu*yv)}, yw])/32 + (3*G[{yu}, yv^(-1)]*G[{1, yv^(-1)}, yw]*
       G[{1, 1/(yu*yv)}, yw])/32 + (G[{1/(yu*yv)}, yw]*G[{1, yv^(-1)}, yw]*
       G[{1, 1/(yu*yv)}, yw])/16 + (G[{0}, yu^(-1)]*G[{1, 1/(yu*yv)}, yw]^2)/
      8 + (G[{0}, yv^(-1)]*G[{1, 1/(yu*yv)}, yw]^2)/8 - 
     (G[{0}, yw]*G[{1, 1/(yu*yv)}, yw]^2)/8 - 
     (G[{1}, yu^(-1)]*G[{1, 1/(yu*yv)}, yw]^2)/16 - 
     (3*G[{1}, yv^(-1)]*G[{1, 1/(yu*yv)}, yw]^2)/32 + 
     (3*G[{1}, yw]*G[{1, 1/(yu*yv)}, yw]^2)/32 - 
     (3*G[{yu}, yv^(-1)]*G[{1, 1/(yu*yv)}, yw]^2)/32 - 
     (11*G[{1/(yu*yv)}, yw]*G[{1, 1/(yu*yv)}, yw]^2)/128 - 
     (Pi^2*G[{0}, yu^(-1)]*G[{yu^(-1), 1/(yu*yv)}, yw])/96 - 
     (Pi^2*G[{0}, yv^(-1)]*G[{yu^(-1), 1/(yu*yv)}, yw])/96 + 
     (Pi^2*G[{0}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw])/96 + 
     (Pi^2*G[{1}, yu^(-1)]*G[{yu^(-1), 1/(yu*yv)}, yw])/96 - 
     (G[{0}, yu^(-1)]^2*G[{1}, yu^(-1)]*G[{yu^(-1), 1/(yu*yv)}, yw])/32 - 
     (G[{0}, yu^(-1)]*G[{0}, yv^(-1)]*G[{1}, yu^(-1)]*G[{yu^(-1), 1/(yu*yv)}, 
        yw])/16 - (G[{0}, yv^(-1)]^2*G[{1}, yu^(-1)]*G[{yu^(-1), 1/(yu*yv)}, 
        yw])/32 + (G[{0}, yu^(-1)]*G[{0}, yw]*G[{1}, yu^(-1)]*
       G[{yu^(-1), 1/(yu*yv)}, yw])/16 + 
     (G[{0}, yv^(-1)]*G[{0}, yw]*G[{1}, yu^(-1)]*G[{yu^(-1), 1/(yu*yv)}, yw])/
      16 - (G[{0}, yw]^2*G[{1}, yu^(-1)]*G[{yu^(-1), 1/(yu*yv)}, yw])/32 - 
     (G[{0}, yu^(-1)]*G[{1}, yu^(-1)]^2*G[{yu^(-1), 1/(yu*yv)}, yw])/32 - 
     (G[{0}, yv^(-1)]*G[{1}, yu^(-1)]^2*G[{yu^(-1), 1/(yu*yv)}, yw])/32 + 
     (G[{0}, yw]*G[{1}, yu^(-1)]^2*G[{yu^(-1), 1/(yu*yv)}, yw])/32 + 
     (5*G[{1}, yu^(-1)]^3*G[{yu^(-1), 1/(yu*yv)}, yw])/128 + 
     (G[{0}, yu^(-1)]^2*G[{1}, yv^(-1)]*G[{yu^(-1), 1/(yu*yv)}, yw])/32 + 
     (G[{0}, yu^(-1)]*G[{0}, yv^(-1)]*G[{1}, yv^(-1)]*G[{yu^(-1), 1/(yu*yv)}, 
        yw])/16 + (G[{0}, yv^(-1)]^2*G[{1}, yv^(-1)]*G[{yu^(-1), 1/(yu*yv)}, 
        yw])/32 - (G[{0}, yu^(-1)]*G[{0}, yw]*G[{1}, yv^(-1)]*
       G[{yu^(-1), 1/(yu*yv)}, yw])/16 - 
     (G[{0}, yv^(-1)]*G[{0}, yw]*G[{1}, yv^(-1)]*G[{yu^(-1), 1/(yu*yv)}, yw])/
      16 + (G[{0}, yw]^2*G[{1}, yv^(-1)]*G[{yu^(-1), 1/(yu*yv)}, yw])/32 + 
     (G[{0}, yu^(-1)]*G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*G[{yu^(-1), 1/(yu*yv)}, 
        yw])/16 + (G[{0}, yv^(-1)]*G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*
       G[{yu^(-1), 1/(yu*yv)}, yw])/16 - 
     (G[{0}, yw]*G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*G[{yu^(-1), 1/(yu*yv)}, yw])/
      16 + (5*G[{1}, yu^(-1)]^2*G[{1}, yv^(-1)]*G[{yu^(-1), 1/(yu*yv)}, yw])/
      128 - (G[{0}, yu^(-1)]*G[{1}, yv^(-1)]^2*G[{yu^(-1), 1/(yu*yv)}, yw])/
      16 - (G[{0}, yv^(-1)]*G[{1}, yv^(-1)]^2*G[{yu^(-1), 1/(yu*yv)}, yw])/
      16 + (G[{0}, yw]*G[{1}, yv^(-1)]^2*G[{yu^(-1), 1/(yu*yv)}, yw])/16 - 
     (11*G[{1}, yu^(-1)]*G[{1}, yv^(-1)]^2*G[{yu^(-1), 1/(yu*yv)}, yw])/128 + 
     (G[{1}, yv^(-1)]^3*G[{yu^(-1), 1/(yu*yv)}, yw])/32 - 
     (Pi^2*G[{1}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw])/48 + 
     (G[{0}, yu^(-1)]^2*G[{1}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw])/32 + 
     (G[{0}, yu^(-1)]*G[{0}, yv^(-1)]*G[{1}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw])/
      16 + (G[{0}, yv^(-1)]^2*G[{1}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw])/32 - 
     (G[{0}, yu^(-1)]*G[{0}, yw]*G[{1}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw])/16 - 
     (G[{0}, yv^(-1)]*G[{0}, yw]*G[{1}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw])/16 + 
     (G[{0}, yw]^2*G[{1}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw])/32 - 
     (G[{0}, yu^(-1)]*G[{1}, yu^(-1)]*G[{1}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw])/
      16 - (G[{0}, yv^(-1)]*G[{1}, yu^(-1)]*G[{1}, yw]*
       G[{yu^(-1), 1/(yu*yv)}, yw])/16 + 
     (G[{0}, yw]*G[{1}, yu^(-1)]*G[{1}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw])/16 + 
     (3*G[{1}, yu^(-1)]^2*G[{1}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw])/128 + 
     (3*G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*G[{1}, yw]*G[{yu^(-1), 1/(yu*yv)}, 
        yw])/64 - (G[{1}, yv^(-1)]^2*G[{1}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw])/
      32 + (G[{0}, yu^(-1)]*G[{1}, yw]^2*G[{yu^(-1), 1/(yu*yv)}, yw])/16 + 
     (G[{0}, yv^(-1)]*G[{1}, yw]^2*G[{yu^(-1), 1/(yu*yv)}, yw])/16 - 
     (G[{0}, yw]*G[{1}, yw]^2*G[{yu^(-1), 1/(yu*yv)}, yw])/16 - 
     (G[{1}, yu^(-1)]*G[{1}, yw]^2*G[{yu^(-1), 1/(yu*yv)}, yw])/128 + 
     (5*G[{1}, yw]^3*G[{yu^(-1), 1/(yu*yv)}, yw])/128 + 
     (Pi^2*G[{yu^(-1)}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw])/96 - 
     (G[{0}, yu^(-1)]^2*G[{yu^(-1)}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw])/16 - 
     (G[{0}, yu^(-1)]*G[{0}, yv^(-1)]*G[{yu^(-1)}, yw]*
       G[{yu^(-1), 1/(yu*yv)}, yw])/8 - (G[{0}, yv^(-1)]^2*G[{yu^(-1)}, yw]*
       G[{yu^(-1), 1/(yu*yv)}, yw])/16 + 
     (G[{0}, yu^(-1)]*G[{0}, yw]*G[{yu^(-1)}, yw]*G[{yu^(-1), 1/(yu*yv)}, 
        yw])/8 + (G[{0}, yv^(-1)]*G[{0}, yw]*G[{yu^(-1)}, yw]*
       G[{yu^(-1), 1/(yu*yv)}, yw])/8 - (G[{0}, yw]^2*G[{yu^(-1)}, yw]*
       G[{yu^(-1), 1/(yu*yv)}, yw])/16 - (G[{0}, yu^(-1)]*G[{1}, yu^(-1)]*
       G[{yu^(-1)}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw])/8 - 
     (G[{0}, yv^(-1)]*G[{1}, yu^(-1)]*G[{yu^(-1)}, yw]*
       G[{yu^(-1), 1/(yu*yv)}, yw])/8 + (G[{0}, yw]*G[{1}, yu^(-1)]*
       G[{yu^(-1)}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw])/8 + 
     (G[{1}, yu^(-1)]^2*G[{yu^(-1)}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw])/32 + 
     (G[{0}, yu^(-1)]*G[{1}, yv^(-1)]*G[{yu^(-1)}, yw]*
       G[{yu^(-1), 1/(yu*yv)}, yw])/8 + (G[{0}, yv^(-1)]*G[{1}, yv^(-1)]*
       G[{yu^(-1)}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw])/8 - 
     (G[{0}, yw]*G[{1}, yv^(-1)]*G[{yu^(-1)}, yw]*G[{yu^(-1), 1/(yu*yv)}, 
        yw])/8 + (3*G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*G[{yu^(-1)}, yw]*
       G[{yu^(-1), 1/(yu*yv)}, yw])/16 - (G[{1}, yv^(-1)]^2*G[{yu^(-1)}, yw]*
       G[{yu^(-1), 1/(yu*yv)}, yw])/16 - 
     (G[{0}, yu^(-1)]*G[{1}, yw]*G[{yu^(-1)}, yw]*G[{yu^(-1), 1/(yu*yv)}, 
        yw])/8 - (G[{0}, yv^(-1)]*G[{1}, yw]*G[{yu^(-1)}, yw]*
       G[{yu^(-1), 1/(yu*yv)}, yw])/8 + 
     (G[{0}, yw]*G[{1}, yw]*G[{yu^(-1)}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw])/8 - 
     (3*G[{1}, yu^(-1)]*G[{1}, yw]*G[{yu^(-1)}, yw]*G[{yu^(-1), 1/(yu*yv)}, 
        yw])/16 + (G[{1}, yv^(-1)]*G[{1}, yw]*G[{yu^(-1)}, yw]*
       G[{yu^(-1), 1/(yu*yv)}, yw])/8 - (5*G[{1}, yw]^2*G[{yu^(-1)}, yw]*
       G[{yu^(-1), 1/(yu*yv)}, yw])/32 - (G[{0}, yu^(-1)]*G[{yu^(-1)}, yw]^2*
       G[{yu^(-1), 1/(yu*yv)}, yw])/8 - (G[{0}, yv^(-1)]*G[{yu^(-1)}, yw]^2*
       G[{yu^(-1), 1/(yu*yv)}, yw])/8 + (G[{0}, yw]*G[{yu^(-1)}, yw]^2*
       G[{yu^(-1), 1/(yu*yv)}, yw])/8 + (G[{1}, yv^(-1)]*G[{yu^(-1)}, yw]^2*
       G[{yu^(-1), 1/(yu*yv)}, yw])/16 - (3*G[{1}, yw]*G[{yu^(-1)}, yw]^2*
       G[{yu^(-1), 1/(yu*yv)}, yw])/16 - 
     (G[{yu^(-1)}, yw]^3*G[{yu^(-1), 1/(yu*yv)}, yw])/48 + 
     (Pi^2*G[{yu}, yv^(-1)]*G[{yu^(-1), 1/(yu*yv)}, yw])/96 + 
     (G[{0}, yu^(-1)]*G[{1}, yu^(-1)]*G[{yu}, yv^(-1)]*
       G[{yu^(-1), 1/(yu*yv)}, yw])/8 + (G[{0}, yv^(-1)]*G[{1}, yu^(-1)]*
       G[{yu}, yv^(-1)]*G[{yu^(-1), 1/(yu*yv)}, yw])/8 - 
     (G[{0}, yw]*G[{1}, yu^(-1)]*G[{yu}, yv^(-1)]*G[{yu^(-1), 1/(yu*yv)}, 
        yw])/8 - (3*G[{1}, yu^(-1)]^2*G[{yu}, yv^(-1)]*
       G[{yu^(-1), 1/(yu*yv)}, yw])/32 - (G[{0}, yu^(-1)]*G[{1}, yv^(-1)]*
       G[{yu}, yv^(-1)]*G[{yu^(-1), 1/(yu*yv)}, yw])/8 - 
     (G[{0}, yv^(-1)]*G[{1}, yv^(-1)]*G[{yu}, yv^(-1)]*
       G[{yu^(-1), 1/(yu*yv)}, yw])/8 + (G[{0}, yw]*G[{1}, yv^(-1)]*
       G[{yu}, yv^(-1)]*G[{yu^(-1), 1/(yu*yv)}, yw])/8 - 
     (G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*G[{yu}, yv^(-1)]*
       G[{yu^(-1), 1/(yu*yv)}, yw])/16 + (G[{1}, yv^(-1)]^2*G[{yu}, yv^(-1)]*
       G[{yu^(-1), 1/(yu*yv)}, yw])/8 - (G[{0}, yu^(-1)]*G[{1}, yw]*
       G[{yu}, yv^(-1)]*G[{yu^(-1), 1/(yu*yv)}, yw])/16 - 
     (G[{0}, yv^(-1)]*G[{1}, yw]*G[{yu}, yv^(-1)]*G[{yu^(-1), 1/(yu*yv)}, 
        yw])/16 + (G[{0}, yw]*G[{1}, yw]*G[{yu}, yv^(-1)]*
       G[{yu^(-1), 1/(yu*yv)}, yw])/16 + 
     (G[{1}, yu^(-1)]*G[{1}, yw]*G[{yu}, yv^(-1)]*G[{yu^(-1), 1/(yu*yv)}, 
        yw])/32 - (G[{1}, yv^(-1)]*G[{1}, yw]*G[{yu}, yv^(-1)]*
       G[{yu^(-1), 1/(yu*yv)}, yw])/8 - (15*G[{1}, yw]^2*G[{yu}, yv^(-1)]*
       G[{yu^(-1), 1/(yu*yv)}, yw])/128 + 
     (G[{0}, yu^(-1)]*G[{yu^(-1)}, yw]*G[{yu}, yv^(-1)]*
       G[{yu^(-1), 1/(yu*yv)}, yw])/4 + (G[{0}, yv^(-1)]*G[{yu^(-1)}, yw]*
       G[{yu}, yv^(-1)]*G[{yu^(-1), 1/(yu*yv)}, yw])/4 - 
     (G[{0}, yw]*G[{yu^(-1)}, yw]*G[{yu}, yv^(-1)]*G[{yu^(-1), 1/(yu*yv)}, 
        yw])/4 - (3*G[{1}, yv^(-1)]*G[{yu^(-1)}, yw]*G[{yu}, yv^(-1)]*
       G[{yu^(-1), 1/(yu*yv)}, yw])/8 + (5*G[{1}, yw]*G[{yu^(-1)}, yw]*
       G[{yu}, yv^(-1)]*G[{yu^(-1), 1/(yu*yv)}, yw])/16 + 
     (3*G[{yu^(-1)}, yw]^2*G[{yu}, yv^(-1)]*G[{yu^(-1), 1/(yu*yv)}, yw])/16 + 
     (G[{1}, yv^(-1)]*G[{yu}, yv^(-1)]^2*G[{yu^(-1), 1/(yu*yv)}, yw])/16 + 
     (7*G[{1}, yw]*G[{yu}, yv^(-1)]^2*G[{yu^(-1), 1/(yu*yv)}, yw])/64 - 
     (G[{yu^(-1)}, yw]*G[{yu}, yv^(-1)]^2*G[{yu^(-1), 1/(yu*yv)}, yw])/16 - 
     (G[{yu}, yv^(-1)]^3*G[{yu^(-1), 1/(yu*yv)}, yw])/48 - 
     (G[{0}, yu^(-1)]*G[{1}, yu^(-1)]*G[{1/(yu*yv)}, yw]*
       G[{yu^(-1), 1/(yu*yv)}, yw])/16 - (G[{0}, yv^(-1)]*G[{1}, yu^(-1)]*
       G[{1/(yu*yv)}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw])/16 + 
     (G[{0}, yw]*G[{1}, yu^(-1)]*G[{1/(yu*yv)}, yw]*G[{yu^(-1), 1/(yu*yv)}, 
        yw])/16 + (13*G[{1}, yu^(-1)]^2*G[{1/(yu*yv)}, yw]*
       G[{yu^(-1), 1/(yu*yv)}, yw])/128 - 
     (3*G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*G[{1/(yu*yv)}, yw]*
       G[{yu^(-1), 1/(yu*yv)}, yw])/64 + 
     (G[{1}, yu^(-1)]*G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{yu^(-1), 1/(yu*yv)}, 
        yw])/64 - (G[{1}, yv^(-1)]*G[{1}, yw]*G[{1/(yu*yv)}, yw]*
       G[{yu^(-1), 1/(yu*yv)}, yw])/16 - (3*G[{1}, yw]^2*G[{1/(yu*yv)}, yw]*
       G[{yu^(-1), 1/(yu*yv)}, yw])/128 - 
     (G[{0}, yu^(-1)]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*
       G[{yu^(-1), 1/(yu*yv)}, yw])/16 - (G[{0}, yv^(-1)]*G[{yu^(-1)}, yw]*
       G[{1/(yu*yv)}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw])/16 + 
     (G[{0}, yw]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{yu^(-1), 1/(yu*yv)}, 
        yw])/16 + (G[{1}, yu^(-1)]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*
       G[{yu^(-1), 1/(yu*yv)}, yw])/16 + (G[{1}, yv^(-1)]*G[{yu^(-1)}, yw]*
       G[{1/(yu*yv)}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw])/8 + 
     (G[{1}, yw]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{yu^(-1), 1/(yu*yv)}, 
        yw])/16 - (G[{yu^(-1)}, yw]^2*G[{1/(yu*yv)}, yw]*
       G[{yu^(-1), 1/(yu*yv)}, yw])/16 + (G[{0}, yu^(-1)]*G[{yu}, yv^(-1)]*
       G[{1/(yu*yv)}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw])/16 + 
     (G[{0}, yv^(-1)]*G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw]*
       G[{yu^(-1), 1/(yu*yv)}, yw])/16 - 
     (G[{0}, yw]*G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{yu^(-1), 1/(yu*yv)}, 
        yw])/16 - (G[{1}, yu^(-1)]*G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw]*
       G[{yu^(-1), 1/(yu*yv)}, yw])/32 + (G[{1}, yv^(-1)]*G[{yu}, yv^(-1)]*
       G[{1/(yu*yv)}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw])/16 + 
     (3*G[{1}, yw]*G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw]*
       G[{yu^(-1), 1/(yu*yv)}, yw])/64 - (G[{yu^(-1)}, yw]*G[{yu}, yv^(-1)]*
       G[{1/(yu*yv)}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw])/16 - 
     (5*G[{yu}, yv^(-1)]^2*G[{1/(yu*yv)}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw])/
      64 + (3*G[{0}, yu^(-1)]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*
       G[{yu^(-1), 1/(yu*yv)}, yw])/16 + (3*G[{0}, yv^(-1)]*G[{yv^(-1)}, yw]*
       G[{1/(yu*yv)}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw])/16 - 
     (3*G[{0}, yw]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*
       G[{yu^(-1), 1/(yu*yv)}, yw])/16 + (G[{1}, yu^(-1)]*G[{yv^(-1)}, yw]*
       G[{1/(yu*yv)}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw])/32 - 
     (3*G[{1}, yv^(-1)]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*
       G[{yu^(-1), 1/(yu*yv)}, yw])/16 + (7*G[{1}, yw]*G[{yv^(-1)}, yw]*
       G[{1/(yu*yv)}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw])/32 + 
     (3*G[{yu^(-1)}, yw]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*
       G[{yu^(-1), 1/(yu*yv)}, yw])/16 - (7*G[{yu}, yv^(-1)]*G[{yv^(-1)}, yw]*
       G[{1/(yu*yv)}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw])/32 - 
     (9*G[{yv^(-1)}, yw]^2*G[{1/(yu*yv)}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw])/
      64 + (G[{0}, yu^(-1)]*G[{1/(yu*yv)}, yw]^2*G[{yu^(-1), 1/(yu*yv)}, yw])/
      16 + (G[{0}, yv^(-1)]*G[{1/(yu*yv)}, yw]^2*G[{yu^(-1), 1/(yu*yv)}, yw])/
      16 - (G[{0}, yw]*G[{1/(yu*yv)}, yw]^2*G[{yu^(-1), 1/(yu*yv)}, yw])/16 - 
     (7*G[{1}, yu^(-1)]*G[{1/(yu*yv)}, yw]^2*G[{yu^(-1), 1/(yu*yv)}, yw])/
      128 - (G[{1}, yv^(-1)]*G[{1/(yu*yv)}, yw]^2*G[{yu^(-1), 1/(yu*yv)}, 
        yw])/16 + (G[{1}, yw]*G[{1/(yu*yv)}, yw]^2*G[{yu^(-1), 1/(yu*yv)}, 
        yw])/128 + (G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2*
       G[{yu^(-1), 1/(yu*yv)}, yw])/16 - 
     (G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw]^2*G[{yu^(-1), 1/(yu*yv)}, yw])/
      128 + (7*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2*G[{yu^(-1), 1/(yu*yv)}, 
        yw])/128 - (G[{1}, yu^(-1)]*G[{0, 1}, yu^(-1)]*
       G[{yu^(-1), 1/(yu*yv)}, yw])/64 - 
     (3*G[{1}, yv^(-1)]*G[{0, 1}, yu^(-1)]*G[{yu^(-1), 1/(yu*yv)}, yw])/64 - 
     (5*G[{1}, yw]*G[{0, 1}, yu^(-1)]*G[{yu^(-1), 1/(yu*yv)}, yw])/64 + 
     (G[{yu^(-1)}, yw]*G[{0, 1}, yu^(-1)]*G[{yu^(-1), 1/(yu*yv)}, yw])/16 + 
     (G[{yu}, yv^(-1)]*G[{0, 1}, yu^(-1)]*G[{yu^(-1), 1/(yu*yv)}, yw])/16 - 
     (3*G[{1/(yu*yv)}, yw]*G[{0, 1}, yu^(-1)]*G[{yu^(-1), 1/(yu*yv)}, yw])/
      64 + (G[{0}, yu^(-1)]*G[{0, 1}, yv^(-1)]*G[{yu^(-1), 1/(yu*yv)}, yw])/
      16 + (G[{0}, yv^(-1)]*G[{0, 1}, yv^(-1)]*G[{yu^(-1), 1/(yu*yv)}, yw])/
      16 - (G[{0}, yw]*G[{0, 1}, yv^(-1)]*G[{yu^(-1), 1/(yu*yv)}, yw])/16 - 
     (G[{1}, yv^(-1)]*G[{0, 1}, yv^(-1)]*G[{yu^(-1), 1/(yu*yv)}, yw])/16 + 
     (G[{1}, yw]*G[{0, 1}, yv^(-1)]*G[{yu^(-1), 1/(yu*yv)}, yw])/16 + 
     (G[{yu^(-1)}, yw]*G[{0, 1}, yv^(-1)]*G[{yu^(-1), 1/(yu*yv)}, yw])/8 - 
     (G[{1/(yu*yv)}, yw]*G[{0, 1}, yv^(-1)]*G[{yu^(-1), 1/(yu*yv)}, yw])/16 + 
     (G[{1}, yu^(-1)]*G[{0, 1}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw])/8 + 
     (G[{1}, yw]*G[{0, 1}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw])/16 + 
     (G[{yu^(-1)}, yw]*G[{0, 1}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw])/8 - 
     (G[{yu}, yv^(-1)]*G[{0, 1}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw])/8 + 
     (G[{1/(yu*yv)}, yw]*G[{0, 1}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw])/16 - 
     (G[{1}, yu^(-1)]*G[{0, yu^(-1)}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw])/8 - 
     (G[{1}, yw]*G[{0, yu^(-1)}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw])/16 - 
     (G[{yu^(-1)}, yw]*G[{0, yu^(-1)}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw])/8 + 
     (G[{yu}, yv^(-1)]*G[{0, yu^(-1)}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw])/8 - 
     (G[{1/(yu*yv)}, yw]*G[{0, yu^(-1)}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw])/
      16 - (G[{0}, yu^(-1)]*G[{0, yu}, yv^(-1)]*G[{yu^(-1), 1/(yu*yv)}, yw])/
      16 - (G[{0}, yv^(-1)]*G[{0, yu}, yv^(-1)]*G[{yu^(-1), 1/(yu*yv)}, yw])/
      16 + (G[{0}, yw]*G[{0, yu}, yv^(-1)]*G[{yu^(-1), 1/(yu*yv)}, yw])/16 + 
     (G[{1}, yv^(-1)]*G[{0, yu}, yv^(-1)]*G[{yu^(-1), 1/(yu*yv)}, yw])/16 - 
     (G[{1}, yw]*G[{0, yu}, yv^(-1)]*G[{yu^(-1), 1/(yu*yv)}, yw])/16 - 
     (G[{yu^(-1)}, yw]*G[{0, yu}, yv^(-1)]*G[{yu^(-1), 1/(yu*yv)}, yw])/8 + 
     (G[{1/(yu*yv)}, yw]*G[{0, yu}, yv^(-1)]*G[{yu^(-1), 1/(yu*yv)}, yw])/
      16 - (G[{1}, yu^(-1)]*G[{0, yv^(-1)}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw])/
      8 - (G[{1}, yw]*G[{0, yv^(-1)}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw])/16 - 
     (G[{yu^(-1)}, yw]*G[{0, yv^(-1)}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw])/8 + 
     (G[{yu}, yv^(-1)]*G[{0, yv^(-1)}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw])/8 - 
     (G[{1/(yu*yv)}, yw]*G[{0, yv^(-1)}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw])/
      16 + (G[{1}, yu^(-1)]*G[{0, 1/(yu*yv)}, yw]*G[{yu^(-1), 1/(yu*yv)}, 
        yw])/8 + (G[{1}, yw]*G[{0, 1/(yu*yv)}, yw]*G[{yu^(-1), 1/(yu*yv)}, 
        yw])/16 + (G[{yu^(-1)}, yw]*G[{0, 1/(yu*yv)}, yw]*
       G[{yu^(-1), 1/(yu*yv)}, yw])/8 - 
     (G[{yu}, yv^(-1)]*G[{0, 1/(yu*yv)}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw])/8 + 
     (G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv)}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw])/
      16 + (G[{0}, yu^(-1)]*G[{1, yu^(-1)}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw])/
      16 + (G[{0}, yv^(-1)]*G[{1, yu^(-1)}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw])/
      16 - (G[{0}, yw]*G[{1, yu^(-1)}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw])/16 + 
     (G[{1}, yu^(-1)]*G[{1, yu^(-1)}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw])/8 - 
     (G[{1}, yv^(-1)]*G[{1, yu^(-1)}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw])/16 + 
     (3*G[{1}, yw]*G[{1, yu^(-1)}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw])/16 + 
     (G[{yu^(-1)}, yw]*G[{1, yu^(-1)}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw])/4 - 
     (3*G[{yu}, yv^(-1)]*G[{1, yu^(-1)}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw])/
      16 + (G[{0}, yu^(-1)]*G[{1, yu}, yv^(-1)]*G[{yu^(-1), 1/(yu*yv)}, yw])/
      16 + (G[{0}, yv^(-1)]*G[{1, yu}, yv^(-1)]*G[{yu^(-1), 1/(yu*yv)}, yw])/
      16 - (G[{0}, yw]*G[{1, yu}, yv^(-1)]*G[{yu^(-1), 1/(yu*yv)}, yw])/16 + 
     (G[{1}, yu^(-1)]*G[{1, yu}, yv^(-1)]*G[{yu^(-1), 1/(yu*yv)}, yw])/32 + 
     (9*G[{1}, yw]*G[{1, yu}, yv^(-1)]*G[{yu^(-1), 1/(yu*yv)}, yw])/64 + 
     (G[{yu^(-1)}, yw]*G[{1, yu}, yv^(-1)]*G[{yu^(-1), 1/(yu*yv)}, yw])/16 - 
     (G[{yu}, yv^(-1)]*G[{1, yu}, yv^(-1)]*G[{yu^(-1), 1/(yu*yv)}, yw])/16 - 
     (G[{1/(yu*yv)}, yw]*G[{1, yu}, yv^(-1)]*G[{yu^(-1), 1/(yu*yv)}, yw])/
      64 + (3*G[{1}, yu^(-1)]*G[{1, yv^(-1)}, yw]*G[{yu^(-1), 1/(yu*yv)}, 
        yw])/32 - (G[{1}, yv^(-1)]*G[{1, yv^(-1)}, yw]*
       G[{yu^(-1), 1/(yu*yv)}, yw])/16 + (G[{1}, yw]*G[{1, yv^(-1)}, yw]*
       G[{yu^(-1), 1/(yu*yv)}, yw])/32 + 
     (3*G[{yu^(-1)}, yw]*G[{1, yv^(-1)}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw])/
      16 - (G[{yu}, yv^(-1)]*G[{1, yv^(-1)}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw])/
      32 + (G[{1/(yu*yv)}, yw]*G[{1, yv^(-1)}, yw]*G[{yu^(-1), 1/(yu*yv)}, 
        yw])/64 - (G[{0}, yu^(-1)]*G[{1, 1/(yu*yv)}, yw]*
       G[{yu^(-1), 1/(yu*yv)}, yw])/16 - 
     (G[{0}, yv^(-1)]*G[{1, 1/(yu*yv)}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw])/16 + 
     (G[{0}, yw]*G[{1, 1/(yu*yv)}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw])/16 + 
     (G[{1}, yu^(-1)]*G[{1, 1/(yu*yv)}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw])/32 + 
     (G[{1}, yv^(-1)]*G[{1, 1/(yu*yv)}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw])/8 + 
     (G[{1}, yw]*G[{1, 1/(yu*yv)}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw])/32 - 
     (3*G[{yu^(-1)}, yw]*G[{1, 1/(yu*yv)}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw])/
      16 - (G[{yu}, yv^(-1)]*G[{1, 1/(yu*yv)}, yw]*G[{yu^(-1), 1/(yu*yv)}, 
        yw])/32 + (7*G[{1/(yu*yv)}, yw]*G[{1, 1/(yu*yv)}, yw]*
       G[{yu^(-1), 1/(yu*yv)}, yw])/64 + 
     (G[{0}, yu^(-1)]*G[{yu^(-1), 1/(yu*yv)}, yw]^2)/32 + 
     (G[{0}, yv^(-1)]*G[{yu^(-1), 1/(yu*yv)}, yw]^2)/32 - 
     (G[{0}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw]^2)/32 - 
     (G[{1}, yu^(-1)]*G[{yu^(-1), 1/(yu*yv)}, yw]^2)/16 - 
     (G[{1}, yv^(-1)]*G[{yu^(-1), 1/(yu*yv)}, yw]^2)/32 - 
     (G[{1}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw]^2)/32 + 
     (G[{yu^(-1)}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw]^2)/32 + 
     (G[{yu}, yv^(-1)]*G[{yu^(-1), 1/(yu*yv)}, yw]^2)/32 - 
     (G[{1/(yu*yv)}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw]^2)/16 + 
     (Pi^2*G[{0}, yu^(-1)]*G[{yv^(-1), 1/(yu*yv)}, yw])/48 + 
     (Pi^2*G[{0}, yv^(-1)]*G[{yv^(-1), 1/(yu*yv)}, yw])/48 - 
     (Pi^2*G[{0}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw])/48 - 
     (11*Pi^2*G[{1}, yu^(-1)]*G[{yv^(-1), 1/(yu*yv)}, yw])/256 + 
     (G[{0}, yu^(-1)]^2*G[{1}, yu^(-1)]*G[{yv^(-1), 1/(yu*yv)}, yw])/32 + 
     (G[{0}, yu^(-1)]*G[{0}, yv^(-1)]*G[{1}, yu^(-1)]*G[{yv^(-1), 1/(yu*yv)}, 
        yw])/16 + (G[{0}, yv^(-1)]^2*G[{1}, yu^(-1)]*G[{yv^(-1), 1/(yu*yv)}, 
        yw])/32 - (G[{0}, yu^(-1)]*G[{0}, yw]*G[{1}, yu^(-1)]*
       G[{yv^(-1), 1/(yu*yv)}, yw])/16 - 
     (G[{0}, yv^(-1)]*G[{0}, yw]*G[{1}, yu^(-1)]*G[{yv^(-1), 1/(yu*yv)}, yw])/
      16 + (G[{0}, yw]^2*G[{1}, yu^(-1)]*G[{yv^(-1), 1/(yu*yv)}, yw])/32 + 
     (G[{0}, yu^(-1)]*G[{1}, yu^(-1)]^2*G[{yv^(-1), 1/(yu*yv)}, yw])/32 + 
     (G[{0}, yv^(-1)]*G[{1}, yu^(-1)]^2*G[{yv^(-1), 1/(yu*yv)}, yw])/32 - 
     (G[{0}, yw]*G[{1}, yu^(-1)]^2*G[{yv^(-1), 1/(yu*yv)}, yw])/32 - 
     (G[{1}, yu^(-1)]^3*G[{yv^(-1), 1/(yu*yv)}, yw])/16 + 
     (Pi^2*G[{1}, yv^(-1)]*G[{yv^(-1), 1/(yu*yv)}, yw])/96 - 
     (G[{0}, yu^(-1)]^2*G[{1}, yv^(-1)]*G[{yv^(-1), 1/(yu*yv)}, yw])/32 - 
     (G[{0}, yu^(-1)]*G[{0}, yv^(-1)]*G[{1}, yv^(-1)]*G[{yv^(-1), 1/(yu*yv)}, 
        yw])/16 - (G[{0}, yv^(-1)]^2*G[{1}, yv^(-1)]*G[{yv^(-1), 1/(yu*yv)}, 
        yw])/32 + (G[{0}, yu^(-1)]*G[{0}, yw]*G[{1}, yv^(-1)]*
       G[{yv^(-1), 1/(yu*yv)}, yw])/16 + 
     (G[{0}, yv^(-1)]*G[{0}, yw]*G[{1}, yv^(-1)]*G[{yv^(-1), 1/(yu*yv)}, yw])/
      16 - (G[{0}, yw]^2*G[{1}, yv^(-1)]*G[{yv^(-1), 1/(yu*yv)}, yw])/32 - 
     (G[{0}, yu^(-1)]*G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*G[{yv^(-1), 1/(yu*yv)}, 
        yw])/16 - (G[{0}, yv^(-1)]*G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*
       G[{yv^(-1), 1/(yu*yv)}, yw])/16 + 
     (G[{0}, yw]*G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*G[{yv^(-1), 1/(yu*yv)}, yw])/
      16 + (3*G[{1}, yu^(-1)]^2*G[{1}, yv^(-1)]*G[{yv^(-1), 1/(yu*yv)}, yw])/
      64 + (G[{0}, yu^(-1)]*G[{1}, yv^(-1)]^2*G[{yv^(-1), 1/(yu*yv)}, yw])/
      16 + (G[{0}, yv^(-1)]*G[{1}, yv^(-1)]^2*G[{yv^(-1), 1/(yu*yv)}, yw])/
      16 - (G[{0}, yw]*G[{1}, yv^(-1)]^2*G[{yv^(-1), 1/(yu*yv)}, yw])/16 + 
     (G[{1}, yu^(-1)]*G[{1}, yv^(-1)]^2*G[{yv^(-1), 1/(yu*yv)}, yw])/16 - 
     (G[{1}, yv^(-1)]^3*G[{yv^(-1), 1/(yu*yv)}, yw])/32 - 
     (Pi^2*G[{1}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw])/768 + 
     (G[{0}, yu^(-1)]^2*G[{1}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw])/32 + 
     (G[{0}, yu^(-1)]*G[{0}, yv^(-1)]*G[{1}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw])/
      16 + (G[{0}, yv^(-1)]^2*G[{1}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw])/32 - 
     (G[{0}, yu^(-1)]*G[{0}, yw]*G[{1}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw])/16 - 
     (G[{0}, yv^(-1)]*G[{0}, yw]*G[{1}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw])/16 + 
     (G[{0}, yw]^2*G[{1}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw])/32 + 
     (3*G[{0}, yu^(-1)]*G[{1}, yu^(-1)]*G[{1}, yw]*G[{yv^(-1), 1/(yu*yv)}, 
        yw])/16 + (3*G[{0}, yv^(-1)]*G[{1}, yu^(-1)]*G[{1}, yw]*
       G[{yv^(-1), 1/(yu*yv)}, yw])/16 - (3*G[{0}, yw]*G[{1}, yu^(-1)]*
       G[{1}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw])/16 - 
     (G[{1}, yu^(-1)]^2*G[{1}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw])/8 - 
     (G[{0}, yu^(-1)]*G[{1}, yv^(-1)]*G[{1}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw])/
      4 - (G[{0}, yv^(-1)]*G[{1}, yv^(-1)]*G[{1}, yw]*G[{yv^(-1), 1/(yu*yv)}, 
        yw])/4 + (G[{0}, yw]*G[{1}, yv^(-1)]*G[{1}, yw]*
       G[{yv^(-1), 1/(yu*yv)}, yw])/4 + (G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*
       G[{1}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw])/16 + 
     (11*G[{1}, yv^(-1)]^2*G[{1}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw])/64 + 
     (G[{0}, yu^(-1)]*G[{1}, yw]^2*G[{yv^(-1), 1/(yu*yv)}, yw])/16 + 
     (G[{0}, yv^(-1)]*G[{1}, yw]^2*G[{yv^(-1), 1/(yu*yv)}, yw])/16 - 
     (G[{0}, yw]*G[{1}, yw]^2*G[{yv^(-1), 1/(yu*yv)}, yw])/16 + 
     (5*G[{1}, yu^(-1)]*G[{1}, yw]^2*G[{yv^(-1), 1/(yu*yv)}, yw])/64 - 
     (G[{1}, yv^(-1)]*G[{1}, yw]^2*G[{yv^(-1), 1/(yu*yv)}, yw])/16 + 
     (3*G[{1}, yw]^3*G[{yv^(-1), 1/(yu*yv)}, yw])/64 - 
     (7*Pi^2*G[{yu}, yv^(-1)]*G[{yv^(-1), 1/(yu*yv)}, yw])/768 - 
     (G[{0}, yu^(-1)]*G[{1}, yu^(-1)]*G[{yu}, yv^(-1)]*
       G[{yv^(-1), 1/(yu*yv)}, yw])/8 - (G[{0}, yv^(-1)]*G[{1}, yu^(-1)]*
       G[{yu}, yv^(-1)]*G[{yv^(-1), 1/(yu*yv)}, yw])/8 + 
     (G[{0}, yw]*G[{1}, yu^(-1)]*G[{yu}, yv^(-1)]*G[{yv^(-1), 1/(yu*yv)}, 
        yw])/8 + (5*G[{1}, yu^(-1)]^2*G[{yu}, yv^(-1)]*
       G[{yv^(-1), 1/(yu*yv)}, yw])/64 + (G[{0}, yu^(-1)]*G[{1}, yv^(-1)]*
       G[{yu}, yv^(-1)]*G[{yv^(-1), 1/(yu*yv)}, yw])/8 + 
     (G[{0}, yv^(-1)]*G[{1}, yv^(-1)]*G[{yu}, yv^(-1)]*
       G[{yv^(-1), 1/(yu*yv)}, yw])/8 - (G[{0}, yw]*G[{1}, yv^(-1)]*
       G[{yu}, yv^(-1)]*G[{yv^(-1), 1/(yu*yv)}, yw])/8 - 
     (G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*G[{yu}, yv^(-1)]*
       G[{yv^(-1), 1/(yu*yv)}, yw])/8 - (5*G[{1}, yv^(-1)]^2*G[{yu}, yv^(-1)]*
       G[{yv^(-1), 1/(yu*yv)}, yw])/64 - 
     (G[{0}, yu^(-1)]*G[{1}, yw]*G[{yu}, yv^(-1)]*G[{yv^(-1), 1/(yu*yv)}, 
        yw])/16 - (G[{0}, yv^(-1)]*G[{1}, yw]*G[{yu}, yv^(-1)]*
       G[{yv^(-1), 1/(yu*yv)}, yw])/16 + 
     (G[{0}, yw]*G[{1}, yw]*G[{yu}, yv^(-1)]*G[{yv^(-1), 1/(yu*yv)}, yw])/
      16 - (3*G[{1}, yu^(-1)]*G[{1}, yw]*G[{yu}, yv^(-1)]*
       G[{yv^(-1), 1/(yu*yv)}, yw])/16 + 
     (G[{1}, yv^(-1)]*G[{1}, yw]*G[{yu}, yv^(-1)]*G[{yv^(-1), 1/(yu*yv)}, 
        yw])/32 - (9*G[{1}, yw]^2*G[{yu}, yv^(-1)]*G[{yv^(-1), 1/(yu*yv)}, 
        yw])/64 + (7*G[{1}, yu^(-1)]*G[{yu}, yv^(-1)]^2*
       G[{yv^(-1), 1/(yu*yv)}, yw])/64 + (9*G[{1}, yw]*G[{yu}, yv^(-1)]^2*
       G[{yv^(-1), 1/(yu*yv)}, yw])/64 - 
     (7*G[{yu}, yv^(-1)]^3*G[{yv^(-1), 1/(yu*yv)}, yw])/192 + 
     (41*Pi^2*G[{yv^(-1)}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw])/768 - 
     (G[{0}, yu^(-1)]^2*G[{yv^(-1)}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw])/16 - 
     (G[{0}, yu^(-1)]*G[{0}, yv^(-1)]*G[{yv^(-1)}, yw]*
       G[{yv^(-1), 1/(yu*yv)}, yw])/8 - (G[{0}, yv^(-1)]^2*G[{yv^(-1)}, yw]*
       G[{yv^(-1), 1/(yu*yv)}, yw])/16 + 
     (G[{0}, yu^(-1)]*G[{0}, yw]*G[{yv^(-1)}, yw]*G[{yv^(-1), 1/(yu*yv)}, 
        yw])/8 + (G[{0}, yv^(-1)]*G[{0}, yw]*G[{yv^(-1)}, yw]*
       G[{yv^(-1), 1/(yu*yv)}, yw])/8 - (G[{0}, yw]^2*G[{yv^(-1)}, yw]*
       G[{yv^(-1), 1/(yu*yv)}, yw])/16 - (G[{0}, yu^(-1)]*G[{1}, yu^(-1)]*
       G[{yv^(-1)}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw])/4 - 
     (G[{0}, yv^(-1)]*G[{1}, yu^(-1)]*G[{yv^(-1)}, yw]*
       G[{yv^(-1), 1/(yu*yv)}, yw])/4 + (G[{0}, yw]*G[{1}, yu^(-1)]*
       G[{yv^(-1)}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw])/4 + 
     (29*G[{1}, yu^(-1)]^2*G[{yv^(-1)}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw])/64 + 
     (G[{0}, yu^(-1)]*G[{1}, yv^(-1)]*G[{yv^(-1)}, yw]*
       G[{yv^(-1), 1/(yu*yv)}, yw])/4 + (G[{0}, yv^(-1)]*G[{1}, yv^(-1)]*
       G[{yv^(-1)}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw])/4 - 
     (G[{0}, yw]*G[{1}, yv^(-1)]*G[{yv^(-1)}, yw]*G[{yv^(-1), 1/(yu*yv)}, 
        yw])/4 - (G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*G[{yv^(-1)}, yw]*
       G[{yv^(-1), 1/(yu*yv)}, yw])/8 - (9*G[{1}, yv^(-1)]^2*G[{yv^(-1)}, yw]*
       G[{yv^(-1), 1/(yu*yv)}, yw])/64 - 
     (G[{0}, yu^(-1)]*G[{1}, yw]*G[{yv^(-1)}, yw]*G[{yv^(-1), 1/(yu*yv)}, 
        yw])/2 - (G[{0}, yv^(-1)]*G[{1}, yw]*G[{yv^(-1)}, yw]*
       G[{yv^(-1), 1/(yu*yv)}, yw])/2 + 
     (G[{0}, yw]*G[{1}, yw]*G[{yv^(-1)}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw])/2 + 
     (13*G[{1}, yu^(-1)]*G[{1}, yw]*G[{yv^(-1)}, yw]*G[{yv^(-1), 1/(yu*yv)}, 
        yw])/32 + (7*G[{1}, yv^(-1)]*G[{1}, yw]*G[{yv^(-1)}, yw]*
       G[{yv^(-1), 1/(yu*yv)}, yw])/32 - (3*G[{1}, yw]^2*G[{yv^(-1)}, yw]*
       G[{yv^(-1), 1/(yu*yv)}, yw])/16 + (G[{0}, yu^(-1)]*G[{yu}, yv^(-1)]*
       G[{yv^(-1)}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw])/4 + 
     (G[{0}, yv^(-1)]*G[{yu}, yv^(-1)]*G[{yv^(-1)}, yw]*
       G[{yv^(-1), 1/(yu*yv)}, yw])/4 - (G[{0}, yw]*G[{yu}, yv^(-1)]*
       G[{yv^(-1)}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw])/4 - 
     (9*G[{1}, yu^(-1)]*G[{yu}, yv^(-1)]*G[{yv^(-1)}, yw]*
       G[{yv^(-1), 1/(yu*yv)}, yw])/32 + (3*G[{1}, yw]*G[{yu}, yv^(-1)]*
       G[{yv^(-1)}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw])/8 - 
     (7*G[{yu}, yv^(-1)]^2*G[{yv^(-1)}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw])/64 + 
     (G[{0}, yu^(-1)]*G[{yv^(-1)}, yw]^2*G[{yv^(-1), 1/(yu*yv)}, yw])/4 + 
     (G[{0}, yv^(-1)]*G[{yv^(-1)}, yw]^2*G[{yv^(-1), 1/(yu*yv)}, yw])/4 - 
     (G[{0}, yw]*G[{yv^(-1)}, yw]^2*G[{yv^(-1), 1/(yu*yv)}, yw])/4 - 
     (41*G[{1}, yu^(-1)]*G[{yv^(-1)}, yw]^2*G[{yv^(-1), 1/(yu*yv)}, yw])/64 - 
     (9*G[{1}, yw]*G[{yv^(-1)}, yw]^2*G[{yv^(-1), 1/(yu*yv)}, yw])/64 + 
     (9*G[{yu}, yv^(-1)]*G[{yv^(-1)}, yw]^2*G[{yv^(-1), 1/(yu*yv)}, yw])/64 + 
     (41*G[{yv^(-1)}, yw]^3*G[{yv^(-1), 1/(yu*yv)}, yw])/192 - 
     (Pi^2*G[{1/(yu*yv)}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw])/256 - 
     (3*G[{0}, yu^(-1)]*G[{1}, yu^(-1)]*G[{1/(yu*yv)}, yw]*
       G[{yv^(-1), 1/(yu*yv)}, yw])/16 - (3*G[{0}, yv^(-1)]*G[{1}, yu^(-1)]*
       G[{1/(yu*yv)}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw])/16 + 
     (3*G[{0}, yw]*G[{1}, yu^(-1)]*G[{1/(yu*yv)}, yw]*G[{yv^(-1), 1/(yu*yv)}, 
        yw])/16 + (9*G[{1}, yu^(-1)]^2*G[{1/(yu*yv)}, yw]*
       G[{yv^(-1), 1/(yu*yv)}, yw])/64 + (G[{0}, yu^(-1)]*G[{1}, yv^(-1)]*
       G[{1/(yu*yv)}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw])/8 + 
     (G[{0}, yv^(-1)]*G[{1}, yv^(-1)]*G[{1/(yu*yv)}, yw]*
       G[{yv^(-1), 1/(yu*yv)}, yw])/8 - (G[{0}, yw]*G[{1}, yv^(-1)]*
       G[{1/(yu*yv)}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw])/8 + 
     (G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*G[{1/(yu*yv)}, yw]*
       G[{yv^(-1), 1/(yu*yv)}, yw])/64 - 
     (13*G[{1}, yv^(-1)]^2*G[{1/(yu*yv)}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw])/
      128 - (G[{1}, yu^(-1)]*G[{1}, yw]*G[{1/(yu*yv)}, yw]*
       G[{yv^(-1), 1/(yu*yv)}, yw])/8 + (G[{1}, yv^(-1)]*G[{1}, yw]*
       G[{1/(yu*yv)}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw])/64 - 
     (7*G[{1}, yw]^2*G[{1/(yu*yv)}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw])/128 - 
     (3*G[{0}, yu^(-1)]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*
       G[{yv^(-1), 1/(yu*yv)}, yw])/16 - (3*G[{0}, yv^(-1)]*G[{yu^(-1)}, yw]*
       G[{1/(yu*yv)}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw])/16 + 
     (3*G[{0}, yw]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*
       G[{yv^(-1), 1/(yu*yv)}, yw])/16 + (G[{1}, yu^(-1)]*G[{yu^(-1)}, yw]*
       G[{1/(yu*yv)}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw])/32 + 
     (5*G[{1}, yv^(-1)]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*
       G[{yv^(-1), 1/(yu*yv)}, yw])/16 - 
     (G[{1}, yw]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{yv^(-1), 1/(yu*yv)}, 
        yw])/32 - (5*G[{yu^(-1)}, yw]^2*G[{1/(yu*yv)}, yw]*
       G[{yv^(-1), 1/(yu*yv)}, yw])/32 + (G[{0}, yu^(-1)]*G[{yu}, yv^(-1)]*
       G[{1/(yu*yv)}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw])/16 + 
     (G[{0}, yv^(-1)]*G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw]*
       G[{yv^(-1), 1/(yu*yv)}, yw])/16 - 
     (G[{0}, yw]*G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{yv^(-1), 1/(yu*yv)}, 
        yw])/16 + (5*G[{1}, yu^(-1)]*G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw]*
       G[{yv^(-1), 1/(yu*yv)}, yw])/64 - (G[{1}, yv^(-1)]*G[{yu}, yv^(-1)]*
       G[{1/(yu*yv)}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw])/32 + 
     (7*G[{1}, yw]*G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw]*
       G[{yv^(-1), 1/(yu*yv)}, yw])/64 + (G[{yu^(-1)}, yw]*G[{yu}, yv^(-1)]*
       G[{1/(yu*yv)}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw])/32 - 
     (11*G[{yu}, yv^(-1)]^2*G[{1/(yu*yv)}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw])/
      128 + (G[{0}, yu^(-1)]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*
       G[{yv^(-1), 1/(yu*yv)}, yw])/8 + (G[{0}, yv^(-1)]*G[{yv^(-1)}, yw]*
       G[{1/(yu*yv)}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw])/8 - 
     (G[{0}, yw]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{yv^(-1), 1/(yu*yv)}, 
        yw])/8 - (13*G[{1}, yu^(-1)]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*
       G[{yv^(-1), 1/(yu*yv)}, yw])/64 + (G[{1}, yv^(-1)]*G[{yv^(-1)}, yw]*
       G[{1/(yu*yv)}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw])/32 + 
     (5*G[{1}, yw]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*
       G[{yv^(-1), 1/(yu*yv)}, yw])/64 - (G[{yu^(-1)}, yw]*G[{yv^(-1)}, yw]*
       G[{1/(yu*yv)}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw])/32 - 
     (5*G[{yu}, yv^(-1)]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*
       G[{yv^(-1), 1/(yu*yv)}, yw])/64 + 
     (13*G[{yv^(-1)}, yw]^2*G[{1/(yu*yv)}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw])/
      128 - (G[{0}, yu^(-1)]*G[{1/(yu*yv)}, yw]^2*G[{yv^(-1), 1/(yu*yv)}, 
        yw])/32 - (G[{0}, yv^(-1)]*G[{1/(yu*yv)}, yw]^2*
       G[{yv^(-1), 1/(yu*yv)}, yw])/32 + (G[{0}, yw]*G[{1/(yu*yv)}, yw]^2*
       G[{yv^(-1), 1/(yu*yv)}, yw])/32 + 
     (7*G[{1}, yu^(-1)]*G[{1/(yu*yv)}, yw]^2*G[{yv^(-1), 1/(yu*yv)}, yw])/
      128 - (G[{1}, yv^(-1)]*G[{1/(yu*yv)}, yw]^2*G[{yv^(-1), 1/(yu*yv)}, 
        yw])/64 - (3*G[{1}, yw]*G[{1/(yu*yv)}, yw]^2*G[{yv^(-1), 1/(yu*yv)}, 
        yw])/128 + (G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2*
       G[{yv^(-1), 1/(yu*yv)}, yw])/64 + 
     (3*G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw]^2*G[{yv^(-1), 1/(yu*yv)}, yw])/
      128 - (7*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2*G[{yv^(-1), 1/(yu*yv)}, 
        yw])/128 + (G[{0}, yu^(-1)]*G[{0, 1}, yu^(-1)]*
       G[{yv^(-1), 1/(yu*yv)}, yw])/16 + (G[{0}, yv^(-1)]*G[{0, 1}, yu^(-1)]*
       G[{yv^(-1), 1/(yu*yv)}, yw])/16 - (G[{0}, yw]*G[{0, 1}, yu^(-1)]*
       G[{yv^(-1), 1/(yu*yv)}, yw])/16 - 
     (5*G[{1}, yu^(-1)]*G[{0, 1}, yu^(-1)]*G[{yv^(-1), 1/(yu*yv)}, yw])/32 + 
     (G[{1}, yv^(-1)]*G[{0, 1}, yu^(-1)]*G[{yv^(-1), 1/(yu*yv)}, yw])/32 - 
     (G[{1}, yw]*G[{0, 1}, yu^(-1)]*G[{yv^(-1), 1/(yu*yv)}, yw])/32 + 
     (G[{yv^(-1)}, yw]*G[{0, 1}, yu^(-1)]*G[{yv^(-1), 1/(yu*yv)}, yw])/8 - 
     (G[{1/(yu*yv)}, yw]*G[{0, 1}, yu^(-1)]*G[{yv^(-1), 1/(yu*yv)}, yw])/64 - 
     (G[{1}, yu^(-1)]*G[{0, 1}, yv^(-1)]*G[{yv^(-1), 1/(yu*yv)}, yw])/32 + 
     (G[{1}, yv^(-1)]*G[{0, 1}, yv^(-1)]*G[{yv^(-1), 1/(yu*yv)}, yw])/16 + 
     (G[{1}, yw]*G[{0, 1}, yv^(-1)]*G[{yv^(-1), 1/(yu*yv)}, yw])/32 + 
     (G[{yu}, yv^(-1)]*G[{0, 1}, yv^(-1)]*G[{yv^(-1), 1/(yu*yv)}, yw])/32 + 
     (G[{yv^(-1)}, yw]*G[{0, 1}, yv^(-1)]*G[{yv^(-1), 1/(yu*yv)}, yw])/32 - 
     (3*G[{1/(yu*yv)}, yw]*G[{0, 1}, yv^(-1)]*G[{yv^(-1), 1/(yu*yv)}, yw])/
      64 + (3*G[{0}, yu^(-1)]*G[{0, 1}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw])/16 + 
     (3*G[{0}, yv^(-1)]*G[{0, 1}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw])/16 - 
     (3*G[{0}, yw]*G[{0, 1}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw])/16 - 
     (G[{1}, yv^(-1)]*G[{0, 1}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw])/4 + 
     (G[{1}, yw]*G[{0, 1}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw])/16 - 
     (G[{yu}, yv^(-1)]*G[{0, 1}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw])/8 - 
     (G[{yv^(-1)}, yw]*G[{0, 1}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw])/4 + 
     (G[{1/(yu*yv)}, yw]*G[{0, 1}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw])/16 - 
     (3*G[{0}, yu^(-1)]*G[{0, yu^(-1)}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw])/16 - 
     (3*G[{0}, yv^(-1)]*G[{0, yu^(-1)}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw])/16 + 
     (3*G[{0}, yw]*G[{0, yu^(-1)}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw])/16 + 
     (G[{1}, yv^(-1)]*G[{0, yu^(-1)}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw])/4 - 
     (G[{1}, yw]*G[{0, yu^(-1)}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw])/16 + 
     (G[{yu}, yv^(-1)]*G[{0, yu^(-1)}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw])/8 + 
     (G[{yv^(-1)}, yw]*G[{0, yu^(-1)}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw])/4 - 
     (G[{1/(yu*yv)}, yw]*G[{0, yu^(-1)}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw])/
      16 + (G[{1}, yu^(-1)]*G[{0, yu}, yv^(-1)]*G[{yv^(-1), 1/(yu*yv)}, yw])/
      32 - (G[{1}, yv^(-1)]*G[{0, yu}, yv^(-1)]*G[{yv^(-1), 1/(yu*yv)}, yw])/
      16 - (G[{1}, yw]*G[{0, yu}, yv^(-1)]*G[{yv^(-1), 1/(yu*yv)}, yw])/32 - 
     (G[{yu}, yv^(-1)]*G[{0, yu}, yv^(-1)]*G[{yv^(-1), 1/(yu*yv)}, yw])/32 - 
     (G[{yv^(-1)}, yw]*G[{0, yu}, yv^(-1)]*G[{yv^(-1), 1/(yu*yv)}, yw])/32 + 
     (3*G[{1/(yu*yv)}, yw]*G[{0, yu}, yv^(-1)]*G[{yv^(-1), 1/(yu*yv)}, yw])/
      64 - (3*G[{0}, yu^(-1)]*G[{0, yv^(-1)}, yw]*G[{yv^(-1), 1/(yu*yv)}, 
        yw])/16 - (3*G[{0}, yv^(-1)]*G[{0, yv^(-1)}, yw]*
       G[{yv^(-1), 1/(yu*yv)}, yw])/16 + (3*G[{0}, yw]*G[{0, yv^(-1)}, yw]*
       G[{yv^(-1), 1/(yu*yv)}, yw])/16 + (G[{1}, yv^(-1)]*G[{0, yv^(-1)}, yw]*
       G[{yv^(-1), 1/(yu*yv)}, yw])/4 - (G[{1}, yw]*G[{0, yv^(-1)}, yw]*
       G[{yv^(-1), 1/(yu*yv)}, yw])/16 + 
     (G[{yu}, yv^(-1)]*G[{0, yv^(-1)}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw])/8 + 
     (G[{yv^(-1)}, yw]*G[{0, yv^(-1)}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw])/4 - 
     (G[{1/(yu*yv)}, yw]*G[{0, yv^(-1)}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw])/
      16 + (3*G[{0}, yu^(-1)]*G[{0, 1/(yu*yv)}, yw]*G[{yv^(-1), 1/(yu*yv)}, 
        yw])/16 + (3*G[{0}, yv^(-1)]*G[{0, 1/(yu*yv)}, yw]*
       G[{yv^(-1), 1/(yu*yv)}, yw])/16 - (3*G[{0}, yw]*G[{0, 1/(yu*yv)}, yw]*
       G[{yv^(-1), 1/(yu*yv)}, yw])/16 - 
     (G[{1}, yv^(-1)]*G[{0, 1/(yu*yv)}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw])/4 + 
     (G[{1}, yw]*G[{0, 1/(yu*yv)}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw])/16 - 
     (G[{yu}, yv^(-1)]*G[{0, 1/(yu*yv)}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw])/8 - 
     (G[{yv^(-1)}, yw]*G[{0, 1/(yu*yv)}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw])/4 + 
     (G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv)}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw])/
      16 + (3*G[{0}, yu^(-1)]*G[{1, yu^(-1)}, yw]*G[{yv^(-1), 1/(yu*yv)}, 
        yw])/16 + (3*G[{0}, yv^(-1)]*G[{1, yu^(-1)}, yw]*
       G[{yv^(-1), 1/(yu*yv)}, yw])/16 - (3*G[{0}, yw]*G[{1, yu^(-1)}, yw]*
       G[{yv^(-1), 1/(yu*yv)}, yw])/16 - (G[{1}, yu^(-1)]*G[{1, yu^(-1)}, yw]*
       G[{yv^(-1), 1/(yu*yv)}, yw])/32 - 
     (5*G[{1}, yv^(-1)]*G[{1, yu^(-1)}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw])/16 + 
     (G[{1}, yw]*G[{1, yu^(-1)}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw])/32 - 
     (G[{yu}, yv^(-1)]*G[{1, yu^(-1)}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw])/32 - 
     (7*G[{yv^(-1)}, yw]*G[{1, yu^(-1)}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw])/
      32 + (G[{1/(yu*yv)}, yw]*G[{1, yu^(-1)}, yw]*G[{yv^(-1), 1/(yu*yv)}, 
        yw])/64 - (G[{0}, yu^(-1)]*G[{1, yu}, yv^(-1)]*
       G[{yv^(-1), 1/(yu*yv)}, yw])/16 - (G[{0}, yv^(-1)]*G[{1, yu}, yv^(-1)]*
       G[{yv^(-1), 1/(yu*yv)}, yw])/16 + (G[{0}, yw]*G[{1, yu}, yv^(-1)]*
       G[{yv^(-1), 1/(yu*yv)}, yw])/16 + (G[{1}, yu^(-1)]*G[{1, yu}, yv^(-1)]*
       G[{yv^(-1), 1/(yu*yv)}, yw])/32 - (G[{1}, yv^(-1)]*G[{1, yu}, yv^(-1)]*
       G[{yv^(-1), 1/(yu*yv)}, yw])/16 + (G[{1}, yw]*G[{1, yu}, yv^(-1)]*
       G[{yv^(-1), 1/(yu*yv)}, yw])/16 + 
     (G[{yu}, yv^(-1)]*G[{1, yu}, yv^(-1)]*G[{yv^(-1), 1/(yu*yv)}, yw])/32 - 
     (3*G[{yv^(-1)}, yw]*G[{1, yu}, yv^(-1)]*G[{yv^(-1), 1/(yu*yv)}, yw])/
      32 - (G[{1/(yu*yv)}, yw]*G[{1, yu}, yv^(-1)]*G[{yv^(-1), 1/(yu*yv)}, 
        yw])/32 + (G[{0}, yu^(-1)]*G[{1, yv^(-1)}, yw]*
       G[{yv^(-1), 1/(yu*yv)}, yw])/4 + (G[{0}, yv^(-1)]*G[{1, yv^(-1)}, yw]*
       G[{yv^(-1), 1/(yu*yv)}, yw])/4 - (G[{0}, yw]*G[{1, yv^(-1)}, yw]*
       G[{yv^(-1), 1/(yu*yv)}, yw])/4 - (G[{1}, yu^(-1)]*G[{1, yv^(-1)}, yw]*
       G[{yv^(-1), 1/(yu*yv)}, yw])/16 - (G[{1}, yv^(-1)]*G[{1, yv^(-1)}, yw]*
       G[{yv^(-1), 1/(yu*yv)}, yw])/4 + (3*G[{1}, yw]*G[{1, yv^(-1)}, yw]*
       G[{yv^(-1), 1/(yu*yv)}, yw])/16 - 
     (3*G[{yu}, yv^(-1)]*G[{1, yv^(-1)}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw])/
      16 - (G[{yv^(-1)}, yw]*G[{1, yv^(-1)}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw])/
      8 + (3*G[{1/(yu*yv)}, yw]*G[{1, yv^(-1)}, yw]*G[{yv^(-1), 1/(yu*yv)}, 
        yw])/64 - (G[{0}, yu^(-1)]*G[{1, 1/(yu*yv)}, yw]*
       G[{yv^(-1), 1/(yu*yv)}, yw])/16 - 
     (G[{0}, yv^(-1)]*G[{1, 1/(yu*yv)}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw])/16 + 
     (G[{0}, yw]*G[{1, 1/(yu*yv)}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw])/16 + 
     (3*G[{1}, yu^(-1)]*G[{1, 1/(yu*yv)}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw])/
      32 + (G[{1}, yv^(-1)]*G[{1, 1/(yu*yv)}, yw]*G[{yv^(-1), 1/(yu*yv)}, 
        yw])/16 + (G[{1}, yw]*G[{1, 1/(yu*yv)}, yw]*G[{yv^(-1), 1/(yu*yv)}, 
        yw])/32 - (G[{yu}, yv^(-1)]*G[{1, 1/(yu*yv)}, yw]*
       G[{yv^(-1), 1/(yu*yv)}, yw])/32 - 
     (5*G[{yv^(-1)}, yw]*G[{1, 1/(yu*yv)}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw])/
      32 + (G[{1/(yu*yv)}, yw]*G[{1, 1/(yu*yv)}, yw]*G[{yv^(-1), 1/(yu*yv)}, 
        yw])/16 - (3*G[{0}, yu^(-1)]*G[{yu^(-1), 1/(yu*yv)}, yw]*
       G[{yv^(-1), 1/(yu*yv)}, yw])/16 - 
     (3*G[{0}, yv^(-1)]*G[{yu^(-1), 1/(yu*yv)}, yw]*G[{yv^(-1), 1/(yu*yv)}, 
        yw])/16 + (3*G[{0}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw]*
       G[{yv^(-1), 1/(yu*yv)}, yw])/16 - 
     (G[{1}, yu^(-1)]*G[{yu^(-1), 1/(yu*yv)}, yw]*G[{yv^(-1), 1/(yu*yv)}, 
        yw])/32 + (3*G[{1}, yv^(-1)]*G[{yu^(-1), 1/(yu*yv)}, yw]*
       G[{yv^(-1), 1/(yu*yv)}, yw])/16 - 
     (7*G[{1}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw])/
      32 - (3*G[{yu^(-1)}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw]*
       G[{yv^(-1), 1/(yu*yv)}, yw])/16 + 
     (7*G[{yu}, yv^(-1)]*G[{yu^(-1), 1/(yu*yv)}, yw]*G[{yv^(-1), 1/(yu*yv)}, 
        yw])/32 + (9*G[{yv^(-1)}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw]*
       G[{yv^(-1), 1/(yu*yv)}, yw])/32 - 
     (7*G[{1/(yu*yv)}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw]*
       G[{yv^(-1), 1/(yu*yv)}, yw])/64 - 
     (G[{0}, yu^(-1)]*G[{yv^(-1), 1/(yu*yv)}, yw]^2)/16 - 
     (G[{0}, yv^(-1)]*G[{yv^(-1), 1/(yu*yv)}, yw]^2)/16 + 
     (G[{0}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw]^2)/16 - 
     (G[{1}, yu^(-1)]*G[{yv^(-1), 1/(yu*yv)}, yw]^2)/32 + 
     (G[{1}, yv^(-1)]*G[{yv^(-1), 1/(yu*yv)}, yw]^2)/8 - 
     (G[{1}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw]^2)/32 - 
     (G[{yu^(-1)}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw]^2)/8 + 
     (G[{yu}, yv^(-1)]*G[{yv^(-1), 1/(yu*yv)}, yw]^2)/32 + 
     (G[{yv^(-1)}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw]^2)/32 - 
     (5*G[{1/(yu*yv)}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw]^2)/128 + 
     (13*Pi^2*G[{0, 0, 1}, yu^(-1)])/768 - 
     (G[{1}, yu^(-1)]^2*G[{0, 0, 1}, yu^(-1)])/64 + 
     (G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*G[{0, 0, 1}, yu^(-1)])/32 - 
     (G[{1}, yv^(-1)]^2*G[{0, 0, 1}, yu^(-1)])/128 + 
     (G[{0}, yu^(-1)]*G[{1}, yw]*G[{0, 0, 1}, yu^(-1)])/16 + 
     (G[{0}, yv^(-1)]*G[{1}, yw]*G[{0, 0, 1}, yu^(-1)])/16 - 
     (G[{0}, yw]*G[{1}, yw]*G[{0, 0, 1}, yu^(-1)])/16 - 
     (G[{1}, yu^(-1)]*G[{1}, yw]*G[{0, 0, 1}, yu^(-1)])/32 - 
     (G[{1}, yv^(-1)]*G[{1}, yw]*G[{0, 0, 1}, yu^(-1)])/64 + 
     (5*G[{1}, yw]^2*G[{0, 0, 1}, yu^(-1)])/128 - 
     (5*G[{1}, yw]*G[{yu}, yv^(-1)]*G[{0, 0, 1}, yu^(-1)])/64 - 
     (G[{0}, yu^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, 0, 1}, yu^(-1)])/16 - 
     (G[{0}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, 0, 1}, yu^(-1)])/16 + 
     (G[{0}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 0, 1}, yu^(-1)])/16 + 
     (G[{1}, yu^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, 0, 1}, yu^(-1)])/32 + 
     (G[{1}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, 0, 1}, yu^(-1)])/64 - 
     (5*G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 0, 1}, yu^(-1)])/64 - 
     (G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 0, 1}, yu^(-1)])/64 + 
     (5*G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, 0, 1}, yu^(-1)])/64 - 
     (G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 0, 1}, yu^(-1)])/32 + 
     (G[{0, 1}, yu^(-1)]*G[{0, 0, 1}, yu^(-1)])/32 + 
     (G[{0, 1}, yv^(-1)]*G[{0, 0, 1}, yu^(-1)])/64 + 
     (G[{0, 1}, yw]*G[{0, 0, 1}, yu^(-1)])/16 + 
     (3*G[{0, yu}, yv^(-1)]*G[{0, 0, 1}, yu^(-1)])/64 - 
     (G[{0, 1/(yu*yv)}, yw]*G[{0, 0, 1}, yu^(-1)])/16 + 
     (G[{1, yu^(-1)}, yw]*G[{0, 0, 1}, yu^(-1)])/64 - 
     (G[{1, yu}, yv^(-1)]*G[{0, 0, 1}, yu^(-1)])/64 + 
     (G[{1, yv^(-1)}, yw]*G[{0, 0, 1}, yu^(-1)])/32 + 
     (5*G[{1, 1/(yu*yv)}, yw]*G[{0, 0, 1}, yu^(-1)])/64 + 
     (G[{yu^(-1), 1/(yu*yv)}, yw]*G[{0, 0, 1}, yu^(-1)])/64 + 
     (G[{yv^(-1), 1/(yu*yv)}, yw]*G[{0, 0, 1}, yu^(-1)])/32 - 
     (Pi^2*G[{0, 0, 1}, yv^(-1)])/96 - 
     (G[{1}, yu^(-1)]^2*G[{0, 0, 1}, yv^(-1)])/32 - 
     (G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*G[{0, 0, 1}, yv^(-1)])/16 + 
     (G[{1}, yv^(-1)]^2*G[{0, 0, 1}, yv^(-1)])/32 - 
     (G[{0}, yu^(-1)]*G[{1}, yw]*G[{0, 0, 1}, yv^(-1)])/8 - 
     (G[{0}, yv^(-1)]*G[{1}, yw]*G[{0, 0, 1}, yv^(-1)])/8 + 
     (G[{0}, yw]*G[{1}, yw]*G[{0, 0, 1}, yv^(-1)])/8 + 
     (G[{1}, yu^(-1)]*G[{1}, yw]*G[{0, 0, 1}, yv^(-1)])/16 + 
     (G[{1}, yv^(-1)]*G[{1}, yw]*G[{0, 0, 1}, yv^(-1)])/16 - 
     (G[{1}, yw]^2*G[{0, 0, 1}, yv^(-1)])/16 + 
     (G[{1}, yw]*G[{yu}, yv^(-1)]*G[{0, 0, 1}, yv^(-1)])/8 + 
     (G[{0}, yu^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, 0, 1}, yv^(-1)])/8 + 
     (G[{0}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, 0, 1}, yv^(-1)])/8 - 
     (G[{0}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 0, 1}, yv^(-1)])/8 - 
     (G[{1}, yu^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, 0, 1}, yv^(-1)])/16 - 
     (G[{1}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, 0, 1}, yv^(-1)])/16 + 
     (G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 0, 1}, yv^(-1)])/8 + 
     (G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 0, 1}, yv^(-1)])/16 - 
     (G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, 0, 1}, yv^(-1)])/8 + 
     (G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 0, 1}, yv^(-1)])/16 - 
     (G[{0, 1}, yu^(-1)]*G[{0, 0, 1}, yv^(-1)])/16 - 
     (G[{0, 1}, yv^(-1)]*G[{0, 0, 1}, yv^(-1)])/16 - 
     (G[{0, 1}, yw]*G[{0, 0, 1}, yv^(-1)])/8 - 
     (G[{0, yu}, yv^(-1)]*G[{0, 0, 1}, yv^(-1)])/16 + 
     (G[{0, 1/(yu*yv)}, yw]*G[{0, 0, 1}, yv^(-1)])/8 - 
     (G[{1, yu^(-1)}, yw]*G[{0, 0, 1}, yv^(-1)])/16 - 
     (G[{1, yv^(-1)}, yw]*G[{0, 0, 1}, yv^(-1)])/16 - 
     (G[{1, 1/(yu*yv)}, yw]*G[{0, 0, 1}, yv^(-1)])/8 - 
     (G[{yu^(-1), 1/(yu*yv)}, yw]*G[{0, 0, 1}, yv^(-1)])/16 - 
     (G[{yv^(-1), 1/(yu*yv)}, yw]*G[{0, 0, 1}, yv^(-1)])/16 - 
     (Pi^2*G[{0, 0, 1}, yw])/96 - (G[{0}, yu^(-1)]*G[{1}, yw]*
       G[{0, 0, 1}, yw])/16 - (G[{0}, yv^(-1)]*G[{1}, yw]*G[{0, 0, 1}, yw])/
      16 + (G[{0}, yw]*G[{1}, yw]*G[{0, 0, 1}, yw])/16 - 
     (3*G[{1}, yu^(-1)]*G[{1}, yw]*G[{0, 0, 1}, yw])/16 + 
     (3*G[{1}, yv^(-1)]*G[{1}, yw]*G[{0, 0, 1}, yw])/16 - 
     (G[{1}, yw]^2*G[{0, 0, 1}, yw])/8 + 
     (G[{1}, yw]*G[{yu}, yv^(-1)]*G[{0, 0, 1}, yw])/8 + 
     (G[{0}, yu^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, 0, 1}, yw])/16 + 
     (G[{0}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, 0, 1}, yw])/16 - 
     (G[{0}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 0, 1}, yw])/16 + 
     (3*G[{1}, yu^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, 0, 1}, yw])/16 - 
     (3*G[{1}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, 0, 1}, yw])/16 + 
     (G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 0, 1}, yw])/4 + 
     (G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 0, 1}, yw])/16 - 
     (G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, 0, 1}, yw])/8 - 
     (5*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 0, 1}, yw])/16 - 
     (G[{0, 1}, yu^(-1)]*G[{0, 0, 1}, yw])/16 - 
     (G[{0, 1}, yv^(-1)]*G[{0, 0, 1}, yw])/16 - 
     (G[{0, 1}, yw]*G[{0, 0, 1}, yw])/16 + 
     (G[{0, yu}, yv^(-1)]*G[{0, 0, 1}, yw])/16 + 
     (G[{0, 1/(yu*yv)}, yw]*G[{0, 0, 1}, yw])/16 - 
     (G[{1, yu^(-1)}, yw]*G[{0, 0, 1}, yw])/16 + 
     (5*G[{1, yv^(-1)}, yw]*G[{0, 0, 1}, yw])/16 - 
     (G[{1, 1/(yu*yv)}, yw]*G[{0, 0, 1}, yw])/4 - 
     (G[{yu^(-1), 1/(yu*yv)}, yw]*G[{0, 0, 1}, yw])/16 + 
     (5*G[{yv^(-1), 1/(yu*yv)}, yw]*G[{0, 0, 1}, yw])/16 + 
     (G[{0}, yu^(-1)]*G[{1}, yw]*G[{0, 0, yu^(-1)}, yw])/16 + 
     (G[{0}, yv^(-1)]*G[{1}, yw]*G[{0, 0, yu^(-1)}, yw])/16 - 
     (G[{0}, yw]*G[{1}, yw]*G[{0, 0, yu^(-1)}, yw])/16 + 
     (3*G[{1}, yu^(-1)]*G[{1}, yw]*G[{0, 0, yu^(-1)}, yw])/16 - 
     (G[{1}, yv^(-1)]*G[{1}, yw]*G[{0, 0, yu^(-1)}, yw])/16 + 
     (G[{1}, yw]^2*G[{0, 0, yu^(-1)}, yw])/8 - 
     (G[{1}, yw]*G[{yu}, yv^(-1)]*G[{0, 0, yu^(-1)}, yw])/4 - 
     (G[{0}, yu^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, 0, yu^(-1)}, yw])/16 - 
     (G[{0}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, 0, yu^(-1)}, yw])/16 + 
     (G[{0}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 0, yu^(-1)}, yw])/16 - 
     (3*G[{1}, yu^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, 0, yu^(-1)}, yw])/16 + 
     (G[{1}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, 0, yu^(-1)}, yw])/16 - 
     (G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 0, yu^(-1)}, yw])/4 - 
     (G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 0, yu^(-1)}, yw])/16 + 
     (G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, 0, yu^(-1)}, yw])/4 + 
     (5*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 0, yu^(-1)}, yw])/16 + 
     (G[{0, 1}, yw]*G[{0, 0, yu^(-1)}, yw])/16 - 
     (G[{0, 1/(yu*yv)}, yw]*G[{0, 0, yu^(-1)}, yw])/16 + 
     (G[{1, yu^(-1)}, yw]*G[{0, 0, yu^(-1)}, yw])/16 - 
     (5*G[{1, yv^(-1)}, yw]*G[{0, 0, yu^(-1)}, yw])/16 + 
     (G[{1, 1/(yu*yv)}, yw]*G[{0, 0, yu^(-1)}, yw])/4 + 
     (G[{yu^(-1), 1/(yu*yv)}, yw]*G[{0, 0, yu^(-1)}, yw])/16 - 
     (5*G[{yv^(-1), 1/(yu*yv)}, yw]*G[{0, 0, yu^(-1)}, yw])/16 - 
     (Pi^2*G[{0, 0, yu}, yv^(-1)])/96 + 
     (G[{1}, yu^(-1)]^2*G[{0, 0, yu}, yv^(-1)])/32 + 
     (G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*G[{0, 0, yu}, yv^(-1)])/16 - 
     (G[{1}, yv^(-1)]^2*G[{0, 0, yu}, yv^(-1)])/32 + 
     (G[{0}, yu^(-1)]*G[{1}, yw]*G[{0, 0, yu}, yv^(-1)])/8 + 
     (G[{0}, yv^(-1)]*G[{1}, yw]*G[{0, 0, yu}, yv^(-1)])/8 - 
     (G[{0}, yw]*G[{1}, yw]*G[{0, 0, yu}, yv^(-1)])/8 - 
     (G[{1}, yu^(-1)]*G[{1}, yw]*G[{0, 0, yu}, yv^(-1)])/16 - 
     (G[{1}, yv^(-1)]*G[{1}, yw]*G[{0, 0, yu}, yv^(-1)])/16 + 
     (G[{1}, yw]^2*G[{0, 0, yu}, yv^(-1)])/16 - 
     (G[{1}, yw]*G[{yu}, yv^(-1)]*G[{0, 0, yu}, yv^(-1)])/8 - 
     (G[{0}, yu^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, 0, yu}, yv^(-1)])/8 - 
     (G[{0}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, 0, yu}, yv^(-1)])/8 + 
     (G[{0}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 0, yu}, yv^(-1)])/8 + 
     (G[{1}, yu^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, 0, yu}, yv^(-1)])/16 + 
     (G[{1}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, 0, yu}, yv^(-1)])/16 - 
     (G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 0, yu}, yv^(-1)])/8 - 
     (G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 0, yu}, yv^(-1)])/16 + 
     (G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, 0, yu}, yv^(-1)])/8 - 
     (G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 0, yu}, yv^(-1)])/16 - 
     (G[{0, 1}, yu^(-1)]*G[{0, 0, yu}, yv^(-1)])/16 + 
     (G[{0, 1}, yv^(-1)]*G[{0, 0, yu}, yv^(-1)])/16 + 
     (G[{0, 1}, yw]*G[{0, 0, yu}, yv^(-1)])/8 + 
     (G[{0, yu}, yv^(-1)]*G[{0, 0, yu}, yv^(-1)])/16 - 
     (G[{0, 1/(yu*yv)}, yw]*G[{0, 0, yu}, yv^(-1)])/8 + 
     (G[{1, yu^(-1)}, yw]*G[{0, 0, yu}, yv^(-1)])/16 + 
     (G[{1, yv^(-1)}, yw]*G[{0, 0, yu}, yv^(-1)])/16 + 
     (G[{1, 1/(yu*yv)}, yw]*G[{0, 0, yu}, yv^(-1)])/8 + 
     (G[{yu^(-1), 1/(yu*yv)}, yw]*G[{0, 0, yu}, yv^(-1)])/16 + 
     (G[{yv^(-1), 1/(yu*yv)}, yw]*G[{0, 0, yu}, yv^(-1)])/16 + 
     (G[{0}, yu^(-1)]*G[{1}, yw]*G[{0, 0, yv^(-1)}, yw])/16 + 
     (G[{0}, yv^(-1)]*G[{1}, yw]*G[{0, 0, yv^(-1)}, yw])/16 - 
     (G[{0}, yw]*G[{1}, yw]*G[{0, 0, yv^(-1)}, yw])/16 + 
     (5*G[{1}, yu^(-1)]*G[{1}, yw]*G[{0, 0, yv^(-1)}, yw])/16 - 
     (3*G[{1}, yv^(-1)]*G[{1}, yw]*G[{0, 0, yv^(-1)}, yw])/16 + 
     (G[{1}, yw]^2*G[{0, 0, yv^(-1)}, yw])/8 - 
     (G[{1}, yw]*G[{yu}, yv^(-1)]*G[{0, 0, yv^(-1)}, yw])/4 - 
     (G[{0}, yu^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, 0, yv^(-1)}, yw])/16 - 
     (G[{0}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, 0, yv^(-1)}, yw])/16 + 
     (G[{0}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 0, yv^(-1)}, yw])/16 - 
     (5*G[{1}, yu^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, 0, yv^(-1)}, yw])/16 + 
     (3*G[{1}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, 0, yv^(-1)}, yw])/16 - 
     (G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 0, yv^(-1)}, yw])/4 - 
     (G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 0, yv^(-1)}, yw])/16 + 
     (G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, 0, yv^(-1)}, yw])/4 + 
     (5*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 0, yv^(-1)}, yw])/16 + 
     (G[{0, 1}, yw]*G[{0, 0, yv^(-1)}, yw])/16 - 
     (G[{0, 1/(yu*yv)}, yw]*G[{0, 0, yv^(-1)}, yw])/16 + 
     (G[{1, yu^(-1)}, yw]*G[{0, 0, yv^(-1)}, yw])/16 - 
     (5*G[{1, yv^(-1)}, yw]*G[{0, 0, yv^(-1)}, yw])/16 + 
     (G[{1, 1/(yu*yv)}, yw]*G[{0, 0, yv^(-1)}, yw])/4 + 
     (G[{yu^(-1), 1/(yu*yv)}, yw]*G[{0, 0, yv^(-1)}, yw])/16 - 
     (5*G[{yv^(-1), 1/(yu*yv)}, yw]*G[{0, 0, yv^(-1)}, yw])/16 + 
     (Pi^2*G[{0, 0, 1/(yu*yv)}, yw])/96 - 
     (G[{0}, yu^(-1)]*G[{1}, yw]*G[{0, 0, 1/(yu*yv)}, yw])/16 - 
     (G[{0}, yv^(-1)]*G[{1}, yw]*G[{0, 0, 1/(yu*yv)}, yw])/16 + 
     (G[{0}, yw]*G[{1}, yw]*G[{0, 0, 1/(yu*yv)}, yw])/16 - 
     (5*G[{1}, yu^(-1)]*G[{1}, yw]*G[{0, 0, 1/(yu*yv)}, yw])/16 + 
     (G[{1}, yv^(-1)]*G[{1}, yw]*G[{0, 0, 1/(yu*yv)}, yw])/16 - 
     (G[{1}, yw]^2*G[{0, 0, 1/(yu*yv)}, yw])/8 + 
     (3*G[{1}, yw]*G[{yu}, yv^(-1)]*G[{0, 0, 1/(yu*yv)}, yw])/8 + 
     (G[{0}, yu^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, 0, 1/(yu*yv)}, yw])/16 + 
     (G[{0}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, 0, 1/(yu*yv)}, yw])/16 - 
     (G[{0}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 0, 1/(yu*yv)}, yw])/16 + 
     (5*G[{1}, yu^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, 0, 1/(yu*yv)}, yw])/16 - 
     (G[{1}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, 0, 1/(yu*yv)}, yw])/16 + 
     (G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 0, 1/(yu*yv)}, yw])/4 + 
     (G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 0, 1/(yu*yv)}, yw])/16 - 
     (3*G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, 0, 1/(yu*yv)}, yw])/8 - 
     (5*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 0, 1/(yu*yv)}, yw])/16 + 
     (G[{0, 1}, yu^(-1)]*G[{0, 0, 1/(yu*yv)}, yw])/16 + 
     (G[{0, 1}, yv^(-1)]*G[{0, 0, 1/(yu*yv)}, yw])/16 - 
     (G[{0, 1}, yw]*G[{0, 0, 1/(yu*yv)}, yw])/16 - 
     (G[{0, yu}, yv^(-1)]*G[{0, 0, 1/(yu*yv)}, yw])/16 + 
     (G[{0, 1/(yu*yv)}, yw]*G[{0, 0, 1/(yu*yv)}, yw])/16 - 
     (G[{1, yu^(-1)}, yw]*G[{0, 0, 1/(yu*yv)}, yw])/16 + 
     (5*G[{1, yv^(-1)}, yw]*G[{0, 0, 1/(yu*yv)}, yw])/16 - 
     (G[{1, 1/(yu*yv)}, yw]*G[{0, 0, 1/(yu*yv)}, yw])/4 - 
     (G[{yu^(-1), 1/(yu*yv)}, yw]*G[{0, 0, 1/(yu*yv)}, yw])/16 + 
     (5*G[{yv^(-1), 1/(yu*yv)}, yw]*G[{0, 0, 1/(yu*yv)}, yw])/16 + 
     (Pi^2*G[{0, 1, 1}, yu^(-1)])/192 - 
     (G[{1}, yu^(-1)]^2*G[{0, 1, 1}, yu^(-1)])/8 + 
     (G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*G[{0, 1, 1}, yu^(-1)])/4 - 
     (17*G[{1}, yv^(-1)]^2*G[{0, 1, 1}, yu^(-1)])/128 + 
     (3*G[{0}, yu^(-1)]*G[{1}, yw]*G[{0, 1, 1}, yu^(-1)])/16 + 
     (3*G[{0}, yv^(-1)]*G[{1}, yw]*G[{0, 1, 1}, yu^(-1)])/16 - 
     (3*G[{0}, yw]*G[{1}, yw]*G[{0, 1, 1}, yu^(-1)])/16 - 
     (5*G[{1}, yv^(-1)]*G[{1}, yw]*G[{0, 1, 1}, yu^(-1)])/64 + 
     (17*G[{1}, yw]^2*G[{0, 1, 1}, yu^(-1)])/128 - 
     (11*G[{1}, yw]*G[{yu}, yv^(-1)]*G[{0, 1, 1}, yu^(-1)])/64 - 
     (3*G[{0}, yu^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, 1, 1}, yu^(-1)])/16 - 
     (3*G[{0}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, 1, 1}, yu^(-1)])/16 + 
     (3*G[{0}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1, 1}, yu^(-1)])/16 + 
     (5*G[{1}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, 1, 1}, yu^(-1)])/64 - 
     (17*G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1, 1}, yu^(-1)])/64 + 
     (G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1, 1}, yu^(-1)])/64 + 
     (11*G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, 1, 1}, yu^(-1)])/64 - 
     (3*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1, 1}, yu^(-1)])/32 + 
     (3*G[{1/(yu*yv)}, yw]^2*G[{0, 1, 1}, yu^(-1)])/64 - 
     (3*G[{0, 1}, yu^(-1)]*G[{0, 1, 1}, yu^(-1)])/64 + 
     (7*G[{0, 1}, yv^(-1)]*G[{0, 1, 1}, yu^(-1)])/64 + 
     (3*G[{0, 1}, yw]*G[{0, 1, 1}, yu^(-1)])/16 - 
     (3*G[{0, yu}, yv^(-1)]*G[{0, 1, 1}, yu^(-1)])/64 - 
     (3*G[{0, 1/(yu*yv)}, yw]*G[{0, 1, 1}, yu^(-1)])/16 - 
     (G[{1, yu^(-1)}, yw]*G[{0, 1, 1}, yu^(-1)])/64 + 
     (G[{1, yu}, yv^(-1)]*G[{0, 1, 1}, yu^(-1)])/64 + 
     (3*G[{1, yv^(-1)}, yw]*G[{0, 1, 1}, yu^(-1)])/32 + 
     (11*G[{1, 1/(yu*yv)}, yw]*G[{0, 1, 1}, yu^(-1)])/64 - 
     (G[{yu^(-1), 1/(yu*yv)}, yw]*G[{0, 1, 1}, yu^(-1)])/64 + 
     (3*G[{yv^(-1), 1/(yu*yv)}, yw]*G[{0, 1, 1}, yu^(-1)])/32 - 
     (Pi^2*G[{0, 1, 1}, yv^(-1)])/96 + 
     (G[{1}, yu^(-1)]^2*G[{0, 1, 1}, yv^(-1)])/32 - 
     (G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*G[{0, 1, 1}, yv^(-1)])/4 + 
     (G[{1}, yv^(-1)]^2*G[{0, 1, 1}, yv^(-1)])/16 + 
     (G[{1}, yu^(-1)]*G[{1}, yw]*G[{0, 1, 1}, yv^(-1)])/8 - 
     (G[{1}, yu^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, 1, 1}, yv^(-1)])/8 + 
     (G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1, 1}, yv^(-1)])/8 - 
     (G[{0, 1}, yu^(-1)]*G[{0, 1, 1}, yv^(-1)])/8 - 
     (G[{0, yu}, yv^(-1)]*G[{0, 1, 1}, yv^(-1)])/8 - 
     (G[{1, yv^(-1)}, yw]*G[{0, 1, 1}, yv^(-1)])/8 - 
     (G[{yv^(-1), 1/(yu*yv)}, yw]*G[{0, 1, 1}, yv^(-1)])/8 - 
     (Pi^2*G[{0, 1, 1}, yw])/24 + (G[{0}, yu^(-1)]^2*G[{0, 1, 1}, yw])/16 + 
     (G[{0}, yu^(-1)]*G[{0}, yv^(-1)]*G[{0, 1, 1}, yw])/8 + 
     (G[{0}, yv^(-1)]^2*G[{0, 1, 1}, yw])/16 - 
     (G[{0}, yu^(-1)]*G[{0}, yw]*G[{0, 1, 1}, yw])/8 - 
     (G[{0}, yv^(-1)]*G[{0}, yw]*G[{0, 1, 1}, yw])/8 + 
     (G[{0}, yw]^2*G[{0, 1, 1}, yw])/16 + 
     (3*G[{0}, yu^(-1)]*G[{1}, yu^(-1)]*G[{0, 1, 1}, yw])/16 + 
     (3*G[{0}, yv^(-1)]*G[{1}, yu^(-1)]*G[{0, 1, 1}, yw])/16 - 
     (3*G[{0}, yw]*G[{1}, yu^(-1)]*G[{0, 1, 1}, yw])/16 - 
     (5*G[{1}, yu^(-1)]^2*G[{0, 1, 1}, yw])/32 - 
     (3*G[{0}, yu^(-1)]*G[{1}, yv^(-1)]*G[{0, 1, 1}, yw])/16 - 
     (3*G[{0}, yv^(-1)]*G[{1}, yv^(-1)]*G[{0, 1, 1}, yw])/16 + 
     (3*G[{0}, yw]*G[{1}, yv^(-1)]*G[{0, 1, 1}, yw])/16 - 
     (3*G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*G[{0, 1, 1}, yw])/16 + 
     (G[{1}, yv^(-1)]^2*G[{0, 1, 1}, yw])/8 + 
     (G[{0}, yu^(-1)]*G[{1}, yw]*G[{0, 1, 1}, yw])/8 + 
     (G[{0}, yv^(-1)]*G[{1}, yw]*G[{0, 1, 1}, yw])/8 - 
     (G[{0}, yw]*G[{1}, yw]*G[{0, 1, 1}, yw])/8 - 
     (G[{1}, yu^(-1)]*G[{1}, yw]*G[{0, 1, 1}, yw])/16 - 
     (G[{1}, yv^(-1)]*G[{1}, yw]*G[{0, 1, 1}, yw])/16 - 
     (G[{0}, yu^(-1)]*G[{yu}, yv^(-1)]*G[{0, 1, 1}, yw])/4 - 
     (G[{0}, yv^(-1)]*G[{yu}, yv^(-1)]*G[{0, 1, 1}, yw])/4 + 
     (G[{0}, yw]*G[{yu}, yv^(-1)]*G[{0, 1, 1}, yw])/4 + 
     (G[{1}, yu^(-1)]*G[{yu}, yv^(-1)]*G[{0, 1, 1}, yw])/8 + 
     (G[{1}, yv^(-1)]*G[{yu}, yv^(-1)]*G[{0, 1, 1}, yw])/8 - 
     (G[{1}, yw]*G[{yu}, yv^(-1)]*G[{0, 1, 1}, yw])/8 + 
     (G[{yu}, yv^(-1)]^2*G[{0, 1, 1}, yw])/8 - 
     (G[{0}, yu^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, 1, 1}, yw])/8 - 
     (G[{0}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, 1, 1}, yw])/8 + 
     (G[{0}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1, 1}, yw])/8 + 
     (G[{1}, yu^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, 1, 1}, yw])/16 + 
     (G[{1}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, 1, 1}, yw])/16 - 
     (G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1, 1}, yw])/16 + 
     (G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, 1, 1}, yw])/8 - 
     (G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1, 1}, yw])/16 - 
     (3*G[{0, 1}, yu^(-1)]*G[{0, 1, 1}, yw])/16 + 
     (G[{1, yu^(-1)}, yw]*G[{0, 1, 1}, yw])/16 + 
     (3*G[{1, yu}, yv^(-1)]*G[{0, 1, 1}, yw])/16 + 
     (G[{1, yv^(-1)}, yw]*G[{0, 1, 1}, yw])/16 + 
     (G[{yu^(-1), 1/(yu*yv)}, yw]*G[{0, 1, 1}, yw])/16 + 
     (G[{yv^(-1), 1/(yu*yv)}, yw]*G[{0, 1, 1}, yw])/16 - 
     (G[{0}, yu^(-1)]^2*G[{0, 1, yu^(-1)}, yw])/32 - 
     (G[{0}, yu^(-1)]*G[{0}, yv^(-1)]*G[{0, 1, yu^(-1)}, yw])/16 - 
     (G[{0}, yv^(-1)]^2*G[{0, 1, yu^(-1)}, yw])/32 + 
     (G[{0}, yu^(-1)]*G[{0}, yw]*G[{0, 1, yu^(-1)}, yw])/16 + 
     (G[{0}, yv^(-1)]*G[{0}, yw]*G[{0, 1, yu^(-1)}, yw])/16 - 
     (G[{0}, yw]^2*G[{0, 1, yu^(-1)}, yw])/32 - 
     (G[{0}, yu^(-1)]*G[{1}, yu^(-1)]*G[{0, 1, yu^(-1)}, yw])/8 - 
     (G[{0}, yv^(-1)]*G[{1}, yu^(-1)]*G[{0, 1, yu^(-1)}, yw])/8 + 
     (G[{0}, yw]*G[{1}, yu^(-1)]*G[{0, 1, yu^(-1)}, yw])/8 + 
     (G[{1}, yu^(-1)]^2*G[{0, 1, yu^(-1)}, yw])/16 + 
     (G[{0}, yu^(-1)]*G[{1}, yv^(-1)]*G[{0, 1, yu^(-1)}, yw])/8 + 
     (G[{0}, yv^(-1)]*G[{1}, yv^(-1)]*G[{0, 1, yu^(-1)}, yw])/8 - 
     (G[{0}, yw]*G[{1}, yv^(-1)]*G[{0, 1, yu^(-1)}, yw])/8 + 
     (G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*G[{0, 1, yu^(-1)}, yw])/8 - 
     (3*G[{1}, yv^(-1)]^2*G[{0, 1, yu^(-1)}, yw])/32 - 
     (3*G[{0}, yu^(-1)]*G[{1}, yw]*G[{0, 1, yu^(-1)}, yw])/16 - 
     (3*G[{0}, yv^(-1)]*G[{1}, yw]*G[{0, 1, yu^(-1)}, yw])/16 + 
     (3*G[{0}, yw]*G[{1}, yw]*G[{0, 1, yu^(-1)}, yw])/16 - 
     (G[{1}, yu^(-1)]*G[{1}, yw]*G[{0, 1, yu^(-1)}, yw])/8 + 
     (G[{1}, yv^(-1)]*G[{1}, yw]*G[{0, 1, yu^(-1)}, yw])/4 - 
     (G[{1}, yw]^2*G[{0, 1, yu^(-1)}, yw])/8 + 
     (G[{0}, yu^(-1)]*G[{yu}, yv^(-1)]*G[{0, 1, yu^(-1)}, yw])/8 + 
     (G[{0}, yv^(-1)]*G[{yu}, yv^(-1)]*G[{0, 1, yu^(-1)}, yw])/8 - 
     (G[{0}, yw]*G[{yu}, yv^(-1)]*G[{0, 1, yu^(-1)}, yw])/8 - 
     (G[{1}, yv^(-1)]*G[{yu}, yv^(-1)]*G[{0, 1, yu^(-1)}, yw])/4 + 
     (G[{1}, yw]*G[{yu}, yv^(-1)]*G[{0, 1, yu^(-1)}, yw])/4 + 
     (3*G[{0}, yu^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, 1, yu^(-1)}, yw])/16 + 
     (3*G[{0}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, 1, yu^(-1)}, yw])/16 - 
     (3*G[{0}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1, yu^(-1)}, yw])/16 + 
     (G[{1}, yu^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, 1, yu^(-1)}, yw])/8 - 
     (G[{1}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, 1, yu^(-1)}, yw])/4 + 
     (G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1, yu^(-1)}, yw])/4 + 
     (G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1, yu^(-1)}, yw])/8 - 
     (G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, 1, yu^(-1)}, yw])/4 - 
     (G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1, yu^(-1)}, yw])/4 + 
     (G[{0, 1}, yv^(-1)]*G[{0, 1, yu^(-1)}, yw])/16 + 
     (G[{0, 1}, yw]*G[{0, 1, yu^(-1)}, yw])/8 - 
     (G[{0, yu}, yv^(-1)]*G[{0, 1, yu^(-1)}, yw])/16 + 
     (G[{0, 1/(yu*yv)}, yw]*G[{0, 1, yu^(-1)}, yw])/16 - 
     (G[{1, yu^(-1)}, yw]*G[{0, 1, yu^(-1)}, yw])/8 + 
     (G[{1, yu}, yv^(-1)]*G[{0, 1, yu^(-1)}, yw])/16 + 
     (G[{1, yv^(-1)}, yw]*G[{0, 1, yu^(-1)}, yw])/4 - 
     (G[{1, 1/(yu*yv)}, yw]*G[{0, 1, yu^(-1)}, yw])/4 - 
     (G[{yu^(-1), 1/(yu*yv)}, yw]*G[{0, 1, yu^(-1)}, yw])/8 + 
     (G[{yv^(-1), 1/(yu*yv)}, yw]*G[{0, 1, yu^(-1)}, yw])/4 + 
     (Pi^2*G[{0, 1, yu}, yv^(-1)])/96 + 
     (G[{1}, yu^(-1)]^2*G[{0, 1, yu}, yv^(-1)])/32 + 
     (G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*G[{0, 1, yu}, yv^(-1)])/16 - 
     (G[{1}, yv^(-1)]^2*G[{0, 1, yu}, yv^(-1)])/32 - 
     (G[{0}, yu^(-1)]*G[{1}, yw]*G[{0, 1, yu}, yv^(-1)])/16 - 
     (G[{0}, yv^(-1)]*G[{1}, yw]*G[{0, 1, yu}, yv^(-1)])/16 + 
     (G[{0}, yw]*G[{1}, yw]*G[{0, 1, yu}, yv^(-1)])/16 - 
     (G[{1}, yu^(-1)]*G[{1}, yw]*G[{0, 1, yu}, yv^(-1)])/16 + 
     (G[{1}, yv^(-1)]*G[{1}, yw]*G[{0, 1, yu}, yv^(-1)])/16 - 
     (G[{1}, yw]^2*G[{0, 1, yu}, yv^(-1)])/16 + 
     (G[{1}, yw]*G[{yu}, yv^(-1)]*G[{0, 1, yu}, yv^(-1)])/8 + 
     (G[{0}, yu^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, 1, yu}, yv^(-1)])/16 + 
     (G[{0}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, 1, yu}, yv^(-1)])/16 - 
     (G[{0}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1, yu}, yv^(-1)])/16 + 
     (G[{1}, yu^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, 1, yu}, yv^(-1)])/16 - 
     (G[{1}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, 1, yu}, yv^(-1)])/16 + 
     (G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1, yu}, yv^(-1)])/8 + 
     (G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1, yu}, yv^(-1)])/16 - 
     (G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, 1, yu}, yv^(-1)])/8 - 
     (G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1, yu}, yv^(-1)])/16 + 
     (G[{0, 1}, yu^(-1)]*G[{0, 1, yu}, yv^(-1)])/16 - 
     (G[{0, 1}, yw]*G[{0, 1, yu}, yv^(-1)])/16 - 
     (G[{0, yu}, yv^(-1)]*G[{0, 1, yu}, yv^(-1)])/16 + 
     (G[{0, 1/(yu*yv)}, yw]*G[{0, 1, yu}, yv^(-1)])/16 - 
     (G[{1, yu^(-1)}, yw]*G[{0, 1, yu}, yv^(-1)])/16 + 
     (G[{1, yv^(-1)}, yw]*G[{0, 1, yu}, yv^(-1)])/16 - 
     (G[{1, 1/(yu*yv)}, yw]*G[{0, 1, yu}, yv^(-1)])/8 - 
     (G[{yu^(-1), 1/(yu*yv)}, yw]*G[{0, 1, yu}, yv^(-1)])/16 + 
     (G[{yv^(-1), 1/(yu*yv)}, yw]*G[{0, 1, yu}, yv^(-1)])/16 + 
     (Pi^2*G[{0, 1, yv^(-1)}, yw])/32 - 
     (G[{0}, yu^(-1)]^2*G[{0, 1, yv^(-1)}, yw])/32 - 
     (G[{0}, yu^(-1)]*G[{0}, yv^(-1)]*G[{0, 1, yv^(-1)}, yw])/16 - 
     (G[{0}, yv^(-1)]^2*G[{0, 1, yv^(-1)}, yw])/32 + 
     (G[{0}, yu^(-1)]*G[{0}, yw]*G[{0, 1, yv^(-1)}, yw])/16 + 
     (G[{0}, yv^(-1)]*G[{0}, yw]*G[{0, 1, yv^(-1)}, yw])/16 - 
     (G[{0}, yw]^2*G[{0, 1, yv^(-1)}, yw])/32 - 
     (G[{0}, yu^(-1)]*G[{1}, yu^(-1)]*G[{0, 1, yv^(-1)}, yw])/16 - 
     (G[{0}, yv^(-1)]*G[{1}, yu^(-1)]*G[{0, 1, yv^(-1)}, yw])/16 + 
     (G[{0}, yw]*G[{1}, yu^(-1)]*G[{0, 1, yv^(-1)}, yw])/16 + 
     (3*G[{1}, yu^(-1)]^2*G[{0, 1, yv^(-1)}, yw])/16 + 
     (G[{0}, yu^(-1)]*G[{1}, yv^(-1)]*G[{0, 1, yv^(-1)}, yw])/16 + 
     (G[{0}, yv^(-1)]*G[{1}, yv^(-1)]*G[{0, 1, yv^(-1)}, yw])/16 - 
     (G[{0}, yw]*G[{1}, yv^(-1)]*G[{0, 1, yv^(-1)}, yw])/16 - 
     (G[{1}, yv^(-1)]^2*G[{0, 1, yv^(-1)}, yw])/32 - 
     (3*G[{0}, yu^(-1)]*G[{1}, yw]*G[{0, 1, yv^(-1)}, yw])/16 - 
     (3*G[{0}, yv^(-1)]*G[{1}, yw]*G[{0, 1, yv^(-1)}, yw])/16 + 
     (3*G[{0}, yw]*G[{1}, yw]*G[{0, 1, yv^(-1)}, yw])/16 - 
     (G[{1}, yu^(-1)]*G[{1}, yw]*G[{0, 1, yv^(-1)}, yw])/8 + 
     (G[{1}, yv^(-1)]*G[{1}, yw]*G[{0, 1, yv^(-1)}, yw])/4 - 
     (G[{1}, yw]^2*G[{0, 1, yv^(-1)}, yw])/8 + 
     (G[{0}, yu^(-1)]*G[{yu}, yv^(-1)]*G[{0, 1, yv^(-1)}, yw])/8 + 
     (G[{0}, yv^(-1)]*G[{yu}, yv^(-1)]*G[{0, 1, yv^(-1)}, yw])/8 - 
     (G[{0}, yw]*G[{yu}, yv^(-1)]*G[{0, 1, yv^(-1)}, yw])/8 - 
     (G[{1}, yu^(-1)]*G[{yu}, yv^(-1)]*G[{0, 1, yv^(-1)}, yw])/4 + 
     (G[{1}, yw]*G[{yu}, yv^(-1)]*G[{0, 1, yv^(-1)}, yw])/4 + 
     (3*G[{0}, yu^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, 1, yv^(-1)}, yw])/16 + 
     (3*G[{0}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, 1, yv^(-1)}, yw])/16 - 
     (3*G[{0}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1, yv^(-1)}, yw])/16 + 
     (G[{1}, yu^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, 1, yv^(-1)}, yw])/8 - 
     (G[{1}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, 1, yv^(-1)}, yw])/4 + 
     (G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1, yv^(-1)}, yw])/4 + 
     (G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1, yv^(-1)}, yw])/8 - 
     (G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, 1, yv^(-1)}, yw])/4 - 
     (G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1, yv^(-1)}, yw])/4 + 
     (G[{0, 1}, yu^(-1)]*G[{0, 1, yv^(-1)}, yw])/16 - 
     (G[{0, 1}, yw]*G[{0, 1, yv^(-1)}, yw])/16 - 
     (G[{0, yu^(-1)}, yw]*G[{0, 1, yv^(-1)}, yw])/16 + 
     (G[{0, 1/(yu*yv)}, yw]*G[{0, 1, yv^(-1)}, yw])/16 - 
     (G[{1, yu^(-1)}, yw]*G[{0, 1, yv^(-1)}, yw])/8 - 
     (G[{1, yu}, yv^(-1)]*G[{0, 1, yv^(-1)}, yw])/16 + 
     (G[{1, yv^(-1)}, yw]*G[{0, 1, yv^(-1)}, yw])/4 - 
     (G[{1, 1/(yu*yv)}, yw]*G[{0, 1, yv^(-1)}, yw])/4 - 
     (G[{yu^(-1), 1/(yu*yv)}, yw]*G[{0, 1, yv^(-1)}, yw])/8 + 
     (G[{yv^(-1), 1/(yu*yv)}, yw]*G[{0, 1, yv^(-1)}, yw])/4 - 
     (3*G[{1}, yu^(-1)]^2*G[{0, 1, 1/(yu*yv)}, yw])/32 + 
     (G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*G[{0, 1, 1/(yu*yv)}, yw])/16 + 
     (G[{0}, yu^(-1)]*G[{1}, yw]*G[{0, 1, 1/(yu*yv)}, yw])/16 + 
     (G[{0}, yv^(-1)]*G[{1}, yw]*G[{0, 1, 1/(yu*yv)}, yw])/16 - 
     (G[{0}, yw]*G[{1}, yw]*G[{0, 1, 1/(yu*yv)}, yw])/16 - 
     (G[{1}, yu^(-1)]*G[{1}, yw]*G[{0, 1, 1/(yu*yv)}, yw])/16 - 
     (G[{1}, yv^(-1)]*G[{1}, yw]*G[{0, 1, 1/(yu*yv)}, yw])/16 + 
     (G[{1}, yu^(-1)]*G[{yu}, yv^(-1)]*G[{0, 1, 1/(yu*yv)}, yw])/8 + 
     (G[{1}, yv^(-1)]*G[{yu}, yv^(-1)]*G[{0, 1, 1/(yu*yv)}, yw])/8 - 
     (G[{yu}, yv^(-1)]^2*G[{0, 1, 1/(yu*yv)}, yw])/8 - 
     (G[{0}, yu^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, 1, 1/(yu*yv)}, yw])/16 - 
     (G[{0}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, 1, 1/(yu*yv)}, yw])/16 + 
     (G[{0}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1, 1/(yu*yv)}, yw])/16 + 
     (G[{1}, yu^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, 1, 1/(yu*yv)}, yw])/16 + 
     (G[{1}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, 1, 1/(yu*yv)}, yw])/16 - 
     (G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1, 1/(yu*yv)}, yw])/16 - 
     (G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1, 1/(yu*yv)}, yw])/16 + 
     (G[{0, 1}, yu^(-1)]*G[{0, 1, 1/(yu*yv)}, yw])/16 - 
     (G[{0, 1}, yv^(-1)]*G[{0, 1, 1/(yu*yv)}, yw])/8 + 
     (G[{0, yu}, yv^(-1)]*G[{0, 1, 1/(yu*yv)}, yw])/8 - 
     (G[{0, 1/(yu*yv)}, yw]*G[{0, 1, 1/(yu*yv)}, yw])/16 + 
     (G[{1, yu^(-1)}, yw]*G[{0, 1, 1/(yu*yv)}, yw])/16 - 
     (3*G[{1, yu}, yv^(-1)]*G[{0, 1, 1/(yu*yv)}, yw])/16 + 
     (G[{1, yv^(-1)}, yw]*G[{0, 1, 1/(yu*yv)}, yw])/16 + 
     (G[{yu^(-1), 1/(yu*yv)}, yw]*G[{0, 1, 1/(yu*yv)}, yw])/16 + 
     (G[{yv^(-1), 1/(yu*yv)}, yw]*G[{0, 1, 1/(yu*yv)}, yw])/16 + 
     (Pi^2*G[{0, yu^(-1), 1}, yw])/96 - 
     (G[{0}, yu^(-1)]^2*G[{0, yu^(-1), 1}, yw])/32 - 
     (G[{0}, yu^(-1)]*G[{0}, yv^(-1)]*G[{0, yu^(-1), 1}, yw])/16 - 
     (G[{0}, yv^(-1)]^2*G[{0, yu^(-1), 1}, yw])/32 + 
     (G[{0}, yu^(-1)]*G[{0}, yw]*G[{0, yu^(-1), 1}, yw])/16 + 
     (G[{0}, yv^(-1)]*G[{0}, yw]*G[{0, yu^(-1), 1}, yw])/16 - 
     (G[{0}, yw]^2*G[{0, yu^(-1), 1}, yw])/32 - 
     (G[{0}, yu^(-1)]*G[{1}, yu^(-1)]*G[{0, yu^(-1), 1}, yw])/16 - 
     (G[{0}, yv^(-1)]*G[{1}, yu^(-1)]*G[{0, yu^(-1), 1}, yw])/16 + 
     (G[{0}, yw]*G[{1}, yu^(-1)]*G[{0, yu^(-1), 1}, yw])/16 + 
     (3*G[{1}, yu^(-1)]^2*G[{0, yu^(-1), 1}, yw])/32 + 
     (G[{0}, yu^(-1)]*G[{1}, yv^(-1)]*G[{0, yu^(-1), 1}, yw])/16 + 
     (G[{0}, yv^(-1)]*G[{1}, yv^(-1)]*G[{0, yu^(-1), 1}, yw])/16 - 
     (G[{0}, yw]*G[{1}, yv^(-1)]*G[{0, yu^(-1), 1}, yw])/16 + 
     (G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*G[{0, yu^(-1), 1}, yw])/16 - 
     (G[{1}, yv^(-1)]^2*G[{0, yu^(-1), 1}, yw])/32 - 
     (G[{0}, yu^(-1)]*G[{1}, yw]*G[{0, yu^(-1), 1}, yw])/16 - 
     (G[{0}, yv^(-1)]*G[{1}, yw]*G[{0, yu^(-1), 1}, yw])/16 + 
     (G[{0}, yw]*G[{1}, yw]*G[{0, yu^(-1), 1}, yw])/16 + 
     (G[{1}, yu^(-1)]*G[{1}, yw]*G[{0, yu^(-1), 1}, yw])/16 + 
     (G[{1}, yv^(-1)]*G[{1}, yw]*G[{0, yu^(-1), 1}, yw])/16 + 
     (G[{0}, yu^(-1)]*G[{yu}, yv^(-1)]*G[{0, yu^(-1), 1}, yw])/8 + 
     (G[{0}, yv^(-1)]*G[{yu}, yv^(-1)]*G[{0, yu^(-1), 1}, yw])/8 - 
     (G[{0}, yw]*G[{yu}, yv^(-1)]*G[{0, yu^(-1), 1}, yw])/8 - 
     (G[{1}, yu^(-1)]*G[{yu}, yv^(-1)]*G[{0, yu^(-1), 1}, yw])/8 - 
     (G[{1}, yv^(-1)]*G[{yu}, yv^(-1)]*G[{0, yu^(-1), 1}, yw])/8 + 
     (G[{0}, yu^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1), 1}, yw])/16 + 
     (G[{0}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1), 1}, yw])/16 - 
     (G[{0}, yw]*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1), 1}, yw])/16 - 
     (G[{1}, yu^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1), 1}, yw])/16 - 
     (G[{1}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1), 1}, yw])/16 + 
     (G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1), 1}, yw])/16 + 
     (G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1), 1}, yw])/16 + 
     (G[{0, 1}, yw]*G[{0, yu^(-1), 1}, yw])/16 - 
     (G[{0, yu^(-1)}, yw]*G[{0, yu^(-1), 1}, yw])/16 + 
     (G[{0, 1/(yu*yv)}, yw]*G[{0, yu^(-1), 1}, yw])/16 - 
     (G[{1, yu^(-1)}, yw]*G[{0, yu^(-1), 1}, yw])/16 - 
     (G[{1, yv^(-1)}, yw]*G[{0, yu^(-1), 1}, yw])/16 - 
     (G[{yu^(-1), 1/(yu*yv)}, yw]*G[{0, yu^(-1), 1}, yw])/16 - 
     (G[{yv^(-1), 1/(yu*yv)}, yw]*G[{0, yu^(-1), 1}, yw])/16 + 
     (G[{0}, yu^(-1)]*G[{1}, yw]*G[{0, yu^(-1), yu^(-1)}, yw])/8 + 
     (G[{0}, yv^(-1)]*G[{1}, yw]*G[{0, yu^(-1), yu^(-1)}, yw])/8 - 
     (G[{0}, yw]*G[{1}, yw]*G[{0, yu^(-1), yu^(-1)}, yw])/8 + 
     (G[{1}, yu^(-1)]*G[{1}, yw]*G[{0, yu^(-1), yu^(-1)}, yw])/8 - 
     (G[{1}, yv^(-1)]*G[{1}, yw]*G[{0, yu^(-1), yu^(-1)}, yw])/8 + 
     (G[{1}, yw]^2*G[{0, yu^(-1), yu^(-1)}, yw])/8 - 
     (G[{1}, yw]*G[{yu}, yv^(-1)]*G[{0, yu^(-1), yu^(-1)}, yw])/4 - 
     (G[{0}, yu^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1), yu^(-1)}, yw])/8 - 
     (G[{0}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1), yu^(-1)}, yw])/8 + 
     (G[{0}, yw]*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1), yu^(-1)}, yw])/8 - 
     (G[{1}, yu^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1), yu^(-1)}, yw])/8 + 
     (G[{1}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1), yu^(-1)}, yw])/8 - 
     (G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1), yu^(-1)}, yw])/4 - 
     (G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1), yu^(-1)}, yw])/8 + 
     (G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1), yu^(-1)}, yw])/4 + 
     (G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1), yu^(-1)}, yw])/4 - 
     (G[{0, 1/(yu*yv)}, yw]*G[{0, yu^(-1), yu^(-1)}, yw])/8 + 
     (G[{1, yu^(-1)}, yw]*G[{0, yu^(-1), yu^(-1)}, yw])/8 - 
     (G[{1, yv^(-1)}, yw]*G[{0, yu^(-1), yu^(-1)}, yw])/4 + 
     (G[{1, 1/(yu*yv)}, yw]*G[{0, yu^(-1), yu^(-1)}, yw])/4 + 
     (G[{yu^(-1), 1/(yu*yv)}, yw]*G[{0, yu^(-1), yu^(-1)}, yw])/8 - 
     (G[{yv^(-1), 1/(yu*yv)}, yw]*G[{0, yu^(-1), yu^(-1)}, yw])/4 + 
     (3*G[{0}, yu^(-1)]*G[{1}, yw]*G[{0, yu^(-1), yv^(-1)}, yw])/16 + 
     (3*G[{0}, yv^(-1)]*G[{1}, yw]*G[{0, yu^(-1), yv^(-1)}, yw])/16 - 
     (3*G[{0}, yw]*G[{1}, yw]*G[{0, yu^(-1), yv^(-1)}, yw])/16 + 
     (G[{1}, yu^(-1)]*G[{1}, yw]*G[{0, yu^(-1), yv^(-1)}, yw])/8 - 
     (G[{1}, yv^(-1)]*G[{1}, yw]*G[{0, yu^(-1), yv^(-1)}, yw])/4 + 
     (G[{1}, yw]^2*G[{0, yu^(-1), yv^(-1)}, yw])/8 - 
     (G[{1}, yw]*G[{yu}, yv^(-1)]*G[{0, yu^(-1), yv^(-1)}, yw])/4 - 
     (3*G[{0}, yu^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1), yv^(-1)}, yw])/16 - 
     (3*G[{0}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1), yv^(-1)}, yw])/16 + 
     (3*G[{0}, yw]*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1), yv^(-1)}, yw])/16 - 
     (G[{1}, yu^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1), yv^(-1)}, yw])/8 + 
     (G[{1}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1), yv^(-1)}, yw])/4 - 
     (G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1), yv^(-1)}, yw])/4 - 
     (G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1), yv^(-1)}, yw])/8 + 
     (G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1), yv^(-1)}, yw])/4 + 
     (G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1), yv^(-1)}, yw])/4 - 
     (G[{0, 1/(yu*yv)}, yw]*G[{0, yu^(-1), yv^(-1)}, yw])/16 + 
     (G[{1, yu^(-1)}, yw]*G[{0, yu^(-1), yv^(-1)}, yw])/8 - 
     (G[{1, yv^(-1)}, yw]*G[{0, yu^(-1), yv^(-1)}, yw])/4 + 
     (G[{1, 1/(yu*yv)}, yw]*G[{0, yu^(-1), yv^(-1)}, yw])/4 + 
     (G[{yu^(-1), 1/(yu*yv)}, yw]*G[{0, yu^(-1), yv^(-1)}, yw])/8 - 
     (G[{yv^(-1), 1/(yu*yv)}, yw]*G[{0, yu^(-1), yv^(-1)}, yw])/4 - 
     (Pi^2*G[{0, yu^(-1), 1/(yu*yv)}, yw])/96 + 
     (G[{0}, yu^(-1)]^2*G[{0, yu^(-1), 1/(yu*yv)}, yw])/32 + 
     (G[{0}, yu^(-1)]*G[{0}, yv^(-1)]*G[{0, yu^(-1), 1/(yu*yv)}, yw])/16 + 
     (G[{0}, yv^(-1)]^2*G[{0, yu^(-1), 1/(yu*yv)}, yw])/32 - 
     (G[{0}, yu^(-1)]*G[{0}, yw]*G[{0, yu^(-1), 1/(yu*yv)}, yw])/16 - 
     (G[{0}, yv^(-1)]*G[{0}, yw]*G[{0, yu^(-1), 1/(yu*yv)}, yw])/16 + 
     (G[{0}, yw]^2*G[{0, yu^(-1), 1/(yu*yv)}, yw])/32 + 
     (G[{0}, yu^(-1)]*G[{1}, yu^(-1)]*G[{0, yu^(-1), 1/(yu*yv)}, yw])/16 + 
     (G[{0}, yv^(-1)]*G[{1}, yu^(-1)]*G[{0, yu^(-1), 1/(yu*yv)}, yw])/16 - 
     (G[{0}, yw]*G[{1}, yu^(-1)]*G[{0, yu^(-1), 1/(yu*yv)}, yw])/16 - 
     (3*G[{1}, yu^(-1)]^2*G[{0, yu^(-1), 1/(yu*yv)}, yw])/32 - 
     (G[{0}, yu^(-1)]*G[{1}, yv^(-1)]*G[{0, yu^(-1), 1/(yu*yv)}, yw])/16 - 
     (G[{0}, yv^(-1)]*G[{1}, yv^(-1)]*G[{0, yu^(-1), 1/(yu*yv)}, yw])/16 + 
     (G[{0}, yw]*G[{1}, yv^(-1)]*G[{0, yu^(-1), 1/(yu*yv)}, yw])/16 - 
     (G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*G[{0, yu^(-1), 1/(yu*yv)}, yw])/16 + 
     (G[{1}, yv^(-1)]^2*G[{0, yu^(-1), 1/(yu*yv)}, yw])/32 - 
     (G[{0}, yu^(-1)]*G[{1}, yw]*G[{0, yu^(-1), 1/(yu*yv)}, yw])/16 - 
     (G[{0}, yv^(-1)]*G[{1}, yw]*G[{0, yu^(-1), 1/(yu*yv)}, yw])/16 + 
     (G[{0}, yw]*G[{1}, yw]*G[{0, yu^(-1), 1/(yu*yv)}, yw])/16 + 
     (G[{1}, yu^(-1)]*G[{1}, yw]*G[{0, yu^(-1), 1/(yu*yv)}, yw])/16 + 
     (G[{1}, yv^(-1)]*G[{1}, yw]*G[{0, yu^(-1), 1/(yu*yv)}, yw])/16 - 
     (G[{0}, yu^(-1)]*G[{yu}, yv^(-1)]*G[{0, yu^(-1), 1/(yu*yv)}, yw])/8 - 
     (G[{0}, yv^(-1)]*G[{yu}, yv^(-1)]*G[{0, yu^(-1), 1/(yu*yv)}, yw])/8 + 
     (G[{0}, yw]*G[{yu}, yv^(-1)]*G[{0, yu^(-1), 1/(yu*yv)}, yw])/8 + 
     (G[{1}, yu^(-1)]*G[{yu}, yv^(-1)]*G[{0, yu^(-1), 1/(yu*yv)}, yw])/8 + 
     (G[{1}, yv^(-1)]*G[{yu}, yv^(-1)]*G[{0, yu^(-1), 1/(yu*yv)}, yw])/8 + 
     (G[{0}, yu^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1), 1/(yu*yv)}, yw])/16 + 
     (G[{0}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1), 1/(yu*yv)}, yw])/16 - 
     (G[{0}, yw]*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1), 1/(yu*yv)}, yw])/16 - 
     (G[{1}, yu^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1), 1/(yu*yv)}, yw])/16 - 
     (G[{1}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1), 1/(yu*yv)}, yw])/16 + 
     (G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1), 1/(yu*yv)}, yw])/
      16 + (G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1), 1/(yu*yv)}, 
        yw])/16 - (G[{0, 1}, yw]*G[{0, yu^(-1), 1/(yu*yv)}, yw])/16 + 
     (G[{0, yu^(-1)}, yw]*G[{0, yu^(-1), 1/(yu*yv)}, yw])/16 + 
     (G[{0, yv^(-1)}, yw]*G[{0, yu^(-1), 1/(yu*yv)}, yw])/16 + 
     (G[{0, 1/(yu*yv)}, yw]*G[{0, yu^(-1), 1/(yu*yv)}, yw])/16 - 
     (G[{1, yu^(-1)}, yw]*G[{0, yu^(-1), 1/(yu*yv)}, yw])/16 - 
     (G[{1, yv^(-1)}, yw]*G[{0, yu^(-1), 1/(yu*yv)}, yw])/16 - 
     (G[{yu^(-1), 1/(yu*yv)}, yw]*G[{0, yu^(-1), 1/(yu*yv)}, yw])/16 - 
     (G[{yv^(-1), 1/(yu*yv)}, yw]*G[{0, yu^(-1), 1/(yu*yv)}, yw])/16 - 
     (G[{1}, yu^(-1)]^2*G[{0, yu, 1}, yv^(-1)])/32 + 
     (G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*G[{0, yu, 1}, yv^(-1)])/4 - 
     (G[{1}, yv^(-1)]^2*G[{0, yu, 1}, yv^(-1)])/16 + 
     (G[{0}, yu^(-1)]*G[{1}, yw]*G[{0, yu, 1}, yv^(-1)])/16 + 
     (G[{0}, yv^(-1)]*G[{1}, yw]*G[{0, yu, 1}, yv^(-1)])/16 - 
     (G[{0}, yw]*G[{1}, yw]*G[{0, yu, 1}, yv^(-1)])/16 - 
     (G[{1}, yu^(-1)]*G[{1}, yw]*G[{0, yu, 1}, yv^(-1)])/8 - 
     (G[{0}, yu^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, yu, 1}, yv^(-1)])/16 - 
     (G[{0}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, yu, 1}, yv^(-1)])/16 + 
     (G[{0}, yw]*G[{1/(yu*yv)}, yw]*G[{0, yu, 1}, yv^(-1)])/16 + 
     (G[{1}, yu^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, yu, 1}, yv^(-1)])/8 - 
     (G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{0, yu, 1}, yv^(-1)])/8 + 
     (G[{0, 1}, yu^(-1)]*G[{0, yu, 1}, yv^(-1)])/16 - 
     (G[{0, 1}, yv^(-1)]*G[{0, yu, 1}, yv^(-1)])/16 + 
     (G[{0, 1}, yw]*G[{0, yu, 1}, yv^(-1)])/16 + 
     (G[{0, yu}, yv^(-1)]*G[{0, yu, 1}, yv^(-1)])/16 - 
     (G[{0, 1/(yu*yv)}, yw]*G[{0, yu, 1}, yv^(-1)])/16 + 
     (G[{1, yv^(-1)}, yw]*G[{0, yu, 1}, yv^(-1)])/8 + 
     (G[{yv^(-1), 1/(yu*yv)}, yw]*G[{0, yu, 1}, yv^(-1)])/8 + 
     (Pi^2*G[{0, yu, yu}, yv^(-1)])/96 - 
     (G[{1}, yu^(-1)]^2*G[{0, yu, yu}, yv^(-1)])/32 - 
     (G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*G[{0, yu, yu}, yv^(-1)])/16 + 
     (G[{1}, yv^(-1)]^2*G[{0, yu, yu}, yv^(-1)])/32 + 
     (G[{1}, yu^(-1)]*G[{1}, yw]*G[{0, yu, yu}, yv^(-1)])/16 - 
     (G[{1}, yv^(-1)]*G[{1}, yw]*G[{0, yu, yu}, yv^(-1)])/16 + 
     (G[{1}, yw]^2*G[{0, yu, yu}, yv^(-1)])/16 - 
     (G[{1}, yw]*G[{yu}, yv^(-1)]*G[{0, yu, yu}, yv^(-1)])/8 - 
     (G[{1}, yu^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, yu, yu}, yv^(-1)])/16 + 
     (G[{1}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, yu, yu}, yv^(-1)])/16 - 
     (G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{0, yu, yu}, yv^(-1)])/8 - 
     (G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{0, yu, yu}, yv^(-1)])/16 + 
     (G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, yu, yu}, yv^(-1)])/8 + 
     (G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{0, yu, yu}, yv^(-1)])/16 + 
     (G[{0, 1}, yu^(-1)]*G[{0, yu, yu}, yv^(-1)])/16 + 
     (G[{0, 1}, yv^(-1)]*G[{0, yu, yu}, yv^(-1)])/8 - 
     (G[{0, yu}, yv^(-1)]*G[{0, yu, yu}, yv^(-1)])/8 + 
     (G[{1, yu^(-1)}, yw]*G[{0, yu, yu}, yv^(-1)])/16 - 
     (G[{1, yv^(-1)}, yw]*G[{0, yu, yu}, yv^(-1)])/16 + 
     (G[{1, 1/(yu*yv)}, yw]*G[{0, yu, yu}, yv^(-1)])/8 + 
     (G[{yu^(-1), 1/(yu*yv)}, yw]*G[{0, yu, yu}, yv^(-1)])/16 - 
     (G[{yv^(-1), 1/(yu*yv)}, yw]*G[{0, yu, yu}, yv^(-1)])/16 + 
     (Pi^2*G[{0, yv^(-1), 1}, yw])/96 - 
     (G[{0}, yu^(-1)]^2*G[{0, yv^(-1), 1}, yw])/32 - 
     (G[{0}, yu^(-1)]*G[{0}, yv^(-1)]*G[{0, yv^(-1), 1}, yw])/16 - 
     (G[{0}, yv^(-1)]^2*G[{0, yv^(-1), 1}, yw])/32 + 
     (G[{0}, yu^(-1)]*G[{0}, yw]*G[{0, yv^(-1), 1}, yw])/16 + 
     (G[{0}, yv^(-1)]*G[{0}, yw]*G[{0, yv^(-1), 1}, yw])/16 - 
     (G[{0}, yw]^2*G[{0, yv^(-1), 1}, yw])/32 - 
     (G[{0}, yu^(-1)]*G[{1}, yu^(-1)]*G[{0, yv^(-1), 1}, yw])/8 - 
     (G[{0}, yv^(-1)]*G[{1}, yu^(-1)]*G[{0, yv^(-1), 1}, yw])/8 + 
     (G[{0}, yw]*G[{1}, yu^(-1)]*G[{0, yv^(-1), 1}, yw])/8 + 
     (5*G[{1}, yu^(-1)]^2*G[{0, yv^(-1), 1}, yw])/32 + 
     (G[{0}, yu^(-1)]*G[{1}, yv^(-1)]*G[{0, yv^(-1), 1}, yw])/8 + 
     (G[{0}, yv^(-1)]*G[{1}, yv^(-1)]*G[{0, yv^(-1), 1}, yw])/8 - 
     (G[{0}, yw]*G[{1}, yv^(-1)]*G[{0, yv^(-1), 1}, yw])/8 + 
     (G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*G[{0, yv^(-1), 1}, yw])/16 - 
     (3*G[{1}, yv^(-1)]^2*G[{0, yv^(-1), 1}, yw])/32 - 
     (G[{0}, yu^(-1)]*G[{1}, yw]*G[{0, yv^(-1), 1}, yw])/16 - 
     (G[{0}, yv^(-1)]*G[{1}, yw]*G[{0, yv^(-1), 1}, yw])/16 + 
     (G[{0}, yw]*G[{1}, yw]*G[{0, yv^(-1), 1}, yw])/16 + 
     (G[{1}, yu^(-1)]*G[{1}, yw]*G[{0, yv^(-1), 1}, yw])/16 + 
     (G[{1}, yv^(-1)]*G[{1}, yw]*G[{0, yv^(-1), 1}, yw])/16 + 
     (G[{0}, yu^(-1)]*G[{yu}, yv^(-1)]*G[{0, yv^(-1), 1}, yw])/8 + 
     (G[{0}, yv^(-1)]*G[{yu}, yv^(-1)]*G[{0, yv^(-1), 1}, yw])/8 - 
     (G[{0}, yw]*G[{yu}, yv^(-1)]*G[{0, yv^(-1), 1}, yw])/8 - 
     (G[{1}, yu^(-1)]*G[{yu}, yv^(-1)]*G[{0, yv^(-1), 1}, yw])/8 - 
     (G[{1}, yv^(-1)]*G[{yu}, yv^(-1)]*G[{0, yv^(-1), 1}, yw])/8 + 
     (G[{0}, yu^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, yv^(-1), 1}, yw])/16 + 
     (G[{0}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, yv^(-1), 1}, yw])/16 - 
     (G[{0}, yw]*G[{1/(yu*yv)}, yw]*G[{0, yv^(-1), 1}, yw])/16 - 
     (G[{1}, yu^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, yv^(-1), 1}, yw])/16 - 
     (G[{1}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, yv^(-1), 1}, yw])/16 + 
     (G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{0, yv^(-1), 1}, yw])/16 + 
     (G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{0, yv^(-1), 1}, yw])/16 + 
     (G[{0, 1}, yw]*G[{0, yv^(-1), 1}, yw])/16 - 
     (G[{0, yu^(-1)}, yw]*G[{0, yv^(-1), 1}, yw])/16 - 
     (G[{0, yv^(-1)}, yw]*G[{0, yv^(-1), 1}, yw])/16 + 
     (G[{0, 1/(yu*yv)}, yw]*G[{0, yv^(-1), 1}, yw])/16 - 
     (G[{1, yu^(-1)}, yw]*G[{0, yv^(-1), 1}, yw])/16 - 
     (G[{1, yv^(-1)}, yw]*G[{0, yv^(-1), 1}, yw])/16 - 
     (G[{yu^(-1), 1/(yu*yv)}, yw]*G[{0, yv^(-1), 1}, yw])/16 - 
     (G[{yv^(-1), 1/(yu*yv)}, yw]*G[{0, yv^(-1), 1}, yw])/16 + 
     (3*G[{0}, yu^(-1)]*G[{1}, yw]*G[{0, yv^(-1), yu^(-1)}, yw])/16 + 
     (3*G[{0}, yv^(-1)]*G[{1}, yw]*G[{0, yv^(-1), yu^(-1)}, yw])/16 - 
     (3*G[{0}, yw]*G[{1}, yw]*G[{0, yv^(-1), yu^(-1)}, yw])/16 + 
     (G[{1}, yu^(-1)]*G[{1}, yw]*G[{0, yv^(-1), yu^(-1)}, yw])/8 - 
     (G[{1}, yv^(-1)]*G[{1}, yw]*G[{0, yv^(-1), yu^(-1)}, yw])/4 + 
     (G[{1}, yw]^2*G[{0, yv^(-1), yu^(-1)}, yw])/8 - 
     (G[{1}, yw]*G[{yu}, yv^(-1)]*G[{0, yv^(-1), yu^(-1)}, yw])/4 - 
     (3*G[{0}, yu^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, yv^(-1), yu^(-1)}, yw])/16 - 
     (3*G[{0}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, yv^(-1), yu^(-1)}, yw])/16 + 
     (3*G[{0}, yw]*G[{1/(yu*yv)}, yw]*G[{0, yv^(-1), yu^(-1)}, yw])/16 - 
     (G[{1}, yu^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, yv^(-1), yu^(-1)}, yw])/8 + 
     (G[{1}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, yv^(-1), yu^(-1)}, yw])/4 - 
     (G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{0, yv^(-1), yu^(-1)}, yw])/4 - 
     (G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{0, yv^(-1), yu^(-1)}, yw])/8 + 
     (G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, yv^(-1), yu^(-1)}, yw])/4 + 
     (G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{0, yv^(-1), yu^(-1)}, yw])/4 - 
     (G[{0, 1/(yu*yv)}, yw]*G[{0, yv^(-1), yu^(-1)}, yw])/16 + 
     (G[{1, yu^(-1)}, yw]*G[{0, yv^(-1), yu^(-1)}, yw])/8 - 
     (G[{1, yv^(-1)}, yw]*G[{0, yv^(-1), yu^(-1)}, yw])/4 + 
     (G[{1, 1/(yu*yv)}, yw]*G[{0, yv^(-1), yu^(-1)}, yw])/4 + 
     (G[{yu^(-1), 1/(yu*yv)}, yw]*G[{0, yv^(-1), yu^(-1)}, yw])/8 - 
     (G[{yv^(-1), 1/(yu*yv)}, yw]*G[{0, yv^(-1), yu^(-1)}, yw])/4 + 
     (G[{0}, yu^(-1)]*G[{1}, yw]*G[{0, yv^(-1), yv^(-1)}, yw])/8 + 
     (G[{0}, yv^(-1)]*G[{1}, yw]*G[{0, yv^(-1), yv^(-1)}, yw])/8 - 
     (G[{0}, yw]*G[{1}, yw]*G[{0, yv^(-1), yv^(-1)}, yw])/8 + 
     (G[{1}, yu^(-1)]*G[{1}, yw]*G[{0, yv^(-1), yv^(-1)}, yw])/4 - 
     (G[{1}, yv^(-1)]*G[{1}, yw]*G[{0, yv^(-1), yv^(-1)}, yw])/4 + 
     (G[{1}, yw]^2*G[{0, yv^(-1), yv^(-1)}, yw])/8 - 
     (G[{1}, yw]*G[{yu}, yv^(-1)]*G[{0, yv^(-1), yv^(-1)}, yw])/4 - 
     (G[{0}, yu^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, yv^(-1), yv^(-1)}, yw])/8 - 
     (G[{0}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, yv^(-1), yv^(-1)}, yw])/8 + 
     (G[{0}, yw]*G[{1/(yu*yv)}, yw]*G[{0, yv^(-1), yv^(-1)}, yw])/8 - 
     (G[{1}, yu^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, yv^(-1), yv^(-1)}, yw])/4 + 
     (G[{1}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, yv^(-1), yv^(-1)}, yw])/4 - 
     (G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{0, yv^(-1), yv^(-1)}, yw])/4 - 
     (G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{0, yv^(-1), yv^(-1)}, yw])/8 + 
     (G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, yv^(-1), yv^(-1)}, yw])/4 + 
     (G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{0, yv^(-1), yv^(-1)}, yw])/4 - 
     (G[{0, 1/(yu*yv)}, yw]*G[{0, yv^(-1), yv^(-1)}, yw])/8 + 
     (G[{1, yu^(-1)}, yw]*G[{0, yv^(-1), yv^(-1)}, yw])/8 - 
     (G[{1, yv^(-1)}, yw]*G[{0, yv^(-1), yv^(-1)}, yw])/4 + 
     (G[{1, 1/(yu*yv)}, yw]*G[{0, yv^(-1), yv^(-1)}, yw])/4 + 
     (G[{yu^(-1), 1/(yu*yv)}, yw]*G[{0, yv^(-1), yv^(-1)}, yw])/8 - 
     (G[{yv^(-1), 1/(yu*yv)}, yw]*G[{0, yv^(-1), yv^(-1)}, yw])/4 - 
     (Pi^2*G[{0, yv^(-1), 1/(yu*yv)}, yw])/96 + 
     (G[{0}, yu^(-1)]^2*G[{0, yv^(-1), 1/(yu*yv)}, yw])/32 + 
     (G[{0}, yu^(-1)]*G[{0}, yv^(-1)]*G[{0, yv^(-1), 1/(yu*yv)}, yw])/16 + 
     (G[{0}, yv^(-1)]^2*G[{0, yv^(-1), 1/(yu*yv)}, yw])/32 - 
     (G[{0}, yu^(-1)]*G[{0}, yw]*G[{0, yv^(-1), 1/(yu*yv)}, yw])/16 - 
     (G[{0}, yv^(-1)]*G[{0}, yw]*G[{0, yv^(-1), 1/(yu*yv)}, yw])/16 + 
     (G[{0}, yw]^2*G[{0, yv^(-1), 1/(yu*yv)}, yw])/32 + 
     (G[{0}, yu^(-1)]*G[{1}, yu^(-1)]*G[{0, yv^(-1), 1/(yu*yv)}, yw])/8 + 
     (G[{0}, yv^(-1)]*G[{1}, yu^(-1)]*G[{0, yv^(-1), 1/(yu*yv)}, yw])/8 - 
     (G[{0}, yw]*G[{1}, yu^(-1)]*G[{0, yv^(-1), 1/(yu*yv)}, yw])/8 - 
     (5*G[{1}, yu^(-1)]^2*G[{0, yv^(-1), 1/(yu*yv)}, yw])/32 - 
     (G[{0}, yu^(-1)]*G[{1}, yv^(-1)]*G[{0, yv^(-1), 1/(yu*yv)}, yw])/8 - 
     (G[{0}, yv^(-1)]*G[{1}, yv^(-1)]*G[{0, yv^(-1), 1/(yu*yv)}, yw])/8 + 
     (G[{0}, yw]*G[{1}, yv^(-1)]*G[{0, yv^(-1), 1/(yu*yv)}, yw])/8 - 
     (G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*G[{0, yv^(-1), 1/(yu*yv)}, yw])/16 + 
     (3*G[{1}, yv^(-1)]^2*G[{0, yv^(-1), 1/(yu*yv)}, yw])/32 - 
     (G[{0}, yu^(-1)]*G[{1}, yw]*G[{0, yv^(-1), 1/(yu*yv)}, yw])/16 - 
     (G[{0}, yv^(-1)]*G[{1}, yw]*G[{0, yv^(-1), 1/(yu*yv)}, yw])/16 + 
     (G[{0}, yw]*G[{1}, yw]*G[{0, yv^(-1), 1/(yu*yv)}, yw])/16 + 
     (G[{1}, yu^(-1)]*G[{1}, yw]*G[{0, yv^(-1), 1/(yu*yv)}, yw])/16 + 
     (G[{1}, yv^(-1)]*G[{1}, yw]*G[{0, yv^(-1), 1/(yu*yv)}, yw])/16 - 
     (G[{0}, yu^(-1)]*G[{yu}, yv^(-1)]*G[{0, yv^(-1), 1/(yu*yv)}, yw])/8 - 
     (G[{0}, yv^(-1)]*G[{yu}, yv^(-1)]*G[{0, yv^(-1), 1/(yu*yv)}, yw])/8 + 
     (G[{0}, yw]*G[{yu}, yv^(-1)]*G[{0, yv^(-1), 1/(yu*yv)}, yw])/8 + 
     (G[{1}, yu^(-1)]*G[{yu}, yv^(-1)]*G[{0, yv^(-1), 1/(yu*yv)}, yw])/8 + 
     (G[{1}, yv^(-1)]*G[{yu}, yv^(-1)]*G[{0, yv^(-1), 1/(yu*yv)}, yw])/8 + 
     (G[{0}, yu^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, yv^(-1), 1/(yu*yv)}, yw])/16 + 
     (G[{0}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, yv^(-1), 1/(yu*yv)}, yw])/16 - 
     (G[{0}, yw]*G[{1/(yu*yv)}, yw]*G[{0, yv^(-1), 1/(yu*yv)}, yw])/16 - 
     (G[{1}, yu^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, yv^(-1), 1/(yu*yv)}, yw])/16 - 
     (G[{1}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, yv^(-1), 1/(yu*yv)}, yw])/16 + 
     (G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{0, yv^(-1), 1/(yu*yv)}, yw])/
      16 + (G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{0, yv^(-1), 1/(yu*yv)}, 
        yw])/16 - (G[{0, 1}, yw]*G[{0, yv^(-1), 1/(yu*yv)}, yw])/16 + 
     (G[{0, yu^(-1)}, yw]*G[{0, yv^(-1), 1/(yu*yv)}, yw])/16 + 
     (G[{0, yv^(-1)}, yw]*G[{0, yv^(-1), 1/(yu*yv)}, yw])/16 + 
     (G[{0, 1/(yu*yv)}, yw]*G[{0, yv^(-1), 1/(yu*yv)}, yw])/16 - 
     (G[{1, yu^(-1)}, yw]*G[{0, yv^(-1), 1/(yu*yv)}, yw])/16 - 
     (G[{1, yv^(-1)}, yw]*G[{0, yv^(-1), 1/(yu*yv)}, yw])/16 - 
     (G[{yu^(-1), 1/(yu*yv)}, yw]*G[{0, yv^(-1), 1/(yu*yv)}, yw])/16 - 
     (G[{yv^(-1), 1/(yu*yv)}, yw]*G[{0, yv^(-1), 1/(yu*yv)}, yw])/16 + 
     (Pi^2*G[{0, 1/(yu*yv), 1}, yw])/48 - 
     (3*G[{1}, yu^(-1)]^2*G[{0, 1/(yu*yv), 1}, yw])/32 + 
     (G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*G[{0, 1/(yu*yv), 1}, yw])/16 - 
     (G[{1}, yu^(-1)]*G[{1}, yw]*G[{0, 1/(yu*yv), 1}, yw])/16 - 
     (G[{1}, yv^(-1)]*G[{1}, yw]*G[{0, 1/(yu*yv), 1}, yw])/16 + 
     (G[{1}, yu^(-1)]*G[{yu}, yv^(-1)]*G[{0, 1/(yu*yv), 1}, yw])/8 + 
     (G[{1}, yv^(-1)]*G[{yu}, yv^(-1)]*G[{0, 1/(yu*yv), 1}, yw])/8 + 
     (G[{1}, yw]*G[{yu}, yv^(-1)]*G[{0, 1/(yu*yv), 1}, yw])/8 - 
     (G[{yu}, yv^(-1)]^2*G[{0, 1/(yu*yv), 1}, yw])/8 + 
     (G[{1}, yu^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv), 1}, yw])/16 + 
     (G[{1}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv), 1}, yw])/16 - 
     (G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv), 1}, yw])/16 - 
     (G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv), 1}, yw])/8 - 
     (G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv), 1}, yw])/16 + 
     (3*G[{0, 1}, yu^(-1)]*G[{0, 1/(yu*yv), 1}, yw])/16 - 
     (G[{0, 1}, yw]*G[{0, 1/(yu*yv), 1}, yw])/8 + 
     (G[{0, yu^(-1)}, yw]*G[{0, 1/(yu*yv), 1}, yw])/8 + 
     (G[{0, yv^(-1)}, yw]*G[{0, 1/(yu*yv), 1}, yw])/8 - 
     (G[{0, 1/(yu*yv)}, yw]*G[{0, 1/(yu*yv), 1}, yw])/8 + 
     (G[{1, yu^(-1)}, yw]*G[{0, 1/(yu*yv), 1}, yw])/16 - 
     (3*G[{1, yu}, yv^(-1)]*G[{0, 1/(yu*yv), 1}, yw])/16 + 
     (G[{1, yv^(-1)}, yw]*G[{0, 1/(yu*yv), 1}, yw])/16 + 
     (G[{yu^(-1), 1/(yu*yv)}, yw]*G[{0, 1/(yu*yv), 1}, yw])/16 + 
     (G[{yv^(-1), 1/(yu*yv)}, yw]*G[{0, 1/(yu*yv), 1}, yw])/16 + 
     (G[{0}, yu^(-1)]^2*G[{0, 1/(yu*yv), yu^(-1)}, yw])/32 + 
     (G[{0}, yu^(-1)]*G[{0}, yv^(-1)]*G[{0, 1/(yu*yv), yu^(-1)}, yw])/16 + 
     (G[{0}, yv^(-1)]^2*G[{0, 1/(yu*yv), yu^(-1)}, yw])/32 - 
     (G[{0}, yu^(-1)]*G[{0}, yw]*G[{0, 1/(yu*yv), yu^(-1)}, yw])/16 - 
     (G[{0}, yv^(-1)]*G[{0}, yw]*G[{0, 1/(yu*yv), yu^(-1)}, yw])/16 + 
     (G[{0}, yw]^2*G[{0, 1/(yu*yv), yu^(-1)}, yw])/32 + 
     (G[{0}, yu^(-1)]*G[{1}, yu^(-1)]*G[{0, 1/(yu*yv), yu^(-1)}, yw])/8 + 
     (G[{0}, yv^(-1)]*G[{1}, yu^(-1)]*G[{0, 1/(yu*yv), yu^(-1)}, yw])/8 - 
     (G[{0}, yw]*G[{1}, yu^(-1)]*G[{0, 1/(yu*yv), yu^(-1)}, yw])/8 - 
     (G[{1}, yu^(-1)]^2*G[{0, 1/(yu*yv), yu^(-1)}, yw])/16 - 
     (G[{0}, yu^(-1)]*G[{1}, yv^(-1)]*G[{0, 1/(yu*yv), yu^(-1)}, yw])/8 - 
     (G[{0}, yv^(-1)]*G[{1}, yv^(-1)]*G[{0, 1/(yu*yv), yu^(-1)}, yw])/8 + 
     (G[{0}, yw]*G[{1}, yv^(-1)]*G[{0, 1/(yu*yv), yu^(-1)}, yw])/8 - 
     (G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*G[{0, 1/(yu*yv), yu^(-1)}, yw])/8 + 
     (3*G[{1}, yv^(-1)]^2*G[{0, 1/(yu*yv), yu^(-1)}, yw])/32 - 
     (G[{0}, yu^(-1)]*G[{1}, yw]*G[{0, 1/(yu*yv), yu^(-1)}, yw])/8 - 
     (G[{0}, yv^(-1)]*G[{1}, yw]*G[{0, 1/(yu*yv), yu^(-1)}, yw])/8 + 
     (G[{0}, yw]*G[{1}, yw]*G[{0, 1/(yu*yv), yu^(-1)}, yw])/8 - 
     (G[{1}, yu^(-1)]*G[{1}, yw]*G[{0, 1/(yu*yv), yu^(-1)}, yw])/8 + 
     (G[{1}, yv^(-1)]*G[{1}, yw]*G[{0, 1/(yu*yv), yu^(-1)}, yw])/8 - 
     (G[{1}, yw]^2*G[{0, 1/(yu*yv), yu^(-1)}, yw])/8 - 
     (G[{0}, yu^(-1)]*G[{yu}, yv^(-1)]*G[{0, 1/(yu*yv), yu^(-1)}, yw])/8 - 
     (G[{0}, yv^(-1)]*G[{yu}, yv^(-1)]*G[{0, 1/(yu*yv), yu^(-1)}, yw])/8 + 
     (G[{0}, yw]*G[{yu}, yv^(-1)]*G[{0, 1/(yu*yv), yu^(-1)}, yw])/8 + 
     (G[{1}, yv^(-1)]*G[{yu}, yv^(-1)]*G[{0, 1/(yu*yv), yu^(-1)}, yw])/4 + 
     (G[{1}, yw]*G[{yu}, yv^(-1)]*G[{0, 1/(yu*yv), yu^(-1)}, yw])/4 + 
     (G[{0}, yu^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv), yu^(-1)}, yw])/8 + 
     (G[{0}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv), yu^(-1)}, yw])/8 - 
     (G[{0}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv), yu^(-1)}, yw])/8 + 
     (G[{1}, yu^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv), yu^(-1)}, yw])/8 - 
     (G[{1}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv), yu^(-1)}, yw])/8 + 
     (G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv), yu^(-1)}, yw])/4 + 
     (G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv), yu^(-1)}, yw])/8 - 
     (G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv), yu^(-1)}, yw])/4 - 
     (G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv), yu^(-1)}, yw])/4 - 
     (G[{0, 1}, yv^(-1)]*G[{0, 1/(yu*yv), yu^(-1)}, yw])/16 - 
     (G[{0, 1}, yw]*G[{0, 1/(yu*yv), yu^(-1)}, yw])/8 + 
     (G[{0, yu^(-1)}, yw]*G[{0, 1/(yu*yv), yu^(-1)}, yw])/8 + 
     (G[{0, yu}, yv^(-1)]*G[{0, 1/(yu*yv), yu^(-1)}, yw])/16 + 
     (G[{0, yv^(-1)}, yw]*G[{0, 1/(yu*yv), yu^(-1)}, yw])/8 - 
     (G[{0, 1/(yu*yv)}, yw]*G[{0, 1/(yu*yv), yu^(-1)}, yw])/8 - 
     (G[{1, yu^(-1)}, yw]*G[{0, 1/(yu*yv), yu^(-1)}, yw])/8 - 
     (G[{1, yu}, yv^(-1)]*G[{0, 1/(yu*yv), yu^(-1)}, yw])/16 + 
     (G[{1, yv^(-1)}, yw]*G[{0, 1/(yu*yv), yu^(-1)}, yw])/4 - 
     (G[{1, 1/(yu*yv)}, yw]*G[{0, 1/(yu*yv), yu^(-1)}, yw])/4 - 
     (G[{yu^(-1), 1/(yu*yv)}, yw]*G[{0, 1/(yu*yv), yu^(-1)}, yw])/8 + 
     (G[{yv^(-1), 1/(yu*yv)}, yw]*G[{0, 1/(yu*yv), yu^(-1)}, yw])/4 - 
     (Pi^2*G[{0, 1/(yu*yv), yv^(-1)}, yw])/32 + 
     (G[{0}, yu^(-1)]^2*G[{0, 1/(yu*yv), yv^(-1)}, yw])/32 + 
     (G[{0}, yu^(-1)]*G[{0}, yv^(-1)]*G[{0, 1/(yu*yv), yv^(-1)}, yw])/16 + 
     (G[{0}, yv^(-1)]^2*G[{0, 1/(yu*yv), yv^(-1)}, yw])/32 - 
     (G[{0}, yu^(-1)]*G[{0}, yw]*G[{0, 1/(yu*yv), yv^(-1)}, yw])/16 - 
     (G[{0}, yv^(-1)]*G[{0}, yw]*G[{0, 1/(yu*yv), yv^(-1)}, yw])/16 + 
     (G[{0}, yw]^2*G[{0, 1/(yu*yv), yv^(-1)}, yw])/32 + 
     (G[{0}, yu^(-1)]*G[{1}, yu^(-1)]*G[{0, 1/(yu*yv), yv^(-1)}, yw])/16 + 
     (G[{0}, yv^(-1)]*G[{1}, yu^(-1)]*G[{0, 1/(yu*yv), yv^(-1)}, yw])/16 - 
     (G[{0}, yw]*G[{1}, yu^(-1)]*G[{0, 1/(yu*yv), yv^(-1)}, yw])/16 - 
     (3*G[{1}, yu^(-1)]^2*G[{0, 1/(yu*yv), yv^(-1)}, yw])/16 - 
     (G[{0}, yu^(-1)]*G[{1}, yv^(-1)]*G[{0, 1/(yu*yv), yv^(-1)}, yw])/16 - 
     (G[{0}, yv^(-1)]*G[{1}, yv^(-1)]*G[{0, 1/(yu*yv), yv^(-1)}, yw])/16 + 
     (G[{0}, yw]*G[{1}, yv^(-1)]*G[{0, 1/(yu*yv), yv^(-1)}, yw])/16 + 
     (G[{1}, yv^(-1)]^2*G[{0, 1/(yu*yv), yv^(-1)}, yw])/32 - 
     (G[{0}, yu^(-1)]*G[{1}, yw]*G[{0, 1/(yu*yv), yv^(-1)}, yw])/8 - 
     (G[{0}, yv^(-1)]*G[{1}, yw]*G[{0, 1/(yu*yv), yv^(-1)}, yw])/8 + 
     (G[{0}, yw]*G[{1}, yw]*G[{0, 1/(yu*yv), yv^(-1)}, yw])/8 - 
     (G[{1}, yu^(-1)]*G[{1}, yw]*G[{0, 1/(yu*yv), yv^(-1)}, yw])/4 + 
     (G[{1}, yv^(-1)]*G[{1}, yw]*G[{0, 1/(yu*yv), yv^(-1)}, yw])/4 - 
     (G[{1}, yw]^2*G[{0, 1/(yu*yv), yv^(-1)}, yw])/8 - 
     (G[{0}, yu^(-1)]*G[{yu}, yv^(-1)]*G[{0, 1/(yu*yv), yv^(-1)}, yw])/8 - 
     (G[{0}, yv^(-1)]*G[{yu}, yv^(-1)]*G[{0, 1/(yu*yv), yv^(-1)}, yw])/8 + 
     (G[{0}, yw]*G[{yu}, yv^(-1)]*G[{0, 1/(yu*yv), yv^(-1)}, yw])/8 + 
     (G[{1}, yu^(-1)]*G[{yu}, yv^(-1)]*G[{0, 1/(yu*yv), yv^(-1)}, yw])/4 + 
     (G[{1}, yw]*G[{yu}, yv^(-1)]*G[{0, 1/(yu*yv), yv^(-1)}, yw])/4 + 
     (G[{0}, yu^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv), yv^(-1)}, yw])/8 + 
     (G[{0}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv), yv^(-1)}, yw])/8 - 
     (G[{0}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv), yv^(-1)}, yw])/8 + 
     (G[{1}, yu^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv), yv^(-1)}, yw])/4 - 
     (G[{1}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv), yv^(-1)}, yw])/4 + 
     (G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv), yv^(-1)}, yw])/4 + 
     (G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv), yv^(-1)}, yw])/8 - 
     (G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv), yv^(-1)}, yw])/4 - 
     (G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv), yv^(-1)}, yw])/4 - 
     (G[{0, 1}, yu^(-1)]*G[{0, 1/(yu*yv), yv^(-1)}, yw])/16 + 
     (G[{0, 1}, yw]*G[{0, 1/(yu*yv), yv^(-1)}, yw])/16 - 
     (G[{0, yu^(-1)}, yw]*G[{0, 1/(yu*yv), yv^(-1)}, yw])/16 - 
     (G[{0, yv^(-1)}, yw]*G[{0, 1/(yu*yv), yv^(-1)}, yw])/16 + 
     (G[{0, 1/(yu*yv)}, yw]*G[{0, 1/(yu*yv), yv^(-1)}, yw])/16 - 
     (G[{1, yu^(-1)}, yw]*G[{0, 1/(yu*yv), yv^(-1)}, yw])/8 + 
     (G[{1, yu}, yv^(-1)]*G[{0, 1/(yu*yv), yv^(-1)}, yw])/16 + 
     (G[{1, yv^(-1)}, yw]*G[{0, 1/(yu*yv), yv^(-1)}, yw])/4 - 
     (G[{1, 1/(yu*yv)}, yw]*G[{0, 1/(yu*yv), yv^(-1)}, yw])/4 - 
     (G[{yu^(-1), 1/(yu*yv)}, yw]*G[{0, 1/(yu*yv), yv^(-1)}, yw])/8 + 
     (G[{yv^(-1), 1/(yu*yv)}, yw]*G[{0, 1/(yu*yv), yv^(-1)}, yw])/4 + 
     (Pi^2*G[{0, 1/(yu*yv), 1/(yu*yv)}, yw])/48 - 
     (G[{0}, yu^(-1)]^2*G[{0, 1/(yu*yv), 1/(yu*yv)}, yw])/16 - 
     (G[{0}, yu^(-1)]*G[{0}, yv^(-1)]*G[{0, 1/(yu*yv), 1/(yu*yv)}, yw])/8 - 
     (G[{0}, yv^(-1)]^2*G[{0, 1/(yu*yv), 1/(yu*yv)}, yw])/16 + 
     (G[{0}, yu^(-1)]*G[{0}, yw]*G[{0, 1/(yu*yv), 1/(yu*yv)}, yw])/8 + 
     (G[{0}, yv^(-1)]*G[{0}, yw]*G[{0, 1/(yu*yv), 1/(yu*yv)}, yw])/8 - 
     (G[{0}, yw]^2*G[{0, 1/(yu*yv), 1/(yu*yv)}, yw])/16 - 
     (3*G[{0}, yu^(-1)]*G[{1}, yu^(-1)]*G[{0, 1/(yu*yv), 1/(yu*yv)}, yw])/
      16 - (3*G[{0}, yv^(-1)]*G[{1}, yu^(-1)]*G[{0, 1/(yu*yv), 1/(yu*yv)}, 
        yw])/16 + (3*G[{0}, yw]*G[{1}, yu^(-1)]*G[{0, 1/(yu*yv), 1/(yu*yv)}, 
        yw])/16 + (11*G[{1}, yu^(-1)]^2*G[{0, 1/(yu*yv), 1/(yu*yv)}, yw])/
      32 + (3*G[{0}, yu^(-1)]*G[{1}, yv^(-1)]*G[{0, 1/(yu*yv), 1/(yu*yv)}, 
        yw])/16 + (3*G[{0}, yv^(-1)]*G[{1}, yv^(-1)]*
       G[{0, 1/(yu*yv), 1/(yu*yv)}, yw])/16 - 
     (3*G[{0}, yw]*G[{1}, yv^(-1)]*G[{0, 1/(yu*yv), 1/(yu*yv)}, yw])/16 + 
     (G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*G[{0, 1/(yu*yv), 1/(yu*yv)}, yw])/16 - 
     (G[{1}, yv^(-1)]^2*G[{0, 1/(yu*yv), 1/(yu*yv)}, yw])/8 + 
     (G[{0}, yu^(-1)]*G[{1}, yw]*G[{0, 1/(yu*yv), 1/(yu*yv)}, yw])/16 + 
     (G[{0}, yv^(-1)]*G[{1}, yw]*G[{0, 1/(yu*yv), 1/(yu*yv)}, yw])/16 - 
     (G[{0}, yw]*G[{1}, yw]*G[{0, 1/(yu*yv), 1/(yu*yv)}, yw])/16 - 
     (G[{1}, yu^(-1)]*G[{1}, yw]*G[{0, 1/(yu*yv), 1/(yu*yv)}, yw])/16 - 
     (G[{1}, yv^(-1)]*G[{1}, yw]*G[{0, 1/(yu*yv), 1/(yu*yv)}, yw])/16 + 
     (G[{0}, yu^(-1)]*G[{yu}, yv^(-1)]*G[{0, 1/(yu*yv), 1/(yu*yv)}, yw])/4 + 
     (G[{0}, yv^(-1)]*G[{yu}, yv^(-1)]*G[{0, 1/(yu*yv), 1/(yu*yv)}, yw])/4 - 
     (G[{0}, yw]*G[{yu}, yv^(-1)]*G[{0, 1/(yu*yv), 1/(yu*yv)}, yw])/4 - 
     (3*G[{1}, yu^(-1)]*G[{yu}, yv^(-1)]*G[{0, 1/(yu*yv), 1/(yu*yv)}, yw])/
      8 - (3*G[{1}, yv^(-1)]*G[{yu}, yv^(-1)]*G[{0, 1/(yu*yv), 1/(yu*yv)}, 
        yw])/8 + (G[{yu}, yv^(-1)]^2*G[{0, 1/(yu*yv), 1/(yu*yv)}, yw])/8 - 
     (G[{0}, yu^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv), 1/(yu*yv)}, yw])/
      16 - (G[{0}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv), 1/(yu*yv)}, 
        yw])/16 + (G[{0}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv), 1/(yu*yv)}, 
        yw])/16 + (G[{1}, yu^(-1)]*G[{1/(yu*yv)}, yw]*
       G[{0, 1/(yu*yv), 1/(yu*yv)}, yw])/16 + 
     (G[{1}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv), 1/(yu*yv)}, yw])/
      16 - (G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv), 1/(yu*yv)}, 
        yw])/16 - (G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*
       G[{0, 1/(yu*yv), 1/(yu*yv)}, yw])/16 - 
     (G[{0, 1}, yu^(-1)]*G[{0, 1/(yu*yv), 1/(yu*yv)}, yw])/16 + 
     (G[{0, 1}, yv^(-1)]*G[{0, 1/(yu*yv), 1/(yu*yv)}, yw])/8 + 
     (G[{0, 1}, yw]*G[{0, 1/(yu*yv), 1/(yu*yv)}, yw])/8 - 
     (G[{0, yu^(-1)}, yw]*G[{0, 1/(yu*yv), 1/(yu*yv)}, yw])/8 - 
     (G[{0, yu}, yv^(-1)]*G[{0, 1/(yu*yv), 1/(yu*yv)}, yw])/8 - 
     (G[{0, yv^(-1)}, yw]*G[{0, 1/(yu*yv), 1/(yu*yv)}, yw])/8 + 
     (G[{0, 1/(yu*yv)}, yw]*G[{0, 1/(yu*yv), 1/(yu*yv)}, yw])/8 + 
     (G[{1, yu^(-1)}, yw]*G[{0, 1/(yu*yv), 1/(yu*yv)}, yw])/16 + 
     (3*G[{1, yu}, yv^(-1)]*G[{0, 1/(yu*yv), 1/(yu*yv)}, yw])/16 + 
     (G[{1, yv^(-1)}, yw]*G[{0, 1/(yu*yv), 1/(yu*yv)}, yw])/16 + 
     (G[{yu^(-1), 1/(yu*yv)}, yw]*G[{0, 1/(yu*yv), 1/(yu*yv)}, yw])/16 + 
     (G[{yv^(-1), 1/(yu*yv)}, yw]*G[{0, 1/(yu*yv), 1/(yu*yv)}, yw])/16 + 
     (Pi^2*G[{1, 1, yu^(-1)}, yw])/24 - 
     (3*G[{0}, yu^(-1)]^2*G[{1, 1, yu^(-1)}, yw])/32 - 
     (3*G[{0}, yu^(-1)]*G[{0}, yv^(-1)]*G[{1, 1, yu^(-1)}, yw])/16 - 
     (3*G[{0}, yv^(-1)]^2*G[{1, 1, yu^(-1)}, yw])/32 + 
     (3*G[{0}, yu^(-1)]*G[{0}, yw]*G[{1, 1, yu^(-1)}, yw])/16 + 
     (3*G[{0}, yv^(-1)]*G[{0}, yw]*G[{1, 1, yu^(-1)}, yw])/16 - 
     (3*G[{0}, yw]^2*G[{1, 1, yu^(-1)}, yw])/32 + 
     (G[{1}, yu^(-1)]^2*G[{1, 1, yu^(-1)}, yw])/16 + 
     (G[{0}, yu^(-1)]*G[{1}, yv^(-1)]*G[{1, 1, yu^(-1)}, yw])/8 + 
     (G[{0}, yv^(-1)]*G[{1}, yv^(-1)]*G[{1, 1, yu^(-1)}, yw])/8 - 
     (G[{0}, yw]*G[{1}, yv^(-1)]*G[{1, 1, yu^(-1)}, yw])/8 + 
     (G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*G[{1, 1, yu^(-1)}, yw])/8 - 
     (G[{1}, yv^(-1)]^2*G[{1, 1, yu^(-1)}, yw])/32 - 
     (G[{0}, yu^(-1)]*G[{1}, yw]*G[{1, 1, yu^(-1)}, yw])/4 - 
     (G[{0}, yv^(-1)]*G[{1}, yw]*G[{1, 1, yu^(-1)}, yw])/4 + 
     (G[{0}, yw]*G[{1}, yw]*G[{1, 1, yu^(-1)}, yw])/4 + 
     (G[{1}, yu^(-1)]*G[{1}, yw]*G[{1, 1, yu^(-1)}, yw])/8 + 
     (3*G[{1}, yv^(-1)]*G[{1}, yw]*G[{1, 1, yu^(-1)}, yw])/16 - 
     (3*G[{1}, yw]^2*G[{1, 1, yu^(-1)}, yw])/32 + 
     (G[{0}, yu^(-1)]*G[{yu}, yv^(-1)]*G[{1, 1, yu^(-1)}, yw])/4 + 
     (G[{0}, yv^(-1)]*G[{yu}, yv^(-1)]*G[{1, 1, yu^(-1)}, yw])/4 - 
     (G[{0}, yw]*G[{yu}, yv^(-1)]*G[{1, 1, yu^(-1)}, yw])/4 - 
     (G[{1}, yu^(-1)]*G[{yu}, yv^(-1)]*G[{1, 1, yu^(-1)}, yw])/4 - 
     (3*G[{1}, yv^(-1)]*G[{yu}, yv^(-1)]*G[{1, 1, yu^(-1)}, yw])/16 + 
     (3*G[{1}, yw]*G[{yu}, yv^(-1)]*G[{1, 1, yu^(-1)}, yw])/16 - 
     (G[{yu}, yv^(-1)]^2*G[{1, 1, yu^(-1)}, yw])/32 + 
     (G[{1}, yu^(-1)]*G[{1/(yu*yv)}, yw]*G[{1, 1, yu^(-1)}, yw])/16 + 
     (G[{1}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{1, 1, yu^(-1)}, yw])/16 + 
     (G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{1, 1, yu^(-1)}, yw])/8 + 
     (G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{1, 1, yu^(-1)}, yw])/16 - 
     (G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{1, 1, yu^(-1)}, yw])/8 - 
     (G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{1, 1, yu^(-1)}, yw])/16 + 
     (G[{0, 1}, yu^(-1)]*G[{1, 1, yu^(-1)}, yw])/8 - 
     (G[{1, yu^(-1)}, yw]*G[{1, 1, yu^(-1)}, yw])/16 - 
     (G[{1, yu}, yv^(-1)]*G[{1, 1, yu^(-1)}, yw])/8 + 
     (G[{1, yv^(-1)}, yw]*G[{1, 1, yu^(-1)}, yw])/16 - 
     (G[{yu^(-1), 1/(yu*yv)}, yw]*G[{1, 1, yu^(-1)}, yw])/16 + 
     (G[{yv^(-1), 1/(yu*yv)}, yw]*G[{1, 1, yu^(-1)}, yw])/16 - 
     (5*Pi^2*G[{1, 1, yu}, yv^(-1)])/768 - 
     (G[{1}, yu^(-1)]^2*G[{1, 1, yu}, yv^(-1)])/32 - 
     (5*G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*G[{1, 1, yu}, yv^(-1)])/64 - 
     (3*G[{1}, yv^(-1)]^2*G[{1, 1, yu}, yv^(-1)])/128 - 
     (7*G[{1}, yv^(-1)]*G[{1}, yw]*G[{1, 1, yu}, yv^(-1)])/64 - 
     (5*G[{1}, yw]^2*G[{1, 1, yu}, yv^(-1)])/128 + 
     (5*G[{1}, yw]*G[{yu}, yv^(-1)]*G[{1, 1, yu}, yv^(-1)])/64 + 
     (7*G[{1}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{1, 1, yu}, yv^(-1)])/64 + 
     (5*G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{1, 1, yu}, yv^(-1)])/64 + 
     (G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{1, 1, yu}, yv^(-1)])/64 - 
     (5*G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{1, 1, yu}, yv^(-1)])/64 - 
     (3*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{1, 1, yu}, yv^(-1)])/32 + 
     (3*G[{0, 1}, yu^(-1)]*G[{1, 1, yu}, yv^(-1)])/64 - 
     (9*G[{0, 1}, yv^(-1)]*G[{1, 1, yu}, yv^(-1)])/64 + 
     (9*G[{0, yu}, yv^(-1)]*G[{1, 1, yu}, yv^(-1)])/64 - 
     (G[{1, yu^(-1)}, yw]*G[{1, 1, yu}, yv^(-1)])/64 + 
     (G[{1, yu}, yv^(-1)]*G[{1, 1, yu}, yv^(-1)])/64 + 
     (3*G[{1, yv^(-1)}, yw]*G[{1, 1, yu}, yv^(-1)])/32 - 
     (5*G[{1, 1/(yu*yv)}, yw]*G[{1, 1, yu}, yv^(-1)])/64 - 
     (G[{yu^(-1), 1/(yu*yv)}, yw]*G[{1, 1, yu}, yv^(-1)])/64 + 
     (3*G[{yv^(-1), 1/(yu*yv)}, yw]*G[{1, 1, yu}, yv^(-1)])/32 + 
     (5*Pi^2*G[{1, 1, yv^(-1)}, yw])/192 - 
     (3*G[{0}, yu^(-1)]^2*G[{1, 1, yv^(-1)}, yw])/32 - 
     (3*G[{0}, yu^(-1)]*G[{0}, yv^(-1)]*G[{1, 1, yv^(-1)}, yw])/16 - 
     (3*G[{0}, yv^(-1)]^2*G[{1, 1, yv^(-1)}, yw])/32 + 
     (3*G[{0}, yu^(-1)]*G[{0}, yw]*G[{1, 1, yv^(-1)}, yw])/16 + 
     (3*G[{0}, yv^(-1)]*G[{0}, yw]*G[{1, 1, yv^(-1)}, yw])/16 - 
     (3*G[{0}, yw]^2*G[{1, 1, yv^(-1)}, yw])/32 - 
     (G[{0}, yu^(-1)]*G[{1}, yu^(-1)]*G[{1, 1, yv^(-1)}, yw])/4 - 
     (G[{0}, yv^(-1)]*G[{1}, yu^(-1)]*G[{1, 1, yv^(-1)}, yw])/4 + 
     (G[{0}, yw]*G[{1}, yu^(-1)]*G[{1, 1, yv^(-1)}, yw])/4 + 
     (19*G[{1}, yu^(-1)]^2*G[{1, 1, yv^(-1)}, yw])/64 + 
     (3*G[{0}, yu^(-1)]*G[{1}, yv^(-1)]*G[{1, 1, yv^(-1)}, yw])/8 + 
     (3*G[{0}, yv^(-1)]*G[{1}, yv^(-1)]*G[{1, 1, yv^(-1)}, yw])/8 - 
     (3*G[{0}, yw]*G[{1}, yv^(-1)]*G[{1, 1, yv^(-1)}, yw])/8 + 
     (3*G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*G[{1, 1, yv^(-1)}, yw])/64 - 
     (33*G[{1}, yv^(-1)]^2*G[{1, 1, yv^(-1)}, yw])/128 - 
     (G[{0}, yu^(-1)]*G[{1}, yw]*G[{1, 1, yv^(-1)}, yw])/4 - 
     (G[{0}, yv^(-1)]*G[{1}, yw]*G[{1, 1, yv^(-1)}, yw])/4 + 
     (G[{0}, yw]*G[{1}, yw]*G[{1, 1, yv^(-1)}, yw])/4 + 
     (3*G[{1}, yu^(-1)]*G[{1}, yw]*G[{1, 1, yv^(-1)}, yw])/32 + 
     (15*G[{1}, yv^(-1)]*G[{1}, yw]*G[{1, 1, yv^(-1)}, yw])/64 - 
     (11*G[{1}, yw]^2*G[{1, 1, yv^(-1)}, yw])/128 + 
     (G[{0}, yu^(-1)]*G[{yu}, yv^(-1)]*G[{1, 1, yv^(-1)}, yw])/4 + 
     (G[{0}, yv^(-1)]*G[{yu}, yv^(-1)]*G[{1, 1, yv^(-1)}, yw])/4 - 
     (G[{0}, yw]*G[{yu}, yv^(-1)]*G[{1, 1, yv^(-1)}, yw])/4 - 
     (9*G[{1}, yu^(-1)]*G[{yu}, yv^(-1)]*G[{1, 1, yv^(-1)}, yw])/64 - 
     (G[{1}, yv^(-1)]*G[{yu}, yv^(-1)]*G[{1, 1, yv^(-1)}, yw])/4 + 
     (11*G[{1}, yw]*G[{yu}, yv^(-1)]*G[{1, 1, yv^(-1)}, yw])/64 - 
     (7*G[{yu}, yv^(-1)]^2*G[{1, 1, yv^(-1)}, yw])/128 + 
     (3*G[{0}, yu^(-1)]*G[{1/(yu*yv)}, yw]*G[{1, 1, yv^(-1)}, yw])/16 + 
     (3*G[{0}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{1, 1, yv^(-1)}, yw])/16 - 
     (3*G[{0}, yw]*G[{1/(yu*yv)}, yw]*G[{1, 1, yv^(-1)}, yw])/16 - 
     (5*G[{1}, yu^(-1)]*G[{1/(yu*yv)}, yw]*G[{1, 1, yv^(-1)}, yw])/64 - 
     (3*G[{1}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{1, 1, yv^(-1)}, yw])/64 + 
     (G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{1, 1, yv^(-1)}, yw])/4 + 
     (3*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{1, 1, yv^(-1)}, yw])/64 - 
     (G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{1, 1, yv^(-1)}, yw])/4 + 
     (5*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{1, 1, yv^(-1)}, yw])/32 - 
     (3*G[{1/(yu*yv)}, yw]^2*G[{1, 1, yv^(-1)}, yw])/64 + 
     (3*G[{0, 1}, yu^(-1)]*G[{1, 1, yv^(-1)}, yw])/64 + 
     (G[{0, 1}, yv^(-1)]*G[{1, 1, yv^(-1)}, yw])/64 - 
     (G[{0, yu}, yv^(-1)]*G[{1, 1, yv^(-1)}, yw])/64 - 
     (3*G[{1, yu^(-1)}, yw]*G[{1, 1, yv^(-1)}, yw])/64 - 
     (G[{1, yu}, yv^(-1)]*G[{1, 1, yv^(-1)}, yw])/32 - 
     (5*G[{1, yv^(-1)}, yw]*G[{1, 1, yv^(-1)}, yw])/32 - 
     (11*G[{1, 1/(yu*yv)}, yw]*G[{1, 1, yv^(-1)}, yw])/64 - 
     (3*G[{yu^(-1), 1/(yu*yv)}, yw]*G[{1, 1, yv^(-1)}, yw])/64 - 
     (5*G[{yv^(-1), 1/(yu*yv)}, yw]*G[{1, 1, yv^(-1)}, yw])/32 + 
     (Pi^2*G[{1, 1, 1/(yu*yv)}, yw])/64 + 
     (G[{0}, yu^(-1)]^2*G[{1, 1, 1/(yu*yv)}, yw])/16 + 
     (G[{0}, yu^(-1)]*G[{0}, yv^(-1)]*G[{1, 1, 1/(yu*yv)}, yw])/8 + 
     (G[{0}, yv^(-1)]^2*G[{1, 1, 1/(yu*yv)}, yw])/16 - 
     (G[{0}, yu^(-1)]*G[{0}, yw]*G[{1, 1, 1/(yu*yv)}, yw])/8 - 
     (G[{0}, yv^(-1)]*G[{0}, yw]*G[{1, 1, 1/(yu*yv)}, yw])/8 + 
     (G[{0}, yw]^2*G[{1, 1, 1/(yu*yv)}, yw])/16 - 
     (G[{0}, yu^(-1)]*G[{1}, yu^(-1)]*G[{1, 1, 1/(yu*yv)}, yw])/8 - 
     (G[{0}, yv^(-1)]*G[{1}, yu^(-1)]*G[{1, 1, 1/(yu*yv)}, yw])/8 + 
     (G[{0}, yw]*G[{1}, yu^(-1)]*G[{1, 1, 1/(yu*yv)}, yw])/8 - 
     (3*G[{1}, yu^(-1)]^2*G[{1, 1, 1/(yu*yv)}, yw])/64 - 
     (G[{0}, yu^(-1)]*G[{1}, yv^(-1)]*G[{1, 1, 1/(yu*yv)}, yw])/8 - 
     (G[{0}, yv^(-1)]*G[{1}, yv^(-1)]*G[{1, 1, 1/(yu*yv)}, yw])/8 + 
     (G[{0}, yw]*G[{1}, yv^(-1)]*G[{1, 1, 1/(yu*yv)}, yw])/8 + 
     (13*G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*G[{1, 1, 1/(yu*yv)}, yw])/64 + 
     (5*G[{1}, yv^(-1)]^2*G[{1, 1, 1/(yu*yv)}, yw])/128 - 
     (11*G[{1}, yu^(-1)]*G[{1}, yw]*G[{1, 1, 1/(yu*yv)}, yw])/32 - 
     (11*G[{1}, yv^(-1)]*G[{1}, yw]*G[{1, 1, 1/(yu*yv)}, yw])/64 - 
     (33*G[{1}, yw]^2*G[{1, 1, 1/(yu*yv)}, yw])/128 + 
     (9*G[{1}, yu^(-1)]*G[{yu}, yv^(-1)]*G[{1, 1, 1/(yu*yv)}, yw])/64 + 
     (3*G[{1}, yv^(-1)]*G[{yu}, yv^(-1)]*G[{1, 1, 1/(yu*yv)}, yw])/16 + 
     (33*G[{1}, yw]*G[{yu}, yv^(-1)]*G[{1, 1, 1/(yu*yv)}, yw])/64 - 
     (21*G[{yu}, yv^(-1)]^2*G[{1, 1, 1/(yu*yv)}, yw])/128 + 
     (G[{0}, yu^(-1)]*G[{1/(yu*yv)}, yw]*G[{1, 1, 1/(yu*yv)}, yw])/16 + 
     (G[{0}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{1, 1, 1/(yu*yv)}, yw])/16 - 
     (G[{0}, yw]*G[{1/(yu*yv)}, yw]*G[{1, 1, 1/(yu*yv)}, yw])/16 - 
     (7*G[{1}, yu^(-1)]*G[{1/(yu*yv)}, yw]*G[{1, 1, 1/(yu*yv)}, yw])/64 - 
     (9*G[{1}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{1, 1, 1/(yu*yv)}, yw])/64 - 
     (G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{1, 1, 1/(yu*yv)}, yw])/8 + 
     (G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{1, 1, 1/(yu*yv)}, yw])/64 + 
     (G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{1, 1, 1/(yu*yv)}, yw])/8 + 
     (G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{1, 1, 1/(yu*yv)}, yw])/32 + 
     (3*G[{1/(yu*yv)}, yw]^2*G[{1, 1, 1/(yu*yv)}, yw])/64 + 
     (13*G[{0, 1}, yu^(-1)]*G[{1, 1, 1/(yu*yv)}, yw])/64 - 
     (G[{0, 1}, yv^(-1)]*G[{1, 1, 1/(yu*yv)}, yw])/64 + 
     (G[{0, yu}, yv^(-1)]*G[{1, 1, 1/(yu*yv)}, yw])/64 - 
     (G[{1, yu^(-1)}, yw]*G[{1, 1, 1/(yu*yv)}, yw])/64 - 
     (7*G[{1, yu}, yv^(-1)]*G[{1, 1, 1/(yu*yv)}, yw])/32 - 
     (G[{1, yv^(-1)}, yw]*G[{1, 1, 1/(yu*yv)}, yw])/32 + 
     (11*G[{1, 1/(yu*yv)}, yw]*G[{1, 1, 1/(yu*yv)}, yw])/64 - 
     (G[{yu^(-1), 1/(yu*yv)}, yw]*G[{1, 1, 1/(yu*yv)}, yw])/64 - 
     (G[{yv^(-1), 1/(yu*yv)}, yw]*G[{1, 1, 1/(yu*yv)}, yw])/32 + 
     (Pi^2*G[{1, yu^(-1), yu^(-1)}, yw])/96 - 
     (G[{0}, yu^(-1)]^2*G[{1, yu^(-1), yu^(-1)}, yw])/16 - 
     (G[{0}, yu^(-1)]*G[{0}, yv^(-1)]*G[{1, yu^(-1), yu^(-1)}, yw])/8 - 
     (G[{0}, yv^(-1)]^2*G[{1, yu^(-1), yu^(-1)}, yw])/16 + 
     (G[{0}, yu^(-1)]*G[{0}, yw]*G[{1, yu^(-1), yu^(-1)}, yw])/8 + 
     (G[{0}, yv^(-1)]*G[{0}, yw]*G[{1, yu^(-1), yu^(-1)}, yw])/8 - 
     (G[{0}, yw]^2*G[{1, yu^(-1), yu^(-1)}, yw])/16 - 
     (G[{0}, yu^(-1)]*G[{1}, yu^(-1)]*G[{1, yu^(-1), yu^(-1)}, yw])/8 - 
     (G[{0}, yv^(-1)]*G[{1}, yu^(-1)]*G[{1, yu^(-1), yu^(-1)}, yw])/8 + 
     (G[{0}, yw]*G[{1}, yu^(-1)]*G[{1, yu^(-1), yu^(-1)}, yw])/8 + 
     (G[{1}, yu^(-1)]^2*G[{1, yu^(-1), yu^(-1)}, yw])/32 + 
     (G[{0}, yu^(-1)]*G[{1}, yv^(-1)]*G[{1, yu^(-1), yu^(-1)}, yw])/8 + 
     (G[{0}, yv^(-1)]*G[{1}, yv^(-1)]*G[{1, yu^(-1), yu^(-1)}, yw])/8 - 
     (G[{0}, yw]*G[{1}, yv^(-1)]*G[{1, yu^(-1), yu^(-1)}, yw])/8 + 
     (3*G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*G[{1, yu^(-1), yu^(-1)}, yw])/16 - 
     (G[{1}, yv^(-1)]^2*G[{1, yu^(-1), yu^(-1)}, yw])/16 - 
     (G[{0}, yu^(-1)]*G[{1}, yw]*G[{1, yu^(-1), yu^(-1)}, yw])/8 - 
     (G[{0}, yv^(-1)]*G[{1}, yw]*G[{1, yu^(-1), yu^(-1)}, yw])/8 + 
     (G[{0}, yw]*G[{1}, yw]*G[{1, yu^(-1), yu^(-1)}, yw])/8 - 
     (3*G[{1}, yu^(-1)]*G[{1}, yw]*G[{1, yu^(-1), yu^(-1)}, yw])/16 + 
     (G[{1}, yv^(-1)]*G[{1}, yw]*G[{1, yu^(-1), yu^(-1)}, yw])/8 - 
     (5*G[{1}, yw]^2*G[{1, yu^(-1), yu^(-1)}, yw])/32 + 
     (G[{0}, yu^(-1)]*G[{yu}, yv^(-1)]*G[{1, yu^(-1), yu^(-1)}, yw])/4 + 
     (G[{0}, yv^(-1)]*G[{yu}, yv^(-1)]*G[{1, yu^(-1), yu^(-1)}, yw])/4 - 
     (G[{0}, yw]*G[{yu}, yv^(-1)]*G[{1, yu^(-1), yu^(-1)}, yw])/4 - 
     (3*G[{1}, yv^(-1)]*G[{yu}, yv^(-1)]*G[{1, yu^(-1), yu^(-1)}, yw])/8 + 
     (5*G[{1}, yw]*G[{yu}, yv^(-1)]*G[{1, yu^(-1), yu^(-1)}, yw])/16 - 
     (G[{yu}, yv^(-1)]^2*G[{1, yu^(-1), yu^(-1)}, yw])/16 + 
     (G[{0}, yu^(-1)]*G[{1/(yu*yv)}, yw]*G[{1, yu^(-1), yu^(-1)}, yw])/4 + 
     (G[{0}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{1, yu^(-1), yu^(-1)}, yw])/4 - 
     (G[{0}, yw]*G[{1/(yu*yv)}, yw]*G[{1, yu^(-1), yu^(-1)}, yw])/4 + 
     (3*G[{1}, yu^(-1)]*G[{1/(yu*yv)}, yw]*G[{1, yu^(-1), yu^(-1)}, yw])/16 - 
     (3*G[{1}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{1, yu^(-1), yu^(-1)}, yw])/16 + 
     (G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{1, yu^(-1), yu^(-1)}, yw])/2 + 
     (3*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{1, yu^(-1), yu^(-1)}, yw])/
      16 - (G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{1, yu^(-1), yu^(-1)}, yw])/
      2 - (5*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{1, yu^(-1), yu^(-1)}, 
        yw])/16 + (G[{0, 1}, yu^(-1)]*G[{1, yu^(-1), yu^(-1)}, yw])/16 + 
     (G[{0, 1}, yv^(-1)]*G[{1, yu^(-1), yu^(-1)}, yw])/8 + 
     (G[{0, 1}, yw]*G[{1, yu^(-1), yu^(-1)}, yw])/8 - 
     (G[{0, yu^(-1)}, yw]*G[{1, yu^(-1), yu^(-1)}, yw])/8 - 
     (G[{0, yu}, yv^(-1)]*G[{1, yu^(-1), yu^(-1)}, yw])/8 - 
     (G[{0, yv^(-1)}, yw]*G[{1, yu^(-1), yu^(-1)}, yw])/8 + 
     (G[{0, 1/(yu*yv)}, yw]*G[{1, yu^(-1), yu^(-1)}, yw])/8 + 
     (G[{1, yu^(-1)}, yw]*G[{1, yu^(-1), yu^(-1)}, yw])/4 + 
     (G[{1, yu}, yv^(-1)]*G[{1, yu^(-1), yu^(-1)}, yw])/16 + 
     (5*G[{1, yv^(-1)}, yw]*G[{1, yu^(-1), yu^(-1)}, yw])/16 - 
     (3*G[{1, 1/(yu*yv)}, yw]*G[{1, yu^(-1), yu^(-1)}, yw])/8 - 
     (3*G[{yu^(-1), 1/(yu*yv)}, yw]*G[{1, yu^(-1), yu^(-1)}, yw])/16 + 
     (5*G[{yv^(-1), 1/(yu*yv)}, yw]*G[{1, yu^(-1), yu^(-1)}, yw])/16 + 
     (3*G[{0}, yu^(-1)]*G[{1/(yu*yv)}, yw]*G[{1, yu^(-1), yv^(-1)}, yw])/16 + 
     (3*G[{0}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{1, yu^(-1), yv^(-1)}, yw])/16 - 
     (3*G[{0}, yw]*G[{1/(yu*yv)}, yw]*G[{1, yu^(-1), yv^(-1)}, yw])/16 + 
     (G[{1}, yu^(-1)]*G[{1/(yu*yv)}, yw]*G[{1, yu^(-1), yv^(-1)}, yw])/8 - 
     (G[{1}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{1, yu^(-1), yv^(-1)}, yw])/4 + 
     (G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{1, yu^(-1), yv^(-1)}, yw])/4 + 
     (G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{1, yu^(-1), yv^(-1)}, yw])/8 - 
     (G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{1, yu^(-1), yv^(-1)}, yw])/4 - 
     (G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{1, yu^(-1), yv^(-1)}, yw])/4 + 
     (G[{1, yv^(-1)}, yw]*G[{1, yu^(-1), yv^(-1)}, yw])/4 - 
     (G[{1, 1/(yu*yv)}, yw]*G[{1, yu^(-1), yv^(-1)}, yw])/4 - 
     (G[{yu^(-1), 1/(yu*yv)}, yw]*G[{1, yu^(-1), yv^(-1)}, yw])/8 + 
     (G[{yv^(-1), 1/(yu*yv)}, yw]*G[{1, yu^(-1), yv^(-1)}, yw])/4 + 
     (Pi^2*G[{1, yu^(-1), 1/(yu*yv)}, yw])/96 - 
     (G[{0}, yu^(-1)]^2*G[{1, yu^(-1), 1/(yu*yv)}, yw])/32 - 
     (G[{0}, yu^(-1)]*G[{0}, yv^(-1)]*G[{1, yu^(-1), 1/(yu*yv)}, yw])/16 - 
     (G[{0}, yv^(-1)]^2*G[{1, yu^(-1), 1/(yu*yv)}, yw])/32 + 
     (G[{0}, yu^(-1)]*G[{0}, yw]*G[{1, yu^(-1), 1/(yu*yv)}, yw])/16 + 
     (G[{0}, yv^(-1)]*G[{0}, yw]*G[{1, yu^(-1), 1/(yu*yv)}, yw])/16 - 
     (G[{0}, yw]^2*G[{1, yu^(-1), 1/(yu*yv)}, yw])/32 - 
     (G[{1}, yu^(-1)]^2*G[{1, yu^(-1), 1/(yu*yv)}, yw])/32 + 
     (G[{0}, yu^(-1)]*G[{1}, yv^(-1)]*G[{1, yu^(-1), 1/(yu*yv)}, yw])/8 + 
     (G[{0}, yv^(-1)]*G[{1}, yv^(-1)]*G[{1, yu^(-1), 1/(yu*yv)}, yw])/8 - 
     (G[{0}, yw]*G[{1}, yv^(-1)]*G[{1, yu^(-1), 1/(yu*yv)}, yw])/8 + 
     (G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*G[{1, yu^(-1), 1/(yu*yv)}, yw])/16 - 
     (3*G[{1}, yv^(-1)]^2*G[{1, yu^(-1), 1/(yu*yv)}, yw])/32 - 
     (G[{1}, yu^(-1)]*G[{1}, yw]*G[{1, yu^(-1), 1/(yu*yv)}, yw])/16 + 
     (G[{1}, yv^(-1)]*G[{1}, yw]*G[{1, yu^(-1), 1/(yu*yv)}, yw])/16 - 
     (G[{1}, yv^(-1)]*G[{yu}, yv^(-1)]*G[{1, yu^(-1), 1/(yu*yv)}, yw])/16 + 
     (G[{yu}, yv^(-1)]^2*G[{1, yu^(-1), 1/(yu*yv)}, yw])/32 - 
     (3*G[{0}, yu^(-1)]*G[{1/(yu*yv)}, yw]*G[{1, yu^(-1), 1/(yu*yv)}, yw])/
      16 - (3*G[{0}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{1, yu^(-1), 1/(yu*yv)}, 
        yw])/16 + (3*G[{0}, yw]*G[{1/(yu*yv)}, yw]*G[{1, yu^(-1), 1/(yu*yv)}, 
        yw])/16 + (G[{1}, yu^(-1)]*G[{1/(yu*yv)}, yw]*
       G[{1, yu^(-1), 1/(yu*yv)}, yw])/8 + 
     (G[{1}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{1, yu^(-1), 1/(yu*yv)}, yw])/8 - 
     (G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{1, yu^(-1), 1/(yu*yv)}, yw])/8 - 
     (G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{1, yu^(-1), 1/(yu*yv)}, yw])/8 + 
     (G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{1, yu^(-1), 1/(yu*yv)}, yw])/8 - 
     (G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{1, yu^(-1), 1/(yu*yv)}, yw])/8 + 
     (G[{0, 1}, yu^(-1)]*G[{1, yu^(-1), 1/(yu*yv)}, yw])/16 - 
     (G[{1, yu}, yv^(-1)]*G[{1, yu^(-1), 1/(yu*yv)}, yw])/16 + 
     (3*G[{1, yv^(-1)}, yw]*G[{1, yu^(-1), 1/(yu*yv)}, yw])/8 + 
     (G[{1, 1/(yu*yv)}, yw]*G[{1, yu^(-1), 1/(yu*yv)}, yw])/8 + 
     (G[{yu^(-1), 1/(yu*yv)}, yw]*G[{1, yu^(-1), 1/(yu*yv)}, yw])/8 + 
     (G[{yv^(-1), 1/(yu*yv)}, yw]*G[{1, yu^(-1), 1/(yu*yv)}, yw])/8 + 
     (5*Pi^2*G[{1, yu, yu}, yv^(-1)])/256 + 
     (5*G[{1}, yu^(-1)]^2*G[{1, yu, yu}, yv^(-1)])/64 + 
     (G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*G[{1, yu, yu}, yv^(-1)])/16 - 
     (3*G[{1}, yv^(-1)]^2*G[{1, yu, yu}, yv^(-1)])/64 + 
     (3*G[{1}, yu^(-1)]*G[{1}, yw]*G[{1, yu, yu}, yv^(-1)])/64 - 
     (G[{1}, yv^(-1)]*G[{1}, yw]*G[{1, yu, yu}, yv^(-1)])/32 + 
     (G[{1}, yw]^2*G[{1, yu, yu}, yv^(-1)])/32 + 
     (G[{1}, yw]*G[{yu}, yv^(-1)]*G[{1, yu, yu}, yv^(-1)])/32 - 
     (3*G[{1}, yu^(-1)]*G[{1/(yu*yv)}, yw]*G[{1, yu, yu}, yv^(-1)])/64 + 
     (G[{1}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{1, yu, yu}, yv^(-1)])/32 - 
     (G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{1, yu, yu}, yv^(-1)])/16 + 
     (3*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{1, yu, yu}, yv^(-1)])/32 - 
     (G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{1, yu, yu}, yv^(-1)])/32 - 
     (G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{1, yu, yu}, yv^(-1)])/8 + 
     (3*G[{1/(yu*yv)}, yw]^2*G[{1, yu, yu}, yv^(-1)])/64 + 
     (G[{0, 1}, yu^(-1)]*G[{1, yu, yu}, yv^(-1)])/16 - 
     (G[{0, 1}, yv^(-1)]*G[{1, yu, yu}, yv^(-1)])/32 + 
     (G[{0, yu}, yv^(-1)]*G[{1, yu, yu}, yv^(-1)])/32 - 
     (3*G[{1, yu^(-1)}, yw]*G[{1, yu, yu}, yv^(-1)])/32 - 
     (3*G[{1, yu}, yv^(-1)]*G[{1, yu, yu}, yv^(-1)])/32 + 
     (G[{1, yv^(-1)}, yw]*G[{1, yu, yu}, yv^(-1)])/8 - 
     (G[{1, 1/(yu*yv)}, yw]*G[{1, yu, yu}, yv^(-1)])/32 - 
     (3*G[{yu^(-1), 1/(yu*yv)}, yw]*G[{1, yu, yu}, yv^(-1)])/32 + 
     (G[{yv^(-1), 1/(yu*yv)}, yw]*G[{1, yu, yu}, yv^(-1)])/8 + 
     (3*G[{0}, yu^(-1)]*G[{1/(yu*yv)}, yw]*G[{1, yv^(-1), yu^(-1)}, yw])/16 + 
     (3*G[{0}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{1, yv^(-1), yu^(-1)}, yw])/16 - 
     (3*G[{0}, yw]*G[{1/(yu*yv)}, yw]*G[{1, yv^(-1), yu^(-1)}, yw])/16 + 
     (G[{1}, yu^(-1)]*G[{1/(yu*yv)}, yw]*G[{1, yv^(-1), yu^(-1)}, yw])/8 - 
     (G[{1}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{1, yv^(-1), yu^(-1)}, yw])/4 + 
     (G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{1, yv^(-1), yu^(-1)}, yw])/4 + 
     (G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{1, yv^(-1), yu^(-1)}, yw])/8 - 
     (G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{1, yv^(-1), yu^(-1)}, yw])/4 - 
     (G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{1, yv^(-1), yu^(-1)}, yw])/4 - 
     (G[{1, 1/(yu*yv)}, yw]*G[{1, yv^(-1), yu^(-1)}, yw])/4 - 
     (G[{yu^(-1), 1/(yu*yv)}, yw]*G[{1, yv^(-1), yu^(-1)}, yw])/8 + 
     (G[{yv^(-1), 1/(yu*yv)}, yw]*G[{1, yv^(-1), yu^(-1)}, yw])/4 + 
     (41*Pi^2*G[{1, yv^(-1), yv^(-1)}, yw])/768 - 
     (G[{0}, yu^(-1)]^2*G[{1, yv^(-1), yv^(-1)}, yw])/16 - 
     (G[{0}, yu^(-1)]*G[{0}, yv^(-1)]*G[{1, yv^(-1), yv^(-1)}, yw])/8 - 
     (G[{0}, yv^(-1)]^2*G[{1, yv^(-1), yv^(-1)}, yw])/16 + 
     (G[{0}, yu^(-1)]*G[{0}, yw]*G[{1, yv^(-1), yv^(-1)}, yw])/8 + 
     (G[{0}, yv^(-1)]*G[{0}, yw]*G[{1, yv^(-1), yv^(-1)}, yw])/8 - 
     (G[{0}, yw]^2*G[{1, yv^(-1), yv^(-1)}, yw])/16 - 
     (G[{0}, yu^(-1)]*G[{1}, yu^(-1)]*G[{1, yv^(-1), yv^(-1)}, yw])/4 - 
     (G[{0}, yv^(-1)]*G[{1}, yu^(-1)]*G[{1, yv^(-1), yv^(-1)}, yw])/4 + 
     (G[{0}, yw]*G[{1}, yu^(-1)]*G[{1, yv^(-1), yv^(-1)}, yw])/4 + 
     (29*G[{1}, yu^(-1)]^2*G[{1, yv^(-1), yv^(-1)}, yw])/64 + 
     (G[{0}, yu^(-1)]*G[{1}, yv^(-1)]*G[{1, yv^(-1), yv^(-1)}, yw])/4 + 
     (G[{0}, yv^(-1)]*G[{1}, yv^(-1)]*G[{1, yv^(-1), yv^(-1)}, yw])/4 - 
     (G[{0}, yw]*G[{1}, yv^(-1)]*G[{1, yv^(-1), yv^(-1)}, yw])/4 - 
     (G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*G[{1, yv^(-1), yv^(-1)}, yw])/8 - 
     (9*G[{1}, yv^(-1)]^2*G[{1, yv^(-1), yv^(-1)}, yw])/64 - 
     (G[{0}, yu^(-1)]*G[{1}, yw]*G[{1, yv^(-1), yv^(-1)}, yw])/2 - 
     (G[{0}, yv^(-1)]*G[{1}, yw]*G[{1, yv^(-1), yv^(-1)}, yw])/2 + 
     (G[{0}, yw]*G[{1}, yw]*G[{1, yv^(-1), yv^(-1)}, yw])/2 + 
     (13*G[{1}, yu^(-1)]*G[{1}, yw]*G[{1, yv^(-1), yv^(-1)}, yw])/32 + 
     (7*G[{1}, yv^(-1)]*G[{1}, yw]*G[{1, yv^(-1), yv^(-1)}, yw])/32 - 
     (3*G[{1}, yw]^2*G[{1, yv^(-1), yv^(-1)}, yw])/16 + 
     (G[{0}, yu^(-1)]*G[{yu}, yv^(-1)]*G[{1, yv^(-1), yv^(-1)}, yw])/4 + 
     (G[{0}, yv^(-1)]*G[{yu}, yv^(-1)]*G[{1, yv^(-1), yv^(-1)}, yw])/4 - 
     (G[{0}, yw]*G[{yu}, yv^(-1)]*G[{1, yv^(-1), yv^(-1)}, yw])/4 - 
     (9*G[{1}, yu^(-1)]*G[{yu}, yv^(-1)]*G[{1, yv^(-1), yv^(-1)}, yw])/32 + 
     (3*G[{1}, yw]*G[{yu}, yv^(-1)]*G[{1, yv^(-1), yv^(-1)}, yw])/8 - 
     (7*G[{yu}, yv^(-1)]^2*G[{1, yv^(-1), yv^(-1)}, yw])/64 + 
     (G[{0}, yu^(-1)]*G[{1/(yu*yv)}, yw]*G[{1, yv^(-1), yv^(-1)}, yw])/4 + 
     (G[{0}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{1, yv^(-1), yv^(-1)}, yw])/4 - 
     (G[{0}, yw]*G[{1/(yu*yv)}, yw]*G[{1, yv^(-1), yv^(-1)}, yw])/4 + 
     (15*G[{1}, yu^(-1)]*G[{1/(yu*yv)}, yw]*G[{1, yv^(-1), yv^(-1)}, yw])/
      64 - (7*G[{1}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{1, yv^(-1), yv^(-1)}, 
        yw])/32 + (33*G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{1, yv^(-1), yv^(-1)}, 
        yw])/64 + (3*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*
       G[{1, yv^(-1), yv^(-1)}, yw])/32 - 
     (33*G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{1, yv^(-1), yv^(-1)}, yw])/
      64 - (3*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{1, yv^(-1), yv^(-1)}, 
        yw])/16 - (3*G[{1/(yu*yv)}, yw]^2*G[{1, yv^(-1), yv^(-1)}, yw])/64 + 
     (G[{0, 1}, yu^(-1)]*G[{1, yv^(-1), yv^(-1)}, yw])/8 + 
     (G[{0, 1}, yv^(-1)]*G[{1, yv^(-1), yv^(-1)}, yw])/32 - 
     (G[{0, 1}, yw]*G[{1, yv^(-1), yv^(-1)}, yw])/4 + 
     (G[{0, yu^(-1)}, yw]*G[{1, yv^(-1), yv^(-1)}, yw])/4 - 
     (G[{0, yu}, yv^(-1)]*G[{1, yv^(-1), yv^(-1)}, yw])/32 + 
     (G[{0, yv^(-1)}, yw]*G[{1, yv^(-1), yv^(-1)}, yw])/4 - 
     (G[{0, 1/(yu*yv)}, yw]*G[{1, yv^(-1), yv^(-1)}, yw])/4 - 
     (7*G[{1, yu^(-1)}, yw]*G[{1, yv^(-1), yv^(-1)}, yw])/32 - 
     (3*G[{1, yu}, yv^(-1)]*G[{1, yv^(-1), yv^(-1)}, yw])/32 - 
     (G[{1, yv^(-1)}, yw]*G[{1, yv^(-1), yv^(-1)}, yw])/8 - 
     (11*G[{1, 1/(yu*yv)}, yw]*G[{1, yv^(-1), yv^(-1)}, yw])/32 - 
     (3*G[{yu^(-1), 1/(yu*yv)}, yw]*G[{1, yv^(-1), yv^(-1)}, yw])/32 + 
     (3*G[{yv^(-1), 1/(yu*yv)}, yw]*G[{1, yv^(-1), yv^(-1)}, yw])/16 + 
     (11*Pi^2*G[{1, yv^(-1), 1/(yu*yv)}, yw])/768 - 
     (G[{0}, yu^(-1)]^2*G[{1, yv^(-1), 1/(yu*yv)}, yw])/32 - 
     (G[{0}, yu^(-1)]*G[{0}, yv^(-1)]*G[{1, yv^(-1), 1/(yu*yv)}, yw])/16 - 
     (G[{0}, yv^(-1)]^2*G[{1, yv^(-1), 1/(yu*yv)}, yw])/32 + 
     (G[{0}, yu^(-1)]*G[{0}, yw]*G[{1, yv^(-1), 1/(yu*yv)}, yw])/16 + 
     (G[{0}, yv^(-1)]*G[{0}, yw]*G[{1, yv^(-1), 1/(yu*yv)}, yw])/16 - 
     (G[{0}, yw]^2*G[{1, yv^(-1), 1/(yu*yv)}, yw])/32 + 
     (G[{0}, yu^(-1)]*G[{1}, yu^(-1)]*G[{1, yv^(-1), 1/(yu*yv)}, yw])/8 + 
     (G[{0}, yv^(-1)]*G[{1}, yu^(-1)]*G[{1, yv^(-1), 1/(yu*yv)}, yw])/8 - 
     (G[{0}, yw]*G[{1}, yu^(-1)]*G[{1, yv^(-1), 1/(yu*yv)}, yw])/8 - 
     (3*G[{1}, yu^(-1)]^2*G[{1, yv^(-1), 1/(yu*yv)}, yw])/32 + 
     (3*G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*G[{1, yv^(-1), 1/(yu*yv)}, yw])/64 + 
     (G[{1}, yv^(-1)]^2*G[{1, yv^(-1), 1/(yu*yv)}, yw])/128 + 
     (G[{1}, yu^(-1)]*G[{1}, yw]*G[{1, yv^(-1), 1/(yu*yv)}, yw])/16 + 
     (G[{1}, yv^(-1)]*G[{1}, yw]*G[{1, yv^(-1), 1/(yu*yv)}, yw])/64 + 
     (5*G[{1}, yw]^2*G[{1, yv^(-1), 1/(yu*yv)}, yw])/128 - 
     (7*G[{1}, yu^(-1)]*G[{yu}, yv^(-1)]*G[{1, yv^(-1), 1/(yu*yv)}, yw])/64 - 
     (5*G[{1}, yw]*G[{yu}, yv^(-1)]*G[{1, yv^(-1), 1/(yu*yv)}, yw])/64 + 
     (7*G[{yu}, yv^(-1)]^2*G[{1, yv^(-1), 1/(yu*yv)}, yw])/128 - 
     (G[{1}, yu^(-1)]*G[{1/(yu*yv)}, yw]*G[{1, yv^(-1), 1/(yu*yv)}, yw])/16 + 
     (3*G[{1}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{1, yv^(-1), 1/(yu*yv)}, yw])/
      64 - (G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{1, yv^(-1), 1/(yu*yv)}, yw])/
      64 - (3*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{1, yv^(-1), 1/(yu*yv)}, 
        yw])/64 + (G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw]*
       G[{1, yv^(-1), 1/(yu*yv)}, yw])/64 - 
     (G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{1, yv^(-1), 1/(yu*yv)}, yw])/
      32 + (3*G[{0, 1}, yu^(-1)]*G[{1, yv^(-1), 1/(yu*yv)}, yw])/64 - 
     (G[{0, 1}, yv^(-1)]*G[{1, yv^(-1), 1/(yu*yv)}, yw])/64 + 
     (G[{0, yu}, yv^(-1)]*G[{1, yv^(-1), 1/(yu*yv)}, yw])/64 - 
     (G[{1, yu^(-1)}, yw]*G[{1, yv^(-1), 1/(yu*yv)}, yw])/64 - 
     (G[{1, yu}, yv^(-1)]*G[{1, yv^(-1), 1/(yu*yv)}, yw])/16 + 
     (3*G[{1, yv^(-1)}, yw]*G[{1, yv^(-1), 1/(yu*yv)}, yw])/64 - 
     (5*G[{1, 1/(yu*yv)}, yw]*G[{1, yv^(-1), 1/(yu*yv)}, yw])/64 + 
     (3*G[{yu^(-1), 1/(yu*yv)}, yw]*G[{1, yv^(-1), 1/(yu*yv)}, yw])/64 + 
     (G[{yv^(-1), 1/(yu*yv)}, yw]*G[{1, yv^(-1), 1/(yu*yv)}, yw])/32 - 
     (Pi^2*G[{1, 1/(yu*yv), yu^(-1)}, yw])/96 - 
     (G[{0}, yu^(-1)]*G[{1}, yu^(-1)]*G[{1, 1/(yu*yv), yu^(-1)}, yw])/8 - 
     (G[{0}, yv^(-1)]*G[{1}, yu^(-1)]*G[{1, 1/(yu*yv), yu^(-1)}, yw])/8 + 
     (G[{0}, yw]*G[{1}, yu^(-1)]*G[{1, 1/(yu*yv), yu^(-1)}, yw])/8 + 
     (3*G[{1}, yu^(-1)]^2*G[{1, 1/(yu*yv), yu^(-1)}, yw])/32 + 
     (G[{0}, yu^(-1)]*G[{1}, yv^(-1)]*G[{1, 1/(yu*yv), yu^(-1)}, yw])/8 + 
     (G[{0}, yv^(-1)]*G[{1}, yv^(-1)]*G[{1, 1/(yu*yv), yu^(-1)}, yw])/8 - 
     (G[{0}, yw]*G[{1}, yv^(-1)]*G[{1, 1/(yu*yv), yu^(-1)}, yw])/8 + 
     (G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*G[{1, 1/(yu*yv), yu^(-1)}, yw])/16 - 
     (G[{1}, yv^(-1)]^2*G[{1, 1/(yu*yv), yu^(-1)}, yw])/8 + 
     (G[{0}, yu^(-1)]*G[{1}, yw]*G[{1, 1/(yu*yv), yu^(-1)}, yw])/8 + 
     (G[{0}, yv^(-1)]*G[{1}, yw]*G[{1, 1/(yu*yv), yu^(-1)}, yw])/8 - 
     (G[{0}, yw]*G[{1}, yw]*G[{1, 1/(yu*yv), yu^(-1)}, yw])/8 - 
     (G[{1}, yu^(-1)]*G[{1}, yw]*G[{1, 1/(yu*yv), yu^(-1)}, yw])/16 + 
     (3*G[{1}, yw]^2*G[{1, 1/(yu*yv), yu^(-1)}, yw])/32 - 
     (G[{1}, yv^(-1)]*G[{yu}, yv^(-1)]*G[{1, 1/(yu*yv), yu^(-1)}, yw])/8 - 
     (3*G[{1}, yw]*G[{yu}, yv^(-1)]*G[{1, 1/(yu*yv), yu^(-1)}, yw])/16 + 
     (G[{yu}, yv^(-1)]^2*G[{1, 1/(yu*yv), yu^(-1)}, yw])/16 - 
     (G[{0}, yu^(-1)]*G[{1/(yu*yv)}, yw]*G[{1, 1/(yu*yv), yu^(-1)}, yw])/16 - 
     (G[{0}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{1, 1/(yu*yv), yu^(-1)}, yw])/16 + 
     (G[{0}, yw]*G[{1/(yu*yv)}, yw]*G[{1, 1/(yu*yv), yu^(-1)}, yw])/16 - 
     (G[{1}, yu^(-1)]*G[{1/(yu*yv)}, yw]*G[{1, 1/(yu*yv), yu^(-1)}, yw])/16 - 
     (G[{1}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{1, 1/(yu*yv), yu^(-1)}, yw])/16 - 
     (G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{1, 1/(yu*yv), yu^(-1)}, yw])/4 - 
     (G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{1, 1/(yu*yv), yu^(-1)}, yw])/
      16 + (G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{1, 1/(yu*yv), yu^(-1)}, 
        yw])/4 + (G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*
       G[{1, 1/(yu*yv), yu^(-1)}, yw])/16 - 
     (G[{0, 1}, yu^(-1)]*G[{1, 1/(yu*yv), yu^(-1)}, yw])/16 + 
     (G[{0, 1}, yw]*G[{1, 1/(yu*yv), yu^(-1)}, yw])/8 - 
     (G[{0, yu^(-1)}, yw]*G[{1, 1/(yu*yv), yu^(-1)}, yw])/8 - 
     (G[{0, yv^(-1)}, yw]*G[{1, 1/(yu*yv), yu^(-1)}, yw])/8 + 
     (G[{0, 1/(yu*yv)}, yw]*G[{1, 1/(yu*yv), yu^(-1)}, yw])/8 + 
     (G[{1, yu^(-1)}, yw]*G[{1, 1/(yu*yv), yu^(-1)}, yw])/8 + 
     (G[{1, yu}, yv^(-1)]*G[{1, 1/(yu*yv), yu^(-1)}, yw])/16 + 
     (G[{1, yv^(-1)}, yw]*G[{1, 1/(yu*yv), yu^(-1)}, yw])/16 + 
     (G[{1, 1/(yu*yv)}, yw]*G[{1, 1/(yu*yv), yu^(-1)}, yw])/16 + 
     (G[{yu^(-1), 1/(yu*yv)}, yw]*G[{1, 1/(yu*yv), yu^(-1)}, yw])/16 - 
     (G[{yv^(-1), 1/(yu*yv)}, yw]*G[{1, 1/(yu*yv), yu^(-1)}, yw])/16 + 
     (7*Pi^2*G[{1, 1/(yu*yv), yv^(-1)}, yw])/768 + 
     (G[{0}, yu^(-1)]*G[{1}, yu^(-1)]*G[{1, 1/(yu*yv), yv^(-1)}, yw])/8 + 
     (G[{0}, yv^(-1)]*G[{1}, yu^(-1)]*G[{1, 1/(yu*yv), yv^(-1)}, yw])/8 - 
     (G[{0}, yw]*G[{1}, yu^(-1)]*G[{1, 1/(yu*yv), yv^(-1)}, yw])/8 - 
     (5*G[{1}, yu^(-1)]^2*G[{1, 1/(yu*yv), yv^(-1)}, yw])/64 - 
     (G[{0}, yu^(-1)]*G[{1}, yv^(-1)]*G[{1, 1/(yu*yv), yv^(-1)}, yw])/8 - 
     (G[{0}, yv^(-1)]*G[{1}, yv^(-1)]*G[{1, 1/(yu*yv), yv^(-1)}, yw])/8 + 
     (G[{0}, yw]*G[{1}, yv^(-1)]*G[{1, 1/(yu*yv), yv^(-1)}, yw])/8 + 
     (G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*G[{1, 1/(yu*yv), yv^(-1)}, yw])/8 + 
     (5*G[{1}, yv^(-1)]^2*G[{1, 1/(yu*yv), yv^(-1)}, yw])/64 + 
     (G[{0}, yu^(-1)]*G[{1}, yw]*G[{1, 1/(yu*yv), yv^(-1)}, yw])/8 + 
     (G[{0}, yv^(-1)]*G[{1}, yw]*G[{1, 1/(yu*yv), yv^(-1)}, yw])/8 - 
     (G[{0}, yw]*G[{1}, yw]*G[{1, 1/(yu*yv), yv^(-1)}, yw])/8 + 
     (3*G[{1}, yu^(-1)]*G[{1}, yw]*G[{1, 1/(yu*yv), yv^(-1)}, yw])/32 - 
     (3*G[{1}, yv^(-1)]*G[{1}, yw]*G[{1, 1/(yu*yv), yv^(-1)}, yw])/32 + 
     (G[{1}, yw]^2*G[{1, 1/(yu*yv), yv^(-1)}, yw])/8 - 
     (7*G[{1}, yu^(-1)]*G[{yu}, yv^(-1)]*G[{1, 1/(yu*yv), yv^(-1)}, yw])/32 - 
     (G[{1}, yw]*G[{yu}, yv^(-1)]*G[{1, 1/(yu*yv), yv^(-1)}, yw])/4 + 
     (7*G[{yu}, yv^(-1)]^2*G[{1, 1/(yu*yv), yv^(-1)}, yw])/64 - 
     (G[{0}, yu^(-1)]*G[{1/(yu*yv)}, yw]*G[{1, 1/(yu*yv), yv^(-1)}, yw])/16 - 
     (G[{0}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{1, 1/(yu*yv), yv^(-1)}, yw])/16 + 
     (G[{0}, yw]*G[{1/(yu*yv)}, yw]*G[{1, 1/(yu*yv), yv^(-1)}, yw])/16 - 
     (7*G[{1}, yu^(-1)]*G[{1/(yu*yv)}, yw]*G[{1, 1/(yu*yv), yv^(-1)}, yw])/
      64 - (G[{1}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{1, 1/(yu*yv), yv^(-1)}, 
        yw])/32 - (17*G[{1}, yw]*G[{1/(yu*yv)}, yw]*
       G[{1, 1/(yu*yv), yv^(-1)}, yw])/64 + 
     (G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{1, 1/(yu*yv), yv^(-1)}, yw])/
      32 + (17*G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{1, 1/(yu*yv), yv^(-1)}, 
        yw])/64 - (G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*
       G[{1, 1/(yu*yv), yv^(-1)}, yw])/16 + 
     (3*G[{1/(yu*yv)}, yw]^2*G[{1, 1/(yu*yv), yv^(-1)}, yw])/64 - 
     (G[{0, 1}, yv^(-1)]*G[{1, 1/(yu*yv), yv^(-1)}, yw])/32 + 
     (G[{0, 1}, yw]*G[{1, 1/(yu*yv), yv^(-1)}, yw])/8 - 
     (G[{0, yu^(-1)}, yw]*G[{1, 1/(yu*yv), yv^(-1)}, yw])/8 + 
     (G[{0, yu}, yv^(-1)]*G[{1, 1/(yu*yv), yv^(-1)}, yw])/32 - 
     (G[{0, yv^(-1)}, yw]*G[{1, 1/(yu*yv), yv^(-1)}, yw])/8 + 
     (G[{0, 1/(yu*yv)}, yw]*G[{1, 1/(yu*yv), yv^(-1)}, yw])/8 + 
     (3*G[{1, yu^(-1)}, yw]*G[{1, 1/(yu*yv), yv^(-1)}, yw])/32 - 
     (G[{1, yu}, yv^(-1)]*G[{1, 1/(yu*yv), yv^(-1)}, yw])/32 + 
     (G[{1, yv^(-1)}, yw]*G[{1, 1/(yu*yv), yv^(-1)}, yw])/8 + 
     (G[{1, 1/(yu*yv)}, yw]*G[{1, 1/(yu*yv), yv^(-1)}, yw])/32 - 
     (G[{yu^(-1), 1/(yu*yv)}, yw]*G[{1, 1/(yu*yv), yv^(-1)}, yw])/32 + 
     (G[{yv^(-1), 1/(yu*yv)}, yw]*G[{1, 1/(yu*yv), yv^(-1)}, yw])/16 - 
     (19*Pi^2*G[{1, 1/(yu*yv), 1/(yu*yv)}, yw])/768 + 
     (G[{0}, yu^(-1)]^2*G[{1, 1/(yu*yv), 1/(yu*yv)}, yw])/16 + 
     (G[{0}, yu^(-1)]*G[{0}, yv^(-1)]*G[{1, 1/(yu*yv), 1/(yu*yv)}, yw])/8 + 
     (G[{0}, yv^(-1)]^2*G[{1, 1/(yu*yv), 1/(yu*yv)}, yw])/16 - 
     (G[{0}, yu^(-1)]*G[{0}, yw]*G[{1, 1/(yu*yv), 1/(yu*yv)}, yw])/8 - 
     (G[{0}, yv^(-1)]*G[{0}, yw]*G[{1, 1/(yu*yv), 1/(yu*yv)}, yw])/8 + 
     (G[{0}, yw]^2*G[{1, 1/(yu*yv), 1/(yu*yv)}, yw])/16 - 
     (G[{0}, yu^(-1)]*G[{1}, yu^(-1)]*G[{1, 1/(yu*yv), 1/(yu*yv)}, yw])/8 - 
     (G[{0}, yv^(-1)]*G[{1}, yu^(-1)]*G[{1, 1/(yu*yv), 1/(yu*yv)}, yw])/8 + 
     (G[{0}, yw]*G[{1}, yu^(-1)]*G[{1, 1/(yu*yv), 1/(yu*yv)}, yw])/8 - 
     (G[{1}, yu^(-1)]^2*G[{1, 1/(yu*yv), 1/(yu*yv)}, yw])/16 - 
     (G[{0}, yu^(-1)]*G[{1}, yv^(-1)]*G[{1, 1/(yu*yv), 1/(yu*yv)}, yw])/8 - 
     (G[{0}, yv^(-1)]*G[{1}, yv^(-1)]*G[{1, 1/(yu*yv), 1/(yu*yv)}, yw])/8 + 
     (G[{0}, yw]*G[{1}, yv^(-1)]*G[{1, 1/(yu*yv), 1/(yu*yv)}, yw])/8 + 
     (G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*G[{1, 1/(yu*yv), 1/(yu*yv)}, yw])/64 + 
     (11*G[{1}, yv^(-1)]^2*G[{1, 1/(yu*yv), 1/(yu*yv)}, yw])/128 - 
     (3*G[{1}, yu^(-1)]*G[{1}, yw]*G[{1, 1/(yu*yv), 1/(yu*yv)}, yw])/8 - 
     (5*G[{1}, yv^(-1)]*G[{1}, yw]*G[{1, 1/(yu*yv), 1/(yu*yv)}, yw])/64 - 
     (29*G[{1}, yw]^2*G[{1, 1/(yu*yv), 1/(yu*yv)}, yw])/128 + 
     (23*G[{1}, yu^(-1)]*G[{yu}, yv^(-1)]*G[{1, 1/(yu*yv), 1/(yu*yv)}, yw])/
      64 + (5*G[{1}, yv^(-1)]*G[{yu}, yv^(-1)]*G[{1, 1/(yu*yv), 1/(yu*yv)}, 
        yw])/16 + (29*G[{1}, yw]*G[{yu}, yv^(-1)]*
       G[{1, 1/(yu*yv), 1/(yu*yv)}, yw])/64 - 
     (43*G[{yu}, yv^(-1)]^2*G[{1, 1/(yu*yv), 1/(yu*yv)}, yw])/128 + 
     (G[{0}, yu^(-1)]*G[{1/(yu*yv)}, yw]*G[{1, 1/(yu*yv), 1/(yu*yv)}, yw])/
      16 + (G[{0}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{1, 1/(yu*yv), 1/(yu*yv)}, 
        yw])/16 - (G[{0}, yw]*G[{1/(yu*yv)}, yw]*G[{1, 1/(yu*yv), 1/(yu*yv)}, 
        yw])/16 + (G[{1}, yu^(-1)]*G[{1/(yu*yv)}, yw]*
       G[{1, 1/(yu*yv), 1/(yu*yv)}, yw])/16 - 
     (3*G[{1}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{1, 1/(yu*yv), 1/(yu*yv)}, yw])/
      64 + (9*G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{1, 1/(yu*yv), 1/(yu*yv)}, yw])/
      64 + (3*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*
       G[{1, 1/(yu*yv), 1/(yu*yv)}, yw])/64 - 
     (9*G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{1, 1/(yu*yv), 1/(yu*yv)}, yw])/
      64 + (G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{1, 1/(yu*yv), 1/(yu*yv)}, 
        yw])/32 + (G[{0, 1}, yu^(-1)]*G[{1, 1/(yu*yv), 1/(yu*yv)}, yw])/64 - 
     (15*G[{0, 1}, yv^(-1)]*G[{1, 1/(yu*yv), 1/(yu*yv)}, yw])/64 + 
     (15*G[{0, yu}, yv^(-1)]*G[{1, 1/(yu*yv), 1/(yu*yv)}, yw])/64 - 
     (15*G[{1, yu^(-1)}, yw]*G[{1, 1/(yu*yv), 1/(yu*yv)}, yw])/64 - 
     (G[{1, yu}, yv^(-1)]*G[{1, 1/(yu*yv), 1/(yu*yv)}, yw])/4 + 
     (G[{1, yv^(-1)}, yw]*G[{1, 1/(yu*yv), 1/(yu*yv)}, yw])/64 + 
     (7*G[{1, 1/(yu*yv)}, yw]*G[{1, 1/(yu*yv), 1/(yu*yv)}, yw])/32 - 
     (3*G[{yu^(-1), 1/(yu*yv)}, yw]*G[{1, 1/(yu*yv), 1/(yu*yv)}, yw])/64 - 
     (G[{yv^(-1), 1/(yu*yv)}, yw]*G[{1, 1/(yu*yv), 1/(yu*yv)}, yw])/32 - 
     (Pi^2*G[{yu^(-1), yu^(-1), 1/(yu*yv)}, yw])/96 + 
     (G[{0}, yu^(-1)]^2*G[{yu^(-1), yu^(-1), 1/(yu*yv)}, yw])/16 + 
     (G[{0}, yu^(-1)]*G[{0}, yv^(-1)]*G[{yu^(-1), yu^(-1), 1/(yu*yv)}, yw])/
      8 + (G[{0}, yv^(-1)]^2*G[{yu^(-1), yu^(-1), 1/(yu*yv)}, yw])/16 - 
     (G[{0}, yu^(-1)]*G[{0}, yw]*G[{yu^(-1), yu^(-1), 1/(yu*yv)}, yw])/8 - 
     (G[{0}, yv^(-1)]*G[{0}, yw]*G[{yu^(-1), yu^(-1), 1/(yu*yv)}, yw])/8 + 
     (G[{0}, yw]^2*G[{yu^(-1), yu^(-1), 1/(yu*yv)}, yw])/16 + 
     (G[{0}, yu^(-1)]*G[{1}, yu^(-1)]*G[{yu^(-1), yu^(-1), 1/(yu*yv)}, yw])/
      8 + (G[{0}, yv^(-1)]*G[{1}, yu^(-1)]*G[{yu^(-1), yu^(-1), 1/(yu*yv)}, 
        yw])/8 - (G[{0}, yw]*G[{1}, yu^(-1)]*G[{yu^(-1), yu^(-1), 1/(yu*yv)}, 
        yw])/8 - (G[{1}, yu^(-1)]^2*G[{yu^(-1), yu^(-1), 1/(yu*yv)}, yw])/
      32 - (G[{0}, yu^(-1)]*G[{1}, yv^(-1)]*G[{yu^(-1), yu^(-1), 1/(yu*yv)}, 
        yw])/8 - (G[{0}, yv^(-1)]*G[{1}, yv^(-1)]*
       G[{yu^(-1), yu^(-1), 1/(yu*yv)}, yw])/8 + 
     (G[{0}, yw]*G[{1}, yv^(-1)]*G[{yu^(-1), yu^(-1), 1/(yu*yv)}, yw])/8 - 
     (3*G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*G[{yu^(-1), yu^(-1), 1/(yu*yv)}, yw])/
      16 + (G[{1}, yv^(-1)]^2*G[{yu^(-1), yu^(-1), 1/(yu*yv)}, yw])/16 + 
     (G[{0}, yu^(-1)]*G[{1}, yw]*G[{yu^(-1), yu^(-1), 1/(yu*yv)}, yw])/8 + 
     (G[{0}, yv^(-1)]*G[{1}, yw]*G[{yu^(-1), yu^(-1), 1/(yu*yv)}, yw])/8 - 
     (G[{0}, yw]*G[{1}, yw]*G[{yu^(-1), yu^(-1), 1/(yu*yv)}, yw])/8 + 
     (3*G[{1}, yu^(-1)]*G[{1}, yw]*G[{yu^(-1), yu^(-1), 1/(yu*yv)}, yw])/16 - 
     (G[{1}, yv^(-1)]*G[{1}, yw]*G[{yu^(-1), yu^(-1), 1/(yu*yv)}, yw])/8 + 
     (5*G[{1}, yw]^2*G[{yu^(-1), yu^(-1), 1/(yu*yv)}, yw])/32 + 
     (G[{0}, yu^(-1)]*G[{yu^(-1)}, yw]*G[{yu^(-1), yu^(-1), 1/(yu*yv)}, yw])/
      4 + (G[{0}, yv^(-1)]*G[{yu^(-1)}, yw]*G[{yu^(-1), yu^(-1), 1/(yu*yv)}, 
        yw])/4 - (G[{0}, yw]*G[{yu^(-1)}, yw]*
       G[{yu^(-1), yu^(-1), 1/(yu*yv)}, yw])/4 - 
     (G[{1}, yv^(-1)]*G[{yu^(-1)}, yw]*G[{yu^(-1), yu^(-1), 1/(yu*yv)}, yw])/
      8 + (3*G[{1}, yw]*G[{yu^(-1)}, yw]*G[{yu^(-1), yu^(-1), 1/(yu*yv)}, 
        yw])/8 + (G[{yu^(-1)}, yw]^2*G[{yu^(-1), yu^(-1), 1/(yu*yv)}, yw])/
      16 - (G[{0}, yu^(-1)]*G[{yu}, yv^(-1)]*G[{yu^(-1), yu^(-1), 1/(yu*yv)}, 
        yw])/4 - (G[{0}, yv^(-1)]*G[{yu}, yv^(-1)]*
       G[{yu^(-1), yu^(-1), 1/(yu*yv)}, yw])/4 + 
     (G[{0}, yw]*G[{yu}, yv^(-1)]*G[{yu^(-1), yu^(-1), 1/(yu*yv)}, yw])/4 + 
     (3*G[{1}, yv^(-1)]*G[{yu}, yv^(-1)]*G[{yu^(-1), yu^(-1), 1/(yu*yv)}, 
        yw])/8 - (5*G[{1}, yw]*G[{yu}, yv^(-1)]*
       G[{yu^(-1), yu^(-1), 1/(yu*yv)}, yw])/16 - 
     (3*G[{yu^(-1)}, yw]*G[{yu}, yv^(-1)]*G[{yu^(-1), yu^(-1), 1/(yu*yv)}, 
        yw])/8 + (G[{yu}, yv^(-1)]^2*G[{yu^(-1), yu^(-1), 1/(yu*yv)}, yw])/
      16 + (G[{1}, yu^(-1)]*G[{1/(yu*yv)}, yw]*
       G[{yu^(-1), yu^(-1), 1/(yu*yv)}, yw])/16 - 
     (G[{1}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{yu^(-1), yu^(-1), 1/(yu*yv)}, 
        yw])/16 + (G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*
       G[{yu^(-1), yu^(-1), 1/(yu*yv)}, yw])/16 - 
     (3*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{yu^(-1), yu^(-1), 1/(yu*yv)}, 
        yw])/16 - (G[{0, 1}, yu^(-1)]*G[{yu^(-1), yu^(-1), 1/(yu*yv)}, yw])/
      16 - (G[{0, 1}, yv^(-1)]*G[{yu^(-1), yu^(-1), 1/(yu*yv)}, yw])/8 - 
     (G[{0, 1}, yw]*G[{yu^(-1), yu^(-1), 1/(yu*yv)}, yw])/8 + 
     (G[{0, yu^(-1)}, yw]*G[{yu^(-1), yu^(-1), 1/(yu*yv)}, yw])/8 + 
     (G[{0, yu}, yv^(-1)]*G[{yu^(-1), yu^(-1), 1/(yu*yv)}, yw])/8 + 
     (G[{0, yv^(-1)}, yw]*G[{yu^(-1), yu^(-1), 1/(yu*yv)}, yw])/8 - 
     (G[{0, 1/(yu*yv)}, yw]*G[{yu^(-1), yu^(-1), 1/(yu*yv)}, yw])/8 - 
     (G[{1, yu^(-1)}, yw]*G[{yu^(-1), yu^(-1), 1/(yu*yv)}, yw])/4 - 
     (G[{1, yu}, yv^(-1)]*G[{yu^(-1), yu^(-1), 1/(yu*yv)}, yw])/16 - 
     (3*G[{1, yv^(-1)}, yw]*G[{yu^(-1), yu^(-1), 1/(yu*yv)}, yw])/16 + 
     (3*G[{1, 1/(yu*yv)}, yw]*G[{yu^(-1), yu^(-1), 1/(yu*yv)}, yw])/16 - 
     (G[{yu^(-1), 1/(yu*yv)}, yw]*G[{yu^(-1), yu^(-1), 1/(yu*yv)}, yw])/16 + 
     (3*G[{yv^(-1), 1/(yu*yv)}, yw]*G[{yu^(-1), yu^(-1), 1/(yu*yv)}, yw])/
      16 - (3*G[{0}, yu^(-1)]*G[{1/(yu*yv)}, yw]*
       G[{yu^(-1), 1/(yu*yv), yv^(-1)}, yw])/16 - 
     (3*G[{0}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{yu^(-1), 1/(yu*yv), yv^(-1)}, 
        yw])/16 + (3*G[{0}, yw]*G[{1/(yu*yv)}, yw]*
       G[{yu^(-1), 1/(yu*yv), yv^(-1)}, yw])/16 - 
     (G[{1}, yu^(-1)]*G[{1/(yu*yv)}, yw]*G[{yu^(-1), 1/(yu*yv), yv^(-1)}, 
        yw])/8 + (G[{1}, yv^(-1)]*G[{1/(yu*yv)}, yw]*
       G[{yu^(-1), 1/(yu*yv), yv^(-1)}, yw])/4 - 
     (G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{yu^(-1), 1/(yu*yv), yv^(-1)}, yw])/4 - 
     (G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{yu^(-1), 1/(yu*yv), yv^(-1)}, 
        yw])/4 + (G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw]*
       G[{yu^(-1), 1/(yu*yv), yv^(-1)}, yw])/4 + 
     (G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{yu^(-1), 1/(yu*yv), yv^(-1)}, 
        yw])/4 - (G[{yv^(-1), 1/(yu*yv)}, yw]*
       G[{yu^(-1), 1/(yu*yv), yv^(-1)}, yw])/4 - 
     (Pi^2*G[{yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/96 + 
     (G[{0}, yu^(-1)]^2*G[{yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/32 + 
     (G[{0}, yu^(-1)]*G[{0}, yv^(-1)]*G[{yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/
      16 + (G[{0}, yv^(-1)]^2*G[{yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/32 - 
     (G[{0}, yu^(-1)]*G[{0}, yw]*G[{yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/16 - 
     (G[{0}, yv^(-1)]*G[{0}, yw]*G[{yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/16 + 
     (G[{0}, yw]^2*G[{yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/32 + 
     (G[{0}, yu^(-1)]*G[{1}, yu^(-1)]*G[{yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/
      8 + (G[{0}, yv^(-1)]*G[{1}, yu^(-1)]*G[{yu^(-1), 1/(yu*yv), 1/(yu*yv)}, 
        yw])/8 - (G[{0}, yw]*G[{1}, yu^(-1)]*
       G[{yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/8 - 
     (7*G[{1}, yu^(-1)]^2*G[{yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/32 - 
     (G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*G[{yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/
      16 - (G[{1}, yv^(-1)]^2*G[{yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/32 + 
     (G[{0}, yu^(-1)]*G[{1}, yw]*G[{yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/8 + 
     (G[{0}, yv^(-1)]*G[{1}, yw]*G[{yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/8 - 
     (G[{0}, yw]*G[{1}, yw]*G[{yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/8 - 
     (3*G[{1}, yu^(-1)]*G[{1}, yw]*G[{yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/
      16 - (G[{1}, yv^(-1)]*G[{1}, yw]*G[{yu^(-1), 1/(yu*yv), 1/(yu*yv)}, 
        yw])/16 + (G[{0}, yu^(-1)]*G[{yu^(-1)}, yw]*
       G[{yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/8 + 
     (G[{0}, yv^(-1)]*G[{yu^(-1)}, yw]*G[{yu^(-1), 1/(yu*yv), 1/(yu*yv)}, 
        yw])/8 - (G[{0}, yw]*G[{yu^(-1)}, yw]*
       G[{yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/8 - 
     (G[{1}, yv^(-1)]*G[{yu^(-1)}, yw]*G[{yu^(-1), 1/(yu*yv), 1/(yu*yv)}, 
        yw])/16 + (3*G[{1}, yw]*G[{yu^(-1)}, yw]*
       G[{yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/16 + 
     (G[{yu^(-1)}, yw]^2*G[{yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/32 - 
     (G[{0}, yu^(-1)]*G[{yu}, yv^(-1)]*G[{yu^(-1), 1/(yu*yv), 1/(yu*yv)}, 
        yw])/4 - (G[{0}, yv^(-1)]*G[{yu}, yv^(-1)]*
       G[{yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/4 + 
     (G[{0}, yw]*G[{yu}, yv^(-1)]*G[{yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/4 + 
     (G[{1}, yu^(-1)]*G[{yu}, yv^(-1)]*G[{yu^(-1), 1/(yu*yv), 1/(yu*yv)}, 
        yw])/4 + (3*G[{1}, yv^(-1)]*G[{yu}, yv^(-1)]*
       G[{yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/16 - 
     (3*G[{yu^(-1)}, yw]*G[{yu}, yv^(-1)]*G[{yu^(-1), 1/(yu*yv), 1/(yu*yv)}, 
        yw])/16 + (G[{yu}, yv^(-1)]^2*G[{yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/
      32 - (G[{0}, yu^(-1)]*G[{1/(yu*yv)}, yw]*
       G[{yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/16 - 
     (G[{0}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{yu^(-1), 1/(yu*yv), 1/(yu*yv)}, 
        yw])/16 + (G[{0}, yw]*G[{1/(yu*yv)}, yw]*
       G[{yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/16 - 
     (G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/
      8 + (G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw]*
       G[{yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/8 + 
     (G[{0, 1}, yu^(-1)]*G[{yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/16 - 
     (G[{0, 1}, yw]*G[{yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/8 + 
     (G[{0, yu^(-1)}, yw]*G[{yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/8 + 
     (G[{0, yv^(-1)}, yw]*G[{yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/8 - 
     (G[{0, 1/(yu*yv)}, yw]*G[{yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/8 - 
     (G[{1, yu^(-1)}, yw]*G[{yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/8 - 
     (G[{1, yu}, yv^(-1)]*G[{yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/16 - 
     (G[{1, yv^(-1)}, yw]*G[{yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/16 - 
     (G[{1, 1/(yu*yv)}, yw]*G[{yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/16 + 
     (G[{yu^(-1), 1/(yu*yv)}, yw]*G[{yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/8 - 
     (41*Pi^2*G[{yv^(-1), yv^(-1), 1/(yu*yv)}, yw])/768 + 
     (G[{0}, yu^(-1)]^2*G[{yv^(-1), yv^(-1), 1/(yu*yv)}, yw])/16 + 
     (G[{0}, yu^(-1)]*G[{0}, yv^(-1)]*G[{yv^(-1), yv^(-1), 1/(yu*yv)}, yw])/
      8 + (G[{0}, yv^(-1)]^2*G[{yv^(-1), yv^(-1), 1/(yu*yv)}, yw])/16 - 
     (G[{0}, yu^(-1)]*G[{0}, yw]*G[{yv^(-1), yv^(-1), 1/(yu*yv)}, yw])/8 - 
     (G[{0}, yv^(-1)]*G[{0}, yw]*G[{yv^(-1), yv^(-1), 1/(yu*yv)}, yw])/8 + 
     (G[{0}, yw]^2*G[{yv^(-1), yv^(-1), 1/(yu*yv)}, yw])/16 + 
     (G[{0}, yu^(-1)]*G[{1}, yu^(-1)]*G[{yv^(-1), yv^(-1), 1/(yu*yv)}, yw])/
      4 + (G[{0}, yv^(-1)]*G[{1}, yu^(-1)]*G[{yv^(-1), yv^(-1), 1/(yu*yv)}, 
        yw])/4 - (G[{0}, yw]*G[{1}, yu^(-1)]*G[{yv^(-1), yv^(-1), 1/(yu*yv)}, 
        yw])/4 - (29*G[{1}, yu^(-1)]^2*G[{yv^(-1), yv^(-1), 1/(yu*yv)}, yw])/
      64 - (G[{0}, yu^(-1)]*G[{1}, yv^(-1)]*G[{yv^(-1), yv^(-1), 1/(yu*yv)}, 
        yw])/4 - (G[{0}, yv^(-1)]*G[{1}, yv^(-1)]*
       G[{yv^(-1), yv^(-1), 1/(yu*yv)}, yw])/4 + 
     (G[{0}, yw]*G[{1}, yv^(-1)]*G[{yv^(-1), yv^(-1), 1/(yu*yv)}, yw])/4 + 
     (G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*G[{yv^(-1), yv^(-1), 1/(yu*yv)}, yw])/
      8 + (9*G[{1}, yv^(-1)]^2*G[{yv^(-1), yv^(-1), 1/(yu*yv)}, yw])/64 + 
     (G[{0}, yu^(-1)]*G[{1}, yw]*G[{yv^(-1), yv^(-1), 1/(yu*yv)}, yw])/2 + 
     (G[{0}, yv^(-1)]*G[{1}, yw]*G[{yv^(-1), yv^(-1), 1/(yu*yv)}, yw])/2 - 
     (G[{0}, yw]*G[{1}, yw]*G[{yv^(-1), yv^(-1), 1/(yu*yv)}, yw])/2 - 
     (13*G[{1}, yu^(-1)]*G[{1}, yw]*G[{yv^(-1), yv^(-1), 1/(yu*yv)}, yw])/
      32 - (7*G[{1}, yv^(-1)]*G[{1}, yw]*G[{yv^(-1), yv^(-1), 1/(yu*yv)}, 
        yw])/32 + (3*G[{1}, yw]^2*G[{yv^(-1), yv^(-1), 1/(yu*yv)}, yw])/16 - 
     (G[{0}, yu^(-1)]*G[{yu}, yv^(-1)]*G[{yv^(-1), yv^(-1), 1/(yu*yv)}, yw])/
      4 - (G[{0}, yv^(-1)]*G[{yu}, yv^(-1)]*G[{yv^(-1), yv^(-1), 1/(yu*yv)}, 
        yw])/4 + (G[{0}, yw]*G[{yu}, yv^(-1)]*
       G[{yv^(-1), yv^(-1), 1/(yu*yv)}, yw])/4 + 
     (9*G[{1}, yu^(-1)]*G[{yu}, yv^(-1)]*G[{yv^(-1), yv^(-1), 1/(yu*yv)}, 
        yw])/32 - (3*G[{1}, yw]*G[{yu}, yv^(-1)]*
       G[{yv^(-1), yv^(-1), 1/(yu*yv)}, yw])/8 + 
     (7*G[{yu}, yv^(-1)]^2*G[{yv^(-1), yv^(-1), 1/(yu*yv)}, yw])/64 - 
     (G[{0}, yu^(-1)]*G[{yv^(-1)}, yw]*G[{yv^(-1), yv^(-1), 1/(yu*yv)}, yw])/
      2 - (G[{0}, yv^(-1)]*G[{yv^(-1)}, yw]*G[{yv^(-1), yv^(-1), 1/(yu*yv)}, 
        yw])/2 + (G[{0}, yw]*G[{yv^(-1)}, yw]*
       G[{yv^(-1), yv^(-1), 1/(yu*yv)}, yw])/2 + 
     (41*G[{1}, yu^(-1)]*G[{yv^(-1)}, yw]*G[{yv^(-1), yv^(-1), 1/(yu*yv)}, 
        yw])/32 + (9*G[{1}, yw]*G[{yv^(-1)}, yw]*
       G[{yv^(-1), yv^(-1), 1/(yu*yv)}, yw])/32 - 
     (9*G[{yu}, yv^(-1)]*G[{yv^(-1)}, yw]*G[{yv^(-1), yv^(-1), 1/(yu*yv)}, 
        yw])/32 - (41*G[{yv^(-1)}, yw]^2*G[{yv^(-1), yv^(-1), 1/(yu*yv)}, 
        yw])/64 + (17*G[{1}, yu^(-1)]*G[{1/(yu*yv)}, yw]*
       G[{yv^(-1), yv^(-1), 1/(yu*yv)}, yw])/64 - 
     (9*G[{1}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{yv^(-1), yv^(-1), 1/(yu*yv)}, 
        yw])/32 - (G[{1}, yw]*G[{1/(yu*yv)}, yw]*
       G[{yv^(-1), yv^(-1), 1/(yu*yv)}, yw])/64 + 
     (9*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{yv^(-1), yv^(-1), 1/(yu*yv)}, 
        yw])/32 + (G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw]*
       G[{yv^(-1), yv^(-1), 1/(yu*yv)}, yw])/64 - 
     (17*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{yv^(-1), yv^(-1), 1/(yu*yv)}, 
        yw])/64 + (3*G[{1/(yu*yv)}, yw]^2*G[{yv^(-1), yv^(-1), 1/(yu*yv)}, 
        yw])/64 - (G[{0, 1}, yu^(-1)]*G[{yv^(-1), yv^(-1), 1/(yu*yv)}, yw])/
      8 - (G[{0, 1}, yv^(-1)]*G[{yv^(-1), yv^(-1), 1/(yu*yv)}, yw])/32 + 
     (G[{0, 1}, yw]*G[{yv^(-1), yv^(-1), 1/(yu*yv)}, yw])/4 - 
     (G[{0, yu^(-1)}, yw]*G[{yv^(-1), yv^(-1), 1/(yu*yv)}, yw])/4 + 
     (G[{0, yu}, yv^(-1)]*G[{yv^(-1), yv^(-1), 1/(yu*yv)}, yw])/32 - 
     (G[{0, yv^(-1)}, yw]*G[{yv^(-1), yv^(-1), 1/(yu*yv)}, yw])/4 + 
     (G[{0, 1/(yu*yv)}, yw]*G[{yv^(-1), yv^(-1), 1/(yu*yv)}, yw])/4 + 
     (7*G[{1, yu^(-1)}, yw]*G[{yv^(-1), yv^(-1), 1/(yu*yv)}, yw])/32 + 
     (3*G[{1, yu}, yv^(-1)]*G[{yv^(-1), yv^(-1), 1/(yu*yv)}, yw])/32 + 
     (G[{1, yv^(-1)}, yw]*G[{yv^(-1), yv^(-1), 1/(yu*yv)}, yw])/8 + 
     (5*G[{1, 1/(yu*yv)}, yw]*G[{yv^(-1), yv^(-1), 1/(yu*yv)}, yw])/32 - 
     (9*G[{yu^(-1), 1/(yu*yv)}, yw]*G[{yv^(-1), yv^(-1), 1/(yu*yv)}, yw])/
      32 + (5*G[{yv^(-1), 1/(yu*yv)}, yw]*G[{yv^(-1), yv^(-1), 1/(yu*yv)}, 
        yw])/16 - (5*Pi^2*G[{yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/768 + 
     (G[{0}, yu^(-1)]^2*G[{yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/32 + 
     (G[{0}, yu^(-1)]*G[{0}, yv^(-1)]*G[{yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/
      16 + (G[{0}, yv^(-1)]^2*G[{yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/32 - 
     (G[{0}, yu^(-1)]*G[{0}, yw]*G[{yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/16 - 
     (G[{0}, yv^(-1)]*G[{0}, yw]*G[{yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/16 + 
     (G[{0}, yw]^2*G[{yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/32 + 
     (3*G[{0}, yu^(-1)]*G[{1}, yu^(-1)]*G[{yv^(-1), 1/(yu*yv), 1/(yu*yv)}, 
        yw])/8 + (3*G[{0}, yv^(-1)]*G[{1}, yu^(-1)]*
       G[{yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/8 - 
     (3*G[{0}, yw]*G[{1}, yu^(-1)]*G[{yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/
      8 - (13*G[{1}, yu^(-1)]^2*G[{yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/32 - 
     (G[{0}, yu^(-1)]*G[{1}, yv^(-1)]*G[{yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/
      4 - (G[{0}, yv^(-1)]*G[{1}, yv^(-1)]*G[{yv^(-1), 1/(yu*yv), 1/(yu*yv)}, 
        yw])/4 + (G[{0}, yw]*G[{1}, yv^(-1)]*
       G[{yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/4 - 
     (5*G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*G[{yv^(-1), 1/(yu*yv), 1/(yu*yv)}, 
        yw])/64 + (25*G[{1}, yv^(-1)]^2*G[{yv^(-1), 1/(yu*yv), 1/(yu*yv)}, 
        yw])/128 + (G[{0}, yu^(-1)]*G[{1}, yw]*
       G[{yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/8 + 
     (G[{0}, yv^(-1)]*G[{1}, yw]*G[{yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/8 - 
     (G[{0}, yw]*G[{1}, yw]*G[{yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/8 - 
     (G[{1}, yu^(-1)]*G[{1}, yw]*G[{yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/16 - 
     (7*G[{1}, yv^(-1)]*G[{1}, yw]*G[{yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/
      64 + (5*G[{1}, yw]^2*G[{yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/128 + 
     (3*G[{0}, yu^(-1)]*G[{yu^(-1)}, yw]*G[{yv^(-1), 1/(yu*yv), 1/(yu*yv)}, 
        yw])/8 + (3*G[{0}, yv^(-1)]*G[{yu^(-1)}, yw]*
       G[{yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/8 - 
     (3*G[{0}, yw]*G[{yu^(-1)}, yw]*G[{yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/
      8 - (G[{1}, yv^(-1)]*G[{yu^(-1)}, yw]*
       G[{yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/2 + 
     (G[{1}, yw]*G[{yu^(-1)}, yw]*G[{yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/4 + 
     (G[{yu^(-1)}, yw]^2*G[{yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/4 - 
     (G[{0}, yu^(-1)]*G[{yu}, yv^(-1)]*G[{yv^(-1), 1/(yu*yv), 1/(yu*yv)}, 
        yw])/4 - (G[{0}, yv^(-1)]*G[{yu}, yv^(-1)]*
       G[{yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/4 + 
     (G[{0}, yw]*G[{yu}, yv^(-1)]*G[{yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/4 + 
     (9*G[{1}, yu^(-1)]*G[{yu}, yv^(-1)]*G[{yv^(-1), 1/(yu*yv), 1/(yu*yv)}, 
        yw])/64 + (G[{1}, yv^(-1)]*G[{yu}, yv^(-1)]*
       G[{yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/4 - 
     (5*G[{1}, yw]*G[{yu}, yv^(-1)]*G[{yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/
      64 - (G[{yu^(-1)}, yw]*G[{yu}, yv^(-1)]*
       G[{yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/4 + 
     (7*G[{yu}, yv^(-1)]^2*G[{yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/128 - 
     (G[{0}, yu^(-1)]*G[{yv^(-1)}, yw]*G[{yv^(-1), 1/(yu*yv), 1/(yu*yv)}, 
        yw])/4 - (G[{0}, yv^(-1)]*G[{yv^(-1)}, yw]*
       G[{yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/4 + 
     (G[{0}, yw]*G[{yv^(-1)}, yw]*G[{yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/4 + 
     (41*G[{1}, yu^(-1)]*G[{yv^(-1)}, yw]*G[{yv^(-1), 1/(yu*yv), 1/(yu*yv)}, 
        yw])/64 + (9*G[{1}, yw]*G[{yv^(-1)}, yw]*
       G[{yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/64 - 
     (9*G[{yu}, yv^(-1)]*G[{yv^(-1)}, yw]*G[{yv^(-1), 1/(yu*yv), 1/(yu*yv)}, 
        yw])/64 - (41*G[{yv^(-1)}, yw]^2*G[{yv^(-1), 1/(yu*yv), 1/(yu*yv)}, 
        yw])/128 + (G[{0}, yu^(-1)]*G[{1/(yu*yv)}, yw]*
       G[{yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/8 + 
     (G[{0}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{yv^(-1), 1/(yu*yv), 1/(yu*yv)}, 
        yw])/8 - (G[{0}, yw]*G[{1/(yu*yv)}, yw]*
       G[{yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/8 - 
     (3*G[{1}, yu^(-1)]*G[{1/(yu*yv)}, yw]*G[{yv^(-1), 1/(yu*yv), 1/(yu*yv)}, 
        yw])/16 - (5*G[{1}, yv^(-1)]*G[{1/(yu*yv)}, yw]*
       G[{yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/64 - 
     (G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/
      64 + (5*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*
       G[{yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/64 + 
     (G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{yv^(-1), 1/(yu*yv), 1/(yu*yv)}, 
        yw])/64 + (3*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*
       G[{yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/16 + 
     (3*G[{0, 1}, yu^(-1)]*G[{yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/64 - 
     (G[{0, 1}, yv^(-1)]*G[{yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/64 - 
     (G[{0, 1}, yw]*G[{yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/8 + 
     (G[{0, yu^(-1)}, yw]*G[{yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/8 + 
     (G[{0, yu}, yv^(-1)]*G[{yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/64 + 
     (G[{0, yv^(-1)}, yw]*G[{yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/8 - 
     (G[{0, 1/(yu*yv)}, yw]*G[{yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/8 - 
     (9*G[{1, yu^(-1)}, yw]*G[{yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/64 - 
     (G[{1, yu}, yv^(-1)]*G[{yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/16 - 
     (5*G[{1, yv^(-1)}, yw]*G[{yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/64 - 
     (G[{1, 1/(yu*yv)}, yw]*G[{yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/32 + 
     (7*G[{yu^(-1), 1/(yu*yv)}, yw]*G[{yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/
      64 + (11*G[{yv^(-1), 1/(yu*yv)}, yw]*G[{yv^(-1), 1/(yu*yv), 1/(yu*yv)}, 
        yw])/64 + (5*G[{1}, yu^(-1)]*G[{0, 0, 1, 1}, yu^(-1)])/32 - 
     (5*G[{1}, yv^(-1)]*G[{0, 0, 1, 1}, yu^(-1)])/32 - 
     (3*G[{1}, yw]*G[{0, 0, 1, 1}, yu^(-1)])/32 + 
     (3*G[{1/(yu*yv)}, yw]*G[{0, 0, 1, 1}, yu^(-1)])/32 + 
     (G[{1}, yu^(-1)]*G[{0, 0, 1, 1}, yv^(-1)])/8 - 
     (G[{1}, yv^(-1)]*G[{0, 0, 1, 1}, yv^(-1)])/8 + 
     (G[{0}, yu^(-1)]*G[{0, 0, 1, 1}, yw])/8 + 
     (G[{0}, yv^(-1)]*G[{0, 0, 1, 1}, yw])/8 - 
     (G[{0}, yw]*G[{0, 0, 1, 1}, yw])/8 + 
     (3*G[{1}, yu^(-1)]*G[{0, 0, 1, 1}, yw])/16 - 
     (3*G[{1}, yv^(-1)]*G[{0, 0, 1, 1}, yw])/16 + 
     (G[{1}, yw]*G[{0, 0, 1, 1}, yw])/8 - 
     (G[{yu}, yv^(-1)]*G[{0, 0, 1, 1}, yw])/4 - 
     (G[{1/(yu*yv)}, yw]*G[{0, 0, 1, 1}, yw])/8 - 
     (G[{0}, yu^(-1)]*G[{0, 0, 1, yu^(-1)}, yw])/16 - 
     (G[{0}, yv^(-1)]*G[{0, 0, 1, yu^(-1)}, yw])/16 + 
     (G[{0}, yw]*G[{0, 0, 1, yu^(-1)}, yw])/16 - 
     (G[{1}, yu^(-1)]*G[{0, 0, 1, yu^(-1)}, yw])/4 + 
     (G[{1}, yv^(-1)]*G[{0, 0, 1, yu^(-1)}, yw])/8 - 
     (G[{1}, yw]*G[{0, 0, 1, yu^(-1)}, yw])/8 + 
     (G[{yu}, yv^(-1)]*G[{0, 0, 1, yu^(-1)}, yw])/4 + 
     (G[{1/(yu*yv)}, yw]*G[{0, 0, 1, yu^(-1)}, yw])/8 - 
     (G[{1}, yv^(-1)]*G[{0, 0, 1, yu}, yv^(-1)])/8 - 
     (G[{0}, yu^(-1)]*G[{0, 0, 1, yv^(-1)}, yw])/16 - 
     (G[{0}, yv^(-1)]*G[{0, 0, 1, yv^(-1)}, yw])/16 + 
     (G[{0}, yw]*G[{0, 0, 1, yv^(-1)}, yw])/16 - 
     (G[{1}, yu^(-1)]*G[{0, 0, 1, yv^(-1)}, yw])/4 + 
     (G[{1}, yv^(-1)]*G[{0, 0, 1, yv^(-1)}, yw])/8 - 
     (G[{1}, yw]*G[{0, 0, 1, yv^(-1)}, yw])/8 + 
     (G[{yu}, yv^(-1)]*G[{0, 0, 1, yv^(-1)}, yw])/4 + 
     (G[{1/(yu*yv)}, yw]*G[{0, 0, 1, yv^(-1)}, yw])/8 + 
     (5*G[{1}, yu^(-1)]*G[{0, 0, 1, 1/(yu*yv)}, yw])/16 - 
     (G[{1}, yv^(-1)]*G[{0, 0, 1, 1/(yu*yv)}, yw])/16 - 
     (G[{yu}, yv^(-1)]*G[{0, 0, 1, 1/(yu*yv)}, yw])/4 - 
     (G[{0}, yu^(-1)]*G[{0, 0, yu^(-1), 1}, yw])/16 - 
     (G[{0}, yv^(-1)]*G[{0, 0, yu^(-1), 1}, yw])/16 + 
     (G[{0}, yw]*G[{0, 0, yu^(-1), 1}, yw])/16 - 
     (3*G[{1}, yu^(-1)]*G[{0, 0, yu^(-1), 1}, yw])/16 + 
     (G[{1}, yv^(-1)]*G[{0, 0, yu^(-1), 1}, yw])/16 + 
     (G[{yu}, yv^(-1)]*G[{0, 0, yu^(-1), 1}, yw])/4 + 
     (G[{1}, yw]*G[{0, 0, yu^(-1), yv^(-1)}, yw])/8 - 
     (G[{1/(yu*yv)}, yw]*G[{0, 0, yu^(-1), yv^(-1)}, yw])/8 + 
     (G[{0}, yu^(-1)]*G[{0, 0, yu^(-1), 1/(yu*yv)}, yw])/16 + 
     (G[{0}, yv^(-1)]*G[{0, 0, yu^(-1), 1/(yu*yv)}, yw])/16 - 
     (G[{0}, yw]*G[{0, 0, yu^(-1), 1/(yu*yv)}, yw])/16 - 
     (G[{1}, yu^(-1)]*G[{0, 0, yu^(-1), 1/(yu*yv)}, yw])/16 - 
     (G[{1}, yv^(-1)]*G[{0, 0, yu^(-1), 1/(yu*yv)}, yw])/16 - 
     (G[{1}, yu^(-1)]*G[{0, 0, yu, 1}, yv^(-1)])/8 - 
     (G[{1}, yv^(-1)]*G[{0, 0, yu, 1}, yv^(-1)])/8 + 
     (G[{1}, yv^(-1)]*G[{0, 0, yu, yu}, yv^(-1)])/8 - 
     (G[{0}, yu^(-1)]*G[{0, 0, yv^(-1), 1}, yw])/16 - 
     (G[{0}, yv^(-1)]*G[{0, 0, yv^(-1), 1}, yw])/16 + 
     (G[{0}, yw]*G[{0, 0, yv^(-1), 1}, yw])/16 - 
     (5*G[{1}, yu^(-1)]*G[{0, 0, yv^(-1), 1}, yw])/16 + 
     (3*G[{1}, yv^(-1)]*G[{0, 0, yv^(-1), 1}, yw])/16 + 
     (G[{yu}, yv^(-1)]*G[{0, 0, yv^(-1), 1}, yw])/4 + 
     (G[{1}, yw]*G[{0, 0, yv^(-1), yu^(-1)}, yw])/8 - 
     (G[{1/(yu*yv)}, yw]*G[{0, 0, yv^(-1), yu^(-1)}, yw])/8 + 
     (G[{0}, yu^(-1)]*G[{0, 0, yv^(-1), 1/(yu*yv)}, yw])/16 + 
     (G[{0}, yv^(-1)]*G[{0, 0, yv^(-1), 1/(yu*yv)}, yw])/16 - 
     (G[{0}, yw]*G[{0, 0, yv^(-1), 1/(yu*yv)}, yw])/16 - 
     (G[{1}, yu^(-1)]*G[{0, 0, yv^(-1), 1/(yu*yv)}, yw])/16 - 
     (G[{1}, yv^(-1)]*G[{0, 0, yv^(-1), 1/(yu*yv)}, yw])/16 + 
     (5*G[{1}, yu^(-1)]*G[{0, 0, 1/(yu*yv), 1}, yw])/16 - 
     (G[{1}, yv^(-1)]*G[{0, 0, 1/(yu*yv), 1}, yw])/16 - 
     (G[{1}, yw]*G[{0, 0, 1/(yu*yv), 1}, yw])/8 - 
     (G[{yu}, yv^(-1)]*G[{0, 0, 1/(yu*yv), 1}, yw])/4 + 
     (G[{1/(yu*yv)}, yw]*G[{0, 0, 1/(yu*yv), 1}, yw])/8 + 
     (G[{0}, yu^(-1)]*G[{0, 0, 1/(yu*yv), yu^(-1)}, yw])/16 + 
     (G[{0}, yv^(-1)]*G[{0, 0, 1/(yu*yv), yu^(-1)}, yw])/16 - 
     (G[{0}, yw]*G[{0, 0, 1/(yu*yv), yu^(-1)}, yw])/16 - 
     (G[{1}, yv^(-1)]*G[{0, 0, 1/(yu*yv), yu^(-1)}, yw])/8 + 
     (G[{0}, yu^(-1)]*G[{0, 0, 1/(yu*yv), yv^(-1)}, yw])/16 + 
     (G[{0}, yv^(-1)]*G[{0, 0, 1/(yu*yv), yv^(-1)}, yw])/16 - 
     (G[{0}, yw]*G[{0, 0, 1/(yu*yv), yv^(-1)}, yw])/16 - 
     (G[{1}, yu^(-1)]*G[{0, 0, 1/(yu*yv), yv^(-1)}, yw])/8 - 
     (G[{0}, yu^(-1)]*G[{0, 0, 1/(yu*yv), 1/(yu*yv)}, yw])/8 - 
     (G[{0}, yv^(-1)]*G[{0, 0, 1/(yu*yv), 1/(yu*yv)}, yw])/8 + 
     (G[{0}, yw]*G[{0, 0, 1/(yu*yv), 1/(yu*yv)}, yw])/8 - 
     (3*G[{1}, yu^(-1)]*G[{0, 0, 1/(yu*yv), 1/(yu*yv)}, yw])/16 + 
     (3*G[{1}, yv^(-1)]*G[{0, 0, 1/(yu*yv), 1/(yu*yv)}, yw])/16 + 
     (G[{yu}, yv^(-1)]*G[{0, 0, 1/(yu*yv), 1/(yu*yv)}, yw])/4 - 
     (G[{1}, yu^(-1)]*G[{0, 1, 0, yu^(-1)}, yw])/8 + 
     (G[{yu}, yv^(-1)]*G[{0, 1, 0, yu^(-1)}, yw])/8 - 
     (G[{1}, yv^(-1)]*G[{0, 1, 0, yu}, yv^(-1)])/8 - 
     (3*G[{1}, yu^(-1)]*G[{0, 1, 0, yv^(-1)}, yw])/16 + 
     (G[{1}, yv^(-1)]*G[{0, 1, 0, yv^(-1)}, yw])/16 + 
     (G[{yu}, yv^(-1)]*G[{0, 1, 0, yv^(-1)}, yw])/8 + 
     (5*G[{1}, yu^(-1)]*G[{0, 1, 0, 1/(yu*yv)}, yw])/16 - 
     (G[{1}, yv^(-1)]*G[{0, 1, 0, 1/(yu*yv)}, yw])/16 - 
     (G[{yu}, yv^(-1)]*G[{0, 1, 0, 1/(yu*yv)}, yw])/4 + 
     (15*G[{1}, yu^(-1)]*G[{0, 1, 1, 1}, yu^(-1)])/64 - 
     (15*G[{1}, yv^(-1)]*G[{0, 1, 1, 1}, yu^(-1)])/64 - 
     (9*G[{1}, yw]*G[{0, 1, 1, 1}, yu^(-1)])/64 + 
     (9*G[{1/(yu*yv)}, yw]*G[{0, 1, 1, 1}, yu^(-1)])/64 + 
     (5*G[{1}, yu^(-1)]*G[{0, 1, 1, 1}, yv^(-1)])/16 - 
     (3*G[{1}, yv^(-1)]*G[{0, 1, 1, 1}, yv^(-1)])/16 + 
     (G[{0}, yu^(-1)]*G[{0, 1, 1, 1}, yw])/8 + 
     (G[{0}, yv^(-1)]*G[{0, 1, 1, 1}, yw])/8 - 
     (G[{0}, yw]*G[{0, 1, 1, 1}, yw])/8 + 
     (G[{1}, yu^(-1)]*G[{0, 1, 1, 1}, yw])/8 - 
     (G[{1}, yv^(-1)]*G[{0, 1, 1, 1}, yw])/16 + 
     (G[{1}, yw]*G[{0, 1, 1, 1}, yw])/8 - 
     (5*G[{yu}, yv^(-1)]*G[{0, 1, 1, 1}, yw])/16 - 
     (G[{1/(yu*yv)}, yw]*G[{0, 1, 1, 1}, yw])/8 + 
     (3*G[{0}, yu^(-1)]*G[{0, 1, 1, yu^(-1)}, yw])/16 + 
     (3*G[{0}, yv^(-1)]*G[{0, 1, 1, yu^(-1)}, yw])/16 - 
     (3*G[{0}, yw]*G[{0, 1, 1, yu^(-1)}, yw])/16 - 
     (G[{1}, yv^(-1)]*G[{0, 1, 1, yu^(-1)}, yw])/4 - 
     (G[{yu}, yv^(-1)]*G[{0, 1, 1, yu^(-1)}, yw])/8 - 
     (G[{1}, yu^(-1)]*G[{0, 1, 1, yu}, yv^(-1)])/8 + 
     (5*G[{1}, yv^(-1)]*G[{0, 1, 1, yu}, yv^(-1)])/16 - 
     (G[{1}, yw]*G[{0, 1, 1, yu}, yv^(-1)])/8 + 
     (G[{1/(yu*yv)}, yw]*G[{0, 1, 1, yu}, yv^(-1)])/8 - 
     (3*G[{0}, yu^(-1)]*G[{0, 1, 1, yv^(-1)}, yw])/16 - 
     (3*G[{0}, yv^(-1)]*G[{0, 1, 1, yv^(-1)}, yw])/16 + 
     (3*G[{0}, yw]*G[{0, 1, 1, yv^(-1)}, yw])/16 + 
     (G[{1}, yu^(-1)]*G[{0, 1, 1, yv^(-1)}, yw])/2 - 
     (G[{yu}, yv^(-1)]*G[{0, 1, 1, yv^(-1)}, yw])/8 + 
     (G[{0}, yu^(-1)]*G[{0, 1, 1, 1/(yu*yv)}, yw])/8 + 
     (G[{0}, yv^(-1)]*G[{0, 1, 1, 1/(yu*yv)}, yw])/8 - 
     (G[{0}, yw]*G[{0, 1, 1, 1/(yu*yv)}, yw])/8 - 
     (G[{1}, yu^(-1)]*G[{0, 1, 1, 1/(yu*yv)}, yw])/4 - 
     (G[{1}, yv^(-1)]*G[{0, 1, 1, 1/(yu*yv)}, yw])/16 + 
     (G[{yu}, yv^(-1)]*G[{0, 1, 1, 1/(yu*yv)}, yw])/16 + 
     (3*G[{0}, yu^(-1)]*G[{0, 1, yu^(-1), 1}, yw])/16 + 
     (3*G[{0}, yv^(-1)]*G[{0, 1, yu^(-1), 1}, yw])/16 - 
     (3*G[{0}, yw]*G[{0, 1, yu^(-1), 1}, yw])/16 - 
     (3*G[{1}, yv^(-1)]*G[{0, 1, yu^(-1), 1}, yw])/16 - 
     (3*G[{yu}, yv^(-1)]*G[{0, 1, yu^(-1), 1}, yw])/16 - 
     (G[{0}, yu^(-1)]*G[{0, 1, yu^(-1), yu^(-1)}, yw])/4 - 
     (G[{0}, yv^(-1)]*G[{0, 1, yu^(-1), yu^(-1)}, yw])/4 + 
     (G[{0}, yw]*G[{0, 1, yu^(-1), yu^(-1)}, yw])/4 + 
     (G[{1}, yv^(-1)]*G[{0, 1, yu^(-1), yu^(-1)}, yw])/4 - 
     (G[{1}, yw]*G[{0, 1, yu^(-1), yu^(-1)}, yw])/8 + 
     (G[{yu}, yv^(-1)]*G[{0, 1, yu^(-1), yu^(-1)}, yw])/4 + 
     (G[{1/(yu*yv)}, yw]*G[{0, 1, yu^(-1), yu^(-1)}, yw])/8 - 
     (G[{1}, yw]*G[{0, 1, yu^(-1), yv^(-1)}, yw])/8 + 
     (G[{1/(yu*yv)}, yw]*G[{0, 1, yu^(-1), yv^(-1)}, yw])/8 - 
     (G[{0}, yu^(-1)]*G[{0, 1, yu^(-1), 1/(yu*yv)}, yw])/16 - 
     (G[{0}, yv^(-1)]*G[{0, 1, yu^(-1), 1/(yu*yv)}, yw])/16 + 
     (G[{0}, yw]*G[{0, 1, yu^(-1), 1/(yu*yv)}, yw])/16 - 
     (G[{1}, yu^(-1)]*G[{0, 1, yu^(-1), 1/(yu*yv)}, yw])/4 + 
     (3*G[{1}, yv^(-1)]*G[{0, 1, yu^(-1), 1/(yu*yv)}, yw])/16 + 
     (3*G[{yu}, yv^(-1)]*G[{0, 1, yu^(-1), 1/(yu*yv)}, yw])/16 - 
     (G[{1}, yu^(-1)]*G[{0, 1, yu, 1}, yv^(-1)])/8 + 
     (G[{1}, yv^(-1)]*G[{0, 1, yu, 1}, yv^(-1)])/4 - 
     (G[{1}, yw]*G[{0, 1, yu, 1}, yv^(-1)])/8 + 
     (G[{1/(yu*yv)}, yw]*G[{0, 1, yu, 1}, yv^(-1)])/8 - 
     (G[{1}, yv^(-1)]*G[{0, 1, yu, yu}, yv^(-1)])/4 + 
     (G[{1}, yw]*G[{0, 1, yu, yu}, yv^(-1)])/8 - 
     (G[{1/(yu*yv)}, yw]*G[{0, 1, yu, yu}, yv^(-1)])/8 + 
     (3*G[{1}, yu^(-1)]*G[{0, 1, yv^(-1), 1}, yw])/8 - 
     (3*G[{1}, yv^(-1)]*G[{0, 1, yv^(-1), 1}, yw])/16 - 
     (3*G[{yu}, yv^(-1)]*G[{0, 1, yv^(-1), 1}, yw])/16 - 
     (G[{1}, yw]*G[{0, 1, yv^(-1), yu^(-1)}, yw])/8 + 
     (G[{1/(yu*yv)}, yw]*G[{0, 1, yv^(-1), yu^(-1)}, yw])/8 + 
     (G[{0}, yu^(-1)]*G[{0, 1, yv^(-1), yv^(-1)}, yw])/8 + 
     (G[{0}, yv^(-1)]*G[{0, 1, yv^(-1), yv^(-1)}, yw])/8 - 
     (G[{0}, yw]*G[{0, 1, yv^(-1), yv^(-1)}, yw])/8 - 
     (G[{1}, yu^(-1)]*G[{0, 1, yv^(-1), yv^(-1)}, yw])/2 - 
     (G[{1}, yw]*G[{0, 1, yv^(-1), yv^(-1)}, yw])/8 + 
     (G[{yu}, yv^(-1)]*G[{0, 1, yv^(-1), yv^(-1)}, yw])/4 + 
     (G[{1/(yu*yv)}, yw]*G[{0, 1, yv^(-1), yv^(-1)}, yw])/8 - 
     (G[{0}, yu^(-1)]*G[{0, 1, yv^(-1), 1/(yu*yv)}, yw])/4 - 
     (G[{0}, yv^(-1)]*G[{0, 1, yv^(-1), 1/(yu*yv)}, yw])/4 + 
     (G[{0}, yw]*G[{0, 1, yv^(-1), 1/(yu*yv)}, yw])/4 + 
     (5*G[{1}, yv^(-1)]*G[{0, 1, yv^(-1), 1/(yu*yv)}, yw])/16 + 
     (3*G[{yu}, yv^(-1)]*G[{0, 1, yv^(-1), 1/(yu*yv)}, yw])/16 - 
     (G[{0}, yu^(-1)]*G[{0, 1, 1/(yu*yv), 1}, yw])/16 - 
     (G[{0}, yv^(-1)]*G[{0, 1, 1/(yu*yv), 1}, yw])/16 + 
     (G[{0}, yw]*G[{0, 1, 1/(yu*yv), 1}, yw])/16 - 
     (G[{1}, yu^(-1)]*G[{0, 1, 1/(yu*yv), 1}, yw])/8 + 
     (G[{1}, yv^(-1)]*G[{0, 1, 1/(yu*yv), 1}, yw])/16 + 
     (3*G[{yu}, yv^(-1)]*G[{0, 1, 1/(yu*yv), 1}, yw])/16 + 
     (G[{1}, yv^(-1)]*G[{0, 1, 1/(yu*yv), yu^(-1)}, yw])/8 - 
     (G[{yu}, yv^(-1)]*G[{0, 1, 1/(yu*yv), yu^(-1)}, yw])/8 + 
     (G[{1}, yu^(-1)]*G[{0, 1, 1/(yu*yv), yv^(-1)}, yw])/8 - 
     (G[{yu}, yv^(-1)]*G[{0, 1, 1/(yu*yv), yv^(-1)}, yw])/8 + 
     (G[{0}, yu^(-1)]*G[{0, 1, 1/(yu*yv), 1/(yu*yv)}, yw])/16 + 
     (G[{0}, yv^(-1)]*G[{0, 1, 1/(yu*yv), 1/(yu*yv)}, yw])/16 - 
     (G[{0}, yw]*G[{0, 1, 1/(yu*yv), 1/(yu*yv)}, yw])/16 - 
     (3*G[{1}, yv^(-1)]*G[{0, 1, 1/(yu*yv), 1/(yu*yv)}, yw])/16 + 
     (G[{yu}, yv^(-1)]*G[{0, 1, 1/(yu*yv), 1/(yu*yv)}, yw])/16 - 
     (G[{1}, yu^(-1)]*G[{0, yu^(-1), 0, 1/(yu*yv)}, yw])/8 + 
     (G[{yu}, yv^(-1)]*G[{0, yu^(-1), 0, 1/(yu*yv)}, yw])/8 - 
     (G[{0}, yu^(-1)]*G[{0, yu^(-1), 1, yu^(-1)}, yw])/8 - 
     (G[{0}, yv^(-1)]*G[{0, yu^(-1), 1, yu^(-1)}, yw])/8 + 
     (G[{0}, yw]*G[{0, yu^(-1), 1, yu^(-1)}, yw])/8 + 
     (G[{1}, yv^(-1)]*G[{0, yu^(-1), 1, yu^(-1)}, yw])/8 + 
     (G[{yu}, yv^(-1)]*G[{0, yu^(-1), 1, yu^(-1)}, yw])/8 - 
     (G[{1}, yu^(-1)]*G[{0, yu^(-1), 1, yv^(-1)}, yw])/8 + 
     (G[{yu}, yv^(-1)]*G[{0, yu^(-1), 1, yv^(-1)}, yw])/8 - 
     (G[{0}, yu^(-1)]*G[{0, yu^(-1), yu^(-1), 1}, yw])/8 - 
     (G[{0}, yv^(-1)]*G[{0, yu^(-1), yu^(-1), 1}, yw])/8 + 
     (G[{0}, yw]*G[{0, yu^(-1), yu^(-1), 1}, yw])/8 - 
     (G[{1}, yu^(-1)]*G[{0, yu^(-1), yu^(-1), 1}, yw])/8 + 
     (G[{1}, yv^(-1)]*G[{0, yu^(-1), yu^(-1), 1}, yw])/8 + 
     (G[{yu}, yv^(-1)]*G[{0, yu^(-1), yu^(-1), 1}, yw])/4 + 
     (G[{1}, yw]*G[{0, yu^(-1), yu^(-1), yv^(-1)}, yw])/8 - 
     (G[{1/(yu*yv)}, yw]*G[{0, yu^(-1), yu^(-1), yv^(-1)}, yw])/8 + 
     (G[{0}, yu^(-1)]*G[{0, yu^(-1), yu^(-1), 1/(yu*yv)}, yw])/8 + 
     (G[{0}, yv^(-1)]*G[{0, yu^(-1), yu^(-1), 1/(yu*yv)}, yw])/8 - 
     (G[{0}, yw]*G[{0, yu^(-1), yu^(-1), 1/(yu*yv)}, yw])/8 + 
     (G[{1}, yu^(-1)]*G[{0, yu^(-1), yu^(-1), 1/(yu*yv)}, yw])/8 - 
     (G[{1}, yv^(-1)]*G[{0, yu^(-1), yu^(-1), 1/(yu*yv)}, yw])/8 - 
     (G[{yu}, yv^(-1)]*G[{0, yu^(-1), yu^(-1), 1/(yu*yv)}, yw])/4 - 
     (3*G[{0}, yu^(-1)]*G[{0, yu^(-1), yv^(-1), 1}, yw])/16 - 
     (3*G[{0}, yv^(-1)]*G[{0, yu^(-1), yv^(-1), 1}, yw])/16 + 
     (3*G[{0}, yw]*G[{0, yu^(-1), yv^(-1), 1}, yw])/16 - 
     (G[{1}, yu^(-1)]*G[{0, yu^(-1), yv^(-1), 1}, yw])/8 + 
     (G[{1}, yv^(-1)]*G[{0, yu^(-1), yv^(-1), 1}, yw])/4 + 
     (G[{yu}, yv^(-1)]*G[{0, yu^(-1), yv^(-1), 1}, yw])/4 + 
     (G[{1}, yw]*G[{0, yu^(-1), yv^(-1), yu^(-1)}, yw])/8 - 
     (G[{1/(yu*yv)}, yw]*G[{0, yu^(-1), yv^(-1), yu^(-1)}, yw])/8 + 
     (G[{1}, yw]*G[{0, yu^(-1), yv^(-1), yv^(-1)}, yw])/8 - 
     (G[{1/(yu*yv)}, yw]*G[{0, yu^(-1), yv^(-1), yv^(-1)}, yw])/8 + 
     (3*G[{0}, yu^(-1)]*G[{0, yu^(-1), yv^(-1), 1/(yu*yv)}, yw])/16 + 
     (3*G[{0}, yv^(-1)]*G[{0, yu^(-1), yv^(-1), 1/(yu*yv)}, yw])/16 - 
     (3*G[{0}, yw]*G[{0, yu^(-1), yv^(-1), 1/(yu*yv)}, yw])/16 + 
     (G[{1}, yu^(-1)]*G[{0, yu^(-1), yv^(-1), 1/(yu*yv)}, yw])/8 - 
     (G[{1}, yv^(-1)]*G[{0, yu^(-1), yv^(-1), 1/(yu*yv)}, yw])/4 - 
     (G[{yu}, yv^(-1)]*G[{0, yu^(-1), yv^(-1), 1/(yu*yv)}, yw])/4 + 
     (G[{0}, yu^(-1)]*G[{0, yu^(-1), 1/(yu*yv), 1}, yw])/8 + 
     (G[{0}, yv^(-1)]*G[{0, yu^(-1), 1/(yu*yv), 1}, yw])/8 - 
     (G[{0}, yw]*G[{0, yu^(-1), 1/(yu*yv), 1}, yw])/8 - 
     (G[{1}, yu^(-1)]*G[{0, yu^(-1), 1/(yu*yv), 1}, yw])/8 - 
     (G[{1}, yv^(-1)]*G[{0, yu^(-1), 1/(yu*yv), 1}, yw])/8 + 
     (G[{0}, yu^(-1)]*G[{0, yu^(-1), 1/(yu*yv), yu^(-1)}, yw])/8 + 
     (G[{0}, yv^(-1)]*G[{0, yu^(-1), 1/(yu*yv), yu^(-1)}, yw])/8 - 
     (G[{0}, yw]*G[{0, yu^(-1), 1/(yu*yv), yu^(-1)}, yw])/8 - 
     (G[{1}, yv^(-1)]*G[{0, yu^(-1), 1/(yu*yv), yu^(-1)}, yw])/8 - 
     (G[{yu}, yv^(-1)]*G[{0, yu^(-1), 1/(yu*yv), yu^(-1)}, yw])/8 + 
     (G[{1}, yu^(-1)]*G[{0, yu^(-1), 1/(yu*yv), yv^(-1)}, yw])/8 - 
     (G[{yu}, yv^(-1)]*G[{0, yu^(-1), 1/(yu*yv), yv^(-1)}, yw])/8 - 
     (G[{0}, yu^(-1)]*G[{0, yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/8 - 
     (G[{0}, yv^(-1)]*G[{0, yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/8 + 
     (G[{0}, yw]*G[{0, yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/8 + 
     (G[{1}, yu^(-1)]*G[{0, yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/8 + 
     (G[{1}, yv^(-1)]*G[{0, yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/8 - 
     (5*G[{1}, yu^(-1)]*G[{0, yu, 1, 1}, yv^(-1)])/16 + 
     (3*G[{1}, yv^(-1)]*G[{0, yu, 1, 1}, yv^(-1)])/16 - 
     (G[{1}, yw]*G[{0, yu, 1, 1}, yv^(-1)])/8 + 
     (G[{1/(yu*yv)}, yw]*G[{0, yu, 1, 1}, yv^(-1)])/8 + 
     (G[{1}, yu^(-1)]*G[{0, yu, 1, yu}, yv^(-1)])/8 - 
     (5*G[{1}, yv^(-1)]*G[{0, yu, 1, yu}, yv^(-1)])/16 + 
     (G[{1}, yw]*G[{0, yu, 1, yu}, yv^(-1)])/8 - 
     (G[{1/(yu*yv)}, yw]*G[{0, yu, 1, yu}, yv^(-1)])/8 + 
     (G[{1}, yu^(-1)]*G[{0, yu, yu, 1}, yv^(-1)])/8 - 
     (G[{1}, yv^(-1)]*G[{0, yu, yu, 1}, yv^(-1)])/4 + 
     (G[{1}, yw]*G[{0, yu, yu, 1}, yv^(-1)])/8 - 
     (G[{1/(yu*yv)}, yw]*G[{0, yu, yu, 1}, yv^(-1)])/8 + 
     (G[{1}, yv^(-1)]*G[{0, yu, yu, yu}, yv^(-1)])/4 - 
     (3*G[{1}, yu^(-1)]*G[{0, yv^(-1), 0, 1/(yu*yv)}, yw])/16 + 
     (G[{1}, yv^(-1)]*G[{0, yv^(-1), 0, 1/(yu*yv)}, yw])/16 + 
     (G[{yu}, yv^(-1)]*G[{0, yv^(-1), 0, 1/(yu*yv)}, yw])/8 - 
     (3*G[{0}, yu^(-1)]*G[{0, yv^(-1), 1, yu^(-1)}, yw])/16 - 
     (3*G[{0}, yv^(-1)]*G[{0, yv^(-1), 1, yu^(-1)}, yw])/16 + 
     (3*G[{0}, yw]*G[{0, yv^(-1), 1, yu^(-1)}, yw])/16 + 
     (G[{1}, yv^(-1)]*G[{0, yv^(-1), 1, yu^(-1)}, yw])/4 + 
     (G[{yu}, yv^(-1)]*G[{0, yv^(-1), 1, yu^(-1)}, yw])/8 + 
     (G[{0}, yu^(-1)]*G[{0, yv^(-1), 1, yv^(-1)}, yw])/16 + 
     (G[{0}, yv^(-1)]*G[{0, yv^(-1), 1, yv^(-1)}, yw])/16 - 
     (G[{0}, yw]*G[{0, yv^(-1), 1, yv^(-1)}, yw])/16 - 
     (G[{1}, yu^(-1)]*G[{0, yv^(-1), 1, yv^(-1)}, yw])/4 + 
     (G[{yu}, yv^(-1)]*G[{0, yv^(-1), 1, yv^(-1)}, yw])/8 - 
     (3*G[{0}, yu^(-1)]*G[{0, yv^(-1), yu^(-1), 1}, yw])/16 - 
     (3*G[{0}, yv^(-1)]*G[{0, yv^(-1), yu^(-1), 1}, yw])/16 + 
     (3*G[{0}, yw]*G[{0, yv^(-1), yu^(-1), 1}, yw])/16 - 
     (G[{1}, yu^(-1)]*G[{0, yv^(-1), yu^(-1), 1}, yw])/8 + 
     (G[{1}, yv^(-1)]*G[{0, yv^(-1), yu^(-1), 1}, yw])/4 + 
     (G[{yu}, yv^(-1)]*G[{0, yv^(-1), yu^(-1), 1}, yw])/4 + 
     (G[{1}, yw]*G[{0, yv^(-1), yu^(-1), yu^(-1)}, yw])/8 - 
     (G[{1/(yu*yv)}, yw]*G[{0, yv^(-1), yu^(-1), yu^(-1)}, yw])/8 + 
     (G[{1}, yw]*G[{0, yv^(-1), yu^(-1), yv^(-1)}, yw])/8 - 
     (G[{1/(yu*yv)}, yw]*G[{0, yv^(-1), yu^(-1), yv^(-1)}, yw])/8 + 
     (3*G[{0}, yu^(-1)]*G[{0, yv^(-1), yu^(-1), 1/(yu*yv)}, yw])/16 + 
     (3*G[{0}, yv^(-1)]*G[{0, yv^(-1), yu^(-1), 1/(yu*yv)}, yw])/16 - 
     (3*G[{0}, yw]*G[{0, yv^(-1), yu^(-1), 1/(yu*yv)}, yw])/16 + 
     (G[{1}, yu^(-1)]*G[{0, yv^(-1), yu^(-1), 1/(yu*yv)}, yw])/8 - 
     (G[{1}, yv^(-1)]*G[{0, yv^(-1), yu^(-1), 1/(yu*yv)}, yw])/4 - 
     (G[{yu}, yv^(-1)]*G[{0, yv^(-1), yu^(-1), 1/(yu*yv)}, yw])/4 - 
     (G[{0}, yu^(-1)]*G[{0, yv^(-1), yv^(-1), 1}, yw])/8 - 
     (G[{0}, yv^(-1)]*G[{0, yv^(-1), yv^(-1), 1}, yw])/8 + 
     (G[{0}, yw]*G[{0, yv^(-1), yv^(-1), 1}, yw])/8 - 
     (G[{1}, yu^(-1)]*G[{0, yv^(-1), yv^(-1), 1}, yw])/4 + 
     (G[{1}, yv^(-1)]*G[{0, yv^(-1), yv^(-1), 1}, yw])/4 + 
     (G[{yu}, yv^(-1)]*G[{0, yv^(-1), yv^(-1), 1}, yw])/4 + 
     (G[{1}, yw]*G[{0, yv^(-1), yv^(-1), yu^(-1)}, yw])/8 - 
     (G[{1/(yu*yv)}, yw]*G[{0, yv^(-1), yv^(-1), yu^(-1)}, yw])/8 + 
     (G[{0}, yu^(-1)]*G[{0, yv^(-1), yv^(-1), 1/(yu*yv)}, yw])/8 + 
     (G[{0}, yv^(-1)]*G[{0, yv^(-1), yv^(-1), 1/(yu*yv)}, yw])/8 - 
     (G[{0}, yw]*G[{0, yv^(-1), yv^(-1), 1/(yu*yv)}, yw])/8 + 
     (G[{1}, yu^(-1)]*G[{0, yv^(-1), yv^(-1), 1/(yu*yv)}, yw])/4 - 
     (G[{1}, yv^(-1)]*G[{0, yv^(-1), yv^(-1), 1/(yu*yv)}, yw])/4 - 
     (G[{yu}, yv^(-1)]*G[{0, yv^(-1), yv^(-1), 1/(yu*yv)}, yw])/4 + 
     (G[{0}, yu^(-1)]*G[{0, yv^(-1), 1/(yu*yv), 1}, yw])/8 + 
     (G[{0}, yv^(-1)]*G[{0, yv^(-1), 1/(yu*yv), 1}, yw])/8 - 
     (G[{0}, yw]*G[{0, yv^(-1), 1/(yu*yv), 1}, yw])/8 - 
     (G[{1}, yu^(-1)]*G[{0, yv^(-1), 1/(yu*yv), 1}, yw])/8 - 
     (G[{1}, yv^(-1)]*G[{0, yv^(-1), 1/(yu*yv), 1}, yw])/8 + 
     (3*G[{0}, yu^(-1)]*G[{0, yv^(-1), 1/(yu*yv), yu^(-1)}, yw])/16 + 
     (3*G[{0}, yv^(-1)]*G[{0, yv^(-1), 1/(yu*yv), yu^(-1)}, yw])/16 - 
     (3*G[{0}, yw]*G[{0, yv^(-1), 1/(yu*yv), yu^(-1)}, yw])/16 - 
     (G[{1}, yv^(-1)]*G[{0, yv^(-1), 1/(yu*yv), yu^(-1)}, yw])/4 - 
     (G[{yu}, yv^(-1)]*G[{0, yv^(-1), 1/(yu*yv), yu^(-1)}, yw])/8 - 
     (G[{0}, yu^(-1)]*G[{0, yv^(-1), 1/(yu*yv), yv^(-1)}, yw])/16 - 
     (G[{0}, yv^(-1)]*G[{0, yv^(-1), 1/(yu*yv), yv^(-1)}, yw])/16 + 
     (G[{0}, yw]*G[{0, yv^(-1), 1/(yu*yv), yv^(-1)}, yw])/16 + 
     (G[{1}, yu^(-1)]*G[{0, yv^(-1), 1/(yu*yv), yv^(-1)}, yw])/4 - 
     (G[{yu}, yv^(-1)]*G[{0, yv^(-1), 1/(yu*yv), yv^(-1)}, yw])/8 - 
     (G[{0}, yu^(-1)]*G[{0, yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/8 - 
     (G[{0}, yv^(-1)]*G[{0, yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/8 + 
     (G[{0}, yw]*G[{0, yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/8 + 
     (G[{1}, yu^(-1)]*G[{0, yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/8 + 
     (G[{1}, yv^(-1)]*G[{0, yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/8 - 
     (G[{0}, yu^(-1)]*G[{0, 1/(yu*yv), 1, 1}, yw])/8 - 
     (G[{0}, yv^(-1)]*G[{0, 1/(yu*yv), 1, 1}, yw])/8 + 
     (G[{0}, yw]*G[{0, 1/(yu*yv), 1, 1}, yw])/8 - 
     (G[{1}, yu^(-1)]*G[{0, 1/(yu*yv), 1, 1}, yw])/8 + 
     (G[{1}, yv^(-1)]*G[{0, 1/(yu*yv), 1, 1}, yw])/16 - 
     (G[{1}, yw]*G[{0, 1/(yu*yv), 1, 1}, yw])/8 + 
     (5*G[{yu}, yv^(-1)]*G[{0, 1/(yu*yv), 1, 1}, yw])/16 + 
     (G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv), 1, 1}, yw])/8 + 
     (G[{0}, yu^(-1)]*G[{0, 1/(yu*yv), 1, yu^(-1)}, yw])/8 + 
     (G[{0}, yv^(-1)]*G[{0, 1/(yu*yv), 1, yu^(-1)}, yw])/8 - 
     (G[{0}, yw]*G[{0, 1/(yu*yv), 1, yu^(-1)}, yw])/8 - 
     (G[{1}, yv^(-1)]*G[{0, 1/(yu*yv), 1, yu^(-1)}, yw])/8 - 
     (G[{yu}, yv^(-1)]*G[{0, 1/(yu*yv), 1, yu^(-1)}, yw])/8 + 
     (G[{0}, yu^(-1)]*G[{0, 1/(yu*yv), 1, yv^(-1)}, yw])/8 + 
     (G[{0}, yv^(-1)]*G[{0, 1/(yu*yv), 1, yv^(-1)}, yw])/8 - 
     (G[{0}, yw]*G[{0, 1/(yu*yv), 1, yv^(-1)}, yw])/8 - 
     (G[{1}, yu^(-1)]*G[{0, 1/(yu*yv), 1, yv^(-1)}, yw])/8 - 
     (G[{yu}, yv^(-1)]*G[{0, 1/(yu*yv), 1, yv^(-1)}, yw])/8 - 
     (G[{0}, yu^(-1)]*G[{0, 1/(yu*yv), 1, 1/(yu*yv)}, yw])/8 - 
     (G[{0}, yv^(-1)]*G[{0, 1/(yu*yv), 1, 1/(yu*yv)}, yw])/8 + 
     (G[{0}, yw]*G[{0, 1/(yu*yv), 1, 1/(yu*yv)}, yw])/8 + 
     (G[{1}, yu^(-1)]*G[{0, 1/(yu*yv), 1, 1/(yu*yv)}, yw])/4 + 
     (G[{1}, yv^(-1)]*G[{0, 1/(yu*yv), 1, 1/(yu*yv)}, yw])/16 - 
     (G[{yu}, yv^(-1)]*G[{0, 1/(yu*yv), 1, 1/(yu*yv)}, yw])/16 + 
     (G[{0}, yu^(-1)]*G[{0, 1/(yu*yv), yu^(-1), 1}, yw])/8 + 
     (G[{0}, yv^(-1)]*G[{0, 1/(yu*yv), yu^(-1), 1}, yw])/8 - 
     (G[{0}, yw]*G[{0, 1/(yu*yv), yu^(-1), 1}, yw])/8 + 
     (G[{1}, yu^(-1)]*G[{0, 1/(yu*yv), yu^(-1), 1}, yw])/4 - 
     (3*G[{1}, yv^(-1)]*G[{0, 1/(yu*yv), yu^(-1), 1}, yw])/16 - 
     (5*G[{yu}, yv^(-1)]*G[{0, 1/(yu*yv), yu^(-1), 1}, yw])/16 + 
     (G[{0}, yu^(-1)]*G[{0, 1/(yu*yv), yu^(-1), yu^(-1)}, yw])/4 + 
     (G[{0}, yv^(-1)]*G[{0, 1/(yu*yv), yu^(-1), yu^(-1)}, yw])/4 - 
     (G[{0}, yw]*G[{0, 1/(yu*yv), yu^(-1), yu^(-1)}, yw])/4 - 
     (G[{1}, yv^(-1)]*G[{0, 1/(yu*yv), yu^(-1), yu^(-1)}, yw])/4 - 
     (G[{yu}, yv^(-1)]*G[{0, 1/(yu*yv), yu^(-1), yu^(-1)}, yw])/4 - 
     (G[{1}, yw]*G[{0, 1/(yu*yv), yu^(-1), yv^(-1)}, yw])/8 + 
     (G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv), yu^(-1), yv^(-1)}, yw])/8 - 
     (G[{0}, yu^(-1)]*G[{0, 1/(yu*yv), yu^(-1), 1/(yu*yv)}, yw])/4 - 
     (G[{0}, yv^(-1)]*G[{0, 1/(yu*yv), yu^(-1), 1/(yu*yv)}, yw])/4 + 
     (G[{0}, yw]*G[{0, 1/(yu*yv), yu^(-1), 1/(yu*yv)}, yw])/4 + 
     (3*G[{1}, yv^(-1)]*G[{0, 1/(yu*yv), yu^(-1), 1/(yu*yv)}, yw])/16 + 
     (5*G[{yu}, yv^(-1)]*G[{0, 1/(yu*yv), yu^(-1), 1/(yu*yv)}, yw])/16 + 
     (5*G[{0}, yu^(-1)]*G[{0, 1/(yu*yv), yv^(-1), 1}, yw])/16 + 
     (5*G[{0}, yv^(-1)]*G[{0, 1/(yu*yv), yv^(-1), 1}, yw])/16 - 
     (5*G[{0}, yw]*G[{0, 1/(yu*yv), yv^(-1), 1}, yw])/16 - 
     (5*G[{1}, yv^(-1)]*G[{0, 1/(yu*yv), yv^(-1), 1}, yw])/16 - 
     (5*G[{yu}, yv^(-1)]*G[{0, 1/(yu*yv), yv^(-1), 1}, yw])/16 - 
     (G[{1}, yw]*G[{0, 1/(yu*yv), yv^(-1), yu^(-1)}, yw])/8 + 
     (G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv), yv^(-1), yu^(-1)}, yw])/8 - 
     (G[{0}, yu^(-1)]*G[{0, 1/(yu*yv), yv^(-1), yv^(-1)}, yw])/8 - 
     (G[{0}, yv^(-1)]*G[{0, 1/(yu*yv), yv^(-1), yv^(-1)}, yw])/8 + 
     (G[{0}, yw]*G[{0, 1/(yu*yv), yv^(-1), yv^(-1)}, yw])/8 + 
     (G[{1}, yu^(-1)]*G[{0, 1/(yu*yv), yv^(-1), yv^(-1)}, yw])/2 - 
     (G[{yu}, yv^(-1)]*G[{0, 1/(yu*yv), yv^(-1), yv^(-1)}, yw])/4 - 
     (G[{0}, yu^(-1)]*G[{0, 1/(yu*yv), yv^(-1), 1/(yu*yv)}, yw])/16 - 
     (G[{0}, yv^(-1)]*G[{0, 1/(yu*yv), yv^(-1), 1/(yu*yv)}, yw])/16 + 
     (G[{0}, yw]*G[{0, 1/(yu*yv), yv^(-1), 1/(yu*yv)}, yw])/16 - 
     (3*G[{1}, yu^(-1)]*G[{0, 1/(yu*yv), yv^(-1), 1/(yu*yv)}, yw])/8 + 
     (3*G[{1}, yv^(-1)]*G[{0, 1/(yu*yv), yv^(-1), 1/(yu*yv)}, yw])/16 + 
     (5*G[{yu}, yv^(-1)]*G[{0, 1/(yu*yv), yv^(-1), 1/(yu*yv)}, yw])/16 - 
     (3*G[{0}, yu^(-1)]*G[{0, 1/(yu*yv), 1/(yu*yv), 1}, yw])/16 - 
     (3*G[{0}, yv^(-1)]*G[{0, 1/(yu*yv), 1/(yu*yv), 1}, yw])/16 + 
     (3*G[{0}, yw]*G[{0, 1/(yu*yv), 1/(yu*yv), 1}, yw])/16 + 
     (3*G[{1}, yu^(-1)]*G[{0, 1/(yu*yv), 1/(yu*yv), 1}, yw])/8 + 
     (3*G[{1}, yv^(-1)]*G[{0, 1/(yu*yv), 1/(yu*yv), 1}, yw])/16 - 
     (3*G[{yu}, yv^(-1)]*G[{0, 1/(yu*yv), 1/(yu*yv), 1}, yw])/16 - 
     (5*G[{0}, yu^(-1)]*G[{0, 1/(yu*yv), 1/(yu*yv), yu^(-1)}, yw])/16 - 
     (5*G[{0}, yv^(-1)]*G[{0, 1/(yu*yv), 1/(yu*yv), yu^(-1)}, yw])/16 + 
     (5*G[{0}, yw]*G[{0, 1/(yu*yv), 1/(yu*yv), yu^(-1)}, yw])/16 + 
     (G[{1}, yv^(-1)]*G[{0, 1/(yu*yv), 1/(yu*yv), yu^(-1)}, yw])/4 + 
     (3*G[{yu}, yv^(-1)]*G[{0, 1/(yu*yv), 1/(yu*yv), yu^(-1)}, yw])/8 + 
     (G[{0}, yu^(-1)]*G[{0, 1/(yu*yv), 1/(yu*yv), yv^(-1)}, yw])/16 + 
     (G[{0}, yv^(-1)]*G[{0, 1/(yu*yv), 1/(yu*yv), yv^(-1)}, yw])/16 - 
     (G[{0}, yw]*G[{0, 1/(yu*yv), 1/(yu*yv), yv^(-1)}, yw])/16 - 
     (G[{1}, yu^(-1)]*G[{0, 1/(yu*yv), 1/(yu*yv), yv^(-1)}, yw])/2 + 
     (3*G[{yu}, yv^(-1)]*G[{0, 1/(yu*yv), 1/(yu*yv), yv^(-1)}, yw])/8 + 
     (3*G[{0}, yu^(-1)]*G[{0, 1/(yu*yv), 1/(yu*yv), 1/(yu*yv)}, yw])/16 + 
     (3*G[{0}, yv^(-1)]*G[{0, 1/(yu*yv), 1/(yu*yv), 1/(yu*yv)}, yw])/16 - 
     (3*G[{0}, yw]*G[{0, 1/(yu*yv), 1/(yu*yv), 1/(yu*yv)}, yw])/16 - 
     (G[{1}, yu^(-1)]*G[{0, 1/(yu*yv), 1/(yu*yv), 1/(yu*yv)}, yw])/4 - 
     (G[{1}, yv^(-1)]*G[{0, 1/(yu*yv), 1/(yu*yv), 1/(yu*yv)}, yw])/16 - 
     (G[{yu}, yv^(-1)]*G[{0, 1/(yu*yv), 1/(yu*yv), 1/(yu*yv)}, yw])/16 + 
     (G[{0}, yu^(-1)]*G[{1, 1, 1, yu^(-1)}, yw])/4 + 
     (G[{0}, yv^(-1)]*G[{1, 1, 1, yu^(-1)}, yw])/4 - 
     (G[{0}, yw]*G[{1, 1, 1, yu^(-1)}, yw])/4 - 
     (3*G[{1}, yu^(-1)]*G[{1, 1, 1, yu^(-1)}, yw])/16 - 
     (G[{1}, yv^(-1)]*G[{1, 1, 1, yu^(-1)}, yw])/4 + 
     (G[{1}, yw]*G[{1, 1, 1, yu^(-1)}, yw])/16 - 
     (G[{yu}, yv^(-1)]*G[{1, 1, 1, yu^(-1)}, yw])/16 - 
     (G[{1/(yu*yv)}, yw]*G[{1, 1, 1, yu^(-1)}, yw])/8 + 
     (29*G[{1}, yu^(-1)]*G[{1, 1, 1, yu}, yv^(-1)])/64 + 
     (3*G[{1}, yv^(-1)]*G[{1, 1, 1, yu}, yv^(-1)])/16 + 
     (G[{1}, yw]*G[{1, 1, 1, yu}, yv^(-1)])/8 - 
     (G[{1/(yu*yv)}, yw]*G[{1, 1, 1, yu}, yv^(-1)])/8 + 
     (G[{0}, yu^(-1)]*G[{1, 1, 1, yv^(-1)}, yw])/16 + 
     (G[{0}, yv^(-1)]*G[{1, 1, 1, yv^(-1)}, yw])/16 - 
     (G[{0}, yw]*G[{1, 1, 1, yv^(-1)}, yw])/16 - 
     (G[{1}, yu^(-1)]*G[{1, 1, 1, yv^(-1)}, yw])/64 - 
     (3*G[{1}, yv^(-1)]*G[{1, 1, 1, yv^(-1)}, yw])/16 - 
     (5*G[{1}, yw]*G[{1, 1, 1, yv^(-1)}, yw])/64 + 
     (5*G[{yu}, yv^(-1)]*G[{1, 1, 1, yv^(-1)}, yw])/64 + 
     (G[{1/(yu*yv)}, yw]*G[{1, 1, 1, yv^(-1)}, yw])/64 - 
     (G[{0}, yu^(-1)]*G[{1, 1, 1, 1/(yu*yv)}, yw])/16 - 
     (G[{0}, yv^(-1)]*G[{1, 1, 1, 1/(yu*yv)}, yw])/16 + 
     (G[{0}, yw]*G[{1, 1, 1, 1/(yu*yv)}, yw])/16 + 
     (29*G[{1}, yu^(-1)]*G[{1, 1, 1, 1/(yu*yv)}, yw])/64 + 
     (5*G[{1}, yv^(-1)]*G[{1, 1, 1, 1/(yu*yv)}, yw])/16 + 
     (41*G[{1}, yw]*G[{1, 1, 1, 1/(yu*yv)}, yw])/64 - 
     (41*G[{yu}, yv^(-1)]*G[{1, 1, 1, 1/(yu*yv)}, yw])/64 - 
     (9*G[{1/(yu*yv)}, yw]*G[{1, 1, 1, 1/(yu*yv)}, yw])/64 - 
     (G[{0}, yu^(-1)]*G[{1, 1, yu^(-1), yu^(-1)}, yw])/8 - 
     (G[{0}, yv^(-1)]*G[{1, 1, yu^(-1), yu^(-1)}, yw])/8 + 
     (G[{0}, yw]*G[{1, 1, yu^(-1), yu^(-1)}, yw])/8 + 
     (G[{1}, yv^(-1)]*G[{1, 1, yu^(-1), yu^(-1)}, yw])/16 - 
     (3*G[{1}, yw]*G[{1, 1, yu^(-1), yu^(-1)}, yw])/16 + 
     (3*G[{yu}, yv^(-1)]*G[{1, 1, yu^(-1), yu^(-1)}, yw])/16 - 
     (G[{1/(yu*yv)}, yw]*G[{1, 1, yu^(-1), yu^(-1)}, yw])/8 - 
     (3*G[{0}, yu^(-1)]*G[{1, 1, yu^(-1), yv^(-1)}, yw])/8 - 
     (3*G[{0}, yv^(-1)]*G[{1, 1, yu^(-1), yv^(-1)}, yw])/8 + 
     (3*G[{0}, yw]*G[{1, 1, yu^(-1), yv^(-1)}, yw])/8 + 
     (G[{1}, yv^(-1)]*G[{1, 1, yu^(-1), yv^(-1)}, yw])/2 - 
     (G[{1}, yw]*G[{1, 1, yu^(-1), yv^(-1)}, yw])/4 + 
     (G[{yu}, yv^(-1)]*G[{1, 1, yu^(-1), yv^(-1)}, yw])/4 + 
     (3*G[{0}, yu^(-1)]*G[{1, 1, yu^(-1), 1/(yu*yv)}, yw])/8 + 
     (3*G[{0}, yv^(-1)]*G[{1, 1, yu^(-1), 1/(yu*yv)}, yw])/8 - 
     (3*G[{0}, yw]*G[{1, 1, yu^(-1), 1/(yu*yv)}, yw])/8 - 
     (3*G[{1}, yu^(-1)]*G[{1, 1, yu^(-1), 1/(yu*yv)}, yw])/16 - 
     (5*G[{1}, yv^(-1)]*G[{1, 1, yu^(-1), 1/(yu*yv)}, yw])/16 + 
     (G[{1}, yw]*G[{1, 1, yu^(-1), 1/(yu*yv)}, yw])/4 - 
     (G[{yu}, yv^(-1)]*G[{1, 1, yu^(-1), 1/(yu*yv)}, yw])/4 + 
     (9*G[{1}, yu^(-1)]*G[{1, 1, yu, yu}, yv^(-1)])/64 + 
     (5*G[{1}, yv^(-1)]*G[{1, 1, yu, yu}, yv^(-1)])/16 + 
     (G[{1}, yw]*G[{1, 1, yu, yu}, yv^(-1)])/32 - 
     (G[{1/(yu*yv)}, yw]*G[{1, 1, yu, yu}, yv^(-1)])/32 - 
     (3*G[{0}, yu^(-1)]*G[{1, 1, yv^(-1), yu^(-1)}, yw])/8 - 
     (3*G[{0}, yv^(-1)]*G[{1, 1, yv^(-1), yu^(-1)}, yw])/8 + 
     (3*G[{0}, yw]*G[{1, 1, yv^(-1), yu^(-1)}, yw])/8 + 
     (G[{1}, yv^(-1)]*G[{1, 1, yv^(-1), yu^(-1)}, yw])/2 - 
     (G[{1}, yw]*G[{1, 1, yv^(-1), yu^(-1)}, yw])/4 + 
     (G[{yu}, yv^(-1)]*G[{1, 1, yv^(-1), yu^(-1)}, yw])/4 + 
     (G[{0}, yu^(-1)]*G[{1, 1, yv^(-1), yv^(-1)}, yw])/4 + 
     (G[{0}, yv^(-1)]*G[{1, 1, yv^(-1), yv^(-1)}, yw])/4 - 
     (G[{0}, yw]*G[{1, 1, yv^(-1), yv^(-1)}, yw])/4 - 
     (41*G[{1}, yu^(-1)]*G[{1, 1, yv^(-1), yv^(-1)}, yw])/64 - 
     (9*G[{1}, yw]*G[{1, 1, yv^(-1), yv^(-1)}, yw])/64 + 
     (9*G[{yu}, yv^(-1)]*G[{1, 1, yv^(-1), yv^(-1)}, yw])/64 - 
     (5*G[{1/(yu*yv)}, yw]*G[{1, 1, yv^(-1), yv^(-1)}, yw])/64 + 
     (3*G[{0}, yu^(-1)]*G[{1, 1, yv^(-1), 1/(yu*yv)}, yw])/16 + 
     (3*G[{0}, yv^(-1)]*G[{1, 1, yv^(-1), 1/(yu*yv)}, yw])/16 - 
     (3*G[{0}, yw]*G[{1, 1, yv^(-1), 1/(yu*yv)}, yw])/16 - 
     (G[{1}, yu^(-1)]*G[{1, 1, yv^(-1), 1/(yu*yv)}, yw])/8 - 
     (3*G[{1}, yv^(-1)]*G[{1, 1, yv^(-1), 1/(yu*yv)}, yw])/16 + 
     (G[{1}, yw]*G[{1, 1, yv^(-1), 1/(yu*yv)}, yw])/16 - 
     (G[{yu}, yv^(-1)]*G[{1, 1, yv^(-1), 1/(yu*yv)}, yw])/16 + 
     (3*G[{1/(yu*yv)}, yw]*G[{1, 1, yv^(-1), 1/(yu*yv)}, yw])/32 + 
     (G[{0}, yu^(-1)]*G[{1, 1, 1/(yu*yv), yu^(-1)}, yw])/8 + 
     (G[{0}, yv^(-1)]*G[{1, 1, 1/(yu*yv), yu^(-1)}, yw])/8 - 
     (G[{0}, yw]*G[{1, 1, 1/(yu*yv), yu^(-1)}, yw])/8 - 
     (G[{1}, yv^(-1)]*G[{1, 1, 1/(yu*yv), yu^(-1)}, yw])/16 + 
     (3*G[{1}, yw]*G[{1, 1, 1/(yu*yv), yu^(-1)}, yw])/16 - 
     (3*G[{yu}, yv^(-1)]*G[{1, 1, 1/(yu*yv), yu^(-1)}, yw])/16 + 
     (G[{1/(yu*yv)}, yw]*G[{1, 1, 1/(yu*yv), yu^(-1)}, yw])/8 + 
     (G[{0}, yu^(-1)]*G[{1, 1, 1/(yu*yv), yv^(-1)}, yw])/8 + 
     (G[{0}, yv^(-1)]*G[{1, 1, 1/(yu*yv), yv^(-1)}, yw])/8 - 
     (G[{0}, yw]*G[{1, 1, 1/(yu*yv), yv^(-1)}, yw])/8 - 
     (7*G[{1}, yu^(-1)]*G[{1, 1, 1/(yu*yv), yv^(-1)}, yw])/64 + 
     (9*G[{1}, yw]*G[{1, 1, 1/(yu*yv), yv^(-1)}, yw])/64 - 
     (9*G[{yu}, yv^(-1)]*G[{1, 1, 1/(yu*yv), yv^(-1)}, yw])/64 + 
     (5*G[{1/(yu*yv)}, yw]*G[{1, 1, 1/(yu*yv), yv^(-1)}, yw])/64 - 
     (G[{0}, yu^(-1)]*G[{1, 1, 1/(yu*yv), 1/(yu*yv)}, yw])/16 - 
     (G[{0}, yv^(-1)]*G[{1, 1, 1/(yu*yv), 1/(yu*yv)}, yw])/16 + 
     (G[{0}, yw]*G[{1, 1, 1/(yu*yv), 1/(yu*yv)}, yw])/16 + 
     (5*G[{1}, yu^(-1)]*G[{1, 1, 1/(yu*yv), 1/(yu*yv)}, yw])/16 + 
     (G[{1}, yv^(-1)]*G[{1, 1, 1/(yu*yv), 1/(yu*yv)}, yw])/8 + 
     (5*G[{1}, yw]*G[{1, 1, 1/(yu*yv), 1/(yu*yv)}, yw])/16 - 
     (5*G[{yu}, yv^(-1)]*G[{1, 1, 1/(yu*yv), 1/(yu*yv)}, yw])/16 - 
     (3*G[{1/(yu*yv)}, yw]*G[{1, 1, 1/(yu*yv), 1/(yu*yv)}, yw])/32 - 
     (3*G[{0}, yu^(-1)]*G[{1, yu^(-1), 1, yv^(-1)}, yw])/16 - 
     (3*G[{0}, yv^(-1)]*G[{1, yu^(-1), 1, yv^(-1)}, yw])/16 + 
     (3*G[{0}, yw]*G[{1, yu^(-1), 1, yv^(-1)}, yw])/16 + 
     (G[{1}, yu^(-1)]*G[{1, yu^(-1), 1, yv^(-1)}, yw])/8 + 
     (G[{1}, yv^(-1)]*G[{1, yu^(-1), 1, yv^(-1)}, yw])/4 + 
     (3*G[{0}, yu^(-1)]*G[{1, yu^(-1), 1, 1/(yu*yv)}, yw])/16 + 
     (3*G[{0}, yv^(-1)]*G[{1, yu^(-1), 1, 1/(yu*yv)}, yw])/16 - 
     (3*G[{0}, yw]*G[{1, yu^(-1), 1, 1/(yu*yv)}, yw])/16 - 
     (G[{1}, yu^(-1)]*G[{1, yu^(-1), 1, 1/(yu*yv)}, yw])/8 - 
     (G[{1}, yv^(-1)]*G[{1, yu^(-1), 1, 1/(yu*yv)}, yw])/8 + 
     (G[{1}, yw]*G[{1, yu^(-1), 1, 1/(yu*yv)}, yw])/8 - 
     (G[{yu}, yv^(-1)]*G[{1, yu^(-1), 1, 1/(yu*yv)}, yw])/8 - 
     (G[{0}, yu^(-1)]*G[{1, yu^(-1), yu^(-1), yu^(-1)}, yw])/4 - 
     (G[{0}, yv^(-1)]*G[{1, yu^(-1), yu^(-1), yu^(-1)}, yw])/4 + 
     (G[{0}, yw]*G[{1, yu^(-1), yu^(-1), yu^(-1)}, yw])/4 + 
     (G[{1}, yv^(-1)]*G[{1, yu^(-1), yu^(-1), yu^(-1)}, yw])/8 - 
     (3*G[{1}, yw]*G[{1, yu^(-1), yu^(-1), yu^(-1)}, yw])/8 + 
     (3*G[{yu}, yv^(-1)]*G[{1, yu^(-1), yu^(-1), yu^(-1)}, yw])/8 + 
     (G[{1/(yu*yv)}, yw]*G[{1, yu^(-1), yu^(-1), yv^(-1)}, yw])/8 - 
     (G[{0}, yu^(-1)]*G[{1, yu^(-1), yu^(-1), 1/(yu*yv)}, yw])/8 - 
     (G[{0}, yv^(-1)]*G[{1, yu^(-1), yu^(-1), 1/(yu*yv)}, yw])/8 + 
     (G[{0}, yw]*G[{1, yu^(-1), yu^(-1), 1/(yu*yv)}, yw])/8 - 
     (G[{1}, yu^(-1)]*G[{1, yu^(-1), yu^(-1), 1/(yu*yv)}, yw])/4 + 
     (3*G[{1}, yv^(-1)]*G[{1, yu^(-1), yu^(-1), 1/(yu*yv)}, yw])/16 - 
     (5*G[{1}, yw]*G[{1, yu^(-1), yu^(-1), 1/(yu*yv)}, yw])/16 + 
     (5*G[{yu}, yv^(-1)]*G[{1, yu^(-1), yu^(-1), 1/(yu*yv)}, yw])/16 + 
     (G[{1/(yu*yv)}, yw]*G[{1, yu^(-1), yv^(-1), yu^(-1)}, yw])/8 + 
     (G[{1/(yu*yv)}, yw]*G[{1, yu^(-1), yv^(-1), yv^(-1)}, yw])/8 - 
     (3*G[{0}, yu^(-1)]*G[{1, yu^(-1), yv^(-1), 1/(yu*yv)}, yw])/16 - 
     (3*G[{0}, yv^(-1)]*G[{1, yu^(-1), yv^(-1), 1/(yu*yv)}, yw])/16 + 
     (3*G[{0}, yw]*G[{1, yu^(-1), yv^(-1), 1/(yu*yv)}, yw])/16 - 
     (G[{1}, yu^(-1)]*G[{1, yu^(-1), yv^(-1), 1/(yu*yv)}, yw])/8 + 
     (G[{1}, yv^(-1)]*G[{1, yu^(-1), yv^(-1), 1/(yu*yv)}, yw])/4 - 
     (G[{1}, yw]*G[{1, yu^(-1), yv^(-1), 1/(yu*yv)}, yw])/4 + 
     (G[{yu}, yv^(-1)]*G[{1, yu^(-1), yv^(-1), 1/(yu*yv)}, yw])/4 - 
     (G[{0}, yu^(-1)]*G[{1, yu^(-1), 1/(yu*yv), yu^(-1)}, yw])/8 - 
     (G[{0}, yv^(-1)]*G[{1, yu^(-1), 1/(yu*yv), yu^(-1)}, yw])/8 + 
     (G[{0}, yw]*G[{1, yu^(-1), 1/(yu*yv), yu^(-1)}, yw])/8 + 
     (3*G[{1}, yv^(-1)]*G[{1, yu^(-1), 1/(yu*yv), yu^(-1)}, yw])/16 - 
     (G[{1}, yw]*G[{1, yu^(-1), 1/(yu*yv), yu^(-1)}, yw])/16 + 
     (G[{yu}, yv^(-1)]*G[{1, yu^(-1), 1/(yu*yv), yu^(-1)}, yw])/16 + 
     (3*G[{0}, yu^(-1)]*G[{1, yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/16 + 
     (3*G[{0}, yv^(-1)]*G[{1, yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/16 - 
     (3*G[{0}, yw]*G[{1, yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/16 - 
     (G[{1}, yu^(-1)]*G[{1, yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/16 - 
     (G[{1}, yv^(-1)]*G[{1, yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/8 + 
     (3*G[{1}, yw]*G[{1, yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/16 - 
     (3*G[{yu}, yv^(-1)]*G[{1, yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/16 - 
     (7*G[{1}, yu^(-1)]*G[{1, yu, yu, yu}, yv^(-1)])/32 + 
     (G[{1}, yv^(-1)]*G[{1, yu, yu, yu}, yv^(-1)])/8 - 
     (3*G[{1}, yw]*G[{1, yu, yu, yu}, yv^(-1)])/64 + 
     (3*G[{1/(yu*yv)}, yw]*G[{1, yu, yu, yu}, yv^(-1)])/64 + 
     (3*G[{0}, yu^(-1)]*G[{1, yv^(-1), 1, 1/(yu*yv)}, yw])/16 + 
     (3*G[{0}, yv^(-1)]*G[{1, yv^(-1), 1, 1/(yu*yv)}, yw])/16 - 
     (3*G[{0}, yw]*G[{1, yv^(-1), 1, 1/(yu*yv)}, yw])/16 - 
     (G[{1}, yu^(-1)]*G[{1, yv^(-1), 1, 1/(yu*yv)}, yw])/8 - 
     (G[{1}, yv^(-1)]*G[{1, yv^(-1), 1, 1/(yu*yv)}, yw])/8 + 
     (G[{1}, yw]*G[{1, yv^(-1), 1, 1/(yu*yv)}, yw])/8 - 
     (G[{yu}, yv^(-1)]*G[{1, yv^(-1), 1, 1/(yu*yv)}, yw])/8 + 
     (G[{1/(yu*yv)}, yw]*G[{1, yv^(-1), yu^(-1), yu^(-1)}, yw])/8 + 
     (G[{1/(yu*yv)}, yw]*G[{1, yv^(-1), yu^(-1), yv^(-1)}, yw])/8 - 
     (3*G[{0}, yu^(-1)]*G[{1, yv^(-1), yu^(-1), 1/(yu*yv)}, yw])/16 - 
     (3*G[{0}, yv^(-1)]*G[{1, yv^(-1), yu^(-1), 1/(yu*yv)}, yw])/16 + 
     (3*G[{0}, yw]*G[{1, yv^(-1), yu^(-1), 1/(yu*yv)}, yw])/16 - 
     (G[{1}, yu^(-1)]*G[{1, yv^(-1), yu^(-1), 1/(yu*yv)}, yw])/8 + 
     (G[{1}, yv^(-1)]*G[{1, yv^(-1), yu^(-1), 1/(yu*yv)}, yw])/4 - 
     (G[{1}, yw]*G[{1, yv^(-1), yu^(-1), 1/(yu*yv)}, yw])/4 + 
     (G[{yu}, yv^(-1)]*G[{1, yv^(-1), yu^(-1), 1/(yu*yv)}, yw])/4 + 
     (G[{1/(yu*yv)}, yw]*G[{1, yv^(-1), yv^(-1), yu^(-1)}, yw])/8 + 
     (G[{0}, yu^(-1)]*G[{1, yv^(-1), yv^(-1), yv^(-1)}, yw])/2 + 
     (G[{0}, yv^(-1)]*G[{1, yv^(-1), yv^(-1), yv^(-1)}, yw])/2 - 
     (G[{0}, yw]*G[{1, yv^(-1), yv^(-1), yv^(-1)}, yw])/2 - 
     (41*G[{1}, yu^(-1)]*G[{1, yv^(-1), yv^(-1), yv^(-1)}, yw])/32 - 
     (9*G[{1}, yw]*G[{1, yv^(-1), yv^(-1), yv^(-1)}, yw])/32 + 
     (9*G[{yu}, yv^(-1)]*G[{1, yv^(-1), yv^(-1), yv^(-1)}, yw])/32 - 
     (3*G[{1/(yu*yv)}, yw]*G[{1, yv^(-1), yv^(-1), yv^(-1)}, yw])/64 - 
     (G[{0}, yu^(-1)]*G[{1, yv^(-1), yv^(-1), 1/(yu*yv)}, yw])/2 - 
     (G[{0}, yv^(-1)]*G[{1, yv^(-1), yv^(-1), 1/(yu*yv)}, yw])/2 + 
     (G[{0}, yw]*G[{1, yv^(-1), yv^(-1), 1/(yu*yv)}, yw])/2 + 
     (9*G[{1}, yu^(-1)]*G[{1, yv^(-1), yv^(-1), 1/(yu*yv)}, yw])/64 + 
     (G[{1}, yv^(-1)]*G[{1, yv^(-1), yv^(-1), 1/(yu*yv)}, yw])/2 - 
     (23*G[{1}, yw]*G[{1, yv^(-1), yv^(-1), 1/(yu*yv)}, yw])/64 + 
     (23*G[{yu}, yv^(-1)]*G[{1, yv^(-1), yv^(-1), 1/(yu*yv)}, yw])/64 + 
     (3*G[{1/(yu*yv)}, yw]*G[{1, yv^(-1), yv^(-1), 1/(yu*yv)}, yw])/32 - 
     (G[{0}, yu^(-1)]*G[{1, yv^(-1), 1/(yu*yv), yv^(-1)}, yw])/8 - 
     (G[{0}, yv^(-1)]*G[{1, yv^(-1), 1/(yu*yv), yv^(-1)}, yw])/8 + 
     (G[{0}, yw]*G[{1, yv^(-1), 1/(yu*yv), yv^(-1)}, yw])/8 + 
     (9*G[{1}, yu^(-1)]*G[{1, yv^(-1), 1/(yu*yv), yv^(-1)}, yw])/64 - 
     (7*G[{1}, yw]*G[{1, yv^(-1), 1/(yu*yv), yv^(-1)}, yw])/64 + 
     (7*G[{yu}, yv^(-1)]*G[{1, yv^(-1), 1/(yu*yv), yv^(-1)}, yw])/64 + 
     (3*G[{1/(yu*yv)}, yw]*G[{1, yv^(-1), 1/(yu*yv), yv^(-1)}, yw])/32 + 
     (7*G[{1}, yu^(-1)]*G[{1, yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/64 - 
     (G[{1}, yv^(-1)]*G[{1, yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/16 + 
     (3*G[{1}, yw]*G[{1, yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/64 - 
     (3*G[{yu}, yv^(-1)]*G[{1, yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/64 - 
     (G[{0}, yu^(-1)]*G[{1, 1/(yu*yv), yu^(-1), yu^(-1)}, yw])/4 - 
     (G[{0}, yv^(-1)]*G[{1, 1/(yu*yv), yu^(-1), yu^(-1)}, yw])/4 + 
     (G[{0}, yw]*G[{1, 1/(yu*yv), yu^(-1), yu^(-1)}, yw])/4 + 
     (3*G[{1}, yv^(-1)]*G[{1, 1/(yu*yv), yu^(-1), yu^(-1)}, yw])/8 - 
     (G[{1}, yw]*G[{1, 1/(yu*yv), yu^(-1), yu^(-1)}, yw])/8 + 
     (G[{yu}, yv^(-1)]*G[{1, 1/(yu*yv), yu^(-1), yu^(-1)}, yw])/8 + 
     (G[{1/(yu*yv)}, yw]*G[{1, 1/(yu*yv), yu^(-1), yu^(-1)}, yw])/8 + 
     (3*G[{0}, yu^(-1)]*G[{1, 1/(yu*yv), yu^(-1), 1/(yu*yv)}, yw])/16 + 
     (3*G[{0}, yv^(-1)]*G[{1, 1/(yu*yv), yu^(-1), 1/(yu*yv)}, yw])/16 - 
     (3*G[{0}, yw]*G[{1, 1/(yu*yv), yu^(-1), 1/(yu*yv)}, yw])/16 - 
     (G[{1}, yu^(-1)]*G[{1, 1/(yu*yv), yu^(-1), 1/(yu*yv)}, yw])/8 - 
     (G[{1}, yv^(-1)]*G[{1, 1/(yu*yv), yu^(-1), 1/(yu*yv)}, yw])/16 + 
     (3*G[{1}, yw]*G[{1, 1/(yu*yv), yu^(-1), 1/(yu*yv)}, yw])/16 - 
     (3*G[{yu}, yv^(-1)]*G[{1, 1/(yu*yv), yu^(-1), 1/(yu*yv)}, yw])/16 - 
     (G[{0}, yu^(-1)]*G[{1, 1/(yu*yv), yv^(-1), yv^(-1)}, yw])/4 - 
     (G[{0}, yv^(-1)]*G[{1, 1/(yu*yv), yv^(-1), yv^(-1)}, yw])/4 + 
     (G[{0}, yw]*G[{1, 1/(yu*yv), yv^(-1), yv^(-1)}, yw])/4 + 
     (9*G[{1}, yu^(-1)]*G[{1, 1/(yu*yv), yv^(-1), yv^(-1)}, yw])/32 - 
     (7*G[{1}, yw]*G[{1, 1/(yu*yv), yv^(-1), yv^(-1)}, yw])/32 + 
     (7*G[{yu}, yv^(-1)]*G[{1, 1/(yu*yv), yv^(-1), yv^(-1)}, yw])/32 + 
     (11*G[{1/(yu*yv)}, yw]*G[{1, 1/(yu*yv), yv^(-1), yv^(-1)}, yw])/64 + 
     (3*G[{0}, yu^(-1)]*G[{1, 1/(yu*yv), yv^(-1), 1/(yu*yv)}, yw])/16 + 
     (3*G[{0}, yv^(-1)]*G[{1, 1/(yu*yv), yv^(-1), 1/(yu*yv)}, yw])/16 - 
     (3*G[{0}, yw]*G[{1, 1/(yu*yv), yv^(-1), 1/(yu*yv)}, yw])/16 - 
     (G[{1}, yu^(-1)]*G[{1, 1/(yu*yv), yv^(-1), 1/(yu*yv)}, yw])/64 - 
     (G[{1}, yv^(-1)]*G[{1, 1/(yu*yv), yv^(-1), 1/(yu*yv)}, yw])/8 + 
     (15*G[{1}, yw]*G[{1, 1/(yu*yv), yv^(-1), 1/(yu*yv)}, yw])/64 - 
     (15*G[{yu}, yv^(-1)]*G[{1, 1/(yu*yv), yv^(-1), 1/(yu*yv)}, yw])/64 - 
     (3*G[{1/(yu*yv)}, yw]*G[{1, 1/(yu*yv), yv^(-1), 1/(yu*yv)}, yw])/32 + 
     (G[{0}, yu^(-1)]*G[{1, 1/(yu*yv), 1/(yu*yv), yu^(-1)}, yw])/8 + 
     (G[{0}, yv^(-1)]*G[{1, 1/(yu*yv), 1/(yu*yv), yu^(-1)}, yw])/8 - 
     (G[{0}, yw]*G[{1, 1/(yu*yv), 1/(yu*yv), yu^(-1)}, yw])/8 + 
     (G[{1}, yv^(-1)]*G[{1, 1/(yu*yv), 1/(yu*yv), yu^(-1)}, yw])/16 + 
     (5*G[{1}, yw]*G[{1, 1/(yu*yv), 1/(yu*yv), yu^(-1)}, yw])/16 - 
     (5*G[{yu}, yv^(-1)]*G[{1, 1/(yu*yv), 1/(yu*yv), yu^(-1)}, yw])/16 + 
     (G[{0}, yu^(-1)]*G[{1, 1/(yu*yv), 1/(yu*yv), yv^(-1)}, yw])/8 + 
     (G[{0}, yv^(-1)]*G[{1, 1/(yu*yv), 1/(yu*yv), yv^(-1)}, yw])/8 - 
     (G[{0}, yw]*G[{1, 1/(yu*yv), 1/(yu*yv), yv^(-1)}, yw])/8 + 
     (7*G[{1}, yu^(-1)]*G[{1, 1/(yu*yv), 1/(yu*yv), yv^(-1)}, yw])/64 + 
     (23*G[{1}, yw]*G[{1, 1/(yu*yv), 1/(yu*yv), yv^(-1)}, yw])/64 - 
     (23*G[{yu}, yv^(-1)]*G[{1, 1/(yu*yv), 1/(yu*yv), yv^(-1)}, yw])/64 - 
     (3*G[{1/(yu*yv)}, yw]*G[{1, 1/(yu*yv), 1/(yu*yv), yv^(-1)}, yw])/32 - 
     (G[{0}, yu^(-1)]*G[{1, 1/(yu*yv), 1/(yu*yv), 1/(yu*yv)}, yw])/16 - 
     (G[{0}, yv^(-1)]*G[{1, 1/(yu*yv), 1/(yu*yv), 1/(yu*yv)}, yw])/16 + 
     (G[{0}, yw]*G[{1, 1/(yu*yv), 1/(yu*yv), 1/(yu*yv)}, yw])/16 - 
     (3*G[{1}, yu^(-1)]*G[{1, 1/(yu*yv), 1/(yu*yv), 1/(yu*yv)}, yw])/64 - 
     (3*G[{1}, yv^(-1)]*G[{1, 1/(yu*yv), 1/(yu*yv), 1/(yu*yv)}, yw])/16 - 
     (23*G[{1}, yw]*G[{1, 1/(yu*yv), 1/(yu*yv), 1/(yu*yv)}, yw])/64 + 
     (23*G[{yu}, yv^(-1)]*G[{1, 1/(yu*yv), 1/(yu*yv), 1/(yu*yv)}, yw])/64 - 
     (G[{0}, yu^(-1)]*G[{yu^(-1), yu^(-1), yu^(-1), 1/(yu*yv)}, yw])/4 - 
     (G[{0}, yv^(-1)]*G[{yu^(-1), yu^(-1), yu^(-1), 1/(yu*yv)}, yw])/4 + 
     (G[{0}, yw]*G[{yu^(-1), yu^(-1), yu^(-1), 1/(yu*yv)}, yw])/4 + 
     (G[{1}, yv^(-1)]*G[{yu^(-1), yu^(-1), yu^(-1), 1/(yu*yv)}, yw])/8 - 
     (3*G[{1}, yw]*G[{yu^(-1), yu^(-1), yu^(-1), 1/(yu*yv)}, yw])/8 - 
     (G[{yu^(-1)}, yw]*G[{yu^(-1), yu^(-1), yu^(-1), 1/(yu*yv)}, yw])/8 + 
     (3*G[{yu}, yv^(-1)]*G[{yu^(-1), yu^(-1), yu^(-1), 1/(yu*yv)}, yw])/8 + 
     (G[{1/(yu*yv)}, yw]*G[{yu^(-1), yu^(-1), 1/(yu*yv), yv^(-1)}, yw])/8 - 
     (G[{0}, yu^(-1)]*G[{yu^(-1), yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/8 - 
     (G[{0}, yv^(-1)]*G[{yu^(-1), yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/8 + 
     (G[{0}, yw]*G[{yu^(-1), yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/8 + 
     (G[{1}, yv^(-1)]*G[{yu^(-1), yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/16 - 
     (3*G[{1}, yw]*G[{yu^(-1), yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/16 - 
     (G[{yu^(-1)}, yw]*G[{yu^(-1), yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/16 + 
     (3*G[{yu}, yv^(-1)]*G[{yu^(-1), yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/
      16 - (G[{1/(yu*yv)}, yw]*G[{yu^(-1), 1/(yu*yv), yv^(-1), yv^(-1)}, yw])/
      8 + (3*G[{0}, yu^(-1)]*G[{yu^(-1), 1/(yu*yv), yv^(-1), 1/(yu*yv)}, yw])/
      16 + (3*G[{0}, yv^(-1)]*G[{yu^(-1), 1/(yu*yv), yv^(-1), 1/(yu*yv)}, 
        yw])/16 - (3*G[{0}, yw]*G[{yu^(-1), 1/(yu*yv), yv^(-1), 1/(yu*yv)}, 
        yw])/16 + (G[{1}, yu^(-1)]*G[{yu^(-1), 1/(yu*yv), yv^(-1), 
         1/(yu*yv)}, yw])/8 - (G[{1}, yv^(-1)]*
       G[{yu^(-1), 1/(yu*yv), yv^(-1), 1/(yu*yv)}, yw])/4 + 
     (G[{1}, yw]*G[{yu^(-1), 1/(yu*yv), yv^(-1), 1/(yu*yv)}, yw])/4 + 
     (G[{yu^(-1)}, yw]*G[{yu^(-1), 1/(yu*yv), yv^(-1), 1/(yu*yv)}, yw])/4 - 
     (G[{yu}, yv^(-1)]*G[{yu^(-1), 1/(yu*yv), yv^(-1), 1/(yu*yv)}, yw])/4 + 
     (G[{1}, yu^(-1)]*G[{yu^(-1), 1/(yu*yv), 1/(yu*yv), yv^(-1)}, yw])/4 + 
     (G[{1}, yw]*G[{yu^(-1), 1/(yu*yv), 1/(yu*yv), yv^(-1)}, yw])/4 - 
     (G[{yu}, yv^(-1)]*G[{yu^(-1), 1/(yu*yv), 1/(yu*yv), yv^(-1)}, yw])/4 - 
     (G[{0}, yu^(-1)]*G[{yu^(-1), 1/(yu*yv), 1/(yu*yv), 1/(yu*yv)}, yw])/16 - 
     (G[{0}, yv^(-1)]*G[{yu^(-1), 1/(yu*yv), 1/(yu*yv), 1/(yu*yv)}, yw])/16 + 
     (G[{0}, yw]*G[{yu^(-1), 1/(yu*yv), 1/(yu*yv), 1/(yu*yv)}, yw])/16 + 
     (3*G[{1}, yu^(-1)]*G[{yu^(-1), 1/(yu*yv), 1/(yu*yv), 1/(yu*yv)}, yw])/
      16 + (G[{1}, yv^(-1)]*G[{yu^(-1), 1/(yu*yv), 1/(yu*yv), 1/(yu*yv)}, 
        yw])/8 + (3*G[{1}, yw]*G[{yu^(-1), 1/(yu*yv), 1/(yu*yv), 1/(yu*yv)}, 
        yw])/16 - (G[{yu^(-1)}, yw]*G[{yu^(-1), 1/(yu*yv), 1/(yu*yv), 
         1/(yu*yv)}, yw])/8 - (3*G[{yu}, yv^(-1)]*
       G[{yu^(-1), 1/(yu*yv), 1/(yu*yv), 1/(yu*yv)}, yw])/16 + 
     (G[{0}, yu^(-1)]*G[{yv^(-1), yv^(-1), yv^(-1), 1/(yu*yv)}, yw])/2 + 
     (G[{0}, yv^(-1)]*G[{yv^(-1), yv^(-1), yv^(-1), 1/(yu*yv)}, yw])/2 - 
     (G[{0}, yw]*G[{yv^(-1), yv^(-1), yv^(-1), 1/(yu*yv)}, yw])/2 - 
     (41*G[{1}, yu^(-1)]*G[{yv^(-1), yv^(-1), yv^(-1), 1/(yu*yv)}, yw])/32 - 
     (9*G[{1}, yw]*G[{yv^(-1), yv^(-1), yv^(-1), 1/(yu*yv)}, yw])/32 + 
     (9*G[{yu}, yv^(-1)]*G[{yv^(-1), yv^(-1), yv^(-1), 1/(yu*yv)}, yw])/32 + 
     (41*G[{yv^(-1)}, yw]*G[{yv^(-1), yv^(-1), yv^(-1), 1/(yu*yv)}, yw])/32 - 
     (3*G[{1/(yu*yv)}, yw]*G[{yv^(-1), yv^(-1), yv^(-1), 1/(yu*yv)}, yw])/
      64 + (G[{0}, yu^(-1)]*G[{yv^(-1), yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/
      4 + (G[{0}, yv^(-1)]*G[{yv^(-1), yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/
      4 - (G[{0}, yw]*G[{yv^(-1), yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/4 - 
     (41*G[{1}, yu^(-1)]*G[{yv^(-1), yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/
      64 - (9*G[{1}, yw]*G[{yv^(-1), yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/
      64 + (9*G[{yu}, yv^(-1)]*G[{yv^(-1), yv^(-1), 1/(yu*yv), 1/(yu*yv)}, 
        yw])/64 + (41*G[{yv^(-1)}, yw]*G[{yv^(-1), yv^(-1), 1/(yu*yv), 
         1/(yu*yv)}, yw])/64 - (3*G[{1/(yu*yv)}, yw]*
       G[{yv^(-1), yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/32 - 
     (G[{0}, yu^(-1)]*G[{yv^(-1), 1/(yu*yv), 1/(yu*yv), 1/(yu*yv)}, yw])/4 - 
     (G[{0}, yv^(-1)]*G[{yv^(-1), 1/(yu*yv), 1/(yu*yv), 1/(yu*yv)}, yw])/4 + 
     (G[{0}, yw]*G[{yv^(-1), 1/(yu*yv), 1/(yu*yv), 1/(yu*yv)}, yw])/4 + 
     (23*G[{1}, yu^(-1)]*G[{yv^(-1), 1/(yu*yv), 1/(yu*yv), 1/(yu*yv)}, yw])/
      64 + (3*G[{1}, yv^(-1)]*G[{yv^(-1), 1/(yu*yv), 1/(yu*yv), 1/(yu*yv)}, 
        yw])/16 + (3*G[{1}, yw]*G[{yv^(-1), 1/(yu*yv), 1/(yu*yv), 1/(yu*yv)}, 
        yw])/64 - (3*G[{yu^(-1)}, yw]*G[{yv^(-1), 1/(yu*yv), 1/(yu*yv), 
         1/(yu*yv)}, yw])/16 - (3*G[{yu}, yv^(-1)]*
       G[{yv^(-1), 1/(yu*yv), 1/(yu*yv), 1/(yu*yv)}, yw])/64 - 
     (23*G[{yv^(-1)}, yw]*G[{yv^(-1), 1/(yu*yv), 1/(yu*yv), 1/(yu*yv)}, yw])/
      64 - (3*G[{0, 0, 0, 1, 1}, yu^(-1)])/16 + 
     (3*G[{0, 0, 0, 1, 1}, yv^(-1)])/8 + (3*G[{0, 0, 0, 1, 1}, yw])/8 - 
     (3*G[{0, 0, 0, 1, yu^(-1)}, yw])/16 - (3*G[{0, 0, 0, 1, yv^(-1)}, yw])/
      16 - (3*G[{0, 0, 0, yu^(-1), 1}, yw])/16 + 
     (3*G[{0, 0, 0, yu^(-1), 1/(yu*yv)}, yw])/16 - 
     (3*G[{0, 0, 0, yu, yu}, yv^(-1)])/8 - (3*G[{0, 0, 0, yv^(-1), 1}, yw])/
      16 + (3*G[{0, 0, 0, yv^(-1), 1/(yu*yv)}, yw])/16 + 
     (3*G[{0, 0, 0, 1/(yu*yv), yu^(-1)}, yw])/16 + 
     (3*G[{0, 0, 0, 1/(yu*yv), yv^(-1)}, yw])/16 - 
     (3*G[{0, 0, 0, 1/(yu*yv), 1/(yu*yv)}, yw])/8 - 
     G[{0, 0, 1, 0, 1}, yu^(-1)]/64 + G[{0, 0, 1, 0, 1}, yv^(-1)]/8 + 
     G[{0, 0, 1, 0, 1}, yw]/8 - G[{0, 0, 1, 0, yu^(-1)}, yw]/16 - 
     G[{0, 0, 1, 0, yv^(-1)}, yw]/16 + (3*G[{0, 0, 1, 1, 1}, yu^(-1)])/16 + 
     (3*G[{0, 0, 1, 1, 1}, yv^(-1)])/16 + G[{0, 0, 1, 1, 1}, yw]/8 - 
     (3*G[{0, 0, 1, 1, yu^(-1)}, yw])/16 + G[{0, 0, 1, 1, yu}, yv^(-1)]/16 - 
     (3*G[{0, 0, 1, 1, yv^(-1)}, yw])/16 + G[{0, 0, 1, 1, 1/(yu*yv)}, yw]/4 - 
     G[{0, 0, 1, yu^(-1), 1}, yw]/8 - (3*G[{0, 0, 1, yu^(-1), yu^(-1)}, yw])/
      8 + G[{0, 0, 1, yu^(-1), yv^(-1)}, yw]/8 + 
     (3*G[{0, 0, 1, yu, 1}, yv^(-1)])/16 + G[{0, 0, 1, yu, yu}, yv^(-1)]/16 - 
     G[{0, 0, 1, yv^(-1), 1}, yw]/8 + G[{0, 0, 1, yv^(-1), yu^(-1)}, yw]/8 + 
     (3*G[{0, 0, 1, yv^(-1), yv^(-1)}, yw])/8 - 
     (3*G[{0, 0, 1, yv^(-1), 1/(yu*yv)}, yw])/8 + 
     G[{0, 0, 1, 1/(yu*yv), 1}, yw]/4 + G[{0, 0, 1, 1/(yu*yv), yu^(-1)}, yw]/
      16 - (5*G[{0, 0, 1, 1/(yu*yv), yv^(-1)}, yw])/16 + 
     G[{0, 0, 1, 1/(yu*yv), 1/(yu*yv)}, yw]/8 - G[{0, 0, yu^(-1), 0, 1}, yw]/
      16 + G[{0, 0, yu^(-1), 0, 1/(yu*yv)}, yw]/16 - 
     G[{0, 0, yu^(-1), 1, 1}, yw]/4 - G[{0, 0, yu^(-1), 1, yu^(-1)}, yw]/16 + 
     (3*G[{0, 0, yu^(-1), 1, yv^(-1)}, yw])/16 + 
     G[{0, 0, yu^(-1), yu^(-1), 1}, yw]/8 + 
     G[{0, 0, yu^(-1), yu^(-1), 1/(yu*yv)}, yw]/8 - 
     G[{0, 0, yu^(-1), yv^(-1), 1}, yw]/8 + 
     G[{0, 0, yu^(-1), yv^(-1), 1/(yu*yv)}, yw]/8 + 
     G[{0, 0, yu^(-1), 1/(yu*yv), yu^(-1)}, yw]/16 + 
     G[{0, 0, yu^(-1), 1/(yu*yv), yv^(-1)}, yw]/16 - 
     G[{0, 0, yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw]/4 - 
     G[{0, 0, yu, 0, yu}, yv^(-1)]/8 + (5*G[{0, 0, yu, 1, 1}, yv^(-1)])/16 - 
     G[{0, 0, yu, 1, yu}, yv^(-1)]/16 - (5*G[{0, 0, yu, yu, 1}, yv^(-1)])/
      16 + (11*G[{0, 0, yu, yu, yu}, yv^(-1)])/16 - 
     G[{0, 0, yv^(-1), 0, 1}, yw]/16 + G[{0, 0, yv^(-1), 0, 1/(yu*yv)}, yw]/
      16 - G[{0, 0, yv^(-1), 1, 1}, yw]/4 - 
     (3*G[{0, 0, yv^(-1), 1, yu^(-1)}, yw])/16 + 
     (5*G[{0, 0, yv^(-1), 1, yv^(-1)}, yw])/16 - 
     G[{0, 0, yv^(-1), yu^(-1), 1}, yw]/8 + 
     G[{0, 0, yv^(-1), yu^(-1), 1/(yu*yv)}, yw]/8 + 
     G[{0, 0, yv^(-1), yv^(-1), 1}, yw]/8 + 
     G[{0, 0, yv^(-1), yv^(-1), 1/(yu*yv)}, yw]/8 + 
     G[{0, 0, yv^(-1), 1/(yu*yv), yu^(-1)}, yw]/16 + 
     G[{0, 0, yv^(-1), 1/(yu*yv), yv^(-1)}, yw]/16 - 
     G[{0, 0, yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw]/4 + 
     G[{0, 0, 1/(yu*yv), 0, yu^(-1)}, yw]/16 + 
     G[{0, 0, 1/(yu*yv), 0, yv^(-1)}, yw]/16 - 
     G[{0, 0, 1/(yu*yv), 0, 1/(yu*yv)}, yw]/8 + 
     (3*G[{0, 0, 1/(yu*yv), 1, 1}, yw])/8 + 
     G[{0, 0, 1/(yu*yv), 1, yu^(-1)}, yw]/16 - 
     (5*G[{0, 0, 1/(yu*yv), 1, yv^(-1)}, yw])/16 - 
     G[{0, 0, 1/(yu*yv), 1, 1/(yu*yv)}, yw]/8 + 
     G[{0, 0, 1/(yu*yv), yu^(-1), yu^(-1)}, yw]/8 + 
     G[{0, 0, 1/(yu*yv), yv^(-1), yv^(-1)}, yw]/8 - 
     G[{0, 0, 1/(yu*yv), 1/(yu*yv), 1}, yw]/4 + 
     (5*G[{0, 0, 1/(yu*yv), 1/(yu*yv), yu^(-1)}, yw])/16 + 
     (5*G[{0, 0, 1/(yu*yv), 1/(yu*yv), yv^(-1)}, yw])/16 - 
     (3*G[{0, 0, 1/(yu*yv), 1/(yu*yv), 1/(yu*yv)}, yw])/8 + 
     (9*G[{0, 1, 0, 1, 1}, yu^(-1)])/64 - (3*G[{0, 1, 0, 1, yu^(-1)}, yw])/
      16 + G[{0, 1, 0, 1, yu}, yv^(-1)]/8 + G[{0, 1, 0, 1, 1/(yu*yv)}, yw]/
      16 - G[{0, 1, 0, yu^(-1), 1}, yw]/8 - 
     G[{0, 1, 0, yu^(-1), yu^(-1)}, yw]/8 + 
     G[{0, 1, 0, yu^(-1), yv^(-1)}, yw]/16 + 
     G[{0, 1, 0, yu^(-1), 1/(yu*yv)}, yw]/16 + G[{0, 1, 0, yu, 1}, yv^(-1)]/
      4 - G[{0, 1, 0, yu, yu}, yv^(-1)]/16 - G[{0, 1, 0, yv^(-1), 1}, yw]/8 + 
     G[{0, 1, 0, yv^(-1), yu^(-1)}, yw]/16 + 
     G[{0, 1, 0, yv^(-1), yv^(-1)}, yw]/4 - 
     G[{0, 1, 0, yv^(-1), 1/(yu*yv)}, yw]/8 + G[{0, 1, 0, 1/(yu*yv), 1}, yw]/
      4 + G[{0, 1, 0, 1/(yu*yv), yu^(-1)}, yw]/16 - 
     (5*G[{0, 1, 0, 1/(yu*yv), yv^(-1)}, yw])/16 + 
     G[{0, 1, 0, 1/(yu*yv), 1/(yu*yv)}, yw]/16 + G[{0, 1, 1, 0, yu}, yv^(-1)]/
      8 - G[{0, 1, 1, 1, 1}, yu^(-1)]/8 + G[{0, 1, 1, 1, 1}, yv^(-1)]/4 + 
     (3*G[{0, 1, 1, 1, 1}, yw])/16 + G[{0, 1, 1, 1, yu^(-1)}, yw]/16 - 
     (3*G[{0, 1, 1, 1, yu}, yv^(-1)])/8 - G[{0, 1, 1, 1, yv^(-1)}, yw]/8 + 
     G[{0, 1, 1, 1, 1/(yu*yv)}, yw]/8 + G[{0, 1, 1, yu^(-1), 1}, yw]/8 + 
     G[{0, 1, 1, yu^(-1), yu^(-1)}, yw]/4 - G[{0, 1, 1, yu, 1}, yv^(-1)]/2 + 
     (5*G[{0, 1, 1, yu, yu}, yv^(-1)])/16 + G[{0, 1, 1, yv^(-1), 1}, yw]/8 - 
     G[{0, 1, 1, yv^(-1), yv^(-1)}, yw]/2 - G[{0, 1, 1, 1/(yu*yv), 1}, yw]/
      16 + G[{0, 1, 1, 1/(yu*yv), yu^(-1)}, yw]/16 + 
     G[{0, 1, 1, 1/(yu*yv), yv^(-1)}, yw]/4 - 
     G[{0, 1, yu^(-1), 0, yu^(-1)}, yw]/8 - 
     G[{0, 1, yu^(-1), 0, yv^(-1)}, yw]/8 + 
     G[{0, 1, yu^(-1), 0, 1/(yu*yv)}, yw]/16 + 
     (3*G[{0, 1, yu^(-1), 1, 1}, yw])/16 + 
     (3*G[{0, 1, yu^(-1), 1, yu^(-1)}, yw])/16 - 
     G[{0, 1, yu^(-1), yu^(-1), 1}, yw]/8 - 
     G[{0, 1, yu^(-1), yu^(-1), yu^(-1)}, yw]/4 - 
     G[{0, 1, yu^(-1), yu^(-1), 1/(yu*yv)}, yw]/8 + 
     G[{0, 1, yu^(-1), yv^(-1), 1}, yw]/8 - 
     G[{0, 1, yu^(-1), yv^(-1), 1/(yu*yv)}, yw]/8 - 
     (3*G[{0, 1, yu^(-1), 1/(yu*yv), 1}, yw])/16 - 
     (3*G[{0, 1, yu^(-1), 1/(yu*yv), yu^(-1)}, yw])/16 + 
     G[{0, 1, yu^(-1), 1/(yu*yv), yv^(-1)}, yw]/4 + 
     G[{0, 1, yu, 0, yu}, yv^(-1)]/16 - (7*G[{0, 1, yu, 1, 1}, yv^(-1)])/16 + 
     (5*G[{0, 1, yu, 1, yu}, yv^(-1)])/16 + (3*G[{0, 1, yu, yu, 1}, yv^(-1)])/
      8 - G[{0, 1, yu, yu, yu}, yv^(-1)]/8 + 
     G[{0, 1, yv^(-1), 0, yu^(-1)}, yw]/8 + 
     G[{0, 1, yv^(-1), 0, yv^(-1)}, yw]/16 - 
     G[{0, 1, yv^(-1), 0, 1/(yu*yv)}, yw]/8 + 
     (3*G[{0, 1, yv^(-1), 1, 1}, yw])/16 + 
     (3*G[{0, 1, yv^(-1), 1, yu^(-1)}, yw])/16 - 
     (3*G[{0, 1, yv^(-1), 1, yv^(-1)}, yw])/8 + 
     G[{0, 1, yv^(-1), yu^(-1), 1}, yw]/8 - 
     G[{0, 1, yv^(-1), yu^(-1), 1/(yu*yv)}, yw]/8 - 
     G[{0, 1, yv^(-1), yv^(-1), 1}, yw]/8 + 
     G[{0, 1, yv^(-1), yv^(-1), yv^(-1)}, yw]/2 - 
     G[{0, 1, yv^(-1), yv^(-1), 1/(yu*yv)}, yw]/8 - 
     (3*G[{0, 1, yv^(-1), 1/(yu*yv), 1}, yw])/16 - 
     (5*G[{0, 1, yv^(-1), 1/(yu*yv), yu^(-1)}, yw])/16 + 
     G[{0, 1, 1/(yu*yv), 0, 1/(yu*yv)}, yw]/16 - 
     (3*G[{0, 1, 1/(yu*yv), 1, 1}, yw])/16 - 
     G[{0, 1, 1/(yu*yv), 1, yu^(-1)}, yw]/16 + 
     G[{0, 1, 1/(yu*yv), 1, yv^(-1)}, yw]/8 + 
     G[{0, 1, 1/(yu*yv), yu^(-1), 1}, yw]/8 - 
     G[{0, 1, 1/(yu*yv), yu^(-1), yu^(-1)}, yw]/8 + 
     G[{0, 1, 1/(yu*yv), yv^(-1), 1}, yw]/8 - 
     G[{0, 1, 1/(yu*yv), yv^(-1), yv^(-1)}, yw]/8 - 
     G[{0, 1, 1/(yu*yv), 1/(yu*yv), 1}, yw]/16 + 
     (3*G[{0, 1, 1/(yu*yv), 1/(yu*yv), yu^(-1)}, yw])/16 + 
     G[{0, yu^(-1), 0, yu^(-1), 1}, yw]/16 + 
     G[{0, yu^(-1), 0, yu^(-1), 1/(yu*yv)}, yw]/16 - 
     G[{0, yu^(-1), 0, 1/(yu*yv), 1}, yw]/8 + 
     G[{0, yu^(-1), 0, 1/(yu*yv), yv^(-1)}, yw]/8 - 
     G[{0, yu^(-1), 0, 1/(yu*yv), 1/(yu*yv)}, yw]/8 - 
     G[{0, yu^(-1), 1, 0, yv^(-1)}, yw]/16 - 
     G[{0, yu^(-1), 1, yu^(-1), 1}, yw]/8 - 
     G[{0, yu^(-1), 1, yu^(-1), yu^(-1)}, yw]/8 - 
     G[{0, yu^(-1), 1, yv^(-1), 1}, yw]/8 + 
     G[{0, yu^(-1), 1, yv^(-1), yv^(-1)}, yw]/8 + 
     G[{0, yu^(-1), yu^(-1), 0, 1/(yu*yv)}, yw]/8 - 
     G[{0, yu^(-1), yu^(-1), 1, 1}, yw]/4 - 
     G[{0, yu^(-1), yu^(-1), 1, yu^(-1)}, yw]/8 + 
     G[{0, yu^(-1), yu^(-1), 1, yv^(-1)}, yw]/8 - 
     G[{0, yu^(-1), yu^(-1), yv^(-1), 1}, yw]/8 + 
     G[{0, yu^(-1), yu^(-1), yv^(-1), 1/(yu*yv)}, yw]/8 + 
     G[{0, yu^(-1), yu^(-1), 1/(yu*yv), 1}, yw]/4 + 
     G[{0, yu^(-1), yu^(-1), 1/(yu*yv), yu^(-1)}, yw]/8 - 
     G[{0, yu^(-1), yu^(-1), 1/(yu*yv), yv^(-1)}, yw]/8 + 
     G[{0, yu^(-1), yv^(-1), 0, 1/(yu*yv)}, yw]/16 - 
     G[{0, yu^(-1), yv^(-1), 1, 1}, yw]/4 - 
     G[{0, yu^(-1), yv^(-1), 1, yu^(-1)}, yw]/4 + 
     G[{0, yu^(-1), yv^(-1), 1, yv^(-1)}, yw]/8 - 
     G[{0, yu^(-1), yv^(-1), yu^(-1), 1}, yw]/8 + 
     G[{0, yu^(-1), yv^(-1), yu^(-1), 1/(yu*yv)}, yw]/8 - 
     G[{0, yu^(-1), yv^(-1), yv^(-1), 1}, yw]/8 + 
     G[{0, yu^(-1), yv^(-1), yv^(-1), 1/(yu*yv)}, yw]/8 + 
     G[{0, yu^(-1), yv^(-1), 1/(yu*yv), 1}, yw]/4 + 
     G[{0, yu^(-1), yv^(-1), 1/(yu*yv), yu^(-1)}, yw]/4 - 
     G[{0, yu^(-1), yv^(-1), 1/(yu*yv), yv^(-1)}, yw]/8 - 
     G[{0, yu^(-1), 1/(yu*yv), 0, 1/(yu*yv)}, yw]/8 + 
     G[{0, yu^(-1), 1/(yu*yv), 1, yu^(-1)}, yw]/8 + 
     G[{0, yu^(-1), 1/(yu*yv), 1, yv^(-1)}, yw]/8 + 
     G[{0, yu^(-1), 1/(yu*yv), yu^(-1), 1}, yw]/8 + 
     G[{0, yu^(-1), 1/(yu*yv), yu^(-1), yu^(-1)}, yw]/8 + 
     G[{0, yu^(-1), 1/(yu*yv), yv^(-1), 1}, yw]/8 - 
     G[{0, yu^(-1), 1/(yu*yv), yv^(-1), yv^(-1)}, yw]/8 - 
     G[{0, yu^(-1), 1/(yu*yv), 1/(yu*yv), yu^(-1)}, yw]/8 - 
     G[{0, yu^(-1), 1/(yu*yv), 1/(yu*yv), yv^(-1)}, yw]/8 - 
     G[{0, yu, 0, yu, 1}, yv^(-1)]/16 + (5*G[{0, yu, 0, yu, yu}, yv^(-1)])/
      16 - G[{0, yu, 1, 1, 1}, yv^(-1)]/4 + (3*G[{0, yu, 1, 1, yu}, yv^(-1)])/
      8 + G[{0, yu, 1, yu, 1}, yv^(-1)]/2 - 
     (5*G[{0, yu, 1, yu, yu}, yv^(-1)])/16 + 
     (7*G[{0, yu, yu, 1, 1}, yv^(-1)])/16 - 
     (5*G[{0, yu, yu, 1, yu}, yv^(-1)])/16 - 
     (3*G[{0, yu, yu, yu, 1}, yv^(-1)])/8 + G[{0, yu, yu, yu, yu}, yv^(-1)]/
      8 + G[{0, yv^(-1), 0, yv^(-1), 1}, yw]/16 + 
     G[{0, yv^(-1), 0, yv^(-1), 1/(yu*yv)}, yw]/16 - 
     G[{0, yv^(-1), 0, 1/(yu*yv), 1}, yw]/8 - 
     G[{0, yv^(-1), 0, 1/(yu*yv), yu^(-1)}, yw]/16 + 
     (3*G[{0, yv^(-1), 0, 1/(yu*yv), yv^(-1)}, yw])/16 - 
     G[{0, yv^(-1), 0, 1/(yu*yv), 1/(yu*yv)}, yw]/8 - 
     G[{0, yv^(-1), 1, yu^(-1), 1}, yw]/8 - 
     G[{0, yv^(-1), 1, yu^(-1), yu^(-1)}, yw]/4 - 
     G[{0, yv^(-1), 1, yv^(-1), 1}, yw]/8 + 
     G[{0, yv^(-1), 1, yv^(-1), yv^(-1)}, yw]/4 + 
     G[{0, yv^(-1), yu^(-1), 0, 1/(yu*yv)}, yw]/16 - 
     G[{0, yv^(-1), yu^(-1), 1, 1}, yw]/4 - 
     G[{0, yv^(-1), yu^(-1), 1, yu^(-1)}, yw]/4 + 
     G[{0, yv^(-1), yu^(-1), 1, yv^(-1)}, yw]/8 - 
     G[{0, yv^(-1), yu^(-1), yu^(-1), 1}, yw]/8 + 
     G[{0, yv^(-1), yu^(-1), yu^(-1), 1/(yu*yv)}, yw]/8 - 
     G[{0, yv^(-1), yu^(-1), yv^(-1), 1}, yw]/8 + 
     G[{0, yv^(-1), yu^(-1), yv^(-1), 1/(yu*yv)}, yw]/8 + 
     G[{0, yv^(-1), yu^(-1), 1/(yu*yv), 1}, yw]/4 + 
     G[{0, yv^(-1), yu^(-1), 1/(yu*yv), yu^(-1)}, yw]/4 - 
     G[{0, yv^(-1), yu^(-1), 1/(yu*yv), yv^(-1)}, yw]/8 + 
     G[{0, yv^(-1), yv^(-1), 0, 1/(yu*yv)}, yw]/8 - 
     G[{0, yv^(-1), yv^(-1), 1, 1}, yw]/4 - 
     G[{0, yv^(-1), yv^(-1), 1, yu^(-1)}, yw]/4 + 
     G[{0, yv^(-1), yv^(-1), 1, yv^(-1)}, yw]/4 - 
     G[{0, yv^(-1), yv^(-1), yu^(-1), 1}, yw]/8 + 
     G[{0, yv^(-1), yv^(-1), yu^(-1), 1/(yu*yv)}, yw]/8 + 
     G[{0, yv^(-1), yv^(-1), 1/(yu*yv), 1}, yw]/4 + 
     G[{0, yv^(-1), yv^(-1), 1/(yu*yv), yu^(-1)}, yw]/4 - 
     G[{0, yv^(-1), yv^(-1), 1/(yu*yv), yv^(-1)}, yw]/4 - 
     G[{0, yv^(-1), 1/(yu*yv), 0, 1/(yu*yv)}, yw]/8 + 
     G[{0, yv^(-1), 1/(yu*yv), 1, yu^(-1)}, yw]/8 + 
     G[{0, yv^(-1), 1/(yu*yv), 1, yv^(-1)}, yw]/8 + 
     G[{0, yv^(-1), 1/(yu*yv), yu^(-1), 1}, yw]/8 + 
     G[{0, yv^(-1), 1/(yu*yv), yu^(-1), yu^(-1)}, yw]/4 + 
     G[{0, yv^(-1), 1/(yu*yv), yv^(-1), 1}, yw]/8 - 
     G[{0, yv^(-1), 1/(yu*yv), yv^(-1), yv^(-1)}, yw]/4 - 
     G[{0, yv^(-1), 1/(yu*yv), 1/(yu*yv), yu^(-1)}, yw]/8 - 
     G[{0, yv^(-1), 1/(yu*yv), 1/(yu*yv), yv^(-1)}, yw]/8 + 
     G[{0, 1/(yu*yv), 0, 1/(yu*yv), yu^(-1)}, yw]/4 + 
     G[{0, 1/(yu*yv), 0, 1/(yu*yv), yv^(-1)}, yw]/16 - 
     (3*G[{0, 1/(yu*yv), 0, 1/(yu*yv), 1/(yu*yv)}, yw])/16 - 
     (3*G[{0, 1/(yu*yv), 1, 1, 1}, yw])/16 - 
     G[{0, 1/(yu*yv), 1, 1, yu^(-1)}, yw]/16 + 
     G[{0, 1/(yu*yv), 1, 1, yv^(-1)}, yw]/8 - 
     G[{0, 1/(yu*yv), 1, 1, 1/(yu*yv)}, yw]/8 + 
     G[{0, 1/(yu*yv), 1, yu^(-1), 1}, yw]/8 + 
     G[{0, 1/(yu*yv), 1, yu^(-1), yu^(-1)}, yw]/8 + 
     G[{0, 1/(yu*yv), 1, yv^(-1), 1}, yw]/8 + 
     G[{0, 1/(yu*yv), 1, yv^(-1), yv^(-1)}, yw]/8 + 
     G[{0, 1/(yu*yv), 1, 1/(yu*yv), 1}, yw]/16 - 
     G[{0, 1/(yu*yv), 1, 1/(yu*yv), yu^(-1)}, yw]/16 - 
     G[{0, 1/(yu*yv), 1, 1/(yu*yv), yv^(-1)}, yw]/4 + 
     (5*G[{0, 1/(yu*yv), yu^(-1), 1, 1}, yw])/16 + 
     (3*G[{0, 1/(yu*yv), yu^(-1), 1, yu^(-1)}, yw])/16 - 
     G[{0, 1/(yu*yv), yu^(-1), 1, yv^(-1)}, yw]/4 + 
     G[{0, 1/(yu*yv), yu^(-1), yu^(-1), 1}, yw]/4 + 
     G[{0, 1/(yu*yv), yu^(-1), yu^(-1), yu^(-1)}, yw]/4 + 
     G[{0, 1/(yu*yv), yu^(-1), yv^(-1), 1}, yw]/8 - 
     G[{0, 1/(yu*yv), yu^(-1), yv^(-1), 1/(yu*yv)}, yw]/8 - 
     (5*G[{0, 1/(yu*yv), yu^(-1), 1/(yu*yv), 1}, yw])/16 - 
     (3*G[{0, 1/(yu*yv), yu^(-1), 1/(yu*yv), yu^(-1)}, yw])/16 + 
     (5*G[{0, 1/(yu*yv), yv^(-1), 1, 1}, yw])/16 + 
     (5*G[{0, 1/(yu*yv), yv^(-1), 1, yu^(-1)}, yw])/16 + 
     G[{0, 1/(yu*yv), yv^(-1), yu^(-1), 1}, yw]/8 - 
     G[{0, 1/(yu*yv), yv^(-1), yu^(-1), 1/(yu*yv)}, yw]/8 + 
     G[{0, 1/(yu*yv), yv^(-1), yv^(-1), 1}, yw]/4 - 
     G[{0, 1/(yu*yv), yv^(-1), yv^(-1), yv^(-1)}, yw]/2 - 
     (5*G[{0, 1/(yu*yv), yv^(-1), 1/(yu*yv), 1}, yw])/16 - 
     (3*G[{0, 1/(yu*yv), yv^(-1), 1/(yu*yv), yu^(-1)}, yw])/16 + 
     (3*G[{0, 1/(yu*yv), yv^(-1), 1/(yu*yv), yv^(-1)}, yw])/8 + 
     (3*G[{0, 1/(yu*yv), 1/(yu*yv), 1, 1}, yw])/16 - 
     (3*G[{0, 1/(yu*yv), 1/(yu*yv), 1, yu^(-1)}, yw])/16 - 
     (3*G[{0, 1/(yu*yv), 1/(yu*yv), 1, yv^(-1)}, yw])/8 - 
     (3*G[{0, 1/(yu*yv), 1/(yu*yv), yu^(-1), 1}, yw])/8 - 
     G[{0, 1/(yu*yv), 1/(yu*yv), yu^(-1), yu^(-1)}, yw]/4 - 
     (3*G[{0, 1/(yu*yv), 1/(yu*yv), yv^(-1), 1}, yw])/8 + 
     G[{0, 1/(yu*yv), 1/(yu*yv), yv^(-1), yv^(-1)}, yw]/2 + 
     G[{0, 1/(yu*yv), 1/(yu*yv), 1/(yu*yv), 1}, yw]/16 + 
     G[{0, 1/(yu*yv), 1/(yu*yv), 1/(yu*yv), yu^(-1)}, yw]/16 + 
     G[{0, 1/(yu*yv), 1/(yu*yv), 1/(yu*yv), yv^(-1)}, yw]/4 + 
     G[{1, 1, 1, 1, yu^(-1)}, yw]/16 - (7*G[{1, 1, 1, 1, yu}, yv^(-1)])/16 + 
     G[{1, 1, 1, 1, yv^(-1)}, yw]/16 - G[{1, 1, 1, 1, 1/(yu*yv)}, yw]/2 + 
     (7*G[{1, 1, 1, yu^(-1), yu^(-1)}, yw])/16 + 
     (3*G[{1, 1, 1, yu^(-1), yv^(-1)}, yw])/8 - 
     G[{1, 1, 1, yu^(-1), 1/(yu*yv)}, yw]/4 - 
     (5*G[{1, 1, 1, yu, yu}, yv^(-1)])/4 + 
     (3*G[{1, 1, 1, yv^(-1), yu^(-1)}, yw])/8 + 
     (5*G[{1, 1, 1, yv^(-1), yv^(-1)}, yw])/8 + 
     (5*G[{1, 1, 1, yv^(-1), 1/(yu*yv)}, yw])/16 - 
     (5*G[{1, 1, 1, 1/(yu*yv), yu^(-1)}, yw])/16 + 
     G[{1, 1, 1, 1/(yu*yv), yv^(-1)}, yw]/4 - 
     (15*G[{1, 1, 1, 1/(yu*yv), 1/(yu*yv)}, yw])/16 + 
     G[{1, 1, yu^(-1), 1, yu^(-1)}, yw]/16 + 
     G[{1, 1, yu^(-1), 1, yv^(-1)}, yw]/16 - 
     G[{1, 1, yu^(-1), 1, 1/(yu*yv)}, yw]/8 - 
     (15*G[{1, 1, yu^(-1), yu^(-1), yu^(-1)}, yw])/16 - 
     G[{1, 1, yu^(-1), yu^(-1), yv^(-1)}, yw]/2 + 
     (3*G[{1, 1, yu^(-1), yu^(-1), 1/(yu*yv)}, yw])/4 - 
     G[{1, 1, yu^(-1), yv^(-1), yu^(-1)}, yw]/2 - 
     G[{1, 1, yu^(-1), yv^(-1), yv^(-1)}, yw]/2 + 
     (5*G[{1, 1, yu^(-1), 1/(yu*yv), yu^(-1)}, yw])/16 - 
     (7*G[{1, 1, yu^(-1), 1/(yu*yv), yv^(-1)}, yw])/16 - 
     (3*G[{1, 1, yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/8 - 
     (13*G[{1, 1, yu, 1, yu}, yv^(-1)])/64 - 
     (13*G[{1, 1, yu, yu, yu}, yv^(-1)])/64 + 
     G[{1, 1, yv^(-1), 1, yu^(-1)}, yw]/16 + 
     (13*G[{1, 1, yv^(-1), 1, yv^(-1)}, yw])/64 + 
     (7*G[{1, 1, yv^(-1), 1, 1/(yu*yv)}, yw])/64 - 
     G[{1, 1, yv^(-1), yu^(-1), yu^(-1)}, yw]/2 + 
     G[{1, 1, yv^(-1), yv^(-1), yu^(-1)}, yw]/2 + 
     (81*G[{1, 1, yv^(-1), yv^(-1), yv^(-1)}, yw])/64 + 
     (27*G[{1, 1, yv^(-1), yv^(-1), 1/(yu*yv)}, yw])/64 + 
     (3*G[{1, 1, yv^(-1), 1/(yu*yv), yu^(-1)}, yw])/16 + 
     G[{1, 1, yv^(-1), 1/(yu*yv), yv^(-1)}, yw]/8 + 
     (15*G[{1, 1, 1/(yu*yv), 1, yv^(-1)}, yw])/64 - 
     (23*G[{1, 1, 1/(yu*yv), 1, 1/(yu*yv)}, yw])/64 + 
     G[{1, 1, 1/(yu*yv), yu^(-1), yu^(-1)}, yw]/16 - 
     G[{1, 1, 1/(yu*yv), yu^(-1), 1/(yu*yv)}, yw]/8 + 
     (7*G[{1, 1, 1/(yu*yv), yv^(-1), yv^(-1)}, yw])/64 - 
     (5*G[{1, 1, 1/(yu*yv), yv^(-1), 1/(yu*yv)}, yw])/64 - 
     (3*G[{1, 1, 1/(yu*yv), 1/(yu*yv), yv^(-1)}, yw])/16 - 
     (7*G[{1, 1, 1/(yu*yv), 1/(yu*yv), 1/(yu*yv)}, yw])/16 - 
     (7*G[{1, yu^(-1), 1, yu^(-1), yu^(-1)}, yw])/16 - 
     G[{1, yu^(-1), 1, yu^(-1), yv^(-1)}, yw]/4 + 
     (5*G[{1, yu^(-1), 1, yu^(-1), 1/(yu*yv)}, yw])/16 - 
     G[{1, yu^(-1), 1, yv^(-1), yu^(-1)}, yw]/4 - 
     (3*G[{1, yu^(-1), 1, yv^(-1), yv^(-1)}, yw])/8 + 
     G[{1, yu^(-1), 1, 1/(yu*yv), yu^(-1)}, yw]/8 - 
     (3*G[{1, yu^(-1), 1, 1/(yu*yv), yv^(-1)}, yw])/16 - 
     (3*G[{1, yu^(-1), 1, 1/(yu*yv), 1/(yu*yv)}, yw])/16 - 
     G[{1, yu^(-1), yu^(-1), 1, yv^(-1)}, yw]/8 + 
     (3*G[{1, yu^(-1), yu^(-1), 1, 1/(yu*yv)}, yw])/16 - 
     G[{1, yu^(-1), yu^(-1), yu^(-1), yu^(-1)}, yw]/8 - 
     G[{1, yu^(-1), yu^(-1), yv^(-1), 1/(yu*yv)}, yw]/8 - 
     (3*G[{1, yu^(-1), yu^(-1), 1/(yu*yv), yu^(-1)}, yw])/16 + 
     G[{1, yu^(-1), yu^(-1), 1/(yu*yv), yv^(-1)}, yw]/4 - 
     G[{1, yu^(-1), yv^(-1), 1, yv^(-1)}, yw]/4 + 
     G[{1, yu^(-1), yv^(-1), 1, 1/(yu*yv)}, yw]/4 - 
     G[{1, yu^(-1), yv^(-1), yu^(-1), 1/(yu*yv)}, yw]/8 - 
     G[{1, yu^(-1), yv^(-1), yv^(-1), 1/(yu*yv)}, yw]/8 - 
     G[{1, yu^(-1), yv^(-1), 1/(yu*yv), yu^(-1)}, yw]/4 + 
     G[{1, yu^(-1), yv^(-1), 1/(yu*yv), yv^(-1)}, yw]/8 - 
     (5*G[{1, yu^(-1), 1/(yu*yv), 1, yv^(-1)}, yw])/16 - 
     (3*G[{1, yu^(-1), 1/(yu*yv), 1, 1/(yu*yv)}, yw])/16 - 
     (3*G[{1, yu^(-1), 1/(yu*yv), yu^(-1), yu^(-1)}, yw])/16 + 
     G[{1, yu^(-1), 1/(yu*yv), 1/(yu*yv), yu^(-1)}, yw]/8 + 
     G[{1, yu^(-1), 1/(yu*yv), 1/(yu*yv), yv^(-1)}, yw]/16 + 
     G[{1, yu, 1, yu, yu}, yv^(-1)]/8 + (3*G[{1, yu, yu, yu, yu}, yv^(-1)])/
      32 + G[{1, yv^(-1), 1, yv^(-1), yu^(-1)}, yw]/4 + 
     (5*G[{1, yv^(-1), 1, yv^(-1), yv^(-1)}, yw])/16 + 
     (11*G[{1, yv^(-1), 1, yv^(-1), 1/(yu*yv)}, yw])/64 + 
     G[{1, yv^(-1), 1, 1/(yu*yv), yu^(-1)}, yw]/8 + 
     G[{1, yv^(-1), 1, 1/(yu*yv), yv^(-1)}, yw]/8 + 
     (3*G[{1, yv^(-1), 1, 1/(yu*yv), 1/(yu*yv)}, yw])/64 + 
     G[{1, yv^(-1), yu^(-1), 1, 1/(yu*yv)}, yw]/4 - 
     G[{1, yv^(-1), yu^(-1), yu^(-1), 1/(yu*yv)}, yw]/8 - 
     G[{1, yv^(-1), yu^(-1), yv^(-1), 1/(yu*yv)}, yw]/8 - 
     G[{1, yv^(-1), yu^(-1), 1/(yu*yv), yu^(-1)}, yw]/4 + 
     G[{1, yv^(-1), yu^(-1), 1/(yu*yv), yv^(-1)}, yw]/8 + 
     (3*G[{1, yv^(-1), yv^(-1), 1, 1/(yu*yv)}, yw])/16 - 
     G[{1, yv^(-1), yv^(-1), yu^(-1), 1/(yu*yv)}, yw]/8 + 
     (41*G[{1, yv^(-1), yv^(-1), yv^(-1), yv^(-1)}, yw])/32 + 
     (3*G[{1, yv^(-1), yv^(-1), yv^(-1), 1/(yu*yv)}, yw])/64 - 
     G[{1, yv^(-1), yv^(-1), 1/(yu*yv), yu^(-1)}, yw]/2 - 
     (9*G[{1, yv^(-1), yv^(-1), 1/(yu*yv), yv^(-1)}, yw])/64 - 
     (3*G[{1, yv^(-1), yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/32 + 
     (3*G[{1, yv^(-1), 1/(yu*yv), 1, 1/(yu*yv)}, yw])/64 - 
     (9*G[{1, yv^(-1), 1/(yu*yv), yv^(-1), yv^(-1)}, yw])/64 - 
     (3*G[{1, yv^(-1), 1/(yu*yv), yv^(-1), 1/(yu*yv)}, yw])/32 + 
     G[{1, yv^(-1), 1/(yu*yv), 1/(yu*yv), yu^(-1)}, yw]/16 - 
     (7*G[{1, yv^(-1), 1/(yu*yv), 1/(yu*yv), yv^(-1)}, yw])/64 + 
     G[{1, 1/(yu*yv), 1, 1/(yu*yv), yu^(-1)}, yw]/16 + 
     G[{1, 1/(yu*yv), 1, 1/(yu*yv), yv^(-1)}, yw]/16 - 
     (17*G[{1, 1/(yu*yv), 1, 1/(yu*yv), 1/(yu*yv)}, yw])/64 - 
     (3*G[{1, 1/(yu*yv), yu^(-1), yu^(-1), yu^(-1)}, yw])/8 - 
     G[{1, 1/(yu*yv), yu^(-1), yu^(-1), 1/(yu*yv)}, yw]/8 + 
     G[{1, 1/(yu*yv), yu^(-1), 1/(yu*yv), yu^(-1)}, yw]/16 + 
     G[{1, 1/(yu*yv), yu^(-1), 1/(yu*yv), yv^(-1)}, yw]/8 - 
     (9*G[{1, 1/(yu*yv), yv^(-1), yv^(-1), yv^(-1)}, yw])/32 - 
     (11*G[{1, 1/(yu*yv), yv^(-1), yv^(-1), 1/(yu*yv)}, yw])/64 + 
     G[{1, 1/(yu*yv), yv^(-1), 1/(yu*yv), yu^(-1)}, yw]/8 + 
     G[{1, 1/(yu*yv), yv^(-1), 1/(yu*yv), yv^(-1)}, yw]/64 + 
     (3*G[{1, 1/(yu*yv), yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/32 - 
     G[{1, 1/(yu*yv), 1/(yu*yv), yu^(-1), yu^(-1)}, yw]/16 - 
     (7*G[{1, 1/(yu*yv), 1/(yu*yv), yv^(-1), yv^(-1)}, yw])/64 + 
     (3*G[{1, 1/(yu*yv), 1/(yu*yv), yv^(-1), 1/(yu*yv)}, yw])/32 + 
     (3*G[{1, 1/(yu*yv), 1/(yu*yv), 1/(yu*yv), yu^(-1)}, yw])/16 + 
     (3*G[{1, 1/(yu*yv), 1/(yu*yv), 1/(yu*yv), yv^(-1)}, yw])/64 + 
     G[{yu^(-1), yu^(-1), yu^(-1), yu^(-1), 1/(yu*yv)}, yw]/8 + 
     (3*G[{yu^(-1), yu^(-1), yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/16 + 
     G[{yu^(-1), yu^(-1), 1/(yu*yv), yu^(-1), 1/(yu*yv)}, yw]/16 - 
     G[{yu^(-1), yu^(-1), 1/(yu*yv), yv^(-1), 1/(yu*yv)}, yw]/8 + 
     G[{yu^(-1), yu^(-1), 1/(yu*yv), 1/(yu*yv), yv^(-1)}, yw]/4 - 
     G[{yu^(-1), yu^(-1), 1/(yu*yv), 1/(yu*yv), 1/(yu*yv)}, yw]/4 + 
     G[{yu^(-1), 1/(yu*yv), yu^(-1), 1/(yu*yv), yv^(-1)}, yw]/8 - 
     G[{yu^(-1), 1/(yu*yv), yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw]/8 + 
     G[{yu^(-1), 1/(yu*yv), yv^(-1), yv^(-1), 1/(yu*yv)}, yw]/8 - 
     G[{yu^(-1), 1/(yu*yv), yv^(-1), 1/(yu*yv), yv^(-1)}, yw]/8 - 
     G[{yu^(-1), 1/(yu*yv), 1/(yu*yv), yv^(-1), yv^(-1)}, yw]/4 - 
     (3*G[{yu^(-1), 1/(yu*yv), 1/(yu*yv), 1/(yu*yv), yv^(-1)}, yw])/16 - 
     (41*G[{yv^(-1), yv^(-1), yv^(-1), yv^(-1), 1/(yu*yv)}, yw])/32 - 
     (129*G[{yv^(-1), yv^(-1), yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/64 - 
     (11*G[{yv^(-1), yv^(-1), 1/(yu*yv), yv^(-1), 1/(yu*yv)}, yw])/16 - 
     (7*G[{yv^(-1), yv^(-1), 1/(yu*yv), 1/(yu*yv), 1/(yu*yv)}, yw])/16 - 
     (17*G[{yv^(-1), 1/(yu*yv), yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/64 - 
     (Pi^2*Zeta[3])/96 + (7*G[{1}, yu^(-1)]^2*Zeta[3])/64 - 
     (7*G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*Zeta[3])/32 - 
     (G[{1}, yv^(-1)]^2*Zeta[3])/32 - (G[{0}, yu^(-1)]*G[{1}, yw]*Zeta[3])/
      8 - (G[{0}, yv^(-1)]*G[{1}, yw]*Zeta[3])/8 + 
     (G[{0}, yw]*G[{1}, yw]*Zeta[3])/8 - (G[{1}, yu^(-1)]*G[{1}, yw]*Zeta[3])/
      32 + (G[{1}, yv^(-1)]*G[{1}, yw]*Zeta[3])/16 - 
     (3*G[{1}, yw]^2*Zeta[3])/64 + (3*G[{1}, yw]*G[{yu}, yv^(-1)]*Zeta[3])/
      32 + (G[{0}, yu^(-1)]*G[{1/(yu*yv)}, yw]*Zeta[3])/8 + 
     (G[{0}, yv^(-1)]*G[{1/(yu*yv)}, yw]*Zeta[3])/8 - 
     (G[{0}, yw]*G[{1/(yu*yv)}, yw]*Zeta[3])/8 + 
     (G[{1}, yu^(-1)]*G[{1/(yu*yv)}, yw]*Zeta[3])/32 - 
     (G[{1}, yv^(-1)]*G[{1/(yu*yv)}, yw]*Zeta[3])/16 + 
     (3*G[{1}, yw]*G[{1/(yu*yv)}, yw]*Zeta[3])/32 + 
     (G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*Zeta[3])/16 - 
     (3*G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw]*Zeta[3])/32 - 
     (G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*Zeta[3])/32 - 
     (7*G[{0, 1}, yu^(-1)]*Zeta[3])/32 + (G[{0, 1}, yv^(-1)]*Zeta[3])/16 - 
     (G[{0, 1}, yw]*Zeta[3])/8 - (G[{0, yu}, yv^(-1)]*Zeta[3])/16 + 
     (G[{0, 1/(yu*yv)}, yw]*Zeta[3])/8 - (G[{1, yu^(-1)}, yw]*Zeta[3])/16 + 
     (9*G[{1, yu}, yv^(-1)]*Zeta[3])/32 + (G[{1, yv^(-1)}, yw]*Zeta[3])/32 - 
     (3*G[{1, 1/(yu*yv)}, yw]*Zeta[3])/32 - 
     (G[{yu^(-1), 1/(yu*yv)}, yw]*Zeta[3])/16 + 
     (G[{yv^(-1), 1/(yu*yv)}, yw]*Zeta[3])/32 + (11*Zeta[5])/32
 
M1uvwRegII = (-17*Pi^4*G[{0}, yu^(-1)])/180 - (17*Pi^4*G[{0}, yv^(-1)])/180 + 
     (17*Pi^4*G[{0}, yw])/180 - (Pi^2*G[{0}, yu^(-1)]*G[{1}, yu^(-1)]^2)/6 - 
     (Pi^2*G[{0}, yv^(-1)]*G[{1}, yu^(-1)]^2)/6 + 
     (Pi^2*G[{0}, yw]*G[{1}, yu^(-1)]^2)/6 + (Pi^2*G[{1}, yu^(-1)]^3)/18 + 
     (Pi^2*G[{0}, yu^(-1)]*G[{1}, yu^(-1)]*G[{yu^(-1)}, yw])/3 + 
     (Pi^2*G[{0}, yv^(-1)]*G[{1}, yu^(-1)]*G[{yu^(-1)}, yw])/3 - 
     (Pi^2*G[{0}, yw]*G[{1}, yu^(-1)]*G[{yu^(-1)}, yw])/3 - 
     (Pi^2*G[{1}, yu^(-1)]^2*G[{yu^(-1)}, yw])/6 + 
     (Pi^2*G[{0}, yu^(-1)]*G[{1}, yv^(-1)]*G[{yu^(-1)}, yw])/3 + 
     (Pi^2*G[{0}, yv^(-1)]*G[{1}, yv^(-1)]*G[{yu^(-1)}, yw])/3 - 
     (Pi^2*G[{0}, yw]*G[{1}, yv^(-1)]*G[{yu^(-1)}, yw])/3 - 
     (Pi^2*G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*G[{yu^(-1)}, yw])/3 - 
     (Pi^2*G[{1}, yv^(-1)]^2*G[{yu^(-1)}, yw])/6 + 
     G[{0}, yu^(-1)]*G[{1}, yu^(-1)]*G[{1}, yv^(-1)]^2*G[{yu^(-1)}, yw] + 
     G[{0}, yv^(-1)]*G[{1}, yu^(-1)]*G[{1}, yv^(-1)]^2*G[{yu^(-1)}, yw] - 
     G[{0}, yw]*G[{1}, yu^(-1)]*G[{1}, yv^(-1)]^2*G[{yu^(-1)}, yw] - 
     G[{1}, yu^(-1)]^2*G[{1}, yv^(-1)]^2*G[{yu^(-1)}, yw] - 
     (2*G[{1}, yu^(-1)]*G[{1}, yv^(-1)]^3*G[{yu^(-1)}, yw])/3 - 
     (Pi^2*G[{0}, yu^(-1)]*G[{1}, yw]*G[{yu^(-1)}, yw])/3 - 
     (Pi^2*G[{0}, yv^(-1)]*G[{1}, yw]*G[{yu^(-1)}, yw])/3 + 
     (Pi^2*G[{0}, yw]*G[{1}, yw]*G[{yu^(-1)}, yw])/3 + 
     (Pi^2*G[{1}, yu^(-1)]*G[{1}, yw]*G[{yu^(-1)}, yw])/3 + 
     (Pi^2*G[{1}, yv^(-1)]*G[{1}, yw]*G[{yu^(-1)}, yw])/3 - 
     2*G[{0}, yu^(-1)]*G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*G[{1}, yw]*
      G[{yu^(-1)}, yw] - 2*G[{0}, yv^(-1)]*G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*
      G[{1}, yw]*G[{yu^(-1)}, yw] + 2*G[{0}, yw]*G[{1}, yu^(-1)]*
      G[{1}, yv^(-1)]*G[{1}, yw]*G[{yu^(-1)}, yw] + 
     2*G[{1}, yu^(-1)]^2*G[{1}, yv^(-1)]*G[{1}, yw]*G[{yu^(-1)}, yw] + 
     2*G[{1}, yu^(-1)]*G[{1}, yv^(-1)]^2*G[{1}, yw]*G[{yu^(-1)}, yw] + 
     (Pi^2*G[{1}, yv^(-1)]*G[{yu^(-1)}, yw]^2)/3 - 
     G[{0}, yu^(-1)]^2*G[{1}, yv^(-1)]*G[{yu^(-1)}, yw]^2 - 
     2*G[{0}, yu^(-1)]*G[{0}, yv^(-1)]*G[{1}, yv^(-1)]*G[{yu^(-1)}, yw]^2 - 
     G[{0}, yv^(-1)]^2*G[{1}, yv^(-1)]*G[{yu^(-1)}, yw]^2 + 
     2*G[{0}, yu^(-1)]*G[{0}, yw]*G[{1}, yv^(-1)]*G[{yu^(-1)}, yw]^2 + 
     2*G[{0}, yv^(-1)]*G[{0}, yw]*G[{1}, yv^(-1)]*G[{yu^(-1)}, yw]^2 - 
     G[{0}, yw]^2*G[{1}, yv^(-1)]*G[{yu^(-1)}, yw]^2 + 
     2*G[{0}, yu^(-1)]*G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*G[{yu^(-1)}, yw]^2 + 
     2*G[{0}, yv^(-1)]*G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*G[{yu^(-1)}, yw]^2 - 
     2*G[{0}, yw]*G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*G[{yu^(-1)}, yw]^2 - 
     G[{1}, yu^(-1)]^2*G[{1}, yv^(-1)]*G[{yu^(-1)}, yw]^2 + 
     2*G[{0}, yu^(-1)]*G[{1}, yv^(-1)]^2*G[{yu^(-1)}, yw]^2 + 
     2*G[{0}, yv^(-1)]*G[{1}, yv^(-1)]^2*G[{yu^(-1)}, yw]^2 - 
     2*G[{0}, yw]*G[{1}, yv^(-1)]^2*G[{yu^(-1)}, yw]^2 - 
     2*G[{1}, yu^(-1)]*G[{1}, yv^(-1)]^2*G[{yu^(-1)}, yw]^2 - 
     G[{1}, yv^(-1)]^3*G[{yu^(-1)}, yw]^2 + 
     (Pi^2*G[{1}, yw]*G[{yu^(-1)}, yw]^2)/3 - G[{0}, yu^(-1)]^2*G[{1}, yw]*
      G[{yu^(-1)}, yw]^2 - 2*G[{0}, yu^(-1)]*G[{0}, yv^(-1)]*G[{1}, yw]*
      G[{yu^(-1)}, yw]^2 - G[{0}, yv^(-1)]^2*G[{1}, yw]*G[{yu^(-1)}, yw]^2 + 
     2*G[{0}, yu^(-1)]*G[{0}, yw]*G[{1}, yw]*G[{yu^(-1)}, yw]^2 + 
     2*G[{0}, yv^(-1)]*G[{0}, yw]*G[{1}, yw]*G[{yu^(-1)}, yw]^2 - 
     G[{0}, yw]^2*G[{1}, yw]*G[{yu^(-1)}, yw]^2 + 
     2*G[{0}, yu^(-1)]*G[{1}, yu^(-1)]*G[{1}, yw]*G[{yu^(-1)}, yw]^2 + 
     2*G[{0}, yv^(-1)]*G[{1}, yu^(-1)]*G[{1}, yw]*G[{yu^(-1)}, yw]^2 - 
     2*G[{0}, yw]*G[{1}, yu^(-1)]*G[{1}, yw]*G[{yu^(-1)}, yw]^2 - 
     G[{1}, yu^(-1)]^2*G[{1}, yw]*G[{yu^(-1)}, yw]^2 + 
     G[{1}, yv^(-1)]^2*G[{1}, yw]*G[{yu^(-1)}, yw]^2 - 
     2*G[{0}, yu^(-1)]*G[{1}, yw]^2*G[{yu^(-1)}, yw]^2 - 
     2*G[{0}, yv^(-1)]*G[{1}, yw]^2*G[{yu^(-1)}, yw]^2 + 
     2*G[{0}, yw]*G[{1}, yw]^2*G[{yu^(-1)}, yw]^2 + 
     2*G[{1}, yu^(-1)]*G[{1}, yw]^2*G[{yu^(-1)}, yw]^2 + 
     2*G[{1}, yv^(-1)]*G[{1}, yw]^2*G[{yu^(-1)}, yw]^2 - 
     (Pi^2*G[{yu^(-1)}, yw]^3)/9 + (G[{0}, yu^(-1)]^2*G[{yu^(-1)}, yw]^3)/3 + 
     (2*G[{0}, yu^(-1)]*G[{0}, yv^(-1)]*G[{yu^(-1)}, yw]^3)/3 + 
     (G[{0}, yv^(-1)]^2*G[{yu^(-1)}, yw]^3)/3 - 
     (2*G[{0}, yu^(-1)]*G[{0}, yw]*G[{yu^(-1)}, yw]^3)/3 - 
     (2*G[{0}, yv^(-1)]*G[{0}, yw]*G[{yu^(-1)}, yw]^3)/3 + 
     (G[{0}, yw]^2*G[{yu^(-1)}, yw]^3)/3 - 
     (2*G[{0}, yu^(-1)]*G[{1}, yu^(-1)]*G[{yu^(-1)}, yw]^3)/3 - 
     (2*G[{0}, yv^(-1)]*G[{1}, yu^(-1)]*G[{yu^(-1)}, yw]^3)/3 + 
     (2*G[{0}, yw]*G[{1}, yu^(-1)]*G[{yu^(-1)}, yw]^3)/3 + 
     (G[{1}, yu^(-1)]^2*G[{yu^(-1)}, yw]^3)/3 - 
     (2*G[{0}, yu^(-1)]*G[{1}, yv^(-1)]*G[{yu^(-1)}, yw]^3)/3 - 
     (2*G[{0}, yv^(-1)]*G[{1}, yv^(-1)]*G[{yu^(-1)}, yw]^3)/3 + 
     (2*G[{0}, yw]*G[{1}, yv^(-1)]*G[{yu^(-1)}, yw]^3)/3 + 
     (2*G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*G[{yu^(-1)}, yw]^3)/3 + 
     (G[{1}, yv^(-1)]^2*G[{yu^(-1)}, yw]^3)/3 + 
     (2*G[{0}, yu^(-1)]*G[{1}, yw]*G[{yu^(-1)}, yw]^3)/3 + 
     (2*G[{0}, yv^(-1)]*G[{1}, yw]*G[{yu^(-1)}, yw]^3)/3 - 
     (2*G[{0}, yw]*G[{1}, yw]*G[{yu^(-1)}, yw]^3)/3 - 
     (2*G[{1}, yu^(-1)]*G[{1}, yw]*G[{yu^(-1)}, yw]^3)/3 - 
     (2*G[{1}, yv^(-1)]*G[{1}, yw]*G[{yu^(-1)}, yw]^3)/3 + 
     (G[{1}, yv^(-1)]*G[{yu^(-1)}, yw]^4)/6 + (G[{1}, yw]*G[{yu^(-1)}, yw]^4)/
      6 - G[{yu^(-1)}, yw]^5/30 + (17*Pi^4*G[{yu}, yv^(-1)])/180 + 
     (Pi^2*G[{1}, yu^(-1)]^2*G[{yu}, yv^(-1)])/6 + 
     (Pi^2*G[{0}, yu^(-1)]*G[{1}, yv^(-1)]*G[{yu}, yv^(-1)])/3 + 
     (Pi^2*G[{0}, yv^(-1)]*G[{1}, yv^(-1)]*G[{yu}, yv^(-1)])/3 - 
     (Pi^2*G[{0}, yw]*G[{1}, yv^(-1)]*G[{yu}, yv^(-1)])/3 - 
     (Pi^2*G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*G[{yu}, yv^(-1)])/3 - 
     (Pi^2*G[{1}, yv^(-1)]^2*G[{yu}, yv^(-1)])/6 + 
     G[{0}, yu^(-1)]*G[{1}, yu^(-1)]*G[{1}, yv^(-1)]^2*G[{yu}, yv^(-1)] + 
     G[{0}, yv^(-1)]*G[{1}, yu^(-1)]*G[{1}, yv^(-1)]^2*G[{yu}, yv^(-1)] - 
     G[{0}, yw]*G[{1}, yu^(-1)]*G[{1}, yv^(-1)]^2*G[{yu}, yv^(-1)] - 
     G[{1}, yu^(-1)]^2*G[{1}, yv^(-1)]^2*G[{yu}, yv^(-1)] - 
     (2*G[{1}, yu^(-1)]*G[{1}, yv^(-1)]^3*G[{yu}, yv^(-1)])/3 - 
     (Pi^2*G[{0}, yu^(-1)]*G[{yu^(-1)}, yw]*G[{yu}, yv^(-1)])/3 - 
     (Pi^2*G[{0}, yv^(-1)]*G[{yu^(-1)}, yw]*G[{yu}, yv^(-1)])/3 + 
     (Pi^2*G[{0}, yw]*G[{yu^(-1)}, yw]*G[{yu}, yv^(-1)])/3 + 
     (2*Pi^2*G[{1}, yv^(-1)]*G[{yu^(-1)}, yw]*G[{yu}, yv^(-1)])/3 - 
     2*G[{0}, yu^(-1)]^2*G[{1}, yv^(-1)]*G[{yu^(-1)}, yw]*G[{yu}, yv^(-1)] - 
     4*G[{0}, yu^(-1)]*G[{0}, yv^(-1)]*G[{1}, yv^(-1)]*G[{yu^(-1)}, yw]*
      G[{yu}, yv^(-1)] - 2*G[{0}, yv^(-1)]^2*G[{1}, yv^(-1)]*G[{yu^(-1)}, yw]*
      G[{yu}, yv^(-1)] + 4*G[{0}, yu^(-1)]*G[{0}, yw]*G[{1}, yv^(-1)]*
      G[{yu^(-1)}, yw]*G[{yu}, yv^(-1)] + 4*G[{0}, yv^(-1)]*G[{0}, yw]*
      G[{1}, yv^(-1)]*G[{yu^(-1)}, yw]*G[{yu}, yv^(-1)] - 
     2*G[{0}, yw]^2*G[{1}, yv^(-1)]*G[{yu^(-1)}, yw]*G[{yu}, yv^(-1)] + 
     2*G[{1}, yu^(-1)]^2*G[{1}, yv^(-1)]*G[{yu^(-1)}, yw]*G[{yu}, yv^(-1)] + 
     4*G[{0}, yu^(-1)]*G[{1}, yv^(-1)]^2*G[{yu^(-1)}, yw]*G[{yu}, yv^(-1)] + 
     4*G[{0}, yv^(-1)]*G[{1}, yv^(-1)]^2*G[{yu^(-1)}, yw]*G[{yu}, yv^(-1)] - 
     4*G[{0}, yw]*G[{1}, yv^(-1)]^2*G[{yu^(-1)}, yw]*G[{yu}, yv^(-1)] - 
     2*G[{1}, yu^(-1)]*G[{1}, yv^(-1)]^2*G[{yu^(-1)}, yw]*G[{yu}, yv^(-1)] - 
     2*G[{1}, yv^(-1)]^3*G[{yu^(-1)}, yw]*G[{yu}, yv^(-1)] + 
     2*G[{0}, yu^(-1)]*G[{1}, yu^(-1)]*G[{1}, yw]*G[{yu^(-1)}, yw]*
      G[{yu}, yv^(-1)] + 2*G[{0}, yv^(-1)]*G[{1}, yu^(-1)]*G[{1}, yw]*
      G[{yu^(-1)}, yw]*G[{yu}, yv^(-1)] - 2*G[{0}, yw]*G[{1}, yu^(-1)]*
      G[{1}, yw]*G[{yu^(-1)}, yw]*G[{yu}, yv^(-1)] - 
     2*G[{1}, yu^(-1)]^2*G[{1}, yw]*G[{yu^(-1)}, yw]*G[{yu}, yv^(-1)] - 
     2*G[{0}, yu^(-1)]*G[{1}, yv^(-1)]*G[{1}, yw]*G[{yu^(-1)}, yw]*
      G[{yu}, yv^(-1)] - 2*G[{0}, yv^(-1)]*G[{1}, yv^(-1)]*G[{1}, yw]*
      G[{yu^(-1)}, yw]*G[{yu}, yv^(-1)] + 2*G[{0}, yw]*G[{1}, yv^(-1)]*
      G[{1}, yw]*G[{yu^(-1)}, yw]*G[{yu}, yv^(-1)] + 
     2*G[{1}, yv^(-1)]^2*G[{1}, yw]*G[{yu^(-1)}, yw]*G[{yu}, yv^(-1)] - 
     (Pi^2*G[{yu^(-1)}, yw]^2*G[{yu}, yv^(-1)])/3 + 
     G[{0}, yu^(-1)]^2*G[{yu^(-1)}, yw]^2*G[{yu}, yv^(-1)] + 
     2*G[{0}, yu^(-1)]*G[{0}, yv^(-1)]*G[{yu^(-1)}, yw]^2*G[{yu}, yv^(-1)] + 
     G[{0}, yv^(-1)]^2*G[{yu^(-1)}, yw]^2*G[{yu}, yv^(-1)] - 
     2*G[{0}, yu^(-1)]*G[{0}, yw]*G[{yu^(-1)}, yw]^2*G[{yu}, yv^(-1)] - 
     2*G[{0}, yv^(-1)]*G[{0}, yw]*G[{yu^(-1)}, yw]^2*G[{yu}, yv^(-1)] + 
     G[{0}, yw]^2*G[{yu^(-1)}, yw]^2*G[{yu}, yv^(-1)] - 
     2*G[{0}, yu^(-1)]*G[{1}, yu^(-1)]*G[{yu^(-1)}, yw]^2*G[{yu}, yv^(-1)] - 
     2*G[{0}, yv^(-1)]*G[{1}, yu^(-1)]*G[{yu^(-1)}, yw]^2*G[{yu}, yv^(-1)] + 
     2*G[{0}, yw]*G[{1}, yu^(-1)]*G[{yu^(-1)}, yw]^2*G[{yu}, yv^(-1)] + 
     G[{1}, yu^(-1)]^2*G[{yu^(-1)}, yw]^2*G[{yu}, yv^(-1)] - 
     2*G[{0}, yu^(-1)]*G[{1}, yv^(-1)]*G[{yu^(-1)}, yw]^2*G[{yu}, yv^(-1)] - 
     2*G[{0}, yv^(-1)]*G[{1}, yv^(-1)]*G[{yu^(-1)}, yw]^2*G[{yu}, yv^(-1)] + 
     2*G[{0}, yw]*G[{1}, yv^(-1)]*G[{yu^(-1)}, yw]^2*G[{yu}, yv^(-1)] + 
     2*G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*G[{yu^(-1)}, yw]^2*G[{yu}, yv^(-1)] + 
     G[{1}, yv^(-1)]^2*G[{yu^(-1)}, yw]^2*G[{yu}, yv^(-1)] + 
     2*G[{0}, yu^(-1)]*G[{1}, yw]*G[{yu^(-1)}, yw]^2*G[{yu}, yv^(-1)] + 
     2*G[{0}, yv^(-1)]*G[{1}, yw]*G[{yu^(-1)}, yw]^2*G[{yu}, yv^(-1)] - 
     2*G[{0}, yw]*G[{1}, yw]*G[{yu^(-1)}, yw]^2*G[{yu}, yv^(-1)] - 
     2*G[{1}, yu^(-1)]*G[{1}, yw]*G[{yu^(-1)}, yw]^2*G[{yu}, yv^(-1)] - 
     3*G[{1}, yv^(-1)]*G[{1}, yw]*G[{yu^(-1)}, yw]^2*G[{yu}, yv^(-1)] + 
     (2*G[{1}, yv^(-1)]*G[{yu^(-1)}, yw]^3*G[{yu}, yv^(-1)])/3 - 
     (G[{yu^(-1)}, yw]^4*G[{yu}, yv^(-1)])/6 - G[{0}, yu^(-1)]^2*
      G[{1}, yv^(-1)]*G[{yu}, yv^(-1)]^2 - 2*G[{0}, yu^(-1)]*G[{0}, yv^(-1)]*
      G[{1}, yv^(-1)]*G[{yu}, yv^(-1)]^2 - G[{0}, yv^(-1)]^2*G[{1}, yv^(-1)]*
      G[{yu}, yv^(-1)]^2 + 2*G[{0}, yu^(-1)]*G[{0}, yw]*G[{1}, yv^(-1)]*
      G[{yu}, yv^(-1)]^2 + 2*G[{0}, yv^(-1)]*G[{0}, yw]*G[{1}, yv^(-1)]*
      G[{yu}, yv^(-1)]^2 - G[{0}, yw]^2*G[{1}, yv^(-1)]*G[{yu}, yv^(-1)]^2 + 
     G[{1}, yu^(-1)]^2*G[{1}, yv^(-1)]*G[{yu}, yv^(-1)]^2 + 
     2*G[{0}, yu^(-1)]*G[{1}, yv^(-1)]^2*G[{yu}, yv^(-1)]^2 + 
     2*G[{0}, yv^(-1)]*G[{1}, yv^(-1)]^2*G[{yu}, yv^(-1)]^2 - 
     2*G[{0}, yw]*G[{1}, yv^(-1)]^2*G[{yu}, yv^(-1)]^2 - 
     2*G[{1}, yu^(-1)]*G[{1}, yv^(-1)]^2*G[{yu}, yv^(-1)]^2 - 
     G[{1}, yv^(-1)]^3*G[{yu}, yv^(-1)]^2 + G[{0}, yu^(-1)]^2*
      G[{yu^(-1)}, yw]*G[{yu}, yv^(-1)]^2 + 2*G[{0}, yu^(-1)]*G[{0}, yv^(-1)]*
      G[{yu^(-1)}, yw]*G[{yu}, yv^(-1)]^2 + G[{0}, yv^(-1)]^2*
      G[{yu^(-1)}, yw]*G[{yu}, yv^(-1)]^2 - 2*G[{0}, yu^(-1)]*G[{0}, yw]*
      G[{yu^(-1)}, yw]*G[{yu}, yv^(-1)]^2 - 2*G[{0}, yv^(-1)]*G[{0}, yw]*
      G[{yu^(-1)}, yw]*G[{yu}, yv^(-1)]^2 + G[{0}, yw]^2*G[{yu^(-1)}, yw]*
      G[{yu}, yv^(-1)]^2 - G[{1}, yu^(-1)]^2*G[{yu^(-1)}, yw]*
      G[{yu}, yv^(-1)]^2 + 2*G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*G[{yu^(-1)}, yw]*
      G[{yu}, yv^(-1)]^2 - G[{1}, yv^(-1)]^2*G[{yu^(-1)}, yw]*
      G[{yu}, yv^(-1)]^2 - G[{1}, yv^(-1)]*G[{1}, yw]*G[{yu^(-1)}, yw]*
      G[{yu}, yv^(-1)]^2 + G[{1}, yv^(-1)]*G[{yu^(-1)}, yw]^2*
      G[{yu}, yv^(-1)]^2 + (G[{1}, yw]*G[{yu^(-1)}, yw]^2*G[{yu}, yv^(-1)]^2)/
      2 - (G[{yu^(-1)}, yw]^3*G[{yu}, yv^(-1)]^2)/3 + 
     (G[{0}, yu^(-1)]^2*G[{yu}, yv^(-1)]^3)/3 + 
     (2*G[{0}, yu^(-1)]*G[{0}, yv^(-1)]*G[{yu}, yv^(-1)]^3)/3 + 
     (G[{0}, yv^(-1)]^2*G[{yu}, yv^(-1)]^3)/3 - 
     (2*G[{0}, yu^(-1)]*G[{0}, yw]*G[{yu}, yv^(-1)]^3)/3 - 
     (2*G[{0}, yv^(-1)]*G[{0}, yw]*G[{yu}, yv^(-1)]^3)/3 + 
     (G[{0}, yw]^2*G[{yu}, yv^(-1)]^3)/3 - 
     (G[{1}, yu^(-1)]^2*G[{yu}, yv^(-1)]^3)/3 + 
     (4*G[{0}, yu^(-1)]*G[{1}, yv^(-1)]*G[{yu}, yv^(-1)]^3)/3 + 
     (4*G[{0}, yv^(-1)]*G[{1}, yv^(-1)]*G[{yu}, yv^(-1)]^3)/3 - 
     (4*G[{0}, yw]*G[{1}, yv^(-1)]*G[{yu}, yv^(-1)]^3)/3 + 
     (2*G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*G[{yu}, yv^(-1)]^3)/3 - 
     (5*G[{1}, yv^(-1)]^2*G[{yu}, yv^(-1)]^3)/3 - 
     (4*G[{0}, yu^(-1)]*G[{yu^(-1)}, yw]*G[{yu}, yv^(-1)]^3)/3 - 
     (4*G[{0}, yv^(-1)]*G[{yu^(-1)}, yw]*G[{yu}, yv^(-1)]^3)/3 + 
     (4*G[{0}, yw]*G[{yu^(-1)}, yw]*G[{yu}, yv^(-1)]^3)/3 + 
     (2*G[{1}, yv^(-1)]*G[{yu^(-1)}, yw]*G[{yu}, yv^(-1)]^3)/3 + 
     (G[{1}, yw]*G[{yu^(-1)}, yw]*G[{yu}, yv^(-1)]^3)/3 - 
     (G[{yu^(-1)}, yw]^2*G[{yu}, yv^(-1)]^3)/3 - 
     (2*G[{0}, yu^(-1)]*G[{yu}, yv^(-1)]^4)/3 - 
     (2*G[{0}, yv^(-1)]*G[{yu}, yv^(-1)]^4)/3 + 
     (2*G[{0}, yw]*G[{yu}, yv^(-1)]^4)/3 - 
     (G[{1}, yv^(-1)]*G[{yu}, yv^(-1)]^4)/2 + 
     (G[{yu^(-1)}, yw]*G[{yu}, yv^(-1)]^4)/2 + (11*G[{yu}, yv^(-1)]^5)/30 - 
     (17*Pi^4*G[{1/(yu*yv)}, yw])/180 - 
     (Pi^2*G[{1}, yu^(-1)]^2*G[{1/(yu*yv)}, yw])/6 - 
     (Pi^2*G[{0}, yu^(-1)]*G[{1}, yv^(-1)]*G[{1/(yu*yv)}, yw])/3 - 
     (Pi^2*G[{0}, yv^(-1)]*G[{1}, yv^(-1)]*G[{1/(yu*yv)}, yw])/3 + 
     (Pi^2*G[{0}, yw]*G[{1}, yv^(-1)]*G[{1/(yu*yv)}, yw])/3 + 
     (Pi^2*G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*G[{1/(yu*yv)}, yw])/3 + 
     (Pi^2*G[{1}, yv^(-1)]^2*G[{1/(yu*yv)}, yw])/6 - 
     G[{0}, yu^(-1)]*G[{1}, yu^(-1)]*G[{1}, yv^(-1)]^2*G[{1/(yu*yv)}, yw] - 
     G[{0}, yv^(-1)]*G[{1}, yu^(-1)]*G[{1}, yv^(-1)]^2*G[{1/(yu*yv)}, yw] + 
     G[{0}, yw]*G[{1}, yu^(-1)]*G[{1}, yv^(-1)]^2*G[{1/(yu*yv)}, yw] + 
     G[{1}, yu^(-1)]^2*G[{1}, yv^(-1)]^2*G[{1/(yu*yv)}, yw] + 
     (2*G[{1}, yu^(-1)]*G[{1}, yv^(-1)]^3*G[{1/(yu*yv)}, yw])/3 + 
     (Pi^2*G[{0}, yu^(-1)]*G[{1}, yw]*G[{1/(yu*yv)}, yw])/3 + 
     (Pi^2*G[{0}, yv^(-1)]*G[{1}, yw]*G[{1/(yu*yv)}, yw])/3 - 
     (Pi^2*G[{0}, yw]*G[{1}, yw]*G[{1/(yu*yv)}, yw])/3 - 
     (Pi^2*G[{1}, yu^(-1)]*G[{1}, yw]*G[{1/(yu*yv)}, yw])/3 - 
     (Pi^2*G[{1}, yv^(-1)]*G[{1}, yw]*G[{1/(yu*yv)}, yw])/3 + 
     2*G[{0}, yu^(-1)]*G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*G[{1}, yw]*
      G[{1/(yu*yv)}, yw] + 2*G[{0}, yv^(-1)]*G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*
      G[{1}, yw]*G[{1/(yu*yv)}, yw] - 2*G[{0}, yw]*G[{1}, yu^(-1)]*
      G[{1}, yv^(-1)]*G[{1}, yw]*G[{1/(yu*yv)}, yw] - 
     2*G[{1}, yu^(-1)]^2*G[{1}, yv^(-1)]*G[{1}, yw]*G[{1/(yu*yv)}, yw] - 
     2*G[{1}, yu^(-1)]*G[{1}, yv^(-1)]^2*G[{1}, yw]*G[{1/(yu*yv)}, yw] + 
     (Pi^2*G[{0}, yu^(-1)]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw])/3 + 
     (Pi^2*G[{0}, yv^(-1)]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw])/3 - 
     (Pi^2*G[{0}, yw]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw])/3 - 
     (2*Pi^2*G[{1}, yv^(-1)]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw])/3 + 
     2*G[{0}, yu^(-1)]^2*G[{1}, yv^(-1)]*G[{yu^(-1)}, yw]*
      G[{1/(yu*yv)}, yw] + 4*G[{0}, yu^(-1)]*G[{0}, yv^(-1)]*G[{1}, yv^(-1)]*
      G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw] + 2*G[{0}, yv^(-1)]^2*
      G[{1}, yv^(-1)]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw] - 
     4*G[{0}, yu^(-1)]*G[{0}, yw]*G[{1}, yv^(-1)]*G[{yu^(-1)}, yw]*
      G[{1/(yu*yv)}, yw] - 4*G[{0}, yv^(-1)]*G[{0}, yw]*G[{1}, yv^(-1)]*
      G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw] + 2*G[{0}, yw]^2*G[{1}, yv^(-1)]*
      G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw] - 2*G[{1}, yu^(-1)]^2*
      G[{1}, yv^(-1)]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw] - 
     4*G[{0}, yu^(-1)]*G[{1}, yv^(-1)]^2*G[{yu^(-1)}, yw]*
      G[{1/(yu*yv)}, yw] - 4*G[{0}, yv^(-1)]*G[{1}, yv^(-1)]^2*
      G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw] + 4*G[{0}, yw]*G[{1}, yv^(-1)]^2*
      G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw] + 2*G[{1}, yu^(-1)]*
      G[{1}, yv^(-1)]^2*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw] + 
     2*G[{1}, yv^(-1)]^3*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw] + 
     2*G[{0}, yu^(-1)]^2*G[{1}, yw]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw] + 
     4*G[{0}, yu^(-1)]*G[{0}, yv^(-1)]*G[{1}, yw]*G[{yu^(-1)}, yw]*
      G[{1/(yu*yv)}, yw] + 2*G[{0}, yv^(-1)]^2*G[{1}, yw]*G[{yu^(-1)}, yw]*
      G[{1/(yu*yv)}, yw] - 4*G[{0}, yu^(-1)]*G[{0}, yw]*G[{1}, yw]*
      G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw] - 4*G[{0}, yv^(-1)]*G[{0}, yw]*
      G[{1}, yw]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw] + 
     2*G[{0}, yw]^2*G[{1}, yw]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw] - 
     4*G[{0}, yu^(-1)]*G[{1}, yu^(-1)]*G[{1}, yw]*G[{yu^(-1)}, yw]*
      G[{1/(yu*yv)}, yw] - 4*G[{0}, yv^(-1)]*G[{1}, yu^(-1)]*G[{1}, yw]*
      G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw] + 4*G[{0}, yw]*G[{1}, yu^(-1)]*
      G[{1}, yw]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw] + 
     2*G[{1}, yu^(-1)]^2*G[{1}, yw]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw] + 
     4*G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*G[{1}, yw]*G[{yu^(-1)}, yw]*
      G[{1/(yu*yv)}, yw] - 2*G[{1}, yv^(-1)]^2*G[{1}, yw]*G[{yu^(-1)}, yw]*
      G[{1/(yu*yv)}, yw] + 2*G[{0}, yu^(-1)]*G[{1}, yw]^2*G[{yu^(-1)}, yw]*
      G[{1/(yu*yv)}, yw] + 2*G[{0}, yv^(-1)]*G[{1}, yw]^2*G[{yu^(-1)}, yw]*
      G[{1/(yu*yv)}, yw] - 2*G[{0}, yw]*G[{1}, yw]^2*G[{yu^(-1)}, yw]*
      G[{1/(yu*yv)}, yw] - 2*G[{1}, yu^(-1)]*G[{1}, yw]^2*G[{yu^(-1)}, yw]*
      G[{1/(yu*yv)}, yw] - 2*G[{1}, yv^(-1)]*G[{1}, yw]^2*G[{yu^(-1)}, yw]*
      G[{1/(yu*yv)}, yw] + (Pi^2*G[{yu^(-1)}, yw]^2*G[{1/(yu*yv)}, yw])/3 - 
     G[{0}, yu^(-1)]^2*G[{yu^(-1)}, yw]^2*G[{1/(yu*yv)}, yw] - 
     2*G[{0}, yu^(-1)]*G[{0}, yv^(-1)]*G[{yu^(-1)}, yw]^2*
      G[{1/(yu*yv)}, yw] - G[{0}, yv^(-1)]^2*G[{yu^(-1)}, yw]^2*
      G[{1/(yu*yv)}, yw] + 2*G[{0}, yu^(-1)]*G[{0}, yw]*G[{yu^(-1)}, yw]^2*
      G[{1/(yu*yv)}, yw] + 2*G[{0}, yv^(-1)]*G[{0}, yw]*G[{yu^(-1)}, yw]^2*
      G[{1/(yu*yv)}, yw] - G[{0}, yw]^2*G[{yu^(-1)}, yw]^2*
      G[{1/(yu*yv)}, yw] + 2*G[{0}, yu^(-1)]*G[{1}, yu^(-1)]*
      G[{yu^(-1)}, yw]^2*G[{1/(yu*yv)}, yw] + 2*G[{0}, yv^(-1)]*
      G[{1}, yu^(-1)]*G[{yu^(-1)}, yw]^2*G[{1/(yu*yv)}, yw] - 
     2*G[{0}, yw]*G[{1}, yu^(-1)]*G[{yu^(-1)}, yw]^2*G[{1/(yu*yv)}, yw] - 
     G[{1}, yu^(-1)]^2*G[{yu^(-1)}, yw]^2*G[{1/(yu*yv)}, yw] + 
     2*G[{0}, yu^(-1)]*G[{1}, yv^(-1)]*G[{yu^(-1)}, yw]^2*
      G[{1/(yu*yv)}, yw] + 2*G[{0}, yv^(-1)]*G[{1}, yv^(-1)]*
      G[{yu^(-1)}, yw]^2*G[{1/(yu*yv)}, yw] - 2*G[{0}, yw]*G[{1}, yv^(-1)]*
      G[{yu^(-1)}, yw]^2*G[{1/(yu*yv)}, yw] - 2*G[{1}, yu^(-1)]*
      G[{1}, yv^(-1)]*G[{yu^(-1)}, yw]^2*G[{1/(yu*yv)}, yw] - 
     G[{1}, yv^(-1)]^2*G[{yu^(-1)}, yw]^2*G[{1/(yu*yv)}, yw] - 
     2*G[{0}, yu^(-1)]*G[{1}, yw]*G[{yu^(-1)}, yw]^2*G[{1/(yu*yv)}, yw] - 
     2*G[{0}, yv^(-1)]*G[{1}, yw]*G[{yu^(-1)}, yw]^2*G[{1/(yu*yv)}, yw] + 
     2*G[{0}, yw]*G[{1}, yw]*G[{yu^(-1)}, yw]^2*G[{1/(yu*yv)}, yw] + 
     2*G[{1}, yu^(-1)]*G[{1}, yw]*G[{yu^(-1)}, yw]^2*G[{1/(yu*yv)}, yw] + 
     2*G[{1}, yv^(-1)]*G[{1}, yw]*G[{yu^(-1)}, yw]^2*G[{1/(yu*yv)}, yw] - 
     (2*G[{1}, yv^(-1)]*G[{yu^(-1)}, yw]^3*G[{1/(yu*yv)}, yw])/3 - 
     (2*G[{1}, yw]*G[{yu^(-1)}, yw]^3*G[{1/(yu*yv)}, yw])/3 + 
     (G[{yu^(-1)}, yw]^4*G[{1/(yu*yv)}, yw])/6 + 2*G[{0}, yu^(-1)]^2*
      G[{1}, yv^(-1)]*G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw] + 
     4*G[{0}, yu^(-1)]*G[{0}, yv^(-1)]*G[{1}, yv^(-1)]*G[{yu}, yv^(-1)]*
      G[{1/(yu*yv)}, yw] + 2*G[{0}, yv^(-1)]^2*G[{1}, yv^(-1)]*
      G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw] - 4*G[{0}, yu^(-1)]*G[{0}, yw]*
      G[{1}, yv^(-1)]*G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw] - 
     4*G[{0}, yv^(-1)]*G[{0}, yw]*G[{1}, yv^(-1)]*G[{yu}, yv^(-1)]*
      G[{1/(yu*yv)}, yw] + 2*G[{0}, yw]^2*G[{1}, yv^(-1)]*G[{yu}, yv^(-1)]*
      G[{1/(yu*yv)}, yw] - 2*G[{1}, yu^(-1)]^2*G[{1}, yv^(-1)]*
      G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw] - 4*G[{0}, yu^(-1)]*
      G[{1}, yv^(-1)]^2*G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw] - 
     4*G[{0}, yv^(-1)]*G[{1}, yv^(-1)]^2*G[{yu}, yv^(-1)]*
      G[{1/(yu*yv)}, yw] + 4*G[{0}, yw]*G[{1}, yv^(-1)]^2*G[{yu}, yv^(-1)]*
      G[{1/(yu*yv)}, yw] + 4*G[{1}, yu^(-1)]*G[{1}, yv^(-1)]^2*
      G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw] + 2*G[{1}, yv^(-1)]^3*
      G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw] - 2*G[{0}, yu^(-1)]*G[{1}, yu^(-1)]*
      G[{1}, yw]*G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw] - 
     2*G[{0}, yv^(-1)]*G[{1}, yu^(-1)]*G[{1}, yw]*G[{yu}, yv^(-1)]*
      G[{1/(yu*yv)}, yw] + 2*G[{0}, yw]*G[{1}, yu^(-1)]*G[{1}, yw]*
      G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw] + 2*G[{1}, yu^(-1)]^2*G[{1}, yw]*
      G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw] + 2*G[{0}, yu^(-1)]*G[{1}, yv^(-1)]*
      G[{1}, yw]*G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw] + 
     2*G[{0}, yv^(-1)]*G[{1}, yv^(-1)]*G[{1}, yw]*G[{yu}, yv^(-1)]*
      G[{1/(yu*yv)}, yw] - 2*G[{0}, yw]*G[{1}, yv^(-1)]*G[{1}, yw]*
      G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw] - 2*G[{1}, yv^(-1)]^2*G[{1}, yw]*
      G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw] - 2*G[{0}, yu^(-1)]^2*
      G[{yu^(-1)}, yw]*G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw] - 
     4*G[{0}, yu^(-1)]*G[{0}, yv^(-1)]*G[{yu^(-1)}, yw]*G[{yu}, yv^(-1)]*
      G[{1/(yu*yv)}, yw] - 2*G[{0}, yv^(-1)]^2*G[{yu^(-1)}, yw]*
      G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw] + 4*G[{0}, yu^(-1)]*G[{0}, yw]*
      G[{yu^(-1)}, yw]*G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw] + 
     4*G[{0}, yv^(-1)]*G[{0}, yw]*G[{yu^(-1)}, yw]*G[{yu}, yv^(-1)]*
      G[{1/(yu*yv)}, yw] - 2*G[{0}, yw]^2*G[{yu^(-1)}, yw]*G[{yu}, yv^(-1)]*
      G[{1/(yu*yv)}, yw] + 2*G[{1}, yu^(-1)]^2*G[{yu^(-1)}, yw]*
      G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw] - 4*G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*
      G[{yu^(-1)}, yw]*G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw] + 
     2*G[{1}, yv^(-1)]^2*G[{yu^(-1)}, yw]*G[{yu}, yv^(-1)]*
      G[{1/(yu*yv)}, yw] - 4*G[{0}, yu^(-1)]*G[{1}, yw]*G[{yu^(-1)}, yw]*
      G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw] - 4*G[{0}, yv^(-1)]*G[{1}, yw]*
      G[{yu^(-1)}, yw]*G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw] + 
     4*G[{0}, yw]*G[{1}, yw]*G[{yu^(-1)}, yw]*G[{yu}, yv^(-1)]*
      G[{1/(yu*yv)}, yw] + 2*G[{1}, yv^(-1)]*G[{1}, yw]*G[{yu^(-1)}, yw]*
      G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw] - 2*G[{1}, yv^(-1)]*
      G[{yu^(-1)}, yw]^2*G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw] + 
     (2*G[{yu^(-1)}, yw]^3*G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw])/3 - 
     G[{0}, yu^(-1)]^2*G[{yu}, yv^(-1)]^2*G[{1/(yu*yv)}, yw] - 
     2*G[{0}, yu^(-1)]*G[{0}, yv^(-1)]*G[{yu}, yv^(-1)]^2*
      G[{1/(yu*yv)}, yw] - G[{0}, yv^(-1)]^2*G[{yu}, yv^(-1)]^2*
      G[{1/(yu*yv)}, yw] + 2*G[{0}, yu^(-1)]*G[{0}, yw]*G[{yu}, yv^(-1)]^2*
      G[{1/(yu*yv)}, yw] + 2*G[{0}, yv^(-1)]*G[{0}, yw]*G[{yu}, yv^(-1)]^2*
      G[{1/(yu*yv)}, yw] - G[{0}, yw]^2*G[{yu}, yv^(-1)]^2*
      G[{1/(yu*yv)}, yw] + G[{1}, yu^(-1)]^2*G[{yu}, yv^(-1)]^2*
      G[{1/(yu*yv)}, yw] - 4*G[{0}, yu^(-1)]*G[{1}, yv^(-1)]*
      G[{yu}, yv^(-1)]^2*G[{1/(yu*yv)}, yw] - 4*G[{0}, yv^(-1)]*
      G[{1}, yv^(-1)]*G[{yu}, yv^(-1)]^2*G[{1/(yu*yv)}, yw] + 
     4*G[{0}, yw]*G[{1}, yv^(-1)]*G[{yu}, yv^(-1)]^2*G[{1/(yu*yv)}, yw] - 
     2*G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*G[{yu}, yv^(-1)]^2*
      G[{1/(yu*yv)}, yw] + 5*G[{1}, yv^(-1)]^2*G[{yu}, yv^(-1)]^2*
      G[{1/(yu*yv)}, yw] - 3*G[{1}, yv^(-1)]*G[{1}, yw]*G[{yu}, yv^(-1)]^2*
      G[{1/(yu*yv)}, yw] + 4*G[{0}, yu^(-1)]*G[{yu^(-1)}, yw]*
      G[{yu}, yv^(-1)]^2*G[{1/(yu*yv)}, yw] + 4*G[{0}, yv^(-1)]*
      G[{yu^(-1)}, yw]*G[{yu}, yv^(-1)]^2*G[{1/(yu*yv)}, yw] - 
     4*G[{0}, yw]*G[{yu^(-1)}, yw]*G[{yu}, yv^(-1)]^2*G[{1/(yu*yv)}, yw] - 
     2*G[{1}, yv^(-1)]*G[{yu^(-1)}, yw]*G[{yu}, yv^(-1)]^2*
      G[{1/(yu*yv)}, yw] + 3*G[{1}, yw]*G[{yu^(-1)}, yw]*G[{yu}, yv^(-1)]^2*
      G[{1/(yu*yv)}, yw] + G[{yu^(-1)}, yw]^2*G[{yu}, yv^(-1)]^2*
      G[{1/(yu*yv)}, yw] + (8*G[{0}, yu^(-1)]*G[{yu}, yv^(-1)]^3*
       G[{1/(yu*yv)}, yw])/3 + (8*G[{0}, yv^(-1)]*G[{yu}, yv^(-1)]^3*
       G[{1/(yu*yv)}, yw])/3 - (8*G[{0}, yw]*G[{yu}, yv^(-1)]^3*
       G[{1/(yu*yv)}, yw])/3 + 2*G[{1}, yv^(-1)]*G[{yu}, yv^(-1)]^3*
      G[{1/(yu*yv)}, yw] + G[{1}, yw]*G[{yu}, yv^(-1)]^3*G[{1/(yu*yv)}, yw] - 
     2*G[{yu^(-1)}, yw]*G[{yu}, yv^(-1)]^3*G[{1/(yu*yv)}, yw] - 
     (11*G[{yu}, yv^(-1)]^4*G[{1/(yu*yv)}, yw])/6 - 
     (Pi^2*G[{0}, yu^(-1)]*G[{1/(yu*yv)}, yw]^2)/6 - 
     (Pi^2*G[{0}, yv^(-1)]*G[{1/(yu*yv)}, yw]^2)/6 + 
     (Pi^2*G[{0}, yw]*G[{1/(yu*yv)}, yw]^2)/6 + 
     (Pi^2*G[{1}, yu^(-1)]*G[{1/(yu*yv)}, yw]^2)/6 + 
     (Pi^2*G[{1}, yv^(-1)]*G[{1/(yu*yv)}, yw]^2)/6 - 
     G[{0}, yu^(-1)]^2*G[{1}, yv^(-1)]*G[{1/(yu*yv)}, yw]^2 - 
     2*G[{0}, yu^(-1)]*G[{0}, yv^(-1)]*G[{1}, yv^(-1)]*G[{1/(yu*yv)}, yw]^2 - 
     G[{0}, yv^(-1)]^2*G[{1}, yv^(-1)]*G[{1/(yu*yv)}, yw]^2 + 
     2*G[{0}, yu^(-1)]*G[{0}, yw]*G[{1}, yv^(-1)]*G[{1/(yu*yv)}, yw]^2 + 
     2*G[{0}, yv^(-1)]*G[{0}, yw]*G[{1}, yv^(-1)]*G[{1/(yu*yv)}, yw]^2 - 
     G[{0}, yw]^2*G[{1}, yv^(-1)]*G[{1/(yu*yv)}, yw]^2 - 
     G[{0}, yu^(-1)]*G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*G[{1/(yu*yv)}, yw]^2 - 
     G[{0}, yv^(-1)]*G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*G[{1/(yu*yv)}, yw]^2 + 
     G[{0}, yw]*G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*G[{1/(yu*yv)}, yw]^2 + 
     2*G[{1}, yu^(-1)]^2*G[{1}, yv^(-1)]*G[{1/(yu*yv)}, yw]^2 + 
     2*G[{0}, yu^(-1)]*G[{1}, yv^(-1)]^2*G[{1/(yu*yv)}, yw]^2 + 
     2*G[{0}, yv^(-1)]*G[{1}, yv^(-1)]^2*G[{1/(yu*yv)}, yw]^2 - 
     2*G[{0}, yw]*G[{1}, yv^(-1)]^2*G[{1/(yu*yv)}, yw]^2 - 
     G[{1}, yu^(-1)]*G[{1}, yv^(-1)]^2*G[{1/(yu*yv)}, yw]^2 - 
     G[{1}, yv^(-1)]^3*G[{1/(yu*yv)}, yw]^2 - G[{0}, yu^(-1)]^2*G[{1}, yw]*
      G[{1/(yu*yv)}, yw]^2 - 2*G[{0}, yu^(-1)]*G[{0}, yv^(-1)]*G[{1}, yw]*
      G[{1/(yu*yv)}, yw]^2 - G[{0}, yv^(-1)]^2*G[{1}, yw]*
      G[{1/(yu*yv)}, yw]^2 + 2*G[{0}, yu^(-1)]*G[{0}, yw]*G[{1}, yw]*
      G[{1/(yu*yv)}, yw]^2 + 2*G[{0}, yv^(-1)]*G[{0}, yw]*G[{1}, yw]*
      G[{1/(yu*yv)}, yw]^2 - G[{0}, yw]^2*G[{1}, yw]*G[{1/(yu*yv)}, yw]^2 + 
     G[{1}, yu^(-1)]^2*G[{1}, yw]*G[{1/(yu*yv)}, yw]^2 + 
     G[{1}, yv^(-1)]^2*G[{1}, yw]*G[{1/(yu*yv)}, yw]^2 - 
     2*G[{0}, yu^(-1)]*G[{1}, yw]^2*G[{1/(yu*yv)}, yw]^2 - 
     2*G[{0}, yv^(-1)]*G[{1}, yw]^2*G[{1/(yu*yv)}, yw]^2 + 
     2*G[{0}, yw]*G[{1}, yw]^2*G[{1/(yu*yv)}, yw]^2 + 
     2*G[{1}, yu^(-1)]*G[{1}, yw]^2*G[{1/(yu*yv)}, yw]^2 + 
     2*G[{1}, yv^(-1)]*G[{1}, yw]^2*G[{1/(yu*yv)}, yw]^2 - 
     (Pi^2*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2)/6 + 
     G[{0}, yu^(-1)]^2*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2 + 
     2*G[{0}, yu^(-1)]*G[{0}, yv^(-1)]*G[{yu^(-1)}, yw]*
      G[{1/(yu*yv)}, yw]^2 + G[{0}, yv^(-1)]^2*G[{yu^(-1)}, yw]*
      G[{1/(yu*yv)}, yw]^2 - 2*G[{0}, yu^(-1)]*G[{0}, yw]*G[{yu^(-1)}, yw]*
      G[{1/(yu*yv)}, yw]^2 - 2*G[{0}, yv^(-1)]*G[{0}, yw]*G[{yu^(-1)}, yw]*
      G[{1/(yu*yv)}, yw]^2 + G[{0}, yw]^2*G[{yu^(-1)}, yw]*
      G[{1/(yu*yv)}, yw]^2 - G[{1}, yu^(-1)]^2*G[{yu^(-1)}, yw]*
      G[{1/(yu*yv)}, yw]^2 - G[{0}, yu^(-1)]*G[{1}, yv^(-1)]*G[{yu^(-1)}, yw]*
      G[{1/(yu*yv)}, yw]^2 - G[{0}, yv^(-1)]*G[{1}, yv^(-1)]*G[{yu^(-1)}, yw]*
      G[{1/(yu*yv)}, yw]^2 + G[{0}, yw]*G[{1}, yv^(-1)]*G[{yu^(-1)}, yw]*
      G[{1/(yu*yv)}, yw]^2 + 2*G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*
      G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2 + 4*G[{0}, yu^(-1)]*G[{1}, yw]*
      G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2 + 4*G[{0}, yv^(-1)]*G[{1}, yw]*
      G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2 - 4*G[{0}, yw]*G[{1}, yw]*
      G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2 - 2*G[{1}, yu^(-1)]*G[{1}, yw]*
      G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2 - 2*G[{1}, yv^(-1)]*G[{1}, yw]*
      G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2 + 2*G[{1}, yw]^2*G[{yu^(-1)}, yw]*
      G[{1/(yu*yv)}, yw]^2 + (3*G[{1}, yv^(-1)]*G[{yu^(-1)}, yw]^2*
       G[{1/(yu*yv)}, yw]^2)/2 + (3*G[{1}, yw]*G[{yu^(-1)}, yw]^2*
       G[{1/(yu*yv)}, yw]^2)/2 - (G[{yu^(-1)}, yw]^3*G[{1/(yu*yv)}, yw]^2)/
      2 + G[{0}, yu^(-1)]^2*G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw]^2 + 
     2*G[{0}, yu^(-1)]*G[{0}, yv^(-1)]*G[{yu}, yv^(-1)]*
      G[{1/(yu*yv)}, yw]^2 + G[{0}, yv^(-1)]^2*G[{yu}, yv^(-1)]*
      G[{1/(yu*yv)}, yw]^2 - 2*G[{0}, yu^(-1)]*G[{0}, yw]*G[{yu}, yv^(-1)]*
      G[{1/(yu*yv)}, yw]^2 - 2*G[{0}, yv^(-1)]*G[{0}, yw]*G[{yu}, yv^(-1)]*
      G[{1/(yu*yv)}, yw]^2 + G[{0}, yw]^2*G[{yu}, yv^(-1)]*
      G[{1/(yu*yv)}, yw]^2 + G[{0}, yu^(-1)]*G[{1}, yu^(-1)]*G[{yu}, yv^(-1)]*
      G[{1/(yu*yv)}, yw]^2 + G[{0}, yv^(-1)]*G[{1}, yu^(-1)]*G[{yu}, yv^(-1)]*
      G[{1/(yu*yv)}, yw]^2 - G[{0}, yw]*G[{1}, yu^(-1)]*G[{yu}, yv^(-1)]*
      G[{1/(yu*yv)}, yw]^2 - 2*G[{1}, yu^(-1)]^2*G[{yu}, yv^(-1)]*
      G[{1/(yu*yv)}, yw]^2 + 3*G[{0}, yu^(-1)]*G[{1}, yv^(-1)]*
      G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw]^2 + 3*G[{0}, yv^(-1)]*
      G[{1}, yv^(-1)]*G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw]^2 - 
     3*G[{0}, yw]*G[{1}, yv^(-1)]*G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw]^2 + 
     2*G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*G[{yu}, yv^(-1)]*
      G[{1/(yu*yv)}, yw]^2 - 4*G[{1}, yv^(-1)]^2*G[{yu}, yv^(-1)]*
      G[{1/(yu*yv)}, yw]^2 + 4*G[{0}, yu^(-1)]*G[{1}, yw]*G[{yu}, yv^(-1)]*
      G[{1/(yu*yv)}, yw]^2 + 4*G[{0}, yv^(-1)]*G[{1}, yw]*G[{yu}, yv^(-1)]*
      G[{1/(yu*yv)}, yw]^2 - 4*G[{0}, yw]*G[{1}, yw]*G[{yu}, yv^(-1)]*
      G[{1/(yu*yv)}, yw]^2 - 2*G[{1}, yu^(-1)]*G[{1}, yw]*G[{yu}, yv^(-1)]*
      G[{1/(yu*yv)}, yw]^2 + G[{1}, yv^(-1)]*G[{1}, yw]*G[{yu}, yv^(-1)]*
      G[{1/(yu*yv)}, yw]^2 - 3*G[{0}, yu^(-1)]*G[{yu^(-1)}, yw]*
      G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw]^2 - 3*G[{0}, yv^(-1)]*
      G[{yu^(-1)}, yw]*G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw]^2 + 
     3*G[{0}, yw]*G[{yu^(-1)}, yw]*G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw]^2 + 
     3*G[{1}, yv^(-1)]*G[{yu^(-1)}, yw]*G[{yu}, yv^(-1)]*
      G[{1/(yu*yv)}, yw]^2 - 4*G[{1}, yw]*G[{yu^(-1)}, yw]*G[{yu}, yv^(-1)]*
      G[{1/(yu*yv)}, yw]^2 - (3*G[{yu^(-1)}, yw]^2*G[{yu}, yv^(-1)]*
       G[{1/(yu*yv)}, yw]^2)/2 - 4*G[{0}, yu^(-1)]*G[{yu}, yv^(-1)]^2*
      G[{1/(yu*yv)}, yw]^2 - 4*G[{0}, yv^(-1)]*G[{yu}, yv^(-1)]^2*
      G[{1/(yu*yv)}, yw]^2 + 4*G[{0}, yw]*G[{yu}, yv^(-1)]^2*
      G[{1/(yu*yv)}, yw]^2 - (3*G[{1}, yv^(-1)]*G[{yu}, yv^(-1)]^2*
       G[{1/(yu*yv)}, yw]^2)/2 - (7*G[{1}, yw]*G[{yu}, yv^(-1)]^2*
       G[{1/(yu*yv)}, yw]^2)/2 + (3*G[{yu^(-1)}, yw]*G[{yu}, yv^(-1)]^2*
       G[{1/(yu*yv)}, yw]^2)/2 + (19*G[{yu}, yv^(-1)]^3*G[{1/(yu*yv)}, yw]^2)/
      6 - (Pi^2*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2)/6 + 
     G[{0}, yu^(-1)]*G[{1}, yu^(-1)]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2 + 
     G[{0}, yv^(-1)]*G[{1}, yu^(-1)]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2 - 
     G[{0}, yw]*G[{1}, yu^(-1)]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2 - 
     G[{1}, yu^(-1)]^2*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2 - 
     2*G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*G[{yv^(-1)}, yw]*
      G[{1/(yu*yv)}, yw]^2 + 2*G[{0}, yu^(-1)]*G[{1}, yw]*G[{yv^(-1)}, yw]*
      G[{1/(yu*yv)}, yw]^2 + 2*G[{0}, yv^(-1)]*G[{1}, yw]*G[{yv^(-1)}, yw]*
      G[{1/(yu*yv)}, yw]^2 - 2*G[{0}, yw]*G[{1}, yw]*G[{yv^(-1)}, yw]*
      G[{1/(yu*yv)}, yw]^2 - 2*G[{1}, yu^(-1)]*G[{1}, yw]*G[{yv^(-1)}, yw]*
      G[{1/(yu*yv)}, yw]^2 - 2*G[{1}, yv^(-1)]*G[{1}, yw]*G[{yv^(-1)}, yw]*
      G[{1/(yu*yv)}, yw]^2 - G[{0}, yu^(-1)]*G[{yu^(-1)}, yw]*
      G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2 - G[{0}, yv^(-1)]*
      G[{yu^(-1)}, yw]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2 + 
     G[{0}, yw]*G[{yu^(-1)}, yw]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2 + 
     2*G[{1}, yu^(-1)]*G[{yu^(-1)}, yw]*G[{yv^(-1)}, yw]*
      G[{1/(yu*yv)}, yw]^2 - G[{0}, yu^(-1)]*G[{yu}, yv^(-1)]*
      G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2 - G[{0}, yv^(-1)]*
      G[{yu}, yv^(-1)]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2 + 
     G[{0}, yw]*G[{yu}, yv^(-1)]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2 + 
     2*G[{1}, yu^(-1)]*G[{yu}, yv^(-1)]*G[{yv^(-1)}, yw]*
      G[{1/(yu*yv)}, yw]^2 - G[{0}, yu^(-1)]*G[{yv^(-1)}, yw]^2*
      G[{1/(yu*yv)}, yw]^2 - G[{0}, yv^(-1)]*G[{yv^(-1)}, yw]^2*
      G[{1/(yu*yv)}, yw]^2 + G[{0}, yw]*G[{yv^(-1)}, yw]^2*
      G[{1/(yu*yv)}, yw]^2 + 2*G[{1}, yu^(-1)]*G[{yv^(-1)}, yw]^2*
      G[{1/(yu*yv)}, yw]^2 + G[{1}, yv^(-1)]*G[{yv^(-1)}, yw]^2*
      G[{1/(yu*yv)}, yw]^2 + G[{1}, yw]*G[{yv^(-1)}, yw]^2*
      G[{1/(yu*yv)}, yw]^2 - G[{yu^(-1)}, yw]*G[{yv^(-1)}, yw]^2*
      G[{1/(yu*yv)}, yw]^2 - G[{yu}, yv^(-1)]*G[{yv^(-1)}, yw]^2*
      G[{1/(yu*yv)}, yw]^2 - (2*G[{yv^(-1)}, yw]^3*G[{1/(yu*yv)}, yw]^2)/3 - 
     (G[{0}, yu^(-1)]*G[{1}, yu^(-1)]*G[{1/(yu*yv)}, yw]^3)/3 - 
     (G[{0}, yv^(-1)]*G[{1}, yu^(-1)]*G[{1/(yu*yv)}, yw]^3)/3 + 
     (G[{0}, yw]*G[{1}, yu^(-1)]*G[{1/(yu*yv)}, yw]^3)/3 + 
     (G[{1}, yu^(-1)]^2*G[{1/(yu*yv)}, yw]^3)/3 - 
     G[{0}, yu^(-1)]*G[{1}, yv^(-1)]*G[{1/(yu*yv)}, yw]^3 - 
     G[{0}, yv^(-1)]*G[{1}, yv^(-1)]*G[{1/(yu*yv)}, yw]^3 + 
     G[{0}, yw]*G[{1}, yv^(-1)]*G[{1/(yu*yv)}, yw]^3 - 
     (2*G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*G[{1/(yu*yv)}, yw]^3)/3 + 
     G[{1}, yv^(-1)]^2*G[{1/(yu*yv)}, yw]^3 - 
     (4*G[{0}, yu^(-1)]*G[{1}, yw]*G[{1/(yu*yv)}, yw]^3)/3 - 
     (4*G[{0}, yv^(-1)]*G[{1}, yw]*G[{1/(yu*yv)}, yw]^3)/3 + 
     (4*G[{0}, yw]*G[{1}, yw]*G[{1/(yu*yv)}, yw]^3)/3 - 
     (2*G[{1}, yu^(-1)]*G[{1}, yw]*G[{1/(yu*yv)}, yw]^3)/3 - 
     (2*G[{1}, yv^(-1)]*G[{1}, yw]*G[{1/(yu*yv)}, yw]^3)/3 - 
     2*G[{1}, yw]^2*G[{1/(yu*yv)}, yw]^3 + G[{0}, yu^(-1)]*G[{yu^(-1)}, yw]*
      G[{1/(yu*yv)}, yw]^3 + G[{0}, yv^(-1)]*G[{yu^(-1)}, yw]*
      G[{1/(yu*yv)}, yw]^3 - G[{0}, yw]*G[{yu^(-1)}, yw]*
      G[{1/(yu*yv)}, yw]^3 + (2*G[{1}, yu^(-1)]*G[{yu^(-1)}, yw]*
       G[{1/(yu*yv)}, yw]^3)/3 - 2*G[{1}, yv^(-1)]*G[{yu^(-1)}, yw]*
      G[{1/(yu*yv)}, yw]^3 + (2*G[{1}, yw]*G[{yu^(-1)}, yw]*
       G[{1/(yu*yv)}, yw]^3)/3 + G[{yu^(-1)}, yw]^2*G[{1/(yu*yv)}, yw]^3 + 
     (4*G[{0}, yu^(-1)]*G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw]^3)/3 + 
     (4*G[{0}, yv^(-1)]*G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw]^3)/3 - 
     (4*G[{0}, yw]*G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw]^3)/3 + 
     (2*G[{1}, yu^(-1)]*G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw]^3)/3 + 
     (2*G[{1}, yv^(-1)]*G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw]^3)/3 + 
     4*G[{1}, yw]*G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw]^3 - 
     (2*G[{yu^(-1)}, yw]*G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw]^3)/3 - 
     2*G[{yu}, yv^(-1)]^2*G[{1/(yu*yv)}, yw]^3 + 
     (G[{0}, yu^(-1)]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]^3)/3 + 
     (G[{0}, yv^(-1)]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]^3)/3 - 
     (G[{0}, yw]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]^3)/3 - 
     (2*G[{1}, yu^(-1)]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]^3)/3 + 
     (2*G[{1}, yv^(-1)]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]^3)/3 + 
     (2*G[{1}, yw]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]^3)/3 - 
     (2*G[{yu^(-1)}, yw]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]^3)/3 - 
     (2*G[{yu}, yv^(-1)]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]^3)/3 + 
     (G[{yv^(-1)}, yw]^2*G[{1/(yu*yv)}, yw]^3)/3 + 
     (Pi^2*G[{0}, yu^(-1)]*G[{0, 1}, yu^(-1)])/3 + 
     (Pi^2*G[{0}, yv^(-1)]*G[{0, 1}, yu^(-1)])/3 - 
     (Pi^2*G[{0}, yw]*G[{0, 1}, yu^(-1)])/3 - G[{0}, yu^(-1)]*
      G[{1}, yu^(-1)]^2*G[{0, 1}, yu^(-1)] - G[{0}, yv^(-1)]*
      G[{1}, yu^(-1)]^2*G[{0, 1}, yu^(-1)] + G[{0}, yw]*G[{1}, yu^(-1)]^2*
      G[{0, 1}, yu^(-1)] + (G[{1}, yu^(-1)]^3*G[{0, 1}, yu^(-1)])/3 + 
     2*G[{0}, yu^(-1)]*G[{1}, yu^(-1)]*G[{yu^(-1)}, yw]*G[{0, 1}, yu^(-1)] + 
     2*G[{0}, yv^(-1)]*G[{1}, yu^(-1)]*G[{yu^(-1)}, yw]*G[{0, 1}, yu^(-1)] - 
     2*G[{0}, yw]*G[{1}, yu^(-1)]*G[{yu^(-1)}, yw]*G[{0, 1}, yu^(-1)] - 
     G[{1}, yu^(-1)]^2*G[{yu^(-1)}, yw]*G[{0, 1}, yu^(-1)] + 
     2*G[{0}, yu^(-1)]*G[{1}, yv^(-1)]*G[{yu^(-1)}, yw]*G[{0, 1}, yu^(-1)] + 
     2*G[{0}, yv^(-1)]*G[{1}, yv^(-1)]*G[{yu^(-1)}, yw]*G[{0, 1}, yu^(-1)] - 
     2*G[{0}, yw]*G[{1}, yv^(-1)]*G[{yu^(-1)}, yw]*G[{0, 1}, yu^(-1)] - 
     2*G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*G[{yu^(-1)}, yw]*G[{0, 1}, yu^(-1)] - 
     G[{1}, yv^(-1)]^2*G[{yu^(-1)}, yw]*G[{0, 1}, yu^(-1)] - 
     2*G[{0}, yu^(-1)]*G[{1}, yw]*G[{yu^(-1)}, yw]*G[{0, 1}, yu^(-1)] - 
     2*G[{0}, yv^(-1)]*G[{1}, yw]*G[{yu^(-1)}, yw]*G[{0, 1}, yu^(-1)] + 
     2*G[{0}, yw]*G[{1}, yw]*G[{yu^(-1)}, yw]*G[{0, 1}, yu^(-1)] + 
     2*G[{1}, yu^(-1)]*G[{1}, yw]*G[{yu^(-1)}, yw]*G[{0, 1}, yu^(-1)] + 
     2*G[{1}, yv^(-1)]*G[{1}, yw]*G[{yu^(-1)}, yw]*G[{0, 1}, yu^(-1)] - 
     (Pi^2*G[{yu}, yv^(-1)]*G[{0, 1}, yu^(-1)])/3 + 
     G[{1}, yu^(-1)]^2*G[{yu}, yv^(-1)]*G[{0, 1}, yu^(-1)] + 
     2*G[{0}, yu^(-1)]*G[{1}, yv^(-1)]*G[{yu}, yv^(-1)]*G[{0, 1}, yu^(-1)] + 
     2*G[{0}, yv^(-1)]*G[{1}, yv^(-1)]*G[{yu}, yv^(-1)]*G[{0, 1}, yu^(-1)] - 
     2*G[{0}, yw]*G[{1}, yv^(-1)]*G[{yu}, yv^(-1)]*G[{0, 1}, yu^(-1)] - 
     2*G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*G[{yu}, yv^(-1)]*G[{0, 1}, yu^(-1)] - 
     G[{1}, yv^(-1)]^2*G[{yu}, yv^(-1)]*G[{0, 1}, yu^(-1)] - 
     2*G[{0}, yu^(-1)]*G[{yu^(-1)}, yw]*G[{yu}, yv^(-1)]*G[{0, 1}, yu^(-1)] - 
     2*G[{0}, yv^(-1)]*G[{yu^(-1)}, yw]*G[{yu}, yv^(-1)]*G[{0, 1}, yu^(-1)] + 
     2*G[{0}, yw]*G[{yu^(-1)}, yw]*G[{yu}, yv^(-1)]*G[{0, 1}, yu^(-1)] - 
     2*G[{1}, yv^(-1)]*G[{yu}, yv^(-1)]^2*G[{0, 1}, yu^(-1)] + 
     2*G[{yu^(-1)}, yw]*G[{yu}, yv^(-1)]^2*G[{0, 1}, yu^(-1)] + 
     (2*G[{yu}, yv^(-1)]^3*G[{0, 1}, yu^(-1)])/3 + 
     (Pi^2*G[{1/(yu*yv)}, yw]*G[{0, 1}, yu^(-1)])/3 - 
     G[{1}, yu^(-1)]^2*G[{1/(yu*yv)}, yw]*G[{0, 1}, yu^(-1)] - 
     2*G[{0}, yu^(-1)]*G[{1}, yv^(-1)]*G[{1/(yu*yv)}, yw]*
      G[{0, 1}, yu^(-1)] - 2*G[{0}, yv^(-1)]*G[{1}, yv^(-1)]*
      G[{1/(yu*yv)}, yw]*G[{0, 1}, yu^(-1)] + 2*G[{0}, yw]*G[{1}, yv^(-1)]*
      G[{1/(yu*yv)}, yw]*G[{0, 1}, yu^(-1)] + 2*G[{1}, yu^(-1)]*
      G[{1}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, 1}, yu^(-1)] + 
     G[{1}, yv^(-1)]^2*G[{1/(yu*yv)}, yw]*G[{0, 1}, yu^(-1)] + 
     2*G[{0}, yu^(-1)]*G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1}, yu^(-1)] + 
     2*G[{0}, yv^(-1)]*G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1}, yu^(-1)] - 
     2*G[{0}, yw]*G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1}, yu^(-1)] - 
     2*G[{1}, yu^(-1)]*G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1}, yu^(-1)] - 
     2*G[{1}, yv^(-1)]*G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1}, yu^(-1)] + 
     2*G[{0}, yu^(-1)]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*
      G[{0, 1}, yu^(-1)] + 2*G[{0}, yv^(-1)]*G[{yu^(-1)}, yw]*
      G[{1/(yu*yv)}, yw]*G[{0, 1}, yu^(-1)] - 2*G[{0}, yw]*G[{yu^(-1)}, yw]*
      G[{1/(yu*yv)}, yw]*G[{0, 1}, yu^(-1)] + 4*G[{1}, yw]*G[{yu^(-1)}, yw]*
      G[{1/(yu*yv)}, yw]*G[{0, 1}, yu^(-1)] + 4*G[{1}, yv^(-1)]*
      G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, 1}, yu^(-1)] - 
     4*G[{yu^(-1)}, yw]*G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw]*
      G[{0, 1}, yu^(-1)] - 2*G[{yu}, yv^(-1)]^2*G[{1/(yu*yv)}, yw]*
      G[{0, 1}, yu^(-1)] - G[{0}, yu^(-1)]*G[{1/(yu*yv)}, yw]^2*
      G[{0, 1}, yu^(-1)] - G[{0}, yv^(-1)]*G[{1/(yu*yv)}, yw]^2*
      G[{0, 1}, yu^(-1)] + G[{0}, yw]*G[{1/(yu*yv)}, yw]^2*
      G[{0, 1}, yu^(-1)] + G[{1}, yu^(-1)]*G[{1/(yu*yv)}, yw]^2*
      G[{0, 1}, yu^(-1)] - G[{1}, yv^(-1)]*G[{1/(yu*yv)}, yw]^2*
      G[{0, 1}, yu^(-1)] - 2*G[{1}, yw]*G[{1/(yu*yv)}, yw]^2*
      G[{0, 1}, yu^(-1)] + G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2*
      G[{0, 1}, yu^(-1)] + 2*G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw]^2*
      G[{0, 1}, yu^(-1)] - G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2*
      G[{0, 1}, yu^(-1)] + G[{0}, yu^(-1)]*G[{0, 1}, yu^(-1)]^2 + 
     G[{0}, yv^(-1)]*G[{0, 1}, yu^(-1)]^2 - G[{0}, yw]*G[{0, 1}, yu^(-1)]^2 - 
     G[{yu}, yv^(-1)]*G[{0, 1}, yu^(-1)]^2 + G[{1/(yu*yv)}, yw]*
      G[{0, 1}, yu^(-1)]^2 - (Pi^2*G[{0}, yu^(-1)]*G[{0, 1}, yv^(-1)])/3 - 
     (Pi^2*G[{0}, yv^(-1)]*G[{0, 1}, yv^(-1)])/3 + 
     (Pi^2*G[{0}, yw]*G[{0, 1}, yv^(-1)])/3 + 
     (Pi^2*G[{1}, yu^(-1)]*G[{0, 1}, yv^(-1)])/3 - 
     (2*Pi^2*G[{yu^(-1)}, yw]*G[{0, 1}, yv^(-1)])/3 + 
     2*G[{0}, yu^(-1)]^2*G[{yu^(-1)}, yw]*G[{0, 1}, yv^(-1)] + 
     4*G[{0}, yu^(-1)]*G[{0}, yv^(-1)]*G[{yu^(-1)}, yw]*G[{0, 1}, yv^(-1)] + 
     2*G[{0}, yv^(-1)]^2*G[{yu^(-1)}, yw]*G[{0, 1}, yv^(-1)] - 
     4*G[{0}, yu^(-1)]*G[{0}, yw]*G[{yu^(-1)}, yw]*G[{0, 1}, yv^(-1)] - 
     4*G[{0}, yv^(-1)]*G[{0}, yw]*G[{yu^(-1)}, yw]*G[{0, 1}, yv^(-1)] + 
     2*G[{0}, yw]^2*G[{yu^(-1)}, yw]*G[{0, 1}, yv^(-1)] - 
     2*G[{0}, yu^(-1)]*G[{1}, yu^(-1)]*G[{yu^(-1)}, yw]*G[{0, 1}, yv^(-1)] - 
     2*G[{0}, yv^(-1)]*G[{1}, yu^(-1)]*G[{yu^(-1)}, yw]*G[{0, 1}, yv^(-1)] + 
     2*G[{0}, yw]*G[{1}, yu^(-1)]*G[{yu^(-1)}, yw]*G[{0, 1}, yv^(-1)] - 
     2*G[{0}, yu^(-1)]*G[{1}, yv^(-1)]*G[{yu^(-1)}, yw]*G[{0, 1}, yv^(-1)] - 
     2*G[{0}, yv^(-1)]*G[{1}, yv^(-1)]*G[{yu^(-1)}, yw]*G[{0, 1}, yv^(-1)] + 
     2*G[{0}, yw]*G[{1}, yv^(-1)]*G[{yu^(-1)}, yw]*G[{0, 1}, yv^(-1)] + 
     2*G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*G[{yu^(-1)}, yw]*G[{0, 1}, yv^(-1)] + 
     G[{1}, yv^(-1)]^2*G[{yu^(-1)}, yw]*G[{0, 1}, yv^(-1)] + 
     2*G[{0}, yu^(-1)]*G[{1}, yw]*G[{yu^(-1)}, yw]*G[{0, 1}, yv^(-1)] + 
     2*G[{0}, yv^(-1)]*G[{1}, yw]*G[{yu^(-1)}, yw]*G[{0, 1}, yv^(-1)] - 
     2*G[{0}, yw]*G[{1}, yw]*G[{yu^(-1)}, yw]*G[{0, 1}, yv^(-1)] - 
     2*G[{1}, yu^(-1)]*G[{1}, yw]*G[{yu^(-1)}, yw]*G[{0, 1}, yv^(-1)] - 
     2*G[{1}, yv^(-1)]*G[{1}, yw]*G[{yu^(-1)}, yw]*G[{0, 1}, yv^(-1)] + 
     G[{1}, yv^(-1)]*G[{yu^(-1)}, yw]^2*G[{0, 1}, yv^(-1)] + 
     G[{1}, yw]*G[{yu^(-1)}, yw]^2*G[{0, 1}, yv^(-1)] - 
     (2*G[{yu^(-1)}, yw]^3*G[{0, 1}, yv^(-1)])/3 - 
     (Pi^2*G[{yu}, yv^(-1)]*G[{0, 1}, yv^(-1)])/3 + 
     2*G[{0}, yu^(-1)]^2*G[{yu}, yv^(-1)]*G[{0, 1}, yv^(-1)] + 
     4*G[{0}, yu^(-1)]*G[{0}, yv^(-1)]*G[{yu}, yv^(-1)]*G[{0, 1}, yv^(-1)] + 
     2*G[{0}, yv^(-1)]^2*G[{yu}, yv^(-1)]*G[{0, 1}, yv^(-1)] - 
     4*G[{0}, yu^(-1)]*G[{0}, yw]*G[{yu}, yv^(-1)]*G[{0, 1}, yv^(-1)] - 
     4*G[{0}, yv^(-1)]*G[{0}, yw]*G[{yu}, yv^(-1)]*G[{0, 1}, yv^(-1)] + 
     2*G[{0}, yw]^2*G[{yu}, yv^(-1)]*G[{0, 1}, yv^(-1)] - 
     2*G[{1}, yu^(-1)]^2*G[{yu}, yv^(-1)]*G[{0, 1}, yv^(-1)] - 
     2*G[{0}, yu^(-1)]*G[{1}, yv^(-1)]*G[{yu}, yv^(-1)]*G[{0, 1}, yv^(-1)] - 
     2*G[{0}, yv^(-1)]*G[{1}, yv^(-1)]*G[{yu}, yv^(-1)]*G[{0, 1}, yv^(-1)] + 
     2*G[{0}, yw]*G[{1}, yv^(-1)]*G[{yu}, yv^(-1)]*G[{0, 1}, yv^(-1)] + 
     2*G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*G[{yu}, yv^(-1)]*G[{0, 1}, yv^(-1)] + 
     G[{1}, yv^(-1)]^2*G[{yu}, yv^(-1)]*G[{0, 1}, yv^(-1)] - 
     2*G[{0}, yu^(-1)]*G[{yu^(-1)}, yw]*G[{yu}, yv^(-1)]*G[{0, 1}, yv^(-1)] - 
     2*G[{0}, yv^(-1)]*G[{yu^(-1)}, yw]*G[{yu}, yv^(-1)]*G[{0, 1}, yv^(-1)] + 
     2*G[{0}, yw]*G[{yu^(-1)}, yw]*G[{yu}, yv^(-1)]*G[{0, 1}, yv^(-1)] + 
     2*G[{1}, yv^(-1)]*G[{yu^(-1)}, yw]*G[{yu}, yv^(-1)]*G[{0, 1}, yv^(-1)] + 
     2*G[{1}, yw]*G[{yu^(-1)}, yw]*G[{yu}, yv^(-1)]*G[{0, 1}, yv^(-1)] - 
     2*G[{yu^(-1)}, yw]^2*G[{yu}, yv^(-1)]*G[{0, 1}, yv^(-1)] - 
     4*G[{0}, yu^(-1)]*G[{yu}, yv^(-1)]^2*G[{0, 1}, yv^(-1)] - 
     4*G[{0}, yv^(-1)]*G[{yu}, yv^(-1)]^2*G[{0, 1}, yv^(-1)] + 
     4*G[{0}, yw]*G[{yu}, yv^(-1)]^2*G[{0, 1}, yv^(-1)] + 
     3*G[{1}, yv^(-1)]*G[{yu}, yv^(-1)]^2*G[{0, 1}, yv^(-1)] + 
     (8*G[{yu}, yv^(-1)]^3*G[{0, 1}, yv^(-1)])/3 + 
     (Pi^2*G[{1/(yu*yv)}, yw]*G[{0, 1}, yv^(-1)])/3 - 
     2*G[{0}, yu^(-1)]^2*G[{1/(yu*yv)}, yw]*G[{0, 1}, yv^(-1)] - 
     4*G[{0}, yu^(-1)]*G[{0}, yv^(-1)]*G[{1/(yu*yv)}, yw]*
      G[{0, 1}, yv^(-1)] - 2*G[{0}, yv^(-1)]^2*G[{1/(yu*yv)}, yw]*
      G[{0, 1}, yv^(-1)] + 4*G[{0}, yu^(-1)]*G[{0}, yw]*G[{1/(yu*yv)}, yw]*
      G[{0, 1}, yv^(-1)] + 4*G[{0}, yv^(-1)]*G[{0}, yw]*G[{1/(yu*yv)}, yw]*
      G[{0, 1}, yv^(-1)] - 2*G[{0}, yw]^2*G[{1/(yu*yv)}, yw]*
      G[{0, 1}, yv^(-1)] + 2*G[{1}, yu^(-1)]^2*G[{1/(yu*yv)}, yw]*
      G[{0, 1}, yv^(-1)] + 2*G[{0}, yu^(-1)]*G[{1}, yv^(-1)]*
      G[{1/(yu*yv)}, yw]*G[{0, 1}, yv^(-1)] + 2*G[{0}, yv^(-1)]*
      G[{1}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, 1}, yv^(-1)] - 
     2*G[{0}, yw]*G[{1}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, 1}, yv^(-1)] - 
     2*G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*G[{1/(yu*yv)}, yw]*
      G[{0, 1}, yv^(-1)] - G[{1}, yv^(-1)]^2*G[{1/(yu*yv)}, yw]*
      G[{0, 1}, yv^(-1)] - 2*G[{0}, yu^(-1)]*G[{1}, yw]*G[{1/(yu*yv)}, yw]*
      G[{0, 1}, yv^(-1)] - 2*G[{0}, yv^(-1)]*G[{1}, yw]*G[{1/(yu*yv)}, yw]*
      G[{0, 1}, yv^(-1)] + 2*G[{0}, yw]*G[{1}, yw]*G[{1/(yu*yv)}, yw]*
      G[{0, 1}, yv^(-1)] + 2*G[{1}, yu^(-1)]*G[{1}, yw]*G[{1/(yu*yv)}, yw]*
      G[{0, 1}, yv^(-1)] + 2*G[{1}, yv^(-1)]*G[{1}, yw]*G[{1/(yu*yv)}, yw]*
      G[{0, 1}, yv^(-1)] + 2*G[{0}, yu^(-1)]*G[{yu^(-1)}, yw]*
      G[{1/(yu*yv)}, yw]*G[{0, 1}, yv^(-1)] + 2*G[{0}, yv^(-1)]*
      G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1}, yv^(-1)] - 
     2*G[{0}, yw]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1}, yv^(-1)] - 
     2*G[{1}, yv^(-1)]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*
      G[{0, 1}, yv^(-1)] + 2*G[{1}, yw]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*
      G[{0, 1}, yv^(-1)] + 2*G[{yu^(-1)}, yw]^2*G[{1/(yu*yv)}, yw]*
      G[{0, 1}, yv^(-1)] + 8*G[{0}, yu^(-1)]*G[{yu}, yv^(-1)]*
      G[{1/(yu*yv)}, yw]*G[{0, 1}, yv^(-1)] + 8*G[{0}, yv^(-1)]*
      G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, 1}, yv^(-1)] - 
     8*G[{0}, yw]*G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, 1}, yv^(-1)] - 
     6*G[{1}, yv^(-1)]*G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw]*
      G[{0, 1}, yv^(-1)] + 6*G[{1}, yw]*G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw]*
      G[{0, 1}, yv^(-1)] - 8*G[{yu}, yv^(-1)]^2*G[{1/(yu*yv)}, yw]*
      G[{0, 1}, yv^(-1)] - 3*G[{0}, yu^(-1)]*G[{1/(yu*yv)}, yw]^2*
      G[{0, 1}, yv^(-1)] - 3*G[{0}, yv^(-1)]*G[{1/(yu*yv)}, yw]^2*
      G[{0, 1}, yv^(-1)] + 3*G[{0}, yw]*G[{1/(yu*yv)}, yw]^2*
      G[{0, 1}, yv^(-1)] - G[{1}, yu^(-1)]*G[{1/(yu*yv)}, yw]^2*
      G[{0, 1}, yv^(-1)] + 2*G[{1}, yv^(-1)]*G[{1/(yu*yv)}, yw]^2*
      G[{0, 1}, yv^(-1)] - 5*G[{1}, yw]*G[{1/(yu*yv)}, yw]^2*
      G[{0, 1}, yv^(-1)] - 2*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2*
      G[{0, 1}, yv^(-1)] + 5*G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw]^2*
      G[{0, 1}, yv^(-1)] + G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2*
      G[{0, 1}, yv^(-1)] - 2*G[{0}, yu^(-1)]*G[{0, 1}, yu^(-1)]*
      G[{0, 1}, yv^(-1)] - 2*G[{0}, yv^(-1)]*G[{0, 1}, yu^(-1)]*
      G[{0, 1}, yv^(-1)] + 2*G[{0}, yw]*G[{0, 1}, yu^(-1)]*
      G[{0, 1}, yv^(-1)] + 2*G[{1}, yu^(-1)]*G[{0, 1}, yu^(-1)]*
      G[{0, 1}, yv^(-1)] + 2*G[{yu}, yv^(-1)]*G[{0, 1}, yu^(-1)]*
      G[{0, 1}, yv^(-1)] - 2*G[{1/(yu*yv)}, yw]*G[{0, 1}, yu^(-1)]*
      G[{0, 1}, yv^(-1)] + G[{0}, yu^(-1)]*G[{0, 1}, yv^(-1)]^2 + 
     G[{0}, yv^(-1)]*G[{0, 1}, yv^(-1)]^2 - G[{0}, yw]*G[{0, 1}, yv^(-1)]^2 - 
     G[{1}, yu^(-1)]*G[{0, 1}, yv^(-1)]^2 - G[{yu}, yv^(-1)]*
      G[{0, 1}, yv^(-1)]^2 + G[{1/(yu*yv)}, yw]*G[{0, 1}, yv^(-1)]^2 - 
     (2*Pi^2*G[{yu^(-1)}, yw]*G[{0, 1}, yw])/3 - 4*G[{1}, yu^(-1)]*
      G[{1}, yv^(-1)]*G[{yu^(-1)}, yw]*G[{0, 1}, yw] - 
     2*G[{0}, yu^(-1)]*G[{1}, yw]*G[{yu^(-1)}, yw]*G[{0, 1}, yw] - 
     2*G[{0}, yv^(-1)]*G[{1}, yw]*G[{yu^(-1)}, yw]*G[{0, 1}, yw] + 
     2*G[{0}, yw]*G[{1}, yw]*G[{yu^(-1)}, yw]*G[{0, 1}, yw] + 
     2*G[{1}, yu^(-1)]*G[{1}, yw]*G[{yu^(-1)}, yw]*G[{0, 1}, yw] + 
     2*G[{1}, yv^(-1)]*G[{1}, yw]*G[{yu^(-1)}, yw]*G[{0, 1}, yw] - 
     2*G[{1}, yv^(-1)]*G[{yu^(-1)}, yw]^2*G[{0, 1}, yw] - 
     2*G[{1}, yw]*G[{yu^(-1)}, yw]^2*G[{0, 1}, yw] + 
     (2*G[{yu^(-1)}, yw]^3*G[{0, 1}, yw])/3 + 4*G[{1}, yu^(-1)]*
      G[{yu^(-1)}, yw]*G[{yu}, yv^(-1)]*G[{0, 1}, yw] + 
     2*G[{yu^(-1)}, yw]^2*G[{yu}, yv^(-1)]*G[{0, 1}, yw] + 
     2*G[{1}, yv^(-1)]*G[{yu}, yv^(-1)]^2*G[{0, 1}, yw] - 
     2*G[{yu^(-1)}, yw]*G[{yu}, yv^(-1)]^2*G[{0, 1}, yw] - 
     (2*G[{yu}, yv^(-1)]^3*G[{0, 1}, yw])/3 + 
     (Pi^2*G[{1/(yu*yv)}, yw]*G[{0, 1}, yw])/3 + 2*G[{0}, yu^(-1)]*
      G[{1}, yu^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, 1}, yw] + 
     2*G[{0}, yv^(-1)]*G[{1}, yu^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, 1}, yw] - 
     2*G[{0}, yw]*G[{1}, yu^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, 1}, yw] - 
     2*G[{1}, yu^(-1)]^2*G[{1/(yu*yv)}, yw]*G[{0, 1}, yw] + 
     2*G[{0}, yu^(-1)]*G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1}, yw] + 
     2*G[{0}, yv^(-1)]*G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1}, yw] - 
     2*G[{0}, yw]*G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1}, yw] - 
     2*G[{1}, yu^(-1)]*G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1}, yw] - 
     2*G[{1}, yv^(-1)]*G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1}, yw] + 
     2*G[{0}, yu^(-1)]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1}, yw] + 
     2*G[{0}, yv^(-1)]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1}, yw] - 
     2*G[{0}, yw]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1}, yw] - 
     4*G[{1}, yu^(-1)]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1}, yw] - 
     2*G[{yu^(-1)}, yw]^2*G[{1/(yu*yv)}, yw]*G[{0, 1}, yw] - 
     2*G[{0}, yu^(-1)]*G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, 1}, yw] - 
     2*G[{0}, yv^(-1)]*G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, 1}, yw] + 
     2*G[{0}, yw]*G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, 1}, yw] + 
     2*G[{yu}, yv^(-1)]^2*G[{1/(yu*yv)}, yw]*G[{0, 1}, yw] - 
     G[{0}, yu^(-1)]*G[{1/(yu*yv)}, yw]^2*G[{0, 1}, yw] - 
     G[{0}, yv^(-1)]*G[{1/(yu*yv)}, yw]^2*G[{0, 1}, yw] + 
     G[{0}, yw]*G[{1/(yu*yv)}, yw]^2*G[{0, 1}, yw] + 
     G[{1}, yu^(-1)]*G[{1/(yu*yv)}, yw]^2*G[{0, 1}, yw] + 
     G[{1}, yv^(-1)]*G[{1/(yu*yv)}, yw]^2*G[{0, 1}, yw] + 
     G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2*G[{0, 1}, yw] + 
     G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2*G[{0, 1}, yw] - 
     4*G[{yu^(-1)}, yw]*G[{0, 1}, yu^(-1)]*G[{0, 1}, yw] + 
     2*G[{1/(yu*yv)}, yw]*G[{0, 1}, yu^(-1)]*G[{0, 1}, yw] - 
     4*G[{yu}, yv^(-1)]*G[{0, 1}, yv^(-1)]*G[{0, 1}, yw] + 
     2*G[{1/(yu*yv)}, yw]*G[{0, 1}, yv^(-1)]*G[{0, 1}, yw] + 
     2*G[{yu^(-1)}, yw]*G[{0, 1}, yw]^2 - G[{1/(yu*yv)}, yw]*
      G[{0, 1}, yw]^2 - (Pi^2*G[{0}, yu^(-1)]*G[{0, yu^(-1)}, yw])/3 - 
     (Pi^2*G[{0}, yv^(-1)]*G[{0, yu^(-1)}, yw])/3 + 
     (Pi^2*G[{0}, yw]*G[{0, yu^(-1)}, yw])/3 + 
     (Pi^2*G[{1}, yu^(-1)]*G[{0, yu^(-1)}, yw])/3 + 
     (Pi^2*G[{1}, yv^(-1)]*G[{0, yu^(-1)}, yw])/3 - 
     2*G[{0}, yu^(-1)]*G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*G[{0, yu^(-1)}, yw] - 
     2*G[{0}, yv^(-1)]*G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*G[{0, yu^(-1)}, yw] + 
     2*G[{0}, yw]*G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*G[{0, yu^(-1)}, yw] + 
     2*G[{1}, yu^(-1)]^2*G[{1}, yv^(-1)]*G[{0, yu^(-1)}, yw] + 
     2*G[{1}, yu^(-1)]*G[{1}, yv^(-1)]^2*G[{0, yu^(-1)}, yw] + 
     (Pi^2*G[{yu^(-1)}, yw]*G[{0, yu^(-1)}, yw])/3 - 
     2*G[{0}, yu^(-1)]*G[{1}, yv^(-1)]*G[{yu^(-1)}, yw]*G[{0, yu^(-1)}, yw] - 
     2*G[{0}, yv^(-1)]*G[{1}, yv^(-1)]*G[{yu^(-1)}, yw]*G[{0, yu^(-1)}, yw] + 
     2*G[{0}, yw]*G[{1}, yv^(-1)]*G[{yu^(-1)}, yw]*G[{0, yu^(-1)}, yw] + 
     4*G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*G[{yu^(-1)}, yw]*G[{0, yu^(-1)}, yw] + 
     2*G[{1}, yv^(-1)]^2*G[{yu^(-1)}, yw]*G[{0, yu^(-1)}, yw] + 
     2*G[{0}, yu^(-1)]*G[{1}, yw]*G[{yu^(-1)}, yw]*G[{0, yu^(-1)}, yw] + 
     2*G[{0}, yv^(-1)]*G[{1}, yw]*G[{yu^(-1)}, yw]*G[{0, yu^(-1)}, yw] - 
     2*G[{0}, yw]*G[{1}, yw]*G[{yu^(-1)}, yw]*G[{0, yu^(-1)}, yw] - 
     2*G[{1}, yu^(-1)]*G[{1}, yw]*G[{yu^(-1)}, yw]*G[{0, yu^(-1)}, yw] - 
     2*G[{1}, yv^(-1)]*G[{1}, yw]*G[{yu^(-1)}, yw]*G[{0, yu^(-1)}, yw] + 
     2*G[{1}, yv^(-1)]*G[{yu^(-1)}, yw]^2*G[{0, yu^(-1)}, yw] + 
     2*G[{1}, yw]*G[{yu^(-1)}, yw]^2*G[{0, yu^(-1)}, yw] - 
     (2*G[{yu^(-1)}, yw]^3*G[{0, yu^(-1)}, yw])/3 + 
     2*G[{0}, yu^(-1)]*G[{1}, yu^(-1)]*G[{yu}, yv^(-1)]*G[{0, yu^(-1)}, yw] + 
     2*G[{0}, yv^(-1)]*G[{1}, yu^(-1)]*G[{yu}, yv^(-1)]*G[{0, yu^(-1)}, yw] - 
     2*G[{0}, yw]*G[{1}, yu^(-1)]*G[{yu}, yv^(-1)]*G[{0, yu^(-1)}, yw] - 
     2*G[{1}, yu^(-1)]^2*G[{yu}, yv^(-1)]*G[{0, yu^(-1)}, yw] - 
     2*G[{0}, yu^(-1)]*G[{1}, yv^(-1)]*G[{yu}, yv^(-1)]*G[{0, yu^(-1)}, yw] - 
     2*G[{0}, yv^(-1)]*G[{1}, yv^(-1)]*G[{yu}, yv^(-1)]*G[{0, yu^(-1)}, yw] + 
     2*G[{0}, yw]*G[{1}, yv^(-1)]*G[{yu}, yv^(-1)]*G[{0, yu^(-1)}, yw] + 
     2*G[{1}, yv^(-1)]^2*G[{yu}, yv^(-1)]*G[{0, yu^(-1)}, yw] + 
     2*G[{0}, yu^(-1)]*G[{yu^(-1)}, yw]*G[{yu}, yv^(-1)]*
      G[{0, yu^(-1)}, yw] + 2*G[{0}, yv^(-1)]*G[{yu^(-1)}, yw]*
      G[{yu}, yv^(-1)]*G[{0, yu^(-1)}, yw] - 2*G[{0}, yw]*G[{yu^(-1)}, yw]*
      G[{yu}, yv^(-1)]*G[{0, yu^(-1)}, yw] - 4*G[{1}, yu^(-1)]*
      G[{yu^(-1)}, yw]*G[{yu}, yv^(-1)]*G[{0, yu^(-1)}, yw] - 
     2*G[{yu^(-1)}, yw]^2*G[{yu}, yv^(-1)]*G[{0, yu^(-1)}, yw] - 
     2*G[{0}, yu^(-1)]*G[{1}, yu^(-1)]*G[{1/(yu*yv)}, yw]*
      G[{0, yu^(-1)}, yw] - 2*G[{0}, yv^(-1)]*G[{1}, yu^(-1)]*
      G[{1/(yu*yv)}, yw]*G[{0, yu^(-1)}, yw] + 2*G[{0}, yw]*G[{1}, yu^(-1)]*
      G[{1/(yu*yv)}, yw]*G[{0, yu^(-1)}, yw] + 2*G[{1}, yu^(-1)]^2*
      G[{1/(yu*yv)}, yw]*G[{0, yu^(-1)}, yw] + 2*G[{0}, yu^(-1)]*
      G[{1}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1)}, yw] + 
     2*G[{0}, yv^(-1)]*G[{1}, yv^(-1)]*G[{1/(yu*yv)}, yw]*
      G[{0, yu^(-1)}, yw] - 2*G[{0}, yw]*G[{1}, yv^(-1)]*G[{1/(yu*yv)}, yw]*
      G[{0, yu^(-1)}, yw] - 2*G[{1}, yv^(-1)]^2*G[{1/(yu*yv)}, yw]*
      G[{0, yu^(-1)}, yw] - 2*G[{0}, yu^(-1)]*G[{1}, yw]*G[{1/(yu*yv)}, yw]*
      G[{0, yu^(-1)}, yw] - 2*G[{0}, yv^(-1)]*G[{1}, yw]*G[{1/(yu*yv)}, yw]*
      G[{0, yu^(-1)}, yw] + 2*G[{0}, yw]*G[{1}, yw]*G[{1/(yu*yv)}, yw]*
      G[{0, yu^(-1)}, yw] + 2*G[{1}, yu^(-1)]*G[{1}, yw]*G[{1/(yu*yv)}, yw]*
      G[{0, yu^(-1)}, yw] + 2*G[{1}, yv^(-1)]*G[{1}, yw]*G[{1/(yu*yv)}, yw]*
      G[{0, yu^(-1)}, yw] - 2*G[{0}, yu^(-1)]*G[{yu^(-1)}, yw]*
      G[{1/(yu*yv)}, yw]*G[{0, yu^(-1)}, yw] - 2*G[{0}, yv^(-1)]*
      G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1)}, yw] + 
     2*G[{0}, yw]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1)}, yw] + 
     4*G[{1}, yu^(-1)]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*
      G[{0, yu^(-1)}, yw] + 2*G[{yu^(-1)}, yw]^2*G[{1/(yu*yv)}, yw]*
      G[{0, yu^(-1)}, yw] + G[{0}, yu^(-1)]*G[{1/(yu*yv)}, yw]^2*
      G[{0, yu^(-1)}, yw] + G[{0}, yv^(-1)]*G[{1/(yu*yv)}, yw]^2*
      G[{0, yu^(-1)}, yw] - G[{0}, yw]*G[{1/(yu*yv)}, yw]^2*
      G[{0, yu^(-1)}, yw] - G[{1}, yu^(-1)]*G[{1/(yu*yv)}, yw]^2*
      G[{0, yu^(-1)}, yw] - G[{1}, yv^(-1)]*G[{1/(yu*yv)}, yw]^2*
      G[{0, yu^(-1)}, yw] - G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2*
      G[{0, yu^(-1)}, yw] - G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2*
      G[{0, yu^(-1)}, yw] - 2*G[{0}, yu^(-1)]*G[{0, 1}, yu^(-1)]*
      G[{0, yu^(-1)}, yw] - 2*G[{0}, yv^(-1)]*G[{0, 1}, yu^(-1)]*
      G[{0, yu^(-1)}, yw] + 2*G[{0}, yw]*G[{0, 1}, yu^(-1)]*
      G[{0, yu^(-1)}, yw] + 2*G[{1}, yu^(-1)]*G[{0, 1}, yu^(-1)]*
      G[{0, yu^(-1)}, yw] + 2*G[{1}, yv^(-1)]*G[{0, 1}, yu^(-1)]*
      G[{0, yu^(-1)}, yw] + 2*G[{yu^(-1)}, yw]*G[{0, 1}, yu^(-1)]*
      G[{0, yu^(-1)}, yw] + 2*G[{0}, yu^(-1)]*G[{0, 1}, yv^(-1)]*
      G[{0, yu^(-1)}, yw] + 2*G[{0}, yv^(-1)]*G[{0, 1}, yv^(-1)]*
      G[{0, yu^(-1)}, yw] - 2*G[{0}, yw]*G[{0, 1}, yv^(-1)]*
      G[{0, yu^(-1)}, yw] - 2*G[{1}, yu^(-1)]*G[{0, 1}, yv^(-1)]*
      G[{0, yu^(-1)}, yw] - 2*G[{1}, yv^(-1)]*G[{0, 1}, yv^(-1)]*
      G[{0, yu^(-1)}, yw] - 2*G[{yu^(-1)}, yw]*G[{0, 1}, yv^(-1)]*
      G[{0, yu^(-1)}, yw] - 2*G[{0}, yu^(-1)]*G[{0, 1}, yw]*
      G[{0, yu^(-1)}, yw] - 2*G[{0}, yv^(-1)]*G[{0, 1}, yw]*
      G[{0, yu^(-1)}, yw] + 2*G[{0}, yw]*G[{0, 1}, yw]*G[{0, yu^(-1)}, yw] + 
     2*G[{1}, yu^(-1)]*G[{0, 1}, yw]*G[{0, yu^(-1)}, yw] + 
     2*G[{1}, yv^(-1)]*G[{0, 1}, yw]*G[{0, yu^(-1)}, yw] - 
     2*G[{yu^(-1)}, yw]*G[{0, 1}, yw]*G[{0, yu^(-1)}, yw] + 
     G[{0}, yu^(-1)]*G[{0, yu^(-1)}, yw]^2 + G[{0}, yv^(-1)]*
      G[{0, yu^(-1)}, yw]^2 - G[{0}, yw]*G[{0, yu^(-1)}, yw]^2 - 
     G[{1}, yu^(-1)]*G[{0, yu^(-1)}, yw]^2 - G[{1}, yv^(-1)]*
      G[{0, yu^(-1)}, yw]^2 + G[{yu^(-1)}, yw]*G[{0, yu^(-1)}, yw]^2 + 
     (Pi^2*G[{yu^(-1)}, yw]*G[{0, yu}, yv^(-1)])/3 - 
     2*G[{0}, yu^(-1)]^2*G[{yu^(-1)}, yw]*G[{0, yu}, yv^(-1)] - 
     4*G[{0}, yu^(-1)]*G[{0}, yv^(-1)]*G[{yu^(-1)}, yw]*G[{0, yu}, yv^(-1)] - 
     2*G[{0}, yv^(-1)]^2*G[{yu^(-1)}, yw]*G[{0, yu}, yv^(-1)] + 
     4*G[{0}, yu^(-1)]*G[{0}, yw]*G[{yu^(-1)}, yw]*G[{0, yu}, yv^(-1)] + 
     4*G[{0}, yv^(-1)]*G[{0}, yw]*G[{yu^(-1)}, yw]*G[{0, yu}, yv^(-1)] - 
     2*G[{0}, yw]^2*G[{yu^(-1)}, yw]*G[{0, yu}, yv^(-1)] + 
     2*G[{0}, yu^(-1)]*G[{1}, yu^(-1)]*G[{yu^(-1)}, yw]*G[{0, yu}, yv^(-1)] + 
     2*G[{0}, yv^(-1)]*G[{1}, yu^(-1)]*G[{yu^(-1)}, yw]*G[{0, yu}, yv^(-1)] - 
     2*G[{0}, yw]*G[{1}, yu^(-1)]*G[{yu^(-1)}, yw]*G[{0, yu}, yv^(-1)] + 
     2*G[{0}, yu^(-1)]*G[{1}, yv^(-1)]*G[{yu^(-1)}, yw]*G[{0, yu}, yv^(-1)] + 
     2*G[{0}, yv^(-1)]*G[{1}, yv^(-1)]*G[{yu^(-1)}, yw]*G[{0, yu}, yv^(-1)] - 
     2*G[{0}, yw]*G[{1}, yv^(-1)]*G[{yu^(-1)}, yw]*G[{0, yu}, yv^(-1)] - 
     2*G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*G[{yu^(-1)}, yw]*G[{0, yu}, yv^(-1)] - 
     G[{1}, yv^(-1)]^2*G[{yu^(-1)}, yw]*G[{0, yu}, yv^(-1)] - 
     2*G[{0}, yu^(-1)]*G[{1}, yw]*G[{yu^(-1)}, yw]*G[{0, yu}, yv^(-1)] - 
     2*G[{0}, yv^(-1)]*G[{1}, yw]*G[{yu^(-1)}, yw]*G[{0, yu}, yv^(-1)] + 
     2*G[{0}, yw]*G[{1}, yw]*G[{yu^(-1)}, yw]*G[{0, yu}, yv^(-1)] + 
     2*G[{1}, yu^(-1)]*G[{1}, yw]*G[{yu^(-1)}, yw]*G[{0, yu}, yv^(-1)] + 
     2*G[{1}, yv^(-1)]*G[{1}, yw]*G[{yu^(-1)}, yw]*G[{0, yu}, yv^(-1)] - 
     G[{1}, yv^(-1)]*G[{yu^(-1)}, yw]^2*G[{0, yu}, yv^(-1)] - 
     G[{1}, yw]*G[{yu^(-1)}, yw]^2*G[{0, yu}, yv^(-1)] + 
     (2*G[{yu^(-1)}, yw]^3*G[{0, yu}, yv^(-1)])/3 - 
     2*G[{0}, yu^(-1)]^2*G[{yu}, yv^(-1)]*G[{0, yu}, yv^(-1)] - 
     4*G[{0}, yu^(-1)]*G[{0}, yv^(-1)]*G[{yu}, yv^(-1)]*G[{0, yu}, yv^(-1)] - 
     2*G[{0}, yv^(-1)]^2*G[{yu}, yv^(-1)]*G[{0, yu}, yv^(-1)] + 
     4*G[{0}, yu^(-1)]*G[{0}, yw]*G[{yu}, yv^(-1)]*G[{0, yu}, yv^(-1)] + 
     4*G[{0}, yv^(-1)]*G[{0}, yw]*G[{yu}, yv^(-1)]*G[{0, yu}, yv^(-1)] - 
     2*G[{0}, yw]^2*G[{yu}, yv^(-1)]*G[{0, yu}, yv^(-1)] + 
     2*G[{1}, yu^(-1)]^2*G[{yu}, yv^(-1)]*G[{0, yu}, yv^(-1)] + 
     2*G[{0}, yu^(-1)]*G[{1}, yv^(-1)]*G[{yu}, yv^(-1)]*G[{0, yu}, yv^(-1)] + 
     2*G[{0}, yv^(-1)]*G[{1}, yv^(-1)]*G[{yu}, yv^(-1)]*G[{0, yu}, yv^(-1)] - 
     2*G[{0}, yw]*G[{1}, yv^(-1)]*G[{yu}, yv^(-1)]*G[{0, yu}, yv^(-1)] - 
     2*G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*G[{yu}, yv^(-1)]*G[{0, yu}, yv^(-1)] - 
     G[{1}, yv^(-1)]^2*G[{yu}, yv^(-1)]*G[{0, yu}, yv^(-1)] + 
     2*G[{0}, yu^(-1)]*G[{yu^(-1)}, yw]*G[{yu}, yv^(-1)]*
      G[{0, yu}, yv^(-1)] + 2*G[{0}, yv^(-1)]*G[{yu^(-1)}, yw]*
      G[{yu}, yv^(-1)]*G[{0, yu}, yv^(-1)] - 2*G[{0}, yw]*G[{yu^(-1)}, yw]*
      G[{yu}, yv^(-1)]*G[{0, yu}, yv^(-1)] - 2*G[{1}, yv^(-1)]*
      G[{yu^(-1)}, yw]*G[{yu}, yv^(-1)]*G[{0, yu}, yv^(-1)] - 
     2*G[{1}, yw]*G[{yu^(-1)}, yw]*G[{yu}, yv^(-1)]*G[{0, yu}, yv^(-1)] + 
     2*G[{yu^(-1)}, yw]^2*G[{yu}, yv^(-1)]*G[{0, yu}, yv^(-1)] + 
     4*G[{0}, yu^(-1)]*G[{yu}, yv^(-1)]^2*G[{0, yu}, yv^(-1)] + 
     4*G[{0}, yv^(-1)]*G[{yu}, yv^(-1)]^2*G[{0, yu}, yv^(-1)] - 
     4*G[{0}, yw]*G[{yu}, yv^(-1)]^2*G[{0, yu}, yv^(-1)] - 
     3*G[{1}, yv^(-1)]*G[{yu}, yv^(-1)]^2*G[{0, yu}, yv^(-1)] - 
     (8*G[{yu}, yv^(-1)]^3*G[{0, yu}, yv^(-1)])/3 + 
     2*G[{0}, yu^(-1)]^2*G[{1/(yu*yv)}, yw]*G[{0, yu}, yv^(-1)] + 
     4*G[{0}, yu^(-1)]*G[{0}, yv^(-1)]*G[{1/(yu*yv)}, yw]*
      G[{0, yu}, yv^(-1)] + 2*G[{0}, yv^(-1)]^2*G[{1/(yu*yv)}, yw]*
      G[{0, yu}, yv^(-1)] - 4*G[{0}, yu^(-1)]*G[{0}, yw]*G[{1/(yu*yv)}, yw]*
      G[{0, yu}, yv^(-1)] - 4*G[{0}, yv^(-1)]*G[{0}, yw]*G[{1/(yu*yv)}, yw]*
      G[{0, yu}, yv^(-1)] + 2*G[{0}, yw]^2*G[{1/(yu*yv)}, yw]*
      G[{0, yu}, yv^(-1)] - 2*G[{1}, yu^(-1)]^2*G[{1/(yu*yv)}, yw]*
      G[{0, yu}, yv^(-1)] - 2*G[{0}, yu^(-1)]*G[{1}, yv^(-1)]*
      G[{1/(yu*yv)}, yw]*G[{0, yu}, yv^(-1)] - 2*G[{0}, yv^(-1)]*
      G[{1}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, yu}, yv^(-1)] + 
     2*G[{0}, yw]*G[{1}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, yu}, yv^(-1)] + 
     2*G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*G[{1/(yu*yv)}, yw]*
      G[{0, yu}, yv^(-1)] + G[{1}, yv^(-1)]^2*G[{1/(yu*yv)}, yw]*
      G[{0, yu}, yv^(-1)] + 2*G[{0}, yu^(-1)]*G[{1}, yw]*G[{1/(yu*yv)}, yw]*
      G[{0, yu}, yv^(-1)] + 2*G[{0}, yv^(-1)]*G[{1}, yw]*G[{1/(yu*yv)}, yw]*
      G[{0, yu}, yv^(-1)] - 2*G[{0}, yw]*G[{1}, yw]*G[{1/(yu*yv)}, yw]*
      G[{0, yu}, yv^(-1)] - 2*G[{1}, yu^(-1)]*G[{1}, yw]*G[{1/(yu*yv)}, yw]*
      G[{0, yu}, yv^(-1)] - 2*G[{1}, yv^(-1)]*G[{1}, yw]*G[{1/(yu*yv)}, yw]*
      G[{0, yu}, yv^(-1)] - 2*G[{0}, yu^(-1)]*G[{yu^(-1)}, yw]*
      G[{1/(yu*yv)}, yw]*G[{0, yu}, yv^(-1)] - 2*G[{0}, yv^(-1)]*
      G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{0, yu}, yv^(-1)] + 
     2*G[{0}, yw]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{0, yu}, yv^(-1)] + 
     2*G[{1}, yv^(-1)]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*
      G[{0, yu}, yv^(-1)] - 2*G[{1}, yw]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*
      G[{0, yu}, yv^(-1)] - 2*G[{yu^(-1)}, yw]^2*G[{1/(yu*yv)}, yw]*
      G[{0, yu}, yv^(-1)] - 8*G[{0}, yu^(-1)]*G[{yu}, yv^(-1)]*
      G[{1/(yu*yv)}, yw]*G[{0, yu}, yv^(-1)] - 8*G[{0}, yv^(-1)]*
      G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, yu}, yv^(-1)] + 
     8*G[{0}, yw]*G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, yu}, yv^(-1)] + 
     6*G[{1}, yv^(-1)]*G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw]*
      G[{0, yu}, yv^(-1)] - 6*G[{1}, yw]*G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw]*
      G[{0, yu}, yv^(-1)] + 8*G[{yu}, yv^(-1)]^2*G[{1/(yu*yv)}, yw]*
      G[{0, yu}, yv^(-1)] + 3*G[{0}, yu^(-1)]*G[{1/(yu*yv)}, yw]^2*
      G[{0, yu}, yv^(-1)] + 3*G[{0}, yv^(-1)]*G[{1/(yu*yv)}, yw]^2*
      G[{0, yu}, yv^(-1)] - 3*G[{0}, yw]*G[{1/(yu*yv)}, yw]^2*
      G[{0, yu}, yv^(-1)] + G[{1}, yu^(-1)]*G[{1/(yu*yv)}, yw]^2*
      G[{0, yu}, yv^(-1)] - 2*G[{1}, yv^(-1)]*G[{1/(yu*yv)}, yw]^2*
      G[{0, yu}, yv^(-1)] + 5*G[{1}, yw]*G[{1/(yu*yv)}, yw]^2*
      G[{0, yu}, yv^(-1)] + 2*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2*
      G[{0, yu}, yv^(-1)] - 5*G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw]^2*
      G[{0, yu}, yv^(-1)] - G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2*
      G[{0, yu}, yv^(-1)] - 2*G[{yu^(-1)}, yw]*G[{0, 1}, yu^(-1)]*
      G[{0, yu}, yv^(-1)] - 4*G[{yu}, yv^(-1)]*G[{0, 1}, yu^(-1)]*
      G[{0, yu}, yv^(-1)] + 4*G[{1/(yu*yv)}, yw]*G[{0, 1}, yu^(-1)]*
      G[{0, yu}, yv^(-1)] - 2*G[{yu^(-1)}, yw]*G[{0, 1}, yv^(-1)]*
      G[{0, yu}, yv^(-1)] + 4*G[{yu}, yv^(-1)]*G[{0, 1}, yw]*
      G[{0, yu}, yv^(-1)] - 2*G[{1/(yu*yv)}, yw]*G[{0, 1}, yw]*
      G[{0, yu}, yv^(-1)] - 2*G[{0}, yu^(-1)]*G[{0, yu^(-1)}, yw]*
      G[{0, yu}, yv^(-1)] - 2*G[{0}, yv^(-1)]*G[{0, yu^(-1)}, yw]*
      G[{0, yu}, yv^(-1)] + 2*G[{0}, yw]*G[{0, yu^(-1)}, yw]*
      G[{0, yu}, yv^(-1)] + 2*G[{1}, yu^(-1)]*G[{0, yu^(-1)}, yw]*
      G[{0, yu}, yv^(-1)] + 2*G[{1}, yv^(-1)]*G[{0, yu^(-1)}, yw]*
      G[{0, yu}, yv^(-1)] + 2*G[{yu^(-1)}, yw]*G[{0, yu^(-1)}, yw]*
      G[{0, yu}, yv^(-1)] + G[{yu^(-1)}, yw]*G[{0, yu}, yv^(-1)]^2 + 
     (Pi^2*G[{yu^(-1)}, yw]*G[{0, yv^(-1)}, yw])/3 - 
     2*G[{0}, yu^(-1)]*G[{1}, yu^(-1)]*G[{yu^(-1)}, yw]*G[{0, yv^(-1)}, yw] - 
     2*G[{0}, yv^(-1)]*G[{1}, yu^(-1)]*G[{yu^(-1)}, yw]*G[{0, yv^(-1)}, yw] + 
     2*G[{0}, yw]*G[{1}, yu^(-1)]*G[{yu^(-1)}, yw]*G[{0, yv^(-1)}, yw] + 
     2*G[{1}, yu^(-1)]^2*G[{yu^(-1)}, yw]*G[{0, yv^(-1)}, yw] + 
     4*G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*G[{yu^(-1)}, yw]*G[{0, yv^(-1)}, yw] + 
     2*G[{0}, yu^(-1)]*G[{1}, yw]*G[{yu^(-1)}, yw]*G[{0, yv^(-1)}, yw] + 
     2*G[{0}, yv^(-1)]*G[{1}, yw]*G[{yu^(-1)}, yw]*G[{0, yv^(-1)}, yw] - 
     2*G[{0}, yw]*G[{1}, yw]*G[{yu^(-1)}, yw]*G[{0, yv^(-1)}, yw] - 
     2*G[{1}, yu^(-1)]*G[{1}, yw]*G[{yu^(-1)}, yw]*G[{0, yv^(-1)}, yw] - 
     2*G[{1}, yv^(-1)]*G[{1}, yw]*G[{yu^(-1)}, yw]*G[{0, yv^(-1)}, yw] + 
     2*G[{1}, yv^(-1)]*G[{yu^(-1)}, yw]^2*G[{0, yv^(-1)}, yw] + 
     2*G[{1}, yw]*G[{yu^(-1)}, yw]^2*G[{0, yv^(-1)}, yw] - 
     (2*G[{yu^(-1)}, yw]^3*G[{0, yv^(-1)}, yw])/3 + 
     2*G[{0}, yu^(-1)]*G[{yu^(-1)}, yw]*G[{yu}, yv^(-1)]*
      G[{0, yv^(-1)}, yw] + 2*G[{0}, yv^(-1)]*G[{yu^(-1)}, yw]*
      G[{yu}, yv^(-1)]*G[{0, yv^(-1)}, yw] - 2*G[{0}, yw]*G[{yu^(-1)}, yw]*
      G[{yu}, yv^(-1)]*G[{0, yv^(-1)}, yw] - 4*G[{1}, yu^(-1)]*
      G[{yu^(-1)}, yw]*G[{yu}, yv^(-1)]*G[{0, yv^(-1)}, yw] - 
     2*G[{yu^(-1)}, yw]^2*G[{yu}, yv^(-1)]*G[{0, yv^(-1)}, yw] - 
     2*G[{0}, yu^(-1)]*G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{0, yv^(-1)}, yw] - 
     2*G[{0}, yv^(-1)]*G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{0, yv^(-1)}, yw] + 
     2*G[{0}, yw]*G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{0, yv^(-1)}, yw] + 
     2*G[{1}, yu^(-1)]*G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{0, yv^(-1)}, yw] + 
     2*G[{1}, yv^(-1)]*G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{0, yv^(-1)}, yw] - 
     2*G[{0}, yu^(-1)]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*
      G[{0, yv^(-1)}, yw] - 2*G[{0}, yv^(-1)]*G[{yu^(-1)}, yw]*
      G[{1/(yu*yv)}, yw]*G[{0, yv^(-1)}, yw] + 2*G[{0}, yw]*G[{yu^(-1)}, yw]*
      G[{1/(yu*yv)}, yw]*G[{0, yv^(-1)}, yw] + 4*G[{1}, yu^(-1)]*
      G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{0, yv^(-1)}, yw] + 
     2*G[{yu^(-1)}, yw]^2*G[{1/(yu*yv)}, yw]*G[{0, yv^(-1)}, yw] + 
     G[{0}, yu^(-1)]*G[{1/(yu*yv)}, yw]^2*G[{0, yv^(-1)}, yw] + 
     G[{0}, yv^(-1)]*G[{1/(yu*yv)}, yw]^2*G[{0, yv^(-1)}, yw] - 
     G[{0}, yw]*G[{1/(yu*yv)}, yw]^2*G[{0, yv^(-1)}, yw] - 
     G[{1}, yu^(-1)]*G[{1/(yu*yv)}, yw]^2*G[{0, yv^(-1)}, yw] - 
     G[{1}, yv^(-1)]*G[{1/(yu*yv)}, yw]^2*G[{0, yv^(-1)}, yw] - 
     G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2*G[{0, yv^(-1)}, yw] - 
     G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2*G[{0, yv^(-1)}, yw] + 
     2*G[{yu^(-1)}, yw]*G[{0, 1}, yu^(-1)]*G[{0, yv^(-1)}, yw] - 
     2*G[{yu^(-1)}, yw]*G[{0, 1}, yv^(-1)]*G[{0, yv^(-1)}, yw] - 
     2*G[{yu^(-1)}, yw]*G[{0, 1}, yw]*G[{0, yv^(-1)}, yw] + 
     2*G[{yu^(-1)}, yw]*G[{0, yu^(-1)}, yw]*G[{0, yv^(-1)}, yw] + 
     2*G[{yu^(-1)}, yw]*G[{0, yu}, yv^(-1)]*G[{0, yv^(-1)}, yw] + 
     G[{yu^(-1)}, yw]*G[{0, yv^(-1)}, yw]^2 + 
     (Pi^2*G[{0}, yu^(-1)]*G[{0, 1/(yu*yv)}, yw])/3 + 
     (Pi^2*G[{0}, yv^(-1)]*G[{0, 1/(yu*yv)}, yw])/3 - 
     (Pi^2*G[{0}, yw]*G[{0, 1/(yu*yv)}, yw])/3 - 
     (Pi^2*G[{1}, yu^(-1)]*G[{0, 1/(yu*yv)}, yw])/3 - 
     (Pi^2*G[{1}, yv^(-1)]*G[{0, 1/(yu*yv)}, yw])/3 + 
     2*G[{0}, yu^(-1)]*G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*
      G[{0, 1/(yu*yv)}, yw] + 2*G[{0}, yv^(-1)]*G[{1}, yu^(-1)]*
      G[{1}, yv^(-1)]*G[{0, 1/(yu*yv)}, yw] - 2*G[{0}, yw]*G[{1}, yu^(-1)]*
      G[{1}, yv^(-1)]*G[{0, 1/(yu*yv)}, yw] - 2*G[{1}, yu^(-1)]^2*
      G[{1}, yv^(-1)]*G[{0, 1/(yu*yv)}, yw] - 2*G[{1}, yu^(-1)]*
      G[{1}, yv^(-1)]^2*G[{0, 1/(yu*yv)}, yw] + 2*G[{0}, yu^(-1)]*
      G[{1}, yu^(-1)]*G[{yu^(-1)}, yw]*G[{0, 1/(yu*yv)}, yw] + 
     2*G[{0}, yv^(-1)]*G[{1}, yu^(-1)]*G[{yu^(-1)}, yw]*
      G[{0, 1/(yu*yv)}, yw] - 2*G[{0}, yw]*G[{1}, yu^(-1)]*G[{yu^(-1)}, yw]*
      G[{0, 1/(yu*yv)}, yw] - 2*G[{1}, yu^(-1)]^2*G[{yu^(-1)}, yw]*
      G[{0, 1/(yu*yv)}, yw] + 2*G[{0}, yu^(-1)]*G[{1}, yv^(-1)]*
      G[{yu^(-1)}, yw]*G[{0, 1/(yu*yv)}, yw] + 2*G[{0}, yv^(-1)]*
      G[{1}, yv^(-1)]*G[{yu^(-1)}, yw]*G[{0, 1/(yu*yv)}, yw] - 
     2*G[{0}, yw]*G[{1}, yv^(-1)]*G[{yu^(-1)}, yw]*G[{0, 1/(yu*yv)}, yw] - 
     4*G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*G[{yu^(-1)}, yw]*
      G[{0, 1/(yu*yv)}, yw] - 2*G[{1}, yv^(-1)]^2*G[{yu^(-1)}, yw]*
      G[{0, 1/(yu*yv)}, yw] - 2*G[{0}, yu^(-1)]*G[{1}, yw]*G[{yu^(-1)}, yw]*
      G[{0, 1/(yu*yv)}, yw] - 2*G[{0}, yv^(-1)]*G[{1}, yw]*G[{yu^(-1)}, yw]*
      G[{0, 1/(yu*yv)}, yw] + 2*G[{0}, yw]*G[{1}, yw]*G[{yu^(-1)}, yw]*
      G[{0, 1/(yu*yv)}, yw] + 2*G[{1}, yu^(-1)]*G[{1}, yw]*G[{yu^(-1)}, yw]*
      G[{0, 1/(yu*yv)}, yw] + 2*G[{1}, yv^(-1)]*G[{1}, yw]*G[{yu^(-1)}, yw]*
      G[{0, 1/(yu*yv)}, yw] - 2*G[{1}, yv^(-1)]*G[{yu^(-1)}, yw]^2*
      G[{0, 1/(yu*yv)}, yw] - 2*G[{1}, yw]*G[{yu^(-1)}, yw]^2*
      G[{0, 1/(yu*yv)}, yw] + (2*G[{yu^(-1)}, yw]^3*G[{0, 1/(yu*yv)}, yw])/
      3 - 2*G[{0}, yu^(-1)]*G[{1}, yu^(-1)]*G[{yu}, yv^(-1)]*
      G[{0, 1/(yu*yv)}, yw] - 2*G[{0}, yv^(-1)]*G[{1}, yu^(-1)]*
      G[{yu}, yv^(-1)]*G[{0, 1/(yu*yv)}, yw] + 2*G[{0}, yw]*G[{1}, yu^(-1)]*
      G[{yu}, yv^(-1)]*G[{0, 1/(yu*yv)}, yw] + 2*G[{1}, yu^(-1)]^2*
      G[{yu}, yv^(-1)]*G[{0, 1/(yu*yv)}, yw] + 2*G[{0}, yu^(-1)]*
      G[{1}, yv^(-1)]*G[{yu}, yv^(-1)]*G[{0, 1/(yu*yv)}, yw] + 
     2*G[{0}, yv^(-1)]*G[{1}, yv^(-1)]*G[{yu}, yv^(-1)]*
      G[{0, 1/(yu*yv)}, yw] - 2*G[{0}, yw]*G[{1}, yv^(-1)]*G[{yu}, yv^(-1)]*
      G[{0, 1/(yu*yv)}, yw] - 2*G[{1}, yv^(-1)]^2*G[{yu}, yv^(-1)]*
      G[{0, 1/(yu*yv)}, yw] - 4*G[{0}, yu^(-1)]*G[{yu^(-1)}, yw]*
      G[{yu}, yv^(-1)]*G[{0, 1/(yu*yv)}, yw] - 4*G[{0}, yv^(-1)]*
      G[{yu^(-1)}, yw]*G[{yu}, yv^(-1)]*G[{0, 1/(yu*yv)}, yw] + 
     4*G[{0}, yw]*G[{yu^(-1)}, yw]*G[{yu}, yv^(-1)]*G[{0, 1/(yu*yv)}, yw] + 
     4*G[{1}, yu^(-1)]*G[{yu^(-1)}, yw]*G[{yu}, yv^(-1)]*
      G[{0, 1/(yu*yv)}, yw] + 2*G[{yu^(-1)}, yw]^2*G[{yu}, yv^(-1)]*
      G[{0, 1/(yu*yv)}, yw] - 2*G[{1}, yv^(-1)]*G[{yu}, yv^(-1)]^2*
      G[{0, 1/(yu*yv)}, yw] + 2*G[{yu^(-1)}, yw]*G[{yu}, yv^(-1)]^2*
      G[{0, 1/(yu*yv)}, yw] + (2*G[{yu}, yv^(-1)]^3*G[{0, 1/(yu*yv)}, yw])/
      3 - (Pi^2*G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv)}, yw])/3 - 
     2*G[{0}, yu^(-1)]*G[{1}, yv^(-1)]*G[{1/(yu*yv)}, yw]*
      G[{0, 1/(yu*yv)}, yw] - 2*G[{0}, yv^(-1)]*G[{1}, yv^(-1)]*
      G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv)}, yw] + 2*G[{0}, yw]*G[{1}, yv^(-1)]*
      G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv)}, yw] + 2*G[{1}, yv^(-1)]^2*
      G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv)}, yw] + 2*G[{0}, yu^(-1)]*G[{1}, yw]*
      G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv)}, yw] + 2*G[{0}, yv^(-1)]*G[{1}, yw]*
      G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv)}, yw] - 2*G[{0}, yw]*G[{1}, yw]*
      G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv)}, yw] - 2*G[{1}, yu^(-1)]*G[{1}, yw]*
      G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv)}, yw] - 2*G[{1}, yv^(-1)]*G[{1}, yw]*
      G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv)}, yw] + 2*G[{0}, yu^(-1)]*
      G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv)}, yw] + 
     2*G[{0}, yv^(-1)]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*
      G[{0, 1/(yu*yv)}, yw] - 2*G[{0}, yw]*G[{yu^(-1)}, yw]*
      G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv)}, yw] - 4*G[{1}, yu^(-1)]*
      G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv)}, yw] - 
     2*G[{yu^(-1)}, yw]^2*G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv)}, yw] + 
     2*G[{0}, yu^(-1)]*G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw]*
      G[{0, 1/(yu*yv)}, yw] + 2*G[{0}, yv^(-1)]*G[{yu}, yv^(-1)]*
      G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv)}, yw] - 
     2*G[{0}, yw]*G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv)}, yw] - 
     2*G[{yu}, yv^(-1)]^2*G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv)}, yw] - 
     G[{0}, yu^(-1)]*G[{1/(yu*yv)}, yw]^2*G[{0, 1/(yu*yv)}, yw] - 
     G[{0}, yv^(-1)]*G[{1/(yu*yv)}, yw]^2*G[{0, 1/(yu*yv)}, yw] + 
     G[{0}, yw]*G[{1/(yu*yv)}, yw]^2*G[{0, 1/(yu*yv)}, yw] + 
     G[{1}, yu^(-1)]*G[{1/(yu*yv)}, yw]^2*G[{0, 1/(yu*yv)}, yw] + 
     G[{1}, yv^(-1)]*G[{1/(yu*yv)}, yw]^2*G[{0, 1/(yu*yv)}, yw] + 
     G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2*G[{0, 1/(yu*yv)}, yw] + 
     G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2*G[{0, 1/(yu*yv)}, yw] + 
     2*G[{0}, yu^(-1)]*G[{0, 1}, yu^(-1)]*G[{0, 1/(yu*yv)}, yw] + 
     2*G[{0}, yv^(-1)]*G[{0, 1}, yu^(-1)]*G[{0, 1/(yu*yv)}, yw] - 
     2*G[{0}, yw]*G[{0, 1}, yu^(-1)]*G[{0, 1/(yu*yv)}, yw] - 
     2*G[{1}, yu^(-1)]*G[{0, 1}, yu^(-1)]*G[{0, 1/(yu*yv)}, yw] - 
     2*G[{1}, yv^(-1)]*G[{0, 1}, yu^(-1)]*G[{0, 1/(yu*yv)}, yw] - 
     2*G[{1/(yu*yv)}, yw]*G[{0, 1}, yu^(-1)]*G[{0, 1/(yu*yv)}, yw] - 
     2*G[{0}, yu^(-1)]*G[{0, 1}, yv^(-1)]*G[{0, 1/(yu*yv)}, yw] - 
     2*G[{0}, yv^(-1)]*G[{0, 1}, yv^(-1)]*G[{0, 1/(yu*yv)}, yw] + 
     2*G[{0}, yw]*G[{0, 1}, yv^(-1)]*G[{0, 1/(yu*yv)}, yw] + 
     2*G[{1}, yu^(-1)]*G[{0, 1}, yv^(-1)]*G[{0, 1/(yu*yv)}, yw] + 
     2*G[{1}, yv^(-1)]*G[{0, 1}, yv^(-1)]*G[{0, 1/(yu*yv)}, yw] + 
     4*G[{yu^(-1)}, yw]*G[{0, 1}, yv^(-1)]*G[{0, 1/(yu*yv)}, yw] + 
     4*G[{yu}, yv^(-1)]*G[{0, 1}, yv^(-1)]*G[{0, 1/(yu*yv)}, yw] - 
     2*G[{1/(yu*yv)}, yw]*G[{0, 1}, yv^(-1)]*G[{0, 1/(yu*yv)}, yw] + 
     2*G[{0}, yu^(-1)]*G[{0, 1}, yw]*G[{0, 1/(yu*yv)}, yw] + 
     2*G[{0}, yv^(-1)]*G[{0, 1}, yw]*G[{0, 1/(yu*yv)}, yw] - 
     2*G[{0}, yw]*G[{0, 1}, yw]*G[{0, 1/(yu*yv)}, yw] - 
     2*G[{1}, yu^(-1)]*G[{0, 1}, yw]*G[{0, 1/(yu*yv)}, yw] - 
     2*G[{1}, yv^(-1)]*G[{0, 1}, yw]*G[{0, 1/(yu*yv)}, yw] + 
     2*G[{1/(yu*yv)}, yw]*G[{0, 1}, yw]*G[{0, 1/(yu*yv)}, yw] - 
     2*G[{0}, yu^(-1)]*G[{0, yu^(-1)}, yw]*G[{0, 1/(yu*yv)}, yw] - 
     2*G[{0}, yv^(-1)]*G[{0, yu^(-1)}, yw]*G[{0, 1/(yu*yv)}, yw] + 
     2*G[{0}, yw]*G[{0, yu^(-1)}, yw]*G[{0, 1/(yu*yv)}, yw] + 
     2*G[{1}, yu^(-1)]*G[{0, yu^(-1)}, yw]*G[{0, 1/(yu*yv)}, yw] + 
     2*G[{1}, yv^(-1)]*G[{0, yu^(-1)}, yw]*G[{0, 1/(yu*yv)}, yw] - 
     2*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1)}, yw]*G[{0, 1/(yu*yv)}, yw] + 
     2*G[{0}, yu^(-1)]*G[{0, yu}, yv^(-1)]*G[{0, 1/(yu*yv)}, yw] + 
     2*G[{0}, yv^(-1)]*G[{0, yu}, yv^(-1)]*G[{0, 1/(yu*yv)}, yw] - 
     2*G[{0}, yw]*G[{0, yu}, yv^(-1)]*G[{0, 1/(yu*yv)}, yw] - 
     2*G[{1}, yu^(-1)]*G[{0, yu}, yv^(-1)]*G[{0, 1/(yu*yv)}, yw] - 
     2*G[{1}, yv^(-1)]*G[{0, yu}, yv^(-1)]*G[{0, 1/(yu*yv)}, yw] - 
     4*G[{yu^(-1)}, yw]*G[{0, yu}, yv^(-1)]*G[{0, 1/(yu*yv)}, yw] - 
     4*G[{yu}, yv^(-1)]*G[{0, yu}, yv^(-1)]*G[{0, 1/(yu*yv)}, yw] + 
     2*G[{1/(yu*yv)}, yw]*G[{0, yu}, yv^(-1)]*G[{0, 1/(yu*yv)}, yw] - 
     2*G[{0}, yu^(-1)]*G[{0, yv^(-1)}, yw]*G[{0, 1/(yu*yv)}, yw] - 
     2*G[{0}, yv^(-1)]*G[{0, yv^(-1)}, yw]*G[{0, 1/(yu*yv)}, yw] + 
     2*G[{0}, yw]*G[{0, yv^(-1)}, yw]*G[{0, 1/(yu*yv)}, yw] + 
     2*G[{1}, yu^(-1)]*G[{0, yv^(-1)}, yw]*G[{0, 1/(yu*yv)}, yw] + 
     2*G[{1}, yv^(-1)]*G[{0, yv^(-1)}, yw]*G[{0, 1/(yu*yv)}, yw] - 
     2*G[{1/(yu*yv)}, yw]*G[{0, yv^(-1)}, yw]*G[{0, 1/(yu*yv)}, yw] + 
     G[{0}, yu^(-1)]*G[{0, 1/(yu*yv)}, yw]^2 + G[{0}, yv^(-1)]*
      G[{0, 1/(yu*yv)}, yw]^2 - G[{0}, yw]*G[{0, 1/(yu*yv)}, yw]^2 - 
     G[{1}, yu^(-1)]*G[{0, 1/(yu*yv)}, yw]^2 - G[{1}, yv^(-1)]*
      G[{0, 1/(yu*yv)}, yw]^2 + G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv)}, yw]^2 + 
     (Pi^2*G[{0}, yu^(-1)]*G[{1, yu^(-1)}, yw])/3 + 
     (Pi^2*G[{0}, yv^(-1)]*G[{1, yu^(-1)}, yw])/3 - 
     (Pi^2*G[{0}, yw]*G[{1, yu^(-1)}, yw])/3 - 
     (Pi^2*G[{1}, yu^(-1)]*G[{1, yu^(-1)}, yw])/3 - 
     (Pi^2*G[{1}, yv^(-1)]*G[{1, yu^(-1)}, yw])/3 + 
     2*G[{0}, yu^(-1)]*G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*G[{1, yu^(-1)}, yw] + 
     2*G[{0}, yv^(-1)]*G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*G[{1, yu^(-1)}, yw] - 
     2*G[{0}, yw]*G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*G[{1, yu^(-1)}, yw] - 
     2*G[{1}, yu^(-1)]^2*G[{1}, yv^(-1)]*G[{1, yu^(-1)}, yw] - 
     2*G[{1}, yu^(-1)]*G[{1}, yv^(-1)]^2*G[{1, yu^(-1)}, yw] - 
     Pi^2*G[{yu^(-1)}, yw]*G[{1, yu^(-1)}, yw] + 2*G[{0}, yu^(-1)]^2*
      G[{yu^(-1)}, yw]*G[{1, yu^(-1)}, yw] + 4*G[{0}, yu^(-1)]*
      G[{0}, yv^(-1)]*G[{yu^(-1)}, yw]*G[{1, yu^(-1)}, yw] + 
     2*G[{0}, yv^(-1)]^2*G[{yu^(-1)}, yw]*G[{1, yu^(-1)}, yw] - 
     4*G[{0}, yu^(-1)]*G[{0}, yw]*G[{yu^(-1)}, yw]*G[{1, yu^(-1)}, yw] - 
     4*G[{0}, yv^(-1)]*G[{0}, yw]*G[{yu^(-1)}, yw]*G[{1, yu^(-1)}, yw] + 
     2*G[{0}, yw]^2*G[{yu^(-1)}, yw]*G[{1, yu^(-1)}, yw] - 
     4*G[{0}, yu^(-1)]*G[{1}, yu^(-1)]*G[{yu^(-1)}, yw]*G[{1, yu^(-1)}, yw] - 
     4*G[{0}, yv^(-1)]*G[{1}, yu^(-1)]*G[{yu^(-1)}, yw]*G[{1, yu^(-1)}, yw] + 
     4*G[{0}, yw]*G[{1}, yu^(-1)]*G[{yu^(-1)}, yw]*G[{1, yu^(-1)}, yw] + 
     2*G[{1}, yu^(-1)]^2*G[{yu^(-1)}, yw]*G[{1, yu^(-1)}, yw] - 
     2*G[{0}, yu^(-1)]*G[{1}, yv^(-1)]*G[{yu^(-1)}, yw]*G[{1, yu^(-1)}, yw] - 
     2*G[{0}, yv^(-1)]*G[{1}, yv^(-1)]*G[{yu^(-1)}, yw]*G[{1, yu^(-1)}, yw] + 
     2*G[{0}, yw]*G[{1}, yv^(-1)]*G[{yu^(-1)}, yw]*G[{1, yu^(-1)}, yw] + 
     8*G[{0}, yu^(-1)]*G[{1}, yw]*G[{yu^(-1)}, yw]*G[{1, yu^(-1)}, yw] + 
     8*G[{0}, yv^(-1)]*G[{1}, yw]*G[{yu^(-1)}, yw]*G[{1, yu^(-1)}, yw] - 
     8*G[{0}, yw]*G[{1}, yw]*G[{yu^(-1)}, yw]*G[{1, yu^(-1)}, yw] - 
     8*G[{1}, yu^(-1)]*G[{1}, yw]*G[{yu^(-1)}, yw]*G[{1, yu^(-1)}, yw] - 
     8*G[{1}, yv^(-1)]*G[{1}, yw]*G[{yu^(-1)}, yw]*G[{1, yu^(-1)}, yw] - 
     3*G[{1}, yv^(-1)]*G[{yu^(-1)}, yw]^2*G[{1, yu^(-1)}, yw] - 
     3*G[{1}, yw]*G[{yu^(-1)}, yw]^2*G[{1, yu^(-1)}, yw] - 
     2*G[{0}, yu^(-1)]*G[{1}, yu^(-1)]*G[{yu}, yv^(-1)]*G[{1, yu^(-1)}, yw] - 
     2*G[{0}, yv^(-1)]*G[{1}, yu^(-1)]*G[{yu}, yv^(-1)]*G[{1, yu^(-1)}, yw] + 
     2*G[{0}, yw]*G[{1}, yu^(-1)]*G[{yu}, yv^(-1)]*G[{1, yu^(-1)}, yw] + 
     2*G[{1}, yu^(-1)]^2*G[{yu}, yv^(-1)]*G[{1, yu^(-1)}, yw] + 
     2*G[{0}, yu^(-1)]*G[{1}, yv^(-1)]*G[{yu}, yv^(-1)]*G[{1, yu^(-1)}, yw] + 
     2*G[{0}, yv^(-1)]*G[{1}, yv^(-1)]*G[{yu}, yv^(-1)]*G[{1, yu^(-1)}, yw] - 
     2*G[{0}, yw]*G[{1}, yv^(-1)]*G[{yu}, yv^(-1)]*G[{1, yu^(-1)}, yw] - 
     2*G[{1}, yv^(-1)]^2*G[{yu}, yv^(-1)]*G[{1, yu^(-1)}, yw] - 
     2*G[{0}, yu^(-1)]*G[{yu^(-1)}, yw]*G[{yu}, yv^(-1)]*
      G[{1, yu^(-1)}, yw] - 2*G[{0}, yv^(-1)]*G[{yu^(-1)}, yw]*
      G[{yu}, yv^(-1)]*G[{1, yu^(-1)}, yw] + 2*G[{0}, yw]*G[{yu^(-1)}, yw]*
      G[{yu}, yv^(-1)]*G[{1, yu^(-1)}, yw] + 4*G[{1}, yu^(-1)]*
      G[{yu^(-1)}, yw]*G[{yu}, yv^(-1)]*G[{1, yu^(-1)}, yw] + 
     3*G[{yu^(-1)}, yw]^2*G[{yu}, yv^(-1)]*G[{1, yu^(-1)}, yw] + 
     G[{1}, yv^(-1)]*G[{yu}, yv^(-1)]^2*G[{1, yu^(-1)}, yw] - 
     (G[{yu}, yv^(-1)]^3*G[{1, yu^(-1)}, yw])/3 + 
     (Pi^2*G[{1/(yu*yv)}, yw]*G[{1, yu^(-1)}, yw])/3 - 
     2*G[{0}, yu^(-1)]^2*G[{1/(yu*yv)}, yw]*G[{1, yu^(-1)}, yw] - 
     4*G[{0}, yu^(-1)]*G[{0}, yv^(-1)]*G[{1/(yu*yv)}, yw]*
      G[{1, yu^(-1)}, yw] - 2*G[{0}, yv^(-1)]^2*G[{1/(yu*yv)}, yw]*
      G[{1, yu^(-1)}, yw] + 4*G[{0}, yu^(-1)]*G[{0}, yw]*G[{1/(yu*yv)}, yw]*
      G[{1, yu^(-1)}, yw] + 4*G[{0}, yv^(-1)]*G[{0}, yw]*G[{1/(yu*yv)}, yw]*
      G[{1, yu^(-1)}, yw] - 2*G[{0}, yw]^2*G[{1/(yu*yv)}, yw]*
      G[{1, yu^(-1)}, yw] + 4*G[{0}, yu^(-1)]*G[{1}, yu^(-1)]*
      G[{1/(yu*yv)}, yw]*G[{1, yu^(-1)}, yw] + 4*G[{0}, yv^(-1)]*
      G[{1}, yu^(-1)]*G[{1/(yu*yv)}, yw]*G[{1, yu^(-1)}, yw] - 
     4*G[{0}, yw]*G[{1}, yu^(-1)]*G[{1/(yu*yv)}, yw]*G[{1, yu^(-1)}, yw] - 
     2*G[{1}, yu^(-1)]^2*G[{1/(yu*yv)}, yw]*G[{1, yu^(-1)}, yw] + 
     2*G[{0}, yu^(-1)]*G[{1}, yv^(-1)]*G[{1/(yu*yv)}, yw]*
      G[{1, yu^(-1)}, yw] + 2*G[{0}, yv^(-1)]*G[{1}, yv^(-1)]*
      G[{1/(yu*yv)}, yw]*G[{1, yu^(-1)}, yw] - 2*G[{0}, yw]*G[{1}, yv^(-1)]*
      G[{1/(yu*yv)}, yw]*G[{1, yu^(-1)}, yw] - 4*G[{1}, yu^(-1)]*
      G[{1}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{1, yu^(-1)}, yw] - 
     4*G[{0}, yu^(-1)]*G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{1, yu^(-1)}, yw] - 
     4*G[{0}, yv^(-1)]*G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{1, yu^(-1)}, yw] + 
     4*G[{0}, yw]*G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{1, yu^(-1)}, yw] + 
     4*G[{1}, yu^(-1)]*G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{1, yu^(-1)}, yw] + 
     4*G[{1}, yv^(-1)]*G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{1, yu^(-1)}, yw] + 
     4*G[{0}, yu^(-1)]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*
      G[{1, yu^(-1)}, yw] + 4*G[{0}, yv^(-1)]*G[{yu^(-1)}, yw]*
      G[{1/(yu*yv)}, yw]*G[{1, yu^(-1)}, yw] - 4*G[{0}, yw]*G[{yu^(-1)}, yw]*
      G[{1/(yu*yv)}, yw]*G[{1, yu^(-1)}, yw] - 4*G[{1}, yu^(-1)]*
      G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{1, yu^(-1)}, yw] - 
     2*G[{1}, yv^(-1)]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*
      G[{1, yu^(-1)}, yw] + 2*G[{1}, yw]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*
      G[{1, yu^(-1)}, yw] + 2*G[{0}, yu^(-1)]*G[{yu}, yv^(-1)]*
      G[{1/(yu*yv)}, yw]*G[{1, yu^(-1)}, yw] + 2*G[{0}, yv^(-1)]*
      G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{1, yu^(-1)}, yw] - 
     2*G[{0}, yw]*G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{1, yu^(-1)}, yw] - 
     4*G[{1}, yv^(-1)]*G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw]*
      G[{1, yu^(-1)}, yw] - 2*G[{yu^(-1)}, yw]*G[{yu}, yv^(-1)]*
      G[{1/(yu*yv)}, yw]*G[{1, yu^(-1)}, yw] - 4*G[{0}, yu^(-1)]*
      G[{1/(yu*yv)}, yw]^2*G[{1, yu^(-1)}, yw] - 4*G[{0}, yv^(-1)]*
      G[{1/(yu*yv)}, yw]^2*G[{1, yu^(-1)}, yw] + 
     4*G[{0}, yw]*G[{1/(yu*yv)}, yw]^2*G[{1, yu^(-1)}, yw] + 
     5*G[{1}, yv^(-1)]*G[{1/(yu*yv)}, yw]^2*G[{1, yu^(-1)}, yw] - 
     3*G[{1}, yw]*G[{1/(yu*yv)}, yw]^2*G[{1, yu^(-1)}, yw] - 
     G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2*G[{1, yu^(-1)}, yw] + 
     3*G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw]^2*G[{1, yu^(-1)}, yw] + 
     2*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2*G[{1, yu^(-1)}, yw] + 
     2*G[{0}, yu^(-1)]*G[{0, 1}, yu^(-1)]*G[{1, yu^(-1)}, yw] + 
     2*G[{0}, yv^(-1)]*G[{0, 1}, yu^(-1)]*G[{1, yu^(-1)}, yw] - 
     2*G[{0}, yw]*G[{0, 1}, yu^(-1)]*G[{1, yu^(-1)}, yw] - 
     2*G[{1}, yu^(-1)]*G[{0, 1}, yu^(-1)]*G[{1, yu^(-1)}, yw] - 
     2*G[{1}, yv^(-1)]*G[{0, 1}, yu^(-1)]*G[{1, yu^(-1)}, yw] - 
     2*G[{yu^(-1)}, yw]*G[{0, 1}, yu^(-1)]*G[{1, yu^(-1)}, yw] - 
     2*G[{1/(yu*yv)}, yw]*G[{0, 1}, yu^(-1)]*G[{1, yu^(-1)}, yw] - 
     2*G[{0}, yu^(-1)]*G[{0, 1}, yv^(-1)]*G[{1, yu^(-1)}, yw] - 
     2*G[{0}, yv^(-1)]*G[{0, 1}, yv^(-1)]*G[{1, yu^(-1)}, yw] + 
     2*G[{0}, yw]*G[{0, 1}, yv^(-1)]*G[{1, yu^(-1)}, yw] + 
     2*G[{1}, yu^(-1)]*G[{0, 1}, yv^(-1)]*G[{1, yu^(-1)}, yw] + 
     2*G[{1}, yv^(-1)]*G[{0, 1}, yv^(-1)]*G[{1, yu^(-1)}, yw] + 
     2*G[{yu^(-1)}, yw]*G[{0, 1}, yv^(-1)]*G[{1, yu^(-1)}, yw] - 
     2*G[{yu}, yv^(-1)]*G[{0, 1}, yv^(-1)]*G[{1, yu^(-1)}, yw] + 
     2*G[{1/(yu*yv)}, yw]*G[{0, 1}, yv^(-1)]*G[{1, yu^(-1)}, yw] + 
     2*G[{0}, yu^(-1)]*G[{0, 1}, yw]*G[{1, yu^(-1)}, yw] + 
     2*G[{0}, yv^(-1)]*G[{0, 1}, yw]*G[{1, yu^(-1)}, yw] - 
     2*G[{0}, yw]*G[{0, 1}, yw]*G[{1, yu^(-1)}, yw] - 
     2*G[{1}, yu^(-1)]*G[{0, 1}, yw]*G[{1, yu^(-1)}, yw] - 
     2*G[{1}, yv^(-1)]*G[{0, 1}, yw]*G[{1, yu^(-1)}, yw] + 
     6*G[{yu^(-1)}, yw]*G[{0, 1}, yw]*G[{1, yu^(-1)}, yw] - 
     2*G[{1/(yu*yv)}, yw]*G[{0, 1}, yw]*G[{1, yu^(-1)}, yw] - 
     2*G[{0}, yu^(-1)]*G[{0, yu^(-1)}, yw]*G[{1, yu^(-1)}, yw] - 
     2*G[{0}, yv^(-1)]*G[{0, yu^(-1)}, yw]*G[{1, yu^(-1)}, yw] + 
     2*G[{0}, yw]*G[{0, yu^(-1)}, yw]*G[{1, yu^(-1)}, yw] + 
     2*G[{1}, yu^(-1)]*G[{0, yu^(-1)}, yw]*G[{1, yu^(-1)}, yw] + 
     2*G[{1}, yv^(-1)]*G[{0, yu^(-1)}, yw]*G[{1, yu^(-1)}, yw] - 
     6*G[{yu^(-1)}, yw]*G[{0, yu^(-1)}, yw]*G[{1, yu^(-1)}, yw] + 
     2*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1)}, yw]*G[{1, yu^(-1)}, yw] + 
     2*G[{0}, yu^(-1)]*G[{0, yu}, yv^(-1)]*G[{1, yu^(-1)}, yw] + 
     2*G[{0}, yv^(-1)]*G[{0, yu}, yv^(-1)]*G[{1, yu^(-1)}, yw] - 
     2*G[{0}, yw]*G[{0, yu}, yv^(-1)]*G[{1, yu^(-1)}, yw] - 
     2*G[{1}, yu^(-1)]*G[{0, yu}, yv^(-1)]*G[{1, yu^(-1)}, yw] - 
     2*G[{1}, yv^(-1)]*G[{0, yu}, yv^(-1)]*G[{1, yu^(-1)}, yw] - 
     2*G[{yu^(-1)}, yw]*G[{0, yu}, yv^(-1)]*G[{1, yu^(-1)}, yw] + 
     2*G[{yu}, yv^(-1)]*G[{0, yu}, yv^(-1)]*G[{1, yu^(-1)}, yw] - 
     2*G[{1/(yu*yv)}, yw]*G[{0, yu}, yv^(-1)]*G[{1, yu^(-1)}, yw] - 
     2*G[{0}, yu^(-1)]*G[{0, yv^(-1)}, yw]*G[{1, yu^(-1)}, yw] - 
     2*G[{0}, yv^(-1)]*G[{0, yv^(-1)}, yw]*G[{1, yu^(-1)}, yw] + 
     2*G[{0}, yw]*G[{0, yv^(-1)}, yw]*G[{1, yu^(-1)}, yw] + 
     2*G[{1}, yu^(-1)]*G[{0, yv^(-1)}, yw]*G[{1, yu^(-1)}, yw] + 
     2*G[{1}, yv^(-1)]*G[{0, yv^(-1)}, yw]*G[{1, yu^(-1)}, yw] - 
     6*G[{yu^(-1)}, yw]*G[{0, yv^(-1)}, yw]*G[{1, yu^(-1)}, yw] + 
     2*G[{1/(yu*yv)}, yw]*G[{0, yv^(-1)}, yw]*G[{1, yu^(-1)}, yw] + 
     2*G[{0}, yu^(-1)]*G[{0, 1/(yu*yv)}, yw]*G[{1, yu^(-1)}, yw] + 
     2*G[{0}, yv^(-1)]*G[{0, 1/(yu*yv)}, yw]*G[{1, yu^(-1)}, yw] - 
     2*G[{0}, yw]*G[{0, 1/(yu*yv)}, yw]*G[{1, yu^(-1)}, yw] - 
     2*G[{1}, yu^(-1)]*G[{0, 1/(yu*yv)}, yw]*G[{1, yu^(-1)}, yw] - 
     2*G[{1}, yv^(-1)]*G[{0, 1/(yu*yv)}, yw]*G[{1, yu^(-1)}, yw] + 
     6*G[{yu^(-1)}, yw]*G[{0, 1/(yu*yv)}, yw]*G[{1, yu^(-1)}, yw] - 
     2*G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv)}, yw]*G[{1, yu^(-1)}, yw] + 
     4*G[{yu^(-1)}, yw]*G[{1, yu^(-1)}, yw]^2 - 
     (Pi^2*G[{0}, yu^(-1)]*G[{1, yu}, yv^(-1)])/3 - 
     (Pi^2*G[{0}, yv^(-1)]*G[{1, yu}, yv^(-1)])/3 + 
     (Pi^2*G[{0}, yw]*G[{1, yu}, yv^(-1)])/3 + 
     (Pi^2*G[{1}, yu^(-1)]*G[{1, yu}, yv^(-1)])/3 + 
     (Pi^2*G[{1}, yv^(-1)]*G[{1, yu}, yv^(-1)])/3 - 
     2*G[{0}, yu^(-1)]*G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*G[{1, yu}, yv^(-1)] - 
     2*G[{0}, yv^(-1)]*G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*G[{1, yu}, yv^(-1)] + 
     2*G[{0}, yw]*G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*G[{1, yu}, yv^(-1)] + 
     2*G[{1}, yu^(-1)]^2*G[{1}, yv^(-1)]*G[{1, yu}, yv^(-1)] + 
     2*G[{1}, yu^(-1)]*G[{1}, yv^(-1)]^2*G[{1, yu}, yv^(-1)] - 
     (2*Pi^2*G[{yu^(-1)}, yw]*G[{1, yu}, yv^(-1)])/3 + 
     2*G[{0}, yu^(-1)]^2*G[{yu^(-1)}, yw]*G[{1, yu}, yv^(-1)] + 
     4*G[{0}, yu^(-1)]*G[{0}, yv^(-1)]*G[{yu^(-1)}, yw]*G[{1, yu}, yv^(-1)] + 
     2*G[{0}, yv^(-1)]^2*G[{yu^(-1)}, yw]*G[{1, yu}, yv^(-1)] - 
     4*G[{0}, yu^(-1)]*G[{0}, yw]*G[{yu^(-1)}, yw]*G[{1, yu}, yv^(-1)] - 
     4*G[{0}, yv^(-1)]*G[{0}, yw]*G[{yu^(-1)}, yw]*G[{1, yu}, yv^(-1)] + 
     2*G[{0}, yw]^2*G[{yu^(-1)}, yw]*G[{1, yu}, yv^(-1)] - 
     2*G[{0}, yu^(-1)]*G[{1}, yu^(-1)]*G[{yu^(-1)}, yw]*G[{1, yu}, yv^(-1)] - 
     2*G[{0}, yv^(-1)]*G[{1}, yu^(-1)]*G[{yu^(-1)}, yw]*G[{1, yu}, yv^(-1)] + 
     2*G[{0}, yw]*G[{1}, yu^(-1)]*G[{yu^(-1)}, yw]*G[{1, yu}, yv^(-1)] - 
     6*G[{0}, yu^(-1)]*G[{1}, yv^(-1)]*G[{yu^(-1)}, yw]*G[{1, yu}, yv^(-1)] - 
     6*G[{0}, yv^(-1)]*G[{1}, yv^(-1)]*G[{yu^(-1)}, yw]*G[{1, yu}, yv^(-1)] + 
     6*G[{0}, yw]*G[{1}, yv^(-1)]*G[{yu^(-1)}, yw]*G[{1, yu}, yv^(-1)] + 
     4*G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*G[{yu^(-1)}, yw]*G[{1, yu}, yv^(-1)] + 
     4*G[{1}, yv^(-1)]^2*G[{yu^(-1)}, yw]*G[{1, yu}, yv^(-1)] + 
     4*G[{0}, yu^(-1)]*G[{1}, yw]*G[{yu^(-1)}, yw]*G[{1, yu}, yv^(-1)] + 
     4*G[{0}, yv^(-1)]*G[{1}, yw]*G[{yu^(-1)}, yw]*G[{1, yu}, yv^(-1)] - 
     4*G[{0}, yw]*G[{1}, yw]*G[{yu^(-1)}, yw]*G[{1, yu}, yv^(-1)] - 
     4*G[{1}, yu^(-1)]*G[{1}, yw]*G[{yu^(-1)}, yw]*G[{1, yu}, yv^(-1)] - 
     4*G[{1}, yv^(-1)]*G[{1}, yw]*G[{yu^(-1)}, yw]*G[{1, yu}, yv^(-1)] - 
     G[{1}, yv^(-1)]*G[{yu^(-1)}, yw]^2*G[{1, yu}, yv^(-1)] + 
     G[{1}, yw]*G[{yu^(-1)}, yw]^2*G[{1, yu}, yv^(-1)] - 
     (2*G[{yu^(-1)}, yw]^3*G[{1, yu}, yv^(-1)])/3 + 
     2*G[{0}, yu^(-1)]^2*G[{yu}, yv^(-1)]*G[{1, yu}, yv^(-1)] + 
     4*G[{0}, yu^(-1)]*G[{0}, yv^(-1)]*G[{yu}, yv^(-1)]*G[{1, yu}, yv^(-1)] + 
     2*G[{0}, yv^(-1)]^2*G[{yu}, yv^(-1)]*G[{1, yu}, yv^(-1)] - 
     4*G[{0}, yu^(-1)]*G[{0}, yw]*G[{yu}, yv^(-1)]*G[{1, yu}, yv^(-1)] - 
     4*G[{0}, yv^(-1)]*G[{0}, yw]*G[{yu}, yv^(-1)]*G[{1, yu}, yv^(-1)] + 
     2*G[{0}, yw]^2*G[{yu}, yv^(-1)]*G[{1, yu}, yv^(-1)] - 
     2*G[{0}, yu^(-1)]*G[{1}, yu^(-1)]*G[{yu}, yv^(-1)]*G[{1, yu}, yv^(-1)] - 
     2*G[{0}, yv^(-1)]*G[{1}, yu^(-1)]*G[{yu}, yv^(-1)]*G[{1, yu}, yv^(-1)] + 
     2*G[{0}, yw]*G[{1}, yu^(-1)]*G[{yu}, yv^(-1)]*G[{1, yu}, yv^(-1)] - 
     6*G[{0}, yu^(-1)]*G[{1}, yv^(-1)]*G[{yu}, yv^(-1)]*G[{1, yu}, yv^(-1)] - 
     6*G[{0}, yv^(-1)]*G[{1}, yv^(-1)]*G[{yu}, yv^(-1)]*G[{1, yu}, yv^(-1)] + 
     6*G[{0}, yw]*G[{1}, yv^(-1)]*G[{yu}, yv^(-1)]*G[{1, yu}, yv^(-1)] + 
     8*G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*G[{yu}, yv^(-1)]*G[{1, yu}, yv^(-1)] + 
     4*G[{1}, yv^(-1)]^2*G[{yu}, yv^(-1)]*G[{1, yu}, yv^(-1)] - 
     4*G[{1}, yu^(-1)]*G[{yu^(-1)}, yw]*G[{yu}, yv^(-1)]*
      G[{1, yu}, yv^(-1)] + 2*G[{1}, yv^(-1)]*G[{yu^(-1)}, yw]*
      G[{yu}, yv^(-1)]*G[{1, yu}, yv^(-1)] + 2*G[{1}, yw]*G[{yu^(-1)}, yw]*
      G[{yu}, yv^(-1)]*G[{1, yu}, yv^(-1)] - 2*G[{yu^(-1)}, yw]^2*
      G[{yu}, yv^(-1)]*G[{1, yu}, yv^(-1)] - 4*G[{0}, yu^(-1)]*
      G[{yu}, yv^(-1)]^2*G[{1, yu}, yv^(-1)] - 4*G[{0}, yv^(-1)]*
      G[{yu}, yv^(-1)]^2*G[{1, yu}, yv^(-1)] + 
     4*G[{0}, yw]*G[{yu}, yv^(-1)]^2*G[{1, yu}, yv^(-1)] + 
     7*G[{1}, yv^(-1)]*G[{yu}, yv^(-1)]^2*G[{1, yu}, yv^(-1)] - 
     2*G[{yu^(-1)}, yw]*G[{yu}, yv^(-1)]^2*G[{1, yu}, yv^(-1)] + 
     2*G[{yu}, yv^(-1)]^3*G[{1, yu}, yv^(-1)] - 2*G[{0}, yu^(-1)]^2*
      G[{1/(yu*yv)}, yw]*G[{1, yu}, yv^(-1)] - 4*G[{0}, yu^(-1)]*
      G[{0}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{1, yu}, yv^(-1)] - 
     2*G[{0}, yv^(-1)]^2*G[{1/(yu*yv)}, yw]*G[{1, yu}, yv^(-1)] + 
     4*G[{0}, yu^(-1)]*G[{0}, yw]*G[{1/(yu*yv)}, yw]*G[{1, yu}, yv^(-1)] + 
     4*G[{0}, yv^(-1)]*G[{0}, yw]*G[{1/(yu*yv)}, yw]*G[{1, yu}, yv^(-1)] - 
     2*G[{0}, yw]^2*G[{1/(yu*yv)}, yw]*G[{1, yu}, yv^(-1)] + 
     2*G[{0}, yu^(-1)]*G[{1}, yu^(-1)]*G[{1/(yu*yv)}, yw]*
      G[{1, yu}, yv^(-1)] + 2*G[{0}, yv^(-1)]*G[{1}, yu^(-1)]*
      G[{1/(yu*yv)}, yw]*G[{1, yu}, yv^(-1)] - 2*G[{0}, yw]*G[{1}, yu^(-1)]*
      G[{1/(yu*yv)}, yw]*G[{1, yu}, yv^(-1)] + 6*G[{0}, yu^(-1)]*
      G[{1}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{1, yu}, yv^(-1)] + 
     6*G[{0}, yv^(-1)]*G[{1}, yv^(-1)]*G[{1/(yu*yv)}, yw]*
      G[{1, yu}, yv^(-1)] - 6*G[{0}, yw]*G[{1}, yv^(-1)]*G[{1/(yu*yv)}, yw]*
      G[{1, yu}, yv^(-1)] - 8*G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*
      G[{1/(yu*yv)}, yw]*G[{1, yu}, yv^(-1)] - 4*G[{1}, yv^(-1)]^2*
      G[{1/(yu*yv)}, yw]*G[{1, yu}, yv^(-1)] - 4*G[{0}, yu^(-1)]*G[{1}, yw]*
      G[{1/(yu*yv)}, yw]*G[{1, yu}, yv^(-1)] - 4*G[{0}, yv^(-1)]*G[{1}, yw]*
      G[{1/(yu*yv)}, yw]*G[{1, yu}, yv^(-1)] + 4*G[{0}, yw]*G[{1}, yw]*
      G[{1/(yu*yv)}, yw]*G[{1, yu}, yv^(-1)] + 4*G[{1}, yu^(-1)]*G[{1}, yw]*
      G[{1/(yu*yv)}, yw]*G[{1, yu}, yv^(-1)] + 4*G[{1}, yv^(-1)]*G[{1}, yw]*
      G[{1/(yu*yv)}, yw]*G[{1, yu}, yv^(-1)] + 4*G[{1}, yu^(-1)]*
      G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{1, yu}, yv^(-1)] - 
     2*G[{1}, yv^(-1)]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*
      G[{1, yu}, yv^(-1)] - 2*G[{1}, yw]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*
      G[{1, yu}, yv^(-1)] + 2*G[{yu^(-1)}, yw]^2*G[{1/(yu*yv)}, yw]*
      G[{1, yu}, yv^(-1)] + 8*G[{0}, yu^(-1)]*G[{yu}, yv^(-1)]*
      G[{1/(yu*yv)}, yw]*G[{1, yu}, yv^(-1)] + 8*G[{0}, yv^(-1)]*
      G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{1, yu}, yv^(-1)] - 
     8*G[{0}, yw]*G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{1, yu}, yv^(-1)] - 
     14*G[{1}, yv^(-1)]*G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw]*
      G[{1, yu}, yv^(-1)] + 6*G[{1}, yw]*G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw]*
      G[{1, yu}, yv^(-1)] + 4*G[{yu^(-1)}, yw]*G[{yu}, yv^(-1)]*
      G[{1/(yu*yv)}, yw]*G[{1, yu}, yv^(-1)] - 6*G[{yu}, yv^(-1)]^2*
      G[{1/(yu*yv)}, yw]*G[{1, yu}, yv^(-1)] - 2*G[{0}, yu^(-1)]*
      G[{1/(yu*yv)}, yw]^2*G[{1, yu}, yv^(-1)] - 2*G[{0}, yv^(-1)]*
      G[{1/(yu*yv)}, yw]^2*G[{1, yu}, yv^(-1)] + 
     2*G[{0}, yw]*G[{1/(yu*yv)}, yw]^2*G[{1, yu}, yv^(-1)] - 
     2*G[{1}, yu^(-1)]*G[{1/(yu*yv)}, yw]^2*G[{1, yu}, yv^(-1)] + 
     5*G[{1}, yv^(-1)]*G[{1/(yu*yv)}, yw]^2*G[{1, yu}, yv^(-1)] - 
     3*G[{1}, yw]*G[{1/(yu*yv)}, yw]^2*G[{1, yu}, yv^(-1)] - 
     3*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2*G[{1, yu}, yv^(-1)] + 
     3*G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw]^2*G[{1, yu}, yv^(-1)] + 
     2*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2*G[{1, yu}, yv^(-1)] - 
     2*G[{0}, yu^(-1)]*G[{0, 1}, yu^(-1)]*G[{1, yu}, yv^(-1)] - 
     2*G[{0}, yv^(-1)]*G[{0, 1}, yu^(-1)]*G[{1, yu}, yv^(-1)] + 
     2*G[{0}, yw]*G[{0, 1}, yu^(-1)]*G[{1, yu}, yv^(-1)] + 
     2*G[{1}, yu^(-1)]*G[{0, 1}, yu^(-1)]*G[{1, yu}, yv^(-1)] + 
     2*G[{1}, yv^(-1)]*G[{0, 1}, yu^(-1)]*G[{1, yu}, yv^(-1)] + 
     4*G[{yu}, yv^(-1)]*G[{0, 1}, yu^(-1)]*G[{1, yu}, yv^(-1)] - 
     4*G[{1/(yu*yv)}, yw]*G[{0, 1}, yu^(-1)]*G[{1, yu}, yv^(-1)] + 
     2*G[{0}, yu^(-1)]*G[{0, 1}, yv^(-1)]*G[{1, yu}, yv^(-1)] + 
     2*G[{0}, yv^(-1)]*G[{0, 1}, yv^(-1)]*G[{1, yu}, yv^(-1)] - 
     2*G[{0}, yw]*G[{0, 1}, yv^(-1)]*G[{1, yu}, yv^(-1)] - 
     2*G[{1}, yu^(-1)]*G[{0, 1}, yv^(-1)]*G[{1, yu}, yv^(-1)] - 
     2*G[{1}, yv^(-1)]*G[{0, 1}, yv^(-1)]*G[{1, yu}, yv^(-1)] - 
     4*G[{yu}, yv^(-1)]*G[{0, 1}, yv^(-1)]*G[{1, yu}, yv^(-1)] + 
     4*G[{1/(yu*yv)}, yw]*G[{0, 1}, yv^(-1)]*G[{1, yu}, yv^(-1)] + 
     4*G[{yu^(-1)}, yw]*G[{0, 1}, yw]*G[{1, yu}, yv^(-1)] - 
     4*G[{yu}, yv^(-1)]*G[{0, 1}, yw]*G[{1, yu}, yv^(-1)] + 
     4*G[{0}, yu^(-1)]*G[{0, yu^(-1)}, yw]*G[{1, yu}, yv^(-1)] + 
     4*G[{0}, yv^(-1)]*G[{0, yu^(-1)}, yw]*G[{1, yu}, yv^(-1)] - 
     4*G[{0}, yw]*G[{0, yu^(-1)}, yw]*G[{1, yu}, yv^(-1)] - 
     4*G[{1}, yu^(-1)]*G[{0, yu^(-1)}, yw]*G[{1, yu}, yv^(-1)] - 
     4*G[{1}, yv^(-1)]*G[{0, yu^(-1)}, yw]*G[{1, yu}, yv^(-1)] - 
     4*G[{yu^(-1)}, yw]*G[{0, yu^(-1)}, yw]*G[{1, yu}, yv^(-1)] - 
     2*G[{0}, yu^(-1)]*G[{0, yu}, yv^(-1)]*G[{1, yu}, yv^(-1)] - 
     2*G[{0}, yv^(-1)]*G[{0, yu}, yv^(-1)]*G[{1, yu}, yv^(-1)] + 
     2*G[{0}, yw]*G[{0, yu}, yv^(-1)]*G[{1, yu}, yv^(-1)] + 
     2*G[{1}, yu^(-1)]*G[{0, yu}, yv^(-1)]*G[{1, yu}, yv^(-1)] + 
     2*G[{1}, yv^(-1)]*G[{0, yu}, yv^(-1)]*G[{1, yu}, yv^(-1)] + 
     4*G[{yu}, yv^(-1)]*G[{0, yu}, yv^(-1)]*G[{1, yu}, yv^(-1)] - 
     4*G[{1/(yu*yv)}, yw]*G[{0, yu}, yv^(-1)]*G[{1, yu}, yv^(-1)] - 
     4*G[{yu^(-1)}, yw]*G[{0, yv^(-1)}, yw]*G[{1, yu}, yv^(-1)] - 
     4*G[{0}, yu^(-1)]*G[{0, 1/(yu*yv)}, yw]*G[{1, yu}, yv^(-1)] - 
     4*G[{0}, yv^(-1)]*G[{0, 1/(yu*yv)}, yw]*G[{1, yu}, yv^(-1)] + 
     4*G[{0}, yw]*G[{0, 1/(yu*yv)}, yw]*G[{1, yu}, yv^(-1)] + 
     4*G[{1}, yu^(-1)]*G[{0, 1/(yu*yv)}, yw]*G[{1, yu}, yv^(-1)] + 
     4*G[{1}, yv^(-1)]*G[{0, 1/(yu*yv)}, yw]*G[{1, yu}, yv^(-1)] + 
     4*G[{yu^(-1)}, yw]*G[{0, 1/(yu*yv)}, yw]*G[{1, yu}, yv^(-1)] + 
     4*G[{yu}, yv^(-1)]*G[{0, 1/(yu*yv)}, yw]*G[{1, yu}, yv^(-1)] - 
     4*G[{0}, yu^(-1)]*G[{1, yu^(-1)}, yw]*G[{1, yu}, yv^(-1)] - 
     4*G[{0}, yv^(-1)]*G[{1, yu^(-1)}, yw]*G[{1, yu}, yv^(-1)] + 
     4*G[{0}, yw]*G[{1, yu^(-1)}, yw]*G[{1, yu}, yv^(-1)] + 
     4*G[{1}, yu^(-1)]*G[{1, yu^(-1)}, yw]*G[{1, yu}, yv^(-1)] + 
     4*G[{1}, yv^(-1)]*G[{1, yu^(-1)}, yw]*G[{1, yu}, yv^(-1)] + 
     4*G[{yu^(-1)}, yw]*G[{1, yu^(-1)}, yw]*G[{1, yu}, yv^(-1)] - 
     2*G[{yu}, yv^(-1)]*G[{1, yu^(-1)}, yw]*G[{1, yu}, yv^(-1)] + 
     4*G[{1/(yu*yv)}, yw]*G[{1, yu^(-1)}, yw]*G[{1, yu}, yv^(-1)] + 
     2*G[{0}, yu^(-1)]*G[{1, yu}, yv^(-1)]^2 + 2*G[{0}, yv^(-1)]*
      G[{1, yu}, yv^(-1)]^2 - 2*G[{0}, yw]*G[{1, yu}, yv^(-1)]^2 - 
     2*G[{1}, yu^(-1)]*G[{1, yu}, yv^(-1)]^2 - 2*G[{1}, yv^(-1)]*
      G[{1, yu}, yv^(-1)]^2 - 4*G[{yu}, yv^(-1)]*G[{1, yu}, yv^(-1)]^2 + 
     4*G[{1/(yu*yv)}, yw]*G[{1, yu}, yv^(-1)]^2 - 
     (Pi^2*G[{yu^(-1)}, yw]*G[{1, yv^(-1)}, yw])/3 + 
     2*G[{0}, yu^(-1)]*G[{1}, yu^(-1)]*G[{yu^(-1)}, yw]*G[{1, yv^(-1)}, yw] + 
     2*G[{0}, yv^(-1)]*G[{1}, yu^(-1)]*G[{yu^(-1)}, yw]*G[{1, yv^(-1)}, yw] - 
     2*G[{0}, yw]*G[{1}, yu^(-1)]*G[{yu^(-1)}, yw]*G[{1, yv^(-1)}, yw] - 
     2*G[{1}, yu^(-1)]^2*G[{yu^(-1)}, yw]*G[{1, yv^(-1)}, yw] - 
     4*G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*G[{yu^(-1)}, yw]*G[{1, yv^(-1)}, yw] + 
     4*G[{0}, yu^(-1)]*G[{1}, yw]*G[{yu^(-1)}, yw]*G[{1, yv^(-1)}, yw] + 
     4*G[{0}, yv^(-1)]*G[{1}, yw]*G[{yu^(-1)}, yw]*G[{1, yv^(-1)}, yw] - 
     4*G[{0}, yw]*G[{1}, yw]*G[{yu^(-1)}, yw]*G[{1, yv^(-1)}, yw] - 
     4*G[{1}, yu^(-1)]*G[{1}, yw]*G[{yu^(-1)}, yw]*G[{1, yv^(-1)}, yw] - 
     4*G[{1}, yv^(-1)]*G[{1}, yw]*G[{yu^(-1)}, yw]*G[{1, yv^(-1)}, yw] - 
     2*G[{1}, yv^(-1)]*G[{yu^(-1)}, yw]^2*G[{1, yv^(-1)}, yw] - 
     2*G[{1}, yw]*G[{yu^(-1)}, yw]^2*G[{1, yv^(-1)}, yw] + 
     (2*G[{yu^(-1)}, yw]^3*G[{1, yv^(-1)}, yw])/3 - 
     2*G[{0}, yu^(-1)]*G[{yu^(-1)}, yw]*G[{yu}, yv^(-1)]*
      G[{1, yv^(-1)}, yw] - 2*G[{0}, yv^(-1)]*G[{yu^(-1)}, yw]*
      G[{yu}, yv^(-1)]*G[{1, yv^(-1)}, yw] + 2*G[{0}, yw]*G[{yu^(-1)}, yw]*
      G[{yu}, yv^(-1)]*G[{1, yv^(-1)}, yw] + 4*G[{1}, yu^(-1)]*
      G[{yu^(-1)}, yw]*G[{yu}, yv^(-1)]*G[{1, yv^(-1)}, yw] + 
     2*G[{yu^(-1)}, yw]^2*G[{yu}, yv^(-1)]*G[{1, yv^(-1)}, yw] + 
     (Pi^2*G[{1/(yu*yv)}, yw]*G[{1, yv^(-1)}, yw])/3 - 
     2*G[{0}, yu^(-1)]*G[{1}, yu^(-1)]*G[{1/(yu*yv)}, yw]*
      G[{1, yv^(-1)}, yw] - 2*G[{0}, yv^(-1)]*G[{1}, yu^(-1)]*
      G[{1/(yu*yv)}, yw]*G[{1, yv^(-1)}, yw] + 2*G[{0}, yw]*G[{1}, yu^(-1)]*
      G[{1/(yu*yv)}, yw]*G[{1, yv^(-1)}, yw] + 2*G[{1}, yu^(-1)]^2*
      G[{1/(yu*yv)}, yw]*G[{1, yv^(-1)}, yw] + 4*G[{1}, yu^(-1)]*
      G[{1}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{1, yv^(-1)}, yw] - 
     4*G[{0}, yu^(-1)]*G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{1, yv^(-1)}, yw] - 
     4*G[{0}, yv^(-1)]*G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{1, yv^(-1)}, yw] + 
     4*G[{0}, yw]*G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{1, yv^(-1)}, yw] + 
     4*G[{1}, yu^(-1)]*G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{1, yv^(-1)}, yw] + 
     4*G[{1}, yv^(-1)]*G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{1, yv^(-1)}, yw] + 
     4*G[{0}, yu^(-1)]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*
      G[{1, yv^(-1)}, yw] + 4*G[{0}, yv^(-1)]*G[{yu^(-1)}, yw]*
      G[{1/(yu*yv)}, yw]*G[{1, yv^(-1)}, yw] - 4*G[{0}, yw]*G[{yu^(-1)}, yw]*
      G[{1/(yu*yv)}, yw]*G[{1, yv^(-1)}, yw] - 8*G[{1}, yu^(-1)]*
      G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{1, yv^(-1)}, yw] - 
     2*G[{yu^(-1)}, yw]^2*G[{1/(yu*yv)}, yw]*G[{1, yv^(-1)}, yw] + 
     2*G[{0}, yu^(-1)]*G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw]*
      G[{1, yv^(-1)}, yw] + 2*G[{0}, yv^(-1)]*G[{yu}, yv^(-1)]*
      G[{1/(yu*yv)}, yw]*G[{1, yv^(-1)}, yw] - 2*G[{0}, yw]*G[{yu}, yv^(-1)]*
      G[{1/(yu*yv)}, yw]*G[{1, yv^(-1)}, yw] - 4*G[{1}, yu^(-1)]*
      G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{1, yv^(-1)}, yw] - 
     2*G[{0}, yu^(-1)]*G[{1/(yu*yv)}, yw]^2*G[{1, yv^(-1)}, yw] - 
     2*G[{0}, yv^(-1)]*G[{1/(yu*yv)}, yw]^2*G[{1, yv^(-1)}, yw] + 
     2*G[{0}, yw]*G[{1/(yu*yv)}, yw]^2*G[{1, yv^(-1)}, yw] + 
     2*G[{1}, yu^(-1)]*G[{1/(yu*yv)}, yw]^2*G[{1, yv^(-1)}, yw] - 
     2*G[{1}, yw]*G[{1/(yu*yv)}, yw]^2*G[{1, yv^(-1)}, yw] + 
     2*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2*G[{1, yv^(-1)}, yw] + 
     2*G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw]^2*G[{1, yv^(-1)}, yw] - 
     2*G[{yu^(-1)}, yw]*G[{0, 1}, yu^(-1)]*G[{1, yv^(-1)}, yw] + 
     2*G[{1/(yu*yv)}, yw]*G[{0, 1}, yu^(-1)]*G[{1, yv^(-1)}, yw] + 
     2*G[{yu^(-1)}, yw]*G[{0, 1}, yv^(-1)]*G[{1, yv^(-1)}, yw] - 
     2*G[{1/(yu*yv)}, yw]*G[{0, 1}, yv^(-1)]*G[{1, yv^(-1)}, yw] + 
     2*G[{yu^(-1)}, yw]*G[{0, 1}, yw]*G[{1, yv^(-1)}, yw] - 
     2*G[{1/(yu*yv)}, yw]*G[{0, 1}, yw]*G[{1, yv^(-1)}, yw] - 
     2*G[{yu^(-1)}, yw]*G[{0, yu^(-1)}, yw]*G[{1, yv^(-1)}, yw] + 
     2*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1)}, yw]*G[{1, yv^(-1)}, yw] - 
     2*G[{yu^(-1)}, yw]*G[{0, yu}, yv^(-1)]*G[{1, yv^(-1)}, yw] + 
     2*G[{1/(yu*yv)}, yw]*G[{0, yu}, yv^(-1)]*G[{1, yv^(-1)}, yw] - 
     2*G[{yu^(-1)}, yw]*G[{0, yv^(-1)}, yw]*G[{1, yv^(-1)}, yw] + 
     2*G[{1/(yu*yv)}, yw]*G[{0, yv^(-1)}, yw]*G[{1, yv^(-1)}, yw] + 
     2*G[{yu^(-1)}, yw]*G[{0, 1/(yu*yv)}, yw]*G[{1, yv^(-1)}, yw] - 
     2*G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv)}, yw]*G[{1, yv^(-1)}, yw] + 
     4*G[{yu^(-1)}, yw]*G[{1, yu^(-1)}, yw]*G[{1, yv^(-1)}, yw] - 
     4*G[{1/(yu*yv)}, yw]*G[{1, yu^(-1)}, yw]*G[{1, yv^(-1)}, yw] + 
     4*G[{yu^(-1)}, yw]*G[{1, yu}, yv^(-1)]*G[{1, yv^(-1)}, yw] - 
     4*G[{1/(yu*yv)}, yw]*G[{1, yu}, yv^(-1)]*G[{1, yv^(-1)}, yw] - 
     (Pi^2*G[{0}, yu^(-1)]*G[{1, 1/(yu*yv)}, yw])/3 - 
     (Pi^2*G[{0}, yv^(-1)]*G[{1, 1/(yu*yv)}, yw])/3 + 
     (Pi^2*G[{0}, yw]*G[{1, 1/(yu*yv)}, yw])/3 + 
     (Pi^2*G[{1}, yu^(-1)]*G[{1, 1/(yu*yv)}, yw])/3 + 
     (Pi^2*G[{1}, yv^(-1)]*G[{1, 1/(yu*yv)}, yw])/3 - 
     2*G[{0}, yu^(-1)]*G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*
      G[{1, 1/(yu*yv)}, yw] - 2*G[{0}, yv^(-1)]*G[{1}, yu^(-1)]*
      G[{1}, yv^(-1)]*G[{1, 1/(yu*yv)}, yw] + 2*G[{0}, yw]*G[{1}, yu^(-1)]*
      G[{1}, yv^(-1)]*G[{1, 1/(yu*yv)}, yw] + 2*G[{1}, yu^(-1)]^2*
      G[{1}, yv^(-1)]*G[{1, 1/(yu*yv)}, yw] + 2*G[{1}, yu^(-1)]*
      G[{1}, yv^(-1)]^2*G[{1, 1/(yu*yv)}, yw] - 2*G[{0}, yu^(-1)]^2*
      G[{yu^(-1)}, yw]*G[{1, 1/(yu*yv)}, yw] - 4*G[{0}, yu^(-1)]*
      G[{0}, yv^(-1)]*G[{yu^(-1)}, yw]*G[{1, 1/(yu*yv)}, yw] - 
     2*G[{0}, yv^(-1)]^2*G[{yu^(-1)}, yw]*G[{1, 1/(yu*yv)}, yw] + 
     4*G[{0}, yu^(-1)]*G[{0}, yw]*G[{yu^(-1)}, yw]*G[{1, 1/(yu*yv)}, yw] + 
     4*G[{0}, yv^(-1)]*G[{0}, yw]*G[{yu^(-1)}, yw]*G[{1, 1/(yu*yv)}, yw] - 
     2*G[{0}, yw]^2*G[{yu^(-1)}, yw]*G[{1, 1/(yu*yv)}, yw] + 
     2*G[{0}, yu^(-1)]*G[{1}, yu^(-1)]*G[{yu^(-1)}, yw]*
      G[{1, 1/(yu*yv)}, yw] + 2*G[{0}, yv^(-1)]*G[{1}, yu^(-1)]*
      G[{yu^(-1)}, yw]*G[{1, 1/(yu*yv)}, yw] - 2*G[{0}, yw]*G[{1}, yu^(-1)]*
      G[{yu^(-1)}, yw]*G[{1, 1/(yu*yv)}, yw] + 2*G[{0}, yu^(-1)]*
      G[{1}, yv^(-1)]*G[{yu^(-1)}, yw]*G[{1, 1/(yu*yv)}, yw] + 
     2*G[{0}, yv^(-1)]*G[{1}, yv^(-1)]*G[{yu^(-1)}, yw]*
      G[{1, 1/(yu*yv)}, yw] - 2*G[{0}, yw]*G[{1}, yv^(-1)]*G[{yu^(-1)}, yw]*
      G[{1, 1/(yu*yv)}, yw] - 4*G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*
      G[{yu^(-1)}, yw]*G[{1, 1/(yu*yv)}, yw] - 4*G[{0}, yu^(-1)]*G[{1}, yw]*
      G[{yu^(-1)}, yw]*G[{1, 1/(yu*yv)}, yw] - 4*G[{0}, yv^(-1)]*G[{1}, yw]*
      G[{yu^(-1)}, yw]*G[{1, 1/(yu*yv)}, yw] + 4*G[{0}, yw]*G[{1}, yw]*
      G[{yu^(-1)}, yw]*G[{1, 1/(yu*yv)}, yw] + 4*G[{1}, yu^(-1)]*G[{1}, yw]*
      G[{yu^(-1)}, yw]*G[{1, 1/(yu*yv)}, yw] + 4*G[{1}, yv^(-1)]*G[{1}, yw]*
      G[{yu^(-1)}, yw]*G[{1, 1/(yu*yv)}, yw] + G[{1}, yv^(-1)]*
      G[{yu^(-1)}, yw]^2*G[{1, 1/(yu*yv)}, yw] + 
     G[{1}, yw]*G[{yu^(-1)}, yw]^2*G[{1, 1/(yu*yv)}, yw] + 
     (2*G[{yu^(-1)}, yw]^3*G[{1, 1/(yu*yv)}, yw])/3 + 
     2*G[{0}, yu^(-1)]*G[{1}, yu^(-1)]*G[{yu}, yv^(-1)]*
      G[{1, 1/(yu*yv)}, yw] + 2*G[{0}, yv^(-1)]*G[{1}, yu^(-1)]*
      G[{yu}, yv^(-1)]*G[{1, 1/(yu*yv)}, yw] - 2*G[{0}, yw]*G[{1}, yu^(-1)]*
      G[{yu}, yv^(-1)]*G[{1, 1/(yu*yv)}, yw] - 2*G[{1}, yu^(-1)]^2*
      G[{yu}, yv^(-1)]*G[{1, 1/(yu*yv)}, yw] - 2*G[{0}, yu^(-1)]*
      G[{1}, yv^(-1)]*G[{yu}, yv^(-1)]*G[{1, 1/(yu*yv)}, yw] - 
     2*G[{0}, yv^(-1)]*G[{1}, yv^(-1)]*G[{yu}, yv^(-1)]*
      G[{1, 1/(yu*yv)}, yw] + 2*G[{0}, yw]*G[{1}, yv^(-1)]*G[{yu}, yv^(-1)]*
      G[{1, 1/(yu*yv)}, yw] + 2*G[{1}, yv^(-1)]^2*G[{yu}, yv^(-1)]*
      G[{1, 1/(yu*yv)}, yw] + 4*G[{0}, yu^(-1)]*G[{yu^(-1)}, yw]*
      G[{yu}, yv^(-1)]*G[{1, 1/(yu*yv)}, yw] + 4*G[{0}, yv^(-1)]*
      G[{yu^(-1)}, yw]*G[{yu}, yv^(-1)]*G[{1, 1/(yu*yv)}, yw] - 
     4*G[{0}, yw]*G[{yu^(-1)}, yw]*G[{yu}, yv^(-1)]*G[{1, 1/(yu*yv)}, yw] - 
     G[{yu^(-1)}, yw]^2*G[{yu}, yv^(-1)]*G[{1, 1/(yu*yv)}, yw] + 
     3*G[{1}, yv^(-1)]*G[{yu}, yv^(-1)]^2*G[{1, 1/(yu*yv)}, yw] - 
     4*G[{yu^(-1)}, yw]*G[{yu}, yv^(-1)]^2*G[{1, 1/(yu*yv)}, yw] - 
     G[{yu}, yv^(-1)]^3*G[{1, 1/(yu*yv)}, yw] + 2*G[{0}, yu^(-1)]^2*
      G[{1/(yu*yv)}, yw]*G[{1, 1/(yu*yv)}, yw] + 4*G[{0}, yu^(-1)]*
      G[{0}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{1, 1/(yu*yv)}, yw] + 
     2*G[{0}, yv^(-1)]^2*G[{1/(yu*yv)}, yw]*G[{1, 1/(yu*yv)}, yw] - 
     4*G[{0}, yu^(-1)]*G[{0}, yw]*G[{1/(yu*yv)}, yw]*G[{1, 1/(yu*yv)}, yw] - 
     4*G[{0}, yv^(-1)]*G[{0}, yw]*G[{1/(yu*yv)}, yw]*G[{1, 1/(yu*yv)}, yw] + 
     2*G[{0}, yw]^2*G[{1/(yu*yv)}, yw]*G[{1, 1/(yu*yv)}, yw] + 
     2*G[{0}, yu^(-1)]*G[{1}, yu^(-1)]*G[{1/(yu*yv)}, yw]*
      G[{1, 1/(yu*yv)}, yw] + 2*G[{0}, yv^(-1)]*G[{1}, yu^(-1)]*
      G[{1/(yu*yv)}, yw]*G[{1, 1/(yu*yv)}, yw] - 2*G[{0}, yw]*G[{1}, yu^(-1)]*
      G[{1/(yu*yv)}, yw]*G[{1, 1/(yu*yv)}, yw] - 4*G[{1}, yu^(-1)]^2*
      G[{1/(yu*yv)}, yw]*G[{1, 1/(yu*yv)}, yw] - 2*G[{0}, yu^(-1)]*
      G[{1}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{1, 1/(yu*yv)}, yw] - 
     2*G[{0}, yv^(-1)]*G[{1}, yv^(-1)]*G[{1/(yu*yv)}, yw]*
      G[{1, 1/(yu*yv)}, yw] + 2*G[{0}, yw]*G[{1}, yv^(-1)]*G[{1/(yu*yv)}, yw]*
      G[{1, 1/(yu*yv)}, yw] + 8*G[{0}, yu^(-1)]*G[{1}, yw]*G[{1/(yu*yv)}, yw]*
      G[{1, 1/(yu*yv)}, yw] + 8*G[{0}, yv^(-1)]*G[{1}, yw]*G[{1/(yu*yv)}, yw]*
      G[{1, 1/(yu*yv)}, yw] - 8*G[{0}, yw]*G[{1}, yw]*G[{1/(yu*yv)}, yw]*
      G[{1, 1/(yu*yv)}, yw] - 8*G[{1}, yu^(-1)]*G[{1}, yw]*G[{1/(yu*yv)}, yw]*
      G[{1, 1/(yu*yv)}, yw] - 8*G[{1}, yv^(-1)]*G[{1}, yw]*G[{1/(yu*yv)}, yw]*
      G[{1, 1/(yu*yv)}, yw] - 4*G[{0}, yu^(-1)]*G[{yu^(-1)}, yw]*
      G[{1/(yu*yv)}, yw]*G[{1, 1/(yu*yv)}, yw] - 4*G[{0}, yv^(-1)]*
      G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{1, 1/(yu*yv)}, yw] + 
     4*G[{0}, yw]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{1, 1/(yu*yv)}, yw] + 
     4*G[{1}, yu^(-1)]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*
      G[{1, 1/(yu*yv)}, yw] + 2*G[{1}, yv^(-1)]*G[{yu^(-1)}, yw]*
      G[{1/(yu*yv)}, yw]*G[{1, 1/(yu*yv)}, yw] - 
     2*G[{1}, yw]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{1, 1/(yu*yv)}, yw] - 
     2*G[{yu^(-1)}, yw]^2*G[{1/(yu*yv)}, yw]*G[{1, 1/(yu*yv)}, yw] - 
     8*G[{0}, yu^(-1)]*G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw]*
      G[{1, 1/(yu*yv)}, yw] - 8*G[{0}, yv^(-1)]*G[{yu}, yv^(-1)]*
      G[{1/(yu*yv)}, yw]*G[{1, 1/(yu*yv)}, yw] + 
     8*G[{0}, yw]*G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{1, 1/(yu*yv)}, yw] + 
     4*G[{1}, yu^(-1)]*G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw]*
      G[{1, 1/(yu*yv)}, yw] + 4*G[{1}, yv^(-1)]*G[{yu}, yv^(-1)]*
      G[{1/(yu*yv)}, yw]*G[{1, 1/(yu*yv)}, yw] + 2*G[{yu^(-1)}, yw]*
      G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{1, 1/(yu*yv)}, yw] + 
     4*G[{yu}, yv^(-1)]^2*G[{1/(yu*yv)}, yw]*G[{1, 1/(yu*yv)}, yw] + 
     4*G[{0}, yu^(-1)]*G[{1/(yu*yv)}, yw]^2*G[{1, 1/(yu*yv)}, yw] + 
     4*G[{0}, yv^(-1)]*G[{1/(yu*yv)}, yw]^2*G[{1, 1/(yu*yv)}, yw] - 
     4*G[{0}, yw]*G[{1/(yu*yv)}, yw]^2*G[{1, 1/(yu*yv)}, yw] - 
     3*G[{1}, yv^(-1)]*G[{1/(yu*yv)}, yw]^2*G[{1, 1/(yu*yv)}, yw] + 
     5*G[{1}, yw]*G[{1/(yu*yv)}, yw]^2*G[{1, 1/(yu*yv)}, yw] + 
     G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2*G[{1, 1/(yu*yv)}, yw] - 
     5*G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw]^2*G[{1, 1/(yu*yv)}, yw] - 
     2*G[{0}, yu^(-1)]*G[{0, 1}, yu^(-1)]*G[{1, 1/(yu*yv)}, yw] - 
     2*G[{0}, yv^(-1)]*G[{0, 1}, yu^(-1)]*G[{1, 1/(yu*yv)}, yw] + 
     2*G[{0}, yw]*G[{0, 1}, yu^(-1)]*G[{1, 1/(yu*yv)}, yw] + 
     2*G[{1}, yu^(-1)]*G[{0, 1}, yu^(-1)]*G[{1, 1/(yu*yv)}, yw] + 
     2*G[{1}, yv^(-1)]*G[{0, 1}, yu^(-1)]*G[{1, 1/(yu*yv)}, yw] - 
     4*G[{yu^(-1)}, yw]*G[{0, 1}, yu^(-1)]*G[{1, 1/(yu*yv)}, yw] + 
     4*G[{1/(yu*yv)}, yw]*G[{0, 1}, yu^(-1)]*G[{1, 1/(yu*yv)}, yw] + 
     2*G[{0}, yu^(-1)]*G[{0, 1}, yv^(-1)]*G[{1, 1/(yu*yv)}, yw] + 
     2*G[{0}, yv^(-1)]*G[{0, 1}, yv^(-1)]*G[{1, 1/(yu*yv)}, yw] - 
     2*G[{0}, yw]*G[{0, 1}, yv^(-1)]*G[{1, 1/(yu*yv)}, yw] - 
     2*G[{1}, yu^(-1)]*G[{0, 1}, yv^(-1)]*G[{1, 1/(yu*yv)}, yw] - 
     2*G[{1}, yv^(-1)]*G[{0, 1}, yv^(-1)]*G[{1, 1/(yu*yv)}, yw] - 
     4*G[{yu^(-1)}, yw]*G[{0, 1}, yv^(-1)]*G[{1, 1/(yu*yv)}, yw] - 
     6*G[{yu}, yv^(-1)]*G[{0, 1}, yv^(-1)]*G[{1, 1/(yu*yv)}, yw] + 
     4*G[{1/(yu*yv)}, yw]*G[{0, 1}, yv^(-1)]*G[{1, 1/(yu*yv)}, yw] - 
     2*G[{0}, yu^(-1)]*G[{0, 1}, yw]*G[{1, 1/(yu*yv)}, yw] - 
     2*G[{0}, yv^(-1)]*G[{0, 1}, yw]*G[{1, 1/(yu*yv)}, yw] + 
     2*G[{0}, yw]*G[{0, 1}, yw]*G[{1, 1/(yu*yv)}, yw] + 
     2*G[{1}, yu^(-1)]*G[{0, 1}, yw]*G[{1, 1/(yu*yv)}, yw] + 
     2*G[{1}, yv^(-1)]*G[{0, 1}, yw]*G[{1, 1/(yu*yv)}, yw] + 
     2*G[{0}, yu^(-1)]*G[{0, yu^(-1)}, yw]*G[{1, 1/(yu*yv)}, yw] + 
     2*G[{0}, yv^(-1)]*G[{0, yu^(-1)}, yw]*G[{1, 1/(yu*yv)}, yw] - 
     2*G[{0}, yw]*G[{0, yu^(-1)}, yw]*G[{1, 1/(yu*yv)}, yw] - 
     2*G[{1}, yu^(-1)]*G[{0, yu^(-1)}, yw]*G[{1, 1/(yu*yv)}, yw] - 
     2*G[{1}, yv^(-1)]*G[{0, yu^(-1)}, yw]*G[{1, 1/(yu*yv)}, yw] - 
     2*G[{0}, yu^(-1)]*G[{0, yu}, yv^(-1)]*G[{1, 1/(yu*yv)}, yw] - 
     2*G[{0}, yv^(-1)]*G[{0, yu}, yv^(-1)]*G[{1, 1/(yu*yv)}, yw] + 
     2*G[{0}, yw]*G[{0, yu}, yv^(-1)]*G[{1, 1/(yu*yv)}, yw] + 
     2*G[{1}, yu^(-1)]*G[{0, yu}, yv^(-1)]*G[{1, 1/(yu*yv)}, yw] + 
     2*G[{1}, yv^(-1)]*G[{0, yu}, yv^(-1)]*G[{1, 1/(yu*yv)}, yw] + 
     4*G[{yu^(-1)}, yw]*G[{0, yu}, yv^(-1)]*G[{1, 1/(yu*yv)}, yw] + 
     6*G[{yu}, yv^(-1)]*G[{0, yu}, yv^(-1)]*G[{1, 1/(yu*yv)}, yw] - 
     4*G[{1/(yu*yv)}, yw]*G[{0, yu}, yv^(-1)]*G[{1, 1/(yu*yv)}, yw] + 
     2*G[{0}, yu^(-1)]*G[{0, yv^(-1)}, yw]*G[{1, 1/(yu*yv)}, yw] + 
     2*G[{0}, yv^(-1)]*G[{0, yv^(-1)}, yw]*G[{1, 1/(yu*yv)}, yw] - 
     2*G[{0}, yw]*G[{0, yv^(-1)}, yw]*G[{1, 1/(yu*yv)}, yw] - 
     2*G[{1}, yu^(-1)]*G[{0, yv^(-1)}, yw]*G[{1, 1/(yu*yv)}, yw] - 
     2*G[{1}, yv^(-1)]*G[{0, yv^(-1)}, yw]*G[{1, 1/(yu*yv)}, yw] - 
     2*G[{0}, yu^(-1)]*G[{0, 1/(yu*yv)}, yw]*G[{1, 1/(yu*yv)}, yw] - 
     2*G[{0}, yv^(-1)]*G[{0, 1/(yu*yv)}, yw]*G[{1, 1/(yu*yv)}, yw] + 
     2*G[{0}, yw]*G[{0, 1/(yu*yv)}, yw]*G[{1, 1/(yu*yv)}, yw] + 
     2*G[{1}, yu^(-1)]*G[{0, 1/(yu*yv)}, yw]*G[{1, 1/(yu*yv)}, yw] + 
     2*G[{1}, yv^(-1)]*G[{0, 1/(yu*yv)}, yw]*G[{1, 1/(yu*yv)}, yw] - 
     4*G[{yu^(-1)}, yw]*G[{1, yu^(-1)}, yw]*G[{1, 1/(yu*yv)}, yw] + 
     4*G[{1/(yu*yv)}, yw]*G[{1, yu^(-1)}, yw]*G[{1, 1/(yu*yv)}, yw] + 
     4*G[{0}, yu^(-1)]*G[{1, yu}, yv^(-1)]*G[{1, 1/(yu*yv)}, yw] + 
     4*G[{0}, yv^(-1)]*G[{1, yu}, yv^(-1)]*G[{1, 1/(yu*yv)}, yw] - 
     4*G[{0}, yw]*G[{1, yu}, yv^(-1)]*G[{1, 1/(yu*yv)}, yw] - 
     4*G[{1}, yu^(-1)]*G[{1, yu}, yv^(-1)]*G[{1, 1/(yu*yv)}, yw] - 
     4*G[{1}, yv^(-1)]*G[{1, yu}, yv^(-1)]*G[{1, 1/(yu*yv)}, yw] - 
     6*G[{yu}, yv^(-1)]*G[{1, yu}, yv^(-1)]*G[{1, 1/(yu*yv)}, yw] - 
     4*G[{0}, yu^(-1)]*G[{1, yv^(-1)}, yw]*G[{1, 1/(yu*yv)}, yw] - 
     4*G[{0}, yv^(-1)]*G[{1, yv^(-1)}, yw]*G[{1, 1/(yu*yv)}, yw] + 
     4*G[{0}, yw]*G[{1, yv^(-1)}, yw]*G[{1, 1/(yu*yv)}, yw] + 
     4*G[{1}, yu^(-1)]*G[{1, yv^(-1)}, yw]*G[{1, 1/(yu*yv)}, yw] + 
     4*G[{1}, yv^(-1)]*G[{1, yv^(-1)}, yw]*G[{1, 1/(yu*yv)}, yw] - 
     4*G[{yu^(-1)}, yw]*G[{1, yv^(-1)}, yw]*G[{1, 1/(yu*yv)}, yw] + 
     4*G[{1/(yu*yv)}, yw]*G[{1, yv^(-1)}, yw]*G[{1, 1/(yu*yv)}, yw] + 
     4*G[{yu^(-1)}, yw]*G[{1, 1/(yu*yv)}, yw]^2 - 4*G[{1/(yu*yv)}, yw]*
      G[{1, 1/(yu*yv)}, yw]^2 - (Pi^2*G[{0}, yu^(-1)]*G[{yu^(-1), 1/(yu*yv)}, 
        yw])/3 - (Pi^2*G[{0}, yv^(-1)]*G[{yu^(-1), 1/(yu*yv)}, yw])/3 + 
     (Pi^2*G[{0}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw])/3 + 
     (Pi^2*G[{1}, yu^(-1)]*G[{yu^(-1), 1/(yu*yv)}, yw])/3 + 
     (Pi^2*G[{1}, yv^(-1)]*G[{yu^(-1), 1/(yu*yv)}, yw])/3 - 
     2*G[{0}, yu^(-1)]*G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*
      G[{yu^(-1), 1/(yu*yv)}, yw] - 2*G[{0}, yv^(-1)]*G[{1}, yu^(-1)]*
      G[{1}, yv^(-1)]*G[{yu^(-1), 1/(yu*yv)}, yw] + 
     2*G[{0}, yw]*G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*G[{yu^(-1), 1/(yu*yv)}, 
       yw] + 2*G[{1}, yu^(-1)]^2*G[{1}, yv^(-1)]*G[{yu^(-1), 1/(yu*yv)}, 
       yw] + 2*G[{1}, yu^(-1)]*G[{1}, yv^(-1)]^2*G[{yu^(-1), 1/(yu*yv)}, 
       yw] - (Pi^2*G[{yu^(-1)}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw])/3 - 
     2*G[{0}, yu^(-1)]*G[{1}, yv^(-1)]*G[{yu^(-1)}, yw]*
      G[{yu^(-1), 1/(yu*yv)}, yw] - 2*G[{0}, yv^(-1)]*G[{1}, yv^(-1)]*
      G[{yu^(-1)}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw] + 
     2*G[{0}, yw]*G[{1}, yv^(-1)]*G[{yu^(-1)}, yw]*G[{yu^(-1), 1/(yu*yv)}, 
       yw] + 2*G[{1}, yv^(-1)]^2*G[{yu^(-1)}, yw]*G[{yu^(-1), 1/(yu*yv)}, 
       yw] - G[{1}, yv^(-1)]*G[{yu^(-1)}, yw]^2*G[{yu^(-1), 1/(yu*yv)}, yw] - 
     G[{1}, yw]*G[{yu^(-1)}, yw]^2*G[{yu^(-1), 1/(yu*yv)}, yw] + 
     (G[{yu^(-1)}, yw]^3*G[{yu^(-1), 1/(yu*yv)}, yw])/3 + 
     2*G[{0}, yu^(-1)]*G[{1}, yu^(-1)]*G[{yu}, yv^(-1)]*
      G[{yu^(-1), 1/(yu*yv)}, yw] + 2*G[{0}, yv^(-1)]*G[{1}, yu^(-1)]*
      G[{yu}, yv^(-1)]*G[{yu^(-1), 1/(yu*yv)}, yw] - 
     2*G[{0}, yw]*G[{1}, yu^(-1)]*G[{yu}, yv^(-1)]*G[{yu^(-1), 1/(yu*yv)}, 
       yw] - 2*G[{1}, yu^(-1)]^2*G[{yu}, yv^(-1)]*G[{yu^(-1), 1/(yu*yv)}, 
       yw] - 2*G[{0}, yu^(-1)]*G[{1}, yv^(-1)]*G[{yu}, yv^(-1)]*
      G[{yu^(-1), 1/(yu*yv)}, yw] - 2*G[{0}, yv^(-1)]*G[{1}, yv^(-1)]*
      G[{yu}, yv^(-1)]*G[{yu^(-1), 1/(yu*yv)}, yw] + 
     2*G[{0}, yw]*G[{1}, yv^(-1)]*G[{yu}, yv^(-1)]*G[{yu^(-1), 1/(yu*yv)}, 
       yw] + 2*G[{1}, yv^(-1)]^2*G[{yu}, yv^(-1)]*G[{yu^(-1), 1/(yu*yv)}, 
       yw] + 2*G[{0}, yu^(-1)]*G[{yu^(-1)}, yw]*G[{yu}, yv^(-1)]*
      G[{yu^(-1), 1/(yu*yv)}, yw] + 2*G[{0}, yv^(-1)]*G[{yu^(-1)}, yw]*
      G[{yu}, yv^(-1)]*G[{yu^(-1), 1/(yu*yv)}, yw] - 
     2*G[{0}, yw]*G[{yu^(-1)}, yw]*G[{yu}, yv^(-1)]*G[{yu^(-1), 1/(yu*yv)}, 
       yw] - 2*G[{1}, yv^(-1)]*G[{yu^(-1)}, yw]*G[{yu}, yv^(-1)]*
      G[{yu^(-1), 1/(yu*yv)}, yw] + G[{yu^(-1)}, yw]^2*G[{yu}, yv^(-1)]*
      G[{yu^(-1), 1/(yu*yv)}, yw] + G[{1}, yv^(-1)]*G[{yu}, yv^(-1)]^2*
      G[{yu^(-1), 1/(yu*yv)}, yw] - G[{yu^(-1)}, yw]*G[{yu}, yv^(-1)]^2*
      G[{yu^(-1), 1/(yu*yv)}, yw] - 
     (G[{yu}, yv^(-1)]^3*G[{yu^(-1), 1/(yu*yv)}, yw])/3 + 
     (Pi^2*G[{1/(yu*yv)}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw])/3 - 
     2*G[{0}, yu^(-1)]^2*G[{1/(yu*yv)}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw] - 
     4*G[{0}, yu^(-1)]*G[{0}, yv^(-1)]*G[{1/(yu*yv)}, yw]*
      G[{yu^(-1), 1/(yu*yv)}, yw] - 2*G[{0}, yv^(-1)]^2*G[{1/(yu*yv)}, yw]*
      G[{yu^(-1), 1/(yu*yv)}, yw] + 4*G[{0}, yu^(-1)]*G[{0}, yw]*
      G[{1/(yu*yv)}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw] + 
     4*G[{0}, yv^(-1)]*G[{0}, yw]*G[{1/(yu*yv)}, yw]*
      G[{yu^(-1), 1/(yu*yv)}, yw] - 2*G[{0}, yw]^2*G[{1/(yu*yv)}, yw]*
      G[{yu^(-1), 1/(yu*yv)}, yw] + 2*G[{1}, yu^(-1)]^2*G[{1/(yu*yv)}, yw]*
      G[{yu^(-1), 1/(yu*yv)}, yw] + 6*G[{0}, yu^(-1)]*G[{1}, yv^(-1)]*
      G[{1/(yu*yv)}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw] + 
     6*G[{0}, yv^(-1)]*G[{1}, yv^(-1)]*G[{1/(yu*yv)}, yw]*
      G[{yu^(-1), 1/(yu*yv)}, yw] - 6*G[{0}, yw]*G[{1}, yv^(-1)]*
      G[{1/(yu*yv)}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw] - 
     4*G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*G[{1/(yu*yv)}, yw]*
      G[{yu^(-1), 1/(yu*yv)}, yw] - 4*G[{1}, yv^(-1)]^2*G[{1/(yu*yv)}, yw]*
      G[{yu^(-1), 1/(yu*yv)}, yw] - 4*G[{0}, yu^(-1)]*G[{1}, yw]*
      G[{1/(yu*yv)}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw] - 
     4*G[{0}, yv^(-1)]*G[{1}, yw]*G[{1/(yu*yv)}, yw]*
      G[{yu^(-1), 1/(yu*yv)}, yw] + 4*G[{0}, yw]*G[{1}, yw]*
      G[{1/(yu*yv)}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw] + 
     4*G[{1}, yu^(-1)]*G[{1}, yw]*G[{1/(yu*yv)}, yw]*
      G[{yu^(-1), 1/(yu*yv)}, yw] + 4*G[{1}, yv^(-1)]*G[{1}, yw]*
      G[{1/(yu*yv)}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw] - 
     4*G[{0}, yu^(-1)]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*
      G[{yu^(-1), 1/(yu*yv)}, yw] - 4*G[{0}, yv^(-1)]*G[{yu^(-1)}, yw]*
      G[{1/(yu*yv)}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw] + 
     4*G[{0}, yw]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*
      G[{yu^(-1), 1/(yu*yv)}, yw] + 4*G[{1}, yv^(-1)]*G[{yu^(-1)}, yw]*
      G[{1/(yu*yv)}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw] - 
     4*G[{1}, yw]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*
      G[{yu^(-1), 1/(yu*yv)}, yw] - 2*G[{yu^(-1)}, yw]^2*G[{1/(yu*yv)}, yw]*
      G[{yu^(-1), 1/(yu*yv)}, yw] + 2*G[{0}, yu^(-1)]*G[{yu}, yv^(-1)]*
      G[{1/(yu*yv)}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw] + 
     2*G[{0}, yv^(-1)]*G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw]*
      G[{yu^(-1), 1/(yu*yv)}, yw] - 2*G[{0}, yw]*G[{yu}, yv^(-1)]*
      G[{1/(yu*yv)}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw] - 
     4*G[{1}, yv^(-1)]*G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw]*
      G[{yu^(-1), 1/(yu*yv)}, yw] + 4*G[{yu^(-1)}, yw]*G[{yu}, yv^(-1)]*
      G[{1/(yu*yv)}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw] - 
     2*G[{0}, yu^(-1)]*G[{1/(yu*yv)}, yw]^2*G[{yu^(-1), 1/(yu*yv)}, yw] - 
     2*G[{0}, yv^(-1)]*G[{1/(yu*yv)}, yw]^2*G[{yu^(-1), 1/(yu*yv)}, yw] + 
     2*G[{0}, yw]*G[{1/(yu*yv)}, yw]^2*G[{yu^(-1), 1/(yu*yv)}, yw] - 
     2*G[{1}, yu^(-1)]*G[{1/(yu*yv)}, yw]^2*G[{yu^(-1), 1/(yu*yv)}, yw] + 
     3*G[{1}, yv^(-1)]*G[{1/(yu*yv)}, yw]^2*G[{yu^(-1), 1/(yu*yv)}, yw] - 
     3*G[{1}, yw]*G[{1/(yu*yv)}, yw]^2*G[{yu^(-1), 1/(yu*yv)}, yw] - 
     3*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2*G[{yu^(-1), 1/(yu*yv)}, yw] + 
     3*G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw]^2*G[{yu^(-1), 1/(yu*yv)}, yw] - 
     2*G[{0}, yu^(-1)]*G[{0, 1}, yu^(-1)]*G[{yu^(-1), 1/(yu*yv)}, yw] - 
     2*G[{0}, yv^(-1)]*G[{0, 1}, yu^(-1)]*G[{yu^(-1), 1/(yu*yv)}, yw] + 
     2*G[{0}, yw]*G[{0, 1}, yu^(-1)]*G[{yu^(-1), 1/(yu*yv)}, yw] + 
     2*G[{1}, yu^(-1)]*G[{0, 1}, yu^(-1)]*G[{yu^(-1), 1/(yu*yv)}, yw] + 
     2*G[{1}, yv^(-1)]*G[{0, 1}, yu^(-1)]*G[{yu^(-1), 1/(yu*yv)}, yw] - 
     2*G[{yu^(-1)}, yw]*G[{0, 1}, yu^(-1)]*G[{yu^(-1), 1/(yu*yv)}, yw] - 
     2*G[{1/(yu*yv)}, yw]*G[{0, 1}, yu^(-1)]*G[{yu^(-1), 1/(yu*yv)}, yw] + 
     2*G[{0}, yu^(-1)]*G[{0, 1}, yv^(-1)]*G[{yu^(-1), 1/(yu*yv)}, yw] + 
     2*G[{0}, yv^(-1)]*G[{0, 1}, yv^(-1)]*G[{yu^(-1), 1/(yu*yv)}, yw] - 
     2*G[{0}, yw]*G[{0, 1}, yv^(-1)]*G[{yu^(-1), 1/(yu*yv)}, yw] - 
     2*G[{1}, yu^(-1)]*G[{0, 1}, yv^(-1)]*G[{yu^(-1), 1/(yu*yv)}, yw] - 
     2*G[{1}, yv^(-1)]*G[{0, 1}, yv^(-1)]*G[{yu^(-1), 1/(yu*yv)}, yw] - 
     2*G[{yu}, yv^(-1)]*G[{0, 1}, yv^(-1)]*G[{yu^(-1), 1/(yu*yv)}, yw] + 
     2*G[{1/(yu*yv)}, yw]*G[{0, 1}, yv^(-1)]*G[{yu^(-1), 1/(yu*yv)}, yw] - 
     2*G[{0}, yu^(-1)]*G[{0, 1}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw] - 
     2*G[{0}, yv^(-1)]*G[{0, 1}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw] + 
     2*G[{0}, yw]*G[{0, 1}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw] + 
     2*G[{1}, yu^(-1)]*G[{0, 1}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw] + 
     2*G[{1}, yv^(-1)]*G[{0, 1}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw] + 
     2*G[{yu^(-1)}, yw]*G[{0, 1}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw] - 
     2*G[{1/(yu*yv)}, yw]*G[{0, 1}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw] + 
     2*G[{0}, yu^(-1)]*G[{0, yu^(-1)}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw] + 
     2*G[{0}, yv^(-1)]*G[{0, yu^(-1)}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw] - 
     2*G[{0}, yw]*G[{0, yu^(-1)}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw] - 
     2*G[{1}, yu^(-1)]*G[{0, yu^(-1)}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw] - 
     2*G[{1}, yv^(-1)]*G[{0, yu^(-1)}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw] - 
     2*G[{yu^(-1)}, yw]*G[{0, yu^(-1)}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw] + 
     2*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1)}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw] - 
     2*G[{0}, yu^(-1)]*G[{0, yu}, yv^(-1)]*G[{yu^(-1), 1/(yu*yv)}, yw] - 
     2*G[{0}, yv^(-1)]*G[{0, yu}, yv^(-1)]*G[{yu^(-1), 1/(yu*yv)}, yw] + 
     2*G[{0}, yw]*G[{0, yu}, yv^(-1)]*G[{yu^(-1), 1/(yu*yv)}, yw] + 
     2*G[{1}, yu^(-1)]*G[{0, yu}, yv^(-1)]*G[{yu^(-1), 1/(yu*yv)}, yw] + 
     2*G[{1}, yv^(-1)]*G[{0, yu}, yv^(-1)]*G[{yu^(-1), 1/(yu*yv)}, yw] + 
     2*G[{yu}, yv^(-1)]*G[{0, yu}, yv^(-1)]*G[{yu^(-1), 1/(yu*yv)}, yw] - 
     2*G[{1/(yu*yv)}, yw]*G[{0, yu}, yv^(-1)]*G[{yu^(-1), 1/(yu*yv)}, yw] + 
     2*G[{0}, yu^(-1)]*G[{0, yv^(-1)}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw] + 
     2*G[{0}, yv^(-1)]*G[{0, yv^(-1)}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw] - 
     2*G[{0}, yw]*G[{0, yv^(-1)}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw] - 
     2*G[{1}, yu^(-1)]*G[{0, yv^(-1)}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw] - 
     2*G[{1}, yv^(-1)]*G[{0, yv^(-1)}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw] - 
     2*G[{yu^(-1)}, yw]*G[{0, yv^(-1)}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw] + 
     2*G[{1/(yu*yv)}, yw]*G[{0, yv^(-1)}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw] - 
     2*G[{0}, yu^(-1)]*G[{0, 1/(yu*yv)}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw] - 
     2*G[{0}, yv^(-1)]*G[{0, 1/(yu*yv)}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw] + 
     2*G[{0}, yw]*G[{0, 1/(yu*yv)}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw] + 
     2*G[{1}, yu^(-1)]*G[{0, 1/(yu*yv)}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw] + 
     2*G[{1}, yv^(-1)]*G[{0, 1/(yu*yv)}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw] + 
     2*G[{yu^(-1)}, yw]*G[{0, 1/(yu*yv)}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw] - 
     2*G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv)}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw] + 
     2*G[{yu^(-1)}, yw]*G[{1, yu^(-1)}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw] + 
     4*G[{0}, yu^(-1)]*G[{1, yu}, yv^(-1)]*G[{yu^(-1), 1/(yu*yv)}, yw] + 
     4*G[{0}, yv^(-1)]*G[{1, yu}, yv^(-1)]*G[{yu^(-1), 1/(yu*yv)}, yw] - 
     4*G[{0}, yw]*G[{1, yu}, yv^(-1)]*G[{yu^(-1), 1/(yu*yv)}, yw] - 
     4*G[{1}, yu^(-1)]*G[{1, yu}, yv^(-1)]*G[{yu^(-1), 1/(yu*yv)}, yw] - 
     4*G[{1}, yv^(-1)]*G[{1, yu}, yv^(-1)]*G[{yu^(-1), 1/(yu*yv)}, yw] + 
     2*G[{yu^(-1)}, yw]*G[{1, yu}, yv^(-1)]*G[{yu^(-1), 1/(yu*yv)}, yw] - 
     2*G[{yu}, yv^(-1)]*G[{1, yu}, yv^(-1)]*G[{yu^(-1), 1/(yu*yv)}, yw] + 
     4*G[{1/(yu*yv)}, yw]*G[{1, yu}, yv^(-1)]*G[{yu^(-1), 1/(yu*yv)}, yw] - 
     4*G[{0}, yu^(-1)]*G[{1, yv^(-1)}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw] - 
     4*G[{0}, yv^(-1)]*G[{1, yv^(-1)}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw] + 
     4*G[{0}, yw]*G[{1, yv^(-1)}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw] + 
     4*G[{1}, yu^(-1)]*G[{1, yv^(-1)}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw] + 
     4*G[{1}, yv^(-1)]*G[{1, yv^(-1)}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw] - 
     4*G[{1/(yu*yv)}, yw]*G[{1, yv^(-1)}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw] + 
     2*G[{yu^(-1)}, yw]*G[{1, 1/(yu*yv)}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw] + 
     2*G[{0}, yu^(-1)]*G[{yu^(-1), 1/(yu*yv)}, yw]^2 + 
     2*G[{0}, yv^(-1)]*G[{yu^(-1), 1/(yu*yv)}, yw]^2 - 
     2*G[{0}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw]^2 - 
     2*G[{1}, yu^(-1)]*G[{yu^(-1), 1/(yu*yv)}, yw]^2 - 
     2*G[{1}, yv^(-1)]*G[{yu^(-1), 1/(yu*yv)}, yw]^2 + 
     2*G[{yu^(-1)}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw]^2 + 
     2*G[{1/(yu*yv)}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw]^2 + 
     (Pi^2*G[{1/(yu*yv)}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw])/3 - 
     2*G[{0}, yu^(-1)]*G[{1}, yu^(-1)]*G[{1/(yu*yv)}, yw]*
      G[{yv^(-1), 1/(yu*yv)}, yw] - 2*G[{0}, yv^(-1)]*G[{1}, yu^(-1)]*
      G[{1/(yu*yv)}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw] + 
     2*G[{0}, yw]*G[{1}, yu^(-1)]*G[{1/(yu*yv)}, yw]*
      G[{yv^(-1), 1/(yu*yv)}, yw] + 2*G[{1}, yu^(-1)]^2*G[{1/(yu*yv)}, yw]*
      G[{yv^(-1), 1/(yu*yv)}, yw] + 4*G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*
      G[{1/(yu*yv)}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw] - 
     4*G[{0}, yu^(-1)]*G[{1}, yw]*G[{1/(yu*yv)}, yw]*
      G[{yv^(-1), 1/(yu*yv)}, yw] - 4*G[{0}, yv^(-1)]*G[{1}, yw]*
      G[{1/(yu*yv)}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw] + 
     4*G[{0}, yw]*G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw] + 
     4*G[{1}, yu^(-1)]*G[{1}, yw]*G[{1/(yu*yv)}, yw]*
      G[{yv^(-1), 1/(yu*yv)}, yw] + 4*G[{1}, yv^(-1)]*G[{1}, yw]*
      G[{1/(yu*yv)}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw] + 
     2*G[{0}, yu^(-1)]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*
      G[{yv^(-1), 1/(yu*yv)}, yw] + 2*G[{0}, yv^(-1)]*G[{yu^(-1)}, yw]*
      G[{1/(yu*yv)}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw] - 
     2*G[{0}, yw]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*
      G[{yv^(-1), 1/(yu*yv)}, yw] - 4*G[{1}, yu^(-1)]*G[{yu^(-1)}, yw]*
      G[{1/(yu*yv)}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw] + 
     2*G[{0}, yu^(-1)]*G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw]*
      G[{yv^(-1), 1/(yu*yv)}, yw] + 2*G[{0}, yv^(-1)]*G[{yu}, yv^(-1)]*
      G[{1/(yu*yv)}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw] - 
     2*G[{0}, yw]*G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw]*
      G[{yv^(-1), 1/(yu*yv)}, yw] - 4*G[{1}, yu^(-1)]*G[{yu}, yv^(-1)]*
      G[{1/(yu*yv)}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw] + 
     4*G[{0}, yu^(-1)]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*
      G[{yv^(-1), 1/(yu*yv)}, yw] + 4*G[{0}, yv^(-1)]*G[{yv^(-1)}, yw]*
      G[{1/(yu*yv)}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw] - 
     4*G[{0}, yw]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*
      G[{yv^(-1), 1/(yu*yv)}, yw] - 8*G[{1}, yu^(-1)]*G[{yv^(-1)}, yw]*
      G[{1/(yu*yv)}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw] - 
     4*G[{1}, yv^(-1)]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*
      G[{yv^(-1), 1/(yu*yv)}, yw] - 4*G[{1}, yw]*G[{yv^(-1)}, yw]*
      G[{1/(yu*yv)}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw] + 
     4*G[{yu^(-1)}, yw]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*
      G[{yv^(-1), 1/(yu*yv)}, yw] + 4*G[{yu}, yv^(-1)]*G[{yv^(-1)}, yw]*
      G[{1/(yu*yv)}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw] + 
     4*G[{yv^(-1)}, yw]^2*G[{1/(yu*yv)}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw] - 
     2*G[{1}, yv^(-1)]*G[{1/(yu*yv)}, yw]^2*G[{yv^(-1), 1/(yu*yv)}, yw] - 
     2*G[{1}, yw]*G[{1/(yu*yv)}, yw]^2*G[{yv^(-1), 1/(yu*yv)}, yw] + 
     2*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2*G[{yv^(-1), 1/(yu*yv)}, yw] + 
     2*G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw]^2*G[{yv^(-1), 1/(yu*yv)}, yw] + 
     2*G[{1/(yu*yv)}, yw]*G[{0, 1}, yu^(-1)]*G[{yv^(-1), 1/(yu*yv)}, yw] - 
     2*G[{1/(yu*yv)}, yw]*G[{0, 1}, yv^(-1)]*G[{yv^(-1), 1/(yu*yv)}, yw] - 
     2*G[{1/(yu*yv)}, yw]*G[{0, 1}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw] + 
     2*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1)}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw] + 
     2*G[{1/(yu*yv)}, yw]*G[{0, yu}, yv^(-1)]*G[{yv^(-1), 1/(yu*yv)}, yw] + 
     2*G[{1/(yu*yv)}, yw]*G[{0, yv^(-1)}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw] - 
     2*G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv)}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw] - 
     4*G[{1/(yu*yv)}, yw]*G[{1, yu^(-1)}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw] - 
     4*G[{1/(yu*yv)}, yw]*G[{1, yu}, yv^(-1)]*G[{yv^(-1), 1/(yu*yv)}, yw] + 
     2*G[{1/(yu*yv)}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw]^2 + 
     (2*Pi^2*G[{0, 0, 1}, yv^(-1)])/3 - 2*G[{0}, yu^(-1)]^2*
      G[{0, 0, 1}, yv^(-1)] - 4*G[{0}, yu^(-1)]*G[{0}, yv^(-1)]*
      G[{0, 0, 1}, yv^(-1)] - 2*G[{0}, yv^(-1)]^2*G[{0, 0, 1}, yv^(-1)] + 
     4*G[{0}, yu^(-1)]*G[{0}, yw]*G[{0, 0, 1}, yv^(-1)] + 
     4*G[{0}, yv^(-1)]*G[{0}, yw]*G[{0, 0, 1}, yv^(-1)] - 
     2*G[{0}, yw]^2*G[{0, 0, 1}, yv^(-1)] + 2*G[{1}, yu^(-1)]^2*
      G[{0, 0, 1}, yv^(-1)] - 2*G[{1}, yv^(-1)]*G[{yu^(-1)}, yw]*
      G[{0, 0, 1}, yv^(-1)] - 2*G[{1}, yw]*G[{yu^(-1)}, yw]*
      G[{0, 0, 1}, yv^(-1)] + G[{yu^(-1)}, yw]^2*G[{0, 0, 1}, yv^(-1)] + 
     4*G[{0}, yu^(-1)]*G[{yu}, yv^(-1)]*G[{0, 0, 1}, yv^(-1)] + 
     4*G[{0}, yv^(-1)]*G[{yu}, yv^(-1)]*G[{0, 0, 1}, yv^(-1)] - 
     4*G[{0}, yw]*G[{yu}, yv^(-1)]*G[{0, 0, 1}, yv^(-1)] - 
     2*G[{1}, yv^(-1)]*G[{yu}, yv^(-1)]*G[{0, 0, 1}, yv^(-1)] + 
     2*G[{yu^(-1)}, yw]*G[{yu}, yv^(-1)]*G[{0, 0, 1}, yv^(-1)] - 
     3*G[{yu}, yv^(-1)]^2*G[{0, 0, 1}, yv^(-1)] - 
     4*G[{0}, yu^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, 0, 1}, yv^(-1)] - 
     4*G[{0}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, 0, 1}, yv^(-1)] + 
     4*G[{0}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 0, 1}, yv^(-1)] + 
     2*G[{1}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, 0, 1}, yv^(-1)] - 
     6*G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 0, 1}, yv^(-1)] - 
     2*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 0, 1}, yv^(-1)] + 
     6*G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, 0, 1}, yv^(-1)] + 
     2*G[{0, 1}, yv^(-1)]*G[{0, 0, 1}, yv^(-1)] + 
     4*G[{0, 1}, yw]*G[{0, 0, 1}, yv^(-1)] + 2*G[{0, yu}, yv^(-1)]*
      G[{0, 0, 1}, yv^(-1)] - 4*G[{0, 1/(yu*yv)}, yw]*G[{0, 0, 1}, yv^(-1)] + 
     2*G[{1, yu^(-1)}, yw]*G[{0, 0, 1}, yv^(-1)] + 2*G[{1, yu}, yv^(-1)]*
      G[{0, 0, 1}, yv^(-1)] + 6*G[{1, 1/(yu*yv)}, yw]*G[{0, 0, 1}, yv^(-1)] + 
     2*G[{yu^(-1), 1/(yu*yv)}, yw]*G[{0, 0, 1}, yv^(-1)] - 
     4*G[{1}, yw]*G[{yu^(-1)}, yw]*G[{0, 0, 1}, yw] + 
     4*G[{1}, yu^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, 0, 1}, yw] + 
     4*G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 0, 1}, yw] + 
     4*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 0, 1}, yw] - 
     4*G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, 0, 1}, yw] - 
     2*G[{1/(yu*yv)}, yw]^2*G[{0, 0, 1}, yw] - 4*G[{0, yu^(-1)}, yw]*
      G[{0, 0, 1}, yw] + 4*G[{0, 1/(yu*yv)}, yw]*G[{0, 0, 1}, yw] + 
     4*G[{1, yu^(-1)}, yw]*G[{0, 0, 1}, yw] - 4*G[{1, 1/(yu*yv)}, yw]*
      G[{0, 0, 1}, yw] - 4*G[{yu^(-1), 1/(yu*yv)}, yw]*G[{0, 0, 1}, yw] - 
     (2*Pi^2*G[{0, 0, yu^(-1)}, yw])/3 - 4*G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*
      G[{0, 0, yu^(-1)}, yw] - 4*G[{1}, yv^(-1)]*G[{yu^(-1)}, yw]*
      G[{0, 0, yu^(-1)}, yw] + 4*G[{1}, yw]*G[{yu^(-1)}, yw]*
      G[{0, 0, yu^(-1)}, yw] + 4*G[{1}, yu^(-1)]*G[{yu}, yv^(-1)]*
      G[{0, 0, yu^(-1)}, yw] - 4*G[{1}, yv^(-1)]*G[{yu}, yv^(-1)]*
      G[{0, 0, yu^(-1)}, yw] + 4*G[{yu^(-1)}, yw]*G[{yu}, yv^(-1)]*
      G[{0, 0, yu^(-1)}, yw] - 4*G[{1}, yu^(-1)]*G[{1/(yu*yv)}, yw]*
      G[{0, 0, yu^(-1)}, yw] + 4*G[{1}, yv^(-1)]*G[{1/(yu*yv)}, yw]*
      G[{0, 0, yu^(-1)}, yw] - 4*G[{1}, yw]*G[{1/(yu*yv)}, yw]*
      G[{0, 0, yu^(-1)}, yw] - 4*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*
      G[{0, 0, yu^(-1)}, yw] + 2*G[{1/(yu*yv)}, yw]^2*
      G[{0, 0, yu^(-1)}, yw] - 4*G[{0, 1}, yu^(-1)]*G[{0, 0, yu^(-1)}, yw] + 
     4*G[{0, 1}, yv^(-1)]*G[{0, 0, yu^(-1)}, yw] + 4*G[{0, yu^(-1)}, yw]*
      G[{0, 0, yu^(-1)}, yw] - 4*G[{0, yu}, yv^(-1)]*G[{0, 0, yu^(-1)}, yw] - 
     4*G[{0, 1/(yu*yv)}, yw]*G[{0, 0, yu^(-1)}, yw] - 
     4*G[{1, yu^(-1)}, yw]*G[{0, 0, yu^(-1)}, yw] + 
     8*G[{1, yu}, yv^(-1)]*G[{0, 0, yu^(-1)}, yw] + 
     4*G[{1, 1/(yu*yv)}, yw]*G[{0, 0, yu^(-1)}, yw] + 
     4*G[{yu^(-1), 1/(yu*yv)}, yw]*G[{0, 0, yu^(-1)}, yw] + 
     2*G[{0}, yu^(-1)]^2*G[{0, 0, yu}, yv^(-1)] + 
     4*G[{0}, yu^(-1)]*G[{0}, yv^(-1)]*G[{0, 0, yu}, yv^(-1)] + 
     2*G[{0}, yv^(-1)]^2*G[{0, 0, yu}, yv^(-1)] - 
     4*G[{0}, yu^(-1)]*G[{0}, yw]*G[{0, 0, yu}, yv^(-1)] - 
     4*G[{0}, yv^(-1)]*G[{0}, yw]*G[{0, 0, yu}, yv^(-1)] + 
     2*G[{0}, yw]^2*G[{0, 0, yu}, yv^(-1)] - 2*G[{1}, yu^(-1)]^2*
      G[{0, 0, yu}, yv^(-1)] + 2*G[{1}, yv^(-1)]*G[{yu^(-1)}, yw]*
      G[{0, 0, yu}, yv^(-1)] + 2*G[{1}, yw]*G[{yu^(-1)}, yw]*
      G[{0, 0, yu}, yv^(-1)] - G[{yu^(-1)}, yw]^2*G[{0, 0, yu}, yv^(-1)] - 
     4*G[{0}, yu^(-1)]*G[{yu}, yv^(-1)]*G[{0, 0, yu}, yv^(-1)] - 
     4*G[{0}, yv^(-1)]*G[{yu}, yv^(-1)]*G[{0, 0, yu}, yv^(-1)] + 
     4*G[{0}, yw]*G[{yu}, yv^(-1)]*G[{0, 0, yu}, yv^(-1)] + 
     2*G[{1}, yv^(-1)]*G[{yu}, yv^(-1)]*G[{0, 0, yu}, yv^(-1)] - 
     2*G[{yu^(-1)}, yw]*G[{yu}, yv^(-1)]*G[{0, 0, yu}, yv^(-1)] + 
     3*G[{yu}, yv^(-1)]^2*G[{0, 0, yu}, yv^(-1)] + 
     4*G[{0}, yu^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, 0, yu}, yv^(-1)] + 
     4*G[{0}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, 0, yu}, yv^(-1)] - 
     4*G[{0}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 0, yu}, yv^(-1)] - 
     2*G[{1}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, 0, yu}, yv^(-1)] + 
     6*G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 0, yu}, yv^(-1)] + 
     2*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 0, yu}, yv^(-1)] - 
     6*G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, 0, yu}, yv^(-1)] + 
     4*G[{0, 1}, yu^(-1)]*G[{0, 0, yu}, yv^(-1)] - 2*G[{0, 1}, yv^(-1)]*
      G[{0, 0, yu}, yv^(-1)] - 4*G[{0, 1}, yw]*G[{0, 0, yu}, yv^(-1)] - 
     2*G[{0, yu}, yv^(-1)]*G[{0, 0, yu}, yv^(-1)] + 
     4*G[{0, 1/(yu*yv)}, yw]*G[{0, 0, yu}, yv^(-1)] - 
     2*G[{1, yu^(-1)}, yw]*G[{0, 0, yu}, yv^(-1)] - 
     2*G[{1, yu}, yv^(-1)]*G[{0, 0, yu}, yv^(-1)] - 
     6*G[{1, 1/(yu*yv)}, yw]*G[{0, 0, yu}, yv^(-1)] - 
     2*G[{yu^(-1), 1/(yu*yv)}, yw]*G[{0, 0, yu}, yv^(-1)] - 
     4*G[{1}, yu^(-1)]*G[{yu^(-1)}, yw]*G[{0, 0, yv^(-1)}, yw] + 
     4*G[{1}, yw]*G[{yu^(-1)}, yw]*G[{0, 0, yv^(-1)}, yw] + 
     4*G[{yu^(-1)}, yw]*G[{yu}, yv^(-1)]*G[{0, 0, yv^(-1)}, yw] - 
     4*G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 0, yv^(-1)}, yw] - 
     4*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 0, yv^(-1)}, yw] + 
     2*G[{1/(yu*yv)}, yw]^2*G[{0, 0, yv^(-1)}, yw] + 
     4*G[{0, yu^(-1)}, yw]*G[{0, 0, yv^(-1)}, yw] - 
     4*G[{0, 1/(yu*yv)}, yw]*G[{0, 0, yv^(-1)}, yw] - 
     4*G[{1, yu^(-1)}, yw]*G[{0, 0, yv^(-1)}, yw] + 
     4*G[{1, 1/(yu*yv)}, yw]*G[{0, 0, yv^(-1)}, yw] + 
     4*G[{yu^(-1), 1/(yu*yv)}, yw]*G[{0, 0, yv^(-1)}, yw] + 
     (2*Pi^2*G[{0, 0, 1/(yu*yv)}, yw])/3 + 4*G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*
      G[{0, 0, 1/(yu*yv)}, yw] + 4*G[{1}, yu^(-1)]*G[{yu^(-1)}, yw]*
      G[{0, 0, 1/(yu*yv)}, yw] + 4*G[{1}, yv^(-1)]*G[{yu^(-1)}, yw]*
      G[{0, 0, 1/(yu*yv)}, yw] - 4*G[{1}, yw]*G[{yu^(-1)}, yw]*
      G[{0, 0, 1/(yu*yv)}, yw] - 4*G[{1}, yu^(-1)]*G[{yu}, yv^(-1)]*
      G[{0, 0, 1/(yu*yv)}, yw] + 4*G[{1}, yv^(-1)]*G[{yu}, yv^(-1)]*
      G[{0, 0, 1/(yu*yv)}, yw] - 8*G[{yu^(-1)}, yw]*G[{yu}, yv^(-1)]*
      G[{0, 0, 1/(yu*yv)}, yw] - 4*G[{1}, yv^(-1)]*G[{1/(yu*yv)}, yw]*
      G[{0, 0, 1/(yu*yv)}, yw] + 4*G[{1}, yw]*G[{1/(yu*yv)}, yw]*
      G[{0, 0, 1/(yu*yv)}, yw] + 4*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*
      G[{0, 0, 1/(yu*yv)}, yw] + 4*G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw]*
      G[{0, 0, 1/(yu*yv)}, yw] - 2*G[{1/(yu*yv)}, yw]^2*
      G[{0, 0, 1/(yu*yv)}, yw] + 4*G[{0, 1}, yu^(-1)]*
      G[{0, 0, 1/(yu*yv)}, yw] - 4*G[{0, 1}, yv^(-1)]*
      G[{0, 0, 1/(yu*yv)}, yw] - 4*G[{0, yu^(-1)}, yw]*
      G[{0, 0, 1/(yu*yv)}, yw] + 4*G[{0, yu}, yv^(-1)]*
      G[{0, 0, 1/(yu*yv)}, yw] + 4*G[{0, 1/(yu*yv)}, yw]*
      G[{0, 0, 1/(yu*yv)}, yw] + 4*G[{1, yu^(-1)}, yw]*
      G[{0, 0, 1/(yu*yv)}, yw] - 8*G[{1, yu}, yv^(-1)]*
      G[{0, 0, 1/(yu*yv)}, yw] - 4*G[{1, 1/(yu*yv)}, yw]*
      G[{0, 0, 1/(yu*yv)}, yw] - 4*G[{yu^(-1), 1/(yu*yv)}, yw]*
      G[{0, 0, 1/(yu*yv)}, yw] - (Pi^2*G[{0, 1, 1}, yu^(-1)])/3 + 
     4*G[{0}, yu^(-1)]*G[{1}, yu^(-1)]*G[{0, 1, 1}, yu^(-1)] + 
     4*G[{0}, yv^(-1)]*G[{1}, yu^(-1)]*G[{0, 1, 1}, yu^(-1)] - 
     4*G[{0}, yw]*G[{1}, yu^(-1)]*G[{0, 1, 1}, yu^(-1)] - 
     4*G[{0}, yu^(-1)]*G[{yu^(-1)}, yw]*G[{0, 1, 1}, yu^(-1)] - 
     4*G[{0}, yv^(-1)]*G[{yu^(-1)}, yw]*G[{0, 1, 1}, yu^(-1)] + 
     4*G[{0}, yw]*G[{yu^(-1)}, yw]*G[{0, 1, 1}, yu^(-1)] - 
     4*G[{1}, yu^(-1)]*G[{yu}, yv^(-1)]*G[{0, 1, 1}, yu^(-1)] + 
     4*G[{yu^(-1)}, yw]*G[{yu}, yv^(-1)]*G[{0, 1, 1}, yu^(-1)] + 
     4*G[{1}, yu^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, 1, 1}, yu^(-1)] - 
     4*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1, 1}, yu^(-1)] - 
     2*G[{0, 1}, yu^(-1)]*G[{0, 1, 1}, yu^(-1)] + 
     (Pi^2*G[{0, 1, 1}, yv^(-1)])/3 - 2*G[{0}, yu^(-1)]*G[{1}, yu^(-1)]*
      G[{0, 1, 1}, yv^(-1)] - 2*G[{0}, yv^(-1)]*G[{1}, yu^(-1)]*
      G[{0, 1, 1}, yv^(-1)] + 2*G[{0}, yw]*G[{1}, yu^(-1)]*
      G[{0, 1, 1}, yv^(-1)] + 2*G[{1}, yu^(-1)]^2*G[{0, 1, 1}, yv^(-1)] - 
     4*G[{0}, yu^(-1)]*G[{yu^(-1)}, yw]*G[{0, 1, 1}, yv^(-1)] - 
     4*G[{0}, yv^(-1)]*G[{yu^(-1)}, yw]*G[{0, 1, 1}, yv^(-1)] + 
     4*G[{0}, yw]*G[{yu^(-1)}, yw]*G[{0, 1, 1}, yv^(-1)] + 
     2*G[{1}, yu^(-1)]*G[{yu^(-1)}, yw]*G[{0, 1, 1}, yv^(-1)] - 
     2*G[{yu^(-1)}, yw]^2*G[{0, 1, 1}, yv^(-1)] - 
     4*G[{0}, yu^(-1)]*G[{yu}, yv^(-1)]*G[{0, 1, 1}, yv^(-1)] - 
     4*G[{0}, yv^(-1)]*G[{yu}, yv^(-1)]*G[{0, 1, 1}, yv^(-1)] + 
     4*G[{0}, yw]*G[{yu}, yv^(-1)]*G[{0, 1, 1}, yv^(-1)] + 
     2*G[{1}, yu^(-1)]*G[{yu}, yv^(-1)]*G[{0, 1, 1}, yv^(-1)] + 
     2*G[{yu}, yv^(-1)]^2*G[{0, 1, 1}, yv^(-1)] + 
     4*G[{0}, yu^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, 1, 1}, yv^(-1)] + 
     4*G[{0}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, 1, 1}, yv^(-1)] - 
     4*G[{0}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1, 1}, yv^(-1)] - 
     2*G[{1}, yu^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, 1, 1}, yv^(-1)] - 
     4*G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, 1, 1}, yv^(-1)] + 
     2*G[{1/(yu*yv)}, yw]^2*G[{0, 1, 1}, yv^(-1)] + 
     2*G[{0, 1}, yu^(-1)]*G[{0, 1, 1}, yv^(-1)] - 2*G[{0, 1}, yv^(-1)]*
      G[{0, 1, 1}, yv^(-1)] + 6*G[{0}, yu^(-1)]*G[{yu^(-1)}, yw]*
      G[{0, 1, 1}, yw] + 6*G[{0}, yv^(-1)]*G[{yu^(-1)}, yw]*
      G[{0, 1, 1}, yw] - 6*G[{0}, yw]*G[{yu^(-1)}, yw]*G[{0, 1, 1}, yw] - 
     6*G[{1}, yu^(-1)]*G[{yu^(-1)}, yw]*G[{0, 1, 1}, yw] - 
     6*G[{1}, yv^(-1)]*G[{yu^(-1)}, yw]*G[{0, 1, 1}, yw] - 
     2*G[{0}, yu^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, 1, 1}, yw] - 
     2*G[{0}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, 1, 1}, yw] + 
     2*G[{0}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1, 1}, yw] + 
     2*G[{1}, yu^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, 1, 1}, yw] + 
     2*G[{1}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, 1, 1}, yw] + 
     (2*Pi^2*G[{0, 1, yu^(-1)}, yw])/3 + 4*G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*
      G[{0, 1, yu^(-1)}, yw] - 4*G[{0}, yu^(-1)]*G[{yu^(-1)}, yw]*
      G[{0, 1, yu^(-1)}, yw] - 4*G[{0}, yv^(-1)]*G[{yu^(-1)}, yw]*
      G[{0, 1, yu^(-1)}, yw] + 4*G[{0}, yw]*G[{yu^(-1)}, yw]*
      G[{0, 1, yu^(-1)}, yw] + 4*G[{1}, yu^(-1)]*G[{yu^(-1)}, yw]*
      G[{0, 1, yu^(-1)}, yw] + 8*G[{1}, yv^(-1)]*G[{yu^(-1)}, yw]*
      G[{0, 1, yu^(-1)}, yw] - 4*G[{1}, yw]*G[{yu^(-1)}, yw]*
      G[{0, 1, yu^(-1)}, yw] - 4*G[{1}, yu^(-1)]*G[{yu}, yv^(-1)]*
      G[{0, 1, yu^(-1)}, yw] + 4*G[{1}, yv^(-1)]*G[{yu}, yv^(-1)]*
      G[{0, 1, yu^(-1)}, yw] - 4*G[{yu^(-1)}, yw]*G[{yu}, yv^(-1)]*
      G[{0, 1, yu^(-1)}, yw] + 4*G[{1}, yu^(-1)]*G[{1/(yu*yv)}, yw]*
      G[{0, 1, yu^(-1)}, yw] - 4*G[{1}, yv^(-1)]*G[{1/(yu*yv)}, yw]*
      G[{0, 1, yu^(-1)}, yw] + 4*G[{1}, yw]*G[{1/(yu*yv)}, yw]*
      G[{0, 1, yu^(-1)}, yw] + 4*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*
      G[{0, 1, yu^(-1)}, yw] - 2*G[{1/(yu*yv)}, yw]^2*
      G[{0, 1, yu^(-1)}, yw] + 4*G[{0, 1}, yu^(-1)]*G[{0, 1, yu^(-1)}, yw] - 
     4*G[{0, 1}, yv^(-1)]*G[{0, 1, yu^(-1)}, yw] - 
     4*G[{0, 1}, yw]*G[{0, 1, yu^(-1)}, yw] - 4*G[{0, yu^(-1)}, yw]*
      G[{0, 1, yu^(-1)}, yw] + 4*G[{0, yu}, yv^(-1)]*G[{0, 1, yu^(-1)}, yw] + 
     4*G[{0, 1/(yu*yv)}, yw]*G[{0, 1, yu^(-1)}, yw] + 
     4*G[{1, yu^(-1)}, yw]*G[{0, 1, yu^(-1)}, yw] - 
     8*G[{1, yu}, yv^(-1)]*G[{0, 1, yu^(-1)}, yw] - 
     4*G[{1, 1/(yu*yv)}, yw]*G[{0, 1, yu^(-1)}, yw] - 
     4*G[{yu^(-1), 1/(yu*yv)}, yw]*G[{0, 1, yu^(-1)}, yw] + 
     (Pi^2*G[{0, 1, yu}, yv^(-1)])/3 - 2*G[{0}, yu^(-1)]^2*
      G[{0, 1, yu}, yv^(-1)] - 4*G[{0}, yu^(-1)]*G[{0}, yv^(-1)]*
      G[{0, 1, yu}, yv^(-1)] - 2*G[{0}, yv^(-1)]^2*G[{0, 1, yu}, yv^(-1)] + 
     4*G[{0}, yu^(-1)]*G[{0}, yw]*G[{0, 1, yu}, yv^(-1)] + 
     4*G[{0}, yv^(-1)]*G[{0}, yw]*G[{0, 1, yu}, yv^(-1)] - 
     2*G[{0}, yw]^2*G[{0, 1, yu}, yv^(-1)] + 2*G[{0}, yu^(-1)]*
      G[{1}, yu^(-1)]*G[{0, 1, yu}, yv^(-1)] + 2*G[{0}, yv^(-1)]*
      G[{1}, yu^(-1)]*G[{0, 1, yu}, yv^(-1)] - 2*G[{0}, yw]*G[{1}, yu^(-1)]*
      G[{0, 1, yu}, yv^(-1)] + 2*G[{0}, yu^(-1)]*G[{yu^(-1)}, yw]*
      G[{0, 1, yu}, yv^(-1)] + 2*G[{0}, yv^(-1)]*G[{yu^(-1)}, yw]*
      G[{0, 1, yu}, yv^(-1)] - 2*G[{0}, yw]*G[{yu^(-1)}, yw]*
      G[{0, 1, yu}, yv^(-1)] - 2*G[{1}, yv^(-1)]*G[{yu^(-1)}, yw]*
      G[{0, 1, yu}, yv^(-1)] - 2*G[{1}, yw]*G[{yu^(-1)}, yw]*
      G[{0, 1, yu}, yv^(-1)] + 3*G[{yu^(-1)}, yw]^2*G[{0, 1, yu}, yv^(-1)] + 
     6*G[{0}, yu^(-1)]*G[{yu}, yv^(-1)]*G[{0, 1, yu}, yv^(-1)] + 
     6*G[{0}, yv^(-1)]*G[{yu}, yv^(-1)]*G[{0, 1, yu}, yv^(-1)] - 
     6*G[{0}, yw]*G[{yu}, yv^(-1)]*G[{0, 1, yu}, yv^(-1)] - 
     2*G[{1}, yv^(-1)]*G[{yu}, yv^(-1)]*G[{0, 1, yu}, yv^(-1)] + 
     2*G[{yu^(-1)}, yw]*G[{yu}, yv^(-1)]*G[{0, 1, yu}, yv^(-1)] - 
     5*G[{yu}, yv^(-1)]^2*G[{0, 1, yu}, yv^(-1)] - 
     6*G[{0}, yu^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, 1, yu}, yv^(-1)] - 
     6*G[{0}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, 1, yu}, yv^(-1)] + 
     6*G[{0}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1, yu}, yv^(-1)] + 
     2*G[{1}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, 1, yu}, yv^(-1)] - 
     6*G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1, yu}, yv^(-1)] - 
     2*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1, yu}, yv^(-1)] + 
     10*G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, 1, yu}, yv^(-1)] - 
     2*G[{1/(yu*yv)}, yw]^2*G[{0, 1, yu}, yv^(-1)] - 
     2*G[{0, 1}, yu^(-1)]*G[{0, 1, yu}, yv^(-1)] + 
     4*G[{0, 1}, yw]*G[{0, 1, yu}, yv^(-1)] + 2*G[{0, yu}, yv^(-1)]*
      G[{0, 1, yu}, yv^(-1)] - 4*G[{0, 1/(yu*yv)}, yw]*
      G[{0, 1, yu}, yv^(-1)] + 2*G[{1, yu^(-1)}, yw]*G[{0, 1, yu}, yv^(-1)] + 
     2*G[{1, yu}, yv^(-1)]*G[{0, 1, yu}, yv^(-1)] + 
     6*G[{1, 1/(yu*yv)}, yw]*G[{0, 1, yu}, yv^(-1)] + 
     2*G[{yu^(-1), 1/(yu*yv)}, yw]*G[{0, 1, yu}, yv^(-1)] - 
     4*G[{0}, yu^(-1)]*G[{yu^(-1)}, yw]*G[{0, 1, yv^(-1)}, yw] - 
     4*G[{0}, yv^(-1)]*G[{yu^(-1)}, yw]*G[{0, 1, yv^(-1)}, yw] + 
     4*G[{0}, yw]*G[{yu^(-1)}, yw]*G[{0, 1, yv^(-1)}, yw] + 
     8*G[{1}, yu^(-1)]*G[{yu^(-1)}, yw]*G[{0, 1, yv^(-1)}, yw] + 
     4*G[{1}, yv^(-1)]*G[{yu^(-1)}, yw]*G[{0, 1, yv^(-1)}, yw] - 
     4*G[{1}, yw]*G[{yu^(-1)}, yw]*G[{0, 1, yv^(-1)}, yw] - 
     4*G[{yu^(-1)}, yw]*G[{yu}, yv^(-1)]*G[{0, 1, yv^(-1)}, yw] + 
     4*G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1, yv^(-1)}, yw] + 
     4*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1, yv^(-1)}, yw] - 
     2*G[{1/(yu*yv)}, yw]^2*G[{0, 1, yv^(-1)}, yw] - 
     4*G[{0, yu^(-1)}, yw]*G[{0, 1, yv^(-1)}, yw] + 
     4*G[{0, 1/(yu*yv)}, yw]*G[{0, 1, yv^(-1)}, yw] + 
     4*G[{1, yu^(-1)}, yw]*G[{0, 1, yv^(-1)}, yw] - 
     4*G[{1, 1/(yu*yv)}, yw]*G[{0, 1, yv^(-1)}, yw] - 
     4*G[{yu^(-1), 1/(yu*yv)}, yw]*G[{0, 1, yv^(-1)}, yw] - 
     (Pi^2*G[{0, 1, 1/(yu*yv)}, yw])/3 - 2*G[{0}, yu^(-1)]*G[{1}, yu^(-1)]*
      G[{0, 1, 1/(yu*yv)}, yw] - 2*G[{0}, yv^(-1)]*G[{1}, yu^(-1)]*
      G[{0, 1, 1/(yu*yv)}, yw] + 2*G[{0}, yw]*G[{1}, yu^(-1)]*
      G[{0, 1, 1/(yu*yv)}, yw] + 2*G[{1}, yu^(-1)]^2*
      G[{0, 1, 1/(yu*yv)}, yw] + 4*G[{0}, yu^(-1)]*G[{yu^(-1)}, yw]*
      G[{0, 1, 1/(yu*yv)}, yw] + 4*G[{0}, yv^(-1)]*G[{yu^(-1)}, yw]*
      G[{0, 1, 1/(yu*yv)}, yw] - 4*G[{0}, yw]*G[{yu^(-1)}, yw]*
      G[{0, 1, 1/(yu*yv)}, yw] - 6*G[{1}, yu^(-1)]*G[{yu^(-1)}, yw]*
      G[{0, 1, 1/(yu*yv)}, yw] - 6*G[{1}, yv^(-1)]*G[{yu^(-1)}, yw]*
      G[{0, 1, 1/(yu*yv)}, yw] + 2*G[{0}, yu^(-1)]*G[{yu}, yv^(-1)]*
      G[{0, 1, 1/(yu*yv)}, yw] + 2*G[{0}, yv^(-1)]*G[{yu}, yv^(-1)]*
      G[{0, 1, 1/(yu*yv)}, yw] - 2*G[{0}, yw]*G[{yu}, yv^(-1)]*
      G[{0, 1, 1/(yu*yv)}, yw] - 4*G[{1}, yv^(-1)]*G[{yu}, yv^(-1)]*
      G[{0, 1, 1/(yu*yv)}, yw] + 4*G[{yu^(-1)}, yw]*G[{yu}, yv^(-1)]*
      G[{0, 1, 1/(yu*yv)}, yw] + 2*G[{1}, yu^(-1)]*G[{1/(yu*yv)}, yw]*
      G[{0, 1, 1/(yu*yv)}, yw] + 2*G[{1}, yv^(-1)]*G[{1/(yu*yv)}, yw]*
      G[{0, 1, 1/(yu*yv)}, yw] - 4*G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw]*
      G[{0, 1, 1/(yu*yv)}, yw] - 2*G[{0, 1}, yu^(-1)]*
      G[{0, 1, 1/(yu*yv)}, yw] + 2*G[{0, 1}, yv^(-1)]*
      G[{0, 1, 1/(yu*yv)}, yw] + 2*G[{0, 1}, yw]*G[{0, 1, 1/(yu*yv)}, yw] - 
     2*G[{0, yu}, yv^(-1)]*G[{0, 1, 1/(yu*yv)}, yw] + 
     4*G[{1, yu}, yv^(-1)]*G[{0, 1, 1/(yu*yv)}, yw] - 
     6*G[{0}, yu^(-1)]*G[{yu^(-1)}, yw]*G[{0, yu^(-1), 1}, yw] - 
     6*G[{0}, yv^(-1)]*G[{yu^(-1)}, yw]*G[{0, yu^(-1), 1}, yw] + 
     6*G[{0}, yw]*G[{yu^(-1)}, yw]*G[{0, yu^(-1), 1}, yw] + 
     6*G[{1}, yu^(-1)]*G[{yu^(-1)}, yw]*G[{0, yu^(-1), 1}, yw] + 
     6*G[{1}, yv^(-1)]*G[{yu^(-1)}, yw]*G[{0, yu^(-1), 1}, yw] + 
     2*G[{0}, yu^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1), 1}, yw] + 
     2*G[{0}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1), 1}, yw] - 
     2*G[{0}, yw]*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1), 1}, yw] - 
     2*G[{1}, yu^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1), 1}, yw] - 
     2*G[{1}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1), 1}, yw] - 
     (2*Pi^2*G[{0, yu^(-1), yu^(-1)}, yw])/3 - 4*G[{1}, yu^(-1)]*
      G[{1}, yv^(-1)]*G[{0, yu^(-1), yu^(-1)}, yw] + 
     4*G[{0}, yu^(-1)]*G[{yu^(-1)}, yw]*G[{0, yu^(-1), yu^(-1)}, yw] + 
     4*G[{0}, yv^(-1)]*G[{yu^(-1)}, yw]*G[{0, yu^(-1), yu^(-1)}, yw] - 
     4*G[{0}, yw]*G[{yu^(-1)}, yw]*G[{0, yu^(-1), yu^(-1)}, yw] - 
     4*G[{1}, yu^(-1)]*G[{yu^(-1)}, yw]*G[{0, yu^(-1), yu^(-1)}, yw] - 
     8*G[{1}, yv^(-1)]*G[{yu^(-1)}, yw]*G[{0, yu^(-1), yu^(-1)}, yw] + 
     4*G[{1}, yw]*G[{yu^(-1)}, yw]*G[{0, yu^(-1), yu^(-1)}, yw] + 
     4*G[{1}, yu^(-1)]*G[{yu}, yv^(-1)]*G[{0, yu^(-1), yu^(-1)}, yw] - 
     4*G[{1}, yv^(-1)]*G[{yu}, yv^(-1)]*G[{0, yu^(-1), yu^(-1)}, yw] + 
     4*G[{yu^(-1)}, yw]*G[{yu}, yv^(-1)]*G[{0, yu^(-1), yu^(-1)}, yw] - 
     4*G[{1}, yu^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1), yu^(-1)}, yw] + 
     4*G[{1}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1), yu^(-1)}, yw] - 
     4*G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1), yu^(-1)}, yw] - 
     4*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1), yu^(-1)}, yw] + 
     2*G[{1/(yu*yv)}, yw]^2*G[{0, yu^(-1), yu^(-1)}, yw] - 
     4*G[{0, 1}, yu^(-1)]*G[{0, yu^(-1), yu^(-1)}, yw] + 
     4*G[{0, 1}, yv^(-1)]*G[{0, yu^(-1), yu^(-1)}, yw] + 
     4*G[{0, 1}, yw]*G[{0, yu^(-1), yu^(-1)}, yw] - 
     4*G[{0, yu^(-1)}, yw]*G[{0, yu^(-1), yu^(-1)}, yw] - 
     4*G[{0, yu}, yv^(-1)]*G[{0, yu^(-1), yu^(-1)}, yw] - 
     4*G[{0, 1/(yu*yv)}, yw]*G[{0, yu^(-1), yu^(-1)}, yw] - 
     4*G[{1, yu^(-1)}, yw]*G[{0, yu^(-1), yu^(-1)}, yw] + 
     8*G[{1, yu}, yv^(-1)]*G[{0, yu^(-1), yu^(-1)}, yw] + 
     4*G[{1, 1/(yu*yv)}, yw]*G[{0, yu^(-1), yu^(-1)}, yw] + 
     4*G[{yu^(-1), 1/(yu*yv)}, yw]*G[{0, yu^(-1), yu^(-1)}, yw] - 
     (Pi^2*G[{0, yu^(-1), yv^(-1)}, yw])/3 + 2*G[{0}, yu^(-1)]*
      G[{1}, yu^(-1)]*G[{0, yu^(-1), yv^(-1)}, yw] + 
     2*G[{0}, yv^(-1)]*G[{1}, yu^(-1)]*G[{0, yu^(-1), yv^(-1)}, yw] - 
     2*G[{0}, yw]*G[{1}, yu^(-1)]*G[{0, yu^(-1), yv^(-1)}, yw] - 
     2*G[{1}, yu^(-1)]^2*G[{0, yu^(-1), yv^(-1)}, yw] - 
     4*G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*G[{0, yu^(-1), yv^(-1)}, yw] + 
     2*G[{0}, yu^(-1)]*G[{yu^(-1)}, yw]*G[{0, yu^(-1), yv^(-1)}, yw] + 
     2*G[{0}, yv^(-1)]*G[{yu^(-1)}, yw]*G[{0, yu^(-1), yv^(-1)}, yw] - 
     2*G[{0}, yw]*G[{yu^(-1)}, yw]*G[{0, yu^(-1), yv^(-1)}, yw] - 
     4*G[{1}, yu^(-1)]*G[{yu^(-1)}, yw]*G[{0, yu^(-1), yv^(-1)}, yw] - 
     4*G[{1}, yv^(-1)]*G[{yu^(-1)}, yw]*G[{0, yu^(-1), yv^(-1)}, yw] + 
     4*G[{1}, yw]*G[{yu^(-1)}, yw]*G[{0, yu^(-1), yv^(-1)}, yw] - 
     2*G[{0}, yu^(-1)]*G[{yu}, yv^(-1)]*G[{0, yu^(-1), yv^(-1)}, yw] - 
     2*G[{0}, yv^(-1)]*G[{yu}, yv^(-1)]*G[{0, yu^(-1), yv^(-1)}, yw] + 
     2*G[{0}, yw]*G[{yu}, yv^(-1)]*G[{0, yu^(-1), yv^(-1)}, yw] + 
     4*G[{1}, yu^(-1)]*G[{yu}, yv^(-1)]*G[{0, yu^(-1), yv^(-1)}, yw] + 
     4*G[{yu^(-1)}, yw]*G[{yu}, yv^(-1)]*G[{0, yu^(-1), yv^(-1)}, yw] + 
     2*G[{0}, yu^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1), yv^(-1)}, yw] + 
     2*G[{0}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1), yv^(-1)}, yw] - 
     2*G[{0}, yw]*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1), yv^(-1)}, yw] - 
     4*G[{1}, yu^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1), yv^(-1)}, yw] - 
     4*G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1), yv^(-1)}, yw] - 
     4*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1), yv^(-1)}, yw] + 
     2*G[{1/(yu*yv)}, yw]^2*G[{0, yu^(-1), yv^(-1)}, yw] - 
     2*G[{0, 1}, yu^(-1)]*G[{0, yu^(-1), yv^(-1)}, yw] + 
     2*G[{0, 1}, yv^(-1)]*G[{0, yu^(-1), yv^(-1)}, yw] + 
     2*G[{0, 1}, yw]*G[{0, yu^(-1), yv^(-1)}, yw] - 
     2*G[{0, yu^(-1)}, yw]*G[{0, yu^(-1), yv^(-1)}, yw] - 
     2*G[{0, yu}, yv^(-1)]*G[{0, yu^(-1), yv^(-1)}, yw] - 
     4*G[{0, 1/(yu*yv)}, yw]*G[{0, yu^(-1), yv^(-1)}, yw] - 
     4*G[{1, yu^(-1)}, yw]*G[{0, yu^(-1), yv^(-1)}, yw] + 
     4*G[{1, yu}, yv^(-1)]*G[{0, yu^(-1), yv^(-1)}, yw] + 
     4*G[{1, 1/(yu*yv)}, yw]*G[{0, yu^(-1), yv^(-1)}, yw] + 
     4*G[{yu^(-1), 1/(yu*yv)}, yw]*G[{0, yu^(-1), yv^(-1)}, yw] - 
     2*G[{0}, yu^(-1)]*G[{yu^(-1)}, yw]*G[{0, yu^(-1), 1/(yu*yv)}, yw] - 
     2*G[{0}, yv^(-1)]*G[{yu^(-1)}, yw]*G[{0, yu^(-1), 1/(yu*yv)}, yw] + 
     2*G[{0}, yw]*G[{yu^(-1)}, yw]*G[{0, yu^(-1), 1/(yu*yv)}, yw] + 
     2*G[{1}, yu^(-1)]*G[{yu^(-1)}, yw]*G[{0, yu^(-1), 1/(yu*yv)}, yw] + 
     2*G[{1}, yv^(-1)]*G[{yu^(-1)}, yw]*G[{0, yu^(-1), 1/(yu*yv)}, yw] - 
     2*G[{0}, yu^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1), 1/(yu*yv)}, yw] - 
     2*G[{0}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1), 1/(yu*yv)}, yw] + 
     2*G[{0}, yw]*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1), 1/(yu*yv)}, yw] + 
     2*G[{1}, yu^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1), 1/(yu*yv)}, yw] + 
     2*G[{1}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1), 1/(yu*yv)}, yw] + 
     6*G[{0, yv^(-1)}, yw]*G[{0, yu^(-1), 1/(yu*yv)}, yw] + 
     2*G[{0}, yu^(-1)]*G[{yu^(-1)}, yw]*G[{0, yu, 1}, yv^(-1)] + 
     2*G[{0}, yv^(-1)]*G[{yu^(-1)}, yw]*G[{0, yu, 1}, yv^(-1)] - 
     2*G[{0}, yw]*G[{yu^(-1)}, yw]*G[{0, yu, 1}, yv^(-1)] - 
     2*G[{1}, yu^(-1)]*G[{yu^(-1)}, yw]*G[{0, yu, 1}, yv^(-1)] + 
     2*G[{yu^(-1)}, yw]^2*G[{0, yu, 1}, yv^(-1)] + 
     2*G[{0}, yu^(-1)]*G[{yu}, yv^(-1)]*G[{0, yu, 1}, yv^(-1)] + 
     2*G[{0}, yv^(-1)]*G[{yu}, yv^(-1)]*G[{0, yu, 1}, yv^(-1)] - 
     2*G[{0}, yw]*G[{yu}, yv^(-1)]*G[{0, yu, 1}, yv^(-1)] - 
     2*G[{1}, yu^(-1)]*G[{yu}, yv^(-1)]*G[{0, yu, 1}, yv^(-1)] - 
     2*G[{yu}, yv^(-1)]^2*G[{0, yu, 1}, yv^(-1)] - 
     2*G[{0}, yu^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, yu, 1}, yv^(-1)] - 
     2*G[{0}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, yu, 1}, yv^(-1)] + 
     2*G[{0}, yw]*G[{1/(yu*yv)}, yw]*G[{0, yu, 1}, yv^(-1)] + 
     2*G[{1}, yu^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, yu, 1}, yv^(-1)] + 
     4*G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, yu, 1}, yv^(-1)] - 
     2*G[{1/(yu*yv)}, yw]^2*G[{0, yu, 1}, yv^(-1)] + 
     2*G[{0}, yu^(-1)]^2*G[{0, yu, yu}, yv^(-1)] + 
     4*G[{0}, yu^(-1)]*G[{0}, yv^(-1)]*G[{0, yu, yu}, yv^(-1)] + 
     2*G[{0}, yv^(-1)]^2*G[{0, yu, yu}, yv^(-1)] - 
     4*G[{0}, yu^(-1)]*G[{0}, yw]*G[{0, yu, yu}, yv^(-1)] - 
     4*G[{0}, yv^(-1)]*G[{0}, yw]*G[{0, yu, yu}, yv^(-1)] + 
     2*G[{0}, yw]^2*G[{0, yu, yu}, yv^(-1)] - 2*G[{1}, yu^(-1)]^2*
      G[{0, yu, yu}, yv^(-1)] + 2*G[{1}, yv^(-1)]*G[{yu^(-1)}, yw]*
      G[{0, yu, yu}, yv^(-1)] + 2*G[{1}, yw]*G[{yu^(-1)}, yw]*
      G[{0, yu, yu}, yv^(-1)] - 3*G[{yu^(-1)}, yw]^2*
      G[{0, yu, yu}, yv^(-1)] - 4*G[{0}, yu^(-1)]*G[{yu}, yv^(-1)]*
      G[{0, yu, yu}, yv^(-1)] - 4*G[{0}, yv^(-1)]*G[{yu}, yv^(-1)]*
      G[{0, yu, yu}, yv^(-1)] + 4*G[{0}, yw]*G[{yu}, yv^(-1)]*
      G[{0, yu, yu}, yv^(-1)] + 2*G[{1}, yv^(-1)]*G[{yu}, yv^(-1)]*
      G[{0, yu, yu}, yv^(-1)] - 2*G[{yu^(-1)}, yw]*G[{yu}, yv^(-1)]*
      G[{0, yu, yu}, yv^(-1)] + 5*G[{yu}, yv^(-1)]^2*
      G[{0, yu, yu}, yv^(-1)] + 4*G[{0}, yu^(-1)]*G[{1/(yu*yv)}, yw]*
      G[{0, yu, yu}, yv^(-1)] + 4*G[{0}, yv^(-1)]*G[{1/(yu*yv)}, yw]*
      G[{0, yu, yu}, yv^(-1)] - 4*G[{0}, yw]*G[{1/(yu*yv)}, yw]*
      G[{0, yu, yu}, yv^(-1)] - 2*G[{1}, yv^(-1)]*G[{1/(yu*yv)}, yw]*
      G[{0, yu, yu}, yv^(-1)] + 6*G[{1}, yw]*G[{1/(yu*yv)}, yw]*
      G[{0, yu, yu}, yv^(-1)] + 2*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*
      G[{0, yu, yu}, yv^(-1)] - 10*G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw]*
      G[{0, yu, yu}, yv^(-1)] + 2*G[{1/(yu*yv)}, yw]^2*
      G[{0, yu, yu}, yv^(-1)] + 4*G[{0, 1}, yu^(-1)]*
      G[{0, yu, yu}, yv^(-1)] - 2*G[{0, 1}, yv^(-1)]*
      G[{0, yu, yu}, yv^(-1)] - 4*G[{0, 1}, yw]*G[{0, yu, yu}, yv^(-1)] + 
     2*G[{0, yu}, yv^(-1)]*G[{0, yu, yu}, yv^(-1)] + 
     4*G[{0, 1/(yu*yv)}, yw]*G[{0, yu, yu}, yv^(-1)] - 
     2*G[{1, yu^(-1)}, yw]*G[{0, yu, yu}, yv^(-1)] - 
     2*G[{1, yu}, yv^(-1)]*G[{0, yu, yu}, yv^(-1)] - 
     6*G[{1, 1/(yu*yv)}, yw]*G[{0, yu, yu}, yv^(-1)] - 
     2*G[{yu^(-1), 1/(yu*yv)}, yw]*G[{0, yu, yu}, yv^(-1)] - 
     6*G[{0}, yu^(-1)]*G[{yu^(-1)}, yw]*G[{0, yv^(-1), 1}, yw] - 
     6*G[{0}, yv^(-1)]*G[{yu^(-1)}, yw]*G[{0, yv^(-1), 1}, yw] + 
     6*G[{0}, yw]*G[{yu^(-1)}, yw]*G[{0, yv^(-1), 1}, yw] + 
     6*G[{1}, yu^(-1)]*G[{yu^(-1)}, yw]*G[{0, yv^(-1), 1}, yw] + 
     6*G[{1}, yv^(-1)]*G[{yu^(-1)}, yw]*G[{0, yv^(-1), 1}, yw] + 
     2*G[{0}, yu^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, yv^(-1), 1}, yw] + 
     2*G[{0}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, yv^(-1), 1}, yw] - 
     2*G[{0}, yw]*G[{1/(yu*yv)}, yw]*G[{0, yv^(-1), 1}, yw] - 
     2*G[{1}, yu^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, yv^(-1), 1}, yw] - 
     2*G[{1}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, yv^(-1), 1}, yw] - 
     (Pi^2*G[{0, yv^(-1), yu^(-1)}, yw])/3 + 2*G[{0}, yu^(-1)]*
      G[{1}, yu^(-1)]*G[{0, yv^(-1), yu^(-1)}, yw] + 
     2*G[{0}, yv^(-1)]*G[{1}, yu^(-1)]*G[{0, yv^(-1), yu^(-1)}, yw] - 
     2*G[{0}, yw]*G[{1}, yu^(-1)]*G[{0, yv^(-1), yu^(-1)}, yw] - 
     2*G[{1}, yu^(-1)]^2*G[{0, yv^(-1), yu^(-1)}, yw] - 
     4*G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*G[{0, yv^(-1), yu^(-1)}, yw] + 
     2*G[{0}, yu^(-1)]*G[{yu^(-1)}, yw]*G[{0, yv^(-1), yu^(-1)}, yw] + 
     2*G[{0}, yv^(-1)]*G[{yu^(-1)}, yw]*G[{0, yv^(-1), yu^(-1)}, yw] - 
     2*G[{0}, yw]*G[{yu^(-1)}, yw]*G[{0, yv^(-1), yu^(-1)}, yw] - 
     4*G[{1}, yu^(-1)]*G[{yu^(-1)}, yw]*G[{0, yv^(-1), yu^(-1)}, yw] - 
     4*G[{1}, yv^(-1)]*G[{yu^(-1)}, yw]*G[{0, yv^(-1), yu^(-1)}, yw] + 
     4*G[{1}, yw]*G[{yu^(-1)}, yw]*G[{0, yv^(-1), yu^(-1)}, yw] - 
     2*G[{0}, yu^(-1)]*G[{yu}, yv^(-1)]*G[{0, yv^(-1), yu^(-1)}, yw] - 
     2*G[{0}, yv^(-1)]*G[{yu}, yv^(-1)]*G[{0, yv^(-1), yu^(-1)}, yw] + 
     2*G[{0}, yw]*G[{yu}, yv^(-1)]*G[{0, yv^(-1), yu^(-1)}, yw] + 
     4*G[{1}, yu^(-1)]*G[{yu}, yv^(-1)]*G[{0, yv^(-1), yu^(-1)}, yw] + 
     4*G[{yu^(-1)}, yw]*G[{yu}, yv^(-1)]*G[{0, yv^(-1), yu^(-1)}, yw] + 
     2*G[{0}, yu^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, yv^(-1), yu^(-1)}, yw] + 
     2*G[{0}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, yv^(-1), yu^(-1)}, yw] - 
     2*G[{0}, yw]*G[{1/(yu*yv)}, yw]*G[{0, yv^(-1), yu^(-1)}, yw] - 
     4*G[{1}, yu^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, yv^(-1), yu^(-1)}, yw] - 
     4*G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{0, yv^(-1), yu^(-1)}, yw] - 
     4*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{0, yv^(-1), yu^(-1)}, yw] + 
     2*G[{1/(yu*yv)}, yw]^2*G[{0, yv^(-1), yu^(-1)}, yw] - 
     2*G[{0, 1}, yu^(-1)]*G[{0, yv^(-1), yu^(-1)}, yw] + 
     2*G[{0, 1}, yv^(-1)]*G[{0, yv^(-1), yu^(-1)}, yw] + 
     2*G[{0, 1}, yw]*G[{0, yv^(-1), yu^(-1)}, yw] - 
     2*G[{0, yu^(-1)}, yw]*G[{0, yv^(-1), yu^(-1)}, yw] - 
     2*G[{0, yu}, yv^(-1)]*G[{0, yv^(-1), yu^(-1)}, yw] - 
     2*G[{0, yv^(-1)}, yw]*G[{0, yv^(-1), yu^(-1)}, yw] - 
     4*G[{0, 1/(yu*yv)}, yw]*G[{0, yv^(-1), yu^(-1)}, yw] - 
     4*G[{1, yu^(-1)}, yw]*G[{0, yv^(-1), yu^(-1)}, yw] + 
     4*G[{1, yu}, yv^(-1)]*G[{0, yv^(-1), yu^(-1)}, yw] + 
     4*G[{1, 1/(yu*yv)}, yw]*G[{0, yv^(-1), yu^(-1)}, yw] + 
     4*G[{yu^(-1), 1/(yu*yv)}, yw]*G[{0, yv^(-1), yu^(-1)}, yw] + 
     4*G[{0}, yu^(-1)]*G[{yu^(-1)}, yw]*G[{0, yv^(-1), yv^(-1)}, yw] + 
     4*G[{0}, yv^(-1)]*G[{yu^(-1)}, yw]*G[{0, yv^(-1), yv^(-1)}, yw] - 
     4*G[{0}, yw]*G[{yu^(-1)}, yw]*G[{0, yv^(-1), yv^(-1)}, yw] - 
     8*G[{1}, yu^(-1)]*G[{yu^(-1)}, yw]*G[{0, yv^(-1), yv^(-1)}, yw] - 
     4*G[{1}, yv^(-1)]*G[{yu^(-1)}, yw]*G[{0, yv^(-1), yv^(-1)}, yw] + 
     4*G[{1}, yw]*G[{yu^(-1)}, yw]*G[{0, yv^(-1), yv^(-1)}, yw] + 
     4*G[{yu^(-1)}, yw]*G[{yu}, yv^(-1)]*G[{0, yv^(-1), yv^(-1)}, yw] - 
     4*G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{0, yv^(-1), yv^(-1)}, yw] - 
     4*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{0, yv^(-1), yv^(-1)}, yw] + 
     2*G[{1/(yu*yv)}, yw]^2*G[{0, yv^(-1), yv^(-1)}, yw] - 
     4*G[{0, 1/(yu*yv)}, yw]*G[{0, yv^(-1), yv^(-1)}, yw] - 
     4*G[{1, yu^(-1)}, yw]*G[{0, yv^(-1), yv^(-1)}, yw] + 
     4*G[{1, 1/(yu*yv)}, yw]*G[{0, yv^(-1), yv^(-1)}, yw] + 
     4*G[{yu^(-1), 1/(yu*yv)}, yw]*G[{0, yv^(-1), yv^(-1)}, yw] - 
     2*G[{0}, yu^(-1)]*G[{yu^(-1)}, yw]*G[{0, yv^(-1), 1/(yu*yv)}, yw] - 
     2*G[{0}, yv^(-1)]*G[{yu^(-1)}, yw]*G[{0, yv^(-1), 1/(yu*yv)}, yw] + 
     2*G[{0}, yw]*G[{yu^(-1)}, yw]*G[{0, yv^(-1), 1/(yu*yv)}, yw] + 
     2*G[{1}, yu^(-1)]*G[{yu^(-1)}, yw]*G[{0, yv^(-1), 1/(yu*yv)}, yw] + 
     2*G[{1}, yv^(-1)]*G[{yu^(-1)}, yw]*G[{0, yv^(-1), 1/(yu*yv)}, yw] - 
     2*G[{0}, yu^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, yv^(-1), 1/(yu*yv)}, yw] - 
     2*G[{0}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, yv^(-1), 1/(yu*yv)}, yw] + 
     2*G[{0}, yw]*G[{1/(yu*yv)}, yw]*G[{0, yv^(-1), 1/(yu*yv)}, yw] + 
     2*G[{1}, yu^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, yv^(-1), 1/(yu*yv)}, yw] + 
     2*G[{1}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, yv^(-1), 1/(yu*yv)}, yw] + 
     6*G[{0}, yu^(-1)]*G[{yu^(-1)}, yw]*G[{0, 1/(yu*yv), 1}, yw] + 
     6*G[{0}, yv^(-1)]*G[{yu^(-1)}, yw]*G[{0, 1/(yu*yv), 1}, yw] - 
     6*G[{0}, yw]*G[{yu^(-1)}, yw]*G[{0, 1/(yu*yv), 1}, yw] - 
     6*G[{1}, yu^(-1)]*G[{yu^(-1)}, yw]*G[{0, 1/(yu*yv), 1}, yw] - 
     6*G[{1}, yv^(-1)]*G[{yu^(-1)}, yw]*G[{0, 1/(yu*yv), 1}, yw] - 
     2*G[{0}, yu^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv), 1}, yw] - 
     2*G[{0}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv), 1}, yw] + 
     2*G[{0}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv), 1}, yw] + 
     2*G[{1}, yu^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv), 1}, yw] + 
     2*G[{1}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv), 1}, yw] + 
     (Pi^2*G[{0, 1/(yu*yv), yu^(-1)}, yw])/3 - 2*G[{0}, yu^(-1)]*
      G[{1}, yu^(-1)]*G[{0, 1/(yu*yv), yu^(-1)}, yw] - 
     2*G[{0}, yv^(-1)]*G[{1}, yu^(-1)]*G[{0, 1/(yu*yv), yu^(-1)}, yw] + 
     2*G[{0}, yw]*G[{1}, yu^(-1)]*G[{0, 1/(yu*yv), yu^(-1)}, yw] + 
     2*G[{1}, yu^(-1)]^2*G[{0, 1/(yu*yv), yu^(-1)}, yw] + 
     4*G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*G[{0, 1/(yu*yv), yu^(-1)}, yw] - 
     2*G[{0}, yu^(-1)]*G[{yu^(-1)}, yw]*G[{0, 1/(yu*yv), yu^(-1)}, yw] - 
     2*G[{0}, yv^(-1)]*G[{yu^(-1)}, yw]*G[{0, 1/(yu*yv), yu^(-1)}, yw] + 
     2*G[{0}, yw]*G[{yu^(-1)}, yw]*G[{0, 1/(yu*yv), yu^(-1)}, yw] + 
     4*G[{1}, yu^(-1)]*G[{yu^(-1)}, yw]*G[{0, 1/(yu*yv), yu^(-1)}, yw] + 
     4*G[{1}, yv^(-1)]*G[{yu^(-1)}, yw]*G[{0, 1/(yu*yv), yu^(-1)}, yw] - 
     4*G[{1}, yw]*G[{yu^(-1)}, yw]*G[{0, 1/(yu*yv), yu^(-1)}, yw] + 
     2*G[{0}, yu^(-1)]*G[{yu}, yv^(-1)]*G[{0, 1/(yu*yv), yu^(-1)}, yw] + 
     2*G[{0}, yv^(-1)]*G[{yu}, yv^(-1)]*G[{0, 1/(yu*yv), yu^(-1)}, yw] - 
     2*G[{0}, yw]*G[{yu}, yv^(-1)]*G[{0, 1/(yu*yv), yu^(-1)}, yw] - 
     4*G[{1}, yu^(-1)]*G[{yu}, yv^(-1)]*G[{0, 1/(yu*yv), yu^(-1)}, yw] - 
     4*G[{yu^(-1)}, yw]*G[{yu}, yv^(-1)]*G[{0, 1/(yu*yv), yu^(-1)}, yw] - 
     2*G[{0}, yu^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv), yu^(-1)}, yw] - 
     2*G[{0}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv), yu^(-1)}, yw] + 
     2*G[{0}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv), yu^(-1)}, yw] + 
     4*G[{1}, yu^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv), yu^(-1)}, yw] + 
     4*G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv), yu^(-1)}, yw] + 
     4*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv), yu^(-1)}, yw] - 
     2*G[{1/(yu*yv)}, yw]^2*G[{0, 1/(yu*yv), yu^(-1)}, yw] + 
     2*G[{0, 1}, yu^(-1)]*G[{0, 1/(yu*yv), yu^(-1)}, yw] - 
     2*G[{0, 1}, yv^(-1)]*G[{0, 1/(yu*yv), yu^(-1)}, yw] - 
     2*G[{0, 1}, yw]*G[{0, 1/(yu*yv), yu^(-1)}, yw] + 
     2*G[{0, yu^(-1)}, yw]*G[{0, 1/(yu*yv), yu^(-1)}, yw] + 
     2*G[{0, yu}, yv^(-1)]*G[{0, 1/(yu*yv), yu^(-1)}, yw] + 
     2*G[{0, yv^(-1)}, yw]*G[{0, 1/(yu*yv), yu^(-1)}, yw] - 
     2*G[{0, 1/(yu*yv)}, yw]*G[{0, 1/(yu*yv), yu^(-1)}, yw] + 
     4*G[{1, yu^(-1)}, yw]*G[{0, 1/(yu*yv), yu^(-1)}, yw] - 
     4*G[{1, yu}, yv^(-1)]*G[{0, 1/(yu*yv), yu^(-1)}, yw] - 
     4*G[{1, 1/(yu*yv)}, yw]*G[{0, 1/(yu*yv), yu^(-1)}, yw] - 
     4*G[{yu^(-1), 1/(yu*yv)}, yw]*G[{0, 1/(yu*yv), yu^(-1)}, yw] + 
     (Pi^2*G[{0, 1/(yu*yv), yv^(-1)}, yw])/3 - 2*G[{0}, yu^(-1)]*
      G[{1}, yu^(-1)]*G[{0, 1/(yu*yv), yv^(-1)}, yw] - 
     2*G[{0}, yv^(-1)]*G[{1}, yu^(-1)]*G[{0, 1/(yu*yv), yv^(-1)}, yw] + 
     2*G[{0}, yw]*G[{1}, yu^(-1)]*G[{0, 1/(yu*yv), yv^(-1)}, yw] + 
     2*G[{1}, yu^(-1)]^2*G[{0, 1/(yu*yv), yv^(-1)}, yw] + 
     4*G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*G[{0, 1/(yu*yv), yv^(-1)}, yw] - 
     2*G[{0}, yu^(-1)]*G[{yu^(-1)}, yw]*G[{0, 1/(yu*yv), yv^(-1)}, yw] - 
     2*G[{0}, yv^(-1)]*G[{yu^(-1)}, yw]*G[{0, 1/(yu*yv), yv^(-1)}, yw] + 
     2*G[{0}, yw]*G[{yu^(-1)}, yw]*G[{0, 1/(yu*yv), yv^(-1)}, yw] + 
     4*G[{1}, yu^(-1)]*G[{yu^(-1)}, yw]*G[{0, 1/(yu*yv), yv^(-1)}, yw] + 
     4*G[{1}, yv^(-1)]*G[{yu^(-1)}, yw]*G[{0, 1/(yu*yv), yv^(-1)}, yw] - 
     4*G[{1}, yw]*G[{yu^(-1)}, yw]*G[{0, 1/(yu*yv), yv^(-1)}, yw] + 
     2*G[{0}, yu^(-1)]*G[{yu}, yv^(-1)]*G[{0, 1/(yu*yv), yv^(-1)}, yw] + 
     2*G[{0}, yv^(-1)]*G[{yu}, yv^(-1)]*G[{0, 1/(yu*yv), yv^(-1)}, yw] - 
     2*G[{0}, yw]*G[{yu}, yv^(-1)]*G[{0, 1/(yu*yv), yv^(-1)}, yw] - 
     4*G[{1}, yu^(-1)]*G[{yu}, yv^(-1)]*G[{0, 1/(yu*yv), yv^(-1)}, yw] - 
     4*G[{yu^(-1)}, yw]*G[{yu}, yv^(-1)]*G[{0, 1/(yu*yv), yv^(-1)}, yw] - 
     2*G[{0}, yu^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv), yv^(-1)}, yw] - 
     2*G[{0}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv), yv^(-1)}, yw] + 
     2*G[{0}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv), yv^(-1)}, yw] + 
     4*G[{1}, yu^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv), yv^(-1)}, yw] + 
     4*G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv), yv^(-1)}, yw] + 
     4*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv), yv^(-1)}, yw] - 
     2*G[{1/(yu*yv)}, yw]^2*G[{0, 1/(yu*yv), yv^(-1)}, yw] + 
     2*G[{0, 1}, yu^(-1)]*G[{0, 1/(yu*yv), yv^(-1)}, yw] - 
     2*G[{0, 1}, yv^(-1)]*G[{0, 1/(yu*yv), yv^(-1)}, yw] - 
     2*G[{0, 1}, yw]*G[{0, 1/(yu*yv), yv^(-1)}, yw] + 
     2*G[{0, yu^(-1)}, yw]*G[{0, 1/(yu*yv), yv^(-1)}, yw] + 
     2*G[{0, yu}, yv^(-1)]*G[{0, 1/(yu*yv), yv^(-1)}, yw] + 
     2*G[{0, yv^(-1)}, yw]*G[{0, 1/(yu*yv), yv^(-1)}, yw] - 
     2*G[{0, 1/(yu*yv)}, yw]*G[{0, 1/(yu*yv), yv^(-1)}, yw] + 
     4*G[{1, yu^(-1)}, yw]*G[{0, 1/(yu*yv), yv^(-1)}, yw] - 
     4*G[{1, yu}, yv^(-1)]*G[{0, 1/(yu*yv), yv^(-1)}, yw] - 
     4*G[{1, 1/(yu*yv)}, yw]*G[{0, 1/(yu*yv), yv^(-1)}, yw] - 
     4*G[{yu^(-1), 1/(yu*yv)}, yw]*G[{0, 1/(yu*yv), yv^(-1)}, yw] + 
     (Pi^2*G[{0, 1/(yu*yv), 1/(yu*yv)}, yw])/3 + 2*G[{0}, yu^(-1)]*
      G[{1}, yu^(-1)]*G[{0, 1/(yu*yv), 1/(yu*yv)}, yw] + 
     2*G[{0}, yv^(-1)]*G[{1}, yu^(-1)]*G[{0, 1/(yu*yv), 1/(yu*yv)}, yw] - 
     2*G[{0}, yw]*G[{1}, yu^(-1)]*G[{0, 1/(yu*yv), 1/(yu*yv)}, yw] - 
     2*G[{1}, yu^(-1)]^2*G[{0, 1/(yu*yv), 1/(yu*yv)}, yw] + 
     2*G[{1}, yu^(-1)]*G[{yu^(-1)}, yw]*G[{0, 1/(yu*yv), 1/(yu*yv)}, yw] + 
     2*G[{1}, yv^(-1)]*G[{yu^(-1)}, yw]*G[{0, 1/(yu*yv), 1/(yu*yv)}, yw] - 
     2*G[{0}, yu^(-1)]*G[{yu}, yv^(-1)]*G[{0, 1/(yu*yv), 1/(yu*yv)}, yw] - 
     2*G[{0}, yv^(-1)]*G[{yu}, yv^(-1)]*G[{0, 1/(yu*yv), 1/(yu*yv)}, yw] + 
     2*G[{0}, yw]*G[{yu}, yv^(-1)]*G[{0, 1/(yu*yv), 1/(yu*yv)}, yw] + 
     4*G[{1}, yv^(-1)]*G[{yu}, yv^(-1)]*G[{0, 1/(yu*yv), 1/(yu*yv)}, yw] - 
     4*G[{yu^(-1)}, yw]*G[{yu}, yv^(-1)]*G[{0, 1/(yu*yv), 1/(yu*yv)}, yw] + 
     4*G[{0}, yu^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv), 1/(yu*yv)}, yw] + 
     4*G[{0}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv), 1/(yu*yv)}, yw] - 
     4*G[{0}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv), 1/(yu*yv)}, yw] - 
     6*G[{1}, yu^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv), 1/(yu*yv)}, yw] - 
     6*G[{1}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv), 1/(yu*yv)}, yw] + 
     4*G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv), 1/(yu*yv)}, yw] + 
     2*G[{0, 1}, yu^(-1)]*G[{0, 1/(yu*yv), 1/(yu*yv)}, yw] - 
     2*G[{0, 1}, yv^(-1)]*G[{0, 1/(yu*yv), 1/(yu*yv)}, yw] - 
     2*G[{0, 1}, yw]*G[{0, 1/(yu*yv), 1/(yu*yv)}, yw] + 
     2*G[{0, yu^(-1)}, yw]*G[{0, 1/(yu*yv), 1/(yu*yv)}, yw] + 
     2*G[{0, yu}, yv^(-1)]*G[{0, 1/(yu*yv), 1/(yu*yv)}, yw] + 
     2*G[{0, yv^(-1)}, yw]*G[{0, 1/(yu*yv), 1/(yu*yv)}, yw] - 
     2*G[{0, 1/(yu*yv)}, yw]*G[{0, 1/(yu*yv), 1/(yu*yv)}, yw] - 
     4*G[{1, yu}, yv^(-1)]*G[{0, 1/(yu*yv), 1/(yu*yv)}, yw] - 
     8*G[{0}, yu^(-1)]*G[{yu^(-1)}, yw]*G[{1, 1, yu^(-1)}, yw] - 
     8*G[{0}, yv^(-1)]*G[{yu^(-1)}, yw]*G[{1, 1, yu^(-1)}, yw] + 
     8*G[{0}, yw]*G[{yu^(-1)}, yw]*G[{1, 1, yu^(-1)}, yw] + 
     8*G[{1}, yu^(-1)]*G[{yu^(-1)}, yw]*G[{1, 1, yu^(-1)}, yw] + 
     8*G[{1}, yv^(-1)]*G[{yu^(-1)}, yw]*G[{1, 1, yu^(-1)}, yw] + 
     2*G[{yu^(-1)}, yw]^2*G[{1, 1, yu^(-1)}, yw] + 
     4*G[{0}, yu^(-1)]*G[{1/(yu*yv)}, yw]*G[{1, 1, yu^(-1)}, yw] + 
     4*G[{0}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{1, 1, yu^(-1)}, yw] - 
     4*G[{0}, yw]*G[{1/(yu*yv)}, yw]*G[{1, 1, yu^(-1)}, yw] - 
     4*G[{1}, yu^(-1)]*G[{1/(yu*yv)}, yw]*G[{1, 1, yu^(-1)}, yw] - 
     4*G[{1}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{1, 1, yu^(-1)}, yw] - 
     2*G[{1/(yu*yv)}, yw]^2*G[{1, 1, yu^(-1)}, yw] - 
     (Pi^2*G[{1, 1, yu}, yv^(-1)])/3 + 2*G[{0}, yu^(-1)]*G[{1}, yu^(-1)]*
      G[{1, 1, yu}, yv^(-1)] + 2*G[{0}, yv^(-1)]*G[{1}, yu^(-1)]*
      G[{1, 1, yu}, yv^(-1)] - 2*G[{0}, yw]*G[{1}, yu^(-1)]*
      G[{1, 1, yu}, yv^(-1)] - 2*G[{1}, yu^(-1)]^2*G[{1, 1, yu}, yv^(-1)] - 
     4*G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*G[{1, 1, yu}, yv^(-1)] + 
     2*G[{0}, yu^(-1)]*G[{yu^(-1)}, yw]*G[{1, 1, yu}, yv^(-1)] + 
     2*G[{0}, yv^(-1)]*G[{yu^(-1)}, yw]*G[{1, 1, yu}, yv^(-1)] - 
     2*G[{0}, yw]*G[{yu^(-1)}, yw]*G[{1, 1, yu}, yv^(-1)] - 
     4*G[{1}, yv^(-1)]*G[{yu^(-1)}, yw]*G[{1, 1, yu}, yv^(-1)] + 
     2*G[{yu^(-1)}, yw]^2*G[{1, 1, yu}, yv^(-1)] + 
     2*G[{0}, yu^(-1)]*G[{yu}, yv^(-1)]*G[{1, 1, yu}, yv^(-1)] + 
     2*G[{0}, yv^(-1)]*G[{yu}, yv^(-1)]*G[{1, 1, yu}, yv^(-1)] - 
     2*G[{0}, yw]*G[{yu}, yv^(-1)]*G[{1, 1, yu}, yv^(-1)] - 
     4*G[{1}, yu^(-1)]*G[{yu}, yv^(-1)]*G[{1, 1, yu}, yv^(-1)] - 
     4*G[{1}, yv^(-1)]*G[{yu}, yv^(-1)]*G[{1, 1, yu}, yv^(-1)] - 
     2*G[{yu}, yv^(-1)]^2*G[{1, 1, yu}, yv^(-1)] - 
     2*G[{0}, yu^(-1)]*G[{1/(yu*yv)}, yw]*G[{1, 1, yu}, yv^(-1)] - 
     2*G[{0}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{1, 1, yu}, yv^(-1)] + 
     2*G[{0}, yw]*G[{1/(yu*yv)}, yw]*G[{1, 1, yu}, yv^(-1)] + 
     4*G[{1}, yu^(-1)]*G[{1/(yu*yv)}, yw]*G[{1, 1, yu}, yv^(-1)] + 
     4*G[{1}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{1, 1, yu}, yv^(-1)] + 
     4*G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{1, 1, yu}, yv^(-1)] - 
     2*G[{1/(yu*yv)}, yw]^2*G[{1, 1, yu}, yv^(-1)] - 
     2*G[{0, 1}, yu^(-1)]*G[{1, 1, yu}, yv^(-1)] + 2*G[{0, 1}, yv^(-1)]*
      G[{1, 1, yu}, yv^(-1)] - 2*G[{0, yu}, yv^(-1)]*G[{1, 1, yu}, yv^(-1)] - 
     8*G[{0}, yu^(-1)]*G[{yu^(-1)}, yw]*G[{1, 1, yv^(-1)}, yw] - 
     8*G[{0}, yv^(-1)]*G[{yu^(-1)}, yw]*G[{1, 1, yv^(-1)}, yw] + 
     8*G[{0}, yw]*G[{yu^(-1)}, yw]*G[{1, 1, yv^(-1)}, yw] + 
     8*G[{1}, yu^(-1)]*G[{yu^(-1)}, yw]*G[{1, 1, yv^(-1)}, yw] + 
     8*G[{1}, yv^(-1)]*G[{yu^(-1)}, yw]*G[{1, 1, yv^(-1)}, yw] + 
     8*G[{0}, yu^(-1)]*G[{1/(yu*yv)}, yw]*G[{1, 1, yv^(-1)}, yw] + 
     8*G[{0}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{1, 1, yv^(-1)}, yw] - 
     8*G[{0}, yw]*G[{1/(yu*yv)}, yw]*G[{1, 1, yv^(-1)}, yw] - 
     8*G[{1}, yu^(-1)]*G[{1/(yu*yv)}, yw]*G[{1, 1, yv^(-1)}, yw] - 
     8*G[{1}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{1, 1, yv^(-1)}, yw] + 
     4*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{1, 1, yv^(-1)}, yw] + 
     4*G[{0}, yu^(-1)]*G[{yu^(-1)}, yw]*G[{1, 1, 1/(yu*yv)}, yw] + 
     4*G[{0}, yv^(-1)]*G[{yu^(-1)}, yw]*G[{1, 1, 1/(yu*yv)}, yw] - 
     4*G[{0}, yw]*G[{yu^(-1)}, yw]*G[{1, 1, 1/(yu*yv)}, yw] - 
     4*G[{1}, yu^(-1)]*G[{yu^(-1)}, yw]*G[{1, 1, 1/(yu*yv)}, yw] - 
     4*G[{1}, yv^(-1)]*G[{yu^(-1)}, yw]*G[{1, 1, 1/(yu*yv)}, yw] - 
     2*G[{yu^(-1)}, yw]^2*G[{1, 1, 1/(yu*yv)}, yw] - 
     8*G[{0}, yu^(-1)]*G[{1/(yu*yv)}, yw]*G[{1, 1, 1/(yu*yv)}, yw] - 
     8*G[{0}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{1, 1, 1/(yu*yv)}, yw] + 
     8*G[{0}, yw]*G[{1/(yu*yv)}, yw]*G[{1, 1, 1/(yu*yv)}, yw] + 
     8*G[{1}, yu^(-1)]*G[{1/(yu*yv)}, yw]*G[{1, 1, 1/(yu*yv)}, yw] + 
     8*G[{1}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{1, 1, 1/(yu*yv)}, yw] - 
     4*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{1, 1, 1/(yu*yv)}, yw] + 
     2*G[{1/(yu*yv)}, yw]^2*G[{1, 1, 1/(yu*yv)}, yw] + 
     (4*Pi^2*G[{1, yu^(-1), yu^(-1)}, yw])/3 - 2*G[{0}, yu^(-1)]^2*
      G[{1, yu^(-1), yu^(-1)}, yw] - 4*G[{0}, yu^(-1)]*G[{0}, yv^(-1)]*
      G[{1, yu^(-1), yu^(-1)}, yw] - 2*G[{0}, yv^(-1)]^2*
      G[{1, yu^(-1), yu^(-1)}, yw] + 4*G[{0}, yu^(-1)]*G[{0}, yw]*
      G[{1, yu^(-1), yu^(-1)}, yw] + 4*G[{0}, yv^(-1)]*G[{0}, yw]*
      G[{1, yu^(-1), yu^(-1)}, yw] - 2*G[{0}, yw]^2*G[{1, yu^(-1), yu^(-1)}, 
       yw] + 4*G[{0}, yu^(-1)]*G[{1}, yu^(-1)]*G[{1, yu^(-1), yu^(-1)}, yw] + 
     4*G[{0}, yv^(-1)]*G[{1}, yu^(-1)]*G[{1, yu^(-1), yu^(-1)}, yw] - 
     4*G[{0}, yw]*G[{1}, yu^(-1)]*G[{1, yu^(-1), yu^(-1)}, yw] - 
     2*G[{1}, yu^(-1)]^2*G[{1, yu^(-1), yu^(-1)}, yw] + 
     4*G[{0}, yu^(-1)]*G[{1}, yv^(-1)]*G[{1, yu^(-1), yu^(-1)}, yw] + 
     4*G[{0}, yv^(-1)]*G[{1}, yv^(-1)]*G[{1, yu^(-1), yu^(-1)}, yw] - 
     4*G[{0}, yw]*G[{1}, yv^(-1)]*G[{1, yu^(-1), yu^(-1)}, yw] - 
     2*G[{1}, yv^(-1)]^2*G[{1, yu^(-1), yu^(-1)}, yw] - 
     8*G[{0}, yu^(-1)]*G[{1}, yw]*G[{1, yu^(-1), yu^(-1)}, yw] - 
     8*G[{0}, yv^(-1)]*G[{1}, yw]*G[{1, yu^(-1), yu^(-1)}, yw] + 
     8*G[{0}, yw]*G[{1}, yw]*G[{1, yu^(-1), yu^(-1)}, yw] + 
     8*G[{1}, yu^(-1)]*G[{1}, yw]*G[{1, yu^(-1), yu^(-1)}, yw] + 
     8*G[{1}, yv^(-1)]*G[{1}, yw]*G[{1, yu^(-1), yu^(-1)}, yw] - 
     4*G[{0}, yu^(-1)]*G[{yu^(-1)}, yw]*G[{1, yu^(-1), yu^(-1)}, yw] - 
     4*G[{0}, yv^(-1)]*G[{yu^(-1)}, yw]*G[{1, yu^(-1), yu^(-1)}, yw] + 
     4*G[{0}, yw]*G[{yu^(-1)}, yw]*G[{1, yu^(-1), yu^(-1)}, yw] + 
     4*G[{1}, yu^(-1)]*G[{yu^(-1)}, yw]*G[{1, yu^(-1), yu^(-1)}, yw] + 
     10*G[{1}, yv^(-1)]*G[{yu^(-1)}, yw]*G[{1, yu^(-1), yu^(-1)}, yw] + 
     6*G[{1}, yw]*G[{yu^(-1)}, yw]*G[{1, yu^(-1), yu^(-1)}, yw] + 
     3*G[{yu^(-1)}, yw]^2*G[{1, yu^(-1), yu^(-1)}, yw] - 
     4*G[{1}, yu^(-1)]*G[{yu}, yv^(-1)]*G[{1, yu^(-1), yu^(-1)}, yw] + 
     6*G[{1}, yv^(-1)]*G[{yu}, yv^(-1)]*G[{1, yu^(-1), yu^(-1)}, yw] - 
     6*G[{yu^(-1)}, yw]*G[{yu}, yv^(-1)]*G[{1, yu^(-1), yu^(-1)}, yw] - 
     G[{yu}, yv^(-1)]^2*G[{1, yu^(-1), yu^(-1)}, yw] - 
     4*G[{0}, yu^(-1)]*G[{1/(yu*yv)}, yw]*G[{1, yu^(-1), yu^(-1)}, yw] - 
     4*G[{0}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{1, yu^(-1), yu^(-1)}, yw] + 
     4*G[{0}, yw]*G[{1/(yu*yv)}, yw]*G[{1, yu^(-1), yu^(-1)}, yw] + 
     4*G[{1}, yu^(-1)]*G[{1/(yu*yv)}, yw]*G[{1, yu^(-1), yu^(-1)}, yw] - 
     2*G[{1}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{1, yu^(-1), yu^(-1)}, yw] - 
     6*G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{1, yu^(-1), yu^(-1)}, yw] + 
     2*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{1, yu^(-1), yu^(-1)}, yw] + 
     6*G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{1, yu^(-1), yu^(-1)}, yw] - 
     4*G[{1/(yu*yv)}, yw]^2*G[{1, yu^(-1), yu^(-1)}, yw] + 
     4*G[{0, 1}, yu^(-1)]*G[{1, yu^(-1), yu^(-1)}, yw] - 
     6*G[{0, 1}, yv^(-1)]*G[{1, yu^(-1), yu^(-1)}, yw] - 
     8*G[{0, 1}, yw]*G[{1, yu^(-1), yu^(-1)}, yw] + 
     8*G[{0, yu^(-1)}, yw]*G[{1, yu^(-1), yu^(-1)}, yw] + 
     6*G[{0, yu}, yv^(-1)]*G[{1, yu^(-1), yu^(-1)}, yw] + 
     8*G[{0, yv^(-1)}, yw]*G[{1, yu^(-1), yu^(-1)}, yw] - 
     8*G[{0, 1/(yu*yv)}, yw]*G[{1, yu^(-1), yu^(-1)}, yw] - 
     14*G[{1, yu^(-1)}, yw]*G[{1, yu^(-1), yu^(-1)}, yw] - 
     10*G[{1, yu}, yv^(-1)]*G[{1, yu^(-1), yu^(-1)}, yw] + 
     2*G[{1, 1/(yu*yv)}, yw]*G[{1, yu^(-1), yu^(-1)}, yw] - 
     2*G[{yu^(-1), 1/(yu*yv)}, yw]*G[{1, yu^(-1), yu^(-1)}, yw] + 
     (Pi^2*G[{1, yu^(-1), yv^(-1)}, yw])/3 - 2*G[{0}, yu^(-1)]*
      G[{1}, yu^(-1)]*G[{1, yu^(-1), yv^(-1)}, yw] - 
     2*G[{0}, yv^(-1)]*G[{1}, yu^(-1)]*G[{1, yu^(-1), yv^(-1)}, yw] + 
     2*G[{0}, yw]*G[{1}, yu^(-1)]*G[{1, yu^(-1), yv^(-1)}, yw] + 
     2*G[{1}, yu^(-1)]^2*G[{1, yu^(-1), yv^(-1)}, yw] + 
     4*G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*G[{1, yu^(-1), yv^(-1)}, yw] - 
     4*G[{0}, yu^(-1)]*G[{1}, yw]*G[{1, yu^(-1), yv^(-1)}, yw] - 
     4*G[{0}, yv^(-1)]*G[{1}, yw]*G[{1, yu^(-1), yv^(-1)}, yw] + 
     4*G[{0}, yw]*G[{1}, yw]*G[{1, yu^(-1), yv^(-1)}, yw] + 
     4*G[{1}, yu^(-1)]*G[{1}, yw]*G[{1, yu^(-1), yv^(-1)}, yw] + 
     4*G[{1}, yv^(-1)]*G[{1}, yw]*G[{1, yu^(-1), yv^(-1)}, yw] - 
     2*G[{0}, yu^(-1)]*G[{yu^(-1)}, yw]*G[{1, yu^(-1), yv^(-1)}, yw] - 
     2*G[{0}, yv^(-1)]*G[{yu^(-1)}, yw]*G[{1, yu^(-1), yv^(-1)}, yw] + 
     2*G[{0}, yw]*G[{yu^(-1)}, yw]*G[{1, yu^(-1), yv^(-1)}, yw] + 
     4*G[{1}, yu^(-1)]*G[{yu^(-1)}, yw]*G[{1, yu^(-1), yv^(-1)}, yw] + 
     4*G[{1}, yv^(-1)]*G[{yu^(-1)}, yw]*G[{1, yu^(-1), yv^(-1)}, yw] + 
     4*G[{1}, yw]*G[{yu^(-1)}, yw]*G[{1, yu^(-1), yv^(-1)}, yw] + 
     2*G[{0}, yu^(-1)]*G[{yu}, yv^(-1)]*G[{1, yu^(-1), yv^(-1)}, yw] + 
     2*G[{0}, yv^(-1)]*G[{yu}, yv^(-1)]*G[{1, yu^(-1), yv^(-1)}, yw] - 
     2*G[{0}, yw]*G[{yu}, yv^(-1)]*G[{1, yu^(-1), yv^(-1)}, yw] - 
     4*G[{1}, yu^(-1)]*G[{yu}, yv^(-1)]*G[{1, yu^(-1), yv^(-1)}, yw] - 
     4*G[{yu^(-1)}, yw]*G[{yu}, yv^(-1)]*G[{1, yu^(-1), yv^(-1)}, yw] - 
     2*G[{0}, yu^(-1)]*G[{1/(yu*yv)}, yw]*G[{1, yu^(-1), yv^(-1)}, yw] - 
     2*G[{0}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{1, yu^(-1), yv^(-1)}, yw] + 
     2*G[{0}, yw]*G[{1/(yu*yv)}, yw]*G[{1, yu^(-1), yv^(-1)}, yw] + 
     4*G[{1}, yu^(-1)]*G[{1/(yu*yv)}, yw]*G[{1, yu^(-1), yv^(-1)}, yw] + 
     4*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{1, yu^(-1), yv^(-1)}, yw] - 
     2*G[{1/(yu*yv)}, yw]^2*G[{1, yu^(-1), yv^(-1)}, yw] + 
     2*G[{0, 1}, yu^(-1)]*G[{1, yu^(-1), yv^(-1)}, yw] - 
     2*G[{0, 1}, yv^(-1)]*G[{1, yu^(-1), yv^(-1)}, yw] - 
     2*G[{0, 1}, yw]*G[{1, yu^(-1), yv^(-1)}, yw] + 
     2*G[{0, yu^(-1)}, yw]*G[{1, yu^(-1), yv^(-1)}, yw] + 
     2*G[{0, yu}, yv^(-1)]*G[{1, yu^(-1), yv^(-1)}, yw] + 
     2*G[{0, yv^(-1)}, yw]*G[{1, yu^(-1), yv^(-1)}, yw] - 
     2*G[{0, 1/(yu*yv)}, yw]*G[{1, yu^(-1), yv^(-1)}, yw] - 
     4*G[{1, yu^(-1)}, yw]*G[{1, yu^(-1), yv^(-1)}, yw] - 
     4*G[{1, yu}, yv^(-1)]*G[{1, yu^(-1), yv^(-1)}, yw] - 
     4*G[{1, 1/(yu*yv)}, yw]*G[{1, yu^(-1), yv^(-1)}, yw] - 
     4*G[{yu^(-1), 1/(yu*yv)}, yw]*G[{1, yu^(-1), yv^(-1)}, yw] - 
     (Pi^2*G[{1, yu^(-1), 1/(yu*yv)}, yw])/3 + 2*G[{0}, yu^(-1)]^2*
      G[{1, yu^(-1), 1/(yu*yv)}, yw] + 4*G[{0}, yu^(-1)]*G[{0}, yv^(-1)]*
      G[{1, yu^(-1), 1/(yu*yv)}, yw] + 2*G[{0}, yv^(-1)]^2*
      G[{1, yu^(-1), 1/(yu*yv)}, yw] - 4*G[{0}, yu^(-1)]*G[{0}, yw]*
      G[{1, yu^(-1), 1/(yu*yv)}, yw] - 4*G[{0}, yv^(-1)]*G[{0}, yw]*
      G[{1, yu^(-1), 1/(yu*yv)}, yw] + 2*G[{0}, yw]^2*
      G[{1, yu^(-1), 1/(yu*yv)}, yw] - 2*G[{0}, yu^(-1)]*G[{1}, yu^(-1)]*
      G[{1, yu^(-1), 1/(yu*yv)}, yw] - 2*G[{0}, yv^(-1)]*G[{1}, yu^(-1)]*
      G[{1, yu^(-1), 1/(yu*yv)}, yw] + 2*G[{0}, yw]*G[{1}, yu^(-1)]*
      G[{1, yu^(-1), 1/(yu*yv)}, yw] - 4*G[{0}, yu^(-1)]*G[{1}, yv^(-1)]*
      G[{1, yu^(-1), 1/(yu*yv)}, yw] - 4*G[{0}, yv^(-1)]*G[{1}, yv^(-1)]*
      G[{1, yu^(-1), 1/(yu*yv)}, yw] + 4*G[{0}, yw]*G[{1}, yv^(-1)]*
      G[{1, yu^(-1), 1/(yu*yv)}, yw] + 4*G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*
      G[{1, yu^(-1), 1/(yu*yv)}, yw] + 2*G[{1}, yv^(-1)]^2*
      G[{1, yu^(-1), 1/(yu*yv)}, yw] + 4*G[{0}, yu^(-1)]*G[{1}, yw]*
      G[{1, yu^(-1), 1/(yu*yv)}, yw] + 4*G[{0}, yv^(-1)]*G[{1}, yw]*
      G[{1, yu^(-1), 1/(yu*yv)}, yw] - 4*G[{0}, yw]*G[{1}, yw]*
      G[{1, yu^(-1), 1/(yu*yv)}, yw] - 4*G[{1}, yu^(-1)]*G[{1}, yw]*
      G[{1, yu^(-1), 1/(yu*yv)}, yw] - 4*G[{1}, yv^(-1)]*G[{1}, yw]*
      G[{1, yu^(-1), 1/(yu*yv)}, yw] + 2*G[{0}, yu^(-1)]*G[{yu^(-1)}, yw]*
      G[{1, yu^(-1), 1/(yu*yv)}, yw] + 2*G[{0}, yv^(-1)]*G[{yu^(-1)}, yw]*
      G[{1, yu^(-1), 1/(yu*yv)}, yw] - 2*G[{0}, yw]*G[{yu^(-1)}, yw]*
      G[{1, yu^(-1), 1/(yu*yv)}, yw] - 4*G[{1}, yu^(-1)]*G[{yu^(-1)}, yw]*
      G[{1, yu^(-1), 1/(yu*yv)}, yw] - 2*G[{1}, yv^(-1)]*G[{yu^(-1)}, yw]*
      G[{1, yu^(-1), 1/(yu*yv)}, yw] - 2*G[{1}, yw]*G[{yu^(-1)}, yw]*
      G[{1, yu^(-1), 1/(yu*yv)}, yw] - G[{yu^(-1)}, yw]^2*
      G[{1, yu^(-1), 1/(yu*yv)}, yw] - 2*G[{0}, yu^(-1)]*G[{yu}, yv^(-1)]*
      G[{1, yu^(-1), 1/(yu*yv)}, yw] - 2*G[{0}, yv^(-1)]*G[{yu}, yv^(-1)]*
      G[{1, yu^(-1), 1/(yu*yv)}, yw] + 2*G[{0}, yw]*G[{yu}, yv^(-1)]*
      G[{1, yu^(-1), 1/(yu*yv)}, yw] + 2*G[{1}, yv^(-1)]*G[{yu}, yv^(-1)]*
      G[{1, yu^(-1), 1/(yu*yv)}, yw] + 2*G[{yu^(-1)}, yw]*G[{yu}, yv^(-1)]*
      G[{1, yu^(-1), 1/(yu*yv)}, yw] + G[{yu}, yv^(-1)]^2*
      G[{1, yu^(-1), 1/(yu*yv)}, yw] + 6*G[{0}, yu^(-1)]*G[{1/(yu*yv)}, yw]*
      G[{1, yu^(-1), 1/(yu*yv)}, yw] + 6*G[{0}, yv^(-1)]*G[{1/(yu*yv)}, yw]*
      G[{1, yu^(-1), 1/(yu*yv)}, yw] - 6*G[{0}, yw]*G[{1/(yu*yv)}, yw]*
      G[{1, yu^(-1), 1/(yu*yv)}, yw] - 6*G[{1}, yv^(-1)]*G[{1/(yu*yv)}, yw]*
      G[{1, yu^(-1), 1/(yu*yv)}, yw] + 6*G[{1}, yw]*G[{1/(yu*yv)}, yw]*
      G[{1, yu^(-1), 1/(yu*yv)}, yw] + 2*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*
      G[{1, yu^(-1), 1/(yu*yv)}, yw] - 6*G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw]*
      G[{1, yu^(-1), 1/(yu*yv)}, yw] + 2*G[{0, 1}, yu^(-1)]*
      G[{1, yu^(-1), 1/(yu*yv)}, yw] + 2*G[{0, 1}, yw]*
      G[{1, yu^(-1), 1/(yu*yv)}, yw] - 2*G[{0, yu^(-1)}, yw]*
      G[{1, yu^(-1), 1/(yu*yv)}, yw] - 2*G[{0, yv^(-1)}, yw]*
      G[{1, yu^(-1), 1/(yu*yv)}, yw] + 2*G[{0, 1/(yu*yv)}, yw]*
      G[{1, yu^(-1), 1/(yu*yv)}, yw] + 2*G[{1, yu^(-1)}, yw]*
      G[{1, yu^(-1), 1/(yu*yv)}, yw] - 2*G[{1, yu}, yv^(-1)]*
      G[{1, yu^(-1), 1/(yu*yv)}, yw] + 4*G[{1, yv^(-1)}, yw]*
      G[{1, yu^(-1), 1/(yu*yv)}, yw] - 6*G[{1, 1/(yu*yv)}, yw]*
      G[{1, yu^(-1), 1/(yu*yv)}, yw] - 2*G[{yu^(-1), 1/(yu*yv)}, yw]*
      G[{1, yu^(-1), 1/(yu*yv)}, yw] - 2*G[{0}, yu^(-1)]^2*
      G[{1, yu, yu}, yv^(-1)] - 4*G[{0}, yu^(-1)]*G[{0}, yv^(-1)]*
      G[{1, yu, yu}, yv^(-1)] - 2*G[{0}, yv^(-1)]^2*G[{1, yu, yu}, yv^(-1)] + 
     4*G[{0}, yu^(-1)]*G[{0}, yw]*G[{1, yu, yu}, yv^(-1)] + 
     4*G[{0}, yv^(-1)]*G[{0}, yw]*G[{1, yu, yu}, yv^(-1)] - 
     2*G[{0}, yw]^2*G[{1, yu, yu}, yv^(-1)] + 4*G[{0}, yu^(-1)]*
      G[{1}, yu^(-1)]*G[{1, yu, yu}, yv^(-1)] + 4*G[{0}, yv^(-1)]*
      G[{1}, yu^(-1)]*G[{1, yu, yu}, yv^(-1)] - 4*G[{0}, yw]*G[{1}, yu^(-1)]*
      G[{1, yu, yu}, yv^(-1)] - 2*G[{1}, yu^(-1)]^2*G[{1, yu, yu}, yv^(-1)] + 
     4*G[{0}, yu^(-1)]*G[{1}, yv^(-1)]*G[{1, yu, yu}, yv^(-1)] + 
     4*G[{0}, yv^(-1)]*G[{1}, yv^(-1)]*G[{1, yu, yu}, yv^(-1)] - 
     4*G[{0}, yw]*G[{1}, yv^(-1)]*G[{1, yu, yu}, yv^(-1)] - 
     8*G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*G[{1, yu, yu}, yv^(-1)] - 
     2*G[{1}, yv^(-1)]^2*G[{1, yu, yu}, yv^(-1)] + 
     4*G[{1}, yu^(-1)]*G[{yu^(-1)}, yw]*G[{1, yu, yu}, yv^(-1)] - 
     2*G[{1}, yv^(-1)]*G[{yu^(-1)}, yw]*G[{1, yu, yu}, yv^(-1)] - 
     2*G[{1}, yw]*G[{yu^(-1)}, yw]*G[{1, yu, yu}, yv^(-1)] + 
     3*G[{yu^(-1)}, yw]^2*G[{1, yu, yu}, yv^(-1)] + 
     8*G[{0}, yu^(-1)]*G[{yu}, yv^(-1)]*G[{1, yu, yu}, yv^(-1)] + 
     8*G[{0}, yv^(-1)]*G[{yu}, yv^(-1)]*G[{1, yu, yu}, yv^(-1)] - 
     8*G[{0}, yw]*G[{yu}, yv^(-1)]*G[{1, yu, yu}, yv^(-1)] - 
     4*G[{1}, yu^(-1)]*G[{yu}, yv^(-1)]*G[{1, yu, yu}, yv^(-1)] - 
     10*G[{1}, yv^(-1)]*G[{yu}, yv^(-1)]*G[{1, yu, yu}, yv^(-1)] + 
     6*G[{yu^(-1)}, yw]*G[{yu}, yv^(-1)]*G[{1, yu, yu}, yv^(-1)] - 
     5*G[{yu}, yv^(-1)]^2*G[{1, yu, yu}, yv^(-1)] - 
     8*G[{0}, yu^(-1)]*G[{1/(yu*yv)}, yw]*G[{1, yu, yu}, yv^(-1)] - 
     8*G[{0}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{1, yu, yu}, yv^(-1)] + 
     8*G[{0}, yw]*G[{1/(yu*yv)}, yw]*G[{1, yu, yu}, yv^(-1)] + 
     4*G[{1}, yu^(-1)]*G[{1/(yu*yv)}, yw]*G[{1, yu, yu}, yv^(-1)] + 
     10*G[{1}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{1, yu, yu}, yv^(-1)] - 
     6*G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{1, yu, yu}, yv^(-1)] - 
     6*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{1, yu, yu}, yv^(-1)] + 
     10*G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{1, yu, yu}, yv^(-1)] - 
     2*G[{1/(yu*yv)}, yw]^2*G[{1, yu, yu}, yv^(-1)] - 
     4*G[{0, 1}, yu^(-1)]*G[{1, yu, yu}, yv^(-1)] + 
     2*G[{0, 1}, yv^(-1)]*G[{1, yu, yu}, yv^(-1)] + 
     4*G[{0, 1}, yw]*G[{1, yu, yu}, yv^(-1)] - 2*G[{0, yu}, yv^(-1)]*
      G[{1, yu, yu}, yv^(-1)] - 4*G[{0, 1/(yu*yv)}, yw]*
      G[{1, yu, yu}, yv^(-1)] + 2*G[{1, yu^(-1)}, yw]*
      G[{1, yu, yu}, yv^(-1)] + 6*G[{1, yu}, yv^(-1)]*
      G[{1, yu, yu}, yv^(-1)] + 6*G[{1, 1/(yu*yv)}, yw]*
      G[{1, yu, yu}, yv^(-1)] + 2*G[{yu^(-1), 1/(yu*yv)}, yw]*
      G[{1, yu, yu}, yv^(-1)] + (Pi^2*G[{1, yv^(-1), yu^(-1)}, yw])/3 - 
     2*G[{0}, yu^(-1)]*G[{1}, yu^(-1)]*G[{1, yv^(-1), yu^(-1)}, yw] - 
     2*G[{0}, yv^(-1)]*G[{1}, yu^(-1)]*G[{1, yv^(-1), yu^(-1)}, yw] + 
     2*G[{0}, yw]*G[{1}, yu^(-1)]*G[{1, yv^(-1), yu^(-1)}, yw] + 
     2*G[{1}, yu^(-1)]^2*G[{1, yv^(-1), yu^(-1)}, yw] + 
     4*G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*G[{1, yv^(-1), yu^(-1)}, yw] - 
     4*G[{0}, yu^(-1)]*G[{1}, yw]*G[{1, yv^(-1), yu^(-1)}, yw] - 
     4*G[{0}, yv^(-1)]*G[{1}, yw]*G[{1, yv^(-1), yu^(-1)}, yw] + 
     4*G[{0}, yw]*G[{1}, yw]*G[{1, yv^(-1), yu^(-1)}, yw] + 
     4*G[{1}, yu^(-1)]*G[{1}, yw]*G[{1, yv^(-1), yu^(-1)}, yw] + 
     4*G[{1}, yv^(-1)]*G[{1}, yw]*G[{1, yv^(-1), yu^(-1)}, yw] - 
     2*G[{0}, yu^(-1)]*G[{yu^(-1)}, yw]*G[{1, yv^(-1), yu^(-1)}, yw] - 
     2*G[{0}, yv^(-1)]*G[{yu^(-1)}, yw]*G[{1, yv^(-1), yu^(-1)}, yw] + 
     2*G[{0}, yw]*G[{yu^(-1)}, yw]*G[{1, yv^(-1), yu^(-1)}, yw] + 
     4*G[{1}, yu^(-1)]*G[{yu^(-1)}, yw]*G[{1, yv^(-1), yu^(-1)}, yw] + 
     4*G[{1}, yv^(-1)]*G[{yu^(-1)}, yw]*G[{1, yv^(-1), yu^(-1)}, yw] + 
     4*G[{1}, yw]*G[{yu^(-1)}, yw]*G[{1, yv^(-1), yu^(-1)}, yw] + 
     2*G[{0}, yu^(-1)]*G[{yu}, yv^(-1)]*G[{1, yv^(-1), yu^(-1)}, yw] + 
     2*G[{0}, yv^(-1)]*G[{yu}, yv^(-1)]*G[{1, yv^(-1), yu^(-1)}, yw] - 
     2*G[{0}, yw]*G[{yu}, yv^(-1)]*G[{1, yv^(-1), yu^(-1)}, yw] - 
     4*G[{1}, yu^(-1)]*G[{yu}, yv^(-1)]*G[{1, yv^(-1), yu^(-1)}, yw] - 
     4*G[{yu^(-1)}, yw]*G[{yu}, yv^(-1)]*G[{1, yv^(-1), yu^(-1)}, yw] - 
     2*G[{0}, yu^(-1)]*G[{1/(yu*yv)}, yw]*G[{1, yv^(-1), yu^(-1)}, yw] - 
     2*G[{0}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{1, yv^(-1), yu^(-1)}, yw] + 
     2*G[{0}, yw]*G[{1/(yu*yv)}, yw]*G[{1, yv^(-1), yu^(-1)}, yw] + 
     4*G[{1}, yu^(-1)]*G[{1/(yu*yv)}, yw]*G[{1, yv^(-1), yu^(-1)}, yw] + 
     4*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{1, yv^(-1), yu^(-1)}, yw] - 
     2*G[{1/(yu*yv)}, yw]^2*G[{1, yv^(-1), yu^(-1)}, yw] + 
     2*G[{0, 1}, yu^(-1)]*G[{1, yv^(-1), yu^(-1)}, yw] - 
     2*G[{0, 1}, yv^(-1)]*G[{1, yv^(-1), yu^(-1)}, yw] - 
     2*G[{0, 1}, yw]*G[{1, yv^(-1), yu^(-1)}, yw] + 
     2*G[{0, yu^(-1)}, yw]*G[{1, yv^(-1), yu^(-1)}, yw] + 
     2*G[{0, yu}, yv^(-1)]*G[{1, yv^(-1), yu^(-1)}, yw] + 
     2*G[{0, yv^(-1)}, yw]*G[{1, yv^(-1), yu^(-1)}, yw] - 
     2*G[{0, 1/(yu*yv)}, yw]*G[{1, yv^(-1), yu^(-1)}, yw] - 
     4*G[{1, yu^(-1)}, yw]*G[{1, yv^(-1), yu^(-1)}, yw] - 
     4*G[{1, yu}, yv^(-1)]*G[{1, yv^(-1), yu^(-1)}, yw] - 
     4*G[{1, 1/(yu*yv)}, yw]*G[{1, yv^(-1), yu^(-1)}, yw] - 
     4*G[{yu^(-1), 1/(yu*yv)}, yw]*G[{1, yv^(-1), yu^(-1)}, yw] - 
     4*G[{0}, yu^(-1)]*G[{yu^(-1)}, yw]*G[{1, yv^(-1), yv^(-1)}, yw] - 
     4*G[{0}, yv^(-1)]*G[{yu^(-1)}, yw]*G[{1, yv^(-1), yv^(-1)}, yw] + 
     4*G[{0}, yw]*G[{yu^(-1)}, yw]*G[{1, yv^(-1), yv^(-1)}, yw] + 
     8*G[{1}, yu^(-1)]*G[{yu^(-1)}, yw]*G[{1, yv^(-1), yv^(-1)}, yw] + 
     4*G[{1}, yv^(-1)]*G[{yu^(-1)}, yw]*G[{1, yv^(-1), yv^(-1)}, yw] + 
     4*G[{1}, yw]*G[{yu^(-1)}, yw]*G[{1, yv^(-1), yv^(-1)}, yw] - 
     4*G[{yu^(-1)}, yw]*G[{yu}, yv^(-1)]*G[{1, yv^(-1), yv^(-1)}, yw] + 
     4*G[{0}, yu^(-1)]*G[{1/(yu*yv)}, yw]*G[{1, yv^(-1), yv^(-1)}, yw] + 
     4*G[{0}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{1, yv^(-1), yv^(-1)}, yw] - 
     4*G[{0}, yw]*G[{1/(yu*yv)}, yw]*G[{1, yv^(-1), yv^(-1)}, yw] - 
     8*G[{1}, yu^(-1)]*G[{1/(yu*yv)}, yw]*G[{1, yv^(-1), yv^(-1)}, yw] - 
     4*G[{1}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{1, yv^(-1), yv^(-1)}, yw] - 
     4*G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{1, yv^(-1), yv^(-1)}, yw] + 
     8*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{1, yv^(-1), yv^(-1)}, yw] + 
     4*G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{1, yv^(-1), yv^(-1)}, yw] - 
     2*G[{1/(yu*yv)}, yw]^2*G[{1, yv^(-1), yv^(-1)}, yw] - 
     4*G[{1, 1/(yu*yv)}, yw]*G[{1, yv^(-1), yv^(-1)}, yw] - 
     4*G[{yu^(-1), 1/(yu*yv)}, yw]*G[{1, yv^(-1), yv^(-1)}, yw] - 
     (Pi^2*G[{1, yv^(-1), 1/(yu*yv)}, yw])/3 + 2*G[{0}, yu^(-1)]*
      G[{1}, yu^(-1)]*G[{1, yv^(-1), 1/(yu*yv)}, yw] + 
     2*G[{0}, yv^(-1)]*G[{1}, yu^(-1)]*G[{1, yv^(-1), 1/(yu*yv)}, yw] - 
     2*G[{0}, yw]*G[{1}, yu^(-1)]*G[{1, yv^(-1), 1/(yu*yv)}, yw] - 
     2*G[{1}, yu^(-1)]^2*G[{1, yv^(-1), 1/(yu*yv)}, yw] - 
     4*G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*G[{1, yv^(-1), 1/(yu*yv)}, yw] + 
     4*G[{0}, yu^(-1)]*G[{1}, yw]*G[{1, yv^(-1), 1/(yu*yv)}, yw] + 
     4*G[{0}, yv^(-1)]*G[{1}, yw]*G[{1, yv^(-1), 1/(yu*yv)}, yw] - 
     4*G[{0}, yw]*G[{1}, yw]*G[{1, yv^(-1), 1/(yu*yv)}, yw] - 
     4*G[{1}, yu^(-1)]*G[{1}, yw]*G[{1, yv^(-1), 1/(yu*yv)}, yw] - 
     4*G[{1}, yv^(-1)]*G[{1}, yw]*G[{1, yv^(-1), 1/(yu*yv)}, yw] + 
     2*G[{0}, yu^(-1)]*G[{yu^(-1)}, yw]*G[{1, yv^(-1), 1/(yu*yv)}, yw] + 
     2*G[{0}, yv^(-1)]*G[{yu^(-1)}, yw]*G[{1, yv^(-1), 1/(yu*yv)}, yw] - 
     2*G[{0}, yw]*G[{yu^(-1)}, yw]*G[{1, yv^(-1), 1/(yu*yv)}, yw] - 
     4*G[{1}, yv^(-1)]*G[{yu^(-1)}, yw]*G[{1, yv^(-1), 1/(yu*yv)}, yw] - 
     2*G[{0}, yu^(-1)]*G[{yu}, yv^(-1)]*G[{1, yv^(-1), 1/(yu*yv)}, yw] - 
     2*G[{0}, yv^(-1)]*G[{yu}, yv^(-1)]*G[{1, yv^(-1), 1/(yu*yv)}, yw] + 
     2*G[{0}, yw]*G[{yu}, yv^(-1)]*G[{1, yv^(-1), 1/(yu*yv)}, yw] + 
     4*G[{1}, yu^(-1)]*G[{yu}, yv^(-1)]*G[{1, yv^(-1), 1/(yu*yv)}, yw] + 
     2*G[{0}, yu^(-1)]*G[{1/(yu*yv)}, yw]*G[{1, yv^(-1), 1/(yu*yv)}, yw] + 
     2*G[{0}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{1, yv^(-1), 1/(yu*yv)}, yw] - 
     2*G[{0}, yw]*G[{1/(yu*yv)}, yw]*G[{1, yv^(-1), 1/(yu*yv)}, yw] + 
     4*G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{1, yv^(-1), 1/(yu*yv)}, yw] - 
     4*G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{1, yv^(-1), 1/(yu*yv)}, yw] - 
     2*G[{0, 1}, yu^(-1)]*G[{1, yv^(-1), 1/(yu*yv)}, yw] + 
     2*G[{0, 1}, yv^(-1)]*G[{1, yv^(-1), 1/(yu*yv)}, yw] + 
     2*G[{0, 1}, yw]*G[{1, yv^(-1), 1/(yu*yv)}, yw] - 
     2*G[{0, yu^(-1)}, yw]*G[{1, yv^(-1), 1/(yu*yv)}, yw] - 
     2*G[{0, yu}, yv^(-1)]*G[{1, yv^(-1), 1/(yu*yv)}, yw] - 
     2*G[{0, yv^(-1)}, yw]*G[{1, yv^(-1), 1/(yu*yv)}, yw] + 
     2*G[{0, 1/(yu*yv)}, yw]*G[{1, yv^(-1), 1/(yu*yv)}, yw] + 
     4*G[{1, yu^(-1)}, yw]*G[{1, yv^(-1), 1/(yu*yv)}, yw] + 
     4*G[{1, yu}, yv^(-1)]*G[{1, yv^(-1), 1/(yu*yv)}, yw] - 
     (Pi^2*G[{1, 1/(yu*yv), yu^(-1)}, yw])/3 + 2*G[{0}, yu^(-1)]^2*
      G[{1, 1/(yu*yv), yu^(-1)}, yw] + 4*G[{0}, yu^(-1)]*G[{0}, yv^(-1)]*
      G[{1, 1/(yu*yv), yu^(-1)}, yw] + 2*G[{0}, yv^(-1)]^2*
      G[{1, 1/(yu*yv), yu^(-1)}, yw] - 4*G[{0}, yu^(-1)]*G[{0}, yw]*
      G[{1, 1/(yu*yv), yu^(-1)}, yw] - 4*G[{0}, yv^(-1)]*G[{0}, yw]*
      G[{1, 1/(yu*yv), yu^(-1)}, yw] + 2*G[{0}, yw]^2*
      G[{1, 1/(yu*yv), yu^(-1)}, yw] - 2*G[{0}, yu^(-1)]*G[{1}, yu^(-1)]*
      G[{1, 1/(yu*yv), yu^(-1)}, yw] - 2*G[{0}, yv^(-1)]*G[{1}, yu^(-1)]*
      G[{1, 1/(yu*yv), yu^(-1)}, yw] + 2*G[{0}, yw]*G[{1}, yu^(-1)]*
      G[{1, 1/(yu*yv), yu^(-1)}, yw] - 4*G[{0}, yu^(-1)]*G[{1}, yv^(-1)]*
      G[{1, 1/(yu*yv), yu^(-1)}, yw] - 4*G[{0}, yv^(-1)]*G[{1}, yv^(-1)]*
      G[{1, 1/(yu*yv), yu^(-1)}, yw] + 4*G[{0}, yw]*G[{1}, yv^(-1)]*
      G[{1, 1/(yu*yv), yu^(-1)}, yw] + 4*G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*
      G[{1, 1/(yu*yv), yu^(-1)}, yw] + 2*G[{1}, yv^(-1)]^2*
      G[{1, 1/(yu*yv), yu^(-1)}, yw] + 4*G[{0}, yu^(-1)]*G[{1}, yw]*
      G[{1, 1/(yu*yv), yu^(-1)}, yw] + 4*G[{0}, yv^(-1)]*G[{1}, yw]*
      G[{1, 1/(yu*yv), yu^(-1)}, yw] - 4*G[{0}, yw]*G[{1}, yw]*
      G[{1, 1/(yu*yv), yu^(-1)}, yw] - 4*G[{1}, yu^(-1)]*G[{1}, yw]*
      G[{1, 1/(yu*yv), yu^(-1)}, yw] - 4*G[{1}, yv^(-1)]*G[{1}, yw]*
      G[{1, 1/(yu*yv), yu^(-1)}, yw] - 2*G[{0}, yu^(-1)]*G[{yu^(-1)}, yw]*
      G[{1, 1/(yu*yv), yu^(-1)}, yw] - 2*G[{0}, yv^(-1)]*G[{yu^(-1)}, yw]*
      G[{1, 1/(yu*yv), yu^(-1)}, yw] + 2*G[{0}, yw]*G[{yu^(-1)}, yw]*
      G[{1, 1/(yu*yv), yu^(-1)}, yw] + 2*G[{1}, yv^(-1)]*G[{yu^(-1)}, yw]*
      G[{1, 1/(yu*yv), yu^(-1)}, yw] - 2*G[{1}, yw]*G[{yu^(-1)}, yw]*
      G[{1, 1/(yu*yv), yu^(-1)}, yw] - 3*G[{yu^(-1)}, yw]^2*
      G[{1, 1/(yu*yv), yu^(-1)}, yw] - 2*G[{0}, yu^(-1)]*G[{yu}, yv^(-1)]*
      G[{1, 1/(yu*yv), yu^(-1)}, yw] - 2*G[{0}, yv^(-1)]*G[{yu}, yv^(-1)]*
      G[{1, 1/(yu*yv), yu^(-1)}, yw] + 2*G[{0}, yw]*G[{yu}, yv^(-1)]*
      G[{1, 1/(yu*yv), yu^(-1)}, yw] + 2*G[{1}, yv^(-1)]*G[{yu}, yv^(-1)]*
      G[{1, 1/(yu*yv), yu^(-1)}, yw] + 2*G[{yu^(-1)}, yw]*G[{yu}, yv^(-1)]*
      G[{1, 1/(yu*yv), yu^(-1)}, yw] + G[{yu}, yv^(-1)]^2*
      G[{1, 1/(yu*yv), yu^(-1)}, yw] + 6*G[{0}, yu^(-1)]*G[{1/(yu*yv)}, yw]*
      G[{1, 1/(yu*yv), yu^(-1)}, yw] + 6*G[{0}, yv^(-1)]*G[{1/(yu*yv)}, yw]*
      G[{1, 1/(yu*yv), yu^(-1)}, yw] - 6*G[{0}, yw]*G[{1/(yu*yv)}, yw]*
      G[{1, 1/(yu*yv), yu^(-1)}, yw] - 6*G[{1}, yv^(-1)]*G[{1/(yu*yv)}, yw]*
      G[{1, 1/(yu*yv), yu^(-1)}, yw] + 6*G[{1}, yw]*G[{1/(yu*yv)}, yw]*
      G[{1, 1/(yu*yv), yu^(-1)}, yw] + 2*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*
      G[{1, 1/(yu*yv), yu^(-1)}, yw] - 6*G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw]*
      G[{1, 1/(yu*yv), yu^(-1)}, yw] + 2*G[{1/(yu*yv)}, yw]^2*
      G[{1, 1/(yu*yv), yu^(-1)}, yw] + 2*G[{0, 1}, yu^(-1)]*
      G[{1, 1/(yu*yv), yu^(-1)}, yw] + 2*G[{0, 1}, yw]*
      G[{1, 1/(yu*yv), yu^(-1)}, yw] - 2*G[{0, yu^(-1)}, yw]*
      G[{1, 1/(yu*yv), yu^(-1)}, yw] - 2*G[{0, yv^(-1)}, yw]*
      G[{1, 1/(yu*yv), yu^(-1)}, yw] + 2*G[{0, 1/(yu*yv)}, yw]*
      G[{1, 1/(yu*yv), yu^(-1)}, yw] + 2*G[{1, yu^(-1)}, yw]*
      G[{1, 1/(yu*yv), yu^(-1)}, yw] - 2*G[{1, yu}, yv^(-1)]*
      G[{1, 1/(yu*yv), yu^(-1)}, yw] + 4*G[{1, yv^(-1)}, yw]*
      G[{1, 1/(yu*yv), yu^(-1)}, yw] - 2*G[{1, 1/(yu*yv)}, yw]*
      G[{1, 1/(yu*yv), yu^(-1)}, yw] - 2*G[{yu^(-1), 1/(yu*yv)}, yw]*
      G[{1, 1/(yu*yv), yu^(-1)}, yw] - (Pi^2*G[{1, 1/(yu*yv), yv^(-1)}, yw])/
      3 + 2*G[{0}, yu^(-1)]*G[{1}, yu^(-1)]*G[{1, 1/(yu*yv), yv^(-1)}, yw] + 
     2*G[{0}, yv^(-1)]*G[{1}, yu^(-1)]*G[{1, 1/(yu*yv), yv^(-1)}, yw] - 
     2*G[{0}, yw]*G[{1}, yu^(-1)]*G[{1, 1/(yu*yv), yv^(-1)}, yw] - 
     2*G[{1}, yu^(-1)]^2*G[{1, 1/(yu*yv), yv^(-1)}, yw] - 
     4*G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*G[{1, 1/(yu*yv), yv^(-1)}, yw] + 
     4*G[{0}, yu^(-1)]*G[{1}, yw]*G[{1, 1/(yu*yv), yv^(-1)}, yw] + 
     4*G[{0}, yv^(-1)]*G[{1}, yw]*G[{1, 1/(yu*yv), yv^(-1)}, yw] - 
     4*G[{0}, yw]*G[{1}, yw]*G[{1, 1/(yu*yv), yv^(-1)}, yw] - 
     4*G[{1}, yu^(-1)]*G[{1}, yw]*G[{1, 1/(yu*yv), yv^(-1)}, yw] - 
     4*G[{1}, yv^(-1)]*G[{1}, yw]*G[{1, 1/(yu*yv), yv^(-1)}, yw] - 
     2*G[{0}, yu^(-1)]*G[{yu^(-1)}, yw]*G[{1, 1/(yu*yv), yv^(-1)}, yw] - 
     2*G[{0}, yv^(-1)]*G[{yu^(-1)}, yw]*G[{1, 1/(yu*yv), yv^(-1)}, yw] + 
     2*G[{0}, yw]*G[{yu^(-1)}, yw]*G[{1, 1/(yu*yv), yv^(-1)}, yw] + 
     4*G[{1}, yu^(-1)]*G[{yu^(-1)}, yw]*G[{1, 1/(yu*yv), yv^(-1)}, yw] - 
     2*G[{0}, yu^(-1)]*G[{yu}, yv^(-1)]*G[{1, 1/(yu*yv), yv^(-1)}, yw] - 
     2*G[{0}, yv^(-1)]*G[{yu}, yv^(-1)]*G[{1, 1/(yu*yv), yv^(-1)}, yw] + 
     2*G[{0}, yw]*G[{yu}, yv^(-1)]*G[{1, 1/(yu*yv), yv^(-1)}, yw] + 
     4*G[{1}, yu^(-1)]*G[{yu}, yv^(-1)]*G[{1, 1/(yu*yv), yv^(-1)}, yw] - 
     2*G[{0}, yu^(-1)]*G[{1/(yu*yv)}, yw]*G[{1, 1/(yu*yv), yv^(-1)}, yw] - 
     2*G[{0}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{1, 1/(yu*yv), yv^(-1)}, yw] + 
     2*G[{0}, yw]*G[{1/(yu*yv)}, yw]*G[{1, 1/(yu*yv), yv^(-1)}, yw] + 
     4*G[{1}, yu^(-1)]*G[{1/(yu*yv)}, yw]*G[{1, 1/(yu*yv), yv^(-1)}, yw] + 
     4*G[{1}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{1, 1/(yu*yv), yv^(-1)}, yw] + 
     4*G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{1, 1/(yu*yv), yv^(-1)}, yw] - 
     4*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{1, 1/(yu*yv), yv^(-1)}, yw] - 
     4*G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{1, 1/(yu*yv), yv^(-1)}, yw] - 
     2*G[{0, 1}, yu^(-1)]*G[{1, 1/(yu*yv), yv^(-1)}, yw] + 
     2*G[{0, 1}, yv^(-1)]*G[{1, 1/(yu*yv), yv^(-1)}, yw] + 
     2*G[{0, 1}, yw]*G[{1, 1/(yu*yv), yv^(-1)}, yw] - 
     2*G[{0, yu^(-1)}, yw]*G[{1, 1/(yu*yv), yv^(-1)}, yw] - 
     2*G[{0, yu}, yv^(-1)]*G[{1, 1/(yu*yv), yv^(-1)}, yw] - 
     2*G[{0, yv^(-1)}, yw]*G[{1, 1/(yu*yv), yv^(-1)}, yw] + 
     2*G[{0, 1/(yu*yv)}, yw]*G[{1, 1/(yu*yv), yv^(-1)}, yw] + 
     4*G[{1, yu^(-1)}, yw]*G[{1, 1/(yu*yv), yv^(-1)}, yw] + 
     4*G[{1, yu}, yv^(-1)]*G[{1, 1/(yu*yv), yv^(-1)}, yw] - 
     2*G[{0}, yu^(-1)]^2*G[{1, 1/(yu*yv), 1/(yu*yv)}, yw] - 
     4*G[{0}, yu^(-1)]*G[{0}, yv^(-1)]*G[{1, 1/(yu*yv), 1/(yu*yv)}, yw] - 
     2*G[{0}, yv^(-1)]^2*G[{1, 1/(yu*yv), 1/(yu*yv)}, yw] + 
     4*G[{0}, yu^(-1)]*G[{0}, yw]*G[{1, 1/(yu*yv), 1/(yu*yv)}, yw] + 
     4*G[{0}, yv^(-1)]*G[{0}, yw]*G[{1, 1/(yu*yv), 1/(yu*yv)}, yw] - 
     2*G[{0}, yw]^2*G[{1, 1/(yu*yv), 1/(yu*yv)}, yw] - 
     4*G[{0}, yu^(-1)]*G[{1}, yu^(-1)]*G[{1, 1/(yu*yv), 1/(yu*yv)}, yw] - 
     4*G[{0}, yv^(-1)]*G[{1}, yu^(-1)]*G[{1, 1/(yu*yv), 1/(yu*yv)}, yw] + 
     4*G[{0}, yw]*G[{1}, yu^(-1)]*G[{1, 1/(yu*yv), 1/(yu*yv)}, yw] + 
     6*G[{1}, yu^(-1)]^2*G[{1, 1/(yu*yv), 1/(yu*yv)}, yw] + 
     4*G[{0}, yu^(-1)]*G[{1}, yv^(-1)]*G[{1, 1/(yu*yv), 1/(yu*yv)}, yw] + 
     4*G[{0}, yv^(-1)]*G[{1}, yv^(-1)]*G[{1, 1/(yu*yv), 1/(yu*yv)}, yw] - 
     4*G[{0}, yw]*G[{1}, yv^(-1)]*G[{1, 1/(yu*yv), 1/(yu*yv)}, yw] - 
     2*G[{1}, yv^(-1)]^2*G[{1, 1/(yu*yv), 1/(yu*yv)}, yw] - 
     8*G[{0}, yu^(-1)]*G[{1}, yw]*G[{1, 1/(yu*yv), 1/(yu*yv)}, yw] - 
     8*G[{0}, yv^(-1)]*G[{1}, yw]*G[{1, 1/(yu*yv), 1/(yu*yv)}, yw] + 
     8*G[{0}, yw]*G[{1}, yw]*G[{1, 1/(yu*yv), 1/(yu*yv)}, yw] + 
     8*G[{1}, yu^(-1)]*G[{1}, yw]*G[{1, 1/(yu*yv), 1/(yu*yv)}, yw] + 
     8*G[{1}, yv^(-1)]*G[{1}, yw]*G[{1, 1/(yu*yv), 1/(yu*yv)}, yw] + 
     4*G[{0}, yu^(-1)]*G[{yu^(-1)}, yw]*G[{1, 1/(yu*yv), 1/(yu*yv)}, yw] + 
     4*G[{0}, yv^(-1)]*G[{yu^(-1)}, yw]*G[{1, 1/(yu*yv), 1/(yu*yv)}, yw] - 
     4*G[{0}, yw]*G[{yu^(-1)}, yw]*G[{1, 1/(yu*yv), 1/(yu*yv)}, yw] - 
     8*G[{1}, yu^(-1)]*G[{yu^(-1)}, yw]*G[{1, 1/(yu*yv), 1/(yu*yv)}, yw] - 
     6*G[{1}, yv^(-1)]*G[{yu^(-1)}, yw]*G[{1, 1/(yu*yv), 1/(yu*yv)}, yw] - 
     6*G[{1}, yw]*G[{yu^(-1)}, yw]*G[{1, 1/(yu*yv), 1/(yu*yv)}, yw] + 
     G[{yu^(-1)}, yw]^2*G[{1, 1/(yu*yv), 1/(yu*yv)}, yw] + 
     8*G[{0}, yu^(-1)]*G[{yu}, yv^(-1)]*G[{1, 1/(yu*yv), 1/(yu*yv)}, yw] + 
     8*G[{0}, yv^(-1)]*G[{yu}, yv^(-1)]*G[{1, 1/(yu*yv), 1/(yu*yv)}, yw] - 
     8*G[{0}, yw]*G[{yu}, yv^(-1)]*G[{1, 1/(yu*yv), 1/(yu*yv)}, yw] - 
     4*G[{1}, yu^(-1)]*G[{yu}, yv^(-1)]*G[{1, 1/(yu*yv), 1/(yu*yv)}, yw] - 
     10*G[{1}, yv^(-1)]*G[{yu}, yv^(-1)]*G[{1, 1/(yu*yv), 1/(yu*yv)}, yw] + 
     6*G[{yu^(-1)}, yw]*G[{yu}, yv^(-1)]*G[{1, 1/(yu*yv), 1/(yu*yv)}, yw] - 
     G[{yu}, yv^(-1)]^2*G[{1, 1/(yu*yv), 1/(yu*yv)}, yw] - 
     8*G[{0}, yu^(-1)]*G[{1/(yu*yv)}, yw]*G[{1, 1/(yu*yv), 1/(yu*yv)}, yw] - 
     8*G[{0}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{1, 1/(yu*yv), 1/(yu*yv)}, yw] + 
     8*G[{0}, yw]*G[{1/(yu*yv)}, yw]*G[{1, 1/(yu*yv), 1/(yu*yv)}, yw] + 
     4*G[{1}, yu^(-1)]*G[{1/(yu*yv)}, yw]*G[{1, 1/(yu*yv), 1/(yu*yv)}, yw] + 
     10*G[{1}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{1, 1/(yu*yv), 1/(yu*yv)}, yw] - 
     2*G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{1, 1/(yu*yv), 1/(yu*yv)}, yw] - 
     2*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{1, 1/(yu*yv), 1/(yu*yv)}, yw] + 
     2*G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{1, 1/(yu*yv), 1/(yu*yv)}, yw] - 
     4*G[{0, 1}, yu^(-1)]*G[{1, 1/(yu*yv), 1/(yu*yv)}, yw] + 
     2*G[{0, 1}, yv^(-1)]*G[{1, 1/(yu*yv), 1/(yu*yv)}, yw] - 
     2*G[{0, yu}, yv^(-1)]*G[{1, 1/(yu*yv), 1/(yu*yv)}, yw] + 
     2*G[{1, yu^(-1)}, yw]*G[{1, 1/(yu*yv), 1/(yu*yv)}, yw] + 
     6*G[{1, yu}, yv^(-1)]*G[{1, 1/(yu*yv), 1/(yu*yv)}, yw] - 
     4*G[{1, yv^(-1)}, yw]*G[{1, 1/(yu*yv), 1/(yu*yv)}, yw] + 
     2*G[{1, 1/(yu*yv)}, yw]*G[{1, 1/(yu*yv), 1/(yu*yv)}, yw] + 
     2*G[{yu^(-1), 1/(yu*yv)}, yw]*G[{1, 1/(yu*yv), 1/(yu*yv)}, yw] + 
     2*G[{0}, yu^(-1)]^2*G[{yu^(-1), yu^(-1), 1/(yu*yv)}, yw] + 
     4*G[{0}, yu^(-1)]*G[{0}, yv^(-1)]*G[{yu^(-1), yu^(-1), 1/(yu*yv)}, yw] + 
     2*G[{0}, yv^(-1)]^2*G[{yu^(-1), yu^(-1), 1/(yu*yv)}, yw] - 
     4*G[{0}, yu^(-1)]*G[{0}, yw]*G[{yu^(-1), yu^(-1), 1/(yu*yv)}, yw] - 
     4*G[{0}, yv^(-1)]*G[{0}, yw]*G[{yu^(-1), yu^(-1), 1/(yu*yv)}, yw] + 
     2*G[{0}, yw]^2*G[{yu^(-1), yu^(-1), 1/(yu*yv)}, yw] - 
     4*G[{0}, yu^(-1)]*G[{1}, yu^(-1)]*G[{yu^(-1), yu^(-1), 1/(yu*yv)}, yw] - 
     4*G[{0}, yv^(-1)]*G[{1}, yu^(-1)]*G[{yu^(-1), yu^(-1), 1/(yu*yv)}, yw] + 
     4*G[{0}, yw]*G[{1}, yu^(-1)]*G[{yu^(-1), yu^(-1), 1/(yu*yv)}, yw] + 
     2*G[{1}, yu^(-1)]^2*G[{yu^(-1), yu^(-1), 1/(yu*yv)}, yw] - 
     4*G[{0}, yu^(-1)]*G[{1}, yv^(-1)]*G[{yu^(-1), yu^(-1), 1/(yu*yv)}, yw] - 
     4*G[{0}, yv^(-1)]*G[{1}, yv^(-1)]*G[{yu^(-1), yu^(-1), 1/(yu*yv)}, yw] + 
     4*G[{0}, yw]*G[{1}, yv^(-1)]*G[{yu^(-1), yu^(-1), 1/(yu*yv)}, yw] + 
     8*G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*G[{yu^(-1), yu^(-1), 1/(yu*yv)}, yw] + 
     2*G[{1}, yv^(-1)]^2*G[{yu^(-1), yu^(-1), 1/(yu*yv)}, yw] + 
     4*G[{0}, yu^(-1)]*G[{yu^(-1)}, yw]*G[{yu^(-1), yu^(-1), 1/(yu*yv)}, 
       yw] + 4*G[{0}, yv^(-1)]*G[{yu^(-1)}, yw]*
      G[{yu^(-1), yu^(-1), 1/(yu*yv)}, yw] - 4*G[{0}, yw]*G[{yu^(-1)}, yw]*
      G[{yu^(-1), yu^(-1), 1/(yu*yv)}, yw] - 4*G[{1}, yu^(-1)]*
      G[{yu^(-1)}, yw]*G[{yu^(-1), yu^(-1), 1/(yu*yv)}, yw] - 
     2*G[{1}, yv^(-1)]*G[{yu^(-1)}, yw]*G[{yu^(-1), yu^(-1), 1/(yu*yv)}, 
       yw] + 2*G[{1}, yw]*G[{yu^(-1)}, yw]*G[{yu^(-1), yu^(-1), 1/(yu*yv)}, 
       yw] + G[{yu^(-1)}, yw]^2*G[{yu^(-1), yu^(-1), 1/(yu*yv)}, yw] - 
     4*G[{1}, yu^(-1)]*G[{yu}, yv^(-1)]*G[{yu^(-1), yu^(-1), 1/(yu*yv)}, 
       yw] + 2*G[{1}, yv^(-1)]*G[{yu}, yv^(-1)]*
      G[{yu^(-1), yu^(-1), 1/(yu*yv)}, yw] - 2*G[{yu^(-1)}, yw]*
      G[{yu}, yv^(-1)]*G[{yu^(-1), yu^(-1), 1/(yu*yv)}, yw] + 
     G[{yu}, yv^(-1)]^2*G[{yu^(-1), yu^(-1), 1/(yu*yv)}, yw] + 
     4*G[{0}, yu^(-1)]*G[{1/(yu*yv)}, yw]*G[{yu^(-1), yu^(-1), 1/(yu*yv)}, 
       yw] + 4*G[{0}, yv^(-1)]*G[{1/(yu*yv)}, yw]*
      G[{yu^(-1), yu^(-1), 1/(yu*yv)}, yw] - 4*G[{0}, yw]*G[{1/(yu*yv)}, yw]*
      G[{yu^(-1), yu^(-1), 1/(yu*yv)}, yw] + 4*G[{1}, yu^(-1)]*
      G[{1/(yu*yv)}, yw]*G[{yu^(-1), yu^(-1), 1/(yu*yv)}, yw] - 
     6*G[{1}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{yu^(-1), yu^(-1), 1/(yu*yv)}, 
       yw] + 6*G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{yu^(-1), yu^(-1), 1/(yu*yv)}, 
       yw] + 6*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*
      G[{yu^(-1), yu^(-1), 1/(yu*yv)}, yw] - 6*G[{yu}, yv^(-1)]*
      G[{1/(yu*yv)}, yw]*G[{yu^(-1), yu^(-1), 1/(yu*yv)}, yw] + 
     4*G[{0, 1}, yu^(-1)]*G[{yu^(-1), yu^(-1), 1/(yu*yv)}, yw] - 
     2*G[{0, 1}, yv^(-1)]*G[{yu^(-1), yu^(-1), 1/(yu*yv)}, yw] + 
     2*G[{0, yu}, yv^(-1)]*G[{yu^(-1), yu^(-1), 1/(yu*yv)}, yw] - 
     2*G[{1, yu^(-1)}, yw]*G[{yu^(-1), yu^(-1), 1/(yu*yv)}, yw] - 
     6*G[{1, yu}, yv^(-1)]*G[{yu^(-1), yu^(-1), 1/(yu*yv)}, yw] + 
     4*G[{1, yv^(-1)}, yw]*G[{yu^(-1), yu^(-1), 1/(yu*yv)}, yw] - 
     2*G[{1, 1/(yu*yv)}, yw]*G[{yu^(-1), yu^(-1), 1/(yu*yv)}, yw] - 
     6*G[{yu^(-1), 1/(yu*yv)}, yw]*G[{yu^(-1), yu^(-1), 1/(yu*yv)}, yw] - 
     (Pi^2*G[{yu^(-1), 1/(yu*yv), yv^(-1)}, yw])/3 + 
     2*G[{0}, yu^(-1)]*G[{1}, yu^(-1)]*G[{yu^(-1), 1/(yu*yv), yv^(-1)}, yw] + 
     2*G[{0}, yv^(-1)]*G[{1}, yu^(-1)]*G[{yu^(-1), 1/(yu*yv), yv^(-1)}, yw] - 
     2*G[{0}, yw]*G[{1}, yu^(-1)]*G[{yu^(-1), 1/(yu*yv), yv^(-1)}, yw] - 
     2*G[{1}, yu^(-1)]^2*G[{yu^(-1), 1/(yu*yv), yv^(-1)}, yw] - 
     4*G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*G[{yu^(-1), 1/(yu*yv), yv^(-1)}, yw] + 
     4*G[{0}, yu^(-1)]*G[{1}, yw]*G[{yu^(-1), 1/(yu*yv), yv^(-1)}, yw] + 
     4*G[{0}, yv^(-1)]*G[{1}, yw]*G[{yu^(-1), 1/(yu*yv), yv^(-1)}, yw] - 
     4*G[{0}, yw]*G[{1}, yw]*G[{yu^(-1), 1/(yu*yv), yv^(-1)}, yw] - 
     4*G[{1}, yu^(-1)]*G[{1}, yw]*G[{yu^(-1), 1/(yu*yv), yv^(-1)}, yw] - 
     4*G[{1}, yv^(-1)]*G[{1}, yw]*G[{yu^(-1), 1/(yu*yv), yv^(-1)}, yw] - 
     2*G[{0}, yu^(-1)]*G[{yu^(-1)}, yw]*G[{yu^(-1), 1/(yu*yv), yv^(-1)}, 
       yw] - 2*G[{0}, yv^(-1)]*G[{yu^(-1)}, yw]*
      G[{yu^(-1), 1/(yu*yv), yv^(-1)}, yw] + 2*G[{0}, yw]*G[{yu^(-1)}, yw]*
      G[{yu^(-1), 1/(yu*yv), yv^(-1)}, yw] + 4*G[{1}, yu^(-1)]*
      G[{yu^(-1)}, yw]*G[{yu^(-1), 1/(yu*yv), yv^(-1)}, yw] - 
     2*G[{0}, yu^(-1)]*G[{yu}, yv^(-1)]*G[{yu^(-1), 1/(yu*yv), yv^(-1)}, 
       yw] - 2*G[{0}, yv^(-1)]*G[{yu}, yv^(-1)]*
      G[{yu^(-1), 1/(yu*yv), yv^(-1)}, yw] + 2*G[{0}, yw]*G[{yu}, yv^(-1)]*
      G[{yu^(-1), 1/(yu*yv), yv^(-1)}, yw] + 4*G[{1}, yu^(-1)]*
      G[{yu}, yv^(-1)]*G[{yu^(-1), 1/(yu*yv), yv^(-1)}, yw] + 
     2*G[{0}, yu^(-1)]*G[{1/(yu*yv)}, yw]*G[{yu^(-1), 1/(yu*yv), yv^(-1)}, 
       yw] + 2*G[{0}, yv^(-1)]*G[{1/(yu*yv)}, yw]*
      G[{yu^(-1), 1/(yu*yv), yv^(-1)}, yw] - 2*G[{0}, yw]*G[{1/(yu*yv)}, yw]*
      G[{yu^(-1), 1/(yu*yv), yv^(-1)}, yw] - 4*G[{1}, yu^(-1)]*
      G[{1/(yu*yv)}, yw]*G[{yu^(-1), 1/(yu*yv), yv^(-1)}, yw] + 
     2*G[{1/(yu*yv)}, yw]^2*G[{yu^(-1), 1/(yu*yv), yv^(-1)}, yw] - 
     2*G[{0, 1}, yu^(-1)]*G[{yu^(-1), 1/(yu*yv), yv^(-1)}, yw] + 
     2*G[{0, 1}, yv^(-1)]*G[{yu^(-1), 1/(yu*yv), yv^(-1)}, yw] + 
     2*G[{0, 1}, yw]*G[{yu^(-1), 1/(yu*yv), yv^(-1)}, yw] - 
     2*G[{0, yu^(-1)}, yw]*G[{yu^(-1), 1/(yu*yv), yv^(-1)}, yw] - 
     2*G[{0, yu}, yv^(-1)]*G[{yu^(-1), 1/(yu*yv), yv^(-1)}, yw] - 
     2*G[{0, yv^(-1)}, yw]*G[{yu^(-1), 1/(yu*yv), yv^(-1)}, yw] + 
     2*G[{0, 1/(yu*yv)}, yw]*G[{yu^(-1), 1/(yu*yv), yv^(-1)}, yw] + 
     4*G[{1, yu^(-1)}, yw]*G[{yu^(-1), 1/(yu*yv), yv^(-1)}, yw] + 
     4*G[{1, yu}, yv^(-1)]*G[{yu^(-1), 1/(yu*yv), yv^(-1)}, yw] - 
     (Pi^2*G[{yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/3 + 
     2*G[{0}, yu^(-1)]^2*G[{yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] + 
     4*G[{0}, yu^(-1)]*G[{0}, yv^(-1)]*G[{yu^(-1), 1/(yu*yv), 1/(yu*yv)}, 
       yw] + 2*G[{0}, yv^(-1)]^2*G[{yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] - 
     4*G[{0}, yu^(-1)]*G[{0}, yw]*G[{yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] - 
     4*G[{0}, yv^(-1)]*G[{0}, yw]*G[{yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] + 
     2*G[{0}, yw]^2*G[{yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] - 
     2*G[{0}, yu^(-1)]*G[{1}, yu^(-1)]*G[{yu^(-1), 1/(yu*yv), 1/(yu*yv)}, 
       yw] - 2*G[{0}, yv^(-1)]*G[{1}, yu^(-1)]*
      G[{yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] + 2*G[{0}, yw]*G[{1}, yu^(-1)]*
      G[{yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] - 4*G[{0}, yu^(-1)]*
      G[{1}, yv^(-1)]*G[{yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] - 
     4*G[{0}, yv^(-1)]*G[{1}, yv^(-1)]*G[{yu^(-1), 1/(yu*yv), 1/(yu*yv)}, 
       yw] + 4*G[{0}, yw]*G[{1}, yv^(-1)]*G[{yu^(-1), 1/(yu*yv), 1/(yu*yv)}, 
       yw] + 4*G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*
      G[{yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] + 2*G[{1}, yv^(-1)]^2*
      G[{yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] + 4*G[{0}, yu^(-1)]*G[{1}, yw]*
      G[{yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] + 4*G[{0}, yv^(-1)]*G[{1}, yw]*
      G[{yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] - 4*G[{0}, yw]*G[{1}, yw]*
      G[{yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] - 4*G[{1}, yu^(-1)]*G[{1}, yw]*
      G[{yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] - 4*G[{1}, yv^(-1)]*G[{1}, yw]*
      G[{yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] + 2*G[{0}, yu^(-1)]*
      G[{yu^(-1)}, yw]*G[{yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] + 
     2*G[{0}, yv^(-1)]*G[{yu^(-1)}, yw]*G[{yu^(-1), 1/(yu*yv), 1/(yu*yv)}, 
       yw] - 2*G[{0}, yw]*G[{yu^(-1)}, yw]*G[{yu^(-1), 1/(yu*yv), 1/(yu*yv)}, 
       yw] - 2*G[{1}, yv^(-1)]*G[{yu^(-1)}, yw]*
      G[{yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] + 2*G[{1}, yw]*G[{yu^(-1)}, yw]*
      G[{yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] + G[{yu^(-1)}, yw]^2*
      G[{yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] - 2*G[{0}, yu^(-1)]*
      G[{yu}, yv^(-1)]*G[{yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] - 
     2*G[{0}, yv^(-1)]*G[{yu}, yv^(-1)]*G[{yu^(-1), 1/(yu*yv), 1/(yu*yv)}, 
       yw] + 2*G[{0}, yw]*G[{yu}, yv^(-1)]*G[{yu^(-1), 1/(yu*yv), 1/(yu*yv)}, 
       yw] + 2*G[{1}, yv^(-1)]*G[{yu}, yv^(-1)]*
      G[{yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] - 2*G[{yu^(-1)}, yw]*
      G[{yu}, yv^(-1)]*G[{yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] + 
     G[{yu}, yv^(-1)]^2*G[{yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] + 
     2*G[{0}, yu^(-1)]*G[{1/(yu*yv)}, yw]*G[{yu^(-1), 1/(yu*yv), 1/(yu*yv)}, 
       yw] + 2*G[{0}, yv^(-1)]*G[{1/(yu*yv)}, yw]*
      G[{yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] - 
     2*G[{0}, yw]*G[{1/(yu*yv)}, yw]*G[{yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] + 
     4*G[{1}, yu^(-1)]*G[{1/(yu*yv)}, yw]*G[{yu^(-1), 1/(yu*yv), 1/(yu*yv)}, 
       yw] - 2*G[{1}, yv^(-1)]*G[{1/(yu*yv)}, yw]*
      G[{yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] + 
     6*G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] + 
     2*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{yu^(-1), 1/(yu*yv), 1/(yu*yv)}, 
       yw] - 6*G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw]*
      G[{yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] + 2*G[{0, 1}, yu^(-1)]*
      G[{yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] + 2*G[{0, 1}, yw]*
      G[{yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] - 2*G[{0, yu^(-1)}, yw]*
      G[{yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] - 2*G[{0, yv^(-1)}, yw]*
      G[{yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] + 2*G[{0, 1/(yu*yv)}, yw]*
      G[{yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] + 2*G[{1, yu^(-1)}, yw]*
      G[{yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] - 2*G[{1, yu}, yv^(-1)]*
      G[{yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] + 4*G[{1, yv^(-1)}, yw]*
      G[{yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] - 2*G[{1, 1/(yu*yv)}, yw]*
      G[{yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] - 2*G[{yu^(-1), 1/(yu*yv)}, yw]*
      G[{yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] - 4*G[{0}, yu^(-1)]*
      G[{1/(yu*yv)}, yw]*G[{yv^(-1), yv^(-1), 1/(yu*yv)}, yw] - 
     4*G[{0}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{yv^(-1), yv^(-1), 1/(yu*yv)}, 
       yw] + 4*G[{0}, yw]*G[{1/(yu*yv)}, yw]*G[{yv^(-1), yv^(-1), 1/(yu*yv)}, 
       yw] + 8*G[{1}, yu^(-1)]*G[{1/(yu*yv)}, yw]*
      G[{yv^(-1), yv^(-1), 1/(yu*yv)}, yw] + 4*G[{1}, yv^(-1)]*
      G[{1/(yu*yv)}, yw]*G[{yv^(-1), yv^(-1), 1/(yu*yv)}, yw] + 
     4*G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{yv^(-1), yv^(-1), 1/(yu*yv)}, yw] - 
     4*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{yv^(-1), yv^(-1), 1/(yu*yv)}, 
       yw] - 4*G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw]*
      G[{yv^(-1), yv^(-1), 1/(yu*yv)}, yw] - 8*G[{yv^(-1)}, yw]*
      G[{1/(yu*yv)}, yw]*G[{yv^(-1), yv^(-1), 1/(yu*yv)}, yw] - 
     2*G[{1/(yu*yv)}, yw]^2*G[{yv^(-1), yv^(-1), 1/(yu*yv)}, yw] - 
     (Pi^2*G[{yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/3 + 
     2*G[{0}, yu^(-1)]*G[{1}, yu^(-1)]*G[{yv^(-1), 1/(yu*yv), 1/(yu*yv)}, 
       yw] + 2*G[{0}, yv^(-1)]*G[{1}, yu^(-1)]*
      G[{yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] - 2*G[{0}, yw]*G[{1}, yu^(-1)]*
      G[{yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] - 2*G[{1}, yu^(-1)]^2*
      G[{yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] - 4*G[{1}, yu^(-1)]*
      G[{1}, yv^(-1)]*G[{yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] + 
     4*G[{0}, yu^(-1)]*G[{1}, yw]*G[{yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] + 
     4*G[{0}, yv^(-1)]*G[{1}, yw]*G[{yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] - 
     4*G[{0}, yw]*G[{1}, yw]*G[{yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] - 
     4*G[{1}, yu^(-1)]*G[{1}, yw]*G[{yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] - 
     4*G[{1}, yv^(-1)]*G[{1}, yw]*G[{yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] - 
     2*G[{0}, yu^(-1)]*G[{yu^(-1)}, yw]*G[{yv^(-1), 1/(yu*yv), 1/(yu*yv)}, 
       yw] - 2*G[{0}, yv^(-1)]*G[{yu^(-1)}, yw]*
      G[{yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] + 2*G[{0}, yw]*G[{yu^(-1)}, yw]*
      G[{yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] + 4*G[{1}, yu^(-1)]*
      G[{yu^(-1)}, yw]*G[{yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] - 
     2*G[{0}, yu^(-1)]*G[{yu}, yv^(-1)]*G[{yv^(-1), 1/(yu*yv), 1/(yu*yv)}, 
       yw] - 2*G[{0}, yv^(-1)]*G[{yu}, yv^(-1)]*
      G[{yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] + 2*G[{0}, yw]*G[{yu}, yv^(-1)]*
      G[{yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] + 4*G[{1}, yu^(-1)]*
      G[{yu}, yv^(-1)]*G[{yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] - 
     4*G[{0}, yu^(-1)]*G[{yv^(-1)}, yw]*G[{yv^(-1), 1/(yu*yv), 1/(yu*yv)}, 
       yw] - 4*G[{0}, yv^(-1)]*G[{yv^(-1)}, yw]*
      G[{yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] + 4*G[{0}, yw]*G[{yv^(-1)}, yw]*
      G[{yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] + 8*G[{1}, yu^(-1)]*
      G[{yv^(-1)}, yw]*G[{yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] + 
     4*G[{1}, yv^(-1)]*G[{yv^(-1)}, yw]*G[{yv^(-1), 1/(yu*yv), 1/(yu*yv)}, 
       yw] + 4*G[{1}, yw]*G[{yv^(-1)}, yw]*G[{yv^(-1), 1/(yu*yv), 1/(yu*yv)}, 
       yw] - 4*G[{yu^(-1)}, yw]*G[{yv^(-1)}, yw]*
      G[{yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] - 4*G[{yu}, yv^(-1)]*
      G[{yv^(-1)}, yw]*G[{yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] - 
     4*G[{yv^(-1)}, yw]^2*G[{yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] - 
     2*G[{0}, yu^(-1)]*G[{1/(yu*yv)}, yw]*G[{yv^(-1), 1/(yu*yv), 1/(yu*yv)}, 
       yw] - 2*G[{0}, yv^(-1)]*G[{1/(yu*yv)}, yw]*
      G[{yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] + 
     2*G[{0}, yw]*G[{1/(yu*yv)}, yw]*G[{yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] + 
     4*G[{1}, yu^(-1)]*G[{1/(yu*yv)}, yw]*G[{yv^(-1), 1/(yu*yv), 1/(yu*yv)}, 
       yw] + 4*G[{1}, yv^(-1)]*G[{1/(yu*yv)}, yw]*
      G[{yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] + 
     4*G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] - 
     4*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{yv^(-1), 1/(yu*yv), 1/(yu*yv)}, 
       yw] - 4*G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw]*
      G[{yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] - 4*G[{yv^(-1)}, yw]*
      G[{1/(yu*yv)}, yw]*G[{yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] - 
     2*G[{0, 1}, yu^(-1)]*G[{yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] + 
     2*G[{0, 1}, yv^(-1)]*G[{yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] + 
     2*G[{0, 1}, yw]*G[{yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] - 
     2*G[{0, yu^(-1)}, yw]*G[{yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] - 
     2*G[{0, yu}, yv^(-1)]*G[{yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] - 
     2*G[{0, yv^(-1)}, yw]*G[{yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] + 
     2*G[{0, 1/(yu*yv)}, yw]*G[{yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] + 
     4*G[{1, yu^(-1)}, yw]*G[{yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] + 
     4*G[{1, yu}, yv^(-1)]*G[{yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] - 
     4*G[{yv^(-1), 1/(yu*yv)}, yw]*G[{yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] - 
     4*G[{0}, yu^(-1)]*G[{0, 0, 1, 1}, yu^(-1)] - 
     4*G[{0}, yv^(-1)]*G[{0, 0, 1, 1}, yu^(-1)] + 
     4*G[{0}, yw]*G[{0, 0, 1, 1}, yu^(-1)] + 4*G[{yu}, yv^(-1)]*
      G[{0, 0, 1, 1}, yu^(-1)] - 4*G[{1/(yu*yv)}, yw]*
      G[{0, 0, 1, 1}, yu^(-1)] + 4*G[{0}, yu^(-1)]*G[{0, 0, 1, 1}, yv^(-1)] + 
     4*G[{0}, yv^(-1)]*G[{0, 0, 1, 1}, yv^(-1)] - 
     4*G[{0}, yw]*G[{0, 0, 1, 1}, yv^(-1)] + 4*G[{yu^(-1)}, yw]*
      G[{0, 0, 1, 1}, yv^(-1)] + 4*G[{yu^(-1)}, yw]*G[{0, 0, 1, 1}, yw] + 
     4*G[{0}, yu^(-1)]*G[{0, 0, 1, yu^(-1)}, yw] + 
     4*G[{0}, yv^(-1)]*G[{0, 0, 1, yu^(-1)}, yw] - 
     4*G[{0}, yw]*G[{0, 0, 1, yu^(-1)}, yw] - 4*G[{1}, yu^(-1)]*
      G[{0, 0, 1, yu^(-1)}, yw] - 4*G[{1}, yv^(-1)]*G[{0, 0, 1, yu^(-1)}, 
       yw] - 4*G[{yu^(-1)}, yw]*G[{0, 0, 1, yu^(-1)}, yw] - 
     4*G[{0}, yu^(-1)]*G[{0, 0, 1, yu}, yv^(-1)] - 
     4*G[{0}, yv^(-1)]*G[{0, 0, 1, yu}, yv^(-1)] + 
     4*G[{0}, yw]*G[{0, 0, 1, yu}, yv^(-1)] + 4*G[{yu}, yv^(-1)]*
      G[{0, 0, 1, yu}, yv^(-1)] - 4*G[{1/(yu*yv)}, yw]*
      G[{0, 0, 1, yu}, yv^(-1)] - 4*G[{yu^(-1)}, yw]*
      G[{0, 0, 1, yv^(-1)}, yw] - 4*G[{0}, yu^(-1)]*G[{0, 0, 1, 1/(yu*yv)}, 
       yw] - 4*G[{0}, yv^(-1)]*G[{0, 0, 1, 1/(yu*yv)}, yw] + 
     4*G[{0}, yw]*G[{0, 0, 1, 1/(yu*yv)}, yw] + 4*G[{1}, yv^(-1)]*
      G[{0, 0, 1, 1/(yu*yv)}, yw] + 8*G[{yu^(-1)}, yw]*
      G[{0, 0, 1, 1/(yu*yv)}, yw] + 4*G[{yu}, yv^(-1)]*
      G[{0, 0, 1, 1/(yu*yv)}, yw] - 4*G[{1/(yu*yv)}, yw]*
      G[{0, 0, 1, 1/(yu*yv)}, yw] + 4*G[{0}, yu^(-1)]*
      G[{0, 0, yu^(-1), 1}, yw] + 4*G[{0}, yv^(-1)]*G[{0, 0, yu^(-1), 1}, 
       yw] - 4*G[{0}, yw]*G[{0, 0, yu^(-1), 1}, yw] - 
     4*G[{1}, yu^(-1)]*G[{0, 0, yu^(-1), 1}, yw] - 
     4*G[{1}, yv^(-1)]*G[{0, 0, yu^(-1), 1}, yw] - 
     8*G[{yu^(-1)}, yw]*G[{0, 0, yu^(-1), 1}, yw] + 
     4*G[{1/(yu*yv)}, yw]*G[{0, 0, yu^(-1), 1}, yw] - 
     4*G[{0}, yu^(-1)]*G[{0, 0, yu^(-1), yu^(-1)}, yw] - 
     4*G[{0}, yv^(-1)]*G[{0, 0, yu^(-1), yu^(-1)}, yw] + 
     4*G[{0}, yw]*G[{0, 0, yu^(-1), yu^(-1)}, yw] + 
     4*G[{1}, yu^(-1)]*G[{0, 0, yu^(-1), yu^(-1)}, yw] + 
     4*G[{1}, yv^(-1)]*G[{0, 0, yu^(-1), yu^(-1)}, yw] + 
     4*G[{yu^(-1)}, yw]*G[{0, 0, yu^(-1), yu^(-1)}, yw] + 
     4*G[{1}, yu^(-1)]*G[{0, 0, yu^(-1), yv^(-1)}, yw] - 
     4*G[{yu}, yv^(-1)]*G[{0, 0, yu^(-1), yv^(-1)}, yw] + 
     4*G[{1/(yu*yv)}, yw]*G[{0, 0, yu^(-1), yv^(-1)}, yw] + 
     4*G[{0}, yu^(-1)]*G[{0, 0, yu^(-1), 1/(yu*yv)}, yw] + 
     4*G[{0}, yv^(-1)]*G[{0, 0, yu^(-1), 1/(yu*yv)}, yw] - 
     4*G[{0}, yw]*G[{0, 0, yu^(-1), 1/(yu*yv)}, yw] - 
     4*G[{1}, yu^(-1)]*G[{0, 0, yu^(-1), 1/(yu*yv)}, yw] - 
     4*G[{1}, yv^(-1)]*G[{0, 0, yu^(-1), 1/(yu*yv)}, yw] - 
     4*G[{yu^(-1)}, yw]*G[{0, 0, yu^(-1), 1/(yu*yv)}, yw] - 
     4*G[{0}, yu^(-1)]*G[{0, 0, yu, 1}, yv^(-1)] - 
     4*G[{0}, yv^(-1)]*G[{0, 0, yu, 1}, yv^(-1)] + 
     4*G[{0}, yw]*G[{0, 0, yu, 1}, yv^(-1)] + 4*G[{1}, yu^(-1)]*
      G[{0, 0, yu, 1}, yv^(-1)] + 4*G[{yu}, yv^(-1)]*
      G[{0, 0, yu, 1}, yv^(-1)] - 4*G[{1/(yu*yv)}, yw]*
      G[{0, 0, yu, 1}, yv^(-1)] - 4*G[{yu}, yv^(-1)]*
      G[{0, 0, yu, yu}, yv^(-1)] + 4*G[{1/(yu*yv)}, yw]*
      G[{0, 0, yu, yu}, yv^(-1)] - 8*G[{yu^(-1)}, yw]*
      G[{0, 0, yv^(-1), 1}, yw] + 4*G[{1/(yu*yv)}, yw]*
      G[{0, 0, yv^(-1), 1}, yw] + 4*G[{1}, yu^(-1)]*
      G[{0, 0, yv^(-1), yu^(-1)}, yw] - 4*G[{yu}, yv^(-1)]*
      G[{0, 0, yv^(-1), yu^(-1)}, yw] + 4*G[{1/(yu*yv)}, yw]*
      G[{0, 0, yv^(-1), yu^(-1)}, yw] + 4*G[{yu^(-1)}, yw]*
      G[{0, 0, yv^(-1), yv^(-1)}, yw] + 4*G[{0}, yu^(-1)]*
      G[{0, 0, yv^(-1), 1/(yu*yv)}, yw] + 4*G[{0}, yv^(-1)]*
      G[{0, 0, yv^(-1), 1/(yu*yv)}, yw] - 4*G[{0}, yw]*
      G[{0, 0, yv^(-1), 1/(yu*yv)}, yw] - 4*G[{1}, yu^(-1)]*
      G[{0, 0, yv^(-1), 1/(yu*yv)}, yw] - 4*G[{1}, yv^(-1)]*
      G[{0, 0, yv^(-1), 1/(yu*yv)}, yw] - 4*G[{yu^(-1)}, yw]*
      G[{0, 0, yv^(-1), 1/(yu*yv)}, yw] - 4*G[{0}, yu^(-1)]*
      G[{0, 0, 1/(yu*yv), 1}, yw] - 4*G[{0}, yv^(-1)]*
      G[{0, 0, 1/(yu*yv), 1}, yw] + 4*G[{0}, yw]*G[{0, 0, 1/(yu*yv), 1}, 
       yw] + 4*G[{1}, yu^(-1)]*G[{0, 0, 1/(yu*yv), 1}, yw] + 
     4*G[{1}, yv^(-1)]*G[{0, 0, 1/(yu*yv), 1}, yw] + 
     12*G[{yu^(-1)}, yw]*G[{0, 0, 1/(yu*yv), 1}, yw] - 
     8*G[{1/(yu*yv)}, yw]*G[{0, 0, 1/(yu*yv), 1}, yw] + 
     4*G[{0}, yu^(-1)]*G[{0, 0, 1/(yu*yv), yu^(-1)}, yw] + 
     4*G[{0}, yv^(-1)]*G[{0, 0, 1/(yu*yv), yu^(-1)}, yw] - 
     4*G[{0}, yw]*G[{0, 0, 1/(yu*yv), yu^(-1)}, yw] - 
     8*G[{1}, yu^(-1)]*G[{0, 0, 1/(yu*yv), yu^(-1)}, yw] - 
     4*G[{1}, yv^(-1)]*G[{0, 0, 1/(yu*yv), yu^(-1)}, yw] - 
     4*G[{yu^(-1)}, yw]*G[{0, 0, 1/(yu*yv), yu^(-1)}, yw] + 
     4*G[{yu}, yv^(-1)]*G[{0, 0, 1/(yu*yv), yu^(-1)}, yw] + 
     4*G[{0}, yu^(-1)]*G[{0, 0, 1/(yu*yv), yv^(-1)}, yw] + 
     4*G[{0}, yv^(-1)]*G[{0, 0, 1/(yu*yv), yv^(-1)}, yw] - 
     4*G[{0}, yw]*G[{0, 0, 1/(yu*yv), yv^(-1)}, yw] - 
     8*G[{1}, yu^(-1)]*G[{0, 0, 1/(yu*yv), yv^(-1)}, yw] - 
     4*G[{1}, yv^(-1)]*G[{0, 0, 1/(yu*yv), yv^(-1)}, yw] - 
     4*G[{yu^(-1)}, yw]*G[{0, 0, 1/(yu*yv), yv^(-1)}, yw] + 
     4*G[{yu}, yv^(-1)]*G[{0, 0, 1/(yu*yv), yv^(-1)}, yw] - 
     4*G[{0}, yu^(-1)]*G[{0, 0, 1/(yu*yv), 1/(yu*yv)}, yw] - 
     4*G[{0}, yv^(-1)]*G[{0, 0, 1/(yu*yv), 1/(yu*yv)}, yw] + 
     4*G[{0}, yw]*G[{0, 0, 1/(yu*yv), 1/(yu*yv)}, yw] + 
     8*G[{1}, yu^(-1)]*G[{0, 0, 1/(yu*yv), 1/(yu*yv)}, yw] + 
     4*G[{1}, yv^(-1)]*G[{0, 0, 1/(yu*yv), 1/(yu*yv)}, yw] - 
     4*G[{yu}, yv^(-1)]*G[{0, 0, 1/(yu*yv), 1/(yu*yv)}, yw] + 
     4*G[{1/(yu*yv)}, yw]*G[{0, 0, 1/(yu*yv), 1/(yu*yv)}, yw] + 
     2*G[{0}, yu^(-1)]*G[{0, 1, 0, yu^(-1)}, yw] + 
     2*G[{0}, yv^(-1)]*G[{0, 1, 0, yu^(-1)}, yw] - 
     2*G[{0}, yw]*G[{0, 1, 0, yu^(-1)}, yw] - 2*G[{1}, yu^(-1)]*
      G[{0, 1, 0, yu^(-1)}, yw] - 2*G[{1}, yv^(-1)]*G[{0, 1, 0, yu^(-1)}, 
       yw] - 2*G[{yu^(-1)}, yw]*G[{0, 1, 0, yu^(-1)}, yw] + 
     2*G[{1/(yu*yv)}, yw]*G[{0, 1, 0, yu^(-1)}, yw] - 
     2*G[{0}, yu^(-1)]*G[{0, 1, 0, yu}, yv^(-1)] - 
     2*G[{0}, yv^(-1)]*G[{0, 1, 0, yu}, yv^(-1)] + 
     2*G[{0}, yw]*G[{0, 1, 0, yu}, yv^(-1)] + 2*G[{1}, yu^(-1)]*
      G[{0, 1, 0, yu}, yv^(-1)] + 2*G[{yu^(-1)}, yw]*
      G[{0, 1, 0, yu}, yv^(-1)] + 2*G[{yu}, yv^(-1)]*
      G[{0, 1, 0, yu}, yv^(-1)] - 2*G[{1/(yu*yv)}, yw]*
      G[{0, 1, 0, yu}, yv^(-1)] - 2*G[{yu^(-1)}, yw]*
      G[{0, 1, 0, yv^(-1)}, yw] + 2*G[{1/(yu*yv)}, yw]*
      G[{0, 1, 0, yv^(-1)}, yw] - 2*G[{0}, yu^(-1)]*G[{0, 1, 0, 1/(yu*yv)}, 
       yw] - 2*G[{0}, yv^(-1)]*G[{0, 1, 0, 1/(yu*yv)}, yw] + 
     2*G[{0}, yw]*G[{0, 1, 0, 1/(yu*yv)}, yw] + 2*G[{1}, yu^(-1)]*
      G[{0, 1, 0, 1/(yu*yv)}, yw] + 2*G[{1}, yv^(-1)]*
      G[{0, 1, 0, 1/(yu*yv)}, yw] + 4*G[{yu^(-1)}, yw]*
      G[{0, 1, 0, 1/(yu*yv)}, yw] - 4*G[{1/(yu*yv)}, yw]*
      G[{0, 1, 0, 1/(yu*yv)}, yw] - 6*G[{0}, yu^(-1)]*
      G[{0, 1, 1, 1}, yu^(-1)] - 6*G[{0}, yv^(-1)]*G[{0, 1, 1, 1}, yu^(-1)] + 
     6*G[{0}, yw]*G[{0, 1, 1, 1}, yu^(-1)] - 6*G[{1}, yu^(-1)]*
      G[{0, 1, 1, 1}, yu^(-1)] + 6*G[{yu^(-1)}, yw]*
      G[{0, 1, 1, 1}, yu^(-1)] + 6*G[{yu}, yv^(-1)]*
      G[{0, 1, 1, 1}, yu^(-1)] - 6*G[{1/(yu*yv)}, yw]*
      G[{0, 1, 1, 1}, yu^(-1)] + 4*G[{1}, yu^(-1)]*G[{0, 1, 1, 1}, yv^(-1)] + 
     6*G[{yu^(-1)}, yw]*G[{0, 1, 1, 1}, yv^(-1)] + 
     6*G[{yu}, yv^(-1)]*G[{0, 1, 1, 1}, yv^(-1)] - 6*G[{1/(yu*yv)}, yw]*
      G[{0, 1, 1, 1}, yv^(-1)] - 6*G[{0}, yu^(-1)]*G[{0, 1, 1, yu^(-1)}, 
       yw] - 6*G[{0}, yv^(-1)]*G[{0, 1, 1, yu^(-1)}, yw] + 
     6*G[{0}, yw]*G[{0, 1, 1, yu^(-1)}, yw] + 6*G[{1}, yu^(-1)]*
      G[{0, 1, 1, yu^(-1)}, yw] + 6*G[{1}, yv^(-1)]*G[{0, 1, 1, yu^(-1)}, 
       yw] + 6*G[{yu^(-1)}, yw]*G[{0, 1, 1, yu^(-1)}, yw] - 
     2*G[{1/(yu*yv)}, yw]*G[{0, 1, 1, yu^(-1)}, yw] + 
     6*G[{0}, yu^(-1)]*G[{0, 1, 1, yu}, yv^(-1)] + 
     6*G[{0}, yv^(-1)]*G[{0, 1, 1, yu}, yv^(-1)] - 
     6*G[{0}, yw]*G[{0, 1, 1, yu}, yv^(-1)] - 6*G[{1}, yu^(-1)]*
      G[{0, 1, 1, yu}, yv^(-1)] - 4*G[{yu}, yv^(-1)]*
      G[{0, 1, 1, yu}, yv^(-1)] + 4*G[{1/(yu*yv)}, yw]*
      G[{0, 1, 1, yu}, yv^(-1)] + 6*G[{yu^(-1)}, yw]*
      G[{0, 1, 1, yv^(-1)}, yw] - 2*G[{1/(yu*yv)}, yw]*
      G[{0, 1, 1, yv^(-1)}, yw] + 2*G[{0}, yu^(-1)]*G[{0, 1, 1, 1/(yu*yv)}, 
       yw] + 2*G[{0}, yv^(-1)]*G[{0, 1, 1, 1/(yu*yv)}, yw] - 
     2*G[{0}, yw]*G[{0, 1, 1, 1/(yu*yv)}, yw] - 2*G[{1}, yu^(-1)]*
      G[{0, 1, 1, 1/(yu*yv)}, yw] - 2*G[{1}, yv^(-1)]*
      G[{0, 1, 1, 1/(yu*yv)}, yw] - 4*G[{0}, yu^(-1)]*
      G[{0, 1, yu^(-1), 1}, yw] - 4*G[{0}, yv^(-1)]*G[{0, 1, yu^(-1), 1}, 
       yw] + 4*G[{0}, yw]*G[{0, 1, yu^(-1), 1}, yw] + 
     4*G[{1}, yu^(-1)]*G[{0, 1, yu^(-1), 1}, yw] + 
     4*G[{1}, yv^(-1)]*G[{0, 1, yu^(-1), 1}, yw] + 
     8*G[{yu^(-1)}, yw]*G[{0, 1, yu^(-1), 1}, yw] - 
     4*G[{1/(yu*yv)}, yw]*G[{0, 1, yu^(-1), 1}, yw] + 
     8*G[{0}, yu^(-1)]*G[{0, 1, yu^(-1), yu^(-1)}, yw] + 
     8*G[{0}, yv^(-1)]*G[{0, 1, yu^(-1), yu^(-1)}, yw] - 
     8*G[{0}, yw]*G[{0, 1, yu^(-1), yu^(-1)}, yw] - 
     8*G[{1}, yu^(-1)]*G[{0, 1, yu^(-1), yu^(-1)}, yw] - 
     8*G[{1}, yv^(-1)]*G[{0, 1, yu^(-1), yu^(-1)}, yw] - 
     8*G[{yu^(-1)}, yw]*G[{0, 1, yu^(-1), yu^(-1)}, yw] + 
     4*G[{0}, yu^(-1)]*G[{0, 1, yu^(-1), yv^(-1)}, yw] + 
     4*G[{0}, yv^(-1)]*G[{0, 1, yu^(-1), yv^(-1)}, yw] - 
     4*G[{0}, yw]*G[{0, 1, yu^(-1), yv^(-1)}, yw] - 
     8*G[{1}, yu^(-1)]*G[{0, 1, yu^(-1), yv^(-1)}, yw] - 
     4*G[{1}, yv^(-1)]*G[{0, 1, yu^(-1), yv^(-1)}, yw] - 
     4*G[{yu^(-1)}, yw]*G[{0, 1, yu^(-1), yv^(-1)}, yw] + 
     4*G[{yu}, yv^(-1)]*G[{0, 1, yu^(-1), yv^(-1)}, yw] - 
     4*G[{1/(yu*yv)}, yw]*G[{0, 1, yu^(-1), yv^(-1)}, yw] - 
     4*G[{0}, yu^(-1)]*G[{0, 1, yu^(-1), 1/(yu*yv)}, yw] - 
     4*G[{0}, yv^(-1)]*G[{0, 1, yu^(-1), 1/(yu*yv)}, yw] + 
     4*G[{0}, yw]*G[{0, 1, yu^(-1), 1/(yu*yv)}, yw] + 
     4*G[{1}, yu^(-1)]*G[{0, 1, yu^(-1), 1/(yu*yv)}, yw] + 
     4*G[{1}, yv^(-1)]*G[{0, 1, yu^(-1), 1/(yu*yv)}, yw] + 
     4*G[{1/(yu*yv)}, yw]*G[{0, 1, yu^(-1), 1/(yu*yv)}, yw] + 
     4*G[{0}, yu^(-1)]*G[{0, 1, yu, 1}, yv^(-1)] + 
     4*G[{0}, yv^(-1)]*G[{0, 1, yu, 1}, yv^(-1)] - 
     4*G[{0}, yw]*G[{0, 1, yu, 1}, yv^(-1)] - 4*G[{1}, yu^(-1)]*
      G[{0, 1, yu, 1}, yv^(-1)] - 4*G[{yu}, yv^(-1)]*
      G[{0, 1, yu, 1}, yv^(-1)] + 4*G[{1/(yu*yv)}, yw]*
      G[{0, 1, yu, 1}, yv^(-1)] - 4*G[{0}, yu^(-1)]*
      G[{0, 1, yu, yu}, yv^(-1)] - 4*G[{0}, yv^(-1)]*
      G[{0, 1, yu, yu}, yv^(-1)] + 4*G[{0}, yw]*G[{0, 1, yu, yu}, yv^(-1)] - 
     4*G[{yu^(-1)}, yw]*G[{0, 1, yu, yu}, yv^(-1)] + 
     4*G[{yu}, yv^(-1)]*G[{0, 1, yu, yu}, yv^(-1)] - 
     4*G[{1/(yu*yv)}, yw]*G[{0, 1, yu, yu}, yv^(-1)] + 
     8*G[{yu^(-1)}, yw]*G[{0, 1, yv^(-1), 1}, yw] - 
     4*G[{1/(yu*yv)}, yw]*G[{0, 1, yv^(-1), 1}, yw] + 
     4*G[{0}, yu^(-1)]*G[{0, 1, yv^(-1), yu^(-1)}, yw] + 
     4*G[{0}, yv^(-1)]*G[{0, 1, yv^(-1), yu^(-1)}, yw] - 
     4*G[{0}, yw]*G[{0, 1, yv^(-1), yu^(-1)}, yw] - 
     8*G[{1}, yu^(-1)]*G[{0, 1, yv^(-1), yu^(-1)}, yw] - 
     4*G[{1}, yv^(-1)]*G[{0, 1, yv^(-1), yu^(-1)}, yw] - 
     4*G[{yu^(-1)}, yw]*G[{0, 1, yv^(-1), yu^(-1)}, yw] + 
     4*G[{yu}, yv^(-1)]*G[{0, 1, yv^(-1), yu^(-1)}, yw] - 
     4*G[{1/(yu*yv)}, yw]*G[{0, 1, yv^(-1), yu^(-1)}, yw] - 
     8*G[{yu^(-1)}, yw]*G[{0, 1, yv^(-1), yv^(-1)}, yw] + 
     4*G[{1/(yu*yv)}, yw]*G[{0, 1, yv^(-1), 1/(yu*yv)}, yw] - 
     4*G[{yu^(-1)}, yw]*G[{0, 1, 1/(yu*yv), 1}, yw] + 
     4*G[{1/(yu*yv)}, yw]*G[{0, 1, 1/(yu*yv), 1}, yw] - 
     6*G[{0}, yu^(-1)]*G[{0, 1, 1/(yu*yv), yu^(-1)}, yw] - 
     6*G[{0}, yv^(-1)]*G[{0, 1, 1/(yu*yv), yu^(-1)}, yw] + 
     6*G[{0}, yw]*G[{0, 1, 1/(yu*yv), yu^(-1)}, yw] + 
     6*G[{1}, yu^(-1)]*G[{0, 1, 1/(yu*yv), yu^(-1)}, yw] + 
     6*G[{1}, yv^(-1)]*G[{0, 1, 1/(yu*yv), yu^(-1)}, yw] + 
     6*G[{yu^(-1)}, yw]*G[{0, 1, 1/(yu*yv), yu^(-1)}, yw] - 
     2*G[{1/(yu*yv)}, yw]*G[{0, 1, 1/(yu*yv), yu^(-1)}, yw] + 
     6*G[{yu^(-1)}, yw]*G[{0, 1, 1/(yu*yv), yv^(-1)}, yw] - 
     2*G[{1/(yu*yv)}, yw]*G[{0, 1, 1/(yu*yv), yv^(-1)}, yw] + 
     2*G[{0}, yu^(-1)]*G[{0, 1, 1/(yu*yv), 1/(yu*yv)}, yw] + 
     2*G[{0}, yv^(-1)]*G[{0, 1, 1/(yu*yv), 1/(yu*yv)}, yw] - 
     2*G[{0}, yw]*G[{0, 1, 1/(yu*yv), 1/(yu*yv)}, yw] - 
     6*G[{1}, yu^(-1)]*G[{0, 1, 1/(yu*yv), 1/(yu*yv)}, yw] - 
     2*G[{1}, yv^(-1)]*G[{0, 1, 1/(yu*yv), 1/(yu*yv)}, yw] + 
     4*G[{yu}, yv^(-1)]*G[{0, 1, 1/(yu*yv), 1/(yu*yv)}, yw] + 
     2*G[{0}, yu^(-1)]*G[{0, yu^(-1), 0, yv^(-1)}, yw] + 
     2*G[{0}, yv^(-1)]*G[{0, yu^(-1), 0, yv^(-1)}, yw] - 
     2*G[{0}, yw]*G[{0, yu^(-1), 0, yv^(-1)}, yw] - 
     2*G[{1}, yu^(-1)]*G[{0, yu^(-1), 0, yv^(-1)}, yw] - 
     2*G[{1}, yv^(-1)]*G[{0, yu^(-1), 0, yv^(-1)}, yw] - 
     2*G[{yu^(-1)}, yw]*G[{0, yu^(-1), 0, 1/(yu*yv)}, yw] + 
     2*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1), 0, 1/(yu*yv)}, yw] + 
     6*G[{0}, yu^(-1)]*G[{0, yu^(-1), 1, yu^(-1)}, yw] + 
     6*G[{0}, yv^(-1)]*G[{0, yu^(-1), 1, yu^(-1)}, yw] - 
     6*G[{0}, yw]*G[{0, yu^(-1), 1, yu^(-1)}, yw] - 
     6*G[{1}, yu^(-1)]*G[{0, yu^(-1), 1, yu^(-1)}, yw] - 
     6*G[{1}, yv^(-1)]*G[{0, yu^(-1), 1, yu^(-1)}, yw] - 
     6*G[{yu^(-1)}, yw]*G[{0, yu^(-1), 1, yu^(-1)}, yw] + 
     2*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1), 1, yu^(-1)}, yw] - 
     6*G[{yu^(-1)}, yw]*G[{0, yu^(-1), 1, yv^(-1)}, yw] + 
     2*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1), 1, yv^(-1)}, yw] - 
     2*G[{0}, yu^(-1)]*G[{0, yu^(-1), 1, 1/(yu*yv)}, yw] - 
     2*G[{0}, yv^(-1)]*G[{0, yu^(-1), 1, 1/(yu*yv)}, yw] + 
     2*G[{0}, yw]*G[{0, yu^(-1), 1, 1/(yu*yv)}, yw] + 
     2*G[{1}, yu^(-1)]*G[{0, yu^(-1), 1, 1/(yu*yv)}, yw] + 
     2*G[{1}, yv^(-1)]*G[{0, yu^(-1), 1, 1/(yu*yv)}, yw] + 
     4*G[{0}, yu^(-1)]*G[{0, yu^(-1), yu^(-1), 1}, yw] + 
     4*G[{0}, yv^(-1)]*G[{0, yu^(-1), yu^(-1), 1}, yw] - 
     4*G[{0}, yw]*G[{0, yu^(-1), yu^(-1), 1}, yw] - 
     4*G[{1}, yu^(-1)]*G[{0, yu^(-1), yu^(-1), 1}, yw] - 
     4*G[{1}, yv^(-1)]*G[{0, yu^(-1), yu^(-1), 1}, yw] - 
     8*G[{yu^(-1)}, yw]*G[{0, yu^(-1), yu^(-1), 1}, yw] + 
     4*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1), yu^(-1), 1}, yw] - 
     8*G[{0}, yu^(-1)]*G[{0, yu^(-1), yu^(-1), yu^(-1)}, yw] - 
     8*G[{0}, yv^(-1)]*G[{0, yu^(-1), yu^(-1), yu^(-1)}, yw] + 
     8*G[{0}, yw]*G[{0, yu^(-1), yu^(-1), yu^(-1)}, yw] + 
     8*G[{1}, yu^(-1)]*G[{0, yu^(-1), yu^(-1), yu^(-1)}, yw] + 
     8*G[{1}, yv^(-1)]*G[{0, yu^(-1), yu^(-1), yu^(-1)}, yw] + 
     8*G[{yu^(-1)}, yw]*G[{0, yu^(-1), yu^(-1), yu^(-1)}, yw] - 
     4*G[{0}, yu^(-1)]*G[{0, yu^(-1), yu^(-1), yv^(-1)}, yw] - 
     4*G[{0}, yv^(-1)]*G[{0, yu^(-1), yu^(-1), yv^(-1)}, yw] + 
     4*G[{0}, yw]*G[{0, yu^(-1), yu^(-1), yv^(-1)}, yw] + 
     8*G[{1}, yu^(-1)]*G[{0, yu^(-1), yu^(-1), yv^(-1)}, yw] + 
     4*G[{1}, yv^(-1)]*G[{0, yu^(-1), yu^(-1), yv^(-1)}, yw] + 
     4*G[{yu^(-1)}, yw]*G[{0, yu^(-1), yu^(-1), yv^(-1)}, yw] - 
     4*G[{yu}, yv^(-1)]*G[{0, yu^(-1), yu^(-1), yv^(-1)}, yw] + 
     4*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1), yu^(-1), yv^(-1)}, yw] + 
     4*G[{0}, yu^(-1)]*G[{0, yu^(-1), yu^(-1), 1/(yu*yv)}, yw] + 
     4*G[{0}, yv^(-1)]*G[{0, yu^(-1), yu^(-1), 1/(yu*yv)}, yw] - 
     4*G[{0}, yw]*G[{0, yu^(-1), yu^(-1), 1/(yu*yv)}, yw] - 
     4*G[{1}, yu^(-1)]*G[{0, yu^(-1), yu^(-1), 1/(yu*yv)}, yw] - 
     4*G[{1}, yv^(-1)]*G[{0, yu^(-1), yu^(-1), 1/(yu*yv)}, yw] - 
     4*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1), yu^(-1), 1/(yu*yv)}, yw] + 
     4*G[{0}, yu^(-1)]*G[{0, yu^(-1), yv^(-1), 1}, yw] + 
     4*G[{0}, yv^(-1)]*G[{0, yu^(-1), yv^(-1), 1}, yw] - 
     4*G[{0}, yw]*G[{0, yu^(-1), yv^(-1), 1}, yw] - 
     4*G[{1}, yu^(-1)]*G[{0, yu^(-1), yv^(-1), 1}, yw] - 
     4*G[{1}, yv^(-1)]*G[{0, yu^(-1), yv^(-1), 1}, yw] - 
     8*G[{yu^(-1)}, yw]*G[{0, yu^(-1), yv^(-1), 1}, yw] + 
     4*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1), yv^(-1), 1}, yw] - 
     4*G[{0}, yu^(-1)]*G[{0, yu^(-1), yv^(-1), yu^(-1)}, yw] - 
     4*G[{0}, yv^(-1)]*G[{0, yu^(-1), yv^(-1), yu^(-1)}, yw] + 
     4*G[{0}, yw]*G[{0, yu^(-1), yv^(-1), yu^(-1)}, yw] + 
     8*G[{1}, yu^(-1)]*G[{0, yu^(-1), yv^(-1), yu^(-1)}, yw] + 
     4*G[{1}, yv^(-1)]*G[{0, yu^(-1), yv^(-1), yu^(-1)}, yw] + 
     4*G[{yu^(-1)}, yw]*G[{0, yu^(-1), yv^(-1), yu^(-1)}, yw] - 
     4*G[{yu}, yv^(-1)]*G[{0, yu^(-1), yv^(-1), yu^(-1)}, yw] + 
     4*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1), yv^(-1), yu^(-1)}, yw] - 
     4*G[{0}, yu^(-1)]*G[{0, yu^(-1), yv^(-1), yv^(-1)}, yw] - 
     4*G[{0}, yv^(-1)]*G[{0, yu^(-1), yv^(-1), yv^(-1)}, yw] + 
     4*G[{0}, yw]*G[{0, yu^(-1), yv^(-1), yv^(-1)}, yw] + 
     8*G[{1}, yu^(-1)]*G[{0, yu^(-1), yv^(-1), yv^(-1)}, yw] + 
     4*G[{1}, yv^(-1)]*G[{0, yu^(-1), yv^(-1), yv^(-1)}, yw] + 
     4*G[{yu^(-1)}, yw]*G[{0, yu^(-1), yv^(-1), yv^(-1)}, yw] - 
     4*G[{yu}, yv^(-1)]*G[{0, yu^(-1), yv^(-1), yv^(-1)}, yw] + 
     4*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1), yv^(-1), yv^(-1)}, yw] - 
     4*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1), yv^(-1), 1/(yu*yv)}, yw] + 
     2*G[{0}, yu^(-1)]*G[{0, yu^(-1), 1/(yu*yv), yu^(-1)}, yw] + 
     2*G[{0}, yv^(-1)]*G[{0, yu^(-1), 1/(yu*yv), yu^(-1)}, yw] - 
     2*G[{0}, yw]*G[{0, yu^(-1), 1/(yu*yv), yu^(-1)}, yw] - 
     2*G[{1}, yu^(-1)]*G[{0, yu^(-1), 1/(yu*yv), yu^(-1)}, yw] - 
     2*G[{1}, yv^(-1)]*G[{0, yu^(-1), 1/(yu*yv), yu^(-1)}, yw] - 
     2*G[{yu^(-1)}, yw]*G[{0, yu^(-1), 1/(yu*yv), yu^(-1)}, yw] - 
     2*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1), 1/(yu*yv), yu^(-1)}, yw] - 
     2*G[{yu^(-1)}, yw]*G[{0, yu^(-1), 1/(yu*yv), yv^(-1)}, yw] - 
     2*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1), 1/(yu*yv), yv^(-1)}, yw] + 
     2*G[{0}, yu^(-1)]*G[{0, yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] + 
     2*G[{0}, yv^(-1)]*G[{0, yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] - 
     2*G[{0}, yw]*G[{0, yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] - 
     2*G[{1}, yu^(-1)]*G[{0, yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] - 
     2*G[{1}, yv^(-1)]*G[{0, yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] - 
     2*G[{yu^(-1)}, yw]*G[{0, yu, 1, 1}, yv^(-1)] - 
     2*G[{yu}, yv^(-1)]*G[{0, yu, 1, 1}, yv^(-1)] + 
     2*G[{1/(yu*yv)}, yw]*G[{0, yu, 1, 1}, yv^(-1)] - 
     2*G[{0}, yu^(-1)]*G[{0, yu, 1, yu}, yv^(-1)] - 
     2*G[{0}, yv^(-1)]*G[{0, yu, 1, yu}, yv^(-1)] + 
     2*G[{0}, yw]*G[{0, yu, 1, yu}, yv^(-1)] + 2*G[{1}, yu^(-1)]*
      G[{0, yu, 1, yu}, yv^(-1)] + 4*G[{yu}, yv^(-1)]*
      G[{0, yu, 1, yu}, yv^(-1)] - 4*G[{1/(yu*yv)}, yw]*
      G[{0, yu, 1, yu}, yv^(-1)] - 4*G[{0}, yu^(-1)]*
      G[{0, yu, yu, 1}, yv^(-1)] - 4*G[{0}, yv^(-1)]*
      G[{0, yu, yu, 1}, yv^(-1)] + 4*G[{0}, yw]*G[{0, yu, yu, 1}, yv^(-1)] + 
     4*G[{1}, yu^(-1)]*G[{0, yu, yu, 1}, yv^(-1)] + 
     4*G[{yu}, yv^(-1)]*G[{0, yu, yu, 1}, yv^(-1)] - 
     4*G[{1/(yu*yv)}, yw]*G[{0, yu, yu, 1}, yv^(-1)] - 
     8*G[{yu}, yv^(-1)]*G[{0, yu, yu, yu}, yv^(-1)] + 
     8*G[{1/(yu*yv)}, yw]*G[{0, yu, yu, yu}, yv^(-1)] + 
     2*G[{0}, yu^(-1)]*G[{0, yv^(-1), 0, 1/(yu*yv)}, yw] + 
     2*G[{0}, yv^(-1)]*G[{0, yv^(-1), 0, 1/(yu*yv)}, yw] - 
     2*G[{0}, yw]*G[{0, yv^(-1), 0, 1/(yu*yv)}, yw] - 
     2*G[{1}, yu^(-1)]*G[{0, yv^(-1), 0, 1/(yu*yv)}, yw] - 
     2*G[{1}, yv^(-1)]*G[{0, yv^(-1), 0, 1/(yu*yv)}, yw] - 
     2*G[{yu^(-1)}, yw]*G[{0, yv^(-1), 0, 1/(yu*yv)}, yw] + 
     2*G[{1/(yu*yv)}, yw]*G[{0, yv^(-1), 0, 1/(yu*yv)}, yw] + 
     6*G[{0}, yu^(-1)]*G[{0, yv^(-1), 1, yu^(-1)}, yw] + 
     6*G[{0}, yv^(-1)]*G[{0, yv^(-1), 1, yu^(-1)}, yw] - 
     6*G[{0}, yw]*G[{0, yv^(-1), 1, yu^(-1)}, yw] - 
     6*G[{1}, yu^(-1)]*G[{0, yv^(-1), 1, yu^(-1)}, yw] - 
     6*G[{1}, yv^(-1)]*G[{0, yv^(-1), 1, yu^(-1)}, yw] - 
     6*G[{yu^(-1)}, yw]*G[{0, yv^(-1), 1, yu^(-1)}, yw] + 
     2*G[{1/(yu*yv)}, yw]*G[{0, yv^(-1), 1, yu^(-1)}, yw] - 
     6*G[{yu^(-1)}, yw]*G[{0, yv^(-1), 1, yv^(-1)}, yw] + 
     2*G[{1/(yu*yv)}, yw]*G[{0, yv^(-1), 1, yv^(-1)}, yw] - 
     2*G[{0}, yu^(-1)]*G[{0, yv^(-1), 1, 1/(yu*yv)}, yw] - 
     2*G[{0}, yv^(-1)]*G[{0, yv^(-1), 1, 1/(yu*yv)}, yw] + 
     2*G[{0}, yw]*G[{0, yv^(-1), 1, 1/(yu*yv)}, yw] + 
     2*G[{1}, yu^(-1)]*G[{0, yv^(-1), 1, 1/(yu*yv)}, yw] + 
     2*G[{1}, yv^(-1)]*G[{0, yv^(-1), 1, 1/(yu*yv)}, yw] + 
     4*G[{0}, yu^(-1)]*G[{0, yv^(-1), yu^(-1), 1}, yw] + 
     4*G[{0}, yv^(-1)]*G[{0, yv^(-1), yu^(-1), 1}, yw] - 
     4*G[{0}, yw]*G[{0, yv^(-1), yu^(-1), 1}, yw] - 
     4*G[{1}, yu^(-1)]*G[{0, yv^(-1), yu^(-1), 1}, yw] - 
     4*G[{1}, yv^(-1)]*G[{0, yv^(-1), yu^(-1), 1}, yw] - 
     8*G[{yu^(-1)}, yw]*G[{0, yv^(-1), yu^(-1), 1}, yw] + 
     4*G[{1/(yu*yv)}, yw]*G[{0, yv^(-1), yu^(-1), 1}, yw] - 
     4*G[{0}, yu^(-1)]*G[{0, yv^(-1), yu^(-1), yu^(-1)}, yw] - 
     4*G[{0}, yv^(-1)]*G[{0, yv^(-1), yu^(-1), yu^(-1)}, yw] + 
     4*G[{0}, yw]*G[{0, yv^(-1), yu^(-1), yu^(-1)}, yw] + 
     8*G[{1}, yu^(-1)]*G[{0, yv^(-1), yu^(-1), yu^(-1)}, yw] + 
     4*G[{1}, yv^(-1)]*G[{0, yv^(-1), yu^(-1), yu^(-1)}, yw] + 
     4*G[{yu^(-1)}, yw]*G[{0, yv^(-1), yu^(-1), yu^(-1)}, yw] - 
     4*G[{yu}, yv^(-1)]*G[{0, yv^(-1), yu^(-1), yu^(-1)}, yw] + 
     4*G[{1/(yu*yv)}, yw]*G[{0, yv^(-1), yu^(-1), yu^(-1)}, yw] - 
     4*G[{0}, yu^(-1)]*G[{0, yv^(-1), yu^(-1), yv^(-1)}, yw] - 
     4*G[{0}, yv^(-1)]*G[{0, yv^(-1), yu^(-1), yv^(-1)}, yw] + 
     4*G[{0}, yw]*G[{0, yv^(-1), yu^(-1), yv^(-1)}, yw] + 
     8*G[{1}, yu^(-1)]*G[{0, yv^(-1), yu^(-1), yv^(-1)}, yw] + 
     4*G[{1}, yv^(-1)]*G[{0, yv^(-1), yu^(-1), yv^(-1)}, yw] + 
     4*G[{yu^(-1)}, yw]*G[{0, yv^(-1), yu^(-1), yv^(-1)}, yw] - 
     4*G[{yu}, yv^(-1)]*G[{0, yv^(-1), yu^(-1), yv^(-1)}, yw] + 
     4*G[{1/(yu*yv)}, yw]*G[{0, yv^(-1), yu^(-1), yv^(-1)}, yw] - 
     4*G[{1/(yu*yv)}, yw]*G[{0, yv^(-1), yu^(-1), 1/(yu*yv)}, yw] - 
     8*G[{yu^(-1)}, yw]*G[{0, yv^(-1), yv^(-1), 1}, yw] + 
     4*G[{1/(yu*yv)}, yw]*G[{0, yv^(-1), yv^(-1), 1}, yw] - 
     4*G[{0}, yu^(-1)]*G[{0, yv^(-1), yv^(-1), yu^(-1)}, yw] - 
     4*G[{0}, yv^(-1)]*G[{0, yv^(-1), yv^(-1), yu^(-1)}, yw] + 
     4*G[{0}, yw]*G[{0, yv^(-1), yv^(-1), yu^(-1)}, yw] + 
     8*G[{1}, yu^(-1)]*G[{0, yv^(-1), yv^(-1), yu^(-1)}, yw] + 
     4*G[{1}, yv^(-1)]*G[{0, yv^(-1), yv^(-1), yu^(-1)}, yw] + 
     4*G[{yu^(-1)}, yw]*G[{0, yv^(-1), yv^(-1), yu^(-1)}, yw] - 
     4*G[{yu}, yv^(-1)]*G[{0, yv^(-1), yv^(-1), yu^(-1)}, yw] + 
     4*G[{1/(yu*yv)}, yw]*G[{0, yv^(-1), yv^(-1), yu^(-1)}, yw] + 
     8*G[{yu^(-1)}, yw]*G[{0, yv^(-1), yv^(-1), yv^(-1)}, yw] - 
     4*G[{1/(yu*yv)}, yw]*G[{0, yv^(-1), yv^(-1), 1/(yu*yv)}, yw] + 
     2*G[{0}, yu^(-1)]*G[{0, yv^(-1), 1/(yu*yv), yu^(-1)}, yw] + 
     2*G[{0}, yv^(-1)]*G[{0, yv^(-1), 1/(yu*yv), yu^(-1)}, yw] - 
     2*G[{0}, yw]*G[{0, yv^(-1), 1/(yu*yv), yu^(-1)}, yw] - 
     2*G[{1}, yu^(-1)]*G[{0, yv^(-1), 1/(yu*yv), yu^(-1)}, yw] - 
     2*G[{1}, yv^(-1)]*G[{0, yv^(-1), 1/(yu*yv), yu^(-1)}, yw] - 
     2*G[{yu^(-1)}, yw]*G[{0, yv^(-1), 1/(yu*yv), yu^(-1)}, yw] - 
     2*G[{1/(yu*yv)}, yw]*G[{0, yv^(-1), 1/(yu*yv), yu^(-1)}, yw] - 
     2*G[{yu^(-1)}, yw]*G[{0, yv^(-1), 1/(yu*yv), yv^(-1)}, yw] - 
     2*G[{1/(yu*yv)}, yw]*G[{0, yv^(-1), 1/(yu*yv), yv^(-1)}, yw] + 
     2*G[{0}, yu^(-1)]*G[{0, yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] + 
     2*G[{0}, yv^(-1)]*G[{0, yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] - 
     2*G[{0}, yw]*G[{0, yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] - 
     2*G[{1}, yu^(-1)]*G[{0, yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] - 
     2*G[{1}, yv^(-1)]*G[{0, yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] - 
     6*G[{0}, yu^(-1)]*G[{0, 1/(yu*yv), 1, yu^(-1)}, yw] - 
     6*G[{0}, yv^(-1)]*G[{0, 1/(yu*yv), 1, yu^(-1)}, yw] + 
     6*G[{0}, yw]*G[{0, 1/(yu*yv), 1, yu^(-1)}, yw] + 
     6*G[{1}, yu^(-1)]*G[{0, 1/(yu*yv), 1, yu^(-1)}, yw] + 
     6*G[{1}, yv^(-1)]*G[{0, 1/(yu*yv), 1, yu^(-1)}, yw] + 
     6*G[{yu^(-1)}, yw]*G[{0, 1/(yu*yv), 1, yu^(-1)}, yw] - 
     2*G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv), 1, yu^(-1)}, yw] + 
     6*G[{yu^(-1)}, yw]*G[{0, 1/(yu*yv), 1, yv^(-1)}, yw] - 
     2*G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv), 1, yv^(-1)}, yw] + 
     2*G[{0}, yu^(-1)]*G[{0, 1/(yu*yv), 1, 1/(yu*yv)}, yw] + 
     2*G[{0}, yv^(-1)]*G[{0, 1/(yu*yv), 1, 1/(yu*yv)}, yw] - 
     2*G[{0}, yw]*G[{0, 1/(yu*yv), 1, 1/(yu*yv)}, yw] - 
     2*G[{1}, yu^(-1)]*G[{0, 1/(yu*yv), 1, 1/(yu*yv)}, yw] - 
     2*G[{1}, yv^(-1)]*G[{0, 1/(yu*yv), 1, 1/(yu*yv)}, yw] - 
     4*G[{0}, yu^(-1)]*G[{0, 1/(yu*yv), yu^(-1), 1}, yw] - 
     4*G[{0}, yv^(-1)]*G[{0, 1/(yu*yv), yu^(-1), 1}, yw] + 
     4*G[{0}, yw]*G[{0, 1/(yu*yv), yu^(-1), 1}, yw] + 
     4*G[{1}, yu^(-1)]*G[{0, 1/(yu*yv), yu^(-1), 1}, yw] + 
     4*G[{1}, yv^(-1)]*G[{0, 1/(yu*yv), yu^(-1), 1}, yw] + 
     8*G[{yu^(-1)}, yw]*G[{0, 1/(yu*yv), yu^(-1), 1}, yw] - 
     4*G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv), yu^(-1), 1}, yw] + 
     4*G[{0}, yu^(-1)]*G[{0, 1/(yu*yv), yu^(-1), yu^(-1)}, yw] + 
     4*G[{0}, yv^(-1)]*G[{0, 1/(yu*yv), yu^(-1), yu^(-1)}, yw] - 
     4*G[{0}, yw]*G[{0, 1/(yu*yv), yu^(-1), yu^(-1)}, yw] - 
     8*G[{1}, yu^(-1)]*G[{0, 1/(yu*yv), yu^(-1), yu^(-1)}, yw] - 
     4*G[{1}, yv^(-1)]*G[{0, 1/(yu*yv), yu^(-1), yu^(-1)}, yw] - 
     4*G[{yu^(-1)}, yw]*G[{0, 1/(yu*yv), yu^(-1), yu^(-1)}, yw] + 
     4*G[{yu}, yv^(-1)]*G[{0, 1/(yu*yv), yu^(-1), yu^(-1)}, yw] - 
     4*G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv), yu^(-1), yu^(-1)}, yw] + 
     4*G[{0}, yu^(-1)]*G[{0, 1/(yu*yv), yu^(-1), yv^(-1)}, yw] + 
     4*G[{0}, yv^(-1)]*G[{0, 1/(yu*yv), yu^(-1), yv^(-1)}, yw] - 
     4*G[{0}, yw]*G[{0, 1/(yu*yv), yu^(-1), yv^(-1)}, yw] - 
     8*G[{1}, yu^(-1)]*G[{0, 1/(yu*yv), yu^(-1), yv^(-1)}, yw] - 
     4*G[{1}, yv^(-1)]*G[{0, 1/(yu*yv), yu^(-1), yv^(-1)}, yw] - 
     4*G[{yu^(-1)}, yw]*G[{0, 1/(yu*yv), yu^(-1), yv^(-1)}, yw] + 
     4*G[{yu}, yv^(-1)]*G[{0, 1/(yu*yv), yu^(-1), yv^(-1)}, yw] - 
     4*G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv), yu^(-1), yv^(-1)}, yw] + 
     4*G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv), yu^(-1), 1/(yu*yv)}, yw] - 
     4*G[{0}, yu^(-1)]*G[{0, 1/(yu*yv), yv^(-1), 1}, yw] - 
     4*G[{0}, yv^(-1)]*G[{0, 1/(yu*yv), yv^(-1), 1}, yw] + 
     4*G[{0}, yw]*G[{0, 1/(yu*yv), yv^(-1), 1}, yw] + 
     4*G[{1}, yu^(-1)]*G[{0, 1/(yu*yv), yv^(-1), 1}, yw] + 
     4*G[{1}, yv^(-1)]*G[{0, 1/(yu*yv), yv^(-1), 1}, yw] + 
     8*G[{yu^(-1)}, yw]*G[{0, 1/(yu*yv), yv^(-1), 1}, yw] - 
     4*G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv), yv^(-1), 1}, yw] + 
     4*G[{0}, yu^(-1)]*G[{0, 1/(yu*yv), yv^(-1), yu^(-1)}, yw] + 
     4*G[{0}, yv^(-1)]*G[{0, 1/(yu*yv), yv^(-1), yu^(-1)}, yw] - 
     4*G[{0}, yw]*G[{0, 1/(yu*yv), yv^(-1), yu^(-1)}, yw] - 
     8*G[{1}, yu^(-1)]*G[{0, 1/(yu*yv), yv^(-1), yu^(-1)}, yw] - 
     4*G[{1}, yv^(-1)]*G[{0, 1/(yu*yv), yv^(-1), yu^(-1)}, yw] - 
     4*G[{yu^(-1)}, yw]*G[{0, 1/(yu*yv), yv^(-1), yu^(-1)}, yw] + 
     4*G[{yu}, yv^(-1)]*G[{0, 1/(yu*yv), yv^(-1), yu^(-1)}, yw] - 
     4*G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv), yv^(-1), yu^(-1)}, yw] + 
     4*G[{0}, yu^(-1)]*G[{0, 1/(yu*yv), yv^(-1), yv^(-1)}, yw] + 
     4*G[{0}, yv^(-1)]*G[{0, 1/(yu*yv), yv^(-1), yv^(-1)}, yw] - 
     4*G[{0}, yw]*G[{0, 1/(yu*yv), yv^(-1), yv^(-1)}, yw] - 
     8*G[{1}, yu^(-1)]*G[{0, 1/(yu*yv), yv^(-1), yv^(-1)}, yw] - 
     4*G[{1}, yv^(-1)]*G[{0, 1/(yu*yv), yv^(-1), yv^(-1)}, yw] - 
     4*G[{yu^(-1)}, yw]*G[{0, 1/(yu*yv), yv^(-1), yv^(-1)}, yw] + 
     4*G[{yu}, yv^(-1)]*G[{0, 1/(yu*yv), yv^(-1), yv^(-1)}, yw] - 
     4*G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv), yv^(-1), yv^(-1)}, yw] + 
     4*G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv), yv^(-1), 1/(yu*yv)}, yw] + 
     4*G[{yu^(-1)}, yw]*G[{0, 1/(yu*yv), 1/(yu*yv), 1}, yw] - 
     4*G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv), 1/(yu*yv), 1}, yw] + 
     2*G[{0}, yu^(-1)]*G[{0, 1/(yu*yv), 1/(yu*yv), yu^(-1)}, yw] + 
     2*G[{0}, yv^(-1)]*G[{0, 1/(yu*yv), 1/(yu*yv), yu^(-1)}, yw] - 
     2*G[{0}, yw]*G[{0, 1/(yu*yv), 1/(yu*yv), yu^(-1)}, yw] - 
     2*G[{1}, yu^(-1)]*G[{0, 1/(yu*yv), 1/(yu*yv), yu^(-1)}, yw] - 
     2*G[{1}, yv^(-1)]*G[{0, 1/(yu*yv), 1/(yu*yv), yu^(-1)}, yw] - 
     2*G[{yu^(-1)}, yw]*G[{0, 1/(yu*yv), 1/(yu*yv), yu^(-1)}, yw] + 
     6*G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv), 1/(yu*yv), yu^(-1)}, yw] - 
     2*G[{yu^(-1)}, yw]*G[{0, 1/(yu*yv), 1/(yu*yv), yv^(-1)}, yw] + 
     6*G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv), 1/(yu*yv), yv^(-1)}, yw] - 
     6*G[{0}, yu^(-1)]*G[{0, 1/(yu*yv), 1/(yu*yv), 1/(yu*yv)}, yw] - 
     6*G[{0}, yv^(-1)]*G[{0, 1/(yu*yv), 1/(yu*yv), 1/(yu*yv)}, yw] + 
     6*G[{0}, yw]*G[{0, 1/(yu*yv), 1/(yu*yv), 1/(yu*yv)}, yw] + 
     10*G[{1}, yu^(-1)]*G[{0, 1/(yu*yv), 1/(yu*yv), 1/(yu*yv)}, yw] + 
     6*G[{1}, yv^(-1)]*G[{0, 1/(yu*yv), 1/(yu*yv), 1/(yu*yv)}, yw] - 
     4*G[{yu}, yv^(-1)]*G[{0, 1/(yu*yv), 1/(yu*yv), 1/(yu*yv)}, yw] + 
     4*G[{1}, yu^(-1)]*G[{1, 1, 1, yu}, yv^(-1)] + 
     4*G[{yu^(-1)}, yw]*G[{1, 1, 1, yu}, yv^(-1)] + 
     4*G[{yu}, yv^(-1)]*G[{1, 1, 1, yu}, yv^(-1)] - 
     4*G[{1/(yu*yv)}, yw]*G[{1, 1, 1, yu}, yv^(-1)] + 
     8*G[{0}, yu^(-1)]*G[{1, 1, yu^(-1), yu^(-1)}, yw] + 
     8*G[{0}, yv^(-1)]*G[{1, 1, yu^(-1), yu^(-1)}, yw] - 
     8*G[{0}, yw]*G[{1, 1, yu^(-1), yu^(-1)}, yw] - 
     8*G[{1}, yu^(-1)]*G[{1, 1, yu^(-1), yu^(-1)}, yw] - 
     8*G[{1}, yv^(-1)]*G[{1, 1, yu^(-1), yu^(-1)}, yw] - 
     12*G[{yu^(-1)}, yw]*G[{1, 1, yu^(-1), yu^(-1)}, yw] + 
     4*G[{1/(yu*yv)}, yw]*G[{1, 1, yu^(-1), yu^(-1)}, yw] + 
     8*G[{0}, yu^(-1)]*G[{1, 1, yu^(-1), yv^(-1)}, yw] + 
     8*G[{0}, yv^(-1)]*G[{1, 1, yu^(-1), yv^(-1)}, yw] - 
     8*G[{0}, yw]*G[{1, 1, yu^(-1), yv^(-1)}, yw] - 
     8*G[{1}, yu^(-1)]*G[{1, 1, yu^(-1), yv^(-1)}, yw] - 
     8*G[{1}, yv^(-1)]*G[{1, 1, yu^(-1), yv^(-1)}, yw] - 
     8*G[{yu^(-1)}, yw]*G[{1, 1, yu^(-1), yv^(-1)}, yw] + 
     4*G[{1/(yu*yv)}, yw]*G[{1, 1, yu^(-1), yv^(-1)}, yw] - 
     4*G[{0}, yu^(-1)]*G[{1, 1, yu^(-1), 1/(yu*yv)}, yw] - 
     4*G[{0}, yv^(-1)]*G[{1, 1, yu^(-1), 1/(yu*yv)}, yw] + 
     4*G[{0}, yw]*G[{1, 1, yu^(-1), 1/(yu*yv)}, yw] + 
     4*G[{1}, yu^(-1)]*G[{1, 1, yu^(-1), 1/(yu*yv)}, yw] + 
     4*G[{1}, yv^(-1)]*G[{1, 1, yu^(-1), 1/(yu*yv)}, yw] + 
     8*G[{yu^(-1)}, yw]*G[{1, 1, yu^(-1), 1/(yu*yv)}, yw] - 
     4*G[{1/(yu*yv)}, yw]*G[{1, 1, yu^(-1), 1/(yu*yv)}, yw] - 
     4*G[{0}, yu^(-1)]*G[{1, 1, yu, yu}, yv^(-1)] - 
     4*G[{0}, yv^(-1)]*G[{1, 1, yu, yu}, yv^(-1)] + 
     4*G[{0}, yw]*G[{1, 1, yu, yu}, yv^(-1)] + 8*G[{1}, yu^(-1)]*
      G[{1, 1, yu, yu}, yv^(-1)] + 4*G[{1}, yv^(-1)]*
      G[{1, 1, yu, yu}, yv^(-1)] + 8*G[{yu}, yv^(-1)]*
      G[{1, 1, yu, yu}, yv^(-1)] - 8*G[{1/(yu*yv)}, yw]*
      G[{1, 1, yu, yu}, yv^(-1)] + 8*G[{0}, yu^(-1)]*
      G[{1, 1, yv^(-1), yu^(-1)}, yw] + 8*G[{0}, yv^(-1)]*
      G[{1, 1, yv^(-1), yu^(-1)}, yw] - 8*G[{0}, yw]*
      G[{1, 1, yv^(-1), yu^(-1)}, yw] - 8*G[{1}, yu^(-1)]*
      G[{1, 1, yv^(-1), yu^(-1)}, yw] - 8*G[{1}, yv^(-1)]*
      G[{1, 1, yv^(-1), yu^(-1)}, yw] - 8*G[{yu^(-1)}, yw]*
      G[{1, 1, yv^(-1), yu^(-1)}, yw] + 4*G[{1/(yu*yv)}, yw]*
      G[{1, 1, yv^(-1), yu^(-1)}, yw] - 8*G[{yu^(-1)}, yw]*
      G[{1, 1, yv^(-1), yv^(-1)}, yw] + 8*G[{1/(yu*yv)}, yw]*
      G[{1, 1, yv^(-1), yv^(-1)}, yw] + 4*G[{yu^(-1)}, yw]*
      G[{1, 1, yv^(-1), 1/(yu*yv)}, yw] - 8*G[{1/(yu*yv)}, yw]*
      G[{1, 1, yv^(-1), 1/(yu*yv)}, yw] - 4*G[{0}, yu^(-1)]*
      G[{1, 1, 1/(yu*yv), yu^(-1)}, yw] - 4*G[{0}, yv^(-1)]*
      G[{1, 1, 1/(yu*yv), yu^(-1)}, yw] + 4*G[{0}, yw]*
      G[{1, 1, 1/(yu*yv), yu^(-1)}, yw] + 4*G[{1}, yu^(-1)]*
      G[{1, 1, 1/(yu*yv), yu^(-1)}, yw] + 4*G[{1}, yv^(-1)]*
      G[{1, 1, 1/(yu*yv), yu^(-1)}, yw] + 8*G[{yu^(-1)}, yw]*
      G[{1, 1, 1/(yu*yv), yu^(-1)}, yw] - 4*G[{1/(yu*yv)}, yw]*
      G[{1, 1, 1/(yu*yv), yu^(-1)}, yw] + 4*G[{yu^(-1)}, yw]*
      G[{1, 1, 1/(yu*yv), yv^(-1)}, yw] - 8*G[{1/(yu*yv)}, yw]*
      G[{1, 1, 1/(yu*yv), yv^(-1)}, yw] + 8*G[{0}, yu^(-1)]*
      G[{1, 1, 1/(yu*yv), 1/(yu*yv)}, yw] + 8*G[{0}, yv^(-1)]*
      G[{1, 1, 1/(yu*yv), 1/(yu*yv)}, yw] - 8*G[{0}, yw]*
      G[{1, 1, 1/(yu*yv), 1/(yu*yv)}, yw] - 8*G[{1}, yu^(-1)]*
      G[{1, 1, 1/(yu*yv), 1/(yu*yv)}, yw] - 8*G[{1}, yv^(-1)]*
      G[{1, 1, 1/(yu*yv), 1/(yu*yv)}, yw] + 4*G[{yu^(-1)}, yw]*
      G[{1, 1, 1/(yu*yv), 1/(yu*yv)}, yw] - 4*G[{1/(yu*yv)}, yw]*
      G[{1, 1, 1/(yu*yv), 1/(yu*yv)}, yw] + 4*G[{0}, yu^(-1)]*
      G[{1, yu^(-1), 1, yv^(-1)}, yw] + 4*G[{0}, yv^(-1)]*
      G[{1, yu^(-1), 1, yv^(-1)}, yw] - 4*G[{0}, yw]*
      G[{1, yu^(-1), 1, yv^(-1)}, yw] - 4*G[{1}, yu^(-1)]*
      G[{1, yu^(-1), 1, yv^(-1)}, yw] - 4*G[{1}, yv^(-1)]*
      G[{1, yu^(-1), 1, yv^(-1)}, yw] + 4*G[{yu^(-1)}, yw]*
      G[{1, yu^(-1), 1, 1/(yu*yv)}, yw] - 4*G[{1/(yu*yv)}, yw]*
      G[{1, yu^(-1), 1, 1/(yu*yv)}, yw] + 8*G[{0}, yu^(-1)]*
      G[{1, yu^(-1), yu^(-1), yu^(-1)}, yw] + 8*G[{0}, yv^(-1)]*
      G[{1, yu^(-1), yu^(-1), yu^(-1)}, yw] - 
     8*G[{0}, yw]*G[{1, yu^(-1), yu^(-1), yu^(-1)}, yw] - 
     8*G[{1}, yu^(-1)]*G[{1, yu^(-1), yu^(-1), yu^(-1)}, yw] - 
     8*G[{1}, yv^(-1)]*G[{1, yu^(-1), yu^(-1), yu^(-1)}, yw] - 
     16*G[{yu^(-1)}, yw]*G[{1, yu^(-1), yu^(-1), yu^(-1)}, yw] + 
     4*G[{0}, yu^(-1)]*G[{1, yu^(-1), yu^(-1), yv^(-1)}, yw] + 
     4*G[{0}, yv^(-1)]*G[{1, yu^(-1), yu^(-1), yv^(-1)}, yw] - 
     4*G[{0}, yw]*G[{1, yu^(-1), yu^(-1), yv^(-1)}, yw] - 
     8*G[{1}, yu^(-1)]*G[{1, yu^(-1), yu^(-1), yv^(-1)}, yw] - 
     4*G[{1}, yv^(-1)]*G[{1, yu^(-1), yu^(-1), yv^(-1)}, yw] - 
     4*G[{1}, yw]*G[{1, yu^(-1), yu^(-1), yv^(-1)}, yw] - 
     4*G[{yu^(-1)}, yw]*G[{1, yu^(-1), yu^(-1), yv^(-1)}, yw] + 
     4*G[{yu}, yv^(-1)]*G[{1, yu^(-1), yu^(-1), yv^(-1)}, yw] - 
     4*G[{1/(yu*yv)}, yw]*G[{1, yu^(-1), yu^(-1), yv^(-1)}, yw] - 
     4*G[{0}, yu^(-1)]*G[{1, yu^(-1), yu^(-1), 1/(yu*yv)}, yw] - 
     4*G[{0}, yv^(-1)]*G[{1, yu^(-1), yu^(-1), 1/(yu*yv)}, yw] + 
     4*G[{0}, yw]*G[{1, yu^(-1), yu^(-1), 1/(yu*yv)}, yw] + 
     8*G[{1}, yu^(-1)]*G[{1, yu^(-1), yu^(-1), 1/(yu*yv)}, yw] + 
     4*G[{1}, yv^(-1)]*G[{1, yu^(-1), yu^(-1), 1/(yu*yv)}, yw] + 
     4*G[{1}, yw]*G[{1, yu^(-1), yu^(-1), 1/(yu*yv)}, yw] - 
     4*G[{yu}, yv^(-1)]*G[{1, yu^(-1), yu^(-1), 1/(yu*yv)}, yw] + 
     8*G[{1/(yu*yv)}, yw]*G[{1, yu^(-1), yu^(-1), 1/(yu*yv)}, yw] + 
     4*G[{0}, yu^(-1)]*G[{1, yu^(-1), yv^(-1), yu^(-1)}, yw] + 
     4*G[{0}, yv^(-1)]*G[{1, yu^(-1), yv^(-1), yu^(-1)}, yw] - 
     4*G[{0}, yw]*G[{1, yu^(-1), yv^(-1), yu^(-1)}, yw] - 
     8*G[{1}, yu^(-1)]*G[{1, yu^(-1), yv^(-1), yu^(-1)}, yw] - 
     4*G[{1}, yv^(-1)]*G[{1, yu^(-1), yv^(-1), yu^(-1)}, yw] - 
     4*G[{1}, yw]*G[{1, yu^(-1), yv^(-1), yu^(-1)}, yw] - 
     4*G[{yu^(-1)}, yw]*G[{1, yu^(-1), yv^(-1), yu^(-1)}, yw] + 
     4*G[{yu}, yv^(-1)]*G[{1, yu^(-1), yv^(-1), yu^(-1)}, yw] - 
     4*G[{1/(yu*yv)}, yw]*G[{1, yu^(-1), yv^(-1), yu^(-1)}, yw] + 
     4*G[{0}, yu^(-1)]*G[{1, yu^(-1), yv^(-1), yv^(-1)}, yw] + 
     4*G[{0}, yv^(-1)]*G[{1, yu^(-1), yv^(-1), yv^(-1)}, yw] - 
     4*G[{0}, yw]*G[{1, yu^(-1), yv^(-1), yv^(-1)}, yw] - 
     8*G[{1}, yu^(-1)]*G[{1, yu^(-1), yv^(-1), yv^(-1)}, yw] - 
     4*G[{1}, yv^(-1)]*G[{1, yu^(-1), yv^(-1), yv^(-1)}, yw] - 
     4*G[{1}, yw]*G[{1, yu^(-1), yv^(-1), yv^(-1)}, yw] - 
     4*G[{yu^(-1)}, yw]*G[{1, yu^(-1), yv^(-1), yv^(-1)}, yw] + 
     4*G[{yu}, yv^(-1)]*G[{1, yu^(-1), yv^(-1), yv^(-1)}, yw] - 
     4*G[{1/(yu*yv)}, yw]*G[{1, yu^(-1), yv^(-1), yv^(-1)}, yw] + 
     4*G[{1/(yu*yv)}, yw]*G[{1, yu^(-1), yv^(-1), 1/(yu*yv)}, yw] + 
     4*G[{1}, yu^(-1)]*G[{1, yu^(-1), 1/(yu*yv), yu^(-1)}, yw] + 
     4*G[{1}, yw]*G[{1, yu^(-1), 1/(yu*yv), yu^(-1)}, yw] + 
     4*G[{yu^(-1)}, yw]*G[{1, yu^(-1), 1/(yu*yv), yu^(-1)}, yw] - 
     4*G[{yu}, yv^(-1)]*G[{1, yu^(-1), 1/(yu*yv), yu^(-1)}, yw] + 
     4*G[{1/(yu*yv)}, yw]*G[{1, yu^(-1), 1/(yu*yv), yu^(-1)}, yw] + 
     4*G[{yu^(-1)}, yw]*G[{1, yu^(-1), 1/(yu*yv), yv^(-1)}, yw] - 
     4*G[{0}, yu^(-1)]*G[{1, yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] - 
     4*G[{0}, yv^(-1)]*G[{1, yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] + 
     4*G[{0}, yw]*G[{1, yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] + 
     4*G[{1}, yv^(-1)]*G[{1, yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] - 
     4*G[{1}, yw]*G[{1, yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] + 
     4*G[{yu}, yv^(-1)]*G[{1, yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] - 
     8*G[{0}, yu^(-1)]*G[{1, yu, yu, yu}, yv^(-1)] - 
     8*G[{0}, yv^(-1)]*G[{1, yu, yu, yu}, yv^(-1)] + 
     8*G[{0}, yw]*G[{1, yu, yu, yu}, yv^(-1)] + 8*G[{1}, yu^(-1)]*
      G[{1, yu, yu, yu}, yv^(-1)] + 8*G[{1}, yv^(-1)]*
      G[{1, yu, yu, yu}, yv^(-1)] - 8*G[{yu^(-1)}, yw]*
      G[{1, yu, yu, yu}, yv^(-1)] + 8*G[{yu}, yv^(-1)]*
      G[{1, yu, yu, yu}, yv^(-1)] - 8*G[{1/(yu*yv)}, yw]*
      G[{1, yu, yu, yu}, yv^(-1)] + 4*G[{0}, yu^(-1)]*
      G[{1, yv^(-1), 1, 1/(yu*yv)}, yw] + 4*G[{0}, yv^(-1)]*
      G[{1, yv^(-1), 1, 1/(yu*yv)}, yw] - 4*G[{0}, yw]*
      G[{1, yv^(-1), 1, 1/(yu*yv)}, yw] - 4*G[{1}, yu^(-1)]*
      G[{1, yv^(-1), 1, 1/(yu*yv)}, yw] - 4*G[{1}, yv^(-1)]*
      G[{1, yv^(-1), 1, 1/(yu*yv)}, yw] + 4*G[{yu^(-1)}, yw]*
      G[{1, yv^(-1), 1, 1/(yu*yv)}, yw] - 4*G[{1/(yu*yv)}, yw]*
      G[{1, yv^(-1), 1, 1/(yu*yv)}, yw] + 4*G[{0}, yu^(-1)]*
      G[{1, yv^(-1), yu^(-1), yu^(-1)}, yw] + 4*G[{0}, yv^(-1)]*
      G[{1, yv^(-1), yu^(-1), yu^(-1)}, yw] - 
     4*G[{0}, yw]*G[{1, yv^(-1), yu^(-1), yu^(-1)}, yw] - 
     8*G[{1}, yu^(-1)]*G[{1, yv^(-1), yu^(-1), yu^(-1)}, yw] - 
     4*G[{1}, yv^(-1)]*G[{1, yv^(-1), yu^(-1), yu^(-1)}, yw] - 
     4*G[{1}, yw]*G[{1, yv^(-1), yu^(-1), yu^(-1)}, yw] - 
     4*G[{yu^(-1)}, yw]*G[{1, yv^(-1), yu^(-1), yu^(-1)}, yw] + 
     4*G[{yu}, yv^(-1)]*G[{1, yv^(-1), yu^(-1), yu^(-1)}, yw] - 
     4*G[{1/(yu*yv)}, yw]*G[{1, yv^(-1), yu^(-1), yu^(-1)}, yw] + 
     4*G[{0}, yu^(-1)]*G[{1, yv^(-1), yu^(-1), yv^(-1)}, yw] + 
     4*G[{0}, yv^(-1)]*G[{1, yv^(-1), yu^(-1), yv^(-1)}, yw] - 
     4*G[{0}, yw]*G[{1, yv^(-1), yu^(-1), yv^(-1)}, yw] - 
     8*G[{1}, yu^(-1)]*G[{1, yv^(-1), yu^(-1), yv^(-1)}, yw] - 
     4*G[{1}, yv^(-1)]*G[{1, yv^(-1), yu^(-1), yv^(-1)}, yw] - 
     4*G[{1}, yw]*G[{1, yv^(-1), yu^(-1), yv^(-1)}, yw] - 
     4*G[{yu^(-1)}, yw]*G[{1, yv^(-1), yu^(-1), yv^(-1)}, yw] + 
     4*G[{yu}, yv^(-1)]*G[{1, yv^(-1), yu^(-1), yv^(-1)}, yw] - 
     4*G[{1/(yu*yv)}, yw]*G[{1, yv^(-1), yu^(-1), yv^(-1)}, yw] + 
     4*G[{1/(yu*yv)}, yw]*G[{1, yv^(-1), yu^(-1), 1/(yu*yv)}, yw] + 
     4*G[{0}, yu^(-1)]*G[{1, yv^(-1), yv^(-1), yu^(-1)}, yw] + 
     4*G[{0}, yv^(-1)]*G[{1, yv^(-1), yv^(-1), yu^(-1)}, yw] - 
     4*G[{0}, yw]*G[{1, yv^(-1), yv^(-1), yu^(-1)}, yw] - 
     8*G[{1}, yu^(-1)]*G[{1, yv^(-1), yv^(-1), yu^(-1)}, yw] - 
     4*G[{1}, yv^(-1)]*G[{1, yv^(-1), yv^(-1), yu^(-1)}, yw] - 
     4*G[{1}, yw]*G[{1, yv^(-1), yv^(-1), yu^(-1)}, yw] - 
     4*G[{yu^(-1)}, yw]*G[{1, yv^(-1), yv^(-1), yu^(-1)}, yw] + 
     4*G[{yu}, yv^(-1)]*G[{1, yv^(-1), yv^(-1), yu^(-1)}, yw] - 
     4*G[{1/(yu*yv)}, yw]*G[{1, yv^(-1), yv^(-1), yu^(-1)}, yw] - 
     8*G[{yu^(-1)}, yw]*G[{1, yv^(-1), yv^(-1), yv^(-1)}, yw] + 
     8*G[{1/(yu*yv)}, yw]*G[{1, yv^(-1), yv^(-1), yv^(-1)}, yw] - 
     4*G[{0}, yu^(-1)]*G[{1, yv^(-1), yv^(-1), 1/(yu*yv)}, yw] - 
     4*G[{0}, yv^(-1)]*G[{1, yv^(-1), yv^(-1), 1/(yu*yv)}, yw] + 
     4*G[{0}, yw]*G[{1, yv^(-1), yv^(-1), 1/(yu*yv)}, yw] + 
     8*G[{1}, yu^(-1)]*G[{1, yv^(-1), yv^(-1), 1/(yu*yv)}, yw] + 
     4*G[{1}, yv^(-1)]*G[{1, yv^(-1), yv^(-1), 1/(yu*yv)}, yw] + 
     4*G[{1}, yw]*G[{1, yv^(-1), yv^(-1), 1/(yu*yv)}, yw] - 
     4*G[{yu^(-1)}, yw]*G[{1, yv^(-1), yv^(-1), 1/(yu*yv)}, yw] - 
     4*G[{yu}, yv^(-1)]*G[{1, yv^(-1), yv^(-1), 1/(yu*yv)}, yw] + 
     4*G[{1/(yu*yv)}, yw]*G[{1, yv^(-1), yv^(-1), 1/(yu*yv)}, yw] - 
     4*G[{0}, yu^(-1)]*G[{1, yv^(-1), 1/(yu*yv), yu^(-1)}, yw] - 
     4*G[{0}, yv^(-1)]*G[{1, yv^(-1), 1/(yu*yv), yu^(-1)}, yw] + 
     4*G[{0}, yw]*G[{1, yv^(-1), 1/(yu*yv), yu^(-1)}, yw] + 
     4*G[{1}, yu^(-1)]*G[{1, yv^(-1), 1/(yu*yv), yu^(-1)}, yw] + 
     4*G[{1}, yv^(-1)]*G[{1, yv^(-1), 1/(yu*yv), yu^(-1)}, yw] + 
     4*G[{yu^(-1)}, yw]*G[{1, yv^(-1), 1/(yu*yv), yu^(-1)}, yw] - 
     4*G[{0}, yu^(-1)]*G[{1, yv^(-1), 1/(yu*yv), yv^(-1)}, yw] - 
     4*G[{0}, yv^(-1)]*G[{1, yv^(-1), 1/(yu*yv), yv^(-1)}, yw] + 
     4*G[{0}, yw]*G[{1, yv^(-1), 1/(yu*yv), yv^(-1)}, yw] + 
     8*G[{1}, yu^(-1)]*G[{1, yv^(-1), 1/(yu*yv), yv^(-1)}, yw] + 
     4*G[{1}, yv^(-1)]*G[{1, yv^(-1), 1/(yu*yv), yv^(-1)}, yw] + 
     4*G[{1}, yw]*G[{1, yv^(-1), 1/(yu*yv), yv^(-1)}, yw] - 
     4*G[{yu}, yv^(-1)]*G[{1, yv^(-1), 1/(yu*yv), yv^(-1)}, yw] - 
     4*G[{1}, yu^(-1)]*G[{1, yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] - 
     4*G[{1}, yw]*G[{1, yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] + 
     4*G[{yu}, yv^(-1)]*G[{1, yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] + 
     4*G[{0}, yu^(-1)]*G[{1, 1/(yu*yv), yu^(-1), yu^(-1)}, yw] + 
     4*G[{0}, yv^(-1)]*G[{1, 1/(yu*yv), yu^(-1), yu^(-1)}, yw] - 
     4*G[{0}, yw]*G[{1, 1/(yu*yv), yu^(-1), yu^(-1)}, yw] - 
     4*G[{1}, yv^(-1)]*G[{1, 1/(yu*yv), yu^(-1), yu^(-1)}, yw] + 
     4*G[{1}, yw]*G[{1, 1/(yu*yv), yu^(-1), yu^(-1)}, yw] + 
     4*G[{yu^(-1)}, yw]*G[{1, 1/(yu*yv), yu^(-1), yu^(-1)}, yw] - 
     4*G[{yu}, yv^(-1)]*G[{1, 1/(yu*yv), yu^(-1), yu^(-1)}, yw] + 
     4*G[{1/(yu*yv)}, yw]*G[{1, 1/(yu*yv), yu^(-1), yu^(-1)}, yw] - 
     4*G[{0}, yu^(-1)]*G[{1, 1/(yu*yv), yu^(-1), 1/(yu*yv)}, yw] - 
     4*G[{0}, yv^(-1)]*G[{1, 1/(yu*yv), yu^(-1), 1/(yu*yv)}, yw] + 
     4*G[{0}, yw]*G[{1, 1/(yu*yv), yu^(-1), 1/(yu*yv)}, yw] + 
     4*G[{1}, yv^(-1)]*G[{1, 1/(yu*yv), yu^(-1), 1/(yu*yv)}, yw] - 
     4*G[{1}, yw]*G[{1, 1/(yu*yv), yu^(-1), 1/(yu*yv)}, yw] + 
     4*G[{yu}, yv^(-1)]*G[{1, 1/(yu*yv), yu^(-1), 1/(yu*yv)}, yw] - 
     4*G[{1/(yu*yv)}, yw]*G[{1, 1/(yu*yv), yu^(-1), 1/(yu*yv)}, yw] - 
     4*G[{0}, yu^(-1)]*G[{1, 1/(yu*yv), yv^(-1), yv^(-1)}, yw] - 
     4*G[{0}, yv^(-1)]*G[{1, 1/(yu*yv), yv^(-1), yv^(-1)}, yw] + 
     4*G[{0}, yw]*G[{1, 1/(yu*yv), yv^(-1), yv^(-1)}, yw] + 
     8*G[{1}, yu^(-1)]*G[{1, 1/(yu*yv), yv^(-1), yv^(-1)}, yw] + 
     4*G[{1}, yv^(-1)]*G[{1, 1/(yu*yv), yv^(-1), yv^(-1)}, yw] + 
     4*G[{1}, yw]*G[{1, 1/(yu*yv), yv^(-1), yv^(-1)}, yw] - 
     4*G[{yu^(-1)}, yw]*G[{1, 1/(yu*yv), yv^(-1), yv^(-1)}, yw] - 
     4*G[{yu}, yv^(-1)]*G[{1, 1/(yu*yv), yv^(-1), yv^(-1)}, yw] - 
     4*G[{1/(yu*yv)}, yw]*G[{1, 1/(yu*yv), yv^(-1), yv^(-1)}, yw] + 
     4*G[{0}, yu^(-1)]*G[{1, 1/(yu*yv), yv^(-1), 1/(yu*yv)}, yw] + 
     4*G[{0}, yv^(-1)]*G[{1, 1/(yu*yv), yv^(-1), 1/(yu*yv)}, yw] - 
     4*G[{0}, yw]*G[{1, 1/(yu*yv), yv^(-1), 1/(yu*yv)}, yw] - 
     8*G[{1}, yu^(-1)]*G[{1, 1/(yu*yv), yv^(-1), 1/(yu*yv)}, yw] - 
     4*G[{1}, yv^(-1)]*G[{1, 1/(yu*yv), yv^(-1), 1/(yu*yv)}, yw] - 
     4*G[{1}, yw]*G[{1, 1/(yu*yv), yv^(-1), 1/(yu*yv)}, yw] + 
     4*G[{yu^(-1)}, yw]*G[{1, 1/(yu*yv), yv^(-1), 1/(yu*yv)}, yw] + 
     4*G[{yu}, yv^(-1)]*G[{1, 1/(yu*yv), yv^(-1), 1/(yu*yv)}, yw] - 
     8*G[{0}, yu^(-1)]*G[{1, 1/(yu*yv), 1/(yu*yv), yu^(-1)}, yw] - 
     8*G[{0}, yv^(-1)]*G[{1, 1/(yu*yv), 1/(yu*yv), yu^(-1)}, yw] + 
     8*G[{0}, yw]*G[{1, 1/(yu*yv), 1/(yu*yv), yu^(-1)}, yw] + 
     4*G[{1}, yu^(-1)]*G[{1, 1/(yu*yv), 1/(yu*yv), yu^(-1)}, yw] + 
     8*G[{1}, yv^(-1)]*G[{1, 1/(yu*yv), 1/(yu*yv), yu^(-1)}, yw] - 
     4*G[{1}, yw]*G[{1, 1/(yu*yv), 1/(yu*yv), yu^(-1)}, yw] + 
     4*G[{yu^(-1)}, yw]*G[{1, 1/(yu*yv), 1/(yu*yv), yu^(-1)}, yw] + 
     4*G[{yu}, yv^(-1)]*G[{1, 1/(yu*yv), 1/(yu*yv), yu^(-1)}, yw] - 
     8*G[{1/(yu*yv)}, yw]*G[{1, 1/(yu*yv), 1/(yu*yv), yu^(-1)}, yw] + 
     4*G[{0}, yu^(-1)]*G[{1, 1/(yu*yv), 1/(yu*yv), yv^(-1)}, yw] + 
     4*G[{0}, yv^(-1)]*G[{1, 1/(yu*yv), 1/(yu*yv), yv^(-1)}, yw] - 
     4*G[{0}, yw]*G[{1, 1/(yu*yv), 1/(yu*yv), yv^(-1)}, yw] - 
     8*G[{1}, yu^(-1)]*G[{1, 1/(yu*yv), 1/(yu*yv), yv^(-1)}, yw] - 
     4*G[{1}, yv^(-1)]*G[{1, 1/(yu*yv), 1/(yu*yv), yv^(-1)}, yw] - 
     4*G[{1}, yw]*G[{1, 1/(yu*yv), 1/(yu*yv), yv^(-1)}, yw] + 
     8*G[{yu^(-1)}, yw]*G[{1, 1/(yu*yv), 1/(yu*yv), yv^(-1)}, yw] + 
     4*G[{yu}, yv^(-1)]*G[{1, 1/(yu*yv), 1/(yu*yv), yv^(-1)}, yw] - 
     4*G[{1/(yu*yv)}, yw]*G[{1, 1/(yu*yv), 1/(yu*yv), yv^(-1)}, yw] + 
     8*G[{0}, yu^(-1)]*G[{1, 1/(yu*yv), 1/(yu*yv), 1/(yu*yv)}, yw] + 
     8*G[{0}, yv^(-1)]*G[{1, 1/(yu*yv), 1/(yu*yv), 1/(yu*yv)}, yw] - 
     8*G[{0}, yw]*G[{1, 1/(yu*yv), 1/(yu*yv), 1/(yu*yv)}, yw] - 
     8*G[{1}, yu^(-1)]*G[{1, 1/(yu*yv), 1/(yu*yv), 1/(yu*yv)}, yw] - 
     8*G[{1}, yv^(-1)]*G[{1, 1/(yu*yv), 1/(yu*yv), 1/(yu*yv)}, yw] - 
     8*G[{0}, yu^(-1)]*G[{yu^(-1), yu^(-1), yu^(-1), 1/(yu*yv)}, yw] - 
     8*G[{0}, yv^(-1)]*G[{yu^(-1), yu^(-1), yu^(-1), 1/(yu*yv)}, yw] + 
     8*G[{0}, yw]*G[{yu^(-1), yu^(-1), yu^(-1), 1/(yu*yv)}, yw] + 
     8*G[{1}, yu^(-1)]*G[{yu^(-1), yu^(-1), yu^(-1), 1/(yu*yv)}, yw] + 
     8*G[{1}, yv^(-1)]*G[{yu^(-1), yu^(-1), yu^(-1), 1/(yu*yv)}, yw] - 
     8*G[{yu^(-1)}, yw]*G[{yu^(-1), yu^(-1), yu^(-1), 1/(yu*yv)}, yw] + 
     4*G[{0}, yu^(-1)]*G[{yu^(-1), yu^(-1), 1/(yu*yv), yv^(-1)}, yw] + 
     4*G[{0}, yv^(-1)]*G[{yu^(-1), yu^(-1), 1/(yu*yv), yv^(-1)}, yw] - 
     4*G[{0}, yw]*G[{yu^(-1), yu^(-1), 1/(yu*yv), yv^(-1)}, yw] - 
     8*G[{1}, yu^(-1)]*G[{yu^(-1), yu^(-1), 1/(yu*yv), yv^(-1)}, yw] - 
     4*G[{1}, yv^(-1)]*G[{yu^(-1), yu^(-1), 1/(yu*yv), yv^(-1)}, yw] - 
     4*G[{1}, yw]*G[{yu^(-1), yu^(-1), 1/(yu*yv), yv^(-1)}, yw] + 
     4*G[{yu^(-1)}, yw]*G[{yu^(-1), yu^(-1), 1/(yu*yv), yv^(-1)}, yw] + 
     4*G[{yu}, yv^(-1)]*G[{yu^(-1), yu^(-1), 1/(yu*yv), yv^(-1)}, yw] - 
     4*G[{1/(yu*yv)}, yw]*G[{yu^(-1), yu^(-1), 1/(yu*yv), yv^(-1)}, yw] - 
     4*G[{0}, yu^(-1)]*G[{yu^(-1), yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] - 
     4*G[{0}, yv^(-1)]*G[{yu^(-1), yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] + 
     4*G[{0}, yw]*G[{yu^(-1), yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] + 
     4*G[{1}, yv^(-1)]*G[{yu^(-1), yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] - 
     4*G[{1}, yw]*G[{yu^(-1), yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] - 
     4*G[{yu^(-1)}, yw]*G[{yu^(-1), yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] + 
     4*G[{yu}, yv^(-1)]*G[{yu^(-1), yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] - 
     4*G[{0}, yu^(-1)]*G[{yu^(-1), 1/(yu*yv), yv^(-1), yv^(-1)}, yw] - 
     4*G[{0}, yv^(-1)]*G[{yu^(-1), 1/(yu*yv), yv^(-1), yv^(-1)}, yw] + 
     4*G[{0}, yw]*G[{yu^(-1), 1/(yu*yv), yv^(-1), yv^(-1)}, yw] + 
     8*G[{1}, yu^(-1)]*G[{yu^(-1), 1/(yu*yv), yv^(-1), yv^(-1)}, yw] + 
     4*G[{1}, yv^(-1)]*G[{yu^(-1), 1/(yu*yv), yv^(-1), yv^(-1)}, yw] + 
     4*G[{1}, yw]*G[{yu^(-1), 1/(yu*yv), yv^(-1), yv^(-1)}, yw] - 
     4*G[{yu^(-1)}, yw]*G[{yu^(-1), 1/(yu*yv), yv^(-1), yv^(-1)}, yw] - 
     4*G[{yu}, yv^(-1)]*G[{yu^(-1), 1/(yu*yv), yv^(-1), yv^(-1)}, yw] + 
     4*G[{1/(yu*yv)}, yw]*G[{yu^(-1), 1/(yu*yv), yv^(-1), yv^(-1)}, yw] - 
     4*G[{1/(yu*yv)}, yw]*G[{yu^(-1), 1/(yu*yv), yv^(-1), 1/(yu*yv)}, yw] - 
     4*G[{1/(yu*yv)}, yw]*G[{yu^(-1), 1/(yu*yv), 1/(yu*yv), yv^(-1)}, yw] - 
     4*G[{1}, yu^(-1)]*G[{yu^(-1), 1/(yu*yv), 1/(yu*yv), 1/(yu*yv)}, yw] - 
     4*G[{1}, yw]*G[{yu^(-1), 1/(yu*yv), 1/(yu*yv), 1/(yu*yv)}, yw] + 
     4*G[{yu}, yv^(-1)]*G[{yu^(-1), 1/(yu*yv), 1/(yu*yv), 1/(yu*yv)}, yw] + 
     8*G[{1/(yu*yv)}, yw]*G[{yv^(-1), yv^(-1), yv^(-1), 1/(yu*yv)}, yw] + 
     4*G[{0}, yu^(-1)]*G[{yv^(-1), yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] + 
     4*G[{0}, yv^(-1)]*G[{yv^(-1), yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] - 
     4*G[{0}, yw]*G[{yv^(-1), yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] - 
     8*G[{1}, yu^(-1)]*G[{yv^(-1), yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] - 
     4*G[{1}, yv^(-1)]*G[{yv^(-1), yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] - 
     4*G[{1}, yw]*G[{yv^(-1), yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] + 
     4*G[{yu^(-1)}, yw]*G[{yv^(-1), yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] + 
     4*G[{yu}, yv^(-1)]*G[{yv^(-1), yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] + 
     8*G[{yv^(-1)}, yw]*G[{yv^(-1), yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] + 
     4*G[{1/(yu*yv)}, yw]*G[{yv^(-1), yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] + 
     4*G[{0}, yu^(-1)]*G[{yv^(-1), 1/(yu*yv), 1/(yu*yv), 1/(yu*yv)}, yw] + 
     4*G[{0}, yv^(-1)]*G[{yv^(-1), 1/(yu*yv), 1/(yu*yv), 1/(yu*yv)}, yw] - 
     4*G[{0}, yw]*G[{yv^(-1), 1/(yu*yv), 1/(yu*yv), 1/(yu*yv)}, yw] - 
     8*G[{1}, yu^(-1)]*G[{yv^(-1), 1/(yu*yv), 1/(yu*yv), 1/(yu*yv)}, yw] - 
     4*G[{1}, yv^(-1)]*G[{yv^(-1), 1/(yu*yv), 1/(yu*yv), 1/(yu*yv)}, yw] - 
     4*G[{1}, yw]*G[{yv^(-1), 1/(yu*yv), 1/(yu*yv), 1/(yu*yv)}, yw] + 
     4*G[{yu^(-1)}, yw]*G[{yv^(-1), 1/(yu*yv), 1/(yu*yv), 1/(yu*yv)}, yw] + 
     4*G[{yu}, yv^(-1)]*G[{yv^(-1), 1/(yu*yv), 1/(yu*yv), 1/(yu*yv)}, yw] + 
     8*G[{yv^(-1)}, yw]*G[{yv^(-1), 1/(yu*yv), 1/(yu*yv), 1/(yu*yv)}, yw] - 
     12*G[{0, 0, 0, 1, 1}, yv^(-1)] + 12*G[{0, 0, 0, 1, yu^(-1)}, yw] - 
     12*G[{0, 0, 0, 1, 1/(yu*yv)}, yw] + 12*G[{0, 0, 0, yu^(-1), 1}, yw] - 
     24*G[{0, 0, 0, yu^(-1), yu^(-1)}, yw] - 
     12*G[{0, 0, 0, yu^(-1), yv^(-1)}, yw] + 
     24*G[{0, 0, 0, yu^(-1), 1/(yu*yv)}, yw] + 
     12*G[{0, 0, 0, yu, yu}, yv^(-1)] - 12*G[{0, 0, 0, yv^(-1), yu^(-1)}, 
       yw] + 12*G[{0, 0, 0, yv^(-1), 1/(yu*yv)}, yw] - 
     12*G[{0, 0, 0, 1/(yu*yv), 1}, yw] + 24*G[{0, 0, 0, 1/(yu*yv), yu^(-1)}, 
       yw] + 12*G[{0, 0, 0, 1/(yu*yv), yv^(-1)}, yw] - 
     24*G[{0, 0, 0, 1/(yu*yv), 1/(yu*yv)}, yw] - 
     4*G[{0, 0, 1, 0, 1}, yv^(-1)] + 4*G[{0, 0, 1, 0, yu^(-1)}, yw] - 
     4*G[{0, 0, 1, 0, 1/(yu*yv)}, yw] + 12*G[{0, 0, 1, 1, 1}, yu^(-1)] + 
     4*G[{0, 0, 1, 1, yu^(-1)}, yw] + 4*G[{0, 0, 1, 1, yu}, yv^(-1)] - 
     4*G[{0, 0, 1, 1, 1/(yu*yv)}, yw] + 24*G[{0, 0, 1, yu^(-1), yu^(-1)}, 
       yw] + 12*G[{0, 0, 1, yu^(-1), yv^(-1)}, yw] - 
     16*G[{0, 0, 1, yu^(-1), 1/(yu*yv)}, yw] + 
     4*G[{0, 0, 1, yu, 1}, yv^(-1)] - 4*G[{0, 0, 1, yu, yu}, yv^(-1)] + 
     12*G[{0, 0, 1, yv^(-1), yu^(-1)}, yw] - 
     8*G[{0, 0, 1, yv^(-1), 1/(yu*yv)}, yw] - 
     4*G[{0, 0, 1, 1/(yu*yv), 1}, yw] - 16*G[{0, 0, 1, 1/(yu*yv), yu^(-1)}, 
       yw] - 4*G[{0, 0, 1, 1/(yu*yv), yv^(-1)}, yw] + 
     8*G[{0, 0, 1, 1/(yu*yv), 1/(yu*yv)}, yw] + 
     4*G[{0, 0, yu^(-1), 0, 1}, yw] - 8*G[{0, 0, yu^(-1), 0, yu^(-1)}, yw] - 
     4*G[{0, 0, yu^(-1), 0, yv^(-1)}, yw] + 
     8*G[{0, 0, yu^(-1), 0, 1/(yu*yv)}, yw] + 
     12*G[{0, 0, yu^(-1), 1, yu^(-1)}, yw] + 
     4*G[{0, 0, yu^(-1), 1, yv^(-1)}, yw] - 
     4*G[{0, 0, yu^(-1), 1, 1/(yu*yv)}, yw] + 
     8*G[{0, 0, yu^(-1), yu^(-1), yu^(-1)}, yw] + 
     16*G[{0, 0, yu^(-1), yu^(-1), 1/(yu*yv)}, yw] + 
     4*G[{0, 0, yu^(-1), yv^(-1), 1}, yw] - 
     8*G[{0, 0, yu^(-1), yv^(-1), yv^(-1)}, yw] - 
     4*G[{0, 0, yu^(-1), yv^(-1), 1/(yu*yv)}, yw] + 
     8*G[{0, 0, yu^(-1), 1/(yu*yv), yu^(-1)}, yw] - 
     8*G[{0, 0, yu^(-1), 1/(yu*yv), yv^(-1)}, yw] + 
     4*G[{0, 0, yu, 0, yu}, yv^(-1)] + 4*G[{0, 0, yu, 1, 1}, yv^(-1)] - 
     4*G[{0, 0, yu, 1, yu}, yv^(-1)] - 4*G[{0, 0, yu, yu, yu}, yv^(-1)] - 
     4*G[{0, 0, yv^(-1), 0, yu^(-1)}, yw] + 
     4*G[{0, 0, yv^(-1), 0, 1/(yu*yv)}, yw] + 
     8*G[{0, 0, yv^(-1), 1, yu^(-1)}, yw] - 
     4*G[{0, 0, yv^(-1), 1, 1/(yu*yv)}, yw] + 
     4*G[{0, 0, yv^(-1), yu^(-1), 1}, yw] - 
     4*G[{0, 0, yv^(-1), yu^(-1), yv^(-1)}, yw] - 
     4*G[{0, 0, yv^(-1), yu^(-1), 1/(yu*yv)}, yw] + 
     8*G[{0, 0, yv^(-1), yv^(-1), 1/(yu*yv)}, yw] + 
     8*G[{0, 0, yv^(-1), 1/(yu*yv), yu^(-1)}, yw] + 
     4*G[{0, 0, yv^(-1), 1/(yu*yv), yv^(-1)}, yw] - 
     4*G[{0, 0, 1/(yu*yv), 0, 1}, yw] + 8*G[{0, 0, 1/(yu*yv), 0, yu^(-1)}, 
       yw] + 4*G[{0, 0, 1/(yu*yv), 0, yv^(-1)}, yw] - 
     8*G[{0, 0, 1/(yu*yv), 0, 1/(yu*yv)}, yw] - 
     16*G[{0, 0, 1/(yu*yv), 1, yu^(-1)}, yw] - 
     4*G[{0, 0, 1/(yu*yv), 1, yv^(-1)}, yw] + 
     8*G[{0, 0, 1/(yu*yv), 1, 1/(yu*yv)}, yw] - 
     4*G[{0, 0, 1/(yu*yv), yu^(-1), 1}, yw] + 
     8*G[{0, 0, 1/(yu*yv), yu^(-1), yu^(-1)}, yw] + 
     8*G[{0, 0, 1/(yu*yv), yu^(-1), yv^(-1)}, yw] - 
     4*G[{0, 0, 1/(yu*yv), yv^(-1), 1}, yw] + 
     8*G[{0, 0, 1/(yu*yv), yv^(-1), yu^(-1)}, yw] + 
     8*G[{0, 0, 1/(yu*yv), yv^(-1), yv^(-1)}, yw] + 
     4*G[{0, 0, 1/(yu*yv), 1/(yu*yv), 1}, yw] + 
     8*G[{0, 0, 1/(yu*yv), 1/(yu*yv), yu^(-1)}, yw] + 
     4*G[{0, 0, 1/(yu*yv), 1/(yu*yv), yv^(-1)}, yw] + 
     2*G[{0, 1, 0, 1, 1}, yu^(-1)] + 2*G[{0, 1, 0, 1, 1}, yv^(-1)] + 
     4*G[{0, 1, 0, 1, yu^(-1)}, yw] + 4*G[{0, 1, 0, 1, yu}, yv^(-1)] - 
     2*G[{0, 1, 0, 1, 1/(yu*yv)}, yw] + 12*G[{0, 1, 0, yu^(-1), yu^(-1)}, 
       yw] + 6*G[{0, 1, 0, yu^(-1), yv^(-1)}, yw] - 
     10*G[{0, 1, 0, yu^(-1), 1/(yu*yv)}, yw] + 
     2*G[{0, 1, 0, yu, 1}, yv^(-1)] - 4*G[{0, 1, 0, yu, yu}, yv^(-1)] + 
     6*G[{0, 1, 0, yv^(-1), yu^(-1)}, yw] - 
     6*G[{0, 1, 0, yv^(-1), 1/(yu*yv)}, yw] - 
     8*G[{0, 1, 0, 1/(yu*yv), yu^(-1)}, yw] - 
     4*G[{0, 1, 0, 1/(yu*yv), yv^(-1)}, yw] + 
     6*G[{0, 1, 0, 1/(yu*yv), 1/(yu*yv)}, yw] + 
     2*G[{0, 1, 1, 0, yu}, yv^(-1)] + 16*G[{0, 1, 1, 1, 1}, yu^(-1)] - 
     10*G[{0, 1, 1, 1, yu}, yv^(-1)] - 12*G[{0, 1, 1, yu^(-1), yu^(-1)}, 
       yw] - 6*G[{0, 1, 1, yu^(-1), yv^(-1)}, yw] + 
     2*G[{0, 1, 1, yu^(-1), 1/(yu*yv)}, yw] - 
     6*G[{0, 1, 1, yu, 1}, yv^(-1)] + 4*G[{0, 1, 1, yu, yu}, yv^(-1)] - 
     6*G[{0, 1, 1, yv^(-1), yu^(-1)}, yw] + 
     2*G[{0, 1, 1, yv^(-1), 1/(yu*yv)}, yw] + 
     2*G[{0, 1, 1, 1/(yu*yv), yu^(-1)}, yw] + 
     2*G[{0, 1, 1, 1/(yu*yv), yv^(-1)}, yw] + 
     8*G[{0, 1, yu^(-1), 0, yu^(-1)}, yw] + 
     4*G[{0, 1, yu^(-1), 0, yv^(-1)}, yw] - 
     8*G[{0, 1, yu^(-1), 0, 1/(yu*yv)}, yw] - 
     12*G[{0, 1, yu^(-1), 1, yu^(-1)}, yw] - 
     4*G[{0, 1, yu^(-1), 1, yv^(-1)}, yw] + 
     4*G[{0, 1, yu^(-1), 1, 1/(yu*yv)}, yw] + 
     16*G[{0, 1, yu^(-1), yu^(-1), yu^(-1)}, yw] + 
     8*G[{0, 1, yu^(-1), yu^(-1), yv^(-1)}, yw] - 
     4*G[{0, 1, yu^(-1), yv^(-1), 1}, yw] + 
     8*G[{0, 1, yu^(-1), yv^(-1), yu^(-1)}, yw] + 
     8*G[{0, 1, yu^(-1), yv^(-1), yv^(-1)}, yw] + 
     4*G[{0, 1, yu^(-1), yv^(-1), 1/(yu*yv)}, yw] - 
     4*G[{0, 1, yu^(-1), 1/(yu*yv), yu^(-1)}, yw] - 
     4*G[{0, 1, yu^(-1), 1/(yu*yv), yv^(-1)}, yw] - 
     4*G[{0, 1, yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] - 
     2*G[{0, 1, yu, 0, yu}, yv^(-1)] - 4*G[{0, 1, yu, 1, 1}, yv^(-1)] + 
     4*G[{0, 1, yu, 1, yu}, yv^(-1)] + 4*G[{0, 1, yu, yu, 1}, yv^(-1)] + 
     4*G[{0, 1, yv^(-1), 0, yu^(-1)}, yw] - 
     4*G[{0, 1, yv^(-1), 0, 1/(yu*yv)}, yw] - 
     8*G[{0, 1, yv^(-1), 1, yu^(-1)}, yw] + 
     4*G[{0, 1, yv^(-1), 1, 1/(yu*yv)}, yw] - 
     4*G[{0, 1, yv^(-1), yu^(-1), 1}, yw] + 
     8*G[{0, 1, yv^(-1), yu^(-1), yu^(-1)}, yw] + 
     8*G[{0, 1, yv^(-1), yu^(-1), yv^(-1)}, yw] + 
     4*G[{0, 1, yv^(-1), yu^(-1), 1/(yu*yv)}, yw] + 
     8*G[{0, 1, yv^(-1), yv^(-1), yu^(-1)}, yw] - 
     4*G[{0, 1, yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] - 
     2*G[{0, 1, 1/(yu*yv), 0, yu^(-1)}, yw] - 
     2*G[{0, 1, 1/(yu*yv), 0, yv^(-1)}, yw] + 
     2*G[{0, 1, 1/(yu*yv), 0, 1/(yu*yv)}, yw] + 
     4*G[{0, 1, 1/(yu*yv), 1, yu^(-1)}, yw] - 
     4*G[{0, 1, 1/(yu*yv), 1, 1/(yu*yv)}, yw] - 
     12*G[{0, 1, 1/(yu*yv), yu^(-1), yu^(-1)}, yw] - 
     6*G[{0, 1, 1/(yu*yv), yu^(-1), yv^(-1)}, yw] + 
     2*G[{0, 1, 1/(yu*yv), yu^(-1), 1/(yu*yv)}, yw] - 
     6*G[{0, 1, 1/(yu*yv), yv^(-1), yu^(-1)}, yw] + 
     2*G[{0, 1, 1/(yu*yv), yv^(-1), 1/(yu*yv)}, yw] - 
     4*G[{0, 1, 1/(yu*yv), 1/(yu*yv), 1}, yw] + 
     2*G[{0, 1, 1/(yu*yv), 1/(yu*yv), yu^(-1)}, yw] + 
     6*G[{0, 1, 1/(yu*yv), 1/(yu*yv), yv^(-1)}, yw] + 
     8*G[{0, yu^(-1), 0, yu^(-1), yu^(-1)}, yw] + 
     2*G[{0, yu^(-1), 0, yu^(-1), yv^(-1)}, yw] + 
     8*G[{0, yu^(-1), 0, yu^(-1), 1/(yu*yv)}, yw] + 
     2*G[{0, yu^(-1), 0, yv^(-1), yu^(-1)}, yw] + 
     2*G[{0, yu^(-1), 0, 1/(yu*yv), yu^(-1)}, yw] - 
     6*G[{0, yu^(-1), 0, 1/(yu*yv), yv^(-1)}, yw] - 
     2*G[{0, yu^(-1), 0, 1/(yu*yv), 1/(yu*yv)}, yw] + 
     12*G[{0, yu^(-1), 1, yu^(-1), yu^(-1)}, yw] + 
     6*G[{0, yu^(-1), 1, yu^(-1), yv^(-1)}, yw] - 
     2*G[{0, yu^(-1), 1, yu^(-1), 1/(yu*yv)}, yw] + 
     6*G[{0, yu^(-1), 1, yv^(-1), yu^(-1)}, yw] - 
     2*G[{0, yu^(-1), 1, yv^(-1), 1/(yu*yv)}, yw] - 
     2*G[{0, yu^(-1), 1, 1/(yu*yv), yu^(-1)}, yw] - 
     2*G[{0, yu^(-1), 1, 1/(yu*yv), yv^(-1)}, yw] - 
     4*G[{0, yu^(-1), yu^(-1), 0, yv^(-1)}, yw] + 
     8*G[{0, yu^(-1), yu^(-1), 0, 1/(yu*yv)}, yw] + 
     12*G[{0, yu^(-1), yu^(-1), 1, yu^(-1)}, yw] + 
     4*G[{0, yu^(-1), yu^(-1), 1, yv^(-1)}, yw] - 
     4*G[{0, yu^(-1), yu^(-1), 1, 1/(yu*yv)}, yw] - 
     16*G[{0, yu^(-1), yu^(-1), yu^(-1), yu^(-1)}, yw] - 
     8*G[{0, yu^(-1), yu^(-1), yu^(-1), yv^(-1)}, yw] + 
     4*G[{0, yu^(-1), yu^(-1), yv^(-1), 1}, yw] - 
     8*G[{0, yu^(-1), yu^(-1), yv^(-1), yu^(-1)}, yw] - 
     8*G[{0, yu^(-1), yu^(-1), yv^(-1), yv^(-1)}, yw] - 
     4*G[{0, yu^(-1), yu^(-1), yv^(-1), 1/(yu*yv)}, yw] + 
     4*G[{0, yu^(-1), yu^(-1), 1/(yu*yv), yu^(-1)}, yw] + 
     4*G[{0, yu^(-1), yu^(-1), 1/(yu*yv), yv^(-1)}, yw] + 
     4*G[{0, yu^(-1), yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] - 
     2*G[{0, yu^(-1), yv^(-1), 0, yv^(-1)}, yw] + 
     6*G[{0, yu^(-1), yv^(-1), 0, 1/(yu*yv)}, yw] + 
     12*G[{0, yu^(-1), yv^(-1), 1, yu^(-1)}, yw] + 
     4*G[{0, yu^(-1), yv^(-1), 1, yv^(-1)}, yw] - 
     4*G[{0, yu^(-1), yv^(-1), 1, 1/(yu*yv)}, yw] + 
     4*G[{0, yu^(-1), yv^(-1), yu^(-1), 1}, yw] - 
     8*G[{0, yu^(-1), yv^(-1), yu^(-1), yu^(-1)}, yw] - 
     8*G[{0, yu^(-1), yv^(-1), yu^(-1), yv^(-1)}, yw] - 
     4*G[{0, yu^(-1), yv^(-1), yu^(-1), 1/(yu*yv)}, yw] + 
     4*G[{0, yu^(-1), yv^(-1), yv^(-1), 1}, yw] - 
     8*G[{0, yu^(-1), yv^(-1), yv^(-1), yu^(-1)}, yw] - 
     8*G[{0, yu^(-1), yv^(-1), yv^(-1), yv^(-1)}, yw] - 
     4*G[{0, yu^(-1), yv^(-1), yv^(-1), 1/(yu*yv)}, yw] + 
     4*G[{0, yu^(-1), yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] - 
     6*G[{0, yu^(-1), 1/(yu*yv), 0, yv^(-1)}, yw] + 
     4*G[{0, yu^(-1), 1/(yu*yv), yu^(-1), yu^(-1)}, yw] + 
     2*G[{0, yu^(-1), 1/(yu*yv), yu^(-1), yv^(-1)}, yw] + 
     2*G[{0, yu^(-1), 1/(yu*yv), yu^(-1), 1/(yu*yv)}, yw] + 
     2*G[{0, yu^(-1), 1/(yu*yv), yv^(-1), yu^(-1)}, yw] + 
     2*G[{0, yu^(-1), 1/(yu*yv), yv^(-1), 1/(yu*yv)}, yw] + 
     2*G[{0, yu^(-1), 1/(yu*yv), 1/(yu*yv), yu^(-1)}, yw] + 
     2*G[{0, yu^(-1), 1/(yu*yv), 1/(yu*yv), yv^(-1)}, yw] - 
     4*G[{0, yu, 0, yu, yu}, yv^(-1)] + 2*G[{0, yu, 1, 1, yu}, yv^(-1)] + 
     2*G[{0, yu, 1, yu, 1}, yv^(-1)] - 4*G[{0, yu, 1, yu, yu}, yv^(-1)] + 
     4*G[{0, yu, yu, 1, 1}, yv^(-1)] - 4*G[{0, yu, yu, 1, yu}, yv^(-1)] + 
     8*G[{0, yu, yu, yu, yu}, yv^(-1)] + 
     2*G[{0, yv^(-1), 0, yv^(-1), yu^(-1)}, yw] + 
     4*G[{0, yv^(-1), 0, yv^(-1), 1/(yu*yv)}, yw] + 
     4*G[{0, yv^(-1), 0, 1/(yu*yv), yu^(-1)}, yw] + 
     2*G[{0, yv^(-1), 0, 1/(yu*yv), yv^(-1)}, yw] - 
     2*G[{0, yv^(-1), 0, 1/(yu*yv), 1/(yu*yv)}, yw] + 
     12*G[{0, yv^(-1), 1, yu^(-1), yu^(-1)}, yw] + 
     6*G[{0, yv^(-1), 1, yu^(-1), yv^(-1)}, yw] - 
     2*G[{0, yv^(-1), 1, yu^(-1), 1/(yu*yv)}, yw] + 
     6*G[{0, yv^(-1), 1, yv^(-1), yu^(-1)}, yw] - 
     2*G[{0, yv^(-1), 1, yv^(-1), 1/(yu*yv)}, yw] - 
     2*G[{0, yv^(-1), 1, 1/(yu*yv), yu^(-1)}, yw] - 
     2*G[{0, yv^(-1), 1, 1/(yu*yv), yv^(-1)}, yw] + 
     6*G[{0, yv^(-1), yu^(-1), 0, 1/(yu*yv)}, yw] + 
     12*G[{0, yv^(-1), yu^(-1), 1, yu^(-1)}, yw] + 
     4*G[{0, yv^(-1), yu^(-1), 1, yv^(-1)}, yw] - 
     4*G[{0, yv^(-1), yu^(-1), 1, 1/(yu*yv)}, yw] + 
     4*G[{0, yv^(-1), yu^(-1), yu^(-1), 1}, yw] - 
     8*G[{0, yv^(-1), yu^(-1), yu^(-1), yu^(-1)}, yw] - 
     8*G[{0, yv^(-1), yu^(-1), yu^(-1), yv^(-1)}, yw] - 
     4*G[{0, yv^(-1), yu^(-1), yu^(-1), 1/(yu*yv)}, yw] + 
     4*G[{0, yv^(-1), yu^(-1), yv^(-1), 1}, yw] - 
     8*G[{0, yv^(-1), yu^(-1), yv^(-1), yu^(-1)}, yw] - 
     8*G[{0, yv^(-1), yu^(-1), yv^(-1), yv^(-1)}, yw] - 
     4*G[{0, yv^(-1), yu^(-1), yv^(-1), 1/(yu*yv)}, yw] + 
     4*G[{0, yv^(-1), yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] + 
     4*G[{0, yv^(-1), yv^(-1), 0, 1/(yu*yv)}, yw] + 
     8*G[{0, yv^(-1), yv^(-1), 1, yu^(-1)}, yw] - 
     4*G[{0, yv^(-1), yv^(-1), 1, 1/(yu*yv)}, yw] + 
     4*G[{0, yv^(-1), yv^(-1), yu^(-1), 1}, yw] - 
     8*G[{0, yv^(-1), yv^(-1), yu^(-1), yu^(-1)}, yw] - 
     8*G[{0, yv^(-1), yv^(-1), yu^(-1), yv^(-1)}, yw] - 
     4*G[{0, yv^(-1), yv^(-1), yu^(-1), 1/(yu*yv)}, yw] - 
     8*G[{0, yv^(-1), yv^(-1), yv^(-1), yu^(-1)}, yw] + 
     4*G[{0, yv^(-1), yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] + 
     4*G[{0, yv^(-1), 1/(yu*yv), yu^(-1), yu^(-1)}, yw] + 
     2*G[{0, yv^(-1), 1/(yu*yv), yu^(-1), yv^(-1)}, yw] + 
     2*G[{0, yv^(-1), 1/(yu*yv), yu^(-1), 1/(yu*yv)}, yw] + 
     2*G[{0, yv^(-1), 1/(yu*yv), yv^(-1), yu^(-1)}, yw] + 
     2*G[{0, yv^(-1), 1/(yu*yv), yv^(-1), 1/(yu*yv)}, yw] + 
     2*G[{0, yv^(-1), 1/(yu*yv), 1/(yu*yv), yu^(-1)}, yw] + 
     2*G[{0, yv^(-1), 1/(yu*yv), 1/(yu*yv), yv^(-1)}, yw] + 
     6*G[{0, 1/(yu*yv), 0, 1/(yu*yv), yu^(-1)}, yw] + 
     6*G[{0, 1/(yu*yv), 0, 1/(yu*yv), yv^(-1)}, yw] + 
     2*G[{0, 1/(yu*yv), 0, 1/(yu*yv), 1/(yu*yv)}, yw] - 
     12*G[{0, 1/(yu*yv), 1, yu^(-1), yu^(-1)}, yw] - 
     6*G[{0, 1/(yu*yv), 1, yu^(-1), yv^(-1)}, yw] + 
     2*G[{0, 1/(yu*yv), 1, yu^(-1), 1/(yu*yv)}, yw] - 
     6*G[{0, 1/(yu*yv), 1, yv^(-1), yu^(-1)}, yw] + 
     2*G[{0, 1/(yu*yv), 1, yv^(-1), 1/(yu*yv)}, yw] + 
     2*G[{0, 1/(yu*yv), 1, 1/(yu*yv), yu^(-1)}, yw] + 
     2*G[{0, 1/(yu*yv), 1, 1/(yu*yv), yv^(-1)}, yw] - 
     12*G[{0, 1/(yu*yv), yu^(-1), 1, yu^(-1)}, yw] - 
     4*G[{0, 1/(yu*yv), yu^(-1), 1, yv^(-1)}, yw] + 
     4*G[{0, 1/(yu*yv), yu^(-1), 1, 1/(yu*yv)}, yw] - 
     4*G[{0, 1/(yu*yv), yu^(-1), yu^(-1), 1}, yw] + 
     8*G[{0, 1/(yu*yv), yu^(-1), yu^(-1), yu^(-1)}, yw] + 
     8*G[{0, 1/(yu*yv), yu^(-1), yu^(-1), yv^(-1)}, yw] + 
     4*G[{0, 1/(yu*yv), yu^(-1), yu^(-1), 1/(yu*yv)}, yw] - 
     4*G[{0, 1/(yu*yv), yu^(-1), yv^(-1), 1}, yw] + 
     8*G[{0, 1/(yu*yv), yu^(-1), yv^(-1), yu^(-1)}, yw] + 
     8*G[{0, 1/(yu*yv), yu^(-1), yv^(-1), yv^(-1)}, yw] + 
     4*G[{0, 1/(yu*yv), yu^(-1), yv^(-1), 1/(yu*yv)}, yw] - 
     4*G[{0, 1/(yu*yv), yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] - 
     12*G[{0, 1/(yu*yv), yv^(-1), 1, yu^(-1)}, yw] - 
     4*G[{0, 1/(yu*yv), yv^(-1), 1, yv^(-1)}, yw] + 
     4*G[{0, 1/(yu*yv), yv^(-1), 1, 1/(yu*yv)}, yw] - 
     4*G[{0, 1/(yu*yv), yv^(-1), yu^(-1), 1}, yw] + 
     8*G[{0, 1/(yu*yv), yv^(-1), yu^(-1), yu^(-1)}, yw] + 
     8*G[{0, 1/(yu*yv), yv^(-1), yu^(-1), yv^(-1)}, yw] + 
     4*G[{0, 1/(yu*yv), yv^(-1), yu^(-1), 1/(yu*yv)}, yw] - 
     4*G[{0, 1/(yu*yv), yv^(-1), yv^(-1), 1}, yw] + 
     8*G[{0, 1/(yu*yv), yv^(-1), yv^(-1), yu^(-1)}, yw] + 
     8*G[{0, 1/(yu*yv), yv^(-1), yv^(-1), yv^(-1)}, yw] + 
     4*G[{0, 1/(yu*yv), yv^(-1), yv^(-1), 1/(yu*yv)}, yw] - 
     4*G[{0, 1/(yu*yv), yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] - 
     4*G[{0, 1/(yu*yv), 1/(yu*yv), 1, yu^(-1)}, yw] + 
     4*G[{0, 1/(yu*yv), 1/(yu*yv), 1, 1/(yu*yv)}, yw] + 
     4*G[{0, 1/(yu*yv), 1/(yu*yv), yu^(-1), yu^(-1)}, yw] + 
     2*G[{0, 1/(yu*yv), 1/(yu*yv), yu^(-1), yv^(-1)}, yw] - 
     6*G[{0, 1/(yu*yv), 1/(yu*yv), yu^(-1), 1/(yu*yv)}, yw] + 
     2*G[{0, 1/(yu*yv), 1/(yu*yv), yv^(-1), yu^(-1)}, yw] - 
     6*G[{0, 1/(yu*yv), 1/(yu*yv), yv^(-1), 1/(yu*yv)}, yw] + 
     4*G[{0, 1/(yu*yv), 1/(yu*yv), 1/(yu*yv), 1}, yw] - 
     6*G[{0, 1/(yu*yv), 1/(yu*yv), 1/(yu*yv), yu^(-1)}, yw] - 
     10*G[{0, 1/(yu*yv), 1/(yu*yv), 1/(yu*yv), yv^(-1)}, yw] + 
     4*G[{1, 1, 1, yu, yu}, yv^(-1)] + 
     60*G[{1, 1, yu^(-1), yu^(-1), yu^(-1)}, yw] + 
     16*G[{1, 1, yu^(-1), yu^(-1), yv^(-1)}, yw] - 
     12*G[{1, 1, yu^(-1), yu^(-1), 1/(yu*yv)}, yw] + 
     16*G[{1, 1, yu^(-1), yv^(-1), yu^(-1)}, yw] + 
     8*G[{1, 1, yu^(-1), yv^(-1), yv^(-1)}, yw] - 
     4*G[{1, 1, yu^(-1), yv^(-1), 1/(yu*yv)}, yw] - 
     12*G[{1, 1, yu^(-1), 1/(yu*yv), yu^(-1)}, yw] - 
     4*G[{1, 1, yu^(-1), 1/(yu*yv), yv^(-1)}, yw] + 
     12*G[{1, 1, yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] + 
     4*G[{1, 1, yu, 1, yu}, yv^(-1)] - 20*G[{1, 1, yu, yu, yu}, yv^(-1)] + 
     16*G[{1, 1, yv^(-1), yu^(-1), yu^(-1)}, yw] + 
     8*G[{1, 1, yv^(-1), yu^(-1), yv^(-1)}, yw] - 
     4*G[{1, 1, yv^(-1), yu^(-1), 1/(yu*yv)}, yw] + 
     8*G[{1, 1, yv^(-1), yv^(-1), yu^(-1)}, yw] - 
     4*G[{1, 1, yv^(-1), 1/(yu*yv), yu^(-1)}, yw] + 
     8*G[{1, 1, yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] - 
     12*G[{1, 1, 1/(yu*yv), yu^(-1), yu^(-1)}, yw] - 
     4*G[{1, 1, 1/(yu*yv), yu^(-1), yv^(-1)}, yw] + 
     4*G[{1, 1, 1/(yu*yv), yu^(-1), 1/(yu*yv)}, yw] - 
     4*G[{1, 1, 1/(yu*yv), yv^(-1), yu^(-1)}, yw] + 
     8*G[{1, 1, 1/(yu*yv), yv^(-1), 1/(yu*yv)}, yw] - 
     4*G[{1, 1, 1/(yu*yv), 1/(yu*yv), yu^(-1)}, yw] + 
     8*G[{1, 1, 1/(yu*yv), 1/(yu*yv), yv^(-1)}, yw] + 
     12*G[{1, 1, 1/(yu*yv), 1/(yu*yv), 1/(yu*yv)}, yw] + 
     20*G[{1, yu^(-1), 1, yu^(-1), yu^(-1)}, yw] + 
     4*G[{1, yu^(-1), 1, yu^(-1), yv^(-1)}, yw] - 
     4*G[{1, yu^(-1), 1, yu^(-1), 1/(yu*yv)}, yw] + 
     4*G[{1, yu^(-1), 1, yv^(-1), yu^(-1)}, yw] + 
     4*G[{1, yu^(-1), 1, yv^(-1), yv^(-1)}, yw] - 
     4*G[{1, yu^(-1), 1, 1/(yu*yv), yu^(-1)}, yw] + 
     8*G[{1, yu^(-1), 1, 1/(yu*yv), 1/(yu*yv)}, yw] - 
     4*G[{1, yu^(-1), yu^(-1), 1, yv^(-1)}, yw] + 
     24*G[{1, yu^(-1), yu^(-1), yu^(-1), yu^(-1)}, yw] + 
     8*G[{1, yu^(-1), yu^(-1), yu^(-1), yv^(-1)}, yw] + 
     8*G[{1, yu^(-1), yu^(-1), yv^(-1), yu^(-1)}, yw] + 
     8*G[{1, yu^(-1), yu^(-1), yv^(-1), yv^(-1)}, yw] + 
     4*G[{1, yu^(-1), yu^(-1), yv^(-1), 1/(yu*yv)}, yw] - 
     4*G[{1, yu^(-1), yu^(-1), 1/(yu*yv), yu^(-1)}, yw] - 
     8*G[{1, yu^(-1), yu^(-1), 1/(yu*yv), yv^(-1)}, yw] - 
     8*G[{1, yu^(-1), yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] + 
     4*G[{1, yu^(-1), yv^(-1), 1, 1/(yu*yv)}, yw] + 
     8*G[{1, yu^(-1), yv^(-1), yu^(-1), yu^(-1)}, yw] + 
     8*G[{1, yu^(-1), yv^(-1), yu^(-1), yv^(-1)}, yw] + 
     4*G[{1, yu^(-1), yv^(-1), yu^(-1), 1/(yu*yv)}, yw] + 
     8*G[{1, yu^(-1), yv^(-1), yv^(-1), yu^(-1)}, yw] + 
     8*G[{1, yu^(-1), yv^(-1), yv^(-1), yv^(-1)}, yw] + 
     4*G[{1, yu^(-1), yv^(-1), yv^(-1), 1/(yu*yv)}, yw] - 
     4*G[{1, yu^(-1), yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] + 
     4*G[{1, yu^(-1), 1/(yu*yv), 1, 1/(yu*yv)}, yw] - 
     4*G[{1, yu^(-1), 1/(yu*yv), yu^(-1), yu^(-1)}, yw] - 
     4*G[{1, yu^(-1), 1/(yu*yv), yu^(-1), yv^(-1)}, yw] - 
     4*G[{1, yu^(-1), 1/(yu*yv), yu^(-1), 1/(yu*yv)}, yw] - 
     4*G[{1, yu^(-1), 1/(yu*yv), yv^(-1), yu^(-1)}, yw] - 
     4*G[{1, yu^(-1), 1/(yu*yv), 1/(yu*yv), yu^(-1)}, yw] - 
     4*G[{1, yu, 1, yu, yu}, yv^(-1)] - 8*G[{1, yu, yu, yu, yu}, yv^(-1)] + 
     4*G[{1, yv^(-1), 1, yv^(-1), 1/(yu*yv)}, yw] + 
     4*G[{1, yv^(-1), 1, 1/(yu*yv), yv^(-1)}, yw] + 
     4*G[{1, yv^(-1), 1, 1/(yu*yv), 1/(yu*yv)}, yw] + 
     4*G[{1, yv^(-1), yu^(-1), 1, 1/(yu*yv)}, yw] + 
     8*G[{1, yv^(-1), yu^(-1), yu^(-1), yu^(-1)}, yw] + 
     8*G[{1, yv^(-1), yu^(-1), yu^(-1), yv^(-1)}, yw] + 
     4*G[{1, yv^(-1), yu^(-1), yu^(-1), 1/(yu*yv)}, yw] + 
     8*G[{1, yv^(-1), yu^(-1), yv^(-1), yu^(-1)}, yw] + 
     8*G[{1, yv^(-1), yu^(-1), yv^(-1), yv^(-1)}, yw] + 
     4*G[{1, yv^(-1), yu^(-1), yv^(-1), 1/(yu*yv)}, yw] - 
     4*G[{1, yv^(-1), yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] + 
     4*G[{1, yv^(-1), yv^(-1), 1, 1/(yu*yv)}, yw] + 
     8*G[{1, yv^(-1), yv^(-1), yu^(-1), yu^(-1)}, yw] + 
     8*G[{1, yv^(-1), yv^(-1), yu^(-1), yv^(-1)}, yw] + 
     4*G[{1, yv^(-1), yv^(-1), yu^(-1), 1/(yu*yv)}, yw] + 
     8*G[{1, yv^(-1), yv^(-1), yv^(-1), yu^(-1)}, yw] - 
     8*G[{1, yv^(-1), yv^(-1), yv^(-1), 1/(yu*yv)}, yw] - 
     8*G[{1, yv^(-1), yv^(-1), 1/(yu*yv), yv^(-1)}, yw] - 
     4*G[{1, yv^(-1), yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] - 
     8*G[{1, yv^(-1), 1/(yu*yv), yu^(-1), yu^(-1)}, yw] - 
     4*G[{1, yv^(-1), 1/(yu*yv), yu^(-1), yv^(-1)}, yw] - 
     4*G[{1, yv^(-1), 1/(yu*yv), yv^(-1), yu^(-1)}, yw] - 
     8*G[{1, yv^(-1), 1/(yu*yv), yv^(-1), yv^(-1)}, yw] + 
     4*G[{1, yv^(-1), 1/(yu*yv), 1/(yu*yv), yv^(-1)}, yw] - 
     4*G[{1, 1/(yu*yv), 1, 1/(yu*yv), yu^(-1)}, yw] + 
     4*G[{1, 1/(yu*yv), 1, 1/(yu*yv), 1/(yu*yv)}, yw] - 
     4*G[{1, 1/(yu*yv), yu^(-1), yu^(-1), 1/(yu*yv)}, yw] - 
     4*G[{1, 1/(yu*yv), yu^(-1), 1/(yu*yv), yu^(-1)}, yw] + 
     4*G[{1, 1/(yu*yv), yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] - 
     8*G[{1, 1/(yu*yv), yv^(-1), yv^(-1), yv^(-1)}, yw] + 
     4*G[{1, 1/(yu*yv), yv^(-1), yv^(-1), 1/(yu*yv)}, yw] + 
     8*G[{1, 1/(yu*yv), yv^(-1), 1/(yu*yv), yv^(-1)}, yw] - 
     12*G[{1, 1/(yu*yv), 1/(yu*yv), yu^(-1), yu^(-1)}, yw] - 
     4*G[{1, 1/(yu*yv), 1/(yu*yv), yu^(-1), yv^(-1)}, yw] + 
     8*G[{1, 1/(yu*yv), 1/(yu*yv), yu^(-1), 1/(yu*yv)}, yw] - 
     4*G[{1, 1/(yu*yv), 1/(yu*yv), yv^(-1), yu^(-1)}, yw] + 
     8*G[{1, 1/(yu*yv), 1/(yu*yv), yv^(-1), yv^(-1)}, yw] + 
     4*G[{1, 1/(yu*yv), 1/(yu*yv), yv^(-1), 1/(yu*yv)}, yw] + 
     8*G[{1, 1/(yu*yv), 1/(yu*yv), 1/(yu*yv), yu^(-1)}, yw] + 
     8*G[{1, 1/(yu*yv), 1/(yu*yv), 1/(yu*yv), yv^(-1)}, yw] + 
     8*G[{yu^(-1), yu^(-1), yu^(-1), yu^(-1), 1/(yu*yv)}, yw] - 
     8*G[{yu^(-1), yu^(-1), yu^(-1), 1/(yu*yv), yv^(-1)}, yw] + 
     12*G[{yu^(-1), yu^(-1), yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] + 
     4*G[{yu^(-1), yu^(-1), 1/(yu*yv), yu^(-1), 1/(yu*yv)}, yw] + 
     8*G[{yu^(-1), yu^(-1), 1/(yu*yv), yv^(-1), yv^(-1)}, yw] + 
     4*G[{yu^(-1), yu^(-1), 1/(yu*yv), yv^(-1), 1/(yu*yv)}, yw] + 
     8*G[{yu^(-1), yu^(-1), 1/(yu*yv), 1/(yu*yv), yv^(-1)}, yw] + 
     4*G[{yu^(-1), 1/(yu*yv), yu^(-1), 1/(yu*yv), yv^(-1)}, yw] - 
     8*G[{yu^(-1), 1/(yu*yv), yv^(-1), yv^(-1), yv^(-1)}, yw] - 
     4*G[{yu^(-1), 1/(yu*yv), yv^(-1), yv^(-1), 1/(yu*yv)}, yw] + 
     4*G[{yu^(-1), 1/(yu*yv), yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] + 
     4*G[{yu^(-1), 1/(yu*yv), 1/(yu*yv), yv^(-1), 1/(yu*yv)}, yw] + 
     4*G[{yu^(-1), 1/(yu*yv), 1/(yu*yv), 1/(yu*yv), yv^(-1)}, yw] - 
     8*G[{yv^(-1), yv^(-1), yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] + 
     4*G[{yv^(-1), yv^(-1), 1/(yu*yv), 1/(yu*yv), 1/(yu*yv)}, yw] + 
     4*G[{yv^(-1), 1/(yu*yv), yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] + 
     (Pi^2*Zeta[3])/3 - 2*G[{0}, yu^(-1)]^2*Zeta[3] - 
     4*G[{0}, yu^(-1)]*G[{0}, yv^(-1)]*Zeta[3] - 2*G[{0}, yv^(-1)]^2*
      Zeta[3] + 4*G[{0}, yu^(-1)]*G[{0}, yw]*Zeta[3] + 
     4*G[{0}, yv^(-1)]*G[{0}, yw]*Zeta[3] - 2*G[{0}, yw]^2*Zeta[3] - 
     2*G[{1}, yu^(-1)]^2*Zeta[3] + 4*G[{1}, yu^(-1)]*G[{yu^(-1)}, yw]*
      Zeta[3] - 8*G[{1}, yw]*G[{yu^(-1)}, yw]*Zeta[3] + 
     2*G[{yu^(-1)}, yw]^2*Zeta[3] + 4*G[{0}, yu^(-1)]*G[{yu}, yv^(-1)]*
      Zeta[3] + 4*G[{0}, yv^(-1)]*G[{yu}, yv^(-1)]*Zeta[3] - 
     4*G[{0}, yw]*G[{yu}, yv^(-1)]*Zeta[3] - 2*G[{yu}, yv^(-1)]^2*Zeta[3] - 
     4*G[{0}, yu^(-1)]*G[{1/(yu*yv)}, yw]*Zeta[3] - 
     4*G[{0}, yv^(-1)]*G[{1/(yu*yv)}, yw]*Zeta[3] + 
     4*G[{0}, yw]*G[{1/(yu*yv)}, yw]*Zeta[3] + 4*G[{yu}, yv^(-1)]*
      G[{1/(yu*yv)}, yw]*Zeta[3] - 2*G[{1/(yu*yv)}, yw]^2*Zeta[3] + 
     4*G[{0, 1}, yu^(-1)]*Zeta[3] + 4*G[{0, 1}, yw]*Zeta[3] - 
     4*G[{0, yu^(-1)}, yw]*Zeta[3] + 8*G[{1, yu^(-1)}, yw]*Zeta[3] - 7*Zeta[5]
 
M1uwvRegII = (17*Pi^4*G[{1}, yu^(-1)])/180 + (Pi^2*G[{1}, yu^(-1)]^3)/18 - 
     (Pi^2*G[{0}, yu^(-1)]*G[{1}, yu^(-1)]*G[{yu^(-1)}, yw])/3 - 
     (Pi^2*G[{0}, yv^(-1)]*G[{1}, yu^(-1)]*G[{yu^(-1)}, yw])/3 + 
     (Pi^2*G[{0}, yw]*G[{1}, yu^(-1)]*G[{yu^(-1)}, yw])/3 + 
     (Pi^2*G[{1}, yu^(-1)]^2*G[{yu^(-1)}, yw])/6 + 
     (Pi^2*G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*G[{yu^(-1)}, yw])/3 - 
     (Pi^2*G[{1}, yu^(-1)]*G[{1}, yw]*G[{yu^(-1)}, yw])/3 - 
     (Pi^2*G[{1}, yw]^2*G[{yu^(-1)}, yw])/6 + G[{0}, yu^(-1)]*G[{1}, yu^(-1)]*
      G[{1}, yw]^2*G[{yu^(-1)}, yw] + G[{0}, yv^(-1)]*G[{1}, yu^(-1)]*
      G[{1}, yw]^2*G[{yu^(-1)}, yw] - G[{0}, yw]*G[{1}, yu^(-1)]*G[{1}, yw]^2*
      G[{yu^(-1)}, yw] - G[{1}, yu^(-1)]^2*G[{1}, yw]^2*G[{yu^(-1)}, yw] - 
     2*G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*G[{1}, yw]^2*G[{yu^(-1)}, yw] + 
     (2*G[{0}, yu^(-1)]*G[{1}, yw]^3*G[{yu^(-1)}, yw])/3 + 
     (2*G[{0}, yv^(-1)]*G[{1}, yw]^3*G[{yu^(-1)}, yw])/3 - 
     (2*G[{0}, yw]*G[{1}, yw]^3*G[{yu^(-1)}, yw])/3 - 
     (2*G[{1}, yu^(-1)]*G[{1}, yw]^3*G[{yu^(-1)}, yw])/3 - 
     (2*G[{1}, yv^(-1)]*G[{1}, yw]^3*G[{yu^(-1)}, yw])/3 + 
     (Pi^2*G[{1}, yv^(-1)]*G[{yu^(-1)}, yw]^2)/3 - 
     2*G[{0}, yu^(-1)]*G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*G[{yu^(-1)}, yw]^2 - 
     2*G[{0}, yv^(-1)]*G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*G[{yu^(-1)}, yw]^2 + 
     2*G[{0}, yw]*G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*G[{yu^(-1)}, yw]^2 + 
     G[{1}, yu^(-1)]^2*G[{1}, yv^(-1)]*G[{yu^(-1)}, yw]^2 + 
     2*G[{1}, yu^(-1)]*G[{1}, yv^(-1)]^2*G[{yu^(-1)}, yw]^2 + 
     (Pi^2*G[{1}, yw]*G[{yu^(-1)}, yw]^2)/3 - 2*G[{0}, yu^(-1)]*
      G[{1}, yu^(-1)]*G[{1}, yw]*G[{yu^(-1)}, yw]^2 - 
     2*G[{0}, yv^(-1)]*G[{1}, yu^(-1)]*G[{1}, yw]*G[{yu^(-1)}, yw]^2 + 
     2*G[{0}, yw]*G[{1}, yu^(-1)]*G[{1}, yw]*G[{yu^(-1)}, yw]^2 + 
     G[{1}, yu^(-1)]^2*G[{1}, yw]*G[{yu^(-1)}, yw]^2 - 
     2*G[{1}, yu^(-1)]*G[{1}, yw]^2*G[{yu^(-1)}, yw]^2 - 
     G[{1}, yv^(-1)]*G[{1}, yw]^2*G[{yu^(-1)}, yw]^2 - 
     G[{1}, yw]^3*G[{yu^(-1)}, yw]^2 - (Pi^2*G[{yu^(-1)}, yw]^3)/9 + 
     (2*G[{0}, yu^(-1)]*G[{1}, yu^(-1)]*G[{yu^(-1)}, yw]^3)/3 + 
     (2*G[{0}, yv^(-1)]*G[{1}, yu^(-1)]*G[{yu^(-1)}, yw]^3)/3 - 
     (2*G[{0}, yw]*G[{1}, yu^(-1)]*G[{yu^(-1)}, yw]^3)/3 - 
     (G[{1}, yu^(-1)]^2*G[{yu^(-1)}, yw]^3)/3 - 2*G[{0}, yu^(-1)]*
      G[{1}, yv^(-1)]*G[{yu^(-1)}, yw]^3 - 2*G[{0}, yv^(-1)]*G[{1}, yv^(-1)]*
      G[{yu^(-1)}, yw]^3 + 2*G[{0}, yw]*G[{1}, yv^(-1)]*G[{yu^(-1)}, yw]^3 - 
     (2*G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*G[{yu^(-1)}, yw]^3)/3 + 
     2*G[{1}, yv^(-1)]^2*G[{yu^(-1)}, yw]^3 - 2*G[{0}, yu^(-1)]*G[{1}, yw]*
      G[{yu^(-1)}, yw]^3 - 2*G[{0}, yv^(-1)]*G[{1}, yw]*G[{yu^(-1)}, yw]^3 + 
     2*G[{0}, yw]*G[{1}, yw]*G[{yu^(-1)}, yw]^3 + 
     (2*G[{1}, yu^(-1)]*G[{1}, yw]*G[{yu^(-1)}, yw]^3)/3 - 
     (5*G[{1}, yw]^2*G[{yu^(-1)}, yw]^3)/3 + 
     (2*G[{0}, yu^(-1)]*G[{yu^(-1)}, yw]^4)/3 + 
     (2*G[{0}, yv^(-1)]*G[{yu^(-1)}, yw]^4)/3 - 
     (2*G[{0}, yw]*G[{yu^(-1)}, yw]^4)/3 - 
     (11*G[{1}, yv^(-1)]*G[{yu^(-1)}, yw]^4)/6 - 
     (G[{1}, yw]*G[{yu^(-1)}, yw]^4)/2 + (11*G[{yu^(-1)}, yw]^5)/30 - 
     (17*Pi^4*G[{yu}, yv^(-1)])/180 - (Pi^2*G[{1}, yu^(-1)]^2*
       G[{yu}, yv^(-1)])/6 + (Pi^2*G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*
       G[{yu}, yv^(-1)])/3 + (Pi^2*G[{0}, yu^(-1)]*G[{yu^(-1)}, yw]*
       G[{yu}, yv^(-1)])/3 + (Pi^2*G[{0}, yv^(-1)]*G[{yu^(-1)}, yw]*
       G[{yu}, yv^(-1)])/3 - (Pi^2*G[{0}, yw]*G[{yu^(-1)}, yw]*
       G[{yu}, yv^(-1)])/3 + (2*Pi^2*G[{1}, yv^(-1)]*G[{yu^(-1)}, yw]*
       G[{yu}, yv^(-1)])/3 - 2*G[{1}, yu^(-1)]^2*G[{1}, yv^(-1)]*
      G[{yu^(-1)}, yw]*G[{yu}, yv^(-1)] + 2*G[{1}, yu^(-1)]*G[{1}, yv^(-1)]^2*
      G[{yu^(-1)}, yw]*G[{yu}, yv^(-1)] + 
     (Pi^2*G[{1}, yw]*G[{yu^(-1)}, yw]*G[{yu}, yv^(-1)])/3 - 
     G[{0}, yu^(-1)]*G[{1}, yw]^2*G[{yu^(-1)}, yw]*G[{yu}, yv^(-1)] - 
     G[{0}, yv^(-1)]*G[{1}, yw]^2*G[{yu^(-1)}, yw]*G[{yu}, yv^(-1)] + 
     G[{0}, yw]*G[{1}, yw]^2*G[{yu^(-1)}, yw]*G[{yu}, yv^(-1)] + 
     2*G[{1}, yu^(-1)]*G[{1}, yw]^2*G[{yu^(-1)}, yw]*G[{yu}, yv^(-1)] - 
     (Pi^2*G[{yu^(-1)}, yw]^2*G[{yu}, yv^(-1)])/3 + 
     2*G[{0}, yu^(-1)]*G[{1}, yu^(-1)]*G[{yu^(-1)}, yw]^2*G[{yu}, yv^(-1)] + 
     2*G[{0}, yv^(-1)]*G[{1}, yu^(-1)]*G[{yu^(-1)}, yw]^2*G[{yu}, yv^(-1)] - 
     2*G[{0}, yw]*G[{1}, yu^(-1)]*G[{yu^(-1)}, yw]^2*G[{yu}, yv^(-1)] - 
     G[{1}, yu^(-1)]^2*G[{yu^(-1)}, yw]^2*G[{yu}, yv^(-1)] - 
     2*G[{0}, yu^(-1)]*G[{1}, yv^(-1)]*G[{yu^(-1)}, yw]^2*G[{yu}, yv^(-1)] - 
     2*G[{0}, yv^(-1)]*G[{1}, yv^(-1)]*G[{yu^(-1)}, yw]^2*G[{yu}, yv^(-1)] + 
     2*G[{0}, yw]*G[{1}, yv^(-1)]*G[{yu^(-1)}, yw]^2*G[{yu}, yv^(-1)] - 
     2*G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*G[{yu^(-1)}, yw]^2*G[{yu}, yv^(-1)] + 
     2*G[{1}, yv^(-1)]^2*G[{yu^(-1)}, yw]^2*G[{yu}, yv^(-1)] + 
     2*G[{0}, yu^(-1)]*G[{1}, yw]*G[{yu^(-1)}, yw]^2*G[{yu}, yv^(-1)] + 
     2*G[{0}, yv^(-1)]*G[{1}, yw]*G[{yu^(-1)}, yw]^2*G[{yu}, yv^(-1)] - 
     2*G[{0}, yw]*G[{1}, yw]*G[{yu^(-1)}, yw]^2*G[{yu}, yv^(-1)] + 
     2*G[{1}, yu^(-1)]*G[{1}, yw]*G[{yu^(-1)}, yw]^2*G[{yu}, yv^(-1)] - 
     3*G[{1}, yv^(-1)]*G[{1}, yw]*G[{yu^(-1)}, yw]^2*G[{yu}, yv^(-1)] + 
     3*G[{1}, yw]^2*G[{yu^(-1)}, yw]^2*G[{yu}, yv^(-1)] + 
     (4*G[{0}, yu^(-1)]*G[{yu^(-1)}, yw]^3*G[{yu}, yv^(-1)])/3 + 
     (4*G[{0}, yv^(-1)]*G[{yu^(-1)}, yw]^3*G[{yu}, yv^(-1)])/3 - 
     (4*G[{0}, yw]*G[{yu^(-1)}, yw]^3*G[{yu}, yv^(-1)])/3 - 
     2*G[{1}, yv^(-1)]*G[{yu^(-1)}, yw]^3*G[{yu}, yv^(-1)] + 
     (10*G[{1}, yw]*G[{yu^(-1)}, yw]^3*G[{yu}, yv^(-1)])/3 + 
     (G[{yu^(-1)}, yw]^4*G[{yu}, yv^(-1)])/2 + 
     (2*Pi^2*G[{1}, yv^(-1)]*G[{yu}, yv^(-1)]^2)/3 - 
     G[{1}, yu^(-1)]^2*G[{1}, yv^(-1)]*G[{yu}, yv^(-1)]^2 + 
     2*G[{1}, yu^(-1)]*G[{1}, yv^(-1)]^2*G[{yu}, yv^(-1)]^2 - 
     (2*Pi^2*G[{yu^(-1)}, yw]*G[{yu}, yv^(-1)]^2)/3 + 
     G[{1}, yu^(-1)]^2*G[{yu^(-1)}, yw]*G[{yu}, yv^(-1)]^2 - 
     2*G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*G[{yu^(-1)}, yw]*G[{yu}, yv^(-1)]^2 + 
     G[{1}, yv^(-1)]*G[{1}, yw]*G[{yu^(-1)}, yw]*G[{yu}, yv^(-1)]^2 + 
     G[{1}, yv^(-1)]*G[{yu^(-1)}, yw]^2*G[{yu}, yv^(-1)]^2 - 
     (3*G[{1}, yw]*G[{yu^(-1)}, yw]^2*G[{yu}, yv^(-1)]^2)/2 - 
     (G[{yu^(-1)}, yw]^3*G[{yu}, yv^(-1)]^2)/3 - (2*Pi^2*G[{yu}, yv^(-1)]^3)/
      9 + (G[{1}, yu^(-1)]^2*G[{yu}, yv^(-1)]^3)/3 - 
     (2*G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*G[{yu}, yv^(-1)]^3)/3 + 
     (2*G[{1}, yv^(-1)]*G[{yu^(-1)}, yw]*G[{yu}, yv^(-1)]^3)/3 - 
     (G[{1}, yw]*G[{yu^(-1)}, yw]*G[{yu}, yv^(-1)]^3)/3 - 
     (G[{yu^(-1)}, yw]^2*G[{yu}, yv^(-1)]^3)/3 + 
     (G[{1}, yv^(-1)]*G[{yu}, yv^(-1)]^4)/6 - 
     (G[{yu^(-1)}, yw]*G[{yu}, yv^(-1)]^4)/6 - G[{yu}, yv^(-1)]^5/30 + 
     (Pi^2*G[{0}, yu^(-1)]*G[{1}, yu^(-1)]*G[{1/(yu*yv)}, yw])/3 + 
     (Pi^2*G[{0}, yv^(-1)]*G[{1}, yu^(-1)]*G[{1/(yu*yv)}, yw])/3 - 
     (Pi^2*G[{0}, yw]*G[{1}, yu^(-1)]*G[{1/(yu*yv)}, yw])/3 - 
     (Pi^2*G[{1}, yu^(-1)]^2*G[{1/(yu*yv)}, yw])/6 - 
     (Pi^2*G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*G[{1/(yu*yv)}, yw])/3 + 
     (Pi^2*G[{1}, yu^(-1)]*G[{1}, yw]*G[{1/(yu*yv)}, yw])/3 + 
     (Pi^2*G[{1}, yw]^2*G[{1/(yu*yv)}, yw])/6 - G[{0}, yu^(-1)]*
      G[{1}, yu^(-1)]*G[{1}, yw]^2*G[{1/(yu*yv)}, yw] - 
     G[{0}, yv^(-1)]*G[{1}, yu^(-1)]*G[{1}, yw]^2*G[{1/(yu*yv)}, yw] + 
     G[{0}, yw]*G[{1}, yu^(-1)]*G[{1}, yw]^2*G[{1/(yu*yv)}, yw] + 
     G[{1}, yu^(-1)]^2*G[{1}, yw]^2*G[{1/(yu*yv)}, yw] + 
     2*G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*G[{1}, yw]^2*G[{1/(yu*yv)}, yw] - 
     (2*G[{0}, yu^(-1)]*G[{1}, yw]^3*G[{1/(yu*yv)}, yw])/3 - 
     (2*G[{0}, yv^(-1)]*G[{1}, yw]^3*G[{1/(yu*yv)}, yw])/3 + 
     (2*G[{0}, yw]*G[{1}, yw]^3*G[{1/(yu*yv)}, yw])/3 + 
     (2*G[{1}, yu^(-1)]*G[{1}, yw]^3*G[{1/(yu*yv)}, yw])/3 + 
     (2*G[{1}, yv^(-1)]*G[{1}, yw]^3*G[{1/(yu*yv)}, yw])/3 - 
     (2*Pi^2*G[{1}, yv^(-1)]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw])/3 + 
     4*G[{0}, yu^(-1)]*G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*G[{yu^(-1)}, yw]*
      G[{1/(yu*yv)}, yw] + 4*G[{0}, yv^(-1)]*G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*
      G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw] - 4*G[{0}, yw]*G[{1}, yu^(-1)]*
      G[{1}, yv^(-1)]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw] - 
     2*G[{1}, yu^(-1)]^2*G[{1}, yv^(-1)]*G[{yu^(-1)}, yw]*
      G[{1/(yu*yv)}, yw] - 4*G[{1}, yu^(-1)]*G[{1}, yv^(-1)]^2*
      G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw] - 
     (2*Pi^2*G[{1}, yw]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw])/3 + 
     4*G[{0}, yu^(-1)]*G[{1}, yu^(-1)]*G[{1}, yw]*G[{yu^(-1)}, yw]*
      G[{1/(yu*yv)}, yw] + 4*G[{0}, yv^(-1)]*G[{1}, yu^(-1)]*G[{1}, yw]*
      G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw] - 4*G[{0}, yw]*G[{1}, yu^(-1)]*
      G[{1}, yw]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw] - 
     2*G[{1}, yu^(-1)]^2*G[{1}, yw]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw] + 
     4*G[{1}, yu^(-1)]*G[{1}, yw]^2*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw] + 
     2*G[{1}, yv^(-1)]*G[{1}, yw]^2*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw] + 
     2*G[{1}, yw]^3*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw] + 
     (Pi^2*G[{yu^(-1)}, yw]^2*G[{1/(yu*yv)}, yw])/3 - 
     2*G[{0}, yu^(-1)]*G[{1}, yu^(-1)]*G[{yu^(-1)}, yw]^2*
      G[{1/(yu*yv)}, yw] - 2*G[{0}, yv^(-1)]*G[{1}, yu^(-1)]*
      G[{yu^(-1)}, yw]^2*G[{1/(yu*yv)}, yw] + 2*G[{0}, yw]*G[{1}, yu^(-1)]*
      G[{yu^(-1)}, yw]^2*G[{1/(yu*yv)}, yw] + G[{1}, yu^(-1)]^2*
      G[{yu^(-1)}, yw]^2*G[{1/(yu*yv)}, yw] + 6*G[{0}, yu^(-1)]*
      G[{1}, yv^(-1)]*G[{yu^(-1)}, yw]^2*G[{1/(yu*yv)}, yw] + 
     6*G[{0}, yv^(-1)]*G[{1}, yv^(-1)]*G[{yu^(-1)}, yw]^2*
      G[{1/(yu*yv)}, yw] - 6*G[{0}, yw]*G[{1}, yv^(-1)]*G[{yu^(-1)}, yw]^2*
      G[{1/(yu*yv)}, yw] + 2*G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*
      G[{yu^(-1)}, yw]^2*G[{1/(yu*yv)}, yw] - 6*G[{1}, yv^(-1)]^2*
      G[{yu^(-1)}, yw]^2*G[{1/(yu*yv)}, yw] + 6*G[{0}, yu^(-1)]*G[{1}, yw]*
      G[{yu^(-1)}, yw]^2*G[{1/(yu*yv)}, yw] + 6*G[{0}, yv^(-1)]*G[{1}, yw]*
      G[{yu^(-1)}, yw]^2*G[{1/(yu*yv)}, yw] - 6*G[{0}, yw]*G[{1}, yw]*
      G[{yu^(-1)}, yw]^2*G[{1/(yu*yv)}, yw] - 2*G[{1}, yu^(-1)]*G[{1}, yw]*
      G[{yu^(-1)}, yw]^2*G[{1/(yu*yv)}, yw] + 5*G[{1}, yw]^2*
      G[{yu^(-1)}, yw]^2*G[{1/(yu*yv)}, yw] - 
     (8*G[{0}, yu^(-1)]*G[{yu^(-1)}, yw]^3*G[{1/(yu*yv)}, yw])/3 - 
     (8*G[{0}, yv^(-1)]*G[{yu^(-1)}, yw]^3*G[{1/(yu*yv)}, yw])/3 + 
     (8*G[{0}, yw]*G[{yu^(-1)}, yw]^3*G[{1/(yu*yv)}, yw])/3 + 
     (22*G[{1}, yv^(-1)]*G[{yu^(-1)}, yw]^3*G[{1/(yu*yv)}, yw])/3 + 
     2*G[{1}, yw]*G[{yu^(-1)}, yw]^3*G[{1/(yu*yv)}, yw] - 
     (11*G[{yu^(-1)}, yw]^4*G[{1/(yu*yv)}, yw])/6 - 
     (Pi^2*G[{0}, yu^(-1)]*G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw])/3 - 
     (Pi^2*G[{0}, yv^(-1)]*G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw])/3 + 
     (Pi^2*G[{0}, yw]*G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw])/3 - 
     (2*Pi^2*G[{1}, yv^(-1)]*G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw])/3 + 
     2*G[{1}, yu^(-1)]^2*G[{1}, yv^(-1)]*G[{yu}, yv^(-1)]*
      G[{1/(yu*yv)}, yw] - 2*G[{1}, yu^(-1)]*G[{1}, yv^(-1)]^2*
      G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw] - 
     (Pi^2*G[{1}, yw]*G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw])/3 + 
     G[{0}, yu^(-1)]*G[{1}, yw]^2*G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw] + 
     G[{0}, yv^(-1)]*G[{1}, yw]^2*G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw] - 
     G[{0}, yw]*G[{1}, yw]^2*G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw] - 
     2*G[{1}, yu^(-1)]*G[{1}, yw]^2*G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw] + 
     (2*Pi^2*G[{yu^(-1)}, yw]*G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw])/3 - 
     4*G[{0}, yu^(-1)]*G[{1}, yu^(-1)]*G[{yu^(-1)}, yw]*G[{yu}, yv^(-1)]*
      G[{1/(yu*yv)}, yw] - 4*G[{0}, yv^(-1)]*G[{1}, yu^(-1)]*G[{yu^(-1)}, yw]*
      G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw] + 4*G[{0}, yw]*G[{1}, yu^(-1)]*
      G[{yu^(-1)}, yw]*G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw] + 
     2*G[{1}, yu^(-1)]^2*G[{yu^(-1)}, yw]*G[{yu}, yv^(-1)]*
      G[{1/(yu*yv)}, yw] + 4*G[{0}, yu^(-1)]*G[{1}, yv^(-1)]*G[{yu^(-1)}, yw]*
      G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw] + 4*G[{0}, yv^(-1)]*G[{1}, yv^(-1)]*
      G[{yu^(-1)}, yw]*G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw] - 
     4*G[{0}, yw]*G[{1}, yv^(-1)]*G[{yu^(-1)}, yw]*G[{yu}, yv^(-1)]*
      G[{1/(yu*yv)}, yw] + 4*G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*G[{yu^(-1)}, yw]*
      G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw] - 4*G[{1}, yv^(-1)]^2*
      G[{yu^(-1)}, yw]*G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw] - 
     4*G[{0}, yu^(-1)]*G[{1}, yw]*G[{yu^(-1)}, yw]*G[{yu}, yv^(-1)]*
      G[{1/(yu*yv)}, yw] - 4*G[{0}, yv^(-1)]*G[{1}, yw]*G[{yu^(-1)}, yw]*
      G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw] + 4*G[{0}, yw]*G[{1}, yw]*
      G[{yu^(-1)}, yw]*G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw] - 
     4*G[{1}, yu^(-1)]*G[{1}, yw]*G[{yu^(-1)}, yw]*G[{yu}, yv^(-1)]*
      G[{1/(yu*yv)}, yw] + 6*G[{1}, yv^(-1)]*G[{1}, yw]*G[{yu^(-1)}, yw]*
      G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw] - 6*G[{1}, yw]^2*G[{yu^(-1)}, yw]*
      G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw] - 4*G[{0}, yu^(-1)]*
      G[{yu^(-1)}, yw]^2*G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw] - 
     4*G[{0}, yv^(-1)]*G[{yu^(-1)}, yw]^2*G[{yu}, yv^(-1)]*
      G[{1/(yu*yv)}, yw] + 4*G[{0}, yw]*G[{yu^(-1)}, yw]^2*G[{yu}, yv^(-1)]*
      G[{1/(yu*yv)}, yw] + 6*G[{1}, yv^(-1)]*G[{yu^(-1)}, yw]^2*
      G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw] - 10*G[{1}, yw]*G[{yu^(-1)}, yw]^2*
      G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw] - 2*G[{yu^(-1)}, yw]^3*
      G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw] + 
     (2*Pi^2*G[{yu}, yv^(-1)]^2*G[{1/(yu*yv)}, yw])/3 - 
     G[{1}, yu^(-1)]^2*G[{yu}, yv^(-1)]^2*G[{1/(yu*yv)}, yw] + 
     2*G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*G[{yu}, yv^(-1)]^2*
      G[{1/(yu*yv)}, yw] - G[{1}, yv^(-1)]*G[{1}, yw]*G[{yu}, yv^(-1)]^2*
      G[{1/(yu*yv)}, yw] - 2*G[{1}, yv^(-1)]*G[{yu^(-1)}, yw]*
      G[{yu}, yv^(-1)]^2*G[{1/(yu*yv)}, yw] + 3*G[{1}, yw]*G[{yu^(-1)}, yw]*
      G[{yu}, yv^(-1)]^2*G[{1/(yu*yv)}, yw] + G[{yu^(-1)}, yw]^2*
      G[{yu}, yv^(-1)]^2*G[{1/(yu*yv)}, yw] - 
     (2*G[{1}, yv^(-1)]*G[{yu}, yv^(-1)]^3*G[{1/(yu*yv)}, yw])/3 + 
     (G[{1}, yw]*G[{yu}, yv^(-1)]^3*G[{1/(yu*yv)}, yw])/3 + 
     (2*G[{yu^(-1)}, yw]*G[{yu}, yv^(-1)]^3*G[{1/(yu*yv)}, yw])/3 + 
     (G[{yu}, yv^(-1)]^4*G[{1/(yu*yv)}, yw])/6 + 
     (Pi^2*G[{1}, yu^(-1)]*G[{1/(yu*yv)}, yw]^2)/6 + 
     (Pi^2*G[{1}, yv^(-1)]*G[{1/(yu*yv)}, yw]^2)/3 - 
     2*G[{0}, yu^(-1)]*G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*G[{1/(yu*yv)}, yw]^2 - 
     2*G[{0}, yv^(-1)]*G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*G[{1/(yu*yv)}, yw]^2 + 
     2*G[{0}, yw]*G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*G[{1/(yu*yv)}, yw]^2 + 
     G[{1}, yu^(-1)]^2*G[{1}, yv^(-1)]*G[{1/(yu*yv)}, yw]^2 + 
     2*G[{1}, yu^(-1)]*G[{1}, yv^(-1)]^2*G[{1/(yu*yv)}, yw]^2 + 
     (Pi^2*G[{1}, yw]*G[{1/(yu*yv)}, yw]^2)/2 - 3*G[{0}, yu^(-1)]*
      G[{1}, yu^(-1)]*G[{1}, yw]*G[{1/(yu*yv)}, yw]^2 - 
     3*G[{0}, yv^(-1)]*G[{1}, yu^(-1)]*G[{1}, yw]*G[{1/(yu*yv)}, yw]^2 + 
     3*G[{0}, yw]*G[{1}, yu^(-1)]*G[{1}, yw]*G[{1/(yu*yv)}, yw]^2 + 
     2*G[{1}, yu^(-1)]^2*G[{1}, yw]*G[{1/(yu*yv)}, yw]^2 + 
     2*G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*G[{1}, yw]*G[{1/(yu*yv)}, yw]^2 - 
     G[{0}, yu^(-1)]*G[{1}, yw]^2*G[{1/(yu*yv)}, yw]^2 - 
     G[{0}, yv^(-1)]*G[{1}, yw]^2*G[{1/(yu*yv)}, yw]^2 + 
     G[{0}, yw]*G[{1}, yw]^2*G[{1/(yu*yv)}, yw]^2 - 
     G[{1}, yu^(-1)]*G[{1}, yw]^2*G[{1/(yu*yv)}, yw]^2 - 
     G[{1}, yw]^3*G[{1/(yu*yv)}, yw]^2 - 
     (Pi^2*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2)/3 + 
     3*G[{0}, yu^(-1)]*G[{1}, yu^(-1)]*G[{yu^(-1)}, yw]*
      G[{1/(yu*yv)}, yw]^2 + 3*G[{0}, yv^(-1)]*G[{1}, yu^(-1)]*
      G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2 - 3*G[{0}, yw]*G[{1}, yu^(-1)]*
      G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2 - 2*G[{1}, yu^(-1)]^2*
      G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2 - 6*G[{0}, yu^(-1)]*
      G[{1}, yv^(-1)]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2 - 
     6*G[{0}, yv^(-1)]*G[{1}, yv^(-1)]*G[{yu^(-1)}, yw]*
      G[{1/(yu*yv)}, yw]^2 + 6*G[{0}, yw]*G[{1}, yv^(-1)]*G[{yu^(-1)}, yw]*
      G[{1/(yu*yv)}, yw]^2 - 2*G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*
      G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2 + 6*G[{1}, yv^(-1)]^2*
      G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2 - 5*G[{0}, yu^(-1)]*G[{1}, yw]*
      G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2 - 5*G[{0}, yv^(-1)]*G[{1}, yw]*
      G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2 + 5*G[{0}, yw]*G[{1}, yw]*
      G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2 + 2*G[{1}, yu^(-1)]*G[{1}, yw]*
      G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2 - 4*G[{1}, yw]^2*G[{yu^(-1)}, yw]*
      G[{1/(yu*yv)}, yw]^2 + 4*G[{0}, yu^(-1)]*G[{yu^(-1)}, yw]^2*
      G[{1/(yu*yv)}, yw]^2 + 4*G[{0}, yv^(-1)]*G[{yu^(-1)}, yw]^2*
      G[{1/(yu*yv)}, yw]^2 - 4*G[{0}, yw]*G[{yu^(-1)}, yw]^2*
      G[{1/(yu*yv)}, yw]^2 - (19*G[{1}, yv^(-1)]*G[{yu^(-1)}, yw]^2*
       G[{1/(yu*yv)}, yw]^2)/2 - (3*G[{1}, yw]*G[{yu^(-1)}, yw]^2*
       G[{1/(yu*yv)}, yw]^2)/2 + (19*G[{yu^(-1)}, yw]^3*G[{1/(yu*yv)}, yw]^2)/
      6 - (Pi^2*G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw]^2)/2 + 
     2*G[{0}, yu^(-1)]*G[{1}, yu^(-1)]*G[{yu}, yv^(-1)]*
      G[{1/(yu*yv)}, yw]^2 + 2*G[{0}, yv^(-1)]*G[{1}, yu^(-1)]*
      G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw]^2 - 2*G[{0}, yw]*G[{1}, yu^(-1)]*
      G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw]^2 - G[{1}, yu^(-1)]^2*
      G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw]^2 - 2*G[{0}, yu^(-1)]*
      G[{1}, yv^(-1)]*G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw]^2 - 
     2*G[{0}, yv^(-1)]*G[{1}, yv^(-1)]*G[{yu}, yv^(-1)]*
      G[{1/(yu*yv)}, yw]^2 + 2*G[{0}, yw]*G[{1}, yv^(-1)]*G[{yu}, yv^(-1)]*
      G[{1/(yu*yv)}, yw]^2 - 2*G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*
      G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw]^2 + 2*G[{1}, yv^(-1)]^2*
      G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw]^2 + 3*G[{0}, yu^(-1)]*G[{1}, yw]*
      G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw]^2 + 3*G[{0}, yv^(-1)]*G[{1}, yw]*
      G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw]^2 - 3*G[{0}, yw]*G[{1}, yw]*
      G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw]^2 - 3*G[{1}, yv^(-1)]*G[{1}, yw]*
      G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw]^2 + 3*G[{1}, yw]^2*G[{yu}, yv^(-1)]*
      G[{1/(yu*yv)}, yw]^2 + 3*G[{0}, yu^(-1)]*G[{yu^(-1)}, yw]*
      G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw]^2 + 3*G[{0}, yv^(-1)]*
      G[{yu^(-1)}, yw]*G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw]^2 - 
     3*G[{0}, yw]*G[{yu^(-1)}, yw]*G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw]^2 - 
     3*G[{1}, yv^(-1)]*G[{yu^(-1)}, yw]*G[{yu}, yv^(-1)]*
      G[{1/(yu*yv)}, yw]^2 + 8*G[{1}, yw]*G[{yu^(-1)}, yw]*G[{yu}, yv^(-1)]*
      G[{1/(yu*yv)}, yw]^2 + (3*G[{yu^(-1)}, yw]^2*G[{yu}, yv^(-1)]*
       G[{1/(yu*yv)}, yw]^2)/2 + (3*G[{1}, yv^(-1)]*G[{yu}, yv^(-1)]^2*
       G[{1/(yu*yv)}, yw]^2)/2 - (3*G[{1}, yw]*G[{yu}, yv^(-1)]^2*
       G[{1/(yu*yv)}, yw]^2)/2 - (3*G[{yu^(-1)}, yw]*G[{yu}, yv^(-1)]^2*
       G[{1/(yu*yv)}, yw]^2)/2 - (G[{yu}, yv^(-1)]^3*G[{1/(yu*yv)}, yw]^2)/
      2 - (Pi^2*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2)/6 + 
     G[{0}, yu^(-1)]*G[{1}, yu^(-1)]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2 + 
     G[{0}, yv^(-1)]*G[{1}, yu^(-1)]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2 - 
     G[{0}, yw]*G[{1}, yu^(-1)]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2 - 
     G[{1}, yu^(-1)]^2*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2 - 
     2*G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*G[{yv^(-1)}, yw]*
      G[{1/(yu*yv)}, yw]^2 + 2*G[{0}, yu^(-1)]*G[{1}, yw]*G[{yv^(-1)}, yw]*
      G[{1/(yu*yv)}, yw]^2 + 2*G[{0}, yv^(-1)]*G[{1}, yw]*G[{yv^(-1)}, yw]*
      G[{1/(yu*yv)}, yw]^2 - 2*G[{0}, yw]*G[{1}, yw]*G[{yv^(-1)}, yw]*
      G[{1/(yu*yv)}, yw]^2 - 2*G[{1}, yu^(-1)]*G[{1}, yw]*G[{yv^(-1)}, yw]*
      G[{1/(yu*yv)}, yw]^2 - 2*G[{1}, yv^(-1)]*G[{1}, yw]*G[{yv^(-1)}, yw]*
      G[{1/(yu*yv)}, yw]^2 - G[{0}, yu^(-1)]*G[{yu^(-1)}, yw]*
      G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2 - G[{0}, yv^(-1)]*
      G[{yu^(-1)}, yw]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2 + 
     G[{0}, yw]*G[{yu^(-1)}, yw]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2 + 
     2*G[{1}, yu^(-1)]*G[{yu^(-1)}, yw]*G[{yv^(-1)}, yw]*
      G[{1/(yu*yv)}, yw]^2 - G[{0}, yu^(-1)]*G[{yu}, yv^(-1)]*
      G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2 - G[{0}, yv^(-1)]*
      G[{yu}, yv^(-1)]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2 + 
     G[{0}, yw]*G[{yu}, yv^(-1)]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2 + 
     2*G[{1}, yu^(-1)]*G[{yu}, yv^(-1)]*G[{yv^(-1)}, yw]*
      G[{1/(yu*yv)}, yw]^2 - G[{0}, yu^(-1)]*G[{yv^(-1)}, yw]^2*
      G[{1/(yu*yv)}, yw]^2 - G[{0}, yv^(-1)]*G[{yv^(-1)}, yw]^2*
      G[{1/(yu*yv)}, yw]^2 + G[{0}, yw]*G[{yv^(-1)}, yw]^2*
      G[{1/(yu*yv)}, yw]^2 + 2*G[{1}, yu^(-1)]*G[{yv^(-1)}, yw]^2*
      G[{1/(yu*yv)}, yw]^2 + G[{1}, yv^(-1)]*G[{yv^(-1)}, yw]^2*
      G[{1/(yu*yv)}, yw]^2 + G[{1}, yw]*G[{yv^(-1)}, yw]^2*
      G[{1/(yu*yv)}, yw]^2 - G[{yu^(-1)}, yw]*G[{yv^(-1)}, yw]^2*
      G[{1/(yu*yv)}, yw]^2 - G[{yu}, yv^(-1)]*G[{yv^(-1)}, yw]^2*
      G[{1/(yu*yv)}, yw]^2 - (2*G[{yv^(-1)}, yw]^3*G[{1/(yu*yv)}, yw]^2)/3 - 
     (G[{0}, yu^(-1)]*G[{1}, yu^(-1)]*G[{1/(yu*yv)}, yw]^3)/3 - 
     (G[{0}, yv^(-1)]*G[{1}, yu^(-1)]*G[{1/(yu*yv)}, yw]^3)/3 + 
     (G[{0}, yw]*G[{1}, yu^(-1)]*G[{1/(yu*yv)}, yw]^3)/3 + 
     (G[{1}, yu^(-1)]^2*G[{1/(yu*yv)}, yw]^3)/3 + 
     2*G[{0}, yu^(-1)]*G[{1}, yv^(-1)]*G[{1/(yu*yv)}, yw]^3 + 
     2*G[{0}, yv^(-1)]*G[{1}, yv^(-1)]*G[{1/(yu*yv)}, yw]^3 - 
     2*G[{0}, yw]*G[{1}, yv^(-1)]*G[{1/(yu*yv)}, yw]^3 - 
     (2*G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*G[{1/(yu*yv)}, yw]^3)/3 - 
     2*G[{1}, yv^(-1)]^2*G[{1/(yu*yv)}, yw]^3 + 
     (5*G[{0}, yu^(-1)]*G[{1}, yw]*G[{1/(yu*yv)}, yw]^3)/3 + 
     (5*G[{0}, yv^(-1)]*G[{1}, yw]*G[{1/(yu*yv)}, yw]^3)/3 - 
     (5*G[{0}, yw]*G[{1}, yw]*G[{1/(yu*yv)}, yw]^3)/3 - 
     (2*G[{1}, yu^(-1)]*G[{1}, yw]*G[{1/(yu*yv)}, yw]^3)/3 - 
     (2*G[{1}, yv^(-1)]*G[{1}, yw]*G[{1/(yu*yv)}, yw]^3)/3 + 
     G[{1}, yw]^2*G[{1/(yu*yv)}, yw]^3 - 2*G[{0}, yu^(-1)]*G[{yu^(-1)}, yw]*
      G[{1/(yu*yv)}, yw]^3 - 2*G[{0}, yv^(-1)]*G[{yu^(-1)}, yw]*
      G[{1/(yu*yv)}, yw]^3 + 2*G[{0}, yw]*G[{yu^(-1)}, yw]*
      G[{1/(yu*yv)}, yw]^3 + (2*G[{1}, yu^(-1)]*G[{yu^(-1)}, yw]*
       G[{1/(yu*yv)}, yw]^3)/3 + 4*G[{1}, yv^(-1)]*G[{yu^(-1)}, yw]*
      G[{1/(yu*yv)}, yw]^3 + (2*G[{1}, yw]*G[{yu^(-1)}, yw]*
       G[{1/(yu*yv)}, yw]^3)/3 - 2*G[{yu^(-1)}, yw]^2*G[{1/(yu*yv)}, yw]^3 - 
     (5*G[{0}, yu^(-1)]*G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw]^3)/3 - 
     (5*G[{0}, yv^(-1)]*G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw]^3)/3 + 
     (5*G[{0}, yw]*G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw]^3)/3 + 
     (2*G[{1}, yu^(-1)]*G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw]^3)/3 + 
     (2*G[{1}, yv^(-1)]*G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw]^3)/3 - 
     2*G[{1}, yw]*G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw]^3 - 
     (2*G[{yu^(-1)}, yw]*G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw]^3)/3 + 
     G[{yu}, yv^(-1)]^2*G[{1/(yu*yv)}, yw]^3 + 
     (G[{0}, yu^(-1)]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]^3)/3 + 
     (G[{0}, yv^(-1)]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]^3)/3 - 
     (G[{0}, yw]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]^3)/3 - 
     (2*G[{1}, yu^(-1)]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]^3)/3 + 
     (2*G[{1}, yv^(-1)]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]^3)/3 + 
     (2*G[{1}, yw]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]^3)/3 - 
     (2*G[{yu^(-1)}, yw]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]^3)/3 - 
     (2*G[{yu}, yv^(-1)]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]^3)/3 + 
     (G[{yv^(-1)}, yw]^2*G[{1/(yu*yv)}, yw]^3)/3 - 
     (Pi^2*G[{1}, yu^(-1)]*G[{0, 1}, yu^(-1)])/3 + 
     (G[{1}, yu^(-1)]^3*G[{0, 1}, yu^(-1)])/3 - 2*G[{0}, yu^(-1)]*
      G[{1}, yu^(-1)]*G[{yu^(-1)}, yw]*G[{0, 1}, yu^(-1)] - 
     2*G[{0}, yv^(-1)]*G[{1}, yu^(-1)]*G[{yu^(-1)}, yw]*G[{0, 1}, yu^(-1)] + 
     2*G[{0}, yw]*G[{1}, yu^(-1)]*G[{yu^(-1)}, yw]*G[{0, 1}, yu^(-1)] + 
     G[{1}, yu^(-1)]^2*G[{yu^(-1)}, yw]*G[{0, 1}, yu^(-1)] + 
     2*G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*G[{yu^(-1)}, yw]*G[{0, 1}, yu^(-1)] - 
     2*G[{1}, yu^(-1)]*G[{1}, yw]*G[{yu^(-1)}, yw]*G[{0, 1}, yu^(-1)] - 
     G[{1}, yw]^2*G[{yu^(-1)}, yw]*G[{0, 1}, yu^(-1)] + 
     (Pi^2*G[{yu}, yv^(-1)]*G[{0, 1}, yu^(-1)])/3 - 
     G[{1}, yu^(-1)]^2*G[{yu}, yv^(-1)]*G[{0, 1}, yu^(-1)] + 
     2*G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*G[{yu}, yv^(-1)]*G[{0, 1}, yu^(-1)] + 
     2*G[{0}, yu^(-1)]*G[{yu^(-1)}, yw]*G[{yu}, yv^(-1)]*G[{0, 1}, yu^(-1)] + 
     2*G[{0}, yv^(-1)]*G[{yu^(-1)}, yw]*G[{yu}, yv^(-1)]*G[{0, 1}, yu^(-1)] - 
     2*G[{0}, yw]*G[{yu^(-1)}, yw]*G[{yu}, yv^(-1)]*G[{0, 1}, yu^(-1)] + 
     2*G[{1}, yw]*G[{yu^(-1)}, yw]*G[{yu}, yv^(-1)]*G[{0, 1}, yu^(-1)] + 
     2*G[{1}, yv^(-1)]*G[{yu}, yv^(-1)]^2*G[{0, 1}, yu^(-1)] - 
     2*G[{yu^(-1)}, yw]*G[{yu}, yv^(-1)]^2*G[{0, 1}, yu^(-1)] - 
     (2*G[{yu}, yv^(-1)]^3*G[{0, 1}, yu^(-1)])/3 + 
     2*G[{0}, yu^(-1)]*G[{1}, yu^(-1)]*G[{1/(yu*yv)}, yw]*
      G[{0, 1}, yu^(-1)] + 2*G[{0}, yv^(-1)]*G[{1}, yu^(-1)]*
      G[{1/(yu*yv)}, yw]*G[{0, 1}, yu^(-1)] - 2*G[{0}, yw]*G[{1}, yu^(-1)]*
      G[{1/(yu*yv)}, yw]*G[{0, 1}, yu^(-1)] - G[{1}, yu^(-1)]^2*
      G[{1/(yu*yv)}, yw]*G[{0, 1}, yu^(-1)] - 2*G[{1}, yu^(-1)]*
      G[{1}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, 1}, yu^(-1)] + 
     2*G[{1}, yu^(-1)]*G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1}, yu^(-1)] + 
     G[{1}, yw]^2*G[{1/(yu*yv)}, yw]*G[{0, 1}, yu^(-1)] - 
     2*G[{0}, yu^(-1)]*G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw]*
      G[{0, 1}, yu^(-1)] - 2*G[{0}, yv^(-1)]*G[{yu}, yv^(-1)]*
      G[{1/(yu*yv)}, yw]*G[{0, 1}, yu^(-1)] + 2*G[{0}, yw]*G[{yu}, yv^(-1)]*
      G[{1/(yu*yv)}, yw]*G[{0, 1}, yu^(-1)] - 2*G[{1}, yw]*G[{yu}, yv^(-1)]*
      G[{1/(yu*yv)}, yw]*G[{0, 1}, yu^(-1)] + 2*G[{yu}, yv^(-1)]^2*
      G[{1/(yu*yv)}, yw]*G[{0, 1}, yu^(-1)] + G[{1}, yu^(-1)]*
      G[{1/(yu*yv)}, yw]^2*G[{0, 1}, yu^(-1)] + 
     G[{1}, yw]*G[{1/(yu*yv)}, yw]^2*G[{0, 1}, yu^(-1)] - 
     G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw]^2*G[{0, 1}, yu^(-1)] - 
     G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2*G[{0, 1}, yu^(-1)] - 
     G[{1}, yu^(-1)]*G[{0, 1}, yu^(-1)]^2 + G[{yu}, yv^(-1)]*
      G[{0, 1}, yu^(-1)]^2 - (Pi^2*G[{1}, yu^(-1)]*G[{0, 1}, yv^(-1)])/3 - 
     (2*Pi^2*G[{yu^(-1)}, yw]*G[{0, 1}, yv^(-1)])/3 + 
     2*G[{0}, yu^(-1)]*G[{1}, yu^(-1)]*G[{yu^(-1)}, yw]*G[{0, 1}, yv^(-1)] + 
     2*G[{0}, yv^(-1)]*G[{1}, yu^(-1)]*G[{yu^(-1)}, yw]*G[{0, 1}, yv^(-1)] - 
     2*G[{0}, yw]*G[{1}, yu^(-1)]*G[{yu^(-1)}, yw]*G[{0, 1}, yv^(-1)] - 
     2*G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*G[{yu^(-1)}, yw]*G[{0, 1}, yv^(-1)] + 
     2*G[{1}, yu^(-1)]*G[{1}, yw]*G[{yu^(-1)}, yw]*G[{0, 1}, yv^(-1)] + 
     G[{1}, yw]^2*G[{yu^(-1)}, yw]*G[{0, 1}, yv^(-1)] + 
     4*G[{0}, yu^(-1)]*G[{yu^(-1)}, yw]^2*G[{0, 1}, yv^(-1)] + 
     4*G[{0}, yv^(-1)]*G[{yu^(-1)}, yw]^2*G[{0, 1}, yv^(-1)] - 
     4*G[{0}, yw]*G[{yu^(-1)}, yw]^2*G[{0, 1}, yv^(-1)] - 
     5*G[{1}, yv^(-1)]*G[{yu^(-1)}, yw]^2*G[{0, 1}, yv^(-1)] + 
     3*G[{1}, yw]*G[{yu^(-1)}, yw]^2*G[{0, 1}, yv^(-1)] + 
     (8*G[{yu^(-1)}, yw]^3*G[{0, 1}, yv^(-1)])/3 - Pi^2*G[{yu}, yv^(-1)]*
      G[{0, 1}, yv^(-1)] + 2*G[{1}, yu^(-1)]^2*G[{yu}, yv^(-1)]*
      G[{0, 1}, yv^(-1)] - 2*G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*G[{yu}, yv^(-1)]*
      G[{0, 1}, yv^(-1)] + 2*G[{0}, yu^(-1)]*G[{yu^(-1)}, yw]*
      G[{yu}, yv^(-1)]*G[{0, 1}, yv^(-1)] + 2*G[{0}, yv^(-1)]*
      G[{yu^(-1)}, yw]*G[{yu}, yv^(-1)]*G[{0, 1}, yv^(-1)] - 
     2*G[{0}, yw]*G[{yu^(-1)}, yw]*G[{yu}, yv^(-1)]*G[{0, 1}, yv^(-1)] - 
     2*G[{1}, yv^(-1)]*G[{yu^(-1)}, yw]*G[{yu}, yv^(-1)]*G[{0, 1}, yv^(-1)] + 
     G[{1}, yv^(-1)]*G[{yu}, yv^(-1)]^2*G[{0, 1}, yv^(-1)] - 
     2*G[{yu^(-1)}, yw]*G[{yu}, yv^(-1)]^2*G[{0, 1}, yv^(-1)] - 
     (2*G[{yu}, yv^(-1)]^3*G[{0, 1}, yv^(-1)])/3 + 
     (2*Pi^2*G[{1/(yu*yv)}, yw]*G[{0, 1}, yv^(-1)])/3 - 
     2*G[{0}, yu^(-1)]*G[{1}, yu^(-1)]*G[{1/(yu*yv)}, yw]*
      G[{0, 1}, yv^(-1)] - 2*G[{0}, yv^(-1)]*G[{1}, yu^(-1)]*
      G[{1/(yu*yv)}, yw]*G[{0, 1}, yv^(-1)] + 2*G[{0}, yw]*G[{1}, yu^(-1)]*
      G[{1/(yu*yv)}, yw]*G[{0, 1}, yv^(-1)] + 2*G[{1}, yu^(-1)]*
      G[{1}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, 1}, yv^(-1)] - 
     2*G[{1}, yu^(-1)]*G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1}, yv^(-1)] - 
     G[{1}, yw]^2*G[{1/(yu*yv)}, yw]*G[{0, 1}, yv^(-1)] - 
     8*G[{0}, yu^(-1)]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*
      G[{0, 1}, yv^(-1)] - 8*G[{0}, yv^(-1)]*G[{yu^(-1)}, yw]*
      G[{1/(yu*yv)}, yw]*G[{0, 1}, yv^(-1)] + 8*G[{0}, yw]*G[{yu^(-1)}, yw]*
      G[{1/(yu*yv)}, yw]*G[{0, 1}, yv^(-1)] + 10*G[{1}, yv^(-1)]*
      G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1}, yv^(-1)] - 
     6*G[{1}, yw]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1}, yv^(-1)] - 
     8*G[{yu^(-1)}, yw]^2*G[{1/(yu*yv)}, yw]*G[{0, 1}, yv^(-1)] - 
     2*G[{0}, yu^(-1)]*G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw]*
      G[{0, 1}, yv^(-1)] - 2*G[{0}, yv^(-1)]*G[{yu}, yv^(-1)]*
      G[{1/(yu*yv)}, yw]*G[{0, 1}, yv^(-1)] + 2*G[{0}, yw]*G[{yu}, yv^(-1)]*
      G[{1/(yu*yv)}, yw]*G[{0, 1}, yv^(-1)] + 2*G[{1}, yv^(-1)]*
      G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, 1}, yv^(-1)] + 
     2*G[{yu}, yv^(-1)]^2*G[{1/(yu*yv)}, yw]*G[{0, 1}, yv^(-1)] + 
     4*G[{0}, yu^(-1)]*G[{1/(yu*yv)}, yw]^2*G[{0, 1}, yv^(-1)] + 
     4*G[{0}, yv^(-1)]*G[{1/(yu*yv)}, yw]^2*G[{0, 1}, yv^(-1)] - 
     4*G[{0}, yw]*G[{1/(yu*yv)}, yw]^2*G[{0, 1}, yv^(-1)] - 
     G[{1}, yu^(-1)]*G[{1/(yu*yv)}, yw]^2*G[{0, 1}, yv^(-1)] - 
     5*G[{1}, yv^(-1)]*G[{1/(yu*yv)}, yw]^2*G[{0, 1}, yv^(-1)] + 
     2*G[{1}, yw]*G[{1/(yu*yv)}, yw]^2*G[{0, 1}, yv^(-1)] + 
     5*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2*G[{0, 1}, yv^(-1)] - 
     2*G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw]^2*G[{0, 1}, yv^(-1)] + 
     G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2*G[{0, 1}, yv^(-1)] - 
     2*G[{1}, yu^(-1)]*G[{0, 1}, yu^(-1)]*G[{0, 1}, yv^(-1)] - 
     2*G[{yu}, yv^(-1)]*G[{0, 1}, yu^(-1)]*G[{0, 1}, yv^(-1)] + 
     G[{1}, yu^(-1)]*G[{0, 1}, yv^(-1)]^2 + G[{yu}, yv^(-1)]*
      G[{0, 1}, yv^(-1)]^2 + (Pi^2*G[{yu^(-1)}, yw]*G[{0, 1}, yw])/3 - 
     2*G[{0}, yu^(-1)]*G[{1}, yu^(-1)]*G[{yu^(-1)}, yw]*G[{0, 1}, yw] - 
     2*G[{0}, yv^(-1)]*G[{1}, yu^(-1)]*G[{yu^(-1)}, yw]*G[{0, 1}, yw] + 
     2*G[{0}, yw]*G[{1}, yu^(-1)]*G[{yu^(-1)}, yw]*G[{0, 1}, yw] + 
     2*G[{1}, yu^(-1)]^2*G[{yu^(-1)}, yw]*G[{0, 1}, yw] + 
     4*G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*G[{yu^(-1)}, yw]*G[{0, 1}, yw] + 
     2*G[{1}, yu^(-1)]*G[{1}, yw]*G[{yu^(-1)}, yw]*G[{0, 1}, yw] + 
     G[{1}, yw]^2*G[{yu^(-1)}, yw]*G[{0, 1}, yw] + 
     2*G[{1}, yv^(-1)]*G[{yu^(-1)}, yw]^2*G[{0, 1}, yw] + 
     2*G[{1}, yw]*G[{yu^(-1)}, yw]^2*G[{0, 1}, yw] - 
     (2*G[{yu^(-1)}, yw]^3*G[{0, 1}, yw])/3 + 2*G[{0}, yu^(-1)]*
      G[{yu^(-1)}, yw]*G[{yu}, yv^(-1)]*G[{0, 1}, yw] + 
     2*G[{0}, yv^(-1)]*G[{yu^(-1)}, yw]*G[{yu}, yv^(-1)]*G[{0, 1}, yw] - 
     2*G[{0}, yw]*G[{yu^(-1)}, yw]*G[{yu}, yv^(-1)]*G[{0, 1}, yw] - 
     4*G[{1}, yu^(-1)]*G[{yu^(-1)}, yw]*G[{yu}, yv^(-1)]*G[{0, 1}, yw] - 
     2*G[{1}, yw]*G[{yu^(-1)}, yw]*G[{yu}, yv^(-1)]*G[{0, 1}, yw] - 
     2*G[{yu^(-1)}, yw]^2*G[{yu}, yv^(-1)]*G[{0, 1}, yw] - 
     (Pi^2*G[{1/(yu*yv)}, yw]*G[{0, 1}, yw])/3 + 2*G[{0}, yu^(-1)]*
      G[{1}, yu^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, 1}, yw] + 
     2*G[{0}, yv^(-1)]*G[{1}, yu^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, 1}, yw] - 
     2*G[{0}, yw]*G[{1}, yu^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, 1}, yw] - 
     2*G[{1}, yu^(-1)]^2*G[{1/(yu*yv)}, yw]*G[{0, 1}, yw] - 
     4*G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, 1}, yw] - 
     2*G[{1}, yu^(-1)]*G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1}, yw] - 
     G[{1}, yw]^2*G[{1/(yu*yv)}, yw]*G[{0, 1}, yw] - 
     4*G[{1}, yv^(-1)]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1}, yw] - 
     4*G[{1}, yw]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1}, yw] + 
     2*G[{yu^(-1)}, yw]^2*G[{1/(yu*yv)}, yw]*G[{0, 1}, yw] - 
     2*G[{0}, yu^(-1)]*G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, 1}, yw] - 
     2*G[{0}, yv^(-1)]*G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, 1}, yw] + 
     2*G[{0}, yw]*G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, 1}, yw] + 
     4*G[{1}, yu^(-1)]*G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, 1}, yw] + 
     2*G[{1}, yw]*G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, 1}, yw] + 
     4*G[{yu^(-1)}, yw]*G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, 1}, yw] - 
     G[{1}, yu^(-1)]*G[{1/(yu*yv)}, yw]^2*G[{0, 1}, yw] + 
     2*G[{1}, yv^(-1)]*G[{1/(yu*yv)}, yw]^2*G[{0, 1}, yw] + 
     G[{1}, yw]*G[{1/(yu*yv)}, yw]^2*G[{0, 1}, yw] - 
     2*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2*G[{0, 1}, yw] - 
     G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw]^2*G[{0, 1}, yw] + 
     G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2*G[{0, 1}, yw] + 
     2*G[{yu^(-1)}, yw]*G[{0, 1}, yu^(-1)]*G[{0, 1}, yw] - 
     2*G[{1/(yu*yv)}, yw]*G[{0, 1}, yu^(-1)]*G[{0, 1}, yw] - 
     2*G[{yu^(-1)}, yw]*G[{0, 1}, yv^(-1)]*G[{0, 1}, yw] + 
     2*G[{1/(yu*yv)}, yw]*G[{0, 1}, yv^(-1)]*G[{0, 1}, yw] - 
     G[{yu^(-1)}, yw]*G[{0, 1}, yw]^2 + G[{1/(yu*yv)}, yw]*G[{0, 1}, yw]^2 - 
     (Pi^2*G[{1}, yu^(-1)]*G[{0, yu^(-1)}, yw])/3 + 
     2*G[{0}, yu^(-1)]*G[{1}, yu^(-1)]*G[{yu^(-1)}, yw]*G[{0, yu^(-1)}, yw] + 
     2*G[{0}, yv^(-1)]*G[{1}, yu^(-1)]*G[{yu^(-1)}, yw]*G[{0, yu^(-1)}, yw] - 
     2*G[{0}, yw]*G[{1}, yu^(-1)]*G[{yu^(-1)}, yw]*G[{0, yu^(-1)}, yw] - 
     2*G[{1}, yu^(-1)]^2*G[{yu^(-1)}, yw]*G[{0, yu^(-1)}, yw] - 
     4*G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*G[{yu^(-1)}, yw]*G[{0, yu^(-1)}, yw] - 
     2*G[{1}, yu^(-1)]*G[{1}, yw]*G[{yu^(-1)}, yw]*G[{0, yu^(-1)}, yw] - 
     G[{1}, yw]^2*G[{yu^(-1)}, yw]*G[{0, yu^(-1)}, yw] - 
     2*G[{1}, yv^(-1)]*G[{yu^(-1)}, yw]^2*G[{0, yu^(-1)}, yw] - 
     2*G[{1}, yw]*G[{yu^(-1)}, yw]^2*G[{0, yu^(-1)}, yw] + 
     (2*G[{yu^(-1)}, yw]^3*G[{0, yu^(-1)}, yw])/3 + 
     (Pi^2*G[{yu}, yv^(-1)]*G[{0, yu^(-1)}, yw])/3 - 
     2*G[{0}, yu^(-1)]*G[{yu^(-1)}, yw]*G[{yu}, yv^(-1)]*
      G[{0, yu^(-1)}, yw] - 2*G[{0}, yv^(-1)]*G[{yu^(-1)}, yw]*
      G[{yu}, yv^(-1)]*G[{0, yu^(-1)}, yw] + 2*G[{0}, yw]*G[{yu^(-1)}, yw]*
      G[{yu}, yv^(-1)]*G[{0, yu^(-1)}, yw] + 4*G[{1}, yu^(-1)]*
      G[{yu^(-1)}, yw]*G[{yu}, yv^(-1)]*G[{0, yu^(-1)}, yw] + 
     2*G[{1}, yw]*G[{yu^(-1)}, yw]*G[{yu}, yv^(-1)]*G[{0, yu^(-1)}, yw] + 
     2*G[{yu^(-1)}, yw]^2*G[{yu}, yv^(-1)]*G[{0, yu^(-1)}, yw] - 
     2*G[{0}, yu^(-1)]*G[{1}, yu^(-1)]*G[{1/(yu*yv)}, yw]*
      G[{0, yu^(-1)}, yw] - 2*G[{0}, yv^(-1)]*G[{1}, yu^(-1)]*
      G[{1/(yu*yv)}, yw]*G[{0, yu^(-1)}, yw] + 2*G[{0}, yw]*G[{1}, yu^(-1)]*
      G[{1/(yu*yv)}, yw]*G[{0, yu^(-1)}, yw] + 2*G[{1}, yu^(-1)]^2*
      G[{1/(yu*yv)}, yw]*G[{0, yu^(-1)}, yw] + 4*G[{1}, yu^(-1)]*
      G[{1}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1)}, yw] + 
     2*G[{1}, yu^(-1)]*G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1)}, yw] + 
     G[{1}, yw]^2*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1)}, yw] + 
     4*G[{1}, yv^(-1)]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*
      G[{0, yu^(-1)}, yw] + 4*G[{1}, yw]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*
      G[{0, yu^(-1)}, yw] - 2*G[{yu^(-1)}, yw]^2*G[{1/(yu*yv)}, yw]*
      G[{0, yu^(-1)}, yw] + 2*G[{0}, yu^(-1)]*G[{yu}, yv^(-1)]*
      G[{1/(yu*yv)}, yw]*G[{0, yu^(-1)}, yw] + 2*G[{0}, yv^(-1)]*
      G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1)}, yw] - 
     2*G[{0}, yw]*G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1)}, yw] - 
     4*G[{1}, yu^(-1)]*G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw]*
      G[{0, yu^(-1)}, yw] - 2*G[{1}, yw]*G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw]*
      G[{0, yu^(-1)}, yw] - 4*G[{yu^(-1)}, yw]*G[{yu}, yv^(-1)]*
      G[{1/(yu*yv)}, yw]*G[{0, yu^(-1)}, yw] + G[{1}, yu^(-1)]*
      G[{1/(yu*yv)}, yw]^2*G[{0, yu^(-1)}, yw] - 2*G[{1}, yv^(-1)]*
      G[{1/(yu*yv)}, yw]^2*G[{0, yu^(-1)}, yw] - 
     G[{1}, yw]*G[{1/(yu*yv)}, yw]^2*G[{0, yu^(-1)}, yw] + 
     2*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2*G[{0, yu^(-1)}, yw] + 
     G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw]^2*G[{0, yu^(-1)}, yw] - 
     G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2*G[{0, yu^(-1)}, yw] - 
     2*G[{1}, yu^(-1)]*G[{0, 1}, yu^(-1)]*G[{0, yu^(-1)}, yw] + 
     2*G[{yu}, yv^(-1)]*G[{0, 1}, yu^(-1)]*G[{0, yu^(-1)}, yw] + 
     2*G[{1}, yu^(-1)]*G[{0, 1}, yv^(-1)]*G[{0, yu^(-1)}, yw] + 
     4*G[{yu^(-1)}, yw]*G[{0, 1}, yv^(-1)]*G[{0, yu^(-1)}, yw] + 
     2*G[{yu}, yv^(-1)]*G[{0, 1}, yv^(-1)]*G[{0, yu^(-1)}, yw] - 
     4*G[{1/(yu*yv)}, yw]*G[{0, 1}, yv^(-1)]*G[{0, yu^(-1)}, yw] + 
     2*G[{1}, yu^(-1)]*G[{0, 1}, yw]*G[{0, yu^(-1)}, yw] - 
     2*G[{yu}, yv^(-1)]*G[{0, 1}, yw]*G[{0, yu^(-1)}, yw] - 
     G[{1}, yu^(-1)]*G[{0, yu^(-1)}, yw]^2 + G[{yu}, yv^(-1)]*
      G[{0, yu^(-1)}, yw]^2 + Pi^2*G[{yu^(-1)}, yw]*G[{0, yu}, yv^(-1)] - 
     2*G[{0}, yu^(-1)]*G[{1}, yu^(-1)]*G[{yu^(-1)}, yw]*G[{0, yu}, yv^(-1)] - 
     2*G[{0}, yv^(-1)]*G[{1}, yu^(-1)]*G[{yu^(-1)}, yw]*G[{0, yu}, yv^(-1)] + 
     2*G[{0}, yw]*G[{1}, yu^(-1)]*G[{yu^(-1)}, yw]*G[{0, yu}, yv^(-1)] + 
     2*G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*G[{yu^(-1)}, yw]*G[{0, yu}, yv^(-1)] - 
     2*G[{1}, yu^(-1)]*G[{1}, yw]*G[{yu^(-1)}, yw]*G[{0, yu}, yv^(-1)] - 
     G[{1}, yw]^2*G[{yu^(-1)}, yw]*G[{0, yu}, yv^(-1)] - 
     4*G[{0}, yu^(-1)]*G[{yu^(-1)}, yw]^2*G[{0, yu}, yv^(-1)] - 
     4*G[{0}, yv^(-1)]*G[{yu^(-1)}, yw]^2*G[{0, yu}, yv^(-1)] + 
     4*G[{0}, yw]*G[{yu^(-1)}, yw]^2*G[{0, yu}, yv^(-1)] + 
     5*G[{1}, yv^(-1)]*G[{yu^(-1)}, yw]^2*G[{0, yu}, yv^(-1)] - 
     3*G[{1}, yw]*G[{yu^(-1)}, yw]^2*G[{0, yu}, yv^(-1)] - 
     (8*G[{yu^(-1)}, yw]^3*G[{0, yu}, yv^(-1)])/3 + 
     (4*Pi^2*G[{yu}, yv^(-1)]*G[{0, yu}, yv^(-1)])/3 - 
     2*G[{1}, yu^(-1)]^2*G[{yu}, yv^(-1)]*G[{0, yu}, yv^(-1)] + 
     2*G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*G[{yu}, yv^(-1)]*G[{0, yu}, yv^(-1)] - 
     2*G[{0}, yu^(-1)]*G[{yu^(-1)}, yw]*G[{yu}, yv^(-1)]*
      G[{0, yu}, yv^(-1)] - 2*G[{0}, yv^(-1)]*G[{yu^(-1)}, yw]*
      G[{yu}, yv^(-1)]*G[{0, yu}, yv^(-1)] + 2*G[{0}, yw]*G[{yu^(-1)}, yw]*
      G[{yu}, yv^(-1)]*G[{0, yu}, yv^(-1)] + 2*G[{1}, yv^(-1)]*
      G[{yu^(-1)}, yw]*G[{yu}, yv^(-1)]*G[{0, yu}, yv^(-1)] - 
     G[{1}, yv^(-1)]*G[{yu}, yv^(-1)]^2*G[{0, yu}, yv^(-1)] + 
     2*G[{yu^(-1)}, yw]*G[{yu}, yv^(-1)]^2*G[{0, yu}, yv^(-1)] + 
     (2*G[{yu}, yv^(-1)]^3*G[{0, yu}, yv^(-1)])/3 - 
     Pi^2*G[{1/(yu*yv)}, yw]*G[{0, yu}, yv^(-1)] + 
     2*G[{0}, yu^(-1)]*G[{1}, yu^(-1)]*G[{1/(yu*yv)}, yw]*
      G[{0, yu}, yv^(-1)] + 2*G[{0}, yv^(-1)]*G[{1}, yu^(-1)]*
      G[{1/(yu*yv)}, yw]*G[{0, yu}, yv^(-1)] - 2*G[{0}, yw]*G[{1}, yu^(-1)]*
      G[{1/(yu*yv)}, yw]*G[{0, yu}, yv^(-1)] - 2*G[{1}, yu^(-1)]*
      G[{1}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, yu}, yv^(-1)] + 
     2*G[{1}, yu^(-1)]*G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{0, yu}, yv^(-1)] + 
     G[{1}, yw]^2*G[{1/(yu*yv)}, yw]*G[{0, yu}, yv^(-1)] + 
     8*G[{0}, yu^(-1)]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*
      G[{0, yu}, yv^(-1)] + 8*G[{0}, yv^(-1)]*G[{yu^(-1)}, yw]*
      G[{1/(yu*yv)}, yw]*G[{0, yu}, yv^(-1)] - 8*G[{0}, yw]*G[{yu^(-1)}, yw]*
      G[{1/(yu*yv)}, yw]*G[{0, yu}, yv^(-1)] - 10*G[{1}, yv^(-1)]*
      G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{0, yu}, yv^(-1)] + 
     6*G[{1}, yw]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{0, yu}, yv^(-1)] + 
     8*G[{yu^(-1)}, yw]^2*G[{1/(yu*yv)}, yw]*G[{0, yu}, yv^(-1)] + 
     2*G[{0}, yu^(-1)]*G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw]*
      G[{0, yu}, yv^(-1)] + 2*G[{0}, yv^(-1)]*G[{yu}, yv^(-1)]*
      G[{1/(yu*yv)}, yw]*G[{0, yu}, yv^(-1)] - 2*G[{0}, yw]*G[{yu}, yv^(-1)]*
      G[{1/(yu*yv)}, yw]*G[{0, yu}, yv^(-1)] - 2*G[{1}, yv^(-1)]*
      G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, yu}, yv^(-1)] - 
     2*G[{yu}, yv^(-1)]^2*G[{1/(yu*yv)}, yw]*G[{0, yu}, yv^(-1)] - 
     4*G[{0}, yu^(-1)]*G[{1/(yu*yv)}, yw]^2*G[{0, yu}, yv^(-1)] - 
     4*G[{0}, yv^(-1)]*G[{1/(yu*yv)}, yw]^2*G[{0, yu}, yv^(-1)] + 
     4*G[{0}, yw]*G[{1/(yu*yv)}, yw]^2*G[{0, yu}, yv^(-1)] + 
     G[{1}, yu^(-1)]*G[{1/(yu*yv)}, yw]^2*G[{0, yu}, yv^(-1)] + 
     5*G[{1}, yv^(-1)]*G[{1/(yu*yv)}, yw]^2*G[{0, yu}, yv^(-1)] - 
     2*G[{1}, yw]*G[{1/(yu*yv)}, yw]^2*G[{0, yu}, yv^(-1)] - 
     5*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2*G[{0, yu}, yv^(-1)] + 
     2*G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw]^2*G[{0, yu}, yv^(-1)] - 
     G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2*G[{0, yu}, yv^(-1)] + 
     2*G[{yu^(-1)}, yw]*G[{0, 1}, yu^(-1)]*G[{0, yu}, yv^(-1)] + 
     4*G[{yu}, yv^(-1)]*G[{0, 1}, yu^(-1)]*G[{0, yu}, yv^(-1)] - 
     2*G[{1/(yu*yv)}, yw]*G[{0, 1}, yu^(-1)]*G[{0, yu}, yv^(-1)] + 
     2*G[{yu^(-1)}, yw]*G[{0, 1}, yv^(-1)]*G[{0, yu}, yv^(-1)] - 
     2*G[{1/(yu*yv)}, yw]*G[{0, 1}, yv^(-1)]*G[{0, yu}, yv^(-1)] + 
     2*G[{yu^(-1)}, yw]*G[{0, 1}, yw]*G[{0, yu}, yv^(-1)] - 
     2*G[{1/(yu*yv)}, yw]*G[{0, 1}, yw]*G[{0, yu}, yv^(-1)] - 
     2*G[{1}, yu^(-1)]*G[{0, yu^(-1)}, yw]*G[{0, yu}, yv^(-1)] - 
     4*G[{yu^(-1)}, yw]*G[{0, yu^(-1)}, yw]*G[{0, yu}, yv^(-1)] - 
     2*G[{yu}, yv^(-1)]*G[{0, yu^(-1)}, yw]*G[{0, yu}, yv^(-1)] + 
     4*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1)}, yw]*G[{0, yu}, yv^(-1)] - 
     G[{yu^(-1)}, yw]*G[{0, yu}, yv^(-1)]^2 + G[{1/(yu*yv)}, yw]*
      G[{0, yu}, yv^(-1)]^2 - (Pi^2*G[{yu^(-1)}, yw]*G[{0, yv^(-1)}, yw])/3 + 
     2*G[{0}, yu^(-1)]*G[{1}, yu^(-1)]*G[{yu^(-1)}, yw]*G[{0, yv^(-1)}, yw] + 
     2*G[{0}, yv^(-1)]*G[{1}, yu^(-1)]*G[{yu^(-1)}, yw]*G[{0, yv^(-1)}, yw] - 
     2*G[{0}, yw]*G[{1}, yu^(-1)]*G[{yu^(-1)}, yw]*G[{0, yv^(-1)}, yw] - 
     2*G[{1}, yu^(-1)]^2*G[{yu^(-1)}, yw]*G[{0, yv^(-1)}, yw] - 
     4*G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*G[{yu^(-1)}, yw]*G[{0, yv^(-1)}, yw] - 
     2*G[{1}, yu^(-1)]*G[{1}, yw]*G[{yu^(-1)}, yw]*G[{0, yv^(-1)}, yw] - 
     G[{1}, yw]^2*G[{yu^(-1)}, yw]*G[{0, yv^(-1)}, yw] - 
     2*G[{1}, yv^(-1)]*G[{yu^(-1)}, yw]^2*G[{0, yv^(-1)}, yw] - 
     2*G[{1}, yw]*G[{yu^(-1)}, yw]^2*G[{0, yv^(-1)}, yw] + 
     (2*G[{yu^(-1)}, yw]^3*G[{0, yv^(-1)}, yw])/3 - 
     2*G[{0}, yu^(-1)]*G[{yu^(-1)}, yw]*G[{yu}, yv^(-1)]*
      G[{0, yv^(-1)}, yw] - 2*G[{0}, yv^(-1)]*G[{yu^(-1)}, yw]*
      G[{yu}, yv^(-1)]*G[{0, yv^(-1)}, yw] + 2*G[{0}, yw]*G[{yu^(-1)}, yw]*
      G[{yu}, yv^(-1)]*G[{0, yv^(-1)}, yw] + 4*G[{1}, yu^(-1)]*
      G[{yu^(-1)}, yw]*G[{yu}, yv^(-1)]*G[{0, yv^(-1)}, yw] + 
     2*G[{1}, yw]*G[{yu^(-1)}, yw]*G[{yu}, yv^(-1)]*G[{0, yv^(-1)}, yw] + 
     2*G[{yu^(-1)}, yw]^2*G[{yu}, yv^(-1)]*G[{0, yv^(-1)}, yw] + 
     (Pi^2*G[{1/(yu*yv)}, yw]*G[{0, yv^(-1)}, yw])/3 - 
     2*G[{0}, yu^(-1)]*G[{1}, yu^(-1)]*G[{1/(yu*yv)}, yw]*
      G[{0, yv^(-1)}, yw] - 2*G[{0}, yv^(-1)]*G[{1}, yu^(-1)]*
      G[{1/(yu*yv)}, yw]*G[{0, yv^(-1)}, yw] + 2*G[{0}, yw]*G[{1}, yu^(-1)]*
      G[{1/(yu*yv)}, yw]*G[{0, yv^(-1)}, yw] + 2*G[{1}, yu^(-1)]^2*
      G[{1/(yu*yv)}, yw]*G[{0, yv^(-1)}, yw] + 4*G[{1}, yu^(-1)]*
      G[{1}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, yv^(-1)}, yw] + 
     2*G[{1}, yu^(-1)]*G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{0, yv^(-1)}, yw] + 
     G[{1}, yw]^2*G[{1/(yu*yv)}, yw]*G[{0, yv^(-1)}, yw] + 
     4*G[{1}, yv^(-1)]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*
      G[{0, yv^(-1)}, yw] + 4*G[{1}, yw]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*
      G[{0, yv^(-1)}, yw] - 2*G[{yu^(-1)}, yw]^2*G[{1/(yu*yv)}, yw]*
      G[{0, yv^(-1)}, yw] + 2*G[{0}, yu^(-1)]*G[{yu}, yv^(-1)]*
      G[{1/(yu*yv)}, yw]*G[{0, yv^(-1)}, yw] + 2*G[{0}, yv^(-1)]*
      G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, yv^(-1)}, yw] - 
     2*G[{0}, yw]*G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, yv^(-1)}, yw] - 
     4*G[{1}, yu^(-1)]*G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw]*
      G[{0, yv^(-1)}, yw] - 2*G[{1}, yw]*G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw]*
      G[{0, yv^(-1)}, yw] - 4*G[{yu^(-1)}, yw]*G[{yu}, yv^(-1)]*
      G[{1/(yu*yv)}, yw]*G[{0, yv^(-1)}, yw] + G[{1}, yu^(-1)]*
      G[{1/(yu*yv)}, yw]^2*G[{0, yv^(-1)}, yw] - 2*G[{1}, yv^(-1)]*
      G[{1/(yu*yv)}, yw]^2*G[{0, yv^(-1)}, yw] - 
     G[{1}, yw]*G[{1/(yu*yv)}, yw]^2*G[{0, yv^(-1)}, yw] + 
     2*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2*G[{0, yv^(-1)}, yw] + 
     G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw]^2*G[{0, yv^(-1)}, yw] - 
     G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2*G[{0, yv^(-1)}, yw] - 
     2*G[{yu^(-1)}, yw]*G[{0, 1}, yu^(-1)]*G[{0, yv^(-1)}, yw] + 
     2*G[{1/(yu*yv)}, yw]*G[{0, 1}, yu^(-1)]*G[{0, yv^(-1)}, yw] + 
     2*G[{yu^(-1)}, yw]*G[{0, 1}, yv^(-1)]*G[{0, yv^(-1)}, yw] - 
     2*G[{1/(yu*yv)}, yw]*G[{0, 1}, yv^(-1)]*G[{0, yv^(-1)}, yw] + 
     2*G[{yu^(-1)}, yw]*G[{0, 1}, yw]*G[{0, yv^(-1)}, yw] - 
     2*G[{1/(yu*yv)}, yw]*G[{0, 1}, yw]*G[{0, yv^(-1)}, yw] - 
     2*G[{yu^(-1)}, yw]*G[{0, yu^(-1)}, yw]*G[{0, yv^(-1)}, yw] + 
     2*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1)}, yw]*G[{0, yv^(-1)}, yw] - 
     2*G[{yu^(-1)}, yw]*G[{0, yu}, yv^(-1)]*G[{0, yv^(-1)}, yw] + 
     2*G[{1/(yu*yv)}, yw]*G[{0, yu}, yv^(-1)]*G[{0, yv^(-1)}, yw] - 
     G[{yu^(-1)}, yw]*G[{0, yv^(-1)}, yw]^2 + G[{1/(yu*yv)}, yw]*
      G[{0, yv^(-1)}, yw]^2 + (Pi^2*G[{1}, yu^(-1)]*G[{0, 1/(yu*yv)}, yw])/
      3 - 2*G[{0}, yu^(-1)]*G[{1}, yu^(-1)]*G[{yu^(-1)}, yw]*
      G[{0, 1/(yu*yv)}, yw] - 2*G[{0}, yv^(-1)]*G[{1}, yu^(-1)]*
      G[{yu^(-1)}, yw]*G[{0, 1/(yu*yv)}, yw] + 2*G[{0}, yw]*G[{1}, yu^(-1)]*
      G[{yu^(-1)}, yw]*G[{0, 1/(yu*yv)}, yw] + 2*G[{1}, yu^(-1)]^2*
      G[{yu^(-1)}, yw]*G[{0, 1/(yu*yv)}, yw] + 4*G[{1}, yu^(-1)]*
      G[{1}, yv^(-1)]*G[{yu^(-1)}, yw]*G[{0, 1/(yu*yv)}, yw] + 
     2*G[{1}, yu^(-1)]*G[{1}, yw]*G[{yu^(-1)}, yw]*G[{0, 1/(yu*yv)}, yw] + 
     G[{1}, yw]^2*G[{yu^(-1)}, yw]*G[{0, 1/(yu*yv)}, yw] + 
     2*G[{1}, yv^(-1)]*G[{yu^(-1)}, yw]^2*G[{0, 1/(yu*yv)}, yw] + 
     2*G[{1}, yw]*G[{yu^(-1)}, yw]^2*G[{0, 1/(yu*yv)}, yw] - 
     (2*G[{yu^(-1)}, yw]^3*G[{0, 1/(yu*yv)}, yw])/3 - 
     (Pi^2*G[{yu}, yv^(-1)]*G[{0, 1/(yu*yv)}, yw])/3 + 
     2*G[{0}, yu^(-1)]*G[{yu^(-1)}, yw]*G[{yu}, yv^(-1)]*
      G[{0, 1/(yu*yv)}, yw] + 2*G[{0}, yv^(-1)]*G[{yu^(-1)}, yw]*
      G[{yu}, yv^(-1)]*G[{0, 1/(yu*yv)}, yw] - 2*G[{0}, yw]*G[{yu^(-1)}, yw]*
      G[{yu}, yv^(-1)]*G[{0, 1/(yu*yv)}, yw] - 4*G[{1}, yu^(-1)]*
      G[{yu^(-1)}, yw]*G[{yu}, yv^(-1)]*G[{0, 1/(yu*yv)}, yw] - 
     2*G[{1}, yw]*G[{yu^(-1)}, yw]*G[{yu}, yv^(-1)]*G[{0, 1/(yu*yv)}, yw] - 
     2*G[{yu^(-1)}, yw]^2*G[{yu}, yv^(-1)]*G[{0, 1/(yu*yv)}, yw] + 
     2*G[{0}, yu^(-1)]*G[{1}, yu^(-1)]*G[{1/(yu*yv)}, yw]*
      G[{0, 1/(yu*yv)}, yw] + 2*G[{0}, yv^(-1)]*G[{1}, yu^(-1)]*
      G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv)}, yw] - 2*G[{0}, yw]*G[{1}, yu^(-1)]*
      G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv)}, yw] - 2*G[{1}, yu^(-1)]^2*
      G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv)}, yw] - 4*G[{1}, yu^(-1)]*
      G[{1}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv)}, yw] - 
     2*G[{1}, yu^(-1)]*G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv)}, yw] - 
     G[{1}, yw]^2*G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv)}, yw] - 
     4*G[{1}, yv^(-1)]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*
      G[{0, 1/(yu*yv)}, yw] - 4*G[{1}, yw]*G[{yu^(-1)}, yw]*
      G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv)}, yw] + 2*G[{yu^(-1)}, yw]^2*
      G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv)}, yw] - 2*G[{0}, yu^(-1)]*
      G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv)}, yw] - 
     2*G[{0}, yv^(-1)]*G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw]*
      G[{0, 1/(yu*yv)}, yw] + 2*G[{0}, yw]*G[{yu}, yv^(-1)]*
      G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv)}, yw] + 4*G[{1}, yu^(-1)]*
      G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv)}, yw] + 
     2*G[{1}, yw]*G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv)}, yw] + 
     4*G[{yu^(-1)}, yw]*G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw]*
      G[{0, 1/(yu*yv)}, yw] - G[{1}, yu^(-1)]*G[{1/(yu*yv)}, yw]^2*
      G[{0, 1/(yu*yv)}, yw] + 2*G[{1}, yv^(-1)]*G[{1/(yu*yv)}, yw]^2*
      G[{0, 1/(yu*yv)}, yw] + G[{1}, yw]*G[{1/(yu*yv)}, yw]^2*
      G[{0, 1/(yu*yv)}, yw] - 2*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2*
      G[{0, 1/(yu*yv)}, yw] - G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw]^2*
      G[{0, 1/(yu*yv)}, yw] + G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2*
      G[{0, 1/(yu*yv)}, yw] + 2*G[{1}, yu^(-1)]*G[{0, 1}, yu^(-1)]*
      G[{0, 1/(yu*yv)}, yw] - 2*G[{yu}, yv^(-1)]*G[{0, 1}, yu^(-1)]*
      G[{0, 1/(yu*yv)}, yw] - 2*G[{1}, yu^(-1)]*G[{0, 1}, yv^(-1)]*
      G[{0, 1/(yu*yv)}, yw] - 4*G[{yu^(-1)}, yw]*G[{0, 1}, yv^(-1)]*
      G[{0, 1/(yu*yv)}, yw] - 2*G[{yu}, yv^(-1)]*G[{0, 1}, yv^(-1)]*
      G[{0, 1/(yu*yv)}, yw] + 4*G[{1/(yu*yv)}, yw]*G[{0, 1}, yv^(-1)]*
      G[{0, 1/(yu*yv)}, yw] - 2*G[{1}, yu^(-1)]*G[{0, 1}, yw]*
      G[{0, 1/(yu*yv)}, yw] + 2*G[{yu}, yv^(-1)]*G[{0, 1}, yw]*
      G[{0, 1/(yu*yv)}, yw] + 2*G[{1}, yu^(-1)]*G[{0, yu^(-1)}, yw]*
      G[{0, 1/(yu*yv)}, yw] - 2*G[{yu}, yv^(-1)]*G[{0, yu^(-1)}, yw]*
      G[{0, 1/(yu*yv)}, yw] + 2*G[{1}, yu^(-1)]*G[{0, yu}, yv^(-1)]*
      G[{0, 1/(yu*yv)}, yw] + 4*G[{yu^(-1)}, yw]*G[{0, yu}, yv^(-1)]*
      G[{0, 1/(yu*yv)}, yw] + 2*G[{yu}, yv^(-1)]*G[{0, yu}, yv^(-1)]*
      G[{0, 1/(yu*yv)}, yw] - 4*G[{1/(yu*yv)}, yw]*G[{0, yu}, yv^(-1)]*
      G[{0, 1/(yu*yv)}, yw] + 2*G[{1}, yu^(-1)]*G[{0, yv^(-1)}, yw]*
      G[{0, 1/(yu*yv)}, yw] - 2*G[{yu}, yv^(-1)]*G[{0, yv^(-1)}, yw]*
      G[{0, 1/(yu*yv)}, yw] - G[{1}, yu^(-1)]*G[{0, 1/(yu*yv)}, yw]^2 + 
     G[{yu}, yv^(-1)]*G[{0, 1/(yu*yv)}, yw]^2 + 
     (Pi^2*G[{1}, yu^(-1)]*G[{1, yu^(-1)}, yw])/3 + 
     (Pi^2*G[{1}, yw]*G[{1, yu^(-1)}, yw])/3 - 2*G[{0}, yu^(-1)]*
      G[{1}, yu^(-1)]*G[{1}, yw]*G[{1, yu^(-1)}, yw] - 
     2*G[{0}, yv^(-1)]*G[{1}, yu^(-1)]*G[{1}, yw]*G[{1, yu^(-1)}, yw] + 
     2*G[{0}, yw]*G[{1}, yu^(-1)]*G[{1}, yw]*G[{1, yu^(-1)}, yw] + 
     2*G[{1}, yu^(-1)]^2*G[{1}, yw]*G[{1, yu^(-1)}, yw] + 
     4*G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*G[{1}, yw]*G[{1, yu^(-1)}, yw] - 
     2*G[{0}, yu^(-1)]*G[{1}, yw]^2*G[{1, yu^(-1)}, yw] - 
     2*G[{0}, yv^(-1)]*G[{1}, yw]^2*G[{1, yu^(-1)}, yw] + 
     2*G[{0}, yw]*G[{1}, yw]^2*G[{1, yu^(-1)}, yw] + 
     2*G[{1}, yu^(-1)]*G[{1}, yw]^2*G[{1, yu^(-1)}, yw] + 
     2*G[{1}, yv^(-1)]*G[{1}, yw]^2*G[{1, yu^(-1)}, yw] - 
     (2*Pi^2*G[{yu^(-1)}, yw]*G[{1, yu^(-1)}, yw])/3 + 
     2*G[{0}, yu^(-1)]*G[{1}, yu^(-1)]*G[{yu^(-1)}, yw]*G[{1, yu^(-1)}, yw] + 
     2*G[{0}, yv^(-1)]*G[{1}, yu^(-1)]*G[{yu^(-1)}, yw]*G[{1, yu^(-1)}, yw] - 
     2*G[{0}, yw]*G[{1}, yu^(-1)]*G[{yu^(-1)}, yw]*G[{1, yu^(-1)}, yw] - 
     2*G[{0}, yu^(-1)]*G[{1}, yw]*G[{yu^(-1)}, yw]*G[{1, yu^(-1)}, yw] - 
     2*G[{0}, yv^(-1)]*G[{1}, yw]*G[{yu^(-1)}, yw]*G[{1, yu^(-1)}, yw] + 
     2*G[{0}, yw]*G[{1}, yw]*G[{yu^(-1)}, yw]*G[{1, yu^(-1)}, yw] + 
     8*G[{1}, yu^(-1)]*G[{1}, yw]*G[{yu^(-1)}, yw]*G[{1, yu^(-1)}, yw] + 
     4*G[{1}, yv^(-1)]*G[{1}, yw]*G[{yu^(-1)}, yw]*G[{1, yu^(-1)}, yw] + 
     4*G[{1}, yw]^2*G[{yu^(-1)}, yw]*G[{1, yu^(-1)}, yw] + 
     4*G[{0}, yu^(-1)]*G[{yu^(-1)}, yw]^2*G[{1, yu^(-1)}, yw] + 
     4*G[{0}, yv^(-1)]*G[{yu^(-1)}, yw]^2*G[{1, yu^(-1)}, yw] - 
     4*G[{0}, yw]*G[{yu^(-1)}, yw]^2*G[{1, yu^(-1)}, yw] - 
     G[{1}, yv^(-1)]*G[{yu^(-1)}, yw]^2*G[{1, yu^(-1)}, yw] + 
     7*G[{1}, yw]*G[{yu^(-1)}, yw]^2*G[{1, yu^(-1)}, yw] + 
     2*G[{yu^(-1)}, yw]^3*G[{1, yu^(-1)}, yw] - 
     (Pi^2*G[{yu}, yv^(-1)]*G[{1, yu^(-1)}, yw])/3 + 
     2*G[{0}, yu^(-1)]*G[{1}, yw]*G[{yu}, yv^(-1)]*G[{1, yu^(-1)}, yw] + 
     2*G[{0}, yv^(-1)]*G[{1}, yw]*G[{yu}, yv^(-1)]*G[{1, yu^(-1)}, yw] - 
     2*G[{0}, yw]*G[{1}, yw]*G[{yu}, yv^(-1)]*G[{1, yu^(-1)}, yw] - 
     4*G[{1}, yu^(-1)]*G[{1}, yw]*G[{yu}, yv^(-1)]*G[{1, yu^(-1)}, yw] - 
     2*G[{0}, yu^(-1)]*G[{yu^(-1)}, yw]*G[{yu}, yv^(-1)]*
      G[{1, yu^(-1)}, yw] - 2*G[{0}, yv^(-1)]*G[{yu^(-1)}, yw]*
      G[{yu}, yv^(-1)]*G[{1, yu^(-1)}, yw] + 2*G[{0}, yw]*G[{yu^(-1)}, yw]*
      G[{yu}, yv^(-1)]*G[{1, yu^(-1)}, yw] - 4*G[{1}, yu^(-1)]*
      G[{yu^(-1)}, yw]*G[{yu}, yv^(-1)]*G[{1, yu^(-1)}, yw] + 
     4*G[{1}, yv^(-1)]*G[{yu^(-1)}, yw]*G[{yu}, yv^(-1)]*
      G[{1, yu^(-1)}, yw] - 8*G[{1}, yw]*G[{yu^(-1)}, yw]*G[{yu}, yv^(-1)]*
      G[{1, yu^(-1)}, yw] - 7*G[{yu^(-1)}, yw]^2*G[{yu}, yv^(-1)]*
      G[{1, yu^(-1)}, yw] - G[{1}, yv^(-1)]*G[{yu}, yv^(-1)]^2*
      G[{1, yu^(-1)}, yw] + 2*G[{yu^(-1)}, yw]*G[{yu}, yv^(-1)]^2*
      G[{1, yu^(-1)}, yw] + (G[{yu}, yv^(-1)]^3*G[{1, yu^(-1)}, yw])/3 + 
     (2*Pi^2*G[{1/(yu*yv)}, yw]*G[{1, yu^(-1)}, yw])/3 - 
     2*G[{0}, yu^(-1)]*G[{1}, yu^(-1)]*G[{1/(yu*yv)}, yw]*
      G[{1, yu^(-1)}, yw] - 2*G[{0}, yv^(-1)]*G[{1}, yu^(-1)]*
      G[{1/(yu*yv)}, yw]*G[{1, yu^(-1)}, yw] + 2*G[{0}, yw]*G[{1}, yu^(-1)]*
      G[{1/(yu*yv)}, yw]*G[{1, yu^(-1)}, yw] + 2*G[{0}, yu^(-1)]*G[{1}, yw]*
      G[{1/(yu*yv)}, yw]*G[{1, yu^(-1)}, yw] + 2*G[{0}, yv^(-1)]*G[{1}, yw]*
      G[{1/(yu*yv)}, yw]*G[{1, yu^(-1)}, yw] - 2*G[{0}, yw]*G[{1}, yw]*
      G[{1/(yu*yv)}, yw]*G[{1, yu^(-1)}, yw] - 8*G[{1}, yu^(-1)]*G[{1}, yw]*
      G[{1/(yu*yv)}, yw]*G[{1, yu^(-1)}, yw] - 4*G[{1}, yv^(-1)]*G[{1}, yw]*
      G[{1/(yu*yv)}, yw]*G[{1, yu^(-1)}, yw] - 4*G[{1}, yw]^2*
      G[{1/(yu*yv)}, yw]*G[{1, yu^(-1)}, yw] - 8*G[{0}, yu^(-1)]*
      G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{1, yu^(-1)}, yw] - 
     8*G[{0}, yv^(-1)]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*
      G[{1, yu^(-1)}, yw] + 8*G[{0}, yw]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*
      G[{1, yu^(-1)}, yw] + 2*G[{1}, yv^(-1)]*G[{yu^(-1)}, yw]*
      G[{1/(yu*yv)}, yw]*G[{1, yu^(-1)}, yw] - 14*G[{1}, yw]*G[{yu^(-1)}, yw]*
      G[{1/(yu*yv)}, yw]*G[{1, yu^(-1)}, yw] - 6*G[{yu^(-1)}, yw]^2*
      G[{1/(yu*yv)}, yw]*G[{1, yu^(-1)}, yw] + 2*G[{0}, yu^(-1)]*
      G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{1, yu^(-1)}, yw] + 
     2*G[{0}, yv^(-1)]*G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw]*
      G[{1, yu^(-1)}, yw] - 2*G[{0}, yw]*G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw]*
      G[{1, yu^(-1)}, yw] + 4*G[{1}, yu^(-1)]*G[{yu}, yv^(-1)]*
      G[{1/(yu*yv)}, yw]*G[{1, yu^(-1)}, yw] - 4*G[{1}, yv^(-1)]*
      G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{1, yu^(-1)}, yw] + 
     8*G[{1}, yw]*G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{1, yu^(-1)}, yw] + 
     14*G[{yu^(-1)}, yw]*G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw]*
      G[{1, yu^(-1)}, yw] - 2*G[{yu}, yv^(-1)]^2*G[{1/(yu*yv)}, yw]*
      G[{1, yu^(-1)}, yw] + 4*G[{0}, yu^(-1)]*G[{1/(yu*yv)}, yw]^2*
      G[{1, yu^(-1)}, yw] + 4*G[{0}, yv^(-1)]*G[{1/(yu*yv)}, yw]^2*
      G[{1, yu^(-1)}, yw] - 4*G[{0}, yw]*G[{1/(yu*yv)}, yw]^2*
      G[{1, yu^(-1)}, yw] - 2*G[{1}, yu^(-1)]*G[{1/(yu*yv)}, yw]^2*
      G[{1, yu^(-1)}, yw] - G[{1}, yv^(-1)]*G[{1/(yu*yv)}, yw]^2*
      G[{1, yu^(-1)}, yw] + 5*G[{1}, yw]*G[{1/(yu*yv)}, yw]^2*
      G[{1, yu^(-1)}, yw] + 3*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2*
      G[{1, yu^(-1)}, yw] - 5*G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw]^2*
      G[{1, yu^(-1)}, yw] + 2*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2*
      G[{1, yu^(-1)}, yw] + 2*G[{1}, yu^(-1)]*G[{0, 1}, yu^(-1)]*
      G[{1, yu^(-1)}, yw] + 2*G[{1}, yw]*G[{0, 1}, yu^(-1)]*
      G[{1, yu^(-1)}, yw] - 2*G[{yu}, yv^(-1)]*G[{0, 1}, yu^(-1)]*
      G[{1, yu^(-1)}, yw] - 2*G[{1}, yu^(-1)]*G[{0, 1}, yv^(-1)]*
      G[{1, yu^(-1)}, yw] - 2*G[{1}, yw]*G[{0, 1}, yv^(-1)]*
      G[{1, yu^(-1)}, yw] - 4*G[{yu^(-1)}, yw]*G[{0, 1}, yv^(-1)]*
      G[{1, yu^(-1)}, yw] + 4*G[{1/(yu*yv)}, yw]*G[{0, 1}, yv^(-1)]*
      G[{1, yu^(-1)}, yw] - 2*G[{1}, yu^(-1)]*G[{0, 1}, yw]*
      G[{1, yu^(-1)}, yw] - 2*G[{1}, yw]*G[{0, 1}, yw]*G[{1, yu^(-1)}, yw] - 
     4*G[{yu^(-1)}, yw]*G[{0, 1}, yw]*G[{1, yu^(-1)}, yw] + 
     2*G[{yu}, yv^(-1)]*G[{0, 1}, yw]*G[{1, yu^(-1)}, yw] + 
     4*G[{1/(yu*yv)}, yw]*G[{0, 1}, yw]*G[{1, yu^(-1)}, yw] + 
     2*G[{1}, yu^(-1)]*G[{0, yu^(-1)}, yw]*G[{1, yu^(-1)}, yw] + 
     2*G[{1}, yw]*G[{0, yu^(-1)}, yw]*G[{1, yu^(-1)}, yw] + 
     4*G[{yu^(-1)}, yw]*G[{0, yu^(-1)}, yw]*G[{1, yu^(-1)}, yw] - 
     2*G[{yu}, yv^(-1)]*G[{0, yu^(-1)}, yw]*G[{1, yu^(-1)}, yw] - 
     4*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1)}, yw]*G[{1, yu^(-1)}, yw] + 
     2*G[{1}, yu^(-1)]*G[{0, yu}, yv^(-1)]*G[{1, yu^(-1)}, yw] + 
     2*G[{1}, yw]*G[{0, yu}, yv^(-1)]*G[{1, yu^(-1)}, yw] + 
     4*G[{yu^(-1)}, yw]*G[{0, yu}, yv^(-1)]*G[{1, yu^(-1)}, yw] - 
     4*G[{1/(yu*yv)}, yw]*G[{0, yu}, yv^(-1)]*G[{1, yu^(-1)}, yw] + 
     2*G[{1}, yu^(-1)]*G[{0, yv^(-1)}, yw]*G[{1, yu^(-1)}, yw] + 
     2*G[{1}, yw]*G[{0, yv^(-1)}, yw]*G[{1, yu^(-1)}, yw] + 
     4*G[{yu^(-1)}, yw]*G[{0, yv^(-1)}, yw]*G[{1, yu^(-1)}, yw] - 
     2*G[{yu}, yv^(-1)]*G[{0, yv^(-1)}, yw]*G[{1, yu^(-1)}, yw] - 
     4*G[{1/(yu*yv)}, yw]*G[{0, yv^(-1)}, yw]*G[{1, yu^(-1)}, yw] - 
     2*G[{1}, yu^(-1)]*G[{0, 1/(yu*yv)}, yw]*G[{1, yu^(-1)}, yw] - 
     2*G[{1}, yw]*G[{0, 1/(yu*yv)}, yw]*G[{1, yu^(-1)}, yw] - 
     4*G[{yu^(-1)}, yw]*G[{0, 1/(yu*yv)}, yw]*G[{1, yu^(-1)}, yw] + 
     2*G[{yu}, yv^(-1)]*G[{0, 1/(yu*yv)}, yw]*G[{1, yu^(-1)}, yw] + 
     4*G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv)}, yw]*G[{1, yu^(-1)}, yw] - 
     2*G[{1}, yu^(-1)]*G[{1, yu^(-1)}, yw]^2 - 
     2*G[{1}, yw]*G[{1, yu^(-1)}, yw]^2 - 4*G[{yu^(-1)}, yw]*
      G[{1, yu^(-1)}, yw]^2 + 2*G[{yu}, yv^(-1)]*G[{1, yu^(-1)}, yw]^2 + 
     4*G[{1/(yu*yv)}, yw]*G[{1, yu^(-1)}, yw]^2 - 
     (Pi^2*G[{1}, yu^(-1)]*G[{1, yu}, yv^(-1)])/3 - 
     Pi^2*G[{yu^(-1)}, yw]*G[{1, yu}, yv^(-1)] + 2*G[{1}, yu^(-1)]^2*
      G[{yu^(-1)}, yw]*G[{1, yu}, yv^(-1)] - 4*G[{1}, yu^(-1)]*
      G[{1}, yv^(-1)]*G[{yu^(-1)}, yw]*G[{1, yu}, yv^(-1)] + 
     2*G[{1}, yw]^2*G[{yu^(-1)}, yw]*G[{1, yu}, yv^(-1)] + 
     4*G[{0}, yu^(-1)]*G[{yu^(-1)}, yw]^2*G[{1, yu}, yv^(-1)] + 
     4*G[{0}, yv^(-1)]*G[{yu^(-1)}, yw]^2*G[{1, yu}, yv^(-1)] - 
     4*G[{0}, yw]*G[{yu^(-1)}, yw]^2*G[{1, yu}, yv^(-1)] - 
     3*G[{1}, yv^(-1)]*G[{yu^(-1)}, yw]^2*G[{1, yu}, yv^(-1)] + 
     3*G[{1}, yw]*G[{yu^(-1)}, yw]^2*G[{1, yu}, yv^(-1)] + 
     (8*G[{yu^(-1)}, yw]^3*G[{1, yu}, yv^(-1)])/3 - 
     (5*Pi^2*G[{yu}, yv^(-1)]*G[{1, yu}, yv^(-1)])/3 + 
     2*G[{1}, yu^(-1)]^2*G[{yu}, yv^(-1)]*G[{1, yu}, yv^(-1)] - 
     8*G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*G[{yu}, yv^(-1)]*G[{1, yu}, yv^(-1)] + 
     4*G[{1}, yu^(-1)]*G[{yu^(-1)}, yw]*G[{yu}, yv^(-1)]*
      G[{1, yu}, yv^(-1)] - 2*G[{1}, yv^(-1)]*G[{yu^(-1)}, yw]*
      G[{yu}, yv^(-1)]*G[{1, yu}, yv^(-1)] - 2*G[{1}, yw]*G[{yu^(-1)}, yw]*
      G[{yu}, yv^(-1)]*G[{1, yu}, yv^(-1)] - 3*G[{1}, yv^(-1)]*
      G[{yu}, yv^(-1)]^2*G[{1, yu}, yv^(-1)] + Pi^2*G[{1/(yu*yv)}, yw]*
      G[{1, yu}, yv^(-1)] - 2*G[{1}, yu^(-1)]^2*G[{1/(yu*yv)}, yw]*
      G[{1, yu}, yv^(-1)] + 4*G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*
      G[{1/(yu*yv)}, yw]*G[{1, yu}, yv^(-1)] - 2*G[{1}, yw]^2*
      G[{1/(yu*yv)}, yw]*G[{1, yu}, yv^(-1)] - 8*G[{0}, yu^(-1)]*
      G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{1, yu}, yv^(-1)] - 
     8*G[{0}, yv^(-1)]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*
      G[{1, yu}, yv^(-1)] + 8*G[{0}, yw]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*
      G[{1, yu}, yv^(-1)] + 6*G[{1}, yv^(-1)]*G[{yu^(-1)}, yw]*
      G[{1/(yu*yv)}, yw]*G[{1, yu}, yv^(-1)] - 6*G[{1}, yw]*G[{yu^(-1)}, yw]*
      G[{1/(yu*yv)}, yw]*G[{1, yu}, yv^(-1)] - 8*G[{yu^(-1)}, yw]^2*
      G[{1/(yu*yv)}, yw]*G[{1, yu}, yv^(-1)] - 4*G[{1}, yu^(-1)]*
      G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{1, yu}, yv^(-1)] + 
     2*G[{1}, yv^(-1)]*G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw]*
      G[{1, yu}, yv^(-1)] + 2*G[{1}, yw]*G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw]*
      G[{1, yu}, yv^(-1)] + 4*G[{0}, yu^(-1)]*G[{1/(yu*yv)}, yw]^2*
      G[{1, yu}, yv^(-1)] + 4*G[{0}, yv^(-1)]*G[{1/(yu*yv)}, yw]^2*
      G[{1, yu}, yv^(-1)] - 4*G[{0}, yw]*G[{1/(yu*yv)}, yw]^2*
      G[{1, yu}, yv^(-1)] - 3*G[{1}, yv^(-1)]*G[{1/(yu*yv)}, yw]^2*
      G[{1, yu}, yv^(-1)] + G[{1}, yw]*G[{1/(yu*yv)}, yw]^2*
      G[{1, yu}, yv^(-1)] + 5*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2*
      G[{1, yu}, yv^(-1)] - G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw]^2*
      G[{1, yu}, yv^(-1)] + 2*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2*
      G[{1, yu}, yv^(-1)] - 2*G[{1}, yu^(-1)]*G[{0, 1}, yu^(-1)]*
      G[{1, yu}, yv^(-1)] - 2*G[{yu^(-1)}, yw]*G[{0, 1}, yu^(-1)]*
      G[{1, yu}, yv^(-1)] - 6*G[{yu}, yv^(-1)]*G[{0, 1}, yu^(-1)]*
      G[{1, yu}, yv^(-1)] + 2*G[{1/(yu*yv)}, yw]*G[{0, 1}, yu^(-1)]*
      G[{1, yu}, yv^(-1)] + 2*G[{1}, yu^(-1)]*G[{0, 1}, yv^(-1)]*
      G[{1, yu}, yv^(-1)] - 2*G[{yu^(-1)}, yw]*G[{0, 1}, yv^(-1)]*
      G[{1, yu}, yv^(-1)] + 2*G[{yu}, yv^(-1)]*G[{0, 1}, yv^(-1)]*
      G[{1, yu}, yv^(-1)] + 2*G[{1/(yu*yv)}, yw]*G[{0, 1}, yv^(-1)]*
      G[{1, yu}, yv^(-1)] - 4*G[{yu^(-1)}, yw]*G[{0, 1}, yw]*
      G[{1, yu}, yv^(-1)] + 4*G[{1/(yu*yv)}, yw]*G[{0, 1}, yw]*
      G[{1, yu}, yv^(-1)] + 4*G[{yu^(-1)}, yw]*G[{0, yu^(-1)}, yw]*
      G[{1, yu}, yv^(-1)] - 4*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1)}, yw]*
      G[{1, yu}, yv^(-1)] - 2*G[{1}, yu^(-1)]*G[{0, yu}, yv^(-1)]*
      G[{1, yu}, yv^(-1)] + 2*G[{yu^(-1)}, yw]*G[{0, yu}, yv^(-1)]*
      G[{1, yu}, yv^(-1)] - 2*G[{yu}, yv^(-1)]*G[{0, yu}, yv^(-1)]*
      G[{1, yu}, yv^(-1)] - 2*G[{1/(yu*yv)}, yw]*G[{0, yu}, yv^(-1)]*
      G[{1, yu}, yv^(-1)] + 4*G[{yu^(-1)}, yw]*G[{0, yv^(-1)}, yw]*
      G[{1, yu}, yv^(-1)] - 4*G[{1/(yu*yv)}, yw]*G[{0, yv^(-1)}, yw]*
      G[{1, yu}, yv^(-1)] - 4*G[{yu^(-1)}, yw]*G[{0, 1/(yu*yv)}, yw]*
      G[{1, yu}, yv^(-1)] + 4*G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv)}, yw]*
      G[{1, yu}, yv^(-1)] - 4*G[{1}, yw]*G[{1, yu^(-1)}, yw]*
      G[{1, yu}, yv^(-1)] - 4*G[{yu^(-1)}, yw]*G[{1, yu^(-1)}, yw]*
      G[{1, yu}, yv^(-1)] + 2*G[{yu}, yv^(-1)]*G[{1, yu^(-1)}, yw]*
      G[{1, yu}, yv^(-1)] + 4*G[{1/(yu*yv)}, yw]*G[{1, yu^(-1)}, yw]*
      G[{1, yu}, yv^(-1)] + 4*G[{yu}, yv^(-1)]*G[{1, yu}, yv^(-1)]^2 + 
     (Pi^2*G[{yu^(-1)}, yw]*G[{1, yv^(-1)}, yw])/3 - 
     2*G[{0}, yu^(-1)]*G[{1}, yu^(-1)]*G[{yu^(-1)}, yw]*G[{1, yv^(-1)}, yw] - 
     2*G[{0}, yv^(-1)]*G[{1}, yu^(-1)]*G[{yu^(-1)}, yw]*G[{1, yv^(-1)}, yw] + 
     2*G[{0}, yw]*G[{1}, yu^(-1)]*G[{yu^(-1)}, yw]*G[{1, yv^(-1)}, yw] + 
     2*G[{1}, yu^(-1)]^2*G[{yu^(-1)}, yw]*G[{1, yv^(-1)}, yw] + 
     4*G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*G[{yu^(-1)}, yw]*G[{1, yv^(-1)}, yw] - 
     4*G[{0}, yu^(-1)]*G[{1}, yw]*G[{yu^(-1)}, yw]*G[{1, yv^(-1)}, yw] - 
     4*G[{0}, yv^(-1)]*G[{1}, yw]*G[{yu^(-1)}, yw]*G[{1, yv^(-1)}, yw] + 
     4*G[{0}, yw]*G[{1}, yw]*G[{yu^(-1)}, yw]*G[{1, yv^(-1)}, yw] + 
     4*G[{1}, yu^(-1)]*G[{1}, yw]*G[{yu^(-1)}, yw]*G[{1, yv^(-1)}, yw] + 
     4*G[{1}, yv^(-1)]*G[{1}, yw]*G[{yu^(-1)}, yw]*G[{1, yv^(-1)}, yw] + 
     2*G[{1}, yv^(-1)]*G[{yu^(-1)}, yw]^2*G[{1, yv^(-1)}, yw] + 
     2*G[{1}, yw]*G[{yu^(-1)}, yw]^2*G[{1, yv^(-1)}, yw] - 
     (2*G[{yu^(-1)}, yw]^3*G[{1, yv^(-1)}, yw])/3 + 
     2*G[{0}, yu^(-1)]*G[{yu^(-1)}, yw]*G[{yu}, yv^(-1)]*
      G[{1, yv^(-1)}, yw] + 2*G[{0}, yv^(-1)]*G[{yu^(-1)}, yw]*
      G[{yu}, yv^(-1)]*G[{1, yv^(-1)}, yw] - 2*G[{0}, yw]*G[{yu^(-1)}, yw]*
      G[{yu}, yv^(-1)]*G[{1, yv^(-1)}, yw] - 4*G[{1}, yu^(-1)]*
      G[{yu^(-1)}, yw]*G[{yu}, yv^(-1)]*G[{1, yv^(-1)}, yw] - 
     2*G[{yu^(-1)}, yw]^2*G[{yu}, yv^(-1)]*G[{1, yv^(-1)}, yw] - 
     (Pi^2*G[{1/(yu*yv)}, yw]*G[{1, yv^(-1)}, yw])/3 + 
     2*G[{0}, yu^(-1)]*G[{1}, yu^(-1)]*G[{1/(yu*yv)}, yw]*
      G[{1, yv^(-1)}, yw] + 2*G[{0}, yv^(-1)]*G[{1}, yu^(-1)]*
      G[{1/(yu*yv)}, yw]*G[{1, yv^(-1)}, yw] - 2*G[{0}, yw]*G[{1}, yu^(-1)]*
      G[{1/(yu*yv)}, yw]*G[{1, yv^(-1)}, yw] - 2*G[{1}, yu^(-1)]^2*
      G[{1/(yu*yv)}, yw]*G[{1, yv^(-1)}, yw] - 4*G[{1}, yu^(-1)]*
      G[{1}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{1, yv^(-1)}, yw] + 
     4*G[{0}, yu^(-1)]*G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{1, yv^(-1)}, yw] + 
     4*G[{0}, yv^(-1)]*G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{1, yv^(-1)}, yw] - 
     4*G[{0}, yw]*G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{1, yv^(-1)}, yw] - 
     4*G[{1}, yu^(-1)]*G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{1, yv^(-1)}, yw] - 
     4*G[{1}, yv^(-1)]*G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{1, yv^(-1)}, yw] - 
     4*G[{1}, yv^(-1)]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*
      G[{1, yv^(-1)}, yw] - 4*G[{1}, yw]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*
      G[{1, yv^(-1)}, yw] + 2*G[{yu^(-1)}, yw]^2*G[{1/(yu*yv)}, yw]*
      G[{1, yv^(-1)}, yw] - 2*G[{0}, yu^(-1)]*G[{yu}, yv^(-1)]*
      G[{1/(yu*yv)}, yw]*G[{1, yv^(-1)}, yw] - 2*G[{0}, yv^(-1)]*
      G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{1, yv^(-1)}, yw] + 
     2*G[{0}, yw]*G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{1, yv^(-1)}, yw] + 
     4*G[{1}, yu^(-1)]*G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw]*
      G[{1, yv^(-1)}, yw] + 4*G[{yu^(-1)}, yw]*G[{yu}, yv^(-1)]*
      G[{1/(yu*yv)}, yw]*G[{1, yv^(-1)}, yw] - 2*G[{1}, yu^(-1)]*
      G[{1/(yu*yv)}, yw]^2*G[{1, yv^(-1)}, yw] + 2*G[{1}, yv^(-1)]*
      G[{1/(yu*yv)}, yw]^2*G[{1, yv^(-1)}, yw] - 2*G[{yu^(-1)}, yw]*
      G[{1/(yu*yv)}, yw]^2*G[{1, yv^(-1)}, yw] + 2*G[{yu^(-1)}, yw]*
      G[{0, 1}, yu^(-1)]*G[{1, yv^(-1)}, yw] - 2*G[{1/(yu*yv)}, yw]*
      G[{0, 1}, yu^(-1)]*G[{1, yv^(-1)}, yw] - 2*G[{yu^(-1)}, yw]*
      G[{0, 1}, yv^(-1)]*G[{1, yv^(-1)}, yw] + 2*G[{1/(yu*yv)}, yw]*
      G[{0, 1}, yv^(-1)]*G[{1, yv^(-1)}, yw] - 2*G[{yu^(-1)}, yw]*
      G[{0, 1}, yw]*G[{1, yv^(-1)}, yw] + 2*G[{1/(yu*yv)}, yw]*G[{0, 1}, yw]*
      G[{1, yv^(-1)}, yw] + 2*G[{yu^(-1)}, yw]*G[{0, yu^(-1)}, yw]*
      G[{1, yv^(-1)}, yw] - 2*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1)}, yw]*
      G[{1, yv^(-1)}, yw] + 2*G[{yu^(-1)}, yw]*G[{0, yu}, yv^(-1)]*
      G[{1, yv^(-1)}, yw] - 2*G[{1/(yu*yv)}, yw]*G[{0, yu}, yv^(-1)]*
      G[{1, yv^(-1)}, yw] + 2*G[{yu^(-1)}, yw]*G[{0, yv^(-1)}, yw]*
      G[{1, yv^(-1)}, yw] - 2*G[{1/(yu*yv)}, yw]*G[{0, yv^(-1)}, yw]*
      G[{1, yv^(-1)}, yw] - 2*G[{yu^(-1)}, yw]*G[{0, 1/(yu*yv)}, yw]*
      G[{1, yv^(-1)}, yw] + 2*G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv)}, yw]*
      G[{1, yv^(-1)}, yw] - 4*G[{yu^(-1)}, yw]*G[{1, yu^(-1)}, yw]*
      G[{1, yv^(-1)}, yw] + 4*G[{1/(yu*yv)}, yw]*G[{1, yu^(-1)}, yw]*
      G[{1, yv^(-1)}, yw] - 4*G[{yu^(-1)}, yw]*G[{1, yu}, yv^(-1)]*
      G[{1, yv^(-1)}, yw] + 4*G[{1/(yu*yv)}, yw]*G[{1, yu}, yv^(-1)]*
      G[{1, yv^(-1)}, yw] - (Pi^2*G[{1}, yu^(-1)]*G[{1, 1/(yu*yv)}, yw])/3 - 
     (Pi^2*G[{1}, yw]*G[{1, 1/(yu*yv)}, yw])/3 + 2*G[{0}, yu^(-1)]*
      G[{1}, yu^(-1)]*G[{1}, yw]*G[{1, 1/(yu*yv)}, yw] + 
     2*G[{0}, yv^(-1)]*G[{1}, yu^(-1)]*G[{1}, yw]*G[{1, 1/(yu*yv)}, yw] - 
     2*G[{0}, yw]*G[{1}, yu^(-1)]*G[{1}, yw]*G[{1, 1/(yu*yv)}, yw] - 
     2*G[{1}, yu^(-1)]^2*G[{1}, yw]*G[{1, 1/(yu*yv)}, yw] - 
     4*G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*G[{1}, yw]*G[{1, 1/(yu*yv)}, yw] + 
     2*G[{0}, yu^(-1)]*G[{1}, yw]^2*G[{1, 1/(yu*yv)}, yw] + 
     2*G[{0}, yv^(-1)]*G[{1}, yw]^2*G[{1, 1/(yu*yv)}, yw] - 
     2*G[{0}, yw]*G[{1}, yw]^2*G[{1, 1/(yu*yv)}, yw] - 
     2*G[{1}, yu^(-1)]*G[{1}, yw]^2*G[{1, 1/(yu*yv)}, yw] - 
     2*G[{1}, yv^(-1)]*G[{1}, yw]^2*G[{1, 1/(yu*yv)}, yw] + 
     Pi^2*G[{yu^(-1)}, yw]*G[{1, 1/(yu*yv)}, yw] - 
     4*G[{0}, yu^(-1)]*G[{1}, yu^(-1)]*G[{yu^(-1)}, yw]*
      G[{1, 1/(yu*yv)}, yw] - 4*G[{0}, yv^(-1)]*G[{1}, yu^(-1)]*
      G[{yu^(-1)}, yw]*G[{1, 1/(yu*yv)}, yw] + 4*G[{0}, yw]*G[{1}, yu^(-1)]*
      G[{yu^(-1)}, yw]*G[{1, 1/(yu*yv)}, yw] + 2*G[{1}, yu^(-1)]^2*
      G[{yu^(-1)}, yw]*G[{1, 1/(yu*yv)}, yw] + 4*G[{1}, yu^(-1)]*
      G[{1}, yv^(-1)]*G[{yu^(-1)}, yw]*G[{1, 1/(yu*yv)}, yw] - 
     2*G[{0}, yu^(-1)]*G[{1}, yw]*G[{yu^(-1)}, yw]*G[{1, 1/(yu*yv)}, yw] - 
     2*G[{0}, yv^(-1)]*G[{1}, yw]*G[{yu^(-1)}, yw]*G[{1, 1/(yu*yv)}, yw] + 
     2*G[{0}, yw]*G[{1}, yw]*G[{yu^(-1)}, yw]*G[{1, 1/(yu*yv)}, yw] - 
     4*G[{1}, yu^(-1)]*G[{1}, yw]*G[{yu^(-1)}, yw]*G[{1, 1/(yu*yv)}, yw] - 
     4*G[{1}, yw]^2*G[{yu^(-1)}, yw]*G[{1, 1/(yu*yv)}, yw] - 
     4*G[{0}, yu^(-1)]*G[{yu^(-1)}, yw]^2*G[{1, 1/(yu*yv)}, yw] - 
     4*G[{0}, yv^(-1)]*G[{yu^(-1)}, yw]^2*G[{1, 1/(yu*yv)}, yw] + 
     4*G[{0}, yw]*G[{yu^(-1)}, yw]^2*G[{1, 1/(yu*yv)}, yw] + 
     3*G[{1}, yv^(-1)]*G[{yu^(-1)}, yw]^2*G[{1, 1/(yu*yv)}, yw] - 
     5*G[{1}, yw]*G[{yu^(-1)}, yw]^2*G[{1, 1/(yu*yv)}, yw] - 
     (8*G[{yu^(-1)}, yw]^3*G[{1, 1/(yu*yv)}, yw])/3 + 
     (Pi^2*G[{yu}, yv^(-1)]*G[{1, 1/(yu*yv)}, yw])/3 - 
     2*G[{0}, yu^(-1)]*G[{1}, yw]*G[{yu}, yv^(-1)]*G[{1, 1/(yu*yv)}, yw] - 
     2*G[{0}, yv^(-1)]*G[{1}, yw]*G[{yu}, yv^(-1)]*G[{1, 1/(yu*yv)}, yw] + 
     2*G[{0}, yw]*G[{1}, yw]*G[{yu}, yv^(-1)]*G[{1, 1/(yu*yv)}, yw] + 
     4*G[{1}, yu^(-1)]*G[{1}, yw]*G[{yu}, yv^(-1)]*G[{1, 1/(yu*yv)}, yw] + 
     4*G[{0}, yu^(-1)]*G[{yu^(-1)}, yw]*G[{yu}, yv^(-1)]*
      G[{1, 1/(yu*yv)}, yw] + 4*G[{0}, yv^(-1)]*G[{yu^(-1)}, yw]*
      G[{yu}, yv^(-1)]*G[{1, 1/(yu*yv)}, yw] - 4*G[{0}, yw]*G[{yu^(-1)}, yw]*
      G[{yu}, yv^(-1)]*G[{1, 1/(yu*yv)}, yw] - 4*G[{1}, yv^(-1)]*
      G[{yu^(-1)}, yw]*G[{yu}, yv^(-1)]*G[{1, 1/(yu*yv)}, yw] + 
     8*G[{1}, yw]*G[{yu^(-1)}, yw]*G[{yu}, yv^(-1)]*G[{1, 1/(yu*yv)}, yw] + 
     5*G[{yu^(-1)}, yw]^2*G[{yu}, yv^(-1)]*G[{1, 1/(yu*yv)}, yw] + 
     G[{1}, yv^(-1)]*G[{yu}, yv^(-1)]^2*G[{1, 1/(yu*yv)}, yw] - 
     2*G[{yu^(-1)}, yw]*G[{yu}, yv^(-1)]^2*G[{1, 1/(yu*yv)}, yw] - 
     (G[{yu}, yv^(-1)]^3*G[{1, 1/(yu*yv)}, yw])/3 - 
     Pi^2*G[{1/(yu*yv)}, yw]*G[{1, 1/(yu*yv)}, yw] + 
     4*G[{0}, yu^(-1)]*G[{1}, yu^(-1)]*G[{1/(yu*yv)}, yw]*
      G[{1, 1/(yu*yv)}, yw] + 4*G[{0}, yv^(-1)]*G[{1}, yu^(-1)]*
      G[{1/(yu*yv)}, yw]*G[{1, 1/(yu*yv)}, yw] - 4*G[{0}, yw]*G[{1}, yu^(-1)]*
      G[{1/(yu*yv)}, yw]*G[{1, 1/(yu*yv)}, yw] - 2*G[{1}, yu^(-1)]^2*
      G[{1/(yu*yv)}, yw]*G[{1, 1/(yu*yv)}, yw] - 4*G[{1}, yu^(-1)]*
      G[{1}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{1, 1/(yu*yv)}, yw] + 
     2*G[{0}, yu^(-1)]*G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{1, 1/(yu*yv)}, yw] + 
     2*G[{0}, yv^(-1)]*G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{1, 1/(yu*yv)}, yw] - 
     2*G[{0}, yw]*G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{1, 1/(yu*yv)}, yw] + 
     4*G[{1}, yu^(-1)]*G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{1, 1/(yu*yv)}, yw] + 
     4*G[{1}, yw]^2*G[{1/(yu*yv)}, yw]*G[{1, 1/(yu*yv)}, yw] + 
     8*G[{0}, yu^(-1)]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*
      G[{1, 1/(yu*yv)}, yw] + 8*G[{0}, yv^(-1)]*G[{yu^(-1)}, yw]*
      G[{1/(yu*yv)}, yw]*G[{1, 1/(yu*yv)}, yw] - 
     8*G[{0}, yw]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{1, 1/(yu*yv)}, yw] - 
     6*G[{1}, yv^(-1)]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*
      G[{1, 1/(yu*yv)}, yw] + 10*G[{1}, yw]*G[{yu^(-1)}, yw]*
      G[{1/(yu*yv)}, yw]*G[{1, 1/(yu*yv)}, yw] + 8*G[{yu^(-1)}, yw]^2*
      G[{1/(yu*yv)}, yw]*G[{1, 1/(yu*yv)}, yw] - 4*G[{0}, yu^(-1)]*
      G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{1, 1/(yu*yv)}, yw] - 
     4*G[{0}, yv^(-1)]*G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw]*
      G[{1, 1/(yu*yv)}, yw] + 4*G[{0}, yw]*G[{yu}, yv^(-1)]*
      G[{1/(yu*yv)}, yw]*G[{1, 1/(yu*yv)}, yw] + 4*G[{1}, yv^(-1)]*
      G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{1, 1/(yu*yv)}, yw] - 
     8*G[{1}, yw]*G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{1, 1/(yu*yv)}, yw] - 
     10*G[{yu^(-1)}, yw]*G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw]*
      G[{1, 1/(yu*yv)}, yw] + 2*G[{yu}, yv^(-1)]^2*G[{1/(yu*yv)}, yw]*
      G[{1, 1/(yu*yv)}, yw] - 4*G[{0}, yu^(-1)]*G[{1/(yu*yv)}, yw]^2*
      G[{1, 1/(yu*yv)}, yw] - 4*G[{0}, yv^(-1)]*G[{1/(yu*yv)}, yw]^2*
      G[{1, 1/(yu*yv)}, yw] + 4*G[{0}, yw]*G[{1/(yu*yv)}, yw]^2*
      G[{1, 1/(yu*yv)}, yw] + 2*G[{1}, yu^(-1)]*G[{1/(yu*yv)}, yw]^2*
      G[{1, 1/(yu*yv)}, yw] + 3*G[{1}, yv^(-1)]*G[{1/(yu*yv)}, yw]^2*
      G[{1, 1/(yu*yv)}, yw] - 3*G[{1}, yw]*G[{1/(yu*yv)}, yw]^2*
      G[{1, 1/(yu*yv)}, yw] - 5*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2*
      G[{1, 1/(yu*yv)}, yw] + 3*G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw]^2*
      G[{1, 1/(yu*yv)}, yw] - 2*G[{1}, yu^(-1)]*G[{0, 1}, yu^(-1)]*
      G[{1, 1/(yu*yv)}, yw] - 2*G[{1}, yw]*G[{0, 1}, yu^(-1)]*
      G[{1, 1/(yu*yv)}, yw] + 2*G[{yu^(-1)}, yw]*G[{0, 1}, yu^(-1)]*
      G[{1, 1/(yu*yv)}, yw] + 2*G[{yu}, yv^(-1)]*G[{0, 1}, yu^(-1)]*
      G[{1, 1/(yu*yv)}, yw] - 2*G[{1/(yu*yv)}, yw]*G[{0, 1}, yu^(-1)]*
      G[{1, 1/(yu*yv)}, yw] + 2*G[{1}, yu^(-1)]*G[{0, 1}, yv^(-1)]*
      G[{1, 1/(yu*yv)}, yw] + 2*G[{1}, yw]*G[{0, 1}, yv^(-1)]*
      G[{1, 1/(yu*yv)}, yw] + 2*G[{yu^(-1)}, yw]*G[{0, 1}, yv^(-1)]*
      G[{1, 1/(yu*yv)}, yw] - 2*G[{1/(yu*yv)}, yw]*G[{0, 1}, yv^(-1)]*
      G[{1, 1/(yu*yv)}, yw] + 2*G[{1}, yu^(-1)]*G[{0, 1}, yw]*
      G[{1, 1/(yu*yv)}, yw] + 2*G[{1}, yw]*G[{0, 1}, yw]*
      G[{1, 1/(yu*yv)}, yw] + 2*G[{yu^(-1)}, yw]*G[{0, 1}, yw]*
      G[{1, 1/(yu*yv)}, yw] - 2*G[{yu}, yv^(-1)]*G[{0, 1}, yw]*
      G[{1, 1/(yu*yv)}, yw] - 2*G[{1/(yu*yv)}, yw]*G[{0, 1}, yw]*
      G[{1, 1/(yu*yv)}, yw] - 2*G[{1}, yu^(-1)]*G[{0, yu^(-1)}, yw]*
      G[{1, 1/(yu*yv)}, yw] - 2*G[{1}, yw]*G[{0, yu^(-1)}, yw]*
      G[{1, 1/(yu*yv)}, yw] - 2*G[{yu^(-1)}, yw]*G[{0, yu^(-1)}, yw]*
      G[{1, 1/(yu*yv)}, yw] + 2*G[{yu}, yv^(-1)]*G[{0, yu^(-1)}, yw]*
      G[{1, 1/(yu*yv)}, yw] + 2*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1)}, yw]*
      G[{1, 1/(yu*yv)}, yw] - 2*G[{1}, yu^(-1)]*G[{0, yu}, yv^(-1)]*
      G[{1, 1/(yu*yv)}, yw] - 2*G[{1}, yw]*G[{0, yu}, yv^(-1)]*
      G[{1, 1/(yu*yv)}, yw] - 2*G[{yu^(-1)}, yw]*G[{0, yu}, yv^(-1)]*
      G[{1, 1/(yu*yv)}, yw] + 2*G[{1/(yu*yv)}, yw]*G[{0, yu}, yv^(-1)]*
      G[{1, 1/(yu*yv)}, yw] - 2*G[{1}, yu^(-1)]*G[{0, yv^(-1)}, yw]*
      G[{1, 1/(yu*yv)}, yw] - 2*G[{1}, yw]*G[{0, yv^(-1)}, yw]*
      G[{1, 1/(yu*yv)}, yw] - 2*G[{yu^(-1)}, yw]*G[{0, yv^(-1)}, yw]*
      G[{1, 1/(yu*yv)}, yw] + 2*G[{yu}, yv^(-1)]*G[{0, yv^(-1)}, yw]*
      G[{1, 1/(yu*yv)}, yw] + 2*G[{1/(yu*yv)}, yw]*G[{0, yv^(-1)}, yw]*
      G[{1, 1/(yu*yv)}, yw] + 2*G[{1}, yu^(-1)]*G[{0, 1/(yu*yv)}, yw]*
      G[{1, 1/(yu*yv)}, yw] + 2*G[{1}, yw]*G[{0, 1/(yu*yv)}, yw]*
      G[{1, 1/(yu*yv)}, yw] + 2*G[{yu^(-1)}, yw]*G[{0, 1/(yu*yv)}, yw]*
      G[{1, 1/(yu*yv)}, yw] - 2*G[{yu}, yv^(-1)]*G[{0, 1/(yu*yv)}, yw]*
      G[{1, 1/(yu*yv)}, yw] - 2*G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv)}, yw]*
      G[{1, 1/(yu*yv)}, yw] + 4*G[{1}, yu^(-1)]*G[{1, yu^(-1)}, yw]*
      G[{1, 1/(yu*yv)}, yw] + 4*G[{1}, yw]*G[{1, yu^(-1)}, yw]*
      G[{1, 1/(yu*yv)}, yw] + 4*G[{yu^(-1)}, yw]*G[{1, yu^(-1)}, yw]*
      G[{1, 1/(yu*yv)}, yw] - 4*G[{yu}, yv^(-1)]*G[{1, yu^(-1)}, yw]*
      G[{1, 1/(yu*yv)}, yw] - 4*G[{1/(yu*yv)}, yw]*G[{1, yu^(-1)}, yw]*
      G[{1, 1/(yu*yv)}, yw] + 4*G[{1}, yw]*G[{1, yu}, yv^(-1)]*
      G[{1, 1/(yu*yv)}, yw] - 2*G[{yu}, yv^(-1)]*G[{1, yu}, yv^(-1)]*
      G[{1, 1/(yu*yv)}, yw] + 4*G[{1}, yu^(-1)]*G[{1, yv^(-1)}, yw]*
      G[{1, 1/(yu*yv)}, yw] + 4*G[{1}, yw]*G[{1, yv^(-1)}, yw]*
      G[{1, 1/(yu*yv)}, yw] + 4*G[{yu^(-1)}, yw]*G[{1, yv^(-1)}, yw]*
      G[{1, 1/(yu*yv)}, yw] - 4*G[{yu}, yv^(-1)]*G[{1, yv^(-1)}, yw]*
      G[{1, 1/(yu*yv)}, yw] - 4*G[{1/(yu*yv)}, yw]*G[{1, yv^(-1)}, yw]*
      G[{1, 1/(yu*yv)}, yw] - 2*G[{1}, yu^(-1)]*G[{1, 1/(yu*yv)}, yw]^2 - 
     2*G[{1}, yw]*G[{1, 1/(yu*yv)}, yw]^2 - 2*G[{yu^(-1)}, yw]*
      G[{1, 1/(yu*yv)}, yw]^2 + 2*G[{yu}, yv^(-1)]*G[{1, 1/(yu*yv)}, yw]^2 + 
     2*G[{1/(yu*yv)}, yw]*G[{1, 1/(yu*yv)}, yw]^2 - 
     (Pi^2*G[{1}, yu^(-1)]*G[{yu^(-1), 1/(yu*yv)}, yw])/3 - 
     (Pi^2*G[{1}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw])/3 + 
     2*G[{0}, yu^(-1)]*G[{1}, yu^(-1)]*G[{1}, yw]*G[{yu^(-1), 1/(yu*yv)}, 
       yw] + 2*G[{0}, yv^(-1)]*G[{1}, yu^(-1)]*G[{1}, yw]*
      G[{yu^(-1), 1/(yu*yv)}, yw] - 2*G[{0}, yw]*G[{1}, yu^(-1)]*G[{1}, yw]*
      G[{yu^(-1), 1/(yu*yv)}, yw] - 2*G[{1}, yu^(-1)]^2*G[{1}, yw]*
      G[{yu^(-1), 1/(yu*yv)}, yw] - 4*G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*
      G[{1}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw] + 2*G[{0}, yu^(-1)]*G[{1}, yw]^2*
      G[{yu^(-1), 1/(yu*yv)}, yw] + 2*G[{0}, yv^(-1)]*G[{1}, yw]^2*
      G[{yu^(-1), 1/(yu*yv)}, yw] - 2*G[{0}, yw]*G[{1}, yw]^2*
      G[{yu^(-1), 1/(yu*yv)}, yw] - 2*G[{1}, yu^(-1)]*G[{1}, yw]^2*
      G[{yu^(-1), 1/(yu*yv)}, yw] - 2*G[{1}, yv^(-1)]*G[{1}, yw]^2*
      G[{yu^(-1), 1/(yu*yv)}, yw] - 2*G[{0}, yu^(-1)]*G[{1}, yu^(-1)]*
      G[{yu^(-1)}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw] - 
     2*G[{0}, yv^(-1)]*G[{1}, yu^(-1)]*G[{yu^(-1)}, yw]*
      G[{yu^(-1), 1/(yu*yv)}, yw] + 2*G[{0}, yw]*G[{1}, yu^(-1)]*
      G[{yu^(-1)}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw] + 
     2*G[{1}, yu^(-1)]^2*G[{yu^(-1)}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw] - 
     2*G[{0}, yu^(-1)]*G[{1}, yw]*G[{yu^(-1)}, yw]*G[{yu^(-1), 1/(yu*yv)}, 
       yw] - 2*G[{0}, yv^(-1)]*G[{1}, yw]*G[{yu^(-1)}, yw]*
      G[{yu^(-1), 1/(yu*yv)}, yw] + 2*G[{0}, yw]*G[{1}, yw]*G[{yu^(-1)}, yw]*
      G[{yu^(-1), 1/(yu*yv)}, yw] - 2*G[{1}, yw]^2*G[{yu^(-1)}, yw]*
      G[{yu^(-1), 1/(yu*yv)}, yw] - 3*G[{1}, yv^(-1)]*G[{yu^(-1)}, yw]^2*
      G[{yu^(-1), 1/(yu*yv)}, yw] - 3*G[{1}, yw]*G[{yu^(-1)}, yw]^2*
      G[{yu^(-1), 1/(yu*yv)}, yw] + G[{yu^(-1)}, yw]^3*
      G[{yu^(-1), 1/(yu*yv)}, yw] + (Pi^2*G[{yu}, yv^(-1)]*
       G[{yu^(-1), 1/(yu*yv)}, yw])/3 - 2*G[{0}, yu^(-1)]*G[{1}, yw]*
      G[{yu}, yv^(-1)]*G[{yu^(-1), 1/(yu*yv)}, yw] - 
     2*G[{0}, yv^(-1)]*G[{1}, yw]*G[{yu}, yv^(-1)]*G[{yu^(-1), 1/(yu*yv)}, 
       yw] + 2*G[{0}, yw]*G[{1}, yw]*G[{yu}, yv^(-1)]*
      G[{yu^(-1), 1/(yu*yv)}, yw] + 4*G[{1}, yu^(-1)]*G[{1}, yw]*
      G[{yu}, yv^(-1)]*G[{yu^(-1), 1/(yu*yv)}, yw] + 
     2*G[{0}, yu^(-1)]*G[{yu^(-1)}, yw]*G[{yu}, yv^(-1)]*
      G[{yu^(-1), 1/(yu*yv)}, yw] + 2*G[{0}, yv^(-1)]*G[{yu^(-1)}, yw]*
      G[{yu}, yv^(-1)]*G[{yu^(-1), 1/(yu*yv)}, yw] - 
     2*G[{0}, yw]*G[{yu^(-1)}, yw]*G[{yu}, yv^(-1)]*G[{yu^(-1), 1/(yu*yv)}, 
       yw] - 6*G[{1}, yv^(-1)]*G[{yu^(-1)}, yw]*G[{yu}, yv^(-1)]*
      G[{yu^(-1), 1/(yu*yv)}, yw] + 4*G[{1}, yw]*G[{yu^(-1)}, yw]*
      G[{yu}, yv^(-1)]*G[{yu^(-1), 1/(yu*yv)}, yw] + 
     3*G[{yu^(-1)}, yw]^2*G[{yu}, yv^(-1)]*G[{yu^(-1), 1/(yu*yv)}, yw] - 
     G[{1}, yv^(-1)]*G[{yu}, yv^(-1)]^2*G[{yu^(-1), 1/(yu*yv)}, yw] + 
     G[{yu^(-1)}, yw]*G[{yu}, yv^(-1)]^2*G[{yu^(-1), 1/(yu*yv)}, yw] + 
     (G[{yu}, yv^(-1)]^3*G[{yu^(-1), 1/(yu*yv)}, yw])/3 + 
     (2*Pi^2*G[{1/(yu*yv)}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw])/3 - 
     6*G[{0}, yu^(-1)]*G[{1}, yu^(-1)]*G[{1/(yu*yv)}, yw]*
      G[{yu^(-1), 1/(yu*yv)}, yw] - 6*G[{0}, yv^(-1)]*G[{1}, yu^(-1)]*
      G[{1/(yu*yv)}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw] + 
     6*G[{0}, yw]*G[{1}, yu^(-1)]*G[{1/(yu*yv)}, yw]*
      G[{yu^(-1), 1/(yu*yv)}, yw] + 4*G[{1}, yu^(-1)]^2*G[{1/(yu*yv)}, yw]*
      G[{yu^(-1), 1/(yu*yv)}, yw] + 8*G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*
      G[{1/(yu*yv)}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw] - 
     2*G[{0}, yu^(-1)]*G[{1}, yw]*G[{1/(yu*yv)}, yw]*
      G[{yu^(-1), 1/(yu*yv)}, yw] - 2*G[{0}, yv^(-1)]*G[{1}, yw]*
      G[{1/(yu*yv)}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw] + 
     2*G[{0}, yw]*G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw] + 
     4*G[{1}, yv^(-1)]*G[{1}, yw]*G[{1/(yu*yv)}, yw]*
      G[{yu^(-1), 1/(yu*yv)}, yw] - 4*G[{0}, yu^(-1)]*G[{yu^(-1)}, yw]*
      G[{1/(yu*yv)}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw] - 
     4*G[{0}, yv^(-1)]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*
      G[{yu^(-1), 1/(yu*yv)}, yw] + 4*G[{0}, yw]*G[{yu^(-1)}, yw]*
      G[{1/(yu*yv)}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw] - 
     4*G[{1}, yu^(-1)]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*
      G[{yu^(-1), 1/(yu*yv)}, yw] + 8*G[{1}, yv^(-1)]*G[{yu^(-1)}, yw]*
      G[{1/(yu*yv)}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw] - 
     4*G[{1}, yw]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*
      G[{yu^(-1), 1/(yu*yv)}, yw] - 4*G[{yu^(-1)}, yw]^2*G[{1/(yu*yv)}, yw]*
      G[{yu^(-1), 1/(yu*yv)}, yw] + 6*G[{0}, yu^(-1)]*G[{yu}, yv^(-1)]*
      G[{1/(yu*yv)}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw] + 
     6*G[{0}, yv^(-1)]*G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw]*
      G[{yu^(-1), 1/(yu*yv)}, yw] - 6*G[{0}, yw]*G[{yu}, yv^(-1)]*
      G[{1/(yu*yv)}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw] - 
     4*G[{1}, yu^(-1)]*G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw]*
      G[{yu^(-1), 1/(yu*yv)}, yw] - 4*G[{1}, yv^(-1)]*G[{yu}, yv^(-1)]*
      G[{1/(yu*yv)}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw] + 
     4*G[{yu^(-1)}, yw]*G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw]*
      G[{yu^(-1), 1/(yu*yv)}, yw] - 2*G[{yu}, yv^(-1)]^2*G[{1/(yu*yv)}, yw]*
      G[{yu^(-1), 1/(yu*yv)}, yw] + 4*G[{0}, yu^(-1)]*G[{1/(yu*yv)}, yw]^2*
      G[{yu^(-1), 1/(yu*yv)}, yw] + 4*G[{0}, yv^(-1)]*G[{1/(yu*yv)}, yw]^2*
      G[{yu^(-1), 1/(yu*yv)}, yw] - 4*G[{0}, yw]*G[{1/(yu*yv)}, yw]^2*
      G[{yu^(-1), 1/(yu*yv)}, yw] - 5*G[{1}, yv^(-1)]*G[{1/(yu*yv)}, yw]^2*
      G[{yu^(-1), 1/(yu*yv)}, yw] + 3*G[{1}, yw]*G[{1/(yu*yv)}, yw]^2*
      G[{yu^(-1), 1/(yu*yv)}, yw] + 5*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2*
      G[{yu^(-1), 1/(yu*yv)}, yw] - 3*G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw]^2*
      G[{yu^(-1), 1/(yu*yv)}, yw] - 2*G[{1}, yu^(-1)]*G[{0, 1}, yu^(-1)]*
      G[{yu^(-1), 1/(yu*yv)}, yw] - 2*G[{1}, yw]*G[{0, 1}, yu^(-1)]*
      G[{yu^(-1), 1/(yu*yv)}, yw] + 2*G[{yu}, yv^(-1)]*G[{0, 1}, yu^(-1)]*
      G[{yu^(-1), 1/(yu*yv)}, yw] + 2*G[{1}, yu^(-1)]*G[{0, 1}, yv^(-1)]*
      G[{yu^(-1), 1/(yu*yv)}, yw] + 2*G[{1}, yw]*G[{0, 1}, yv^(-1)]*
      G[{yu^(-1), 1/(yu*yv)}, yw] + 6*G[{yu^(-1)}, yw]*G[{0, 1}, yv^(-1)]*
      G[{yu^(-1), 1/(yu*yv)}, yw] + 4*G[{yu}, yv^(-1)]*G[{0, 1}, yv^(-1)]*
      G[{yu^(-1), 1/(yu*yv)}, yw] - 4*G[{1/(yu*yv)}, yw]*G[{0, 1}, yv^(-1)]*
      G[{yu^(-1), 1/(yu*yv)}, yw] + 2*G[{1}, yu^(-1)]*G[{0, 1}, yw]*
      G[{yu^(-1), 1/(yu*yv)}, yw] + 2*G[{1}, yw]*G[{0, 1}, yw]*
      G[{yu^(-1), 1/(yu*yv)}, yw] - 2*G[{yu}, yv^(-1)]*G[{0, 1}, yw]*
      G[{yu^(-1), 1/(yu*yv)}, yw] + 4*G[{1/(yu*yv)}, yw]*G[{0, 1}, yw]*
      G[{yu^(-1), 1/(yu*yv)}, yw] - 2*G[{1}, yu^(-1)]*G[{0, yu^(-1)}, yw]*
      G[{yu^(-1), 1/(yu*yv)}, yw] - 2*G[{1}, yw]*G[{0, yu^(-1)}, yw]*
      G[{yu^(-1), 1/(yu*yv)}, yw] + 2*G[{yu}, yv^(-1)]*G[{0, yu^(-1)}, yw]*
      G[{yu^(-1), 1/(yu*yv)}, yw] - 4*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1)}, yw]*
      G[{yu^(-1), 1/(yu*yv)}, yw] - 2*G[{1}, yu^(-1)]*G[{0, yu}, yv^(-1)]*
      G[{yu^(-1), 1/(yu*yv)}, yw] - 2*G[{1}, yw]*G[{0, yu}, yv^(-1)]*
      G[{yu^(-1), 1/(yu*yv)}, yw] - 6*G[{yu^(-1)}, yw]*G[{0, yu}, yv^(-1)]*
      G[{yu^(-1), 1/(yu*yv)}, yw] - 4*G[{yu}, yv^(-1)]*G[{0, yu}, yv^(-1)]*
      G[{yu^(-1), 1/(yu*yv)}, yw] + 4*G[{1/(yu*yv)}, yw]*G[{0, yu}, yv^(-1)]*
      G[{yu^(-1), 1/(yu*yv)}, yw] - 2*G[{1}, yu^(-1)]*G[{0, yv^(-1)}, yw]*
      G[{yu^(-1), 1/(yu*yv)}, yw] - 2*G[{1}, yw]*G[{0, yv^(-1)}, yw]*
      G[{yu^(-1), 1/(yu*yv)}, yw] + 2*G[{yu}, yv^(-1)]*G[{0, yv^(-1)}, yw]*
      G[{yu^(-1), 1/(yu*yv)}, yw] - 4*G[{1/(yu*yv)}, yw]*G[{0, yv^(-1)}, yw]*
      G[{yu^(-1), 1/(yu*yv)}, yw] + 2*G[{1}, yu^(-1)]*G[{0, 1/(yu*yv)}, yw]*
      G[{yu^(-1), 1/(yu*yv)}, yw] + 2*G[{1}, yw]*G[{0, 1/(yu*yv)}, yw]*
      G[{yu^(-1), 1/(yu*yv)}, yw] - 2*G[{yu}, yv^(-1)]*G[{0, 1/(yu*yv)}, yw]*
      G[{yu^(-1), 1/(yu*yv)}, yw] + 4*G[{1/(yu*yv)}, yw]*
      G[{0, 1/(yu*yv)}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw] + 
     4*G[{1}, yu^(-1)]*G[{1, yu^(-1)}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw] + 
     4*G[{1}, yw]*G[{1, yu^(-1)}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw] + 
     6*G[{yu^(-1)}, yw]*G[{1, yu^(-1)}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw] - 
     4*G[{yu}, yv^(-1)]*G[{1, yu^(-1)}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw] + 
     4*G[{1}, yw]*G[{1, yu}, yv^(-1)]*G[{yu^(-1), 1/(yu*yv)}, yw] + 
     6*G[{yu^(-1)}, yw]*G[{1, yu}, yv^(-1)]*G[{yu^(-1), 1/(yu*yv)}, yw] + 
     2*G[{yu}, yv^(-1)]*G[{1, yu}, yv^(-1)]*G[{yu^(-1), 1/(yu*yv)}, yw] - 
     4*G[{1/(yu*yv)}, yw]*G[{1, yu}, yv^(-1)]*G[{yu^(-1), 1/(yu*yv)}, yw] + 
     4*G[{1}, yu^(-1)]*G[{1, yv^(-1)}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw] + 
     4*G[{1}, yw]*G[{1, yv^(-1)}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw] - 
     4*G[{yu}, yv^(-1)]*G[{1, yv^(-1)}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw] + 
     4*G[{1/(yu*yv)}, yw]*G[{1, yv^(-1)}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw] - 
     4*G[{1}, yu^(-1)]*G[{1, 1/(yu*yv)}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw] - 
     4*G[{1}, yw]*G[{1, 1/(yu*yv)}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw] - 
     6*G[{yu^(-1)}, yw]*G[{1, 1/(yu*yv)}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw] + 
     4*G[{yu}, yv^(-1)]*G[{1, 1/(yu*yv)}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw] + 
     4*G[{1/(yu*yv)}, yw]*G[{1, 1/(yu*yv)}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw] - 
     4*G[{1/(yu*yv)}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw]^2 + 
     (Pi^2*G[{1/(yu*yv)}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw])/3 - 
     2*G[{0}, yu^(-1)]*G[{1}, yu^(-1)]*G[{1/(yu*yv)}, yw]*
      G[{yv^(-1), 1/(yu*yv)}, yw] - 2*G[{0}, yv^(-1)]*G[{1}, yu^(-1)]*
      G[{1/(yu*yv)}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw] + 
     2*G[{0}, yw]*G[{1}, yu^(-1)]*G[{1/(yu*yv)}, yw]*
      G[{yv^(-1), 1/(yu*yv)}, yw] + 2*G[{1}, yu^(-1)]^2*G[{1/(yu*yv)}, yw]*
      G[{yv^(-1), 1/(yu*yv)}, yw] + 4*G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*
      G[{1/(yu*yv)}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw] - 
     4*G[{0}, yu^(-1)]*G[{1}, yw]*G[{1/(yu*yv)}, yw]*
      G[{yv^(-1), 1/(yu*yv)}, yw] - 4*G[{0}, yv^(-1)]*G[{1}, yw]*
      G[{1/(yu*yv)}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw] + 
     4*G[{0}, yw]*G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw] + 
     4*G[{1}, yu^(-1)]*G[{1}, yw]*G[{1/(yu*yv)}, yw]*
      G[{yv^(-1), 1/(yu*yv)}, yw] + 4*G[{1}, yv^(-1)]*G[{1}, yw]*
      G[{1/(yu*yv)}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw] + 
     2*G[{0}, yu^(-1)]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*
      G[{yv^(-1), 1/(yu*yv)}, yw] + 2*G[{0}, yv^(-1)]*G[{yu^(-1)}, yw]*
      G[{1/(yu*yv)}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw] - 
     2*G[{0}, yw]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*
      G[{yv^(-1), 1/(yu*yv)}, yw] - 4*G[{1}, yu^(-1)]*G[{yu^(-1)}, yw]*
      G[{1/(yu*yv)}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw] + 
     2*G[{0}, yu^(-1)]*G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw]*
      G[{yv^(-1), 1/(yu*yv)}, yw] + 2*G[{0}, yv^(-1)]*G[{yu}, yv^(-1)]*
      G[{1/(yu*yv)}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw] - 
     2*G[{0}, yw]*G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw]*
      G[{yv^(-1), 1/(yu*yv)}, yw] - 4*G[{1}, yu^(-1)]*G[{yu}, yv^(-1)]*
      G[{1/(yu*yv)}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw] + 
     4*G[{0}, yu^(-1)]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*
      G[{yv^(-1), 1/(yu*yv)}, yw] + 4*G[{0}, yv^(-1)]*G[{yv^(-1)}, yw]*
      G[{1/(yu*yv)}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw] - 
     4*G[{0}, yw]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*
      G[{yv^(-1), 1/(yu*yv)}, yw] - 8*G[{1}, yu^(-1)]*G[{yv^(-1)}, yw]*
      G[{1/(yu*yv)}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw] - 
     4*G[{1}, yv^(-1)]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*
      G[{yv^(-1), 1/(yu*yv)}, yw] - 4*G[{1}, yw]*G[{yv^(-1)}, yw]*
      G[{1/(yu*yv)}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw] + 
     4*G[{yu^(-1)}, yw]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*
      G[{yv^(-1), 1/(yu*yv)}, yw] + 4*G[{yu}, yv^(-1)]*G[{yv^(-1)}, yw]*
      G[{1/(yu*yv)}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw] + 
     4*G[{yv^(-1)}, yw]^2*G[{1/(yu*yv)}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw] - 
     2*G[{1}, yv^(-1)]*G[{1/(yu*yv)}, yw]^2*G[{yv^(-1), 1/(yu*yv)}, yw] - 
     2*G[{1}, yw]*G[{1/(yu*yv)}, yw]^2*G[{yv^(-1), 1/(yu*yv)}, yw] + 
     2*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2*G[{yv^(-1), 1/(yu*yv)}, yw] + 
     2*G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw]^2*G[{yv^(-1), 1/(yu*yv)}, yw] + 
     2*G[{1/(yu*yv)}, yw]*G[{0, 1}, yu^(-1)]*G[{yv^(-1), 1/(yu*yv)}, yw] - 
     2*G[{1/(yu*yv)}, yw]*G[{0, 1}, yv^(-1)]*G[{yv^(-1), 1/(yu*yv)}, yw] - 
     2*G[{1/(yu*yv)}, yw]*G[{0, 1}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw] + 
     2*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1)}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw] + 
     2*G[{1/(yu*yv)}, yw]*G[{0, yu}, yv^(-1)]*G[{yv^(-1), 1/(yu*yv)}, yw] + 
     2*G[{1/(yu*yv)}, yw]*G[{0, yv^(-1)}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw] - 
     2*G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv)}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw] - 
     4*G[{1/(yu*yv)}, yw]*G[{1, yu^(-1)}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw] - 
     4*G[{1/(yu*yv)}, yw]*G[{1, yu}, yv^(-1)]*G[{yv^(-1), 1/(yu*yv)}, yw] + 
     2*G[{1/(yu*yv)}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw]^2 + 
     (2*Pi^2*G[{0, 0, 1}, yv^(-1)])/3 - 2*G[{1}, yu^(-1)]^2*
      G[{0, 0, 1}, yv^(-1)] - 4*G[{0}, yu^(-1)]*G[{yu^(-1)}, yw]*
      G[{0, 0, 1}, yv^(-1)] - 4*G[{0}, yv^(-1)]*G[{yu^(-1)}, yw]*
      G[{0, 0, 1}, yv^(-1)] + 4*G[{0}, yw]*G[{yu^(-1)}, yw]*
      G[{0, 0, 1}, yv^(-1)] + 6*G[{1}, yv^(-1)]*G[{yu^(-1)}, yw]*
      G[{0, 0, 1}, yv^(-1)] - 2*G[{1}, yw]*G[{yu^(-1)}, yw]*
      G[{0, 0, 1}, yv^(-1)] - 3*G[{yu^(-1)}, yw]^2*G[{0, 0, 1}, yv^(-1)] - 
     2*G[{1}, yv^(-1)]*G[{yu}, yv^(-1)]*G[{0, 0, 1}, yv^(-1)] + 
     2*G[{yu^(-1)}, yw]*G[{yu}, yv^(-1)]*G[{0, 0, 1}, yv^(-1)] + 
     G[{yu}, yv^(-1)]^2*G[{0, 0, 1}, yv^(-1)] + 4*G[{0}, yu^(-1)]*
      G[{1/(yu*yv)}, yw]*G[{0, 0, 1}, yv^(-1)] + 4*G[{0}, yv^(-1)]*
      G[{1/(yu*yv)}, yw]*G[{0, 0, 1}, yv^(-1)] - 
     4*G[{0}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 0, 1}, yv^(-1)] - 
     6*G[{1}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, 0, 1}, yv^(-1)] + 
     2*G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 0, 1}, yv^(-1)] + 
     6*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 0, 1}, yv^(-1)] - 
     2*G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, 0, 1}, yv^(-1)] - 
     2*G[{0, 1}, yv^(-1)]*G[{0, 0, 1}, yv^(-1)] - 4*G[{0, yu^(-1)}, yw]*
      G[{0, 0, 1}, yv^(-1)] - 2*G[{0, yu}, yv^(-1)]*G[{0, 0, 1}, yv^(-1)] + 
     4*G[{0, 1/(yu*yv)}, yw]*G[{0, 0, 1}, yv^(-1)] + 
     2*G[{1, yu^(-1)}, yw]*G[{0, 0, 1}, yv^(-1)] + 2*G[{1, yu}, yv^(-1)]*
      G[{0, 0, 1}, yv^(-1)] - 2*G[{1, 1/(yu*yv)}, yw]*G[{0, 0, 1}, yv^(-1)] - 
     6*G[{yu^(-1), 1/(yu*yv)}, yw]*G[{0, 0, 1}, yv^(-1)] - 
     4*G[{1}, yu^(-1)]*G[{yu^(-1)}, yw]*G[{0, 0, 1}, yw] + 
     4*G[{yu^(-1)}, yw]*G[{yu}, yv^(-1)]*G[{0, 0, 1}, yw] + 
     4*G[{1}, yu^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, 0, 1}, yw] - 
     4*G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, 0, 1}, yw] + 
     4*G[{1}, yu^(-1)]*G[{yu^(-1)}, yw]*G[{0, 0, yu^(-1)}, yw] - 
     4*G[{yu^(-1)}, yw]*G[{yu}, yv^(-1)]*G[{0, 0, yu^(-1)}, yw] - 
     4*G[{1}, yu^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, 0, yu^(-1)}, yw] + 
     4*G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, 0, yu^(-1)}, yw] - 
     (4*Pi^2*G[{0, 0, yu}, yv^(-1)])/3 + 2*G[{1}, yu^(-1)]^2*
      G[{0, 0, yu}, yv^(-1)] + 4*G[{0}, yu^(-1)]*G[{yu^(-1)}, yw]*
      G[{0, 0, yu}, yv^(-1)] + 4*G[{0}, yv^(-1)]*G[{yu^(-1)}, yw]*
      G[{0, 0, yu}, yv^(-1)] - 4*G[{0}, yw]*G[{yu^(-1)}, yw]*
      G[{0, 0, yu}, yv^(-1)] - 6*G[{1}, yv^(-1)]*G[{yu^(-1)}, yw]*
      G[{0, 0, yu}, yv^(-1)] + 2*G[{1}, yw]*G[{yu^(-1)}, yw]*
      G[{0, 0, yu}, yv^(-1)] + 3*G[{yu^(-1)}, yw]^2*G[{0, 0, yu}, yv^(-1)] + 
     2*G[{1}, yv^(-1)]*G[{yu}, yv^(-1)]*G[{0, 0, yu}, yv^(-1)] - 
     2*G[{yu^(-1)}, yw]*G[{yu}, yv^(-1)]*G[{0, 0, yu}, yv^(-1)] - 
     G[{yu}, yv^(-1)]^2*G[{0, 0, yu}, yv^(-1)] - 4*G[{0}, yu^(-1)]*
      G[{1/(yu*yv)}, yw]*G[{0, 0, yu}, yv^(-1)] - 
     4*G[{0}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, 0, yu}, yv^(-1)] + 
     4*G[{0}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 0, yu}, yv^(-1)] + 
     6*G[{1}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, 0, yu}, yv^(-1)] - 
     2*G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 0, yu}, yv^(-1)] - 
     6*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 0, yu}, yv^(-1)] + 
     2*G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, 0, yu}, yv^(-1)] - 
     4*G[{0, 1}, yu^(-1)]*G[{0, 0, yu}, yv^(-1)] + 2*G[{0, 1}, yv^(-1)]*
      G[{0, 0, yu}, yv^(-1)] + 4*G[{0, yu^(-1)}, yw]*G[{0, 0, yu}, yv^(-1)] + 
     2*G[{0, yu}, yv^(-1)]*G[{0, 0, yu}, yv^(-1)] - 
     4*G[{0, 1/(yu*yv)}, yw]*G[{0, 0, yu}, yv^(-1)] - 
     2*G[{1, yu^(-1)}, yw]*G[{0, 0, yu}, yv^(-1)] - 
     2*G[{1, yu}, yv^(-1)]*G[{0, 0, yu}, yv^(-1)] + 
     2*G[{1, 1/(yu*yv)}, yw]*G[{0, 0, yu}, yv^(-1)] + 
     6*G[{yu^(-1), 1/(yu*yv)}, yw]*G[{0, 0, yu}, yv^(-1)] + 
     4*G[{1}, yu^(-1)]*G[{yu^(-1)}, yw]*G[{0, 0, yv^(-1)}, yw] - 
     4*G[{yu^(-1)}, yw]*G[{yu}, yv^(-1)]*G[{0, 0, yv^(-1)}, yw] - 
     4*G[{1}, yu^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, 0, yv^(-1)}, yw] + 
     4*G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, 0, yv^(-1)}, yw] - 
     4*G[{1}, yu^(-1)]*G[{yu^(-1)}, yw]*G[{0, 0, 1/(yu*yv)}, yw] + 
     4*G[{yu^(-1)}, yw]*G[{yu}, yv^(-1)]*G[{0, 0, 1/(yu*yv)}, yw] + 
     4*G[{1}, yu^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, 0, 1/(yu*yv)}, yw] - 
     4*G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, 0, 1/(yu*yv)}, yw] + 
     (2*Pi^2*G[{0, 1, 1}, yu^(-1)])/3 - 2*G[{1}, yu^(-1)]^2*
      G[{0, 1, 1}, yu^(-1)] + 4*G[{0}, yu^(-1)]*G[{yu^(-1)}, yw]*
      G[{0, 1, 1}, yu^(-1)] + 4*G[{0}, yv^(-1)]*G[{yu^(-1)}, yw]*
      G[{0, 1, 1}, yu^(-1)] - 4*G[{0}, yw]*G[{yu^(-1)}, yw]*
      G[{0, 1, 1}, yu^(-1)] - 4*G[{1}, yv^(-1)]*G[{yu^(-1)}, yw]*
      G[{0, 1, 1}, yu^(-1)] + 4*G[{1}, yw]*G[{yu^(-1)}, yw]*
      G[{0, 1, 1}, yu^(-1)] + 4*G[{1}, yu^(-1)]*G[{yu}, yv^(-1)]*
      G[{0, 1, 1}, yu^(-1)] - 4*G[{1}, yv^(-1)]*G[{yu}, yv^(-1)]*
      G[{0, 1, 1}, yu^(-1)] - 4*G[{yu^(-1)}, yw]*G[{yu}, yv^(-1)]*
      G[{0, 1, 1}, yu^(-1)] - 4*G[{0}, yu^(-1)]*G[{1/(yu*yv)}, yw]*
      G[{0, 1, 1}, yu^(-1)] - 4*G[{0}, yv^(-1)]*G[{1/(yu*yv)}, yw]*
      G[{0, 1, 1}, yu^(-1)] + 4*G[{0}, yw]*G[{1/(yu*yv)}, yw]*
      G[{0, 1, 1}, yu^(-1)] + 4*G[{1}, yv^(-1)]*G[{1/(yu*yv)}, yw]*
      G[{0, 1, 1}, yu^(-1)] - 4*G[{1}, yw]*G[{1/(yu*yv)}, yw]*
      G[{0, 1, 1}, yu^(-1)] + 4*G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw]*
      G[{0, 1, 1}, yu^(-1)] - 2*G[{1/(yu*yv)}, yw]^2*G[{0, 1, 1}, yu^(-1)] + 
     4*G[{0, 1}, yu^(-1)]*G[{0, 1, 1}, yu^(-1)] + 4*G[{0, 1}, yv^(-1)]*
      G[{0, 1, 1}, yu^(-1)] + 4*G[{0, yu^(-1)}, yw]*G[{0, 1, 1}, yu^(-1)] - 
     4*G[{0, 1/(yu*yv)}, yw]*G[{0, 1, 1}, yu^(-1)] - 
     4*G[{1, yu^(-1)}, yw]*G[{0, 1, 1}, yu^(-1)] + 4*G[{1, yu}, yv^(-1)]*
      G[{0, 1, 1}, yu^(-1)] + 4*G[{1, 1/(yu*yv)}, yw]*G[{0, 1, 1}, yu^(-1)] + 
     4*G[{yu^(-1), 1/(yu*yv)}, yw]*G[{0, 1, 1}, yu^(-1)] - 
     2*G[{1}, yu^(-1)]*G[{yu^(-1)}, yw]*G[{0, 1, 1}, yv^(-1)] + 
     2*G[{yu^(-1)}, yw]^2*G[{0, 1, 1}, yv^(-1)] - 
     2*G[{1}, yu^(-1)]*G[{yu}, yv^(-1)]*G[{0, 1, 1}, yv^(-1)] - 
     2*G[{yu}, yv^(-1)]^2*G[{0, 1, 1}, yv^(-1)] + 
     2*G[{1}, yu^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, 1, 1}, yv^(-1)] - 
     4*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1, 1}, yv^(-1)] + 
     2*G[{1/(yu*yv)}, yw]^2*G[{0, 1, 1}, yv^(-1)] - 
     4*G[{0}, yu^(-1)]*G[{yu^(-1)}, yw]*G[{0, 1, 1}, yw] - 
     4*G[{0}, yv^(-1)]*G[{yu^(-1)}, yw]*G[{0, 1, 1}, yw] + 
     4*G[{0}, yw]*G[{yu^(-1)}, yw]*G[{0, 1, 1}, yw] + 
     2*G[{1}, yu^(-1)]*G[{yu^(-1)}, yw]*G[{0, 1, 1}, yw] + 
     4*G[{1}, yv^(-1)]*G[{yu^(-1)}, yw]*G[{0, 1, 1}, yw] + 
     2*G[{yu^(-1)}, yw]*G[{yu}, yv^(-1)]*G[{0, 1, 1}, yw] + 
     4*G[{0}, yu^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, 1, 1}, yw] + 
     4*G[{0}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, 1, 1}, yw] - 
     4*G[{0}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1, 1}, yw] - 
     2*G[{1}, yu^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, 1, 1}, yw] - 
     4*G[{1}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, 1, 1}, yw] - 
     2*G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, 1, 1}, yw] - 
     (Pi^2*G[{0, 1, yu^(-1)}, yw])/3 + 2*G[{0}, yu^(-1)]*G[{1}, yu^(-1)]*
      G[{0, 1, yu^(-1)}, yw] + 2*G[{0}, yv^(-1)]*G[{1}, yu^(-1)]*
      G[{0, 1, yu^(-1)}, yw] - 2*G[{0}, yw]*G[{1}, yu^(-1)]*
      G[{0, 1, yu^(-1)}, yw] - 2*G[{1}, yu^(-1)]^2*G[{0, 1, yu^(-1)}, yw] - 
     4*G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*G[{0, 1, yu^(-1)}, yw] + 
     2*G[{0}, yu^(-1)]*G[{yu^(-1)}, yw]*G[{0, 1, yu^(-1)}, yw] + 
     2*G[{0}, yv^(-1)]*G[{yu^(-1)}, yw]*G[{0, 1, yu^(-1)}, yw] - 
     2*G[{0}, yw]*G[{yu^(-1)}, yw]*G[{0, 1, yu^(-1)}, yw] - 
     4*G[{1}, yu^(-1)]*G[{yu^(-1)}, yw]*G[{0, 1, yu^(-1)}, yw] - 
     4*G[{1}, yv^(-1)]*G[{yu^(-1)}, yw]*G[{0, 1, yu^(-1)}, yw] - 
     2*G[{0}, yu^(-1)]*G[{yu}, yv^(-1)]*G[{0, 1, yu^(-1)}, yw] - 
     2*G[{0}, yv^(-1)]*G[{yu}, yv^(-1)]*G[{0, 1, yu^(-1)}, yw] + 
     2*G[{0}, yw]*G[{yu}, yv^(-1)]*G[{0, 1, yu^(-1)}, yw] + 
     4*G[{1}, yu^(-1)]*G[{yu}, yv^(-1)]*G[{0, 1, yu^(-1)}, yw] + 
     4*G[{yu^(-1)}, yw]*G[{yu}, yv^(-1)]*G[{0, 1, yu^(-1)}, yw] - 
     2*G[{0}, yu^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, 1, yu^(-1)}, yw] - 
     2*G[{0}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, 1, yu^(-1)}, yw] + 
     2*G[{0}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1, yu^(-1)}, yw] + 
     4*G[{1}, yu^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, 1, yu^(-1)}, yw] + 
     4*G[{1}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, 1, yu^(-1)}, yw] - 
     4*G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, 1, yu^(-1)}, yw] - 
     2*G[{0, 1}, yu^(-1)]*G[{0, 1, yu^(-1)}, yw] + 2*G[{0, 1}, yv^(-1)]*
      G[{0, 1, yu^(-1)}, yw] + 2*G[{0, 1}, yw]*G[{0, 1, yu^(-1)}, yw] - 
     2*G[{0, yu}, yv^(-1)]*G[{0, 1, yu^(-1)}, yw] + 
     4*G[{1, yu}, yv^(-1)]*G[{0, 1, yu^(-1)}, yw] + 
     (4*Pi^2*G[{0, 1, yu}, yv^(-1)])/3 - 2*G[{1}, yu^(-1)]^2*
      G[{0, 1, yu}, yv^(-1)] - 4*G[{0}, yu^(-1)]*G[{yu^(-1)}, yw]*
      G[{0, 1, yu}, yv^(-1)] - 4*G[{0}, yv^(-1)]*G[{yu^(-1)}, yw]*
      G[{0, 1, yu}, yv^(-1)] + 4*G[{0}, yw]*G[{yu^(-1)}, yw]*
      G[{0, 1, yu}, yv^(-1)] + 6*G[{1}, yv^(-1)]*G[{yu^(-1)}, yw]*
      G[{0, 1, yu}, yv^(-1)] - 2*G[{1}, yw]*G[{yu^(-1)}, yw]*
      G[{0, 1, yu}, yv^(-1)] - 5*G[{yu^(-1)}, yw]^2*G[{0, 1, yu}, yv^(-1)] - 
     2*G[{1}, yv^(-1)]*G[{yu}, yv^(-1)]*G[{0, 1, yu}, yv^(-1)] + 
     2*G[{yu^(-1)}, yw]*G[{yu}, yv^(-1)]*G[{0, 1, yu}, yv^(-1)] + 
     3*G[{yu}, yv^(-1)]^2*G[{0, 1, yu}, yv^(-1)] + 
     4*G[{0}, yu^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, 1, yu}, yv^(-1)] + 
     4*G[{0}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, 1, yu}, yv^(-1)] - 
     4*G[{0}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1, yu}, yv^(-1)] - 
     6*G[{1}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, 1, yu}, yv^(-1)] + 
     2*G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1, yu}, yv^(-1)] + 
     10*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1, yu}, yv^(-1)] - 
     2*G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, 1, yu}, yv^(-1)] - 
     2*G[{1/(yu*yv)}, yw]^2*G[{0, 1, yu}, yv^(-1)] + 
     4*G[{0, 1}, yu^(-1)]*G[{0, 1, yu}, yv^(-1)] - 2*G[{0, 1}, yv^(-1)]*
      G[{0, 1, yu}, yv^(-1)] - 4*G[{0, yu^(-1)}, yw]*G[{0, 1, yu}, yv^(-1)] - 
     2*G[{0, yu}, yv^(-1)]*G[{0, 1, yu}, yv^(-1)] + 
     4*G[{0, 1/(yu*yv)}, yw]*G[{0, 1, yu}, yv^(-1)] + 
     2*G[{1, yu^(-1)}, yw]*G[{0, 1, yu}, yv^(-1)] + 
     2*G[{1, yu}, yv^(-1)]*G[{0, 1, yu}, yv^(-1)] - 
     2*G[{1, 1/(yu*yv)}, yw]*G[{0, 1, yu}, yv^(-1)] - 
     6*G[{yu^(-1), 1/(yu*yv)}, yw]*G[{0, 1, yu}, yv^(-1)] + 
     4*G[{0}, yu^(-1)]*G[{yu^(-1)}, yw]*G[{0, 1, yv^(-1)}, yw] + 
     4*G[{0}, yv^(-1)]*G[{yu^(-1)}, yw]*G[{0, 1, yv^(-1)}, yw] - 
     4*G[{0}, yw]*G[{yu^(-1)}, yw]*G[{0, 1, yv^(-1)}, yw] - 
     8*G[{1}, yu^(-1)]*G[{yu^(-1)}, yw]*G[{0, 1, yv^(-1)}, yw] - 
     4*G[{1}, yv^(-1)]*G[{yu^(-1)}, yw]*G[{0, 1, yv^(-1)}, yw] + 
     4*G[{yu^(-1)}, yw]*G[{yu}, yv^(-1)]*G[{0, 1, yv^(-1)}, yw] - 
     4*G[{0}, yu^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, 1, yv^(-1)}, yw] - 
     4*G[{0}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, 1, yv^(-1)}, yw] + 
     4*G[{0}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1, yv^(-1)}, yw] + 
     8*G[{1}, yu^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, 1, yv^(-1)}, yw] + 
     4*G[{1}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, 1, yv^(-1)}, yw] - 
     4*G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, 1, yv^(-1)}, yw] - 
     2*G[{0, yu^(-1)}, yw]*G[{0, 1, yv^(-1)}, yw] + 
     (Pi^2*G[{0, 1, 1/(yu*yv)}, yw])/3 - 2*G[{0}, yu^(-1)]*G[{1}, yu^(-1)]*
      G[{0, 1, 1/(yu*yv)}, yw] - 2*G[{0}, yv^(-1)]*G[{1}, yu^(-1)]*
      G[{0, 1, 1/(yu*yv)}, yw] + 2*G[{0}, yw]*G[{1}, yu^(-1)]*
      G[{0, 1, 1/(yu*yv)}, yw] + 2*G[{1}, yu^(-1)]^2*
      G[{0, 1, 1/(yu*yv)}, yw] + 4*G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*
      G[{0, 1, 1/(yu*yv)}, yw] - 2*G[{0}, yu^(-1)]*G[{yu^(-1)}, yw]*
      G[{0, 1, 1/(yu*yv)}, yw] - 2*G[{0}, yv^(-1)]*G[{yu^(-1)}, yw]*
      G[{0, 1, 1/(yu*yv)}, yw] + 2*G[{0}, yw]*G[{yu^(-1)}, yw]*
      G[{0, 1, 1/(yu*yv)}, yw] + 2*G[{1}, yu^(-1)]*G[{yu^(-1)}, yw]*
      G[{0, 1, 1/(yu*yv)}, yw] + 4*G[{1}, yv^(-1)]*G[{yu^(-1)}, yw]*
      G[{0, 1, 1/(yu*yv)}, yw] + 2*G[{0}, yu^(-1)]*G[{yu}, yv^(-1)]*
      G[{0, 1, 1/(yu*yv)}, yw] + 2*G[{0}, yv^(-1)]*G[{yu}, yv^(-1)]*
      G[{0, 1, 1/(yu*yv)}, yw] - 2*G[{0}, yw]*G[{yu}, yv^(-1)]*
      G[{0, 1, 1/(yu*yv)}, yw] - 4*G[{1}, yu^(-1)]*G[{yu}, yv^(-1)]*
      G[{0, 1, 1/(yu*yv)}, yw] - 2*G[{yu^(-1)}, yw]*G[{yu}, yv^(-1)]*
      G[{0, 1, 1/(yu*yv)}, yw] + 2*G[{0}, yu^(-1)]*G[{1/(yu*yv)}, yw]*
      G[{0, 1, 1/(yu*yv)}, yw] + 2*G[{0}, yv^(-1)]*G[{1/(yu*yv)}, yw]*
      G[{0, 1, 1/(yu*yv)}, yw] - 2*G[{0}, yw]*G[{1/(yu*yv)}, yw]*
      G[{0, 1, 1/(yu*yv)}, yw] - 2*G[{1}, yu^(-1)]*G[{1/(yu*yv)}, yw]*
      G[{0, 1, 1/(yu*yv)}, yw] - 4*G[{1}, yv^(-1)]*G[{1/(yu*yv)}, yw]*
      G[{0, 1, 1/(yu*yv)}, yw] + 2*G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw]*
      G[{0, 1, 1/(yu*yv)}, yw] + 2*G[{0, 1}, yu^(-1)]*
      G[{0, 1, 1/(yu*yv)}, yw] - 2*G[{0, 1}, yv^(-1)]*
      G[{0, 1, 1/(yu*yv)}, yw] - 2*G[{0, 1}, yw]*G[{0, 1, 1/(yu*yv)}, yw] + 
     2*G[{0, yu^(-1)}, yw]*G[{0, 1, 1/(yu*yv)}, yw] + 
     2*G[{0, yu}, yv^(-1)]*G[{0, 1, 1/(yu*yv)}, yw] - 
     4*G[{1, yu}, yv^(-1)]*G[{0, 1, 1/(yu*yv)}, yw] - 
     (Pi^2*G[{0, yu^(-1), 1}, yw])/3 + 2*G[{0}, yu^(-1)]*G[{1}, yu^(-1)]*
      G[{0, yu^(-1), 1}, yw] + 2*G[{0}, yv^(-1)]*G[{1}, yu^(-1)]*
      G[{0, yu^(-1), 1}, yw] - 2*G[{0}, yw]*G[{1}, yu^(-1)]*
      G[{0, yu^(-1), 1}, yw] - 2*G[{1}, yu^(-1)]^2*G[{0, yu^(-1), 1}, yw] - 
     4*G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*G[{0, yu^(-1), 1}, yw] + 
     2*G[{0}, yu^(-1)]*G[{yu^(-1)}, yw]*G[{0, yu^(-1), 1}, yw] + 
     2*G[{0}, yv^(-1)]*G[{yu^(-1)}, yw]*G[{0, yu^(-1), 1}, yw] - 
     2*G[{0}, yw]*G[{yu^(-1)}, yw]*G[{0, yu^(-1), 1}, yw] - 
     2*G[{1}, yu^(-1)]*G[{yu^(-1)}, yw]*G[{0, yu^(-1), 1}, yw] - 
     4*G[{1}, yv^(-1)]*G[{yu^(-1)}, yw]*G[{0, yu^(-1), 1}, yw] - 
     2*G[{0}, yu^(-1)]*G[{yu}, yv^(-1)]*G[{0, yu^(-1), 1}, yw] - 
     2*G[{0}, yv^(-1)]*G[{yu}, yv^(-1)]*G[{0, yu^(-1), 1}, yw] + 
     2*G[{0}, yw]*G[{yu}, yv^(-1)]*G[{0, yu^(-1), 1}, yw] + 
     4*G[{1}, yu^(-1)]*G[{yu}, yv^(-1)]*G[{0, yu^(-1), 1}, yw] + 
     2*G[{yu^(-1)}, yw]*G[{yu}, yv^(-1)]*G[{0, yu^(-1), 1}, yw] - 
     2*G[{0}, yu^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1), 1}, yw] - 
     2*G[{0}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1), 1}, yw] + 
     2*G[{0}, yw]*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1), 1}, yw] + 
     2*G[{1}, yu^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1), 1}, yw] + 
     4*G[{1}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1), 1}, yw] - 
     2*G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1), 1}, yw] - 
     2*G[{0, 1}, yu^(-1)]*G[{0, yu^(-1), 1}, yw] + 2*G[{0, 1}, yv^(-1)]*
      G[{0, yu^(-1), 1}, yw] + 2*G[{0, 1}, yw]*G[{0, yu^(-1), 1}, yw] - 
     2*G[{0, yu^(-1)}, yw]*G[{0, yu^(-1), 1}, yw] - 
     2*G[{0, yu}, yv^(-1)]*G[{0, yu^(-1), 1}, yw] + 
     4*G[{1, yu}, yv^(-1)]*G[{0, yu^(-1), 1}, yw] - 
     4*G[{0}, yu^(-1)]*G[{1}, yu^(-1)]*G[{0, yu^(-1), yu^(-1)}, yw] - 
     4*G[{0}, yv^(-1)]*G[{1}, yu^(-1)]*G[{0, yu^(-1), yu^(-1)}, yw] + 
     4*G[{0}, yw]*G[{1}, yu^(-1)]*G[{0, yu^(-1), yu^(-1)}, yw] + 
     4*G[{1}, yu^(-1)]^2*G[{0, yu^(-1), yu^(-1)}, yw] + 
     4*G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*G[{0, yu^(-1), yu^(-1)}, yw] + 
     4*G[{1}, yu^(-1)]*G[{yu^(-1)}, yw]*G[{0, yu^(-1), yu^(-1)}, yw] + 
     4*G[{0}, yu^(-1)]*G[{yu}, yv^(-1)]*G[{0, yu^(-1), yu^(-1)}, yw] + 
     4*G[{0}, yv^(-1)]*G[{yu}, yv^(-1)]*G[{0, yu^(-1), yu^(-1)}, yw] - 
     4*G[{0}, yw]*G[{yu}, yv^(-1)]*G[{0, yu^(-1), yu^(-1)}, yw] - 
     4*G[{1}, yu^(-1)]*G[{yu}, yv^(-1)]*G[{0, yu^(-1), yu^(-1)}, yw] - 
     4*G[{1}, yv^(-1)]*G[{yu}, yv^(-1)]*G[{0, yu^(-1), yu^(-1)}, yw] - 
     4*G[{yu^(-1)}, yw]*G[{yu}, yv^(-1)]*G[{0, yu^(-1), yu^(-1)}, yw] - 
     4*G[{1}, yu^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1), yu^(-1)}, yw] + 
     4*G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1), yu^(-1)}, yw] + 
     (Pi^2*G[{0, yu^(-1), yv^(-1)}, yw])/3 - 2*G[{0}, yu^(-1)]*
      G[{1}, yu^(-1)]*G[{0, yu^(-1), yv^(-1)}, yw] - 
     2*G[{0}, yv^(-1)]*G[{1}, yu^(-1)]*G[{0, yu^(-1), yv^(-1)}, yw] + 
     2*G[{0}, yw]*G[{1}, yu^(-1)]*G[{0, yu^(-1), yv^(-1)}, yw] + 
     2*G[{1}, yu^(-1)]^2*G[{0, yu^(-1), yv^(-1)}, yw] + 
     4*G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*G[{0, yu^(-1), yv^(-1)}, yw] - 
     2*G[{0}, yu^(-1)]*G[{yu^(-1)}, yw]*G[{0, yu^(-1), yv^(-1)}, yw] - 
     2*G[{0}, yv^(-1)]*G[{yu^(-1)}, yw]*G[{0, yu^(-1), yv^(-1)}, yw] + 
     2*G[{0}, yw]*G[{yu^(-1)}, yw]*G[{0, yu^(-1), yv^(-1)}, yw] + 
     4*G[{1}, yu^(-1)]*G[{yu^(-1)}, yw]*G[{0, yu^(-1), yv^(-1)}, yw] + 
     4*G[{1}, yv^(-1)]*G[{yu^(-1)}, yw]*G[{0, yu^(-1), yv^(-1)}, yw] + 
     2*G[{0}, yu^(-1)]*G[{yu}, yv^(-1)]*G[{0, yu^(-1), yv^(-1)}, yw] + 
     2*G[{0}, yv^(-1)]*G[{yu}, yv^(-1)]*G[{0, yu^(-1), yv^(-1)}, yw] - 
     2*G[{0}, yw]*G[{yu}, yv^(-1)]*G[{0, yu^(-1), yv^(-1)}, yw] - 
     4*G[{1}, yu^(-1)]*G[{yu}, yv^(-1)]*G[{0, yu^(-1), yv^(-1)}, yw] - 
     4*G[{yu^(-1)}, yw]*G[{yu}, yv^(-1)]*G[{0, yu^(-1), yv^(-1)}, yw] + 
     2*G[{0}, yu^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1), yv^(-1)}, yw] + 
     2*G[{0}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1), yv^(-1)}, yw] - 
     2*G[{0}, yw]*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1), yv^(-1)}, yw] - 
     4*G[{1}, yu^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1), yv^(-1)}, yw] - 
     4*G[{1}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1), yv^(-1)}, yw] + 
     4*G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1), yv^(-1)}, yw] + 
     2*G[{0, 1}, yu^(-1)]*G[{0, yu^(-1), yv^(-1)}, yw] - 
     2*G[{0, 1}, yv^(-1)]*G[{0, yu^(-1), yv^(-1)}, yw] - 
     2*G[{0, 1}, yw]*G[{0, yu^(-1), yv^(-1)}, yw] + 
     2*G[{0, yu^(-1)}, yw]*G[{0, yu^(-1), yv^(-1)}, yw] + 
     2*G[{0, yu}, yv^(-1)]*G[{0, yu^(-1), yv^(-1)}, yw] - 
     4*G[{1, yu}, yv^(-1)]*G[{0, yu^(-1), yv^(-1)}, yw] + 
     4*G[{0}, yu^(-1)]*G[{1}, yu^(-1)]*G[{0, yu^(-1), 1/(yu*yv)}, yw] + 
     4*G[{0}, yv^(-1)]*G[{1}, yu^(-1)]*G[{0, yu^(-1), 1/(yu*yv)}, yw] - 
     4*G[{0}, yw]*G[{1}, yu^(-1)]*G[{0, yu^(-1), 1/(yu*yv)}, yw] - 
     4*G[{1}, yu^(-1)]^2*G[{0, yu^(-1), 1/(yu*yv)}, yw] - 
     4*G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*G[{0, yu^(-1), 1/(yu*yv)}, yw] + 
     2*G[{1}, yu^(-1)]*G[{yu^(-1)}, yw]*G[{0, yu^(-1), 1/(yu*yv)}, yw] - 
     4*G[{0}, yu^(-1)]*G[{yu}, yv^(-1)]*G[{0, yu^(-1), 1/(yu*yv)}, yw] - 
     4*G[{0}, yv^(-1)]*G[{yu}, yv^(-1)]*G[{0, yu^(-1), 1/(yu*yv)}, yw] + 
     4*G[{0}, yw]*G[{yu}, yv^(-1)]*G[{0, yu^(-1), 1/(yu*yv)}, yw] + 
     4*G[{1}, yu^(-1)]*G[{yu}, yv^(-1)]*G[{0, yu^(-1), 1/(yu*yv)}, yw] + 
     4*G[{1}, yv^(-1)]*G[{yu}, yv^(-1)]*G[{0, yu^(-1), 1/(yu*yv)}, yw] - 
     2*G[{yu^(-1)}, yw]*G[{yu}, yv^(-1)]*G[{0, yu^(-1), 1/(yu*yv)}, yw] - 
     2*G[{1}, yu^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1), 1/(yu*yv)}, yw] + 
     2*G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1), 1/(yu*yv)}, yw] - 
     2*G[{0, yv^(-1)}, yw]*G[{0, yu^(-1), 1/(yu*yv)}, yw] + 
     2*G[{1}, yu^(-1)]*G[{yu^(-1)}, yw]*G[{0, yu, 1}, yv^(-1)] - 
     2*G[{yu^(-1)}, yw]^2*G[{0, yu, 1}, yv^(-1)] + 
     2*G[{1}, yu^(-1)]*G[{yu}, yv^(-1)]*G[{0, yu, 1}, yv^(-1)] + 
     2*G[{yu}, yv^(-1)]^2*G[{0, yu, 1}, yv^(-1)] - 
     2*G[{1}, yu^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, yu, 1}, yv^(-1)] + 
     4*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{0, yu, 1}, yv^(-1)] - 
     2*G[{1/(yu*yv)}, yw]^2*G[{0, yu, 1}, yv^(-1)] - 
     (4*Pi^2*G[{0, yu, yu}, yv^(-1)])/3 + 2*G[{1}, yu^(-1)]^2*
      G[{0, yu, yu}, yv^(-1)] + 4*G[{0}, yu^(-1)]*G[{yu^(-1)}, yw]*
      G[{0, yu, yu}, yv^(-1)] + 4*G[{0}, yv^(-1)]*G[{yu^(-1)}, yw]*
      G[{0, yu, yu}, yv^(-1)] - 4*G[{0}, yw]*G[{yu^(-1)}, yw]*
      G[{0, yu, yu}, yv^(-1)] - 6*G[{1}, yv^(-1)]*G[{yu^(-1)}, yw]*
      G[{0, yu, yu}, yv^(-1)] + 2*G[{1}, yw]*G[{yu^(-1)}, yw]*
      G[{0, yu, yu}, yv^(-1)] + 5*G[{yu^(-1)}, yw]^2*
      G[{0, yu, yu}, yv^(-1)] + 2*G[{1}, yv^(-1)]*G[{yu}, yv^(-1)]*
      G[{0, yu, yu}, yv^(-1)] - 2*G[{yu^(-1)}, yw]*G[{yu}, yv^(-1)]*
      G[{0, yu, yu}, yv^(-1)] - 3*G[{yu}, yv^(-1)]^2*
      G[{0, yu, yu}, yv^(-1)] - 4*G[{0}, yu^(-1)]*G[{1/(yu*yv)}, yw]*
      G[{0, yu, yu}, yv^(-1)] - 4*G[{0}, yv^(-1)]*G[{1/(yu*yv)}, yw]*
      G[{0, yu, yu}, yv^(-1)] + 4*G[{0}, yw]*G[{1/(yu*yv)}, yw]*
      G[{0, yu, yu}, yv^(-1)] + 6*G[{1}, yv^(-1)]*G[{1/(yu*yv)}, yw]*
      G[{0, yu, yu}, yv^(-1)] - 2*G[{1}, yw]*G[{1/(yu*yv)}, yw]*
      G[{0, yu, yu}, yv^(-1)] - 10*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*
      G[{0, yu, yu}, yv^(-1)] + 2*G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw]*
      G[{0, yu, yu}, yv^(-1)] + 2*G[{1/(yu*yv)}, yw]^2*
      G[{0, yu, yu}, yv^(-1)] - 4*G[{0, 1}, yu^(-1)]*
      G[{0, yu, yu}, yv^(-1)] + 2*G[{0, 1}, yv^(-1)]*
      G[{0, yu, yu}, yv^(-1)] + 4*G[{0, yu^(-1)}, yw]*
      G[{0, yu, yu}, yv^(-1)] - 2*G[{0, yu}, yv^(-1)]*
      G[{0, yu, yu}, yv^(-1)] - 4*G[{0, 1/(yu*yv)}, yw]*
      G[{0, yu, yu}, yv^(-1)] - 2*G[{1, yu^(-1)}, yw]*
      G[{0, yu, yu}, yv^(-1)] - 2*G[{1, yu}, yv^(-1)]*
      G[{0, yu, yu}, yv^(-1)] + 2*G[{1, 1/(yu*yv)}, yw]*
      G[{0, yu, yu}, yv^(-1)] + 6*G[{yu^(-1), 1/(yu*yv)}, yw]*
      G[{0, yu, yu}, yv^(-1)] + 4*G[{0}, yu^(-1)]*G[{yu^(-1)}, yw]*
      G[{0, yv^(-1), 1}, yw] + 4*G[{0}, yv^(-1)]*G[{yu^(-1)}, yw]*
      G[{0, yv^(-1), 1}, yw] - 4*G[{0}, yw]*G[{yu^(-1)}, yw]*
      G[{0, yv^(-1), 1}, yw] - 2*G[{1}, yu^(-1)]*G[{yu^(-1)}, yw]*
      G[{0, yv^(-1), 1}, yw] - 4*G[{1}, yv^(-1)]*G[{yu^(-1)}, yw]*
      G[{0, yv^(-1), 1}, yw] - 2*G[{yu^(-1)}, yw]*G[{yu}, yv^(-1)]*
      G[{0, yv^(-1), 1}, yw] - 4*G[{0}, yu^(-1)]*G[{1/(yu*yv)}, yw]*
      G[{0, yv^(-1), 1}, yw] - 4*G[{0}, yv^(-1)]*G[{1/(yu*yv)}, yw]*
      G[{0, yv^(-1), 1}, yw] + 4*G[{0}, yw]*G[{1/(yu*yv)}, yw]*
      G[{0, yv^(-1), 1}, yw] + 2*G[{1}, yu^(-1)]*G[{1/(yu*yv)}, yw]*
      G[{0, yv^(-1), 1}, yw] + 4*G[{1}, yv^(-1)]*G[{1/(yu*yv)}, yw]*
      G[{0, yv^(-1), 1}, yw] + 2*G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw]*
      G[{0, yv^(-1), 1}, yw] + (Pi^2*G[{0, yv^(-1), yu^(-1)}, yw])/3 - 
     2*G[{0}, yu^(-1)]*G[{1}, yu^(-1)]*G[{0, yv^(-1), yu^(-1)}, yw] - 
     2*G[{0}, yv^(-1)]*G[{1}, yu^(-1)]*G[{0, yv^(-1), yu^(-1)}, yw] + 
     2*G[{0}, yw]*G[{1}, yu^(-1)]*G[{0, yv^(-1), yu^(-1)}, yw] + 
     2*G[{1}, yu^(-1)]^2*G[{0, yv^(-1), yu^(-1)}, yw] + 
     4*G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*G[{0, yv^(-1), yu^(-1)}, yw] - 
     2*G[{0}, yu^(-1)]*G[{yu^(-1)}, yw]*G[{0, yv^(-1), yu^(-1)}, yw] - 
     2*G[{0}, yv^(-1)]*G[{yu^(-1)}, yw]*G[{0, yv^(-1), yu^(-1)}, yw] + 
     2*G[{0}, yw]*G[{yu^(-1)}, yw]*G[{0, yv^(-1), yu^(-1)}, yw] + 
     4*G[{1}, yu^(-1)]*G[{yu^(-1)}, yw]*G[{0, yv^(-1), yu^(-1)}, yw] + 
     4*G[{1}, yv^(-1)]*G[{yu^(-1)}, yw]*G[{0, yv^(-1), yu^(-1)}, yw] + 
     2*G[{0}, yu^(-1)]*G[{yu}, yv^(-1)]*G[{0, yv^(-1), yu^(-1)}, yw] + 
     2*G[{0}, yv^(-1)]*G[{yu}, yv^(-1)]*G[{0, yv^(-1), yu^(-1)}, yw] - 
     2*G[{0}, yw]*G[{yu}, yv^(-1)]*G[{0, yv^(-1), yu^(-1)}, yw] - 
     4*G[{1}, yu^(-1)]*G[{yu}, yv^(-1)]*G[{0, yv^(-1), yu^(-1)}, yw] - 
     4*G[{yu^(-1)}, yw]*G[{yu}, yv^(-1)]*G[{0, yv^(-1), yu^(-1)}, yw] + 
     2*G[{0}, yu^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, yv^(-1), yu^(-1)}, yw] + 
     2*G[{0}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, yv^(-1), yu^(-1)}, yw] - 
     2*G[{0}, yw]*G[{1/(yu*yv)}, yw]*G[{0, yv^(-1), yu^(-1)}, yw] - 
     4*G[{1}, yu^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, yv^(-1), yu^(-1)}, yw] - 
     4*G[{1}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, yv^(-1), yu^(-1)}, yw] + 
     4*G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, yv^(-1), yu^(-1)}, yw] + 
     2*G[{0, 1}, yu^(-1)]*G[{0, yv^(-1), yu^(-1)}, yw] - 
     2*G[{0, 1}, yv^(-1)]*G[{0, yv^(-1), yu^(-1)}, yw] - 
     2*G[{0, 1}, yw]*G[{0, yv^(-1), yu^(-1)}, yw] + 
     2*G[{0, yu^(-1)}, yw]*G[{0, yv^(-1), yu^(-1)}, yw] + 
     2*G[{0, yu}, yv^(-1)]*G[{0, yv^(-1), yu^(-1)}, yw] + 
     2*G[{0, yv^(-1)}, yw]*G[{0, yv^(-1), yu^(-1)}, yw] - 
     4*G[{1, yu}, yv^(-1)]*G[{0, yv^(-1), yu^(-1)}, yw] - 
     4*G[{0}, yu^(-1)]*G[{yu^(-1)}, yw]*G[{0, yv^(-1), yv^(-1)}, yw] - 
     4*G[{0}, yv^(-1)]*G[{yu^(-1)}, yw]*G[{0, yv^(-1), yv^(-1)}, yw] + 
     4*G[{0}, yw]*G[{yu^(-1)}, yw]*G[{0, yv^(-1), yv^(-1)}, yw] + 
     8*G[{1}, yu^(-1)]*G[{yu^(-1)}, yw]*G[{0, yv^(-1), yv^(-1)}, yw] + 
     4*G[{1}, yv^(-1)]*G[{yu^(-1)}, yw]*G[{0, yv^(-1), yv^(-1)}, yw] - 
     4*G[{yu^(-1)}, yw]*G[{yu}, yv^(-1)]*G[{0, yv^(-1), yv^(-1)}, yw] + 
     4*G[{0}, yu^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, yv^(-1), yv^(-1)}, yw] + 
     4*G[{0}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, yv^(-1), yv^(-1)}, yw] - 
     4*G[{0}, yw]*G[{1/(yu*yv)}, yw]*G[{0, yv^(-1), yv^(-1)}, yw] - 
     8*G[{1}, yu^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, yv^(-1), yv^(-1)}, yw] - 
     4*G[{1}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, yv^(-1), yv^(-1)}, yw] + 
     4*G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, yv^(-1), yv^(-1)}, yw] - 
     (Pi^2*G[{0, yv^(-1), 1/(yu*yv)}, yw])/3 + 2*G[{0}, yu^(-1)]*
      G[{1}, yu^(-1)]*G[{0, yv^(-1), 1/(yu*yv)}, yw] + 
     2*G[{0}, yv^(-1)]*G[{1}, yu^(-1)]*G[{0, yv^(-1), 1/(yu*yv)}, yw] - 
     2*G[{0}, yw]*G[{1}, yu^(-1)]*G[{0, yv^(-1), 1/(yu*yv)}, yw] - 
     2*G[{1}, yu^(-1)]^2*G[{0, yv^(-1), 1/(yu*yv)}, yw] - 
     4*G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*G[{0, yv^(-1), 1/(yu*yv)}, yw] + 
     2*G[{0}, yu^(-1)]*G[{yu^(-1)}, yw]*G[{0, yv^(-1), 1/(yu*yv)}, yw] + 
     2*G[{0}, yv^(-1)]*G[{yu^(-1)}, yw]*G[{0, yv^(-1), 1/(yu*yv)}, yw] - 
     2*G[{0}, yw]*G[{yu^(-1)}, yw]*G[{0, yv^(-1), 1/(yu*yv)}, yw] - 
     2*G[{1}, yu^(-1)]*G[{yu^(-1)}, yw]*G[{0, yv^(-1), 1/(yu*yv)}, yw] - 
     4*G[{1}, yv^(-1)]*G[{yu^(-1)}, yw]*G[{0, yv^(-1), 1/(yu*yv)}, yw] - 
     2*G[{0}, yu^(-1)]*G[{yu}, yv^(-1)]*G[{0, yv^(-1), 1/(yu*yv)}, yw] - 
     2*G[{0}, yv^(-1)]*G[{yu}, yv^(-1)]*G[{0, yv^(-1), 1/(yu*yv)}, yw] + 
     2*G[{0}, yw]*G[{yu}, yv^(-1)]*G[{0, yv^(-1), 1/(yu*yv)}, yw] + 
     4*G[{1}, yu^(-1)]*G[{yu}, yv^(-1)]*G[{0, yv^(-1), 1/(yu*yv)}, yw] + 
     2*G[{yu^(-1)}, yw]*G[{yu}, yv^(-1)]*G[{0, yv^(-1), 1/(yu*yv)}, yw] - 
     2*G[{0}, yu^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, yv^(-1), 1/(yu*yv)}, yw] - 
     2*G[{0}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, yv^(-1), 1/(yu*yv)}, yw] + 
     2*G[{0}, yw]*G[{1/(yu*yv)}, yw]*G[{0, yv^(-1), 1/(yu*yv)}, yw] + 
     2*G[{1}, yu^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, yv^(-1), 1/(yu*yv)}, yw] + 
     4*G[{1}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, yv^(-1), 1/(yu*yv)}, yw] - 
     2*G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, yv^(-1), 1/(yu*yv)}, yw] - 
     2*G[{0, 1}, yu^(-1)]*G[{0, yv^(-1), 1/(yu*yv)}, yw] + 
     2*G[{0, 1}, yv^(-1)]*G[{0, yv^(-1), 1/(yu*yv)}, yw] + 
     2*G[{0, 1}, yw]*G[{0, yv^(-1), 1/(yu*yv)}, yw] - 
     2*G[{0, yu^(-1)}, yw]*G[{0, yv^(-1), 1/(yu*yv)}, yw] - 
     2*G[{0, yu}, yv^(-1)]*G[{0, yv^(-1), 1/(yu*yv)}, yw] - 
     2*G[{0, yv^(-1)}, yw]*G[{0, yv^(-1), 1/(yu*yv)}, yw] + 
     4*G[{1, yu}, yv^(-1)]*G[{0, yv^(-1), 1/(yu*yv)}, yw] + 
     (Pi^2*G[{0, 1/(yu*yv), 1}, yw])/3 - 2*G[{0}, yu^(-1)]*G[{1}, yu^(-1)]*
      G[{0, 1/(yu*yv), 1}, yw] - 2*G[{0}, yv^(-1)]*G[{1}, yu^(-1)]*
      G[{0, 1/(yu*yv), 1}, yw] + 2*G[{0}, yw]*G[{1}, yu^(-1)]*
      G[{0, 1/(yu*yv), 1}, yw] + 2*G[{1}, yu^(-1)]^2*
      G[{0, 1/(yu*yv), 1}, yw] + 4*G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*
      G[{0, 1/(yu*yv), 1}, yw] - 2*G[{0}, yu^(-1)]*G[{yu^(-1)}, yw]*
      G[{0, 1/(yu*yv), 1}, yw] - 2*G[{0}, yv^(-1)]*G[{yu^(-1)}, yw]*
      G[{0, 1/(yu*yv), 1}, yw] + 2*G[{0}, yw]*G[{yu^(-1)}, yw]*
      G[{0, 1/(yu*yv), 1}, yw] + 2*G[{1}, yu^(-1)]*G[{yu^(-1)}, yw]*
      G[{0, 1/(yu*yv), 1}, yw] + 4*G[{1}, yv^(-1)]*G[{yu^(-1)}, yw]*
      G[{0, 1/(yu*yv), 1}, yw] + 2*G[{0}, yu^(-1)]*G[{yu}, yv^(-1)]*
      G[{0, 1/(yu*yv), 1}, yw] + 2*G[{0}, yv^(-1)]*G[{yu}, yv^(-1)]*
      G[{0, 1/(yu*yv), 1}, yw] - 2*G[{0}, yw]*G[{yu}, yv^(-1)]*
      G[{0, 1/(yu*yv), 1}, yw] - 4*G[{1}, yu^(-1)]*G[{yu}, yv^(-1)]*
      G[{0, 1/(yu*yv), 1}, yw] - 2*G[{yu^(-1)}, yw]*G[{yu}, yv^(-1)]*
      G[{0, 1/(yu*yv), 1}, yw] + 2*G[{0}, yu^(-1)]*G[{1/(yu*yv)}, yw]*
      G[{0, 1/(yu*yv), 1}, yw] + 2*G[{0}, yv^(-1)]*G[{1/(yu*yv)}, yw]*
      G[{0, 1/(yu*yv), 1}, yw] - 2*G[{0}, yw]*G[{1/(yu*yv)}, yw]*
      G[{0, 1/(yu*yv), 1}, yw] - 2*G[{1}, yu^(-1)]*G[{1/(yu*yv)}, yw]*
      G[{0, 1/(yu*yv), 1}, yw] - 4*G[{1}, yv^(-1)]*G[{1/(yu*yv)}, yw]*
      G[{0, 1/(yu*yv), 1}, yw] + 2*G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw]*
      G[{0, 1/(yu*yv), 1}, yw] + 2*G[{0, 1}, yu^(-1)]*
      G[{0, 1/(yu*yv), 1}, yw] - 2*G[{0, 1}, yv^(-1)]*
      G[{0, 1/(yu*yv), 1}, yw] - 2*G[{0, 1}, yw]*G[{0, 1/(yu*yv), 1}, yw] + 
     2*G[{0, yu^(-1)}, yw]*G[{0, 1/(yu*yv), 1}, yw] + 
     2*G[{0, yu}, yv^(-1)]*G[{0, 1/(yu*yv), 1}, yw] + 
     2*G[{0, yv^(-1)}, yw]*G[{0, 1/(yu*yv), 1}, yw] - 
     2*G[{0, 1/(yu*yv)}, yw]*G[{0, 1/(yu*yv), 1}, yw] - 
     4*G[{1, yu}, yv^(-1)]*G[{0, 1/(yu*yv), 1}, yw] + 
     4*G[{0}, yu^(-1)]*G[{1}, yu^(-1)]*G[{0, 1/(yu*yv), yu^(-1)}, yw] + 
     4*G[{0}, yv^(-1)]*G[{1}, yu^(-1)]*G[{0, 1/(yu*yv), yu^(-1)}, yw] - 
     4*G[{0}, yw]*G[{1}, yu^(-1)]*G[{0, 1/(yu*yv), yu^(-1)}, yw] - 
     4*G[{1}, yu^(-1)]^2*G[{0, 1/(yu*yv), yu^(-1)}, yw] - 
     4*G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*G[{0, 1/(yu*yv), yu^(-1)}, yw] - 
     4*G[{1}, yu^(-1)]*G[{yu^(-1)}, yw]*G[{0, 1/(yu*yv), yu^(-1)}, yw] - 
     4*G[{0}, yu^(-1)]*G[{yu}, yv^(-1)]*G[{0, 1/(yu*yv), yu^(-1)}, yw] - 
     4*G[{0}, yv^(-1)]*G[{yu}, yv^(-1)]*G[{0, 1/(yu*yv), yu^(-1)}, yw] + 
     4*G[{0}, yw]*G[{yu}, yv^(-1)]*G[{0, 1/(yu*yv), yu^(-1)}, yw] + 
     4*G[{1}, yu^(-1)]*G[{yu}, yv^(-1)]*G[{0, 1/(yu*yv), yu^(-1)}, yw] + 
     4*G[{1}, yv^(-1)]*G[{yu}, yv^(-1)]*G[{0, 1/(yu*yv), yu^(-1)}, yw] + 
     4*G[{yu^(-1)}, yw]*G[{yu}, yv^(-1)]*G[{0, 1/(yu*yv), yu^(-1)}, yw] + 
     4*G[{1}, yu^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv), yu^(-1)}, yw] - 
     4*G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv), yu^(-1)}, yw] - 
     (Pi^2*G[{0, 1/(yu*yv), yv^(-1)}, yw])/3 + 2*G[{0}, yu^(-1)]*
      G[{1}, yu^(-1)]*G[{0, 1/(yu*yv), yv^(-1)}, yw] + 
     2*G[{0}, yv^(-1)]*G[{1}, yu^(-1)]*G[{0, 1/(yu*yv), yv^(-1)}, yw] - 
     2*G[{0}, yw]*G[{1}, yu^(-1)]*G[{0, 1/(yu*yv), yv^(-1)}, yw] - 
     2*G[{1}, yu^(-1)]^2*G[{0, 1/(yu*yv), yv^(-1)}, yw] - 
     4*G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*G[{0, 1/(yu*yv), yv^(-1)}, yw] + 
     2*G[{0}, yu^(-1)]*G[{yu^(-1)}, yw]*G[{0, 1/(yu*yv), yv^(-1)}, yw] + 
     2*G[{0}, yv^(-1)]*G[{yu^(-1)}, yw]*G[{0, 1/(yu*yv), yv^(-1)}, yw] - 
     2*G[{0}, yw]*G[{yu^(-1)}, yw]*G[{0, 1/(yu*yv), yv^(-1)}, yw] - 
     4*G[{1}, yu^(-1)]*G[{yu^(-1)}, yw]*G[{0, 1/(yu*yv), yv^(-1)}, yw] - 
     4*G[{1}, yv^(-1)]*G[{yu^(-1)}, yw]*G[{0, 1/(yu*yv), yv^(-1)}, yw] - 
     2*G[{0}, yu^(-1)]*G[{yu}, yv^(-1)]*G[{0, 1/(yu*yv), yv^(-1)}, yw] - 
     2*G[{0}, yv^(-1)]*G[{yu}, yv^(-1)]*G[{0, 1/(yu*yv), yv^(-1)}, yw] + 
     2*G[{0}, yw]*G[{yu}, yv^(-1)]*G[{0, 1/(yu*yv), yv^(-1)}, yw] + 
     4*G[{1}, yu^(-1)]*G[{yu}, yv^(-1)]*G[{0, 1/(yu*yv), yv^(-1)}, yw] + 
     4*G[{yu^(-1)}, yw]*G[{yu}, yv^(-1)]*G[{0, 1/(yu*yv), yv^(-1)}, yw] - 
     2*G[{0}, yu^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv), yv^(-1)}, yw] - 
     2*G[{0}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv), yv^(-1)}, yw] + 
     2*G[{0}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv), yv^(-1)}, yw] + 
     4*G[{1}, yu^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv), yv^(-1)}, yw] + 
     4*G[{1}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv), yv^(-1)}, yw] - 
     4*G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv), yv^(-1)}, yw] - 
     2*G[{0, 1}, yu^(-1)]*G[{0, 1/(yu*yv), yv^(-1)}, yw] + 
     2*G[{0, 1}, yv^(-1)]*G[{0, 1/(yu*yv), yv^(-1)}, yw] + 
     2*G[{0, 1}, yw]*G[{0, 1/(yu*yv), yv^(-1)}, yw] - 
     2*G[{0, yu^(-1)}, yw]*G[{0, 1/(yu*yv), yv^(-1)}, yw] - 
     2*G[{0, yu}, yv^(-1)]*G[{0, 1/(yu*yv), yv^(-1)}, yw] - 
     2*G[{0, yv^(-1)}, yw]*G[{0, 1/(yu*yv), yv^(-1)}, yw] + 
     2*G[{0, 1/(yu*yv)}, yw]*G[{0, 1/(yu*yv), yv^(-1)}, yw] + 
     4*G[{1, yu}, yv^(-1)]*G[{0, 1/(yu*yv), yv^(-1)}, yw] - 
     4*G[{0}, yu^(-1)]*G[{1}, yu^(-1)]*G[{0, 1/(yu*yv), 1/(yu*yv)}, yw] - 
     4*G[{0}, yv^(-1)]*G[{1}, yu^(-1)]*G[{0, 1/(yu*yv), 1/(yu*yv)}, yw] + 
     4*G[{0}, yw]*G[{1}, yu^(-1)]*G[{0, 1/(yu*yv), 1/(yu*yv)}, yw] + 
     4*G[{1}, yu^(-1)]^2*G[{0, 1/(yu*yv), 1/(yu*yv)}, yw] + 
     4*G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*G[{0, 1/(yu*yv), 1/(yu*yv)}, yw] - 
     2*G[{1}, yu^(-1)]*G[{yu^(-1)}, yw]*G[{0, 1/(yu*yv), 1/(yu*yv)}, yw] + 
     4*G[{0}, yu^(-1)]*G[{yu}, yv^(-1)]*G[{0, 1/(yu*yv), 1/(yu*yv)}, yw] + 
     4*G[{0}, yv^(-1)]*G[{yu}, yv^(-1)]*G[{0, 1/(yu*yv), 1/(yu*yv)}, yw] - 
     4*G[{0}, yw]*G[{yu}, yv^(-1)]*G[{0, 1/(yu*yv), 1/(yu*yv)}, yw] - 
     4*G[{1}, yu^(-1)]*G[{yu}, yv^(-1)]*G[{0, 1/(yu*yv), 1/(yu*yv)}, yw] - 
     4*G[{1}, yv^(-1)]*G[{yu}, yv^(-1)]*G[{0, 1/(yu*yv), 1/(yu*yv)}, yw] + 
     2*G[{yu^(-1)}, yw]*G[{yu}, yv^(-1)]*G[{0, 1/(yu*yv), 1/(yu*yv)}, yw] + 
     2*G[{1}, yu^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv), 1/(yu*yv)}, yw] - 
     2*G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv), 1/(yu*yv)}, yw] - 
     (Pi^2*G[{1, 1, yu^(-1)}, yw])/3 + 2*G[{0}, yu^(-1)]*G[{1}, yu^(-1)]*
      G[{1, 1, yu^(-1)}, yw] + 2*G[{0}, yv^(-1)]*G[{1}, yu^(-1)]*
      G[{1, 1, yu^(-1)}, yw] - 2*G[{0}, yw]*G[{1}, yu^(-1)]*
      G[{1, 1, yu^(-1)}, yw] - 2*G[{1}, yu^(-1)]^2*G[{1, 1, yu^(-1)}, yw] - 
     4*G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*G[{1, 1, yu^(-1)}, yw] + 
     4*G[{0}, yu^(-1)]*G[{1}, yw]*G[{1, 1, yu^(-1)}, yw] + 
     4*G[{0}, yv^(-1)]*G[{1}, yw]*G[{1, 1, yu^(-1)}, yw] - 
     4*G[{0}, yw]*G[{1}, yw]*G[{1, 1, yu^(-1)}, yw] - 
     4*G[{1}, yu^(-1)]*G[{1}, yw]*G[{1, 1, yu^(-1)}, yw] - 
     4*G[{1}, yv^(-1)]*G[{1}, yw]*G[{1, 1, yu^(-1)}, yw] + 
     2*G[{0}, yu^(-1)]*G[{yu^(-1)}, yw]*G[{1, 1, yu^(-1)}, yw] + 
     2*G[{0}, yv^(-1)]*G[{yu^(-1)}, yw]*G[{1, 1, yu^(-1)}, yw] - 
     2*G[{0}, yw]*G[{yu^(-1)}, yw]*G[{1, 1, yu^(-1)}, yw] - 
     4*G[{1}, yu^(-1)]*G[{yu^(-1)}, yw]*G[{1, 1, yu^(-1)}, yw] - 
     4*G[{1}, yv^(-1)]*G[{yu^(-1)}, yw]*G[{1, 1, yu^(-1)}, yw] - 
     4*G[{1}, yw]*G[{yu^(-1)}, yw]*G[{1, 1, yu^(-1)}, yw] - 
     2*G[{yu^(-1)}, yw]^2*G[{1, 1, yu^(-1)}, yw] - 
     2*G[{0}, yu^(-1)]*G[{yu}, yv^(-1)]*G[{1, 1, yu^(-1)}, yw] - 
     2*G[{0}, yv^(-1)]*G[{yu}, yv^(-1)]*G[{1, 1, yu^(-1)}, yw] + 
     2*G[{0}, yw]*G[{yu}, yv^(-1)]*G[{1, 1, yu^(-1)}, yw] + 
     4*G[{1}, yu^(-1)]*G[{yu}, yv^(-1)]*G[{1, 1, yu^(-1)}, yw] + 
     4*G[{yu^(-1)}, yw]*G[{yu}, yv^(-1)]*G[{1, 1, yu^(-1)}, yw] - 
     2*G[{0}, yu^(-1)]*G[{1/(yu*yv)}, yw]*G[{1, 1, yu^(-1)}, yw] - 
     2*G[{0}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{1, 1, yu^(-1)}, yw] + 
     2*G[{0}, yw]*G[{1/(yu*yv)}, yw]*G[{1, 1, yu^(-1)}, yw] + 
     4*G[{1}, yu^(-1)]*G[{1/(yu*yv)}, yw]*G[{1, 1, yu^(-1)}, yw] + 
     4*G[{1}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{1, 1, yu^(-1)}, yw] + 
     4*G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{1, 1, yu^(-1)}, yw] + 
     4*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{1, 1, yu^(-1)}, yw] - 
     4*G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{1, 1, yu^(-1)}, yw] - 
     2*G[{1/(yu*yv)}, yw]^2*G[{1, 1, yu^(-1)}, yw] - 
     2*G[{0, 1}, yu^(-1)]*G[{1, 1, yu^(-1)}, yw] + 2*G[{0, 1}, yv^(-1)]*
      G[{1, 1, yu^(-1)}, yw] + 2*G[{0, 1}, yw]*G[{1, 1, yu^(-1)}, yw] - 
     2*G[{0, yu^(-1)}, yw]*G[{1, 1, yu^(-1)}, yw] - 
     2*G[{0, yu}, yv^(-1)]*G[{1, 1, yu^(-1)}, yw] - 
     2*G[{0, yv^(-1)}, yw]*G[{1, 1, yu^(-1)}, yw] + 
     2*G[{0, 1/(yu*yv)}, yw]*G[{1, 1, yu^(-1)}, yw] + 
     4*G[{1, yu}, yv^(-1)]*G[{1, 1, yu^(-1)}, yw] + 
     4*G[{1}, yu^(-1)]*G[{yu^(-1)}, yw]*G[{1, 1, yu}, yv^(-1)] - 
     2*G[{yu^(-1)}, yw]^2*G[{1, 1, yu}, yv^(-1)] + 
     8*G[{1}, yu^(-1)]*G[{yu}, yv^(-1)]*G[{1, 1, yu}, yv^(-1)] + 
     2*G[{yu}, yv^(-1)]^2*G[{1, 1, yu}, yv^(-1)] - 
     4*G[{1}, yu^(-1)]*G[{1/(yu*yv)}, yw]*G[{1, 1, yu}, yv^(-1)] + 
     4*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{1, 1, yu}, yv^(-1)] - 
     2*G[{1/(yu*yv)}, yw]^2*G[{1, 1, yu}, yv^(-1)] + 
     4*G[{0}, yu^(-1)]*G[{yu^(-1)}, yw]*G[{1, 1, yv^(-1)}, yw] + 
     4*G[{0}, yv^(-1)]*G[{yu^(-1)}, yw]*G[{1, 1, yv^(-1)}, yw] - 
     4*G[{0}, yw]*G[{yu^(-1)}, yw]*G[{1, 1, yv^(-1)}, yw] - 
     4*G[{1}, yv^(-1)]*G[{yu^(-1)}, yw]*G[{1, 1, yv^(-1)}, yw] + 
     4*G[{1}, yw]*G[{yu^(-1)}, yw]*G[{1, 1, yv^(-1)}, yw] - 
     4*G[{yu^(-1)}, yw]*G[{yu}, yv^(-1)]*G[{1, 1, yv^(-1)}, yw] - 
     4*G[{0}, yu^(-1)]*G[{1/(yu*yv)}, yw]*G[{1, 1, yv^(-1)}, yw] - 
     4*G[{0}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{1, 1, yv^(-1)}, yw] + 
     4*G[{0}, yw]*G[{1/(yu*yv)}, yw]*G[{1, 1, yv^(-1)}, yw] + 
     4*G[{1}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{1, 1, yv^(-1)}, yw] - 
     4*G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{1, 1, yv^(-1)}, yw] + 
     4*G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{1, 1, yv^(-1)}, yw] + 
     2*G[{1/(yu*yv)}, yw]^2*G[{1, 1, yv^(-1)}, yw] + 
     4*G[{1, yu^(-1)}, yw]*G[{1, 1, yv^(-1)}, yw] - 
     4*G[{1, 1/(yu*yv)}, yw]*G[{1, 1, yv^(-1)}, yw] - 
     4*G[{yu^(-1), 1/(yu*yv)}, yw]*G[{1, 1, yv^(-1)}, yw] + 
     (Pi^2*G[{1, 1, 1/(yu*yv)}, yw])/3 - 2*G[{0}, yu^(-1)]*G[{1}, yu^(-1)]*
      G[{1, 1, 1/(yu*yv)}, yw] - 2*G[{0}, yv^(-1)]*G[{1}, yu^(-1)]*
      G[{1, 1, 1/(yu*yv)}, yw] + 2*G[{0}, yw]*G[{1}, yu^(-1)]*
      G[{1, 1, 1/(yu*yv)}, yw] + 2*G[{1}, yu^(-1)]^2*
      G[{1, 1, 1/(yu*yv)}, yw] + 4*G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*
      G[{1, 1, 1/(yu*yv)}, yw] - 4*G[{0}, yu^(-1)]*G[{1}, yw]*
      G[{1, 1, 1/(yu*yv)}, yw] - 4*G[{0}, yv^(-1)]*G[{1}, yw]*
      G[{1, 1, 1/(yu*yv)}, yw] + 4*G[{0}, yw]*G[{1}, yw]*
      G[{1, 1, 1/(yu*yv)}, yw] + 4*G[{1}, yu^(-1)]*G[{1}, yw]*
      G[{1, 1, 1/(yu*yv)}, yw] + 4*G[{1}, yv^(-1)]*G[{1}, yw]*
      G[{1, 1, 1/(yu*yv)}, yw] + 2*G[{0}, yu^(-1)]*G[{yu^(-1)}, yw]*
      G[{1, 1, 1/(yu*yv)}, yw] + 2*G[{0}, yv^(-1)]*G[{yu^(-1)}, yw]*
      G[{1, 1, 1/(yu*yv)}, yw] - 2*G[{0}, yw]*G[{yu^(-1)}, yw]*
      G[{1, 1, 1/(yu*yv)}, yw] + 4*G[{1}, yw]*G[{yu^(-1)}, yw]*
      G[{1, 1, 1/(yu*yv)}, yw] + 2*G[{yu^(-1)}, yw]^2*
      G[{1, 1, 1/(yu*yv)}, yw] + 2*G[{0}, yu^(-1)]*G[{yu}, yv^(-1)]*
      G[{1, 1, 1/(yu*yv)}, yw] + 2*G[{0}, yv^(-1)]*G[{yu}, yv^(-1)]*
      G[{1, 1, 1/(yu*yv)}, yw] - 2*G[{0}, yw]*G[{yu}, yv^(-1)]*
      G[{1, 1, 1/(yu*yv)}, yw] - 4*G[{1}, yu^(-1)]*G[{yu}, yv^(-1)]*
      G[{1, 1, 1/(yu*yv)}, yw] - 4*G[{yu^(-1)}, yw]*G[{yu}, yv^(-1)]*
      G[{1, 1, 1/(yu*yv)}, yw] - 2*G[{0}, yu^(-1)]*G[{1/(yu*yv)}, yw]*
      G[{1, 1, 1/(yu*yv)}, yw] - 2*G[{0}, yv^(-1)]*G[{1/(yu*yv)}, yw]*
      G[{1, 1, 1/(yu*yv)}, yw] + 2*G[{0}, yw]*G[{1/(yu*yv)}, yw]*
      G[{1, 1, 1/(yu*yv)}, yw] - 4*G[{1}, yw]*G[{1/(yu*yv)}, yw]*
      G[{1, 1, 1/(yu*yv)}, yw] - 4*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*
      G[{1, 1, 1/(yu*yv)}, yw] + 4*G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw]*
      G[{1, 1, 1/(yu*yv)}, yw] + 2*G[{0, 1}, yu^(-1)]*
      G[{1, 1, 1/(yu*yv)}, yw] - 2*G[{0, 1}, yv^(-1)]*
      G[{1, 1, 1/(yu*yv)}, yw] - 2*G[{0, 1}, yw]*G[{1, 1, 1/(yu*yv)}, yw] + 
     2*G[{0, yu^(-1)}, yw]*G[{1, 1, 1/(yu*yv)}, yw] + 
     2*G[{0, yu}, yv^(-1)]*G[{1, 1, 1/(yu*yv)}, yw] + 
     2*G[{0, yv^(-1)}, yw]*G[{1, 1, 1/(yu*yv)}, yw] - 
     2*G[{0, 1/(yu*yv)}, yw]*G[{1, 1, 1/(yu*yv)}, yw] - 
     4*G[{1, yu^(-1)}, yw]*G[{1, 1, 1/(yu*yv)}, yw] - 
     4*G[{1, yu}, yv^(-1)]*G[{1, 1, 1/(yu*yv)}, yw] + 
     4*G[{1, 1/(yu*yv)}, yw]*G[{1, 1, 1/(yu*yv)}, yw] + 
     4*G[{yu^(-1), 1/(yu*yv)}, yw]*G[{1, 1, 1/(yu*yv)}, yw] + 
     (2*Pi^2*G[{1, yu^(-1), yu^(-1)}, yw])/3 - 2*G[{1}, yu^(-1)]^2*
      G[{1, yu^(-1), yu^(-1)}, yw] + 4*G[{0}, yu^(-1)]*G[{1}, yw]*
      G[{1, yu^(-1), yu^(-1)}, yw] + 4*G[{0}, yv^(-1)]*G[{1}, yw]*
      G[{1, yu^(-1), yu^(-1)}, yw] - 4*G[{0}, yw]*G[{1}, yw]*
      G[{1, yu^(-1), yu^(-1)}, yw] - 8*G[{1}, yu^(-1)]*G[{1}, yw]*
      G[{1, yu^(-1), yu^(-1)}, yw] - 4*G[{1}, yv^(-1)]*G[{1}, yw]*
      G[{1, yu^(-1), yu^(-1)}, yw] - 2*G[{1}, yw]^2*G[{1, yu^(-1), yu^(-1)}, 
       yw] - 4*G[{0}, yu^(-1)]*G[{yu^(-1)}, yw]*G[{1, yu^(-1), yu^(-1)}, 
       yw] - 4*G[{0}, yv^(-1)]*G[{yu^(-1)}, yw]*G[{1, yu^(-1), yu^(-1)}, 
       yw] + 4*G[{0}, yw]*G[{yu^(-1)}, yw]*G[{1, yu^(-1), yu^(-1)}, yw] - 
     4*G[{1}, yu^(-1)]*G[{yu^(-1)}, yw]*G[{1, yu^(-1), yu^(-1)}, yw] + 
     2*G[{1}, yv^(-1)]*G[{yu^(-1)}, yw]*G[{1, yu^(-1), yu^(-1)}, yw] - 
     10*G[{1}, yw]*G[{yu^(-1)}, yw]*G[{1, yu^(-1), yu^(-1)}, yw] - 
     5*G[{yu^(-1)}, yw]^2*G[{1, yu^(-1), yu^(-1)}, yw] + 
     4*G[{1}, yu^(-1)]*G[{yu}, yv^(-1)]*G[{1, yu^(-1), yu^(-1)}, yw] - 
     2*G[{1}, yv^(-1)]*G[{yu}, yv^(-1)]*G[{1, yu^(-1), yu^(-1)}, yw] + 
     4*G[{1}, yw]*G[{yu}, yv^(-1)]*G[{1, yu^(-1), yu^(-1)}, yw] + 
     10*G[{yu^(-1)}, yw]*G[{yu}, yv^(-1)]*G[{1, yu^(-1), yu^(-1)}, yw] - 
     G[{yu}, yv^(-1)]^2*G[{1, yu^(-1), yu^(-1)}, yw] + 
     4*G[{0}, yu^(-1)]*G[{1/(yu*yv)}, yw]*G[{1, yu^(-1), yu^(-1)}, yw] + 
     4*G[{0}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{1, yu^(-1), yu^(-1)}, yw] - 
     4*G[{0}, yw]*G[{1/(yu*yv)}, yw]*G[{1, yu^(-1), yu^(-1)}, yw] + 
     4*G[{1}, yu^(-1)]*G[{1/(yu*yv)}, yw]*G[{1, yu^(-1), yu^(-1)}, yw] - 
     2*G[{1}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{1, yu^(-1), yu^(-1)}, yw] + 
     10*G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{1, yu^(-1), yu^(-1)}, yw] + 
     10*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{1, yu^(-1), yu^(-1)}, yw] - 
     10*G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{1, yu^(-1), yu^(-1)}, yw] - 
     2*G[{1/(yu*yv)}, yw]^2*G[{1, yu^(-1), yu^(-1)}, yw] + 
     2*G[{0, 1}, yv^(-1)]*G[{1, yu^(-1), yu^(-1)}, yw] + 
     4*G[{0, 1}, yw]*G[{1, yu^(-1), yu^(-1)}, yw] - 
     4*G[{0, yu^(-1)}, yw]*G[{1, yu^(-1), yu^(-1)}, yw] - 
     2*G[{0, yu}, yv^(-1)]*G[{1, yu^(-1), yu^(-1)}, yw] - 
     4*G[{0, yv^(-1)}, yw]*G[{1, yu^(-1), yu^(-1)}, yw] + 
     4*G[{0, 1/(yu*yv)}, yw]*G[{1, yu^(-1), yu^(-1)}, yw] + 
     6*G[{1, yu^(-1)}, yw]*G[{1, yu^(-1), yu^(-1)}, yw] + 
     2*G[{1, yu}, yv^(-1)]*G[{1, yu^(-1), yu^(-1)}, yw] - 
     2*G[{1, 1/(yu*yv)}, yw]*G[{1, yu^(-1), yu^(-1)}, yw] - 
     6*G[{yu^(-1), 1/(yu*yv)}, yw]*G[{1, yu^(-1), yu^(-1)}, yw] - 
     (Pi^2*G[{1, yu^(-1), yv^(-1)}, yw])/3 + 2*G[{0}, yu^(-1)]*
      G[{1}, yu^(-1)]*G[{1, yu^(-1), yv^(-1)}, yw] + 
     2*G[{0}, yv^(-1)]*G[{1}, yu^(-1)]*G[{1, yu^(-1), yv^(-1)}, yw] - 
     2*G[{0}, yw]*G[{1}, yu^(-1)]*G[{1, yu^(-1), yv^(-1)}, yw] - 
     2*G[{1}, yu^(-1)]^2*G[{1, yu^(-1), yv^(-1)}, yw] - 
     4*G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*G[{1, yu^(-1), yv^(-1)}, yw] + 
     4*G[{0}, yu^(-1)]*G[{1}, yw]*G[{1, yu^(-1), yv^(-1)}, yw] + 
     4*G[{0}, yv^(-1)]*G[{1}, yw]*G[{1, yu^(-1), yv^(-1)}, yw] - 
     4*G[{0}, yw]*G[{1}, yw]*G[{1, yu^(-1), yv^(-1)}, yw] - 
     4*G[{1}, yu^(-1)]*G[{1}, yw]*G[{1, yu^(-1), yv^(-1)}, yw] - 
     4*G[{1}, yv^(-1)]*G[{1}, yw]*G[{1, yu^(-1), yv^(-1)}, yw] + 
     2*G[{0}, yu^(-1)]*G[{yu^(-1)}, yw]*G[{1, yu^(-1), yv^(-1)}, yw] + 
     2*G[{0}, yv^(-1)]*G[{yu^(-1)}, yw]*G[{1, yu^(-1), yv^(-1)}, yw] - 
     2*G[{0}, yw]*G[{yu^(-1)}, yw]*G[{1, yu^(-1), yv^(-1)}, yw] - 
     4*G[{1}, yu^(-1)]*G[{yu^(-1)}, yw]*G[{1, yu^(-1), yv^(-1)}, yw] - 
     4*G[{1}, yv^(-1)]*G[{yu^(-1)}, yw]*G[{1, yu^(-1), yv^(-1)}, yw] - 
     4*G[{1}, yw]*G[{yu^(-1)}, yw]*G[{1, yu^(-1), yv^(-1)}, yw] - 
     2*G[{0}, yu^(-1)]*G[{yu}, yv^(-1)]*G[{1, yu^(-1), yv^(-1)}, yw] - 
     2*G[{0}, yv^(-1)]*G[{yu}, yv^(-1)]*G[{1, yu^(-1), yv^(-1)}, yw] + 
     2*G[{0}, yw]*G[{yu}, yv^(-1)]*G[{1, yu^(-1), yv^(-1)}, yw] + 
     4*G[{1}, yu^(-1)]*G[{yu}, yv^(-1)]*G[{1, yu^(-1), yv^(-1)}, yw] + 
     4*G[{yu^(-1)}, yw]*G[{yu}, yv^(-1)]*G[{1, yu^(-1), yv^(-1)}, yw] - 
     2*G[{0}, yu^(-1)]*G[{1/(yu*yv)}, yw]*G[{1, yu^(-1), yv^(-1)}, yw] - 
     2*G[{0}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{1, yu^(-1), yv^(-1)}, yw] + 
     2*G[{0}, yw]*G[{1/(yu*yv)}, yw]*G[{1, yu^(-1), yv^(-1)}, yw] + 
     4*G[{1}, yu^(-1)]*G[{1/(yu*yv)}, yw]*G[{1, yu^(-1), yv^(-1)}, yw] + 
     4*G[{1}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{1, yu^(-1), yv^(-1)}, yw] + 
     4*G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{1, yu^(-1), yv^(-1)}, yw] - 
     4*G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{1, yu^(-1), yv^(-1)}, yw] - 
     2*G[{0, 1}, yu^(-1)]*G[{1, yu^(-1), yv^(-1)}, yw] + 
     2*G[{0, 1}, yv^(-1)]*G[{1, yu^(-1), yv^(-1)}, yw] + 
     2*G[{0, 1}, yw]*G[{1, yu^(-1), yv^(-1)}, yw] - 
     2*G[{0, yu^(-1)}, yw]*G[{1, yu^(-1), yv^(-1)}, yw] - 
     2*G[{0, yu}, yv^(-1)]*G[{1, yu^(-1), yv^(-1)}, yw] - 
     2*G[{0, yv^(-1)}, yw]*G[{1, yu^(-1), yv^(-1)}, yw] + 
     2*G[{0, 1/(yu*yv)}, yw]*G[{1, yu^(-1), yv^(-1)}, yw] + 
     4*G[{1, yu^(-1)}, yw]*G[{1, yu^(-1), yv^(-1)}, yw] + 
     4*G[{1, yu}, yv^(-1)]*G[{1, yu^(-1), yv^(-1)}, yw] - 
     (2*Pi^2*G[{1, yu^(-1), 1/(yu*yv)}, yw])/3 + 2*G[{1}, yu^(-1)]^2*
      G[{1, yu^(-1), 1/(yu*yv)}, yw] - 4*G[{0}, yu^(-1)]*G[{1}, yw]*
      G[{1, yu^(-1), 1/(yu*yv)}, yw] - 4*G[{0}, yv^(-1)]*G[{1}, yw]*
      G[{1, yu^(-1), 1/(yu*yv)}, yw] + 4*G[{0}, yw]*G[{1}, yw]*
      G[{1, yu^(-1), 1/(yu*yv)}, yw] + 8*G[{1}, yu^(-1)]*G[{1}, yw]*
      G[{1, yu^(-1), 1/(yu*yv)}, yw] + 4*G[{1}, yv^(-1)]*G[{1}, yw]*
      G[{1, yu^(-1), 1/(yu*yv)}, yw] + 2*G[{1}, yw]^2*
      G[{1, yu^(-1), 1/(yu*yv)}, yw] + 4*G[{0}, yu^(-1)]*G[{yu^(-1)}, yw]*
      G[{1, yu^(-1), 1/(yu*yv)}, yw] + 4*G[{0}, yv^(-1)]*G[{yu^(-1)}, yw]*
      G[{1, yu^(-1), 1/(yu*yv)}, yw] - 4*G[{0}, yw]*G[{yu^(-1)}, yw]*
      G[{1, yu^(-1), 1/(yu*yv)}, yw] - 2*G[{1}, yv^(-1)]*G[{yu^(-1)}, yw]*
      G[{1, yu^(-1), 1/(yu*yv)}, yw] + 6*G[{1}, yw]*G[{yu^(-1)}, yw]*
      G[{1, yu^(-1), 1/(yu*yv)}, yw] + 3*G[{yu^(-1)}, yw]^2*
      G[{1, yu^(-1), 1/(yu*yv)}, yw] - 4*G[{1}, yu^(-1)]*G[{yu}, yv^(-1)]*
      G[{1, yu^(-1), 1/(yu*yv)}, yw] + 2*G[{1}, yv^(-1)]*G[{yu}, yv^(-1)]*
      G[{1, yu^(-1), 1/(yu*yv)}, yw] - 4*G[{1}, yw]*G[{yu}, yv^(-1)]*
      G[{1, yu^(-1), 1/(yu*yv)}, yw] - 6*G[{yu^(-1)}, yw]*G[{yu}, yv^(-1)]*
      G[{1, yu^(-1), 1/(yu*yv)}, yw] + G[{yu}, yv^(-1)]^2*
      G[{1, yu^(-1), 1/(yu*yv)}, yw] - 4*G[{0}, yu^(-1)]*G[{1/(yu*yv)}, yw]*
      G[{1, yu^(-1), 1/(yu*yv)}, yw] - 4*G[{0}, yv^(-1)]*G[{1/(yu*yv)}, yw]*
      G[{1, yu^(-1), 1/(yu*yv)}, yw] + 4*G[{0}, yw]*G[{1/(yu*yv)}, yw]*
      G[{1, yu^(-1), 1/(yu*yv)}, yw] + 2*G[{1}, yv^(-1)]*G[{1/(yu*yv)}, yw]*
      G[{1, yu^(-1), 1/(yu*yv)}, yw] - 6*G[{1}, yw]*G[{1/(yu*yv)}, yw]*
      G[{1, yu^(-1), 1/(yu*yv)}, yw] - 6*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*
      G[{1, yu^(-1), 1/(yu*yv)}, yw] + 6*G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw]*
      G[{1, yu^(-1), 1/(yu*yv)}, yw] - 2*G[{0, 1}, yv^(-1)]*
      G[{1, yu^(-1), 1/(yu*yv)}, yw] - 4*G[{0, 1}, yw]*
      G[{1, yu^(-1), 1/(yu*yv)}, yw] + 4*G[{0, yu^(-1)}, yw]*
      G[{1, yu^(-1), 1/(yu*yv)}, yw] + 2*G[{0, yu}, yv^(-1)]*
      G[{1, yu^(-1), 1/(yu*yv)}, yw] + 4*G[{0, yv^(-1)}, yw]*
      G[{1, yu^(-1), 1/(yu*yv)}, yw] - 4*G[{0, 1/(yu*yv)}, yw]*
      G[{1, yu^(-1), 1/(yu*yv)}, yw] - 6*G[{1, yu^(-1)}, yw]*
      G[{1, yu^(-1), 1/(yu*yv)}, yw] - 2*G[{1, yu}, yv^(-1)]*
      G[{1, yu^(-1), 1/(yu*yv)}, yw] + 2*G[{1, 1/(yu*yv)}, yw]*
      G[{1, yu^(-1), 1/(yu*yv)}, yw] + 6*G[{yu^(-1), 1/(yu*yv)}, yw]*
      G[{1, yu^(-1), 1/(yu*yv)}, yw] + 2*Pi^2*G[{1, yu, yu}, yv^(-1)] - 
     2*G[{1}, yu^(-1)]^2*G[{1, yu, yu}, yv^(-1)] + 
     8*G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*G[{1, yu, yu}, yv^(-1)] - 
     4*G[{1}, yu^(-1)]*G[{yu^(-1)}, yw]*G[{1, yu, yu}, yv^(-1)] + 
     6*G[{1}, yv^(-1)]*G[{yu^(-1)}, yw]*G[{1, yu, yu}, yv^(-1)] + 
     2*G[{1}, yw]*G[{yu^(-1)}, yw]*G[{1, yu, yu}, yv^(-1)] - 
     5*G[{yu^(-1)}, yw]^2*G[{1, yu, yu}, yv^(-1)] + 
     4*G[{1}, yu^(-1)]*G[{yu}, yv^(-1)]*G[{1, yu, yu}, yv^(-1)] + 
     6*G[{1}, yv^(-1)]*G[{yu}, yv^(-1)]*G[{1, yu, yu}, yv^(-1)] - 
     2*G[{yu^(-1)}, yw]*G[{yu}, yv^(-1)]*G[{1, yu, yu}, yv^(-1)] + 
     3*G[{yu}, yv^(-1)]^2*G[{1, yu, yu}, yv^(-1)] + 
     4*G[{1}, yu^(-1)]*G[{1/(yu*yv)}, yw]*G[{1, yu, yu}, yv^(-1)] - 
     6*G[{1}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{1, yu, yu}, yv^(-1)] - 
     2*G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{1, yu, yu}, yv^(-1)] + 
     10*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{1, yu, yu}, yv^(-1)] + 
     2*G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{1, yu, yu}, yv^(-1)] - 
     4*G[{1/(yu*yv)}, yw]^2*G[{1, yu, yu}, yv^(-1)] + 
     8*G[{0, 1}, yu^(-1)]*G[{1, yu, yu}, yv^(-1)] - 
     6*G[{0, 1}, yv^(-1)]*G[{1, yu, yu}, yv^(-1)] + 
     6*G[{0, yu}, yv^(-1)]*G[{1, yu, yu}, yv^(-1)] - 
     2*G[{1, yu^(-1)}, yw]*G[{1, yu, yu}, yv^(-1)] - 
     14*G[{1, yu}, yv^(-1)]*G[{1, yu, yu}, yv^(-1)] + 
     2*G[{1, 1/(yu*yv)}, yw]*G[{1, yu, yu}, yv^(-1)] - 
     2*G[{yu^(-1), 1/(yu*yv)}, yw]*G[{1, yu, yu}, yv^(-1)] - 
     (Pi^2*G[{1, yv^(-1), yu^(-1)}, yw])/3 + 2*G[{0}, yu^(-1)]*
      G[{1}, yu^(-1)]*G[{1, yv^(-1), yu^(-1)}, yw] + 
     2*G[{0}, yv^(-1)]*G[{1}, yu^(-1)]*G[{1, yv^(-1), yu^(-1)}, yw] - 
     2*G[{0}, yw]*G[{1}, yu^(-1)]*G[{1, yv^(-1), yu^(-1)}, yw] - 
     2*G[{1}, yu^(-1)]^2*G[{1, yv^(-1), yu^(-1)}, yw] - 
     4*G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*G[{1, yv^(-1), yu^(-1)}, yw] + 
     4*G[{0}, yu^(-1)]*G[{1}, yw]*G[{1, yv^(-1), yu^(-1)}, yw] + 
     4*G[{0}, yv^(-1)]*G[{1}, yw]*G[{1, yv^(-1), yu^(-1)}, yw] - 
     4*G[{0}, yw]*G[{1}, yw]*G[{1, yv^(-1), yu^(-1)}, yw] - 
     4*G[{1}, yu^(-1)]*G[{1}, yw]*G[{1, yv^(-1), yu^(-1)}, yw] - 
     4*G[{1}, yv^(-1)]*G[{1}, yw]*G[{1, yv^(-1), yu^(-1)}, yw] + 
     2*G[{0}, yu^(-1)]*G[{yu^(-1)}, yw]*G[{1, yv^(-1), yu^(-1)}, yw] + 
     2*G[{0}, yv^(-1)]*G[{yu^(-1)}, yw]*G[{1, yv^(-1), yu^(-1)}, yw] - 
     2*G[{0}, yw]*G[{yu^(-1)}, yw]*G[{1, yv^(-1), yu^(-1)}, yw] - 
     4*G[{1}, yu^(-1)]*G[{yu^(-1)}, yw]*G[{1, yv^(-1), yu^(-1)}, yw] - 
     4*G[{1}, yv^(-1)]*G[{yu^(-1)}, yw]*G[{1, yv^(-1), yu^(-1)}, yw] - 
     4*G[{1}, yw]*G[{yu^(-1)}, yw]*G[{1, yv^(-1), yu^(-1)}, yw] - 
     2*G[{0}, yu^(-1)]*G[{yu}, yv^(-1)]*G[{1, yv^(-1), yu^(-1)}, yw] - 
     2*G[{0}, yv^(-1)]*G[{yu}, yv^(-1)]*G[{1, yv^(-1), yu^(-1)}, yw] + 
     2*G[{0}, yw]*G[{yu}, yv^(-1)]*G[{1, yv^(-1), yu^(-1)}, yw] + 
     4*G[{1}, yu^(-1)]*G[{yu}, yv^(-1)]*G[{1, yv^(-1), yu^(-1)}, yw] + 
     4*G[{yu^(-1)}, yw]*G[{yu}, yv^(-1)]*G[{1, yv^(-1), yu^(-1)}, yw] - 
     2*G[{0}, yu^(-1)]*G[{1/(yu*yv)}, yw]*G[{1, yv^(-1), yu^(-1)}, yw] - 
     2*G[{0}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{1, yv^(-1), yu^(-1)}, yw] + 
     2*G[{0}, yw]*G[{1/(yu*yv)}, yw]*G[{1, yv^(-1), yu^(-1)}, yw] + 
     4*G[{1}, yu^(-1)]*G[{1/(yu*yv)}, yw]*G[{1, yv^(-1), yu^(-1)}, yw] + 
     4*G[{1}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{1, yv^(-1), yu^(-1)}, yw] + 
     4*G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{1, yv^(-1), yu^(-1)}, yw] - 
     4*G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{1, yv^(-1), yu^(-1)}, yw] - 
     2*G[{0, 1}, yu^(-1)]*G[{1, yv^(-1), yu^(-1)}, yw] + 
     2*G[{0, 1}, yv^(-1)]*G[{1, yv^(-1), yu^(-1)}, yw] + 
     2*G[{0, 1}, yw]*G[{1, yv^(-1), yu^(-1)}, yw] - 
     2*G[{0, yu^(-1)}, yw]*G[{1, yv^(-1), yu^(-1)}, yw] - 
     2*G[{0, yu}, yv^(-1)]*G[{1, yv^(-1), yu^(-1)}, yw] - 
     2*G[{0, yv^(-1)}, yw]*G[{1, yv^(-1), yu^(-1)}, yw] + 
     2*G[{0, 1/(yu*yv)}, yw]*G[{1, yv^(-1), yu^(-1)}, yw] + 
     4*G[{1, yu^(-1)}, yw]*G[{1, yv^(-1), yu^(-1)}, yw] + 
     4*G[{1, yu}, yv^(-1)]*G[{1, yv^(-1), yu^(-1)}, yw] + 
     4*G[{0}, yu^(-1)]*G[{yu^(-1)}, yw]*G[{1, yv^(-1), yv^(-1)}, yw] + 
     4*G[{0}, yv^(-1)]*G[{yu^(-1)}, yw]*G[{1, yv^(-1), yv^(-1)}, yw] - 
     4*G[{0}, yw]*G[{yu^(-1)}, yw]*G[{1, yv^(-1), yv^(-1)}, yw] - 
     8*G[{1}, yu^(-1)]*G[{yu^(-1)}, yw]*G[{1, yv^(-1), yv^(-1)}, yw] - 
     4*G[{1}, yv^(-1)]*G[{yu^(-1)}, yw]*G[{1, yv^(-1), yv^(-1)}, yw] - 
     4*G[{1}, yw]*G[{yu^(-1)}, yw]*G[{1, yv^(-1), yv^(-1)}, yw] + 
     4*G[{yu^(-1)}, yw]*G[{yu}, yv^(-1)]*G[{1, yv^(-1), yv^(-1)}, yw] - 
     4*G[{0}, yu^(-1)]*G[{1/(yu*yv)}, yw]*G[{1, yv^(-1), yv^(-1)}, yw] - 
     4*G[{0}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{1, yv^(-1), yv^(-1)}, yw] + 
     4*G[{0}, yw]*G[{1/(yu*yv)}, yw]*G[{1, yv^(-1), yv^(-1)}, yw] + 
     8*G[{1}, yu^(-1)]*G[{1/(yu*yv)}, yw]*G[{1, yv^(-1), yv^(-1)}, yw] + 
     4*G[{1}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{1, yv^(-1), yv^(-1)}, yw] + 
     4*G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{1, yv^(-1), yv^(-1)}, yw] - 
     4*G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{1, yv^(-1), yv^(-1)}, yw] + 
     2*G[{1/(yu*yv)}, yw]^2*G[{1, yv^(-1), yv^(-1)}, yw] - 
     4*G[{1, 1/(yu*yv)}, yw]*G[{1, yv^(-1), yv^(-1)}, yw] - 
     4*G[{yu^(-1), 1/(yu*yv)}, yw]*G[{1, yv^(-1), yv^(-1)}, yw] + 
     (Pi^2*G[{1, yv^(-1), 1/(yu*yv)}, yw])/3 - 2*G[{0}, yu^(-1)]*
      G[{1}, yu^(-1)]*G[{1, yv^(-1), 1/(yu*yv)}, yw] - 
     2*G[{0}, yv^(-1)]*G[{1}, yu^(-1)]*G[{1, yv^(-1), 1/(yu*yv)}, yw] + 
     2*G[{0}, yw]*G[{1}, yu^(-1)]*G[{1, yv^(-1), 1/(yu*yv)}, yw] + 
     2*G[{1}, yu^(-1)]^2*G[{1, yv^(-1), 1/(yu*yv)}, yw] + 
     4*G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*G[{1, yv^(-1), 1/(yu*yv)}, yw] - 
     4*G[{0}, yu^(-1)]*G[{1}, yw]*G[{1, yv^(-1), 1/(yu*yv)}, yw] - 
     4*G[{0}, yv^(-1)]*G[{1}, yw]*G[{1, yv^(-1), 1/(yu*yv)}, yw] + 
     4*G[{0}, yw]*G[{1}, yw]*G[{1, yv^(-1), 1/(yu*yv)}, yw] + 
     4*G[{1}, yu^(-1)]*G[{1}, yw]*G[{1, yv^(-1), 1/(yu*yv)}, yw] + 
     4*G[{1}, yv^(-1)]*G[{1}, yw]*G[{1, yv^(-1), 1/(yu*yv)}, yw] - 
     2*G[{0}, yu^(-1)]*G[{yu^(-1)}, yw]*G[{1, yv^(-1), 1/(yu*yv)}, yw] - 
     2*G[{0}, yv^(-1)]*G[{yu^(-1)}, yw]*G[{1, yv^(-1), 1/(yu*yv)}, yw] + 
     2*G[{0}, yw]*G[{yu^(-1)}, yw]*G[{1, yv^(-1), 1/(yu*yv)}, yw] + 
     4*G[{1}, yv^(-1)]*G[{yu^(-1)}, yw]*G[{1, yv^(-1), 1/(yu*yv)}, yw] + 
     2*G[{0}, yu^(-1)]*G[{yu}, yv^(-1)]*G[{1, yv^(-1), 1/(yu*yv)}, yw] + 
     2*G[{0}, yv^(-1)]*G[{yu}, yv^(-1)]*G[{1, yv^(-1), 1/(yu*yv)}, yw] - 
     2*G[{0}, yw]*G[{yu}, yv^(-1)]*G[{1, yv^(-1), 1/(yu*yv)}, yw] - 
     4*G[{1}, yu^(-1)]*G[{yu}, yv^(-1)]*G[{1, yv^(-1), 1/(yu*yv)}, yw] + 
     2*G[{0}, yu^(-1)]*G[{1/(yu*yv)}, yw]*G[{1, yv^(-1), 1/(yu*yv)}, yw] + 
     2*G[{0}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{1, yv^(-1), 1/(yu*yv)}, yw] - 
     2*G[{0}, yw]*G[{1/(yu*yv)}, yw]*G[{1, yv^(-1), 1/(yu*yv)}, yw] - 
     4*G[{1}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{1, yv^(-1), 1/(yu*yv)}, yw] + 
     2*G[{0, 1}, yu^(-1)]*G[{1, yv^(-1), 1/(yu*yv)}, yw] - 
     2*G[{0, 1}, yv^(-1)]*G[{1, yv^(-1), 1/(yu*yv)}, yw] - 
     2*G[{0, 1}, yw]*G[{1, yv^(-1), 1/(yu*yv)}, yw] + 
     2*G[{0, yu^(-1)}, yw]*G[{1, yv^(-1), 1/(yu*yv)}, yw] + 
     2*G[{0, yu}, yv^(-1)]*G[{1, yv^(-1), 1/(yu*yv)}, yw] + 
     2*G[{0, yv^(-1)}, yw]*G[{1, yv^(-1), 1/(yu*yv)}, yw] - 
     2*G[{0, 1/(yu*yv)}, yw]*G[{1, yv^(-1), 1/(yu*yv)}, yw] - 
     4*G[{1, yu^(-1)}, yw]*G[{1, yv^(-1), 1/(yu*yv)}, yw] - 
     4*G[{1, yu}, yv^(-1)]*G[{1, yv^(-1), 1/(yu*yv)}, yw] - 
     Pi^2*G[{1, 1/(yu*yv), yu^(-1)}, yw] + 2*G[{0}, yu^(-1)]*G[{1}, yu^(-1)]*
      G[{1, 1/(yu*yv), yu^(-1)}, yw] + 2*G[{0}, yv^(-1)]*G[{1}, yu^(-1)]*
      G[{1, 1/(yu*yv), yu^(-1)}, yw] - 2*G[{0}, yw]*G[{1}, yu^(-1)]*
      G[{1, 1/(yu*yv), yu^(-1)}, yw] - 4*G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*
      G[{1, 1/(yu*yv), yu^(-1)}, yw] + 4*G[{1}, yu^(-1)]*G[{1}, yw]*
      G[{1, 1/(yu*yv), yu^(-1)}, yw] + 2*G[{1}, yw]^2*
      G[{1, 1/(yu*yv), yu^(-1)}, yw] + 6*G[{0}, yu^(-1)]*G[{yu^(-1)}, yw]*
      G[{1, 1/(yu*yv), yu^(-1)}, yw] + 6*G[{0}, yv^(-1)]*G[{yu^(-1)}, yw]*
      G[{1, 1/(yu*yv), yu^(-1)}, yw] - 6*G[{0}, yw]*G[{yu^(-1)}, yw]*
      G[{1, 1/(yu*yv), yu^(-1)}, yw] - 6*G[{1}, yv^(-1)]*G[{yu^(-1)}, yw]*
      G[{1, 1/(yu*yv), yu^(-1)}, yw] + 6*G[{1}, yw]*G[{yu^(-1)}, yw]*
      G[{1, 1/(yu*yv), yu^(-1)}, yw] + 5*G[{yu^(-1)}, yw]^2*
      G[{1, 1/(yu*yv), yu^(-1)}, yw] - 2*G[{0}, yu^(-1)]*G[{yu}, yv^(-1)]*
      G[{1, 1/(yu*yv), yu^(-1)}, yw] - 2*G[{0}, yv^(-1)]*G[{yu}, yv^(-1)]*
      G[{1, 1/(yu*yv), yu^(-1)}, yw] + 2*G[{0}, yw]*G[{yu}, yv^(-1)]*
      G[{1, 1/(yu*yv), yu^(-1)}, yw] + 2*G[{1}, yv^(-1)]*G[{yu}, yv^(-1)]*
      G[{1, 1/(yu*yv), yu^(-1)}, yw] - 4*G[{1}, yw]*G[{yu}, yv^(-1)]*
      G[{1, 1/(yu*yv), yu^(-1)}, yw] - 6*G[{yu^(-1)}, yw]*G[{yu}, yv^(-1)]*
      G[{1, 1/(yu*yv), yu^(-1)}, yw] + G[{yu}, yv^(-1)]^2*
      G[{1, 1/(yu*yv), yu^(-1)}, yw] - 6*G[{0}, yu^(-1)]*G[{1/(yu*yv)}, yw]*
      G[{1, 1/(yu*yv), yu^(-1)}, yw] - 6*G[{0}, yv^(-1)]*G[{1/(yu*yv)}, yw]*
      G[{1, 1/(yu*yv), yu^(-1)}, yw] + 6*G[{0}, yw]*G[{1/(yu*yv)}, yw]*
      G[{1, 1/(yu*yv), yu^(-1)}, yw] + 6*G[{1}, yv^(-1)]*G[{1/(yu*yv)}, yw]*
      G[{1, 1/(yu*yv), yu^(-1)}, yw] - 6*G[{1}, yw]*G[{1/(yu*yv)}, yw]*
      G[{1, 1/(yu*yv), yu^(-1)}, yw] - 10*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*
      G[{1, 1/(yu*yv), yu^(-1)}, yw] + 6*G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw]*
      G[{1, 1/(yu*yv), yu^(-1)}, yw] + 2*G[{1/(yu*yv)}, yw]^2*
      G[{1, 1/(yu*yv), yu^(-1)}, yw] - 2*G[{0, 1}, yu^(-1)]*
      G[{1, 1/(yu*yv), yu^(-1)}, yw] - 2*G[{0, 1}, yw]*
      G[{1, 1/(yu*yv), yu^(-1)}, yw] + 2*G[{0, yu^(-1)}, yw]*
      G[{1, 1/(yu*yv), yu^(-1)}, yw] + 2*G[{0, yv^(-1)}, yw]*
      G[{1, 1/(yu*yv), yu^(-1)}, yw] - 2*G[{0, 1/(yu*yv)}, yw]*
      G[{1, 1/(yu*yv), yu^(-1)}, yw] - 2*G[{1, yu^(-1)}, yw]*
      G[{1, 1/(yu*yv), yu^(-1)}, yw] + 2*G[{1, yu}, yv^(-1)]*
      G[{1, 1/(yu*yv), yu^(-1)}, yw] - 4*G[{1, yv^(-1)}, yw]*
      G[{1, 1/(yu*yv), yu^(-1)}, yw] + 2*G[{1, 1/(yu*yv)}, yw]*
      G[{1, 1/(yu*yv), yu^(-1)}, yw] + 6*G[{yu^(-1), 1/(yu*yv)}, yw]*
      G[{1, 1/(yu*yv), yu^(-1)}, yw] + (Pi^2*G[{1, 1/(yu*yv), yv^(-1)}, yw])/
      3 - 2*G[{0}, yu^(-1)]*G[{1}, yu^(-1)]*G[{1, 1/(yu*yv), yv^(-1)}, yw] - 
     2*G[{0}, yv^(-1)]*G[{1}, yu^(-1)]*G[{1, 1/(yu*yv), yv^(-1)}, yw] + 
     2*G[{0}, yw]*G[{1}, yu^(-1)]*G[{1, 1/(yu*yv), yv^(-1)}, yw] + 
     2*G[{1}, yu^(-1)]^2*G[{1, 1/(yu*yv), yv^(-1)}, yw] + 
     4*G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*G[{1, 1/(yu*yv), yv^(-1)}, yw] - 
     4*G[{0}, yu^(-1)]*G[{1}, yw]*G[{1, 1/(yu*yv), yv^(-1)}, yw] - 
     4*G[{0}, yv^(-1)]*G[{1}, yw]*G[{1, 1/(yu*yv), yv^(-1)}, yw] + 
     4*G[{0}, yw]*G[{1}, yw]*G[{1, 1/(yu*yv), yv^(-1)}, yw] + 
     4*G[{1}, yu^(-1)]*G[{1}, yw]*G[{1, 1/(yu*yv), yv^(-1)}, yw] + 
     4*G[{1}, yv^(-1)]*G[{1}, yw]*G[{1, 1/(yu*yv), yv^(-1)}, yw] + 
     2*G[{0}, yu^(-1)]*G[{yu^(-1)}, yw]*G[{1, 1/(yu*yv), yv^(-1)}, yw] + 
     2*G[{0}, yv^(-1)]*G[{yu^(-1)}, yw]*G[{1, 1/(yu*yv), yv^(-1)}, yw] - 
     2*G[{0}, yw]*G[{yu^(-1)}, yw]*G[{1, 1/(yu*yv), yv^(-1)}, yw] - 
     4*G[{1}, yu^(-1)]*G[{yu^(-1)}, yw]*G[{1, 1/(yu*yv), yv^(-1)}, yw] + 
     2*G[{0}, yu^(-1)]*G[{yu}, yv^(-1)]*G[{1, 1/(yu*yv), yv^(-1)}, yw] + 
     2*G[{0}, yv^(-1)]*G[{yu}, yv^(-1)]*G[{1, 1/(yu*yv), yv^(-1)}, yw] - 
     2*G[{0}, yw]*G[{yu}, yv^(-1)]*G[{1, 1/(yu*yv), yv^(-1)}, yw] - 
     4*G[{1}, yu^(-1)]*G[{yu}, yv^(-1)]*G[{1, 1/(yu*yv), yv^(-1)}, yw] - 
     2*G[{0}, yu^(-1)]*G[{1/(yu*yv)}, yw]*G[{1, 1/(yu*yv), yv^(-1)}, yw] - 
     2*G[{0}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{1, 1/(yu*yv), yv^(-1)}, yw] + 
     2*G[{0}, yw]*G[{1/(yu*yv)}, yw]*G[{1, 1/(yu*yv), yv^(-1)}, yw] + 
     4*G[{1}, yu^(-1)]*G[{1/(yu*yv)}, yw]*G[{1, 1/(yu*yv), yv^(-1)}, yw] - 
     2*G[{1/(yu*yv)}, yw]^2*G[{1, 1/(yu*yv), yv^(-1)}, yw] + 
     2*G[{0, 1}, yu^(-1)]*G[{1, 1/(yu*yv), yv^(-1)}, yw] - 
     2*G[{0, 1}, yv^(-1)]*G[{1, 1/(yu*yv), yv^(-1)}, yw] - 
     2*G[{0, 1}, yw]*G[{1, 1/(yu*yv), yv^(-1)}, yw] + 
     2*G[{0, yu^(-1)}, yw]*G[{1, 1/(yu*yv), yv^(-1)}, yw] + 
     2*G[{0, yu}, yv^(-1)]*G[{1, 1/(yu*yv), yv^(-1)}, yw] + 
     2*G[{0, yv^(-1)}, yw]*G[{1, 1/(yu*yv), yv^(-1)}, yw] - 
     2*G[{0, 1/(yu*yv)}, yw]*G[{1, 1/(yu*yv), yv^(-1)}, yw] - 
     4*G[{1, yu^(-1)}, yw]*G[{1, 1/(yu*yv), yv^(-1)}, yw] - 
     4*G[{1, yu}, yv^(-1)]*G[{1, 1/(yu*yv), yv^(-1)}, yw] + 
     4*G[{yu^(-1), 1/(yu*yv)}, yw]*G[{1, 1/(yu*yv), yv^(-1)}, yw] + 
     Pi^2*G[{1, 1/(yu*yv), 1/(yu*yv)}, yw] - 2*G[{0}, yu^(-1)]*
      G[{1}, yu^(-1)]*G[{1, 1/(yu*yv), 1/(yu*yv)}, yw] - 
     2*G[{0}, yv^(-1)]*G[{1}, yu^(-1)]*G[{1, 1/(yu*yv), 1/(yu*yv)}, yw] + 
     2*G[{0}, yw]*G[{1}, yu^(-1)]*G[{1, 1/(yu*yv), 1/(yu*yv)}, yw] + 
     4*G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*G[{1, 1/(yu*yv), 1/(yu*yv)}, yw] - 
     4*G[{1}, yu^(-1)]*G[{1}, yw]*G[{1, 1/(yu*yv), 1/(yu*yv)}, yw] - 
     2*G[{1}, yw]^2*G[{1, 1/(yu*yv), 1/(yu*yv)}, yw] - 
     6*G[{0}, yu^(-1)]*G[{yu^(-1)}, yw]*G[{1, 1/(yu*yv), 1/(yu*yv)}, yw] - 
     6*G[{0}, yv^(-1)]*G[{yu^(-1)}, yw]*G[{1, 1/(yu*yv), 1/(yu*yv)}, yw] + 
     6*G[{0}, yw]*G[{yu^(-1)}, yw]*G[{1, 1/(yu*yv), 1/(yu*yv)}, yw] + 
     4*G[{1}, yu^(-1)]*G[{yu^(-1)}, yw]*G[{1, 1/(yu*yv), 1/(yu*yv)}, yw] + 
     6*G[{1}, yv^(-1)]*G[{yu^(-1)}, yw]*G[{1, 1/(yu*yv), 1/(yu*yv)}, yw] - 
     2*G[{1}, yw]*G[{yu^(-1)}, yw]*G[{1, 1/(yu*yv), 1/(yu*yv)}, yw] - 
     3*G[{yu^(-1)}, yw]^2*G[{1, 1/(yu*yv), 1/(yu*yv)}, yw] + 
     2*G[{0}, yu^(-1)]*G[{yu}, yv^(-1)]*G[{1, 1/(yu*yv), 1/(yu*yv)}, yw] + 
     2*G[{0}, yv^(-1)]*G[{yu}, yv^(-1)]*G[{1, 1/(yu*yv), 1/(yu*yv)}, yw] - 
     2*G[{0}, yw]*G[{yu}, yv^(-1)]*G[{1, 1/(yu*yv), 1/(yu*yv)}, yw] - 
     2*G[{1}, yv^(-1)]*G[{yu}, yv^(-1)]*G[{1, 1/(yu*yv), 1/(yu*yv)}, yw] + 
     4*G[{1}, yw]*G[{yu}, yv^(-1)]*G[{1, 1/(yu*yv), 1/(yu*yv)}, yw] + 
     2*G[{yu^(-1)}, yw]*G[{yu}, yv^(-1)]*G[{1, 1/(yu*yv), 1/(yu*yv)}, yw] - 
     G[{yu}, yv^(-1)]^2*G[{1, 1/(yu*yv), 1/(yu*yv)}, yw] + 
     6*G[{0}, yu^(-1)]*G[{1/(yu*yv)}, yw]*G[{1, 1/(yu*yv), 1/(yu*yv)}, yw] + 
     6*G[{0}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{1, 1/(yu*yv), 1/(yu*yv)}, yw] - 
     6*G[{0}, yw]*G[{1/(yu*yv)}, yw]*G[{1, 1/(yu*yv), 1/(yu*yv)}, yw] - 
     4*G[{1}, yu^(-1)]*G[{1/(yu*yv)}, yw]*G[{1, 1/(yu*yv), 1/(yu*yv)}, yw] - 
     6*G[{1}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{1, 1/(yu*yv), 1/(yu*yv)}, yw] + 
     2*G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{1, 1/(yu*yv), 1/(yu*yv)}, yw] + 
     6*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{1, 1/(yu*yv), 1/(yu*yv)}, yw] - 
     2*G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{1, 1/(yu*yv), 1/(yu*yv)}, yw] + 
     2*G[{0, 1}, yu^(-1)]*G[{1, 1/(yu*yv), 1/(yu*yv)}, yw] + 
     2*G[{0, 1}, yw]*G[{1, 1/(yu*yv), 1/(yu*yv)}, yw] - 
     2*G[{0, yu^(-1)}, yw]*G[{1, 1/(yu*yv), 1/(yu*yv)}, yw] - 
     2*G[{0, yv^(-1)}, yw]*G[{1, 1/(yu*yv), 1/(yu*yv)}, yw] + 
     2*G[{0, 1/(yu*yv)}, yw]*G[{1, 1/(yu*yv), 1/(yu*yv)}, yw] + 
     2*G[{1, yu^(-1)}, yw]*G[{1, 1/(yu*yv), 1/(yu*yv)}, yw] - 
     2*G[{1, yu}, yv^(-1)]*G[{1, 1/(yu*yv), 1/(yu*yv)}, yw] + 
     4*G[{1, yv^(-1)}, yw]*G[{1, 1/(yu*yv), 1/(yu*yv)}, yw] - 
     2*G[{1, 1/(yu*yv)}, yw]*G[{1, 1/(yu*yv), 1/(yu*yv)}, yw] - 
     6*G[{yu^(-1), 1/(yu*yv)}, yw]*G[{1, 1/(yu*yv), 1/(yu*yv)}, yw] - 
     (2*Pi^2*G[{yu^(-1), yu^(-1), 1/(yu*yv)}, yw])/3 + 
     8*G[{0}, yu^(-1)]*G[{1}, yu^(-1)]*G[{yu^(-1), yu^(-1), 1/(yu*yv)}, yw] + 
     8*G[{0}, yv^(-1)]*G[{1}, yu^(-1)]*G[{yu^(-1), yu^(-1), 1/(yu*yv)}, yw] - 
     8*G[{0}, yw]*G[{1}, yu^(-1)]*G[{yu^(-1), yu^(-1), 1/(yu*yv)}, yw] - 
     6*G[{1}, yu^(-1)]^2*G[{yu^(-1), yu^(-1), 1/(yu*yv)}, yw] - 
     8*G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*G[{yu^(-1), yu^(-1), 1/(yu*yv)}, yw] + 
     4*G[{0}, yu^(-1)]*G[{1}, yw]*G[{yu^(-1), yu^(-1), 1/(yu*yv)}, yw] + 
     4*G[{0}, yv^(-1)]*G[{1}, yw]*G[{yu^(-1), yu^(-1), 1/(yu*yv)}, yw] - 
     4*G[{0}, yw]*G[{1}, yw]*G[{yu^(-1), yu^(-1), 1/(yu*yv)}, yw] - 
     4*G[{1}, yv^(-1)]*G[{1}, yw]*G[{yu^(-1), yu^(-1), 1/(yu*yv)}, yw] + 
     2*G[{1}, yw]^2*G[{yu^(-1), yu^(-1), 1/(yu*yv)}, yw] + 
     4*G[{0}, yu^(-1)]*G[{yu^(-1)}, yw]*G[{yu^(-1), yu^(-1), 1/(yu*yv)}, 
       yw] + 4*G[{0}, yv^(-1)]*G[{yu^(-1)}, yw]*
      G[{yu^(-1), yu^(-1), 1/(yu*yv)}, yw] - 4*G[{0}, yw]*G[{yu^(-1)}, yw]*
      G[{yu^(-1), yu^(-1), 1/(yu*yv)}, yw] + 4*G[{1}, yu^(-1)]*
      G[{yu^(-1)}, yw]*G[{yu^(-1), yu^(-1), 1/(yu*yv)}, yw] - 
     2*G[{1}, yv^(-1)]*G[{yu^(-1)}, yw]*G[{yu^(-1), yu^(-1), 1/(yu*yv)}, 
       yw] + 10*G[{1}, yw]*G[{yu^(-1)}, yw]*G[{yu^(-1), yu^(-1), 1/(yu*yv)}, 
       yw] + G[{yu^(-1)}, yw]^2*G[{yu^(-1), yu^(-1), 1/(yu*yv)}, yw] - 
     8*G[{0}, yu^(-1)]*G[{yu}, yv^(-1)]*G[{yu^(-1), yu^(-1), 1/(yu*yv)}, 
       yw] - 8*G[{0}, yv^(-1)]*G[{yu}, yv^(-1)]*
      G[{yu^(-1), yu^(-1), 1/(yu*yv)}, yw] + 8*G[{0}, yw]*G[{yu}, yv^(-1)]*
      G[{yu^(-1), yu^(-1), 1/(yu*yv)}, yw] + 4*G[{1}, yu^(-1)]*
      G[{yu}, yv^(-1)]*G[{yu^(-1), yu^(-1), 1/(yu*yv)}, yw] + 
     10*G[{1}, yv^(-1)]*G[{yu}, yv^(-1)]*G[{yu^(-1), yu^(-1), 1/(yu*yv)}, 
       yw] - 4*G[{1}, yw]*G[{yu}, yv^(-1)]*G[{yu^(-1), yu^(-1), 1/(yu*yv)}, 
       yw] - 10*G[{yu^(-1)}, yw]*G[{yu}, yv^(-1)]*
      G[{yu^(-1), yu^(-1), 1/(yu*yv)}, yw] + G[{yu}, yv^(-1)]^2*
      G[{yu^(-1), yu^(-1), 1/(yu*yv)}, yw] - 4*G[{0}, yu^(-1)]*
      G[{1/(yu*yv)}, yw]*G[{yu^(-1), yu^(-1), 1/(yu*yv)}, yw] - 
     4*G[{0}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{yu^(-1), yu^(-1), 1/(yu*yv)}, 
       yw] + 4*G[{0}, yw]*G[{1/(yu*yv)}, yw]*G[{yu^(-1), yu^(-1), 1/(yu*yv)}, 
       yw] + 4*G[{1}, yu^(-1)]*G[{1/(yu*yv)}, yw]*
      G[{yu^(-1), yu^(-1), 1/(yu*yv)}, yw] + 2*G[{1}, yv^(-1)]*
      G[{1/(yu*yv)}, yw]*G[{yu^(-1), yu^(-1), 1/(yu*yv)}, yw] - 
     2*G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{yu^(-1), yu^(-1), 1/(yu*yv)}, yw] - 
     2*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{yu^(-1), yu^(-1), 1/(yu*yv)}, 
       yw] + 2*G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw]*
      G[{yu^(-1), yu^(-1), 1/(yu*yv)}, yw] + 2*G[{1/(yu*yv)}, yw]^2*
      G[{yu^(-1), yu^(-1), 1/(yu*yv)}, yw] - 2*G[{0, 1}, yv^(-1)]*
      G[{yu^(-1), yu^(-1), 1/(yu*yv)}, yw] - 4*G[{0, 1}, yw]*
      G[{yu^(-1), yu^(-1), 1/(yu*yv)}, yw] + 4*G[{0, yu^(-1)}, yw]*
      G[{yu^(-1), yu^(-1), 1/(yu*yv)}, yw] + 2*G[{0, yu}, yv^(-1)]*
      G[{yu^(-1), yu^(-1), 1/(yu*yv)}, yw] + 4*G[{0, yv^(-1)}, yw]*
      G[{yu^(-1), yu^(-1), 1/(yu*yv)}, yw] - 4*G[{0, 1/(yu*yv)}, yw]*
      G[{yu^(-1), yu^(-1), 1/(yu*yv)}, yw] - 6*G[{1, yu^(-1)}, yw]*
      G[{yu^(-1), yu^(-1), 1/(yu*yv)}, yw] - 2*G[{1, yu}, yv^(-1)]*
      G[{yu^(-1), yu^(-1), 1/(yu*yv)}, yw] - 4*G[{1, yv^(-1)}, yw]*
      G[{yu^(-1), yu^(-1), 1/(yu*yv)}, yw] + 2*G[{1, 1/(yu*yv)}, yw]*
      G[{yu^(-1), yu^(-1), 1/(yu*yv)}, yw] + 6*G[{yu^(-1), 1/(yu*yv)}, yw]*
      G[{yu^(-1), yu^(-1), 1/(yu*yv)}, yw] + 
     (Pi^2*G[{yu^(-1), 1/(yu*yv), yv^(-1)}, yw])/3 - 
     2*G[{0}, yu^(-1)]*G[{1}, yu^(-1)]*G[{yu^(-1), 1/(yu*yv), yv^(-1)}, yw] - 
     2*G[{0}, yv^(-1)]*G[{1}, yu^(-1)]*G[{yu^(-1), 1/(yu*yv), yv^(-1)}, yw] + 
     2*G[{0}, yw]*G[{1}, yu^(-1)]*G[{yu^(-1), 1/(yu*yv), yv^(-1)}, yw] + 
     2*G[{1}, yu^(-1)]^2*G[{yu^(-1), 1/(yu*yv), yv^(-1)}, yw] + 
     4*G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*G[{yu^(-1), 1/(yu*yv), yv^(-1)}, yw] - 
     4*G[{0}, yu^(-1)]*G[{1}, yw]*G[{yu^(-1), 1/(yu*yv), yv^(-1)}, yw] - 
     4*G[{0}, yv^(-1)]*G[{1}, yw]*G[{yu^(-1), 1/(yu*yv), yv^(-1)}, yw] + 
     4*G[{0}, yw]*G[{1}, yw]*G[{yu^(-1), 1/(yu*yv), yv^(-1)}, yw] + 
     4*G[{1}, yu^(-1)]*G[{1}, yw]*G[{yu^(-1), 1/(yu*yv), yv^(-1)}, yw] + 
     4*G[{1}, yv^(-1)]*G[{1}, yw]*G[{yu^(-1), 1/(yu*yv), yv^(-1)}, yw] + 
     2*G[{0}, yu^(-1)]*G[{yu^(-1)}, yw]*G[{yu^(-1), 1/(yu*yv), yv^(-1)}, 
       yw] + 2*G[{0}, yv^(-1)]*G[{yu^(-1)}, yw]*
      G[{yu^(-1), 1/(yu*yv), yv^(-1)}, yw] - 2*G[{0}, yw]*G[{yu^(-1)}, yw]*
      G[{yu^(-1), 1/(yu*yv), yv^(-1)}, yw] - 4*G[{1}, yu^(-1)]*
      G[{yu^(-1)}, yw]*G[{yu^(-1), 1/(yu*yv), yv^(-1)}, yw] + 
     2*G[{0}, yu^(-1)]*G[{yu}, yv^(-1)]*G[{yu^(-1), 1/(yu*yv), yv^(-1)}, 
       yw] + 2*G[{0}, yv^(-1)]*G[{yu}, yv^(-1)]*
      G[{yu^(-1), 1/(yu*yv), yv^(-1)}, yw] - 2*G[{0}, yw]*G[{yu}, yv^(-1)]*
      G[{yu^(-1), 1/(yu*yv), yv^(-1)}, yw] - 4*G[{1}, yu^(-1)]*
      G[{yu}, yv^(-1)]*G[{yu^(-1), 1/(yu*yv), yv^(-1)}, yw] + 
     2*G[{0}, yu^(-1)]*G[{1/(yu*yv)}, yw]*G[{yu^(-1), 1/(yu*yv), yv^(-1)}, 
       yw] + 2*G[{0}, yv^(-1)]*G[{1/(yu*yv)}, yw]*
      G[{yu^(-1), 1/(yu*yv), yv^(-1)}, yw] - 2*G[{0}, yw]*G[{1/(yu*yv)}, yw]*
      G[{yu^(-1), 1/(yu*yv), yv^(-1)}, yw] - 4*G[{1}, yu^(-1)]*
      G[{1/(yu*yv)}, yw]*G[{yu^(-1), 1/(yu*yv), yv^(-1)}, yw] - 
     4*G[{1}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{yu^(-1), 1/(yu*yv), yv^(-1)}, 
       yw] - 4*G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{yu^(-1), 1/(yu*yv), yv^(-1)}, 
       yw] + 4*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*
      G[{yu^(-1), 1/(yu*yv), yv^(-1)}, yw] + 4*G[{yu}, yv^(-1)]*
      G[{1/(yu*yv)}, yw]*G[{yu^(-1), 1/(yu*yv), yv^(-1)}, yw] + 
     2*G[{0, 1}, yu^(-1)]*G[{yu^(-1), 1/(yu*yv), yv^(-1)}, yw] - 
     2*G[{0, 1}, yv^(-1)]*G[{yu^(-1), 1/(yu*yv), yv^(-1)}, yw] - 
     2*G[{0, 1}, yw]*G[{yu^(-1), 1/(yu*yv), yv^(-1)}, yw] + 
     2*G[{0, yu^(-1)}, yw]*G[{yu^(-1), 1/(yu*yv), yv^(-1)}, yw] + 
     2*G[{0, yu}, yv^(-1)]*G[{yu^(-1), 1/(yu*yv), yv^(-1)}, yw] + 
     2*G[{0, yv^(-1)}, yw]*G[{yu^(-1), 1/(yu*yv), yv^(-1)}, yw] - 
     2*G[{0, 1/(yu*yv)}, yw]*G[{yu^(-1), 1/(yu*yv), yv^(-1)}, yw] - 
     4*G[{1, yu^(-1)}, yw]*G[{yu^(-1), 1/(yu*yv), yv^(-1)}, yw] - 
     4*G[{1, yu}, yv^(-1)]*G[{yu^(-1), 1/(yu*yv), yv^(-1)}, yw] - 
     (2*Pi^2*G[{yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/3 + 
     8*G[{0}, yu^(-1)]*G[{1}, yu^(-1)]*G[{yu^(-1), 1/(yu*yv), 1/(yu*yv)}, 
       yw] + 8*G[{0}, yv^(-1)]*G[{1}, yu^(-1)]*
      G[{yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] - 8*G[{0}, yw]*G[{1}, yu^(-1)]*
      G[{yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] - 6*G[{1}, yu^(-1)]^2*
      G[{yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] - 8*G[{1}, yu^(-1)]*
      G[{1}, yv^(-1)]*G[{yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] + 
     4*G[{0}, yu^(-1)]*G[{1}, yw]*G[{yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] + 
     4*G[{0}, yv^(-1)]*G[{1}, yw]*G[{yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] - 
     4*G[{0}, yw]*G[{1}, yw]*G[{yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] - 
     4*G[{1}, yv^(-1)]*G[{1}, yw]*G[{yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] + 
     2*G[{1}, yw]^2*G[{yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] + 
     4*G[{0}, yu^(-1)]*G[{yu^(-1)}, yw]*G[{yu^(-1), 1/(yu*yv), 1/(yu*yv)}, 
       yw] + 4*G[{0}, yv^(-1)]*G[{yu^(-1)}, yw]*
      G[{yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] - 4*G[{0}, yw]*G[{yu^(-1)}, yw]*
      G[{yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] + 4*G[{1}, yu^(-1)]*
      G[{yu^(-1)}, yw]*G[{yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] - 
     2*G[{1}, yv^(-1)]*G[{yu^(-1)}, yw]*G[{yu^(-1), 1/(yu*yv), 1/(yu*yv)}, 
       yw] + 10*G[{1}, yw]*G[{yu^(-1)}, yw]*
      G[{yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] + G[{yu^(-1)}, yw]^2*
      G[{yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] - 8*G[{0}, yu^(-1)]*
      G[{yu}, yv^(-1)]*G[{yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] - 
     8*G[{0}, yv^(-1)]*G[{yu}, yv^(-1)]*G[{yu^(-1), 1/(yu*yv), 1/(yu*yv)}, 
       yw] + 8*G[{0}, yw]*G[{yu}, yv^(-1)]*G[{yu^(-1), 1/(yu*yv), 1/(yu*yv)}, 
       yw] + 4*G[{1}, yu^(-1)]*G[{yu}, yv^(-1)]*
      G[{yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] + 10*G[{1}, yv^(-1)]*
      G[{yu}, yv^(-1)]*G[{yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] - 
     4*G[{1}, yw]*G[{yu}, yv^(-1)]*G[{yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] - 
     10*G[{yu^(-1)}, yw]*G[{yu}, yv^(-1)]*G[{yu^(-1), 1/(yu*yv), 1/(yu*yv)}, 
       yw] + G[{yu}, yv^(-1)]^2*G[{yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] - 
     4*G[{0}, yu^(-1)]*G[{1/(yu*yv)}, yw]*G[{yu^(-1), 1/(yu*yv), 1/(yu*yv)}, 
       yw] - 4*G[{0}, yv^(-1)]*G[{1/(yu*yv)}, yw]*
      G[{yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] + 
     4*G[{0}, yw]*G[{1/(yu*yv)}, yw]*G[{yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] - 
     4*G[{1}, yu^(-1)]*G[{1/(yu*yv)}, yw]*G[{yu^(-1), 1/(yu*yv), 1/(yu*yv)}, 
       yw] + 2*G[{1}, yv^(-1)]*G[{1/(yu*yv)}, yw]*
      G[{yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] - 
     10*G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{yu^(-1), 1/(yu*yv), 1/(yu*yv)}, 
       yw] - 2*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*
      G[{yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] + 10*G[{yu}, yv^(-1)]*
      G[{1/(yu*yv)}, yw]*G[{yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] - 
     2*G[{0, 1}, yv^(-1)]*G[{yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] - 
     4*G[{0, 1}, yw]*G[{yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] + 
     4*G[{0, yu^(-1)}, yw]*G[{yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] + 
     2*G[{0, yu}, yv^(-1)]*G[{yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] + 
     4*G[{0, yv^(-1)}, yw]*G[{yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] - 
     4*G[{0, 1/(yu*yv)}, yw]*G[{yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] - 
     6*G[{1, yu^(-1)}, yw]*G[{yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] - 
     2*G[{1, yu}, yv^(-1)]*G[{yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] - 
     4*G[{1, yv^(-1)}, yw]*G[{yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] + 
     2*G[{1, 1/(yu*yv)}, yw]*G[{yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] + 
     2*G[{yu^(-1), 1/(yu*yv)}, yw]*G[{yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] - 
     4*G[{0}, yu^(-1)]*G[{1/(yu*yv)}, yw]*G[{yv^(-1), yv^(-1), 1/(yu*yv)}, 
       yw] - 4*G[{0}, yv^(-1)]*G[{1/(yu*yv)}, yw]*
      G[{yv^(-1), yv^(-1), 1/(yu*yv)}, yw] + 4*G[{0}, yw]*G[{1/(yu*yv)}, yw]*
      G[{yv^(-1), yv^(-1), 1/(yu*yv)}, yw] + 8*G[{1}, yu^(-1)]*
      G[{1/(yu*yv)}, yw]*G[{yv^(-1), yv^(-1), 1/(yu*yv)}, yw] + 
     4*G[{1}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{yv^(-1), yv^(-1), 1/(yu*yv)}, 
       yw] + 4*G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{yv^(-1), yv^(-1), 1/(yu*yv)}, 
       yw] - 4*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*
      G[{yv^(-1), yv^(-1), 1/(yu*yv)}, yw] - 4*G[{yu}, yv^(-1)]*
      G[{1/(yu*yv)}, yw]*G[{yv^(-1), yv^(-1), 1/(yu*yv)}, yw] - 
     8*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{yv^(-1), yv^(-1), 1/(yu*yv)}, 
       yw] - 2*G[{1/(yu*yv)}, yw]^2*G[{yv^(-1), yv^(-1), 1/(yu*yv)}, yw] - 
     (Pi^2*G[{yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/3 + 
     2*G[{0}, yu^(-1)]*G[{1}, yu^(-1)]*G[{yv^(-1), 1/(yu*yv), 1/(yu*yv)}, 
       yw] + 2*G[{0}, yv^(-1)]*G[{1}, yu^(-1)]*
      G[{yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] - 2*G[{0}, yw]*G[{1}, yu^(-1)]*
      G[{yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] - 2*G[{1}, yu^(-1)]^2*
      G[{yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] - 4*G[{1}, yu^(-1)]*
      G[{1}, yv^(-1)]*G[{yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] + 
     4*G[{0}, yu^(-1)]*G[{1}, yw]*G[{yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] + 
     4*G[{0}, yv^(-1)]*G[{1}, yw]*G[{yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] - 
     4*G[{0}, yw]*G[{1}, yw]*G[{yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] - 
     4*G[{1}, yu^(-1)]*G[{1}, yw]*G[{yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] - 
     4*G[{1}, yv^(-1)]*G[{1}, yw]*G[{yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] - 
     2*G[{0}, yu^(-1)]*G[{yu^(-1)}, yw]*G[{yv^(-1), 1/(yu*yv), 1/(yu*yv)}, 
       yw] - 2*G[{0}, yv^(-1)]*G[{yu^(-1)}, yw]*
      G[{yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] + 2*G[{0}, yw]*G[{yu^(-1)}, yw]*
      G[{yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] + 4*G[{1}, yu^(-1)]*
      G[{yu^(-1)}, yw]*G[{yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] - 
     2*G[{0}, yu^(-1)]*G[{yu}, yv^(-1)]*G[{yv^(-1), 1/(yu*yv), 1/(yu*yv)}, 
       yw] - 2*G[{0}, yv^(-1)]*G[{yu}, yv^(-1)]*
      G[{yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] + 2*G[{0}, yw]*G[{yu}, yv^(-1)]*
      G[{yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] + 4*G[{1}, yu^(-1)]*
      G[{yu}, yv^(-1)]*G[{yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] - 
     4*G[{0}, yu^(-1)]*G[{yv^(-1)}, yw]*G[{yv^(-1), 1/(yu*yv), 1/(yu*yv)}, 
       yw] - 4*G[{0}, yv^(-1)]*G[{yv^(-1)}, yw]*
      G[{yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] + 4*G[{0}, yw]*G[{yv^(-1)}, yw]*
      G[{yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] + 8*G[{1}, yu^(-1)]*
      G[{yv^(-1)}, yw]*G[{yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] + 
     4*G[{1}, yv^(-1)]*G[{yv^(-1)}, yw]*G[{yv^(-1), 1/(yu*yv), 1/(yu*yv)}, 
       yw] + 4*G[{1}, yw]*G[{yv^(-1)}, yw]*G[{yv^(-1), 1/(yu*yv), 1/(yu*yv)}, 
       yw] - 4*G[{yu^(-1)}, yw]*G[{yv^(-1)}, yw]*
      G[{yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] - 4*G[{yu}, yv^(-1)]*
      G[{yv^(-1)}, yw]*G[{yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] - 
     4*G[{yv^(-1)}, yw]^2*G[{yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] - 
     2*G[{0}, yu^(-1)]*G[{1/(yu*yv)}, yw]*G[{yv^(-1), 1/(yu*yv), 1/(yu*yv)}, 
       yw] - 2*G[{0}, yv^(-1)]*G[{1/(yu*yv)}, yw]*
      G[{yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] + 
     2*G[{0}, yw]*G[{1/(yu*yv)}, yw]*G[{yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] + 
     4*G[{1}, yu^(-1)]*G[{1/(yu*yv)}, yw]*G[{yv^(-1), 1/(yu*yv), 1/(yu*yv)}, 
       yw] + 4*G[{1}, yv^(-1)]*G[{1/(yu*yv)}, yw]*
      G[{yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] + 
     4*G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] - 
     4*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{yv^(-1), 1/(yu*yv), 1/(yu*yv)}, 
       yw] - 4*G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw]*
      G[{yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] - 4*G[{yv^(-1)}, yw]*
      G[{1/(yu*yv)}, yw]*G[{yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] - 
     2*G[{0, 1}, yu^(-1)]*G[{yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] + 
     2*G[{0, 1}, yv^(-1)]*G[{yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] + 
     2*G[{0, 1}, yw]*G[{yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] - 
     2*G[{0, yu^(-1)}, yw]*G[{yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] - 
     2*G[{0, yu}, yv^(-1)]*G[{yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] - 
     2*G[{0, yv^(-1)}, yw]*G[{yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] + 
     2*G[{0, 1/(yu*yv)}, yw]*G[{yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] + 
     4*G[{1, yu^(-1)}, yw]*G[{yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] + 
     4*G[{1, yu}, yv^(-1)]*G[{yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] - 
     4*G[{yv^(-1), 1/(yu*yv)}, yw]*G[{yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] + 
     4*G[{1}, yu^(-1)]*G[{0, 0, 1, 1}, yu^(-1)] - 4*G[{yu}, yv^(-1)]*
      G[{0, 0, 1, 1}, yu^(-1)] - 4*G[{yu^(-1)}, yw]*
      G[{0, 0, 1, 1}, yv^(-1)] + 4*G[{1/(yu*yv)}, yw]*
      G[{0, 0, 1, 1}, yv^(-1)] - 4*G[{yu^(-1)}, yw]*G[{0, 0, 1, 1}, yw] + 
     4*G[{1/(yu*yv)}, yw]*G[{0, 0, 1, 1}, yw] + 4*G[{yu^(-1)}, yw]*
      G[{0, 0, 1, yu^(-1)}, yw] - 4*G[{1/(yu*yv)}, yw]*
      G[{0, 0, 1, yu^(-1)}, yw] - 4*G[{yu}, yv^(-1)]*
      G[{0, 0, 1, yu}, yv^(-1)] + 4*G[{yu^(-1)}, yw]*
      G[{0, 0, 1, yv^(-1)}, yw] - 4*G[{1/(yu*yv)}, yw]*
      G[{0, 0, 1, yv^(-1)}, yw] - 4*G[{yu^(-1)}, yw]*
      G[{0, 0, 1, 1/(yu*yv)}, yw] + 4*G[{1/(yu*yv)}, yw]*
      G[{0, 0, 1, 1/(yu*yv)}, yw] + 4*G[{yu^(-1)}, yw]*
      G[{0, 0, yu^(-1), 1}, yw] - 4*G[{1/(yu*yv)}, yw]*
      G[{0, 0, yu^(-1), 1}, yw] - 4*G[{1}, yu^(-1)]*
      G[{0, 0, yu^(-1), yu^(-1)}, yw] + 4*G[{yu}, yv^(-1)]*
      G[{0, 0, yu^(-1), yu^(-1)}, yw] - 4*G[{1}, yu^(-1)]*
      G[{0, 0, yu^(-1), yv^(-1)}, yw] + 4*G[{yu}, yv^(-1)]*
      G[{0, 0, yu^(-1), yv^(-1)}, yw] + 4*G[{1}, yu^(-1)]*
      G[{0, 0, yu^(-1), 1/(yu*yv)}, yw] - 4*G[{yu}, yv^(-1)]*
      G[{0, 0, yu^(-1), 1/(yu*yv)}, yw] - 4*G[{1}, yu^(-1)]*
      G[{0, 0, yu, 1}, yv^(-1)] - 4*G[{yu}, yv^(-1)]*
      G[{0, 0, yu, 1}, yv^(-1)] + 4*G[{yu}, yv^(-1)]*
      G[{0, 0, yu, yu}, yv^(-1)] + 4*G[{yu^(-1)}, yw]*
      G[{0, 0, yv^(-1), 1}, yw] - 4*G[{1/(yu*yv)}, yw]*
      G[{0, 0, yv^(-1), 1}, yw] - 4*G[{1}, yu^(-1)]*
      G[{0, 0, yv^(-1), yu^(-1)}, yw] + 4*G[{yu}, yv^(-1)]*
      G[{0, 0, yv^(-1), yu^(-1)}, yw] - 4*G[{yu^(-1)}, yw]*
      G[{0, 0, yv^(-1), yv^(-1)}, yw] + 4*G[{1/(yu*yv)}, yw]*
      G[{0, 0, yv^(-1), yv^(-1)}, yw] + 4*G[{yu^(-1)}, yw]*
      G[{0, 0, yv^(-1), 1/(yu*yv)}, yw] - 4*G[{1/(yu*yv)}, yw]*
      G[{0, 0, yv^(-1), 1/(yu*yv)}, yw] - 4*G[{yu^(-1)}, yw]*
      G[{0, 0, 1/(yu*yv), 1}, yw] + 4*G[{1/(yu*yv)}, yw]*
      G[{0, 0, 1/(yu*yv), 1}, yw] + 4*G[{1}, yu^(-1)]*
      G[{0, 0, 1/(yu*yv), yu^(-1)}, yw] - 4*G[{yu}, yv^(-1)]*
      G[{0, 0, 1/(yu*yv), yu^(-1)}, yw] + 4*G[{yu^(-1)}, yw]*
      G[{0, 0, 1/(yu*yv), yv^(-1)}, yw] - 4*G[{1/(yu*yv)}, yw]*
      G[{0, 0, 1/(yu*yv), yv^(-1)}, yw] - 4*G[{1}, yu^(-1)]*
      G[{0, 0, 1/(yu*yv), 1/(yu*yv)}, yw] + 4*G[{yu}, yv^(-1)]*
      G[{0, 0, 1/(yu*yv), 1/(yu*yv)}, yw] - 2*G[{1}, yu^(-1)]*
      G[{0, 1, 0, yu^(-1)}, yw] + 2*G[{yu^(-1)}, yw]*
      G[{0, 1, 0, yu^(-1)}, yw] + 2*G[{yu}, yv^(-1)]*
      G[{0, 1, 0, yu^(-1)}, yw] - 2*G[{1/(yu*yv)}, yw]*
      G[{0, 1, 0, yu^(-1)}, yw] - 2*G[{1}, yu^(-1)]*
      G[{0, 1, 0, yu}, yv^(-1)] - 2*G[{yu^(-1)}, yw]*
      G[{0, 1, 0, yu}, yv^(-1)] - 2*G[{yu}, yv^(-1)]*
      G[{0, 1, 0, yu}, yv^(-1)] + 2*G[{1/(yu*yv)}, yw]*
      G[{0, 1, 0, yu}, yv^(-1)] + 2*G[{1}, yu^(-1)]*G[{0, 1, 0, 1/(yu*yv)}, 
       yw] - 2*G[{yu^(-1)}, yw]*G[{0, 1, 0, 1/(yu*yv)}, yw] - 
     2*G[{yu}, yv^(-1)]*G[{0, 1, 0, 1/(yu*yv)}, yw] + 
     2*G[{1/(yu*yv)}, yw]*G[{0, 1, 0, 1/(yu*yv)}, yw] + 
     6*G[{1}, yu^(-1)]*G[{0, 1, 1, 1}, yu^(-1)] - 6*G[{yu^(-1)}, yw]*
      G[{0, 1, 1, 1}, yu^(-1)] - 6*G[{yu}, yv^(-1)]*
      G[{0, 1, 1, 1}, yu^(-1)] + 6*G[{1/(yu*yv)}, yw]*
      G[{0, 1, 1, 1}, yu^(-1)] - 2*G[{yu^(-1)}, yw]*G[{0, 1, 1, 1}, yw] + 
     2*G[{1/(yu*yv)}, yw]*G[{0, 1, 1, 1}, yw] + 4*G[{0}, yu^(-1)]*
      G[{0, 1, 1, yu^(-1)}, yw] + 4*G[{0}, yv^(-1)]*G[{0, 1, 1, yu^(-1)}, 
       yw] - 4*G[{0}, yw]*G[{0, 1, 1, yu^(-1)}, yw] - 
     2*G[{1}, yu^(-1)]*G[{0, 1, 1, yu^(-1)}, yw] - 
     4*G[{1}, yv^(-1)]*G[{0, 1, 1, yu^(-1)}, yw] - 
     4*G[{yu^(-1)}, yw]*G[{0, 1, 1, yu^(-1)}, yw] - 
     2*G[{yu}, yv^(-1)]*G[{0, 1, 1, yu^(-1)}, yw] + 
     4*G[{1/(yu*yv)}, yw]*G[{0, 1, 1, yu^(-1)}, yw] + 
     2*G[{1}, yu^(-1)]*G[{0, 1, 1, yu}, yv^(-1)] + 
     2*G[{yu^(-1)}, yw]*G[{0, 1, 1, yu}, yv^(-1)] + 
     6*G[{yu}, yv^(-1)]*G[{0, 1, 1, yu}, yv^(-1)] - 
     2*G[{1/(yu*yv)}, yw]*G[{0, 1, 1, yu}, yv^(-1)] - 
     2*G[{yu^(-1)}, yw]*G[{0, 1, 1, yv^(-1)}, yw] + 
     2*G[{1/(yu*yv)}, yw]*G[{0, 1, 1, yv^(-1)}, yw] - 
     4*G[{0}, yu^(-1)]*G[{0, 1, 1, 1/(yu*yv)}, yw] - 
     4*G[{0}, yv^(-1)]*G[{0, 1, 1, 1/(yu*yv)}, yw] + 
     4*G[{0}, yw]*G[{0, 1, 1, 1/(yu*yv)}, yw] + 2*G[{1}, yu^(-1)]*
      G[{0, 1, 1, 1/(yu*yv)}, yw] + 4*G[{1}, yv^(-1)]*
      G[{0, 1, 1, 1/(yu*yv)}, yw] + 2*G[{yu}, yv^(-1)]*
      G[{0, 1, 1, 1/(yu*yv)}, yw] + 4*G[{0}, yu^(-1)]*
      G[{0, 1, yu^(-1), 1}, yw] + 4*G[{0}, yv^(-1)]*G[{0, 1, yu^(-1), 1}, 
       yw] - 4*G[{0}, yw]*G[{0, 1, yu^(-1), 1}, yw] - 
     4*G[{1}, yu^(-1)]*G[{0, 1, yu^(-1), 1}, yw] - 
     4*G[{1}, yv^(-1)]*G[{0, 1, yu^(-1), 1}, yw] - 
     4*G[{yu^(-1)}, yw]*G[{0, 1, yu^(-1), 1}, yw] + 
     4*G[{1/(yu*yv)}, yw]*G[{0, 1, yu^(-1), 1}, yw] - 
     4*G[{0}, yu^(-1)]*G[{0, 1, yu^(-1), yu^(-1)}, yw] - 
     4*G[{0}, yv^(-1)]*G[{0, 1, yu^(-1), yu^(-1)}, yw] + 
     4*G[{0}, yw]*G[{0, 1, yu^(-1), yu^(-1)}, yw] + 
     8*G[{1}, yu^(-1)]*G[{0, 1, yu^(-1), yu^(-1)}, yw] + 
     4*G[{1}, yv^(-1)]*G[{0, 1, yu^(-1), yu^(-1)}, yw] + 
     4*G[{yu^(-1)}, yw]*G[{0, 1, yu^(-1), yu^(-1)}, yw] - 
     4*G[{yu}, yv^(-1)]*G[{0, 1, yu^(-1), yu^(-1)}, yw] - 
     4*G[{1/(yu*yv)}, yw]*G[{0, 1, yu^(-1), yu^(-1)}, yw] - 
     4*G[{0}, yu^(-1)]*G[{0, 1, yu^(-1), yv^(-1)}, yw] - 
     4*G[{0}, yv^(-1)]*G[{0, 1, yu^(-1), yv^(-1)}, yw] + 
     4*G[{0}, yw]*G[{0, 1, yu^(-1), yv^(-1)}, yw] + 
     8*G[{1}, yu^(-1)]*G[{0, 1, yu^(-1), yv^(-1)}, yw] + 
     4*G[{1}, yv^(-1)]*G[{0, 1, yu^(-1), yv^(-1)}, yw] + 
     4*G[{yu^(-1)}, yw]*G[{0, 1, yu^(-1), yv^(-1)}, yw] - 
     4*G[{yu}, yv^(-1)]*G[{0, 1, yu^(-1), yv^(-1)}, yw] - 
     4*G[{1/(yu*yv)}, yw]*G[{0, 1, yu^(-1), yv^(-1)}, yw] + 
     4*G[{0}, yu^(-1)]*G[{0, 1, yu^(-1), 1/(yu*yv)}, yw] + 
     4*G[{0}, yv^(-1)]*G[{0, 1, yu^(-1), 1/(yu*yv)}, yw] - 
     4*G[{0}, yw]*G[{0, 1, yu^(-1), 1/(yu*yv)}, yw] - 
     8*G[{1}, yu^(-1)]*G[{0, 1, yu^(-1), 1/(yu*yv)}, yw] - 
     4*G[{1}, yv^(-1)]*G[{0, 1, yu^(-1), 1/(yu*yv)}, yw] + 
     4*G[{yu}, yv^(-1)]*G[{0, 1, yu^(-1), 1/(yu*yv)}, yw] + 
     4*G[{1}, yu^(-1)]*G[{0, 1, yu, 1}, yv^(-1)] + 
     4*G[{yu}, yv^(-1)]*G[{0, 1, yu, 1}, yv^(-1)] - 
     8*G[{yu}, yv^(-1)]*G[{0, 1, yu, yu}, yv^(-1)] - 
     4*G[{yu^(-1)}, yw]*G[{0, 1, yv^(-1), 1}, yw] + 
     4*G[{1/(yu*yv)}, yw]*G[{0, 1, yv^(-1), 1}, yw] - 
     4*G[{0}, yu^(-1)]*G[{0, 1, yv^(-1), yu^(-1)}, yw] - 
     4*G[{0}, yv^(-1)]*G[{0, 1, yv^(-1), yu^(-1)}, yw] + 
     4*G[{0}, yw]*G[{0, 1, yv^(-1), yu^(-1)}, yw] + 
     8*G[{1}, yu^(-1)]*G[{0, 1, yv^(-1), yu^(-1)}, yw] + 
     4*G[{1}, yv^(-1)]*G[{0, 1, yv^(-1), yu^(-1)}, yw] + 
     4*G[{yu^(-1)}, yw]*G[{0, 1, yv^(-1), yu^(-1)}, yw] - 
     4*G[{yu}, yv^(-1)]*G[{0, 1, yv^(-1), yu^(-1)}, yw] - 
     4*G[{1/(yu*yv)}, yw]*G[{0, 1, yv^(-1), yu^(-1)}, yw] + 
     8*G[{yu^(-1)}, yw]*G[{0, 1, yv^(-1), yv^(-1)}, yw] - 
     8*G[{1/(yu*yv)}, yw]*G[{0, 1, yv^(-1), yv^(-1)}, yw] + 
     4*G[{0}, yu^(-1)]*G[{0, 1, yv^(-1), 1/(yu*yv)}, yw] + 
     4*G[{0}, yv^(-1)]*G[{0, 1, yv^(-1), 1/(yu*yv)}, yw] - 
     4*G[{0}, yw]*G[{0, 1, yv^(-1), 1/(yu*yv)}, yw] - 
     8*G[{1}, yu^(-1)]*G[{0, 1, yv^(-1), 1/(yu*yv)}, yw] - 
     4*G[{1}, yv^(-1)]*G[{0, 1, yv^(-1), 1/(yu*yv)}, yw] + 
     4*G[{yu}, yv^(-1)]*G[{0, 1, yv^(-1), 1/(yu*yv)}, yw] - 
     4*G[{0}, yu^(-1)]*G[{0, 1, 1/(yu*yv), 1}, yw] - 
     4*G[{0}, yv^(-1)]*G[{0, 1, 1/(yu*yv), 1}, yw] + 
     4*G[{0}, yw]*G[{0, 1, 1/(yu*yv), 1}, yw] + 4*G[{1}, yu^(-1)]*
      G[{0, 1, 1/(yu*yv), 1}, yw] + 4*G[{1}, yv^(-1)]*
      G[{0, 1, 1/(yu*yv), 1}, yw] + 2*G[{yu^(-1)}, yw]*
      G[{0, 1, 1/(yu*yv), 1}, yw] - 2*G[{1/(yu*yv)}, yw]*
      G[{0, 1, 1/(yu*yv), 1}, yw] + 4*G[{0}, yu^(-1)]*
      G[{0, 1, 1/(yu*yv), yu^(-1)}, yw] + 4*G[{0}, yv^(-1)]*
      G[{0, 1, 1/(yu*yv), yu^(-1)}, yw] - 4*G[{0}, yw]*
      G[{0, 1, 1/(yu*yv), yu^(-1)}, yw] - 6*G[{1}, yu^(-1)]*
      G[{0, 1, 1/(yu*yv), yu^(-1)}, yw] - 4*G[{1}, yv^(-1)]*
      G[{0, 1, 1/(yu*yv), yu^(-1)}, yw] - 4*G[{yu^(-1)}, yw]*
      G[{0, 1, 1/(yu*yv), yu^(-1)}, yw] + 2*G[{yu}, yv^(-1)]*
      G[{0, 1, 1/(yu*yv), yu^(-1)}, yw] + 4*G[{1/(yu*yv)}, yw]*
      G[{0, 1, 1/(yu*yv), yu^(-1)}, yw] + 4*G[{0}, yu^(-1)]*
      G[{0, 1, 1/(yu*yv), yv^(-1)}, yw] + 4*G[{0}, yv^(-1)]*
      G[{0, 1, 1/(yu*yv), yv^(-1)}, yw] - 4*G[{0}, yw]*
      G[{0, 1, 1/(yu*yv), yv^(-1)}, yw] - 8*G[{1}, yu^(-1)]*
      G[{0, 1, 1/(yu*yv), yv^(-1)}, yw] - 4*G[{1}, yv^(-1)]*
      G[{0, 1, 1/(yu*yv), yv^(-1)}, yw] - 2*G[{yu^(-1)}, yw]*
      G[{0, 1, 1/(yu*yv), yv^(-1)}, yw] + 4*G[{yu}, yv^(-1)]*
      G[{0, 1, 1/(yu*yv), yv^(-1)}, yw] + 2*G[{1/(yu*yv)}, yw]*
      G[{0, 1, 1/(yu*yv), yv^(-1)}, yw] - 4*G[{0}, yu^(-1)]*
      G[{0, 1, 1/(yu*yv), 1/(yu*yv)}, yw] - 4*G[{0}, yv^(-1)]*
      G[{0, 1, 1/(yu*yv), 1/(yu*yv)}, yw] + 4*G[{0}, yw]*
      G[{0, 1, 1/(yu*yv), 1/(yu*yv)}, yw] + 6*G[{1}, yu^(-1)]*
      G[{0, 1, 1/(yu*yv), 1/(yu*yv)}, yw] + 4*G[{1}, yv^(-1)]*
      G[{0, 1, 1/(yu*yv), 1/(yu*yv)}, yw] - 2*G[{yu}, yv^(-1)]*
      G[{0, 1, 1/(yu*yv), 1/(yu*yv)}, yw] - 2*G[{1}, yu^(-1)]*
      G[{0, yu^(-1), 0, yv^(-1)}, yw] + 2*G[{yu^(-1)}, yw]*
      G[{0, yu^(-1), 0, yv^(-1)}, yw] + 2*G[{yu}, yv^(-1)]*
      G[{0, yu^(-1), 0, yv^(-1)}, yw] - 2*G[{1/(yu*yv)}, yw]*
      G[{0, yu^(-1), 0, yv^(-1)}, yw] + 4*G[{0}, yu^(-1)]*
      G[{0, yu^(-1), 1, 1}, yw] + 4*G[{0}, yv^(-1)]*G[{0, yu^(-1), 1, 1}, 
       yw] - 4*G[{0}, yw]*G[{0, yu^(-1), 1, 1}, yw] - 
     4*G[{1}, yu^(-1)]*G[{0, yu^(-1), 1, 1}, yw] - 
     4*G[{1}, yv^(-1)]*G[{0, yu^(-1), 1, 1}, yw] - 
     2*G[{yu^(-1)}, yw]*G[{0, yu^(-1), 1, 1}, yw] + 
     2*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1), 1, 1}, yw] - 
     4*G[{0}, yu^(-1)]*G[{0, yu^(-1), 1, yu^(-1)}, yw] - 
     4*G[{0}, yv^(-1)]*G[{0, yu^(-1), 1, yu^(-1)}, yw] + 
     4*G[{0}, yw]*G[{0, yu^(-1), 1, yu^(-1)}, yw] + 
     6*G[{1}, yu^(-1)]*G[{0, yu^(-1), 1, yu^(-1)}, yw] + 
     4*G[{1}, yv^(-1)]*G[{0, yu^(-1), 1, yu^(-1)}, yw] + 
     4*G[{yu^(-1)}, yw]*G[{0, yu^(-1), 1, yu^(-1)}, yw] - 
     2*G[{yu}, yv^(-1)]*G[{0, yu^(-1), 1, yu^(-1)}, yw] - 
     4*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1), 1, yu^(-1)}, yw] - 
     4*G[{0}, yu^(-1)]*G[{0, yu^(-1), 1, yv^(-1)}, yw] - 
     4*G[{0}, yv^(-1)]*G[{0, yu^(-1), 1, yv^(-1)}, yw] + 
     4*G[{0}, yw]*G[{0, yu^(-1), 1, yv^(-1)}, yw] + 
     8*G[{1}, yu^(-1)]*G[{0, yu^(-1), 1, yv^(-1)}, yw] + 
     4*G[{1}, yv^(-1)]*G[{0, yu^(-1), 1, yv^(-1)}, yw] + 
     2*G[{yu^(-1)}, yw]*G[{0, yu^(-1), 1, yv^(-1)}, yw] - 
     4*G[{yu}, yv^(-1)]*G[{0, yu^(-1), 1, yv^(-1)}, yw] - 
     2*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1), 1, yv^(-1)}, yw] + 
     4*G[{0}, yu^(-1)]*G[{0, yu^(-1), 1, 1/(yu*yv)}, yw] + 
     4*G[{0}, yv^(-1)]*G[{0, yu^(-1), 1, 1/(yu*yv)}, yw] - 
     4*G[{0}, yw]*G[{0, yu^(-1), 1, 1/(yu*yv)}, yw] - 
     6*G[{1}, yu^(-1)]*G[{0, yu^(-1), 1, 1/(yu*yv)}, yw] - 
     4*G[{1}, yv^(-1)]*G[{0, yu^(-1), 1, 1/(yu*yv)}, yw] + 
     2*G[{yu}, yv^(-1)]*G[{0, yu^(-1), 1, 1/(yu*yv)}, yw] - 
     4*G[{0}, yu^(-1)]*G[{0, yu^(-1), yu^(-1), 1}, yw] - 
     4*G[{0}, yv^(-1)]*G[{0, yu^(-1), yu^(-1), 1}, yw] + 
     4*G[{0}, yw]*G[{0, yu^(-1), yu^(-1), 1}, yw] + 
     4*G[{1}, yu^(-1)]*G[{0, yu^(-1), yu^(-1), 1}, yw] + 
     4*G[{1}, yv^(-1)]*G[{0, yu^(-1), yu^(-1), 1}, yw] + 
     4*G[{yu^(-1)}, yw]*G[{0, yu^(-1), yu^(-1), 1}, yw] - 
     4*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1), yu^(-1), 1}, yw] - 
     8*G[{1}, yu^(-1)]*G[{0, yu^(-1), yu^(-1), yu^(-1)}, yw] + 
     8*G[{yu}, yv^(-1)]*G[{0, yu^(-1), yu^(-1), yu^(-1)}, yw] + 
     4*G[{0}, yu^(-1)]*G[{0, yu^(-1), yu^(-1), yv^(-1)}, yw] + 
     4*G[{0}, yv^(-1)]*G[{0, yu^(-1), yu^(-1), yv^(-1)}, yw] - 
     4*G[{0}, yw]*G[{0, yu^(-1), yu^(-1), yv^(-1)}, yw] - 
     8*G[{1}, yu^(-1)]*G[{0, yu^(-1), yu^(-1), yv^(-1)}, yw] - 
     4*G[{1}, yv^(-1)]*G[{0, yu^(-1), yu^(-1), yv^(-1)}, yw] - 
     4*G[{yu^(-1)}, yw]*G[{0, yu^(-1), yu^(-1), yv^(-1)}, yw] + 
     4*G[{yu}, yv^(-1)]*G[{0, yu^(-1), yu^(-1), yv^(-1)}, yw] + 
     4*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1), yu^(-1), yv^(-1)}, yw] + 
     4*G[{1}, yu^(-1)]*G[{0, yu^(-1), yu^(-1), 1/(yu*yv)}, yw] - 
     4*G[{yu}, yv^(-1)]*G[{0, yu^(-1), yu^(-1), 1/(yu*yv)}, yw] - 
     4*G[{0}, yu^(-1)]*G[{0, yu^(-1), yv^(-1), 1}, yw] - 
     4*G[{0}, yv^(-1)]*G[{0, yu^(-1), yv^(-1), 1}, yw] + 
     4*G[{0}, yw]*G[{0, yu^(-1), yv^(-1), 1}, yw] + 
     4*G[{1}, yu^(-1)]*G[{0, yu^(-1), yv^(-1), 1}, yw] + 
     4*G[{1}, yv^(-1)]*G[{0, yu^(-1), yv^(-1), 1}, yw] + 
     4*G[{yu^(-1)}, yw]*G[{0, yu^(-1), yv^(-1), 1}, yw] - 
     4*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1), yv^(-1), 1}, yw] + 
     4*G[{0}, yu^(-1)]*G[{0, yu^(-1), yv^(-1), yu^(-1)}, yw] + 
     4*G[{0}, yv^(-1)]*G[{0, yu^(-1), yv^(-1), yu^(-1)}, yw] - 
     4*G[{0}, yw]*G[{0, yu^(-1), yv^(-1), yu^(-1)}, yw] - 
     8*G[{1}, yu^(-1)]*G[{0, yu^(-1), yv^(-1), yu^(-1)}, yw] - 
     4*G[{1}, yv^(-1)]*G[{0, yu^(-1), yv^(-1), yu^(-1)}, yw] - 
     4*G[{yu^(-1)}, yw]*G[{0, yu^(-1), yv^(-1), yu^(-1)}, yw] + 
     4*G[{yu}, yv^(-1)]*G[{0, yu^(-1), yv^(-1), yu^(-1)}, yw] + 
     4*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1), yv^(-1), yu^(-1)}, yw] + 
     4*G[{0}, yu^(-1)]*G[{0, yu^(-1), yv^(-1), yv^(-1)}, yw] + 
     4*G[{0}, yv^(-1)]*G[{0, yu^(-1), yv^(-1), yv^(-1)}, yw] - 
     4*G[{0}, yw]*G[{0, yu^(-1), yv^(-1), yv^(-1)}, yw] - 
     8*G[{1}, yu^(-1)]*G[{0, yu^(-1), yv^(-1), yv^(-1)}, yw] - 
     4*G[{1}, yv^(-1)]*G[{0, yu^(-1), yv^(-1), yv^(-1)}, yw] - 
     4*G[{yu^(-1)}, yw]*G[{0, yu^(-1), yv^(-1), yv^(-1)}, yw] + 
     4*G[{yu}, yv^(-1)]*G[{0, yu^(-1), yv^(-1), yv^(-1)}, yw] + 
     4*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1), yv^(-1), yv^(-1)}, yw] - 
     4*G[{0}, yu^(-1)]*G[{0, yu^(-1), yv^(-1), 1/(yu*yv)}, yw] - 
     4*G[{0}, yv^(-1)]*G[{0, yu^(-1), yv^(-1), 1/(yu*yv)}, yw] + 
     4*G[{0}, yw]*G[{0, yu^(-1), yv^(-1), 1/(yu*yv)}, yw] + 
     8*G[{1}, yu^(-1)]*G[{0, yu^(-1), yv^(-1), 1/(yu*yv)}, yw] + 
     4*G[{1}, yv^(-1)]*G[{0, yu^(-1), yv^(-1), 1/(yu*yv)}, yw] - 
     4*G[{yu}, yv^(-1)]*G[{0, yu^(-1), yv^(-1), 1/(yu*yv)}, yw] + 
     4*G[{0}, yu^(-1)]*G[{0, yu^(-1), 1/(yu*yv), 1}, yw] + 
     4*G[{0}, yv^(-1)]*G[{0, yu^(-1), 1/(yu*yv), 1}, yw] - 
     4*G[{0}, yw]*G[{0, yu^(-1), 1/(yu*yv), 1}, yw] - 
     4*G[{1}, yu^(-1)]*G[{0, yu^(-1), 1/(yu*yv), 1}, yw] - 
     4*G[{1}, yv^(-1)]*G[{0, yu^(-1), 1/(yu*yv), 1}, yw] + 
     2*G[{yu^(-1)}, yw]*G[{0, yu^(-1), 1/(yu*yv), 1}, yw] - 
     2*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1), 1/(yu*yv), 1}, yw] + 
     2*G[{1}, yu^(-1)]*G[{0, yu^(-1), 1/(yu*yv), yu^(-1)}, yw] - 
     2*G[{yu}, yv^(-1)]*G[{0, yu^(-1), 1/(yu*yv), yu^(-1)}, yw] - 
     4*G[{0}, yu^(-1)]*G[{0, yu^(-1), 1/(yu*yv), yv^(-1)}, yw] - 
     4*G[{0}, yv^(-1)]*G[{0, yu^(-1), 1/(yu*yv), yv^(-1)}, yw] + 
     4*G[{0}, yw]*G[{0, yu^(-1), 1/(yu*yv), yv^(-1)}, yw] + 
     8*G[{1}, yu^(-1)]*G[{0, yu^(-1), 1/(yu*yv), yv^(-1)}, yw] + 
     4*G[{1}, yv^(-1)]*G[{0, yu^(-1), 1/(yu*yv), yv^(-1)}, yw] - 
     2*G[{yu^(-1)}, yw]*G[{0, yu^(-1), 1/(yu*yv), yv^(-1)}, yw] - 
     4*G[{yu}, yv^(-1)]*G[{0, yu^(-1), 1/(yu*yv), yv^(-1)}, yw] + 
     2*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1), 1/(yu*yv), yv^(-1)}, yw] + 
     2*G[{1}, yu^(-1)]*G[{0, yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] - 
     2*G[{yu}, yv^(-1)]*G[{0, yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] - 
     2*G[{1}, yu^(-1)]*G[{0, yu, 1, yu}, yv^(-1)] - 
     2*G[{yu^(-1)}, yw]*G[{0, yu, 1, yu}, yv^(-1)] - 
     6*G[{yu}, yv^(-1)]*G[{0, yu, 1, yu}, yv^(-1)] + 
     2*G[{1/(yu*yv)}, yw]*G[{0, yu, 1, yu}, yv^(-1)] - 
     4*G[{1}, yu^(-1)]*G[{0, yu, yu, 1}, yv^(-1)] - 
     4*G[{yu}, yv^(-1)]*G[{0, yu, yu, 1}, yv^(-1)] + 
     8*G[{yu}, yv^(-1)]*G[{0, yu, yu, yu}, yv^(-1)] - 
     2*G[{1}, yu^(-1)]*G[{0, yv^(-1), 0, 1/(yu*yv)}, yw] + 
     2*G[{yu^(-1)}, yw]*G[{0, yv^(-1), 0, 1/(yu*yv)}, yw] + 
     2*G[{yu}, yv^(-1)]*G[{0, yv^(-1), 0, 1/(yu*yv)}, yw] - 
     2*G[{1/(yu*yv)}, yw]*G[{0, yv^(-1), 0, 1/(yu*yv)}, yw] + 
     2*G[{yu^(-1)}, yw]*G[{0, yv^(-1), 1, 1}, yw] - 
     2*G[{1/(yu*yv)}, yw]*G[{0, yv^(-1), 1, 1}, yw] - 
     4*G[{0}, yu^(-1)]*G[{0, yv^(-1), 1, yu^(-1)}, yw] - 
     4*G[{0}, yv^(-1)]*G[{0, yv^(-1), 1, yu^(-1)}, yw] + 
     4*G[{0}, yw]*G[{0, yv^(-1), 1, yu^(-1)}, yw] + 
     2*G[{1}, yu^(-1)]*G[{0, yv^(-1), 1, yu^(-1)}, yw] + 
     4*G[{1}, yv^(-1)]*G[{0, yv^(-1), 1, yu^(-1)}, yw] + 
     4*G[{yu^(-1)}, yw]*G[{0, yv^(-1), 1, yu^(-1)}, yw] + 
     2*G[{yu}, yv^(-1)]*G[{0, yv^(-1), 1, yu^(-1)}, yw] - 
     4*G[{1/(yu*yv)}, yw]*G[{0, yv^(-1), 1, yu^(-1)}, yw] + 
     2*G[{yu^(-1)}, yw]*G[{0, yv^(-1), 1, yv^(-1)}, yw] - 
     2*G[{1/(yu*yv)}, yw]*G[{0, yv^(-1), 1, yv^(-1)}, yw] + 
     4*G[{0}, yu^(-1)]*G[{0, yv^(-1), 1, 1/(yu*yv)}, yw] + 
     4*G[{0}, yv^(-1)]*G[{0, yv^(-1), 1, 1/(yu*yv)}, yw] - 
     4*G[{0}, yw]*G[{0, yv^(-1), 1, 1/(yu*yv)}, yw] - 
     2*G[{1}, yu^(-1)]*G[{0, yv^(-1), 1, 1/(yu*yv)}, yw] - 
     4*G[{1}, yv^(-1)]*G[{0, yv^(-1), 1, 1/(yu*yv)}, yw] - 
     2*G[{yu}, yv^(-1)]*G[{0, yv^(-1), 1, 1/(yu*yv)}, yw] - 
     4*G[{0}, yu^(-1)]*G[{0, yv^(-1), yu^(-1), 1}, yw] - 
     4*G[{0}, yv^(-1)]*G[{0, yv^(-1), yu^(-1), 1}, yw] + 
     4*G[{0}, yw]*G[{0, yv^(-1), yu^(-1), 1}, yw] + 
     4*G[{1}, yu^(-1)]*G[{0, yv^(-1), yu^(-1), 1}, yw] + 
     4*G[{1}, yv^(-1)]*G[{0, yv^(-1), yu^(-1), 1}, yw] + 
     4*G[{yu^(-1)}, yw]*G[{0, yv^(-1), yu^(-1), 1}, yw] - 
     4*G[{1/(yu*yv)}, yw]*G[{0, yv^(-1), yu^(-1), 1}, yw] + 
     4*G[{0}, yu^(-1)]*G[{0, yv^(-1), yu^(-1), yu^(-1)}, yw] + 
     4*G[{0}, yv^(-1)]*G[{0, yv^(-1), yu^(-1), yu^(-1)}, yw] - 
     4*G[{0}, yw]*G[{0, yv^(-1), yu^(-1), yu^(-1)}, yw] - 
     8*G[{1}, yu^(-1)]*G[{0, yv^(-1), yu^(-1), yu^(-1)}, yw] - 
     4*G[{1}, yv^(-1)]*G[{0, yv^(-1), yu^(-1), yu^(-1)}, yw] - 
     4*G[{yu^(-1)}, yw]*G[{0, yv^(-1), yu^(-1), yu^(-1)}, yw] + 
     4*G[{yu}, yv^(-1)]*G[{0, yv^(-1), yu^(-1), yu^(-1)}, yw] + 
     4*G[{1/(yu*yv)}, yw]*G[{0, yv^(-1), yu^(-1), yu^(-1)}, yw] + 
     4*G[{0}, yu^(-1)]*G[{0, yv^(-1), yu^(-1), yv^(-1)}, yw] + 
     4*G[{0}, yv^(-1)]*G[{0, yv^(-1), yu^(-1), yv^(-1)}, yw] - 
     4*G[{0}, yw]*G[{0, yv^(-1), yu^(-1), yv^(-1)}, yw] - 
     8*G[{1}, yu^(-1)]*G[{0, yv^(-1), yu^(-1), yv^(-1)}, yw] - 
     4*G[{1}, yv^(-1)]*G[{0, yv^(-1), yu^(-1), yv^(-1)}, yw] - 
     4*G[{yu^(-1)}, yw]*G[{0, yv^(-1), yu^(-1), yv^(-1)}, yw] + 
     4*G[{yu}, yv^(-1)]*G[{0, yv^(-1), yu^(-1), yv^(-1)}, yw] + 
     4*G[{1/(yu*yv)}, yw]*G[{0, yv^(-1), yu^(-1), yv^(-1)}, yw] - 
     4*G[{0}, yu^(-1)]*G[{0, yv^(-1), yu^(-1), 1/(yu*yv)}, yw] - 
     4*G[{0}, yv^(-1)]*G[{0, yv^(-1), yu^(-1), 1/(yu*yv)}, yw] + 
     4*G[{0}, yw]*G[{0, yv^(-1), yu^(-1), 1/(yu*yv)}, yw] + 
     8*G[{1}, yu^(-1)]*G[{0, yv^(-1), yu^(-1), 1/(yu*yv)}, yw] + 
     4*G[{1}, yv^(-1)]*G[{0, yv^(-1), yu^(-1), 1/(yu*yv)}, yw] - 
     4*G[{yu}, yv^(-1)]*G[{0, yv^(-1), yu^(-1), 1/(yu*yv)}, yw] + 
     4*G[{yu^(-1)}, yw]*G[{0, yv^(-1), yv^(-1), 1}, yw] - 
     4*G[{1/(yu*yv)}, yw]*G[{0, yv^(-1), yv^(-1), 1}, yw] + 
     4*G[{0}, yu^(-1)]*G[{0, yv^(-1), yv^(-1), yu^(-1)}, yw] + 
     4*G[{0}, yv^(-1)]*G[{0, yv^(-1), yv^(-1), yu^(-1)}, yw] - 
     4*G[{0}, yw]*G[{0, yv^(-1), yv^(-1), yu^(-1)}, yw] - 
     8*G[{1}, yu^(-1)]*G[{0, yv^(-1), yv^(-1), yu^(-1)}, yw] - 
     4*G[{1}, yv^(-1)]*G[{0, yv^(-1), yv^(-1), yu^(-1)}, yw] - 
     4*G[{yu^(-1)}, yw]*G[{0, yv^(-1), yv^(-1), yu^(-1)}, yw] + 
     4*G[{yu}, yv^(-1)]*G[{0, yv^(-1), yv^(-1), yu^(-1)}, yw] + 
     4*G[{1/(yu*yv)}, yw]*G[{0, yv^(-1), yv^(-1), yu^(-1)}, yw] - 
     8*G[{yu^(-1)}, yw]*G[{0, yv^(-1), yv^(-1), yv^(-1)}, yw] + 
     8*G[{1/(yu*yv)}, yw]*G[{0, yv^(-1), yv^(-1), yv^(-1)}, yw] - 
     4*G[{0}, yu^(-1)]*G[{0, yv^(-1), yv^(-1), 1/(yu*yv)}, yw] - 
     4*G[{0}, yv^(-1)]*G[{0, yv^(-1), yv^(-1), 1/(yu*yv)}, yw] + 
     4*G[{0}, yw]*G[{0, yv^(-1), yv^(-1), 1/(yu*yv)}, yw] + 
     8*G[{1}, yu^(-1)]*G[{0, yv^(-1), yv^(-1), 1/(yu*yv)}, yw] + 
     4*G[{1}, yv^(-1)]*G[{0, yv^(-1), yv^(-1), 1/(yu*yv)}, yw] - 
     4*G[{yu}, yv^(-1)]*G[{0, yv^(-1), yv^(-1), 1/(yu*yv)}, yw] + 
     4*G[{0}, yu^(-1)]*G[{0, yv^(-1), 1/(yu*yv), 1}, yw] + 
     4*G[{0}, yv^(-1)]*G[{0, yv^(-1), 1/(yu*yv), 1}, yw] - 
     4*G[{0}, yw]*G[{0, yv^(-1), 1/(yu*yv), 1}, yw] - 
     4*G[{1}, yu^(-1)]*G[{0, yv^(-1), 1/(yu*yv), 1}, yw] - 
     4*G[{1}, yv^(-1)]*G[{0, yv^(-1), 1/(yu*yv), 1}, yw] - 
     2*G[{yu^(-1)}, yw]*G[{0, yv^(-1), 1/(yu*yv), 1}, yw] + 
     2*G[{1/(yu*yv)}, yw]*G[{0, yv^(-1), 1/(yu*yv), 1}, yw] - 
     4*G[{0}, yu^(-1)]*G[{0, yv^(-1), 1/(yu*yv), yu^(-1)}, yw] - 
     4*G[{0}, yv^(-1)]*G[{0, yv^(-1), 1/(yu*yv), yu^(-1)}, yw] + 
     4*G[{0}, yw]*G[{0, yv^(-1), 1/(yu*yv), yu^(-1)}, yw] + 
     6*G[{1}, yu^(-1)]*G[{0, yv^(-1), 1/(yu*yv), yu^(-1)}, yw] + 
     4*G[{1}, yv^(-1)]*G[{0, yv^(-1), 1/(yu*yv), yu^(-1)}, yw] + 
     4*G[{yu^(-1)}, yw]*G[{0, yv^(-1), 1/(yu*yv), yu^(-1)}, yw] - 
     2*G[{yu}, yv^(-1)]*G[{0, yv^(-1), 1/(yu*yv), yu^(-1)}, yw] - 
     4*G[{1/(yu*yv)}, yw]*G[{0, yv^(-1), 1/(yu*yv), yu^(-1)}, yw] - 
     4*G[{0}, yu^(-1)]*G[{0, yv^(-1), 1/(yu*yv), yv^(-1)}, yw] - 
     4*G[{0}, yv^(-1)]*G[{0, yv^(-1), 1/(yu*yv), yv^(-1)}, yw] + 
     4*G[{0}, yw]*G[{0, yv^(-1), 1/(yu*yv), yv^(-1)}, yw] + 
     8*G[{1}, yu^(-1)]*G[{0, yv^(-1), 1/(yu*yv), yv^(-1)}, yw] + 
     4*G[{1}, yv^(-1)]*G[{0, yv^(-1), 1/(yu*yv), yv^(-1)}, yw] + 
     2*G[{yu^(-1)}, yw]*G[{0, yv^(-1), 1/(yu*yv), yv^(-1)}, yw] - 
     4*G[{yu}, yv^(-1)]*G[{0, yv^(-1), 1/(yu*yv), yv^(-1)}, yw] - 
     2*G[{1/(yu*yv)}, yw]*G[{0, yv^(-1), 1/(yu*yv), yv^(-1)}, yw] + 
     4*G[{0}, yu^(-1)]*G[{0, yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] + 
     4*G[{0}, yv^(-1)]*G[{0, yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] - 
     4*G[{0}, yw]*G[{0, yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] - 
     6*G[{1}, yu^(-1)]*G[{0, yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] - 
     4*G[{1}, yv^(-1)]*G[{0, yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] + 
     2*G[{yu}, yv^(-1)]*G[{0, yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] - 
     4*G[{0}, yu^(-1)]*G[{0, 1/(yu*yv), 1, 1}, yw] - 
     4*G[{0}, yv^(-1)]*G[{0, 1/(yu*yv), 1, 1}, yw] + 
     4*G[{0}, yw]*G[{0, 1/(yu*yv), 1, 1}, yw] + 4*G[{1}, yu^(-1)]*
      G[{0, 1/(yu*yv), 1, 1}, yw] + 4*G[{1}, yv^(-1)]*
      G[{0, 1/(yu*yv), 1, 1}, yw] + 2*G[{yu^(-1)}, yw]*
      G[{0, 1/(yu*yv), 1, 1}, yw] - 2*G[{1/(yu*yv)}, yw]*
      G[{0, 1/(yu*yv), 1, 1}, yw] + 4*G[{0}, yu^(-1)]*
      G[{0, 1/(yu*yv), 1, yu^(-1)}, yw] + 4*G[{0}, yv^(-1)]*
      G[{0, 1/(yu*yv), 1, yu^(-1)}, yw] - 4*G[{0}, yw]*
      G[{0, 1/(yu*yv), 1, yu^(-1)}, yw] - 6*G[{1}, yu^(-1)]*
      G[{0, 1/(yu*yv), 1, yu^(-1)}, yw] - 4*G[{1}, yv^(-1)]*
      G[{0, 1/(yu*yv), 1, yu^(-1)}, yw] - 4*G[{yu^(-1)}, yw]*
      G[{0, 1/(yu*yv), 1, yu^(-1)}, yw] + 2*G[{yu}, yv^(-1)]*
      G[{0, 1/(yu*yv), 1, yu^(-1)}, yw] + 4*G[{1/(yu*yv)}, yw]*
      G[{0, 1/(yu*yv), 1, yu^(-1)}, yw] + 4*G[{0}, yu^(-1)]*
      G[{0, 1/(yu*yv), 1, yv^(-1)}, yw] + 4*G[{0}, yv^(-1)]*
      G[{0, 1/(yu*yv), 1, yv^(-1)}, yw] - 4*G[{0}, yw]*
      G[{0, 1/(yu*yv), 1, yv^(-1)}, yw] - 8*G[{1}, yu^(-1)]*
      G[{0, 1/(yu*yv), 1, yv^(-1)}, yw] - 4*G[{1}, yv^(-1)]*
      G[{0, 1/(yu*yv), 1, yv^(-1)}, yw] - 2*G[{yu^(-1)}, yw]*
      G[{0, 1/(yu*yv), 1, yv^(-1)}, yw] + 4*G[{yu}, yv^(-1)]*
      G[{0, 1/(yu*yv), 1, yv^(-1)}, yw] + 2*G[{1/(yu*yv)}, yw]*
      G[{0, 1/(yu*yv), 1, yv^(-1)}, yw] - 4*G[{0}, yu^(-1)]*
      G[{0, 1/(yu*yv), 1, 1/(yu*yv)}, yw] - 4*G[{0}, yv^(-1)]*
      G[{0, 1/(yu*yv), 1, 1/(yu*yv)}, yw] + 4*G[{0}, yw]*
      G[{0, 1/(yu*yv), 1, 1/(yu*yv)}, yw] + 6*G[{1}, yu^(-1)]*
      G[{0, 1/(yu*yv), 1, 1/(yu*yv)}, yw] + 4*G[{1}, yv^(-1)]*
      G[{0, 1/(yu*yv), 1, 1/(yu*yv)}, yw] - 2*G[{yu}, yv^(-1)]*
      G[{0, 1/(yu*yv), 1, 1/(yu*yv)}, yw] + 4*G[{0}, yu^(-1)]*
      G[{0, 1/(yu*yv), yu^(-1), 1}, yw] + 4*G[{0}, yv^(-1)]*
      G[{0, 1/(yu*yv), yu^(-1), 1}, yw] - 4*G[{0}, yw]*
      G[{0, 1/(yu*yv), yu^(-1), 1}, yw] - 4*G[{1}, yu^(-1)]*
      G[{0, 1/(yu*yv), yu^(-1), 1}, yw] - 4*G[{1}, yv^(-1)]*
      G[{0, 1/(yu*yv), yu^(-1), 1}, yw] - 4*G[{yu^(-1)}, yw]*
      G[{0, 1/(yu*yv), yu^(-1), 1}, yw] + 4*G[{1/(yu*yv)}, yw]*
      G[{0, 1/(yu*yv), yu^(-1), 1}, yw] + 8*G[{1}, yu^(-1)]*
      G[{0, 1/(yu*yv), yu^(-1), yu^(-1)}, yw] - 8*G[{yu}, yv^(-1)]*
      G[{0, 1/(yu*yv), yu^(-1), yu^(-1)}, yw] - 4*G[{0}, yu^(-1)]*
      G[{0, 1/(yu*yv), yu^(-1), yv^(-1)}, yw] - 4*G[{0}, yv^(-1)]*
      G[{0, 1/(yu*yv), yu^(-1), yv^(-1)}, yw] + 
     4*G[{0}, yw]*G[{0, 1/(yu*yv), yu^(-1), yv^(-1)}, yw] + 
     8*G[{1}, yu^(-1)]*G[{0, 1/(yu*yv), yu^(-1), yv^(-1)}, yw] + 
     4*G[{1}, yv^(-1)]*G[{0, 1/(yu*yv), yu^(-1), yv^(-1)}, yw] + 
     4*G[{yu^(-1)}, yw]*G[{0, 1/(yu*yv), yu^(-1), yv^(-1)}, yw] - 
     4*G[{yu}, yv^(-1)]*G[{0, 1/(yu*yv), yu^(-1), yv^(-1)}, yw] - 
     4*G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv), yu^(-1), yv^(-1)}, yw] - 
     4*G[{1}, yu^(-1)]*G[{0, 1/(yu*yv), yu^(-1), 1/(yu*yv)}, yw] + 
     4*G[{yu}, yv^(-1)]*G[{0, 1/(yu*yv), yu^(-1), 1/(yu*yv)}, yw] + 
     4*G[{0}, yu^(-1)]*G[{0, 1/(yu*yv), yv^(-1), 1}, yw] + 
     4*G[{0}, yv^(-1)]*G[{0, 1/(yu*yv), yv^(-1), 1}, yw] - 
     4*G[{0}, yw]*G[{0, 1/(yu*yv), yv^(-1), 1}, yw] - 
     4*G[{1}, yu^(-1)]*G[{0, 1/(yu*yv), yv^(-1), 1}, yw] - 
     4*G[{1}, yv^(-1)]*G[{0, 1/(yu*yv), yv^(-1), 1}, yw] - 
     4*G[{yu^(-1)}, yw]*G[{0, 1/(yu*yv), yv^(-1), 1}, yw] + 
     4*G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv), yv^(-1), 1}, yw] - 
     4*G[{0}, yu^(-1)]*G[{0, 1/(yu*yv), yv^(-1), yu^(-1)}, yw] - 
     4*G[{0}, yv^(-1)]*G[{0, 1/(yu*yv), yv^(-1), yu^(-1)}, yw] + 
     4*G[{0}, yw]*G[{0, 1/(yu*yv), yv^(-1), yu^(-1)}, yw] + 
     8*G[{1}, yu^(-1)]*G[{0, 1/(yu*yv), yv^(-1), yu^(-1)}, yw] + 
     4*G[{1}, yv^(-1)]*G[{0, 1/(yu*yv), yv^(-1), yu^(-1)}, yw] + 
     4*G[{yu^(-1)}, yw]*G[{0, 1/(yu*yv), yv^(-1), yu^(-1)}, yw] - 
     4*G[{yu}, yv^(-1)]*G[{0, 1/(yu*yv), yv^(-1), yu^(-1)}, yw] - 
     4*G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv), yv^(-1), yu^(-1)}, yw] - 
     4*G[{0}, yu^(-1)]*G[{0, 1/(yu*yv), yv^(-1), yv^(-1)}, yw] - 
     4*G[{0}, yv^(-1)]*G[{0, 1/(yu*yv), yv^(-1), yv^(-1)}, yw] + 
     4*G[{0}, yw]*G[{0, 1/(yu*yv), yv^(-1), yv^(-1)}, yw] + 
     8*G[{1}, yu^(-1)]*G[{0, 1/(yu*yv), yv^(-1), yv^(-1)}, yw] + 
     4*G[{1}, yv^(-1)]*G[{0, 1/(yu*yv), yv^(-1), yv^(-1)}, yw] + 
     4*G[{yu^(-1)}, yw]*G[{0, 1/(yu*yv), yv^(-1), yv^(-1)}, yw] - 
     4*G[{yu}, yv^(-1)]*G[{0, 1/(yu*yv), yv^(-1), yv^(-1)}, yw] - 
     4*G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv), yv^(-1), yv^(-1)}, yw] + 
     4*G[{0}, yu^(-1)]*G[{0, 1/(yu*yv), yv^(-1), 1/(yu*yv)}, yw] + 
     4*G[{0}, yv^(-1)]*G[{0, 1/(yu*yv), yv^(-1), 1/(yu*yv)}, yw] - 
     4*G[{0}, yw]*G[{0, 1/(yu*yv), yv^(-1), 1/(yu*yv)}, yw] - 
     8*G[{1}, yu^(-1)]*G[{0, 1/(yu*yv), yv^(-1), 1/(yu*yv)}, yw] - 
     4*G[{1}, yv^(-1)]*G[{0, 1/(yu*yv), yv^(-1), 1/(yu*yv)}, yw] + 
     4*G[{yu}, yv^(-1)]*G[{0, 1/(yu*yv), yv^(-1), 1/(yu*yv)}, yw] - 
     4*G[{0}, yu^(-1)]*G[{0, 1/(yu*yv), 1/(yu*yv), 1}, yw] - 
     4*G[{0}, yv^(-1)]*G[{0, 1/(yu*yv), 1/(yu*yv), 1}, yw] + 
     4*G[{0}, yw]*G[{0, 1/(yu*yv), 1/(yu*yv), 1}, yw] + 
     4*G[{1}, yu^(-1)]*G[{0, 1/(yu*yv), 1/(yu*yv), 1}, yw] + 
     4*G[{1}, yv^(-1)]*G[{0, 1/(yu*yv), 1/(yu*yv), 1}, yw] - 
     2*G[{yu^(-1)}, yw]*G[{0, 1/(yu*yv), 1/(yu*yv), 1}, yw] + 
     2*G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv), 1/(yu*yv), 1}, yw] - 
     2*G[{1}, yu^(-1)]*G[{0, 1/(yu*yv), 1/(yu*yv), yu^(-1)}, yw] + 
     2*G[{yu}, yv^(-1)]*G[{0, 1/(yu*yv), 1/(yu*yv), yu^(-1)}, yw] + 
     4*G[{0}, yu^(-1)]*G[{0, 1/(yu*yv), 1/(yu*yv), yv^(-1)}, yw] + 
     4*G[{0}, yv^(-1)]*G[{0, 1/(yu*yv), 1/(yu*yv), yv^(-1)}, yw] - 
     4*G[{0}, yw]*G[{0, 1/(yu*yv), 1/(yu*yv), yv^(-1)}, yw] - 
     8*G[{1}, yu^(-1)]*G[{0, 1/(yu*yv), 1/(yu*yv), yv^(-1)}, yw] - 
     4*G[{1}, yv^(-1)]*G[{0, 1/(yu*yv), 1/(yu*yv), yv^(-1)}, yw] + 
     2*G[{yu^(-1)}, yw]*G[{0, 1/(yu*yv), 1/(yu*yv), yv^(-1)}, yw] + 
     4*G[{yu}, yv^(-1)]*G[{0, 1/(yu*yv), 1/(yu*yv), yv^(-1)}, yw] - 
     2*G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv), 1/(yu*yv), yv^(-1)}, yw] - 
     2*G[{1}, yu^(-1)]*G[{0, 1/(yu*yv), 1/(yu*yv), 1/(yu*yv)}, yw] + 
     2*G[{yu}, yv^(-1)]*G[{0, 1/(yu*yv), 1/(yu*yv), 1/(yu*yv)}, yw] - 
     4*G[{0}, yu^(-1)]*G[{1, 1, 1, yu^(-1)}, yw] - 
     4*G[{0}, yv^(-1)]*G[{1, 1, 1, yu^(-1)}, yw] + 
     4*G[{0}, yw]*G[{1, 1, 1, yu^(-1)}, yw] + 4*G[{1}, yu^(-1)]*
      G[{1, 1, 1, yu^(-1)}, yw] + 4*G[{1}, yv^(-1)]*G[{1, 1, 1, yu^(-1)}, 
       yw] + 4*G[{yu^(-1)}, yw]*G[{1, 1, 1, yu^(-1)}, yw] - 
     4*G[{1/(yu*yv)}, yw]*G[{1, 1, 1, yu^(-1)}, yw] - 
     8*G[{yu^(-1)}, yw]*G[{1, 1, 1, yv^(-1)}, yw] + 
     8*G[{1/(yu*yv)}, yw]*G[{1, 1, 1, yv^(-1)}, yw] + 
     4*G[{0}, yu^(-1)]*G[{1, 1, 1, 1/(yu*yv)}, yw] + 
     4*G[{0}, yv^(-1)]*G[{1, 1, 1, 1/(yu*yv)}, yw] - 
     4*G[{0}, yw]*G[{1, 1, 1, 1/(yu*yv)}, yw] - 4*G[{1}, yu^(-1)]*
      G[{1, 1, 1, 1/(yu*yv)}, yw] - 4*G[{1}, yv^(-1)]*
      G[{1, 1, 1, 1/(yu*yv)}, yw] - 4*G[{0}, yu^(-1)]*
      G[{1, 1, yu^(-1), yu^(-1)}, yw] - 4*G[{0}, yv^(-1)]*
      G[{1, 1, yu^(-1), yu^(-1)}, yw] + 4*G[{0}, yw]*
      G[{1, 1, yu^(-1), yu^(-1)}, yw] + 8*G[{1}, yu^(-1)]*
      G[{1, 1, yu^(-1), yu^(-1)}, yw] + 4*G[{1}, yv^(-1)]*
      G[{1, 1, yu^(-1), yu^(-1)}, yw] + 4*G[{1}, yw]*
      G[{1, 1, yu^(-1), yu^(-1)}, yw] + 8*G[{yu^(-1)}, yw]*
      G[{1, 1, yu^(-1), yu^(-1)}, yw] - 4*G[{yu}, yv^(-1)]*
      G[{1, 1, yu^(-1), yu^(-1)}, yw] - 8*G[{1/(yu*yv)}, yw]*
      G[{1, 1, yu^(-1), yu^(-1)}, yw] - 4*G[{0}, yu^(-1)]*
      G[{1, 1, yu^(-1), yv^(-1)}, yw] - 4*G[{0}, yv^(-1)]*
      G[{1, 1, yu^(-1), yv^(-1)}, yw] + 4*G[{0}, yw]*
      G[{1, 1, yu^(-1), yv^(-1)}, yw] + 4*G[{1}, yv^(-1)]*
      G[{1, 1, yu^(-1), yv^(-1)}, yw] - 4*G[{1}, yw]*
      G[{1, 1, yu^(-1), yv^(-1)}, yw] + 4*G[{yu^(-1)}, yw]*
      G[{1, 1, yu^(-1), yv^(-1)}, yw] + 4*G[{yu}, yv^(-1)]*
      G[{1, 1, yu^(-1), yv^(-1)}, yw] - 4*G[{1/(yu*yv)}, yw]*
      G[{1, 1, yu^(-1), yv^(-1)}, yw] + 4*G[{0}, yu^(-1)]*
      G[{1, 1, yu^(-1), 1/(yu*yv)}, yw] + 4*G[{0}, yv^(-1)]*
      G[{1, 1, yu^(-1), 1/(yu*yv)}, yw] - 4*G[{0}, yw]*
      G[{1, 1, yu^(-1), 1/(yu*yv)}, yw] - 8*G[{1}, yu^(-1)]*
      G[{1, 1, yu^(-1), 1/(yu*yv)}, yw] - 4*G[{1}, yv^(-1)]*
      G[{1, 1, yu^(-1), 1/(yu*yv)}, yw] - 4*G[{1}, yw]*
      G[{1, 1, yu^(-1), 1/(yu*yv)}, yw] - 4*G[{yu^(-1)}, yw]*
      G[{1, 1, yu^(-1), 1/(yu*yv)}, yw] + 4*G[{yu}, yv^(-1)]*
      G[{1, 1, yu^(-1), 1/(yu*yv)}, yw] + 4*G[{1/(yu*yv)}, yw]*
      G[{1, 1, yu^(-1), 1/(yu*yv)}, yw] - 8*G[{1}, yu^(-1)]*
      G[{1, 1, yu, yu}, yv^(-1)] - 4*G[{yu^(-1)}, yw]*
      G[{1, 1, yu, yu}, yv^(-1)] - 12*G[{yu}, yv^(-1)]*
      G[{1, 1, yu, yu}, yv^(-1)] + 4*G[{1/(yu*yv)}, yw]*
      G[{1, 1, yu, yu}, yv^(-1)] - 4*G[{0}, yu^(-1)]*
      G[{1, 1, yv^(-1), yu^(-1)}, yw] - 4*G[{0}, yv^(-1)]*
      G[{1, 1, yv^(-1), yu^(-1)}, yw] + 4*G[{0}, yw]*
      G[{1, 1, yv^(-1), yu^(-1)}, yw] + 4*G[{1}, yv^(-1)]*
      G[{1, 1, yv^(-1), yu^(-1)}, yw] - 4*G[{1}, yw]*
      G[{1, 1, yv^(-1), yu^(-1)}, yw] + 4*G[{yu^(-1)}, yw]*
      G[{1, 1, yv^(-1), yu^(-1)}, yw] + 4*G[{yu}, yv^(-1)]*
      G[{1, 1, yv^(-1), yu^(-1)}, yw] - 4*G[{1/(yu*yv)}, yw]*
      G[{1, 1, yv^(-1), yu^(-1)}, yw] + 4*G[{0}, yu^(-1)]*
      G[{1, 1, yv^(-1), 1/(yu*yv)}, yw] + 4*G[{0}, yv^(-1)]*
      G[{1, 1, yv^(-1), 1/(yu*yv)}, yw] - 4*G[{0}, yw]*
      G[{1, 1, yv^(-1), 1/(yu*yv)}, yw] - 8*G[{1}, yu^(-1)]*
      G[{1, 1, yv^(-1), 1/(yu*yv)}, yw] - 4*G[{1}, yv^(-1)]*
      G[{1, 1, yv^(-1), 1/(yu*yv)}, yw] - 4*G[{1}, yw]*
      G[{1, 1, yv^(-1), 1/(yu*yv)}, yw] - 4*G[{yu^(-1)}, yw]*
      G[{1, 1, yv^(-1), 1/(yu*yv)}, yw] + 4*G[{yu}, yv^(-1)]*
      G[{1, 1, yv^(-1), 1/(yu*yv)}, yw] + 4*G[{1/(yu*yv)}, yw]*
      G[{1, 1, yv^(-1), 1/(yu*yv)}, yw] - 4*G[{1}, yu^(-1)]*
      G[{1, 1, 1/(yu*yv), yu^(-1)}, yw] - 4*G[{1}, yw]*
      G[{1, 1, 1/(yu*yv), yu^(-1)}, yw] - 4*G[{yu^(-1)}, yw]*
      G[{1, 1, 1/(yu*yv), yu^(-1)}, yw] + 4*G[{yu}, yv^(-1)]*
      G[{1, 1, 1/(yu*yv), yu^(-1)}, yw] + 4*G[{1/(yu*yv)}, yw]*
      G[{1, 1, 1/(yu*yv), yu^(-1)}, yw] + 4*G[{0}, yu^(-1)]*
      G[{1, 1, 1/(yu*yv), yv^(-1)}, yw] + 4*G[{0}, yv^(-1)]*
      G[{1, 1, 1/(yu*yv), yv^(-1)}, yw] - 4*G[{0}, yw]*
      G[{1, 1, 1/(yu*yv), yv^(-1)}, yw] - 8*G[{1}, yu^(-1)]*
      G[{1, 1, 1/(yu*yv), yv^(-1)}, yw] - 4*G[{1}, yv^(-1)]*
      G[{1, 1, 1/(yu*yv), yv^(-1)}, yw] - 4*G[{1}, yw]*
      G[{1, 1, 1/(yu*yv), yv^(-1)}, yw] + 4*G[{yu}, yv^(-1)]*
      G[{1, 1, 1/(yu*yv), yv^(-1)}, yw] + 4*G[{1}, yu^(-1)]*
      G[{1, 1, 1/(yu*yv), 1/(yu*yv)}, yw] + 4*G[{1}, yw]*
      G[{1, 1, 1/(yu*yv), 1/(yu*yv)}, yw] - 4*G[{yu}, yv^(-1)]*
      G[{1, 1, 1/(yu*yv), 1/(yu*yv)}, yw] - 4*G[{1}, yu^(-1)]*
      G[{1, yu^(-1), 1, yv^(-1)}, yw] - 4*G[{1}, yw]*
      G[{1, yu^(-1), 1, yv^(-1)}, yw] + 4*G[{yu}, yv^(-1)]*
      G[{1, yu^(-1), 1, yv^(-1)}, yw] + 8*G[{1}, yu^(-1)]*
      G[{1, yu^(-1), yu^(-1), yu^(-1)}, yw] + 
     8*G[{1}, yw]*G[{1, yu^(-1), yu^(-1), yu^(-1)}, yw] + 
     8*G[{yu^(-1)}, yw]*G[{1, yu^(-1), yu^(-1), yu^(-1)}, yw] - 
     8*G[{yu}, yv^(-1)]*G[{1, yu^(-1), yu^(-1), yu^(-1)}, yw] - 
     8*G[{1/(yu*yv)}, yw]*G[{1, yu^(-1), yu^(-1), yu^(-1)}, yw] - 
     4*G[{0}, yu^(-1)]*G[{1, yu^(-1), yu^(-1), yv^(-1)}, yw] - 
     4*G[{0}, yv^(-1)]*G[{1, yu^(-1), yu^(-1), yv^(-1)}, yw] + 
     4*G[{0}, yw]*G[{1, yu^(-1), yu^(-1), yv^(-1)}, yw] + 
     8*G[{1}, yu^(-1)]*G[{1, yu^(-1), yu^(-1), yv^(-1)}, yw] + 
     4*G[{1}, yv^(-1)]*G[{1, yu^(-1), yu^(-1), yv^(-1)}, yw] + 
     4*G[{1}, yw]*G[{1, yu^(-1), yu^(-1), yv^(-1)}, yw] + 
     4*G[{yu^(-1)}, yw]*G[{1, yu^(-1), yu^(-1), yv^(-1)}, yw] - 
     4*G[{yu}, yv^(-1)]*G[{1, yu^(-1), yu^(-1), yv^(-1)}, yw] - 
     4*G[{1/(yu*yv)}, yw]*G[{1, yu^(-1), yu^(-1), yv^(-1)}, yw] - 
     8*G[{1}, yu^(-1)]*G[{1, yu^(-1), yu^(-1), 1/(yu*yv)}, yw] - 
     8*G[{1}, yw]*G[{1, yu^(-1), yu^(-1), 1/(yu*yv)}, yw] - 
     4*G[{yu^(-1)}, yw]*G[{1, yu^(-1), yu^(-1), 1/(yu*yv)}, yw] + 
     8*G[{yu}, yv^(-1)]*G[{1, yu^(-1), yu^(-1), 1/(yu*yv)}, yw] + 
     4*G[{1/(yu*yv)}, yw]*G[{1, yu^(-1), yu^(-1), 1/(yu*yv)}, yw] - 
     4*G[{0}, yu^(-1)]*G[{1, yu^(-1), yv^(-1), yu^(-1)}, yw] - 
     4*G[{0}, yv^(-1)]*G[{1, yu^(-1), yv^(-1), yu^(-1)}, yw] + 
     4*G[{0}, yw]*G[{1, yu^(-1), yv^(-1), yu^(-1)}, yw] + 
     8*G[{1}, yu^(-1)]*G[{1, yu^(-1), yv^(-1), yu^(-1)}, yw] + 
     4*G[{1}, yv^(-1)]*G[{1, yu^(-1), yv^(-1), yu^(-1)}, yw] + 
     4*G[{1}, yw]*G[{1, yu^(-1), yv^(-1), yu^(-1)}, yw] + 
     4*G[{yu^(-1)}, yw]*G[{1, yu^(-1), yv^(-1), yu^(-1)}, yw] - 
     4*G[{yu}, yv^(-1)]*G[{1, yu^(-1), yv^(-1), yu^(-1)}, yw] - 
     4*G[{1/(yu*yv)}, yw]*G[{1, yu^(-1), yv^(-1), yu^(-1)}, yw] - 
     4*G[{0}, yu^(-1)]*G[{1, yu^(-1), yv^(-1), yv^(-1)}, yw] - 
     4*G[{0}, yv^(-1)]*G[{1, yu^(-1), yv^(-1), yv^(-1)}, yw] + 
     4*G[{0}, yw]*G[{1, yu^(-1), yv^(-1), yv^(-1)}, yw] + 
     8*G[{1}, yu^(-1)]*G[{1, yu^(-1), yv^(-1), yv^(-1)}, yw] + 
     4*G[{1}, yv^(-1)]*G[{1, yu^(-1), yv^(-1), yv^(-1)}, yw] + 
     4*G[{1}, yw]*G[{1, yu^(-1), yv^(-1), yv^(-1)}, yw] + 
     4*G[{yu^(-1)}, yw]*G[{1, yu^(-1), yv^(-1), yv^(-1)}, yw] - 
     4*G[{yu}, yv^(-1)]*G[{1, yu^(-1), yv^(-1), yv^(-1)}, yw] - 
     4*G[{1/(yu*yv)}, yw]*G[{1, yu^(-1), yv^(-1), yv^(-1)}, yw] + 
     4*G[{0}, yu^(-1)]*G[{1, yu^(-1), yv^(-1), 1/(yu*yv)}, yw] + 
     4*G[{0}, yv^(-1)]*G[{1, yu^(-1), yv^(-1), 1/(yu*yv)}, yw] - 
     4*G[{0}, yw]*G[{1, yu^(-1), yv^(-1), 1/(yu*yv)}, yw] - 
     8*G[{1}, yu^(-1)]*G[{1, yu^(-1), yv^(-1), 1/(yu*yv)}, yw] - 
     4*G[{1}, yv^(-1)]*G[{1, yu^(-1), yv^(-1), 1/(yu*yv)}, yw] - 
     4*G[{1}, yw]*G[{1, yu^(-1), yv^(-1), 1/(yu*yv)}, yw] + 
     4*G[{yu}, yv^(-1)]*G[{1, yu^(-1), yv^(-1), 1/(yu*yv)}, yw] - 
     4*G[{1}, yu^(-1)]*G[{1, yu^(-1), 1/(yu*yv), yu^(-1)}, yw] - 
     4*G[{1}, yw]*G[{1, yu^(-1), 1/(yu*yv), yu^(-1)}, yw] - 
     4*G[{yu^(-1)}, yw]*G[{1, yu^(-1), 1/(yu*yv), yu^(-1)}, yw] + 
     4*G[{yu}, yv^(-1)]*G[{1, yu^(-1), 1/(yu*yv), yu^(-1)}, yw] + 
     4*G[{1/(yu*yv)}, yw]*G[{1, yu^(-1), 1/(yu*yv), yu^(-1)}, yw] + 
     4*G[{0}, yu^(-1)]*G[{1, yu^(-1), 1/(yu*yv), yv^(-1)}, yw] + 
     4*G[{0}, yv^(-1)]*G[{1, yu^(-1), 1/(yu*yv), yv^(-1)}, yw] - 
     4*G[{0}, yw]*G[{1, yu^(-1), 1/(yu*yv), yv^(-1)}, yw] - 
     8*G[{1}, yu^(-1)]*G[{1, yu^(-1), 1/(yu*yv), yv^(-1)}, yw] - 
     4*G[{1}, yv^(-1)]*G[{1, yu^(-1), 1/(yu*yv), yv^(-1)}, yw] - 
     4*G[{1}, yw]*G[{1, yu^(-1), 1/(yu*yv), yv^(-1)}, yw] + 
     4*G[{yu}, yv^(-1)]*G[{1, yu^(-1), 1/(yu*yv), yv^(-1)}, yw] + 
     4*G[{1}, yu^(-1)]*G[{1, yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] + 
     4*G[{1}, yw]*G[{1, yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] - 
     4*G[{yu}, yv^(-1)]*G[{1, yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] - 
     8*G[{1}, yu^(-1)]*G[{1, yu, yu, yu}, yv^(-1)] - 
     16*G[{yu}, yv^(-1)]*G[{1, yu, yu, yu}, yv^(-1)] - 
     4*G[{1}, yu^(-1)]*G[{1, yv^(-1), 1, 1/(yu*yv)}, yw] - 
     4*G[{1}, yw]*G[{1, yv^(-1), 1, 1/(yu*yv)}, yw] - 
     4*G[{yu^(-1)}, yw]*G[{1, yv^(-1), 1, 1/(yu*yv)}, yw] + 
     4*G[{yu}, yv^(-1)]*G[{1, yv^(-1), 1, 1/(yu*yv)}, yw] + 
     4*G[{1/(yu*yv)}, yw]*G[{1, yv^(-1), 1, 1/(yu*yv)}, yw] - 
     4*G[{0}, yu^(-1)]*G[{1, yv^(-1), yu^(-1), yu^(-1)}, yw] - 
     4*G[{0}, yv^(-1)]*G[{1, yv^(-1), yu^(-1), yu^(-1)}, yw] + 
     4*G[{0}, yw]*G[{1, yv^(-1), yu^(-1), yu^(-1)}, yw] + 
     8*G[{1}, yu^(-1)]*G[{1, yv^(-1), yu^(-1), yu^(-1)}, yw] + 
     4*G[{1}, yv^(-1)]*G[{1, yv^(-1), yu^(-1), yu^(-1)}, yw] + 
     4*G[{1}, yw]*G[{1, yv^(-1), yu^(-1), yu^(-1)}, yw] + 
     4*G[{yu^(-1)}, yw]*G[{1, yv^(-1), yu^(-1), yu^(-1)}, yw] - 
     4*G[{yu}, yv^(-1)]*G[{1, yv^(-1), yu^(-1), yu^(-1)}, yw] - 
     4*G[{1/(yu*yv)}, yw]*G[{1, yv^(-1), yu^(-1), yu^(-1)}, yw] - 
     4*G[{0}, yu^(-1)]*G[{1, yv^(-1), yu^(-1), yv^(-1)}, yw] - 
     4*G[{0}, yv^(-1)]*G[{1, yv^(-1), yu^(-1), yv^(-1)}, yw] + 
     4*G[{0}, yw]*G[{1, yv^(-1), yu^(-1), yv^(-1)}, yw] + 
     8*G[{1}, yu^(-1)]*G[{1, yv^(-1), yu^(-1), yv^(-1)}, yw] + 
     4*G[{1}, yv^(-1)]*G[{1, yv^(-1), yu^(-1), yv^(-1)}, yw] + 
     4*G[{1}, yw]*G[{1, yv^(-1), yu^(-1), yv^(-1)}, yw] + 
     4*G[{yu^(-1)}, yw]*G[{1, yv^(-1), yu^(-1), yv^(-1)}, yw] - 
     4*G[{yu}, yv^(-1)]*G[{1, yv^(-1), yu^(-1), yv^(-1)}, yw] - 
     4*G[{1/(yu*yv)}, yw]*G[{1, yv^(-1), yu^(-1), yv^(-1)}, yw] + 
     4*G[{0}, yu^(-1)]*G[{1, yv^(-1), yu^(-1), 1/(yu*yv)}, yw] + 
     4*G[{0}, yv^(-1)]*G[{1, yv^(-1), yu^(-1), 1/(yu*yv)}, yw] - 
     4*G[{0}, yw]*G[{1, yv^(-1), yu^(-1), 1/(yu*yv)}, yw] - 
     8*G[{1}, yu^(-1)]*G[{1, yv^(-1), yu^(-1), 1/(yu*yv)}, yw] - 
     4*G[{1}, yv^(-1)]*G[{1, yv^(-1), yu^(-1), 1/(yu*yv)}, yw] - 
     4*G[{1}, yw]*G[{1, yv^(-1), yu^(-1), 1/(yu*yv)}, yw] + 
     4*G[{yu}, yv^(-1)]*G[{1, yv^(-1), yu^(-1), 1/(yu*yv)}, yw] - 
     4*G[{0}, yu^(-1)]*G[{1, yv^(-1), yv^(-1), yu^(-1)}, yw] - 
     4*G[{0}, yv^(-1)]*G[{1, yv^(-1), yv^(-1), yu^(-1)}, yw] + 
     4*G[{0}, yw]*G[{1, yv^(-1), yv^(-1), yu^(-1)}, yw] + 
     8*G[{1}, yu^(-1)]*G[{1, yv^(-1), yv^(-1), yu^(-1)}, yw] + 
     4*G[{1}, yv^(-1)]*G[{1, yv^(-1), yv^(-1), yu^(-1)}, yw] + 
     4*G[{1}, yw]*G[{1, yv^(-1), yv^(-1), yu^(-1)}, yw] + 
     4*G[{yu^(-1)}, yw]*G[{1, yv^(-1), yv^(-1), yu^(-1)}, yw] - 
     4*G[{yu}, yv^(-1)]*G[{1, yv^(-1), yv^(-1), yu^(-1)}, yw] - 
     4*G[{1/(yu*yv)}, yw]*G[{1, yv^(-1), yv^(-1), yu^(-1)}, yw] + 
     8*G[{yu^(-1)}, yw]*G[{1, yv^(-1), yv^(-1), yv^(-1)}, yw] - 
     8*G[{1/(yu*yv)}, yw]*G[{1, yv^(-1), yv^(-1), yv^(-1)}, yw] + 
     4*G[{0}, yu^(-1)]*G[{1, yv^(-1), yv^(-1), 1/(yu*yv)}, yw] + 
     4*G[{0}, yv^(-1)]*G[{1, yv^(-1), yv^(-1), 1/(yu*yv)}, yw] - 
     4*G[{0}, yw]*G[{1, yv^(-1), yv^(-1), 1/(yu*yv)}, yw] - 
     8*G[{1}, yu^(-1)]*G[{1, yv^(-1), yv^(-1), 1/(yu*yv)}, yw] - 
     4*G[{1}, yv^(-1)]*G[{1, yv^(-1), yv^(-1), 1/(yu*yv)}, yw] - 
     4*G[{1}, yw]*G[{1, yv^(-1), yv^(-1), 1/(yu*yv)}, yw] + 
     4*G[{yu^(-1)}, yw]*G[{1, yv^(-1), yv^(-1), 1/(yu*yv)}, yw] + 
     4*G[{yu}, yv^(-1)]*G[{1, yv^(-1), yv^(-1), 1/(yu*yv)}, yw] - 
     4*G[{1/(yu*yv)}, yw]*G[{1, yv^(-1), yv^(-1), 1/(yu*yv)}, yw] + 
     4*G[{0}, yu^(-1)]*G[{1, yv^(-1), 1/(yu*yv), yu^(-1)}, yw] + 
     4*G[{0}, yv^(-1)]*G[{1, yv^(-1), 1/(yu*yv), yu^(-1)}, yw] - 
     4*G[{0}, yw]*G[{1, yv^(-1), 1/(yu*yv), yu^(-1)}, yw] - 
     4*G[{1}, yu^(-1)]*G[{1, yv^(-1), 1/(yu*yv), yu^(-1)}, yw] - 
     4*G[{1}, yv^(-1)]*G[{1, yv^(-1), 1/(yu*yv), yu^(-1)}, yw] - 
     4*G[{yu^(-1)}, yw]*G[{1, yv^(-1), 1/(yu*yv), yu^(-1)}, yw] + 
     4*G[{1/(yu*yv)}, yw]*G[{1, yv^(-1), 1/(yu*yv), yu^(-1)}, yw] + 
     4*G[{0}, yu^(-1)]*G[{1, yv^(-1), 1/(yu*yv), yv^(-1)}, yw] + 
     4*G[{0}, yv^(-1)]*G[{1, yv^(-1), 1/(yu*yv), yv^(-1)}, yw] - 
     4*G[{0}, yw]*G[{1, yv^(-1), 1/(yu*yv), yv^(-1)}, yw] - 
     8*G[{1}, yu^(-1)]*G[{1, yv^(-1), 1/(yu*yv), yv^(-1)}, yw] - 
     4*G[{1}, yv^(-1)]*G[{1, yv^(-1), 1/(yu*yv), yv^(-1)}, yw] - 
     4*G[{1}, yw]*G[{1, yv^(-1), 1/(yu*yv), yv^(-1)}, yw] + 
     4*G[{yu}, yv^(-1)]*G[{1, yv^(-1), 1/(yu*yv), yv^(-1)}, yw] - 
     4*G[{0}, yu^(-1)]*G[{1, yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] - 
     4*G[{0}, yv^(-1)]*G[{1, yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] + 
     4*G[{0}, yw]*G[{1, yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] + 
     4*G[{1}, yu^(-1)]*G[{1, yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] + 
     4*G[{1}, yv^(-1)]*G[{1, yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] - 
     4*G[{0}, yu^(-1)]*G[{1, 1/(yu*yv), yu^(-1), yu^(-1)}, yw] - 
     4*G[{0}, yv^(-1)]*G[{1, 1/(yu*yv), yu^(-1), yu^(-1)}, yw] + 
     4*G[{0}, yw]*G[{1, 1/(yu*yv), yu^(-1), yu^(-1)}, yw] + 
     4*G[{1}, yv^(-1)]*G[{1, 1/(yu*yv), yu^(-1), yu^(-1)}, yw] - 
     4*G[{1}, yw]*G[{1, 1/(yu*yv), yu^(-1), yu^(-1)}, yw] - 
     4*G[{yu^(-1)}, yw]*G[{1, 1/(yu*yv), yu^(-1), yu^(-1)}, yw] + 
     4*G[{yu}, yv^(-1)]*G[{1, 1/(yu*yv), yu^(-1), yu^(-1)}, yw] + 
     4*G[{1/(yu*yv)}, yw]*G[{1, 1/(yu*yv), yu^(-1), yu^(-1)}, yw] + 
     4*G[{0}, yu^(-1)]*G[{1, 1/(yu*yv), yu^(-1), 1/(yu*yv)}, yw] + 
     4*G[{0}, yv^(-1)]*G[{1, 1/(yu*yv), yu^(-1), 1/(yu*yv)}, yw] - 
     4*G[{0}, yw]*G[{1, 1/(yu*yv), yu^(-1), 1/(yu*yv)}, yw] - 
     4*G[{1}, yv^(-1)]*G[{1, 1/(yu*yv), yu^(-1), 1/(yu*yv)}, yw] + 
     4*G[{1}, yw]*G[{1, 1/(yu*yv), yu^(-1), 1/(yu*yv)}, yw] + 
     4*G[{yu^(-1)}, yw]*G[{1, 1/(yu*yv), yu^(-1), 1/(yu*yv)}, yw] - 
     4*G[{yu}, yv^(-1)]*G[{1, 1/(yu*yv), yu^(-1), 1/(yu*yv)}, yw] - 
     4*G[{1/(yu*yv)}, yw]*G[{1, 1/(yu*yv), yu^(-1), 1/(yu*yv)}, yw] + 
     4*G[{0}, yu^(-1)]*G[{1, 1/(yu*yv), yv^(-1), yv^(-1)}, yw] + 
     4*G[{0}, yv^(-1)]*G[{1, 1/(yu*yv), yv^(-1), yv^(-1)}, yw] - 
     4*G[{0}, yw]*G[{1, 1/(yu*yv), yv^(-1), yv^(-1)}, yw] - 
     8*G[{1}, yu^(-1)]*G[{1, 1/(yu*yv), yv^(-1), yv^(-1)}, yw] - 
     4*G[{1}, yv^(-1)]*G[{1, 1/(yu*yv), yv^(-1), yv^(-1)}, yw] - 
     4*G[{1}, yw]*G[{1, 1/(yu*yv), yv^(-1), yv^(-1)}, yw] + 
     4*G[{yu^(-1)}, yw]*G[{1, 1/(yu*yv), yv^(-1), yv^(-1)}, yw] + 
     4*G[{yu}, yv^(-1)]*G[{1, 1/(yu*yv), yv^(-1), yv^(-1)}, yw] - 
     4*G[{1/(yu*yv)}, yw]*G[{1, 1/(yu*yv), yv^(-1), yv^(-1)}, yw] - 
     4*G[{yu^(-1)}, yw]*G[{1, 1/(yu*yv), yv^(-1), 1/(yu*yv)}, yw] + 
     4*G[{1/(yu*yv)}, yw]*G[{1, 1/(yu*yv), yv^(-1), 1/(yu*yv)}, yw] + 
     4*G[{0}, yu^(-1)]*G[{1, 1/(yu*yv), 1/(yu*yv), yu^(-1)}, yw] + 
     4*G[{0}, yv^(-1)]*G[{1, 1/(yu*yv), 1/(yu*yv), yu^(-1)}, yw] - 
     4*G[{0}, yw]*G[{1, 1/(yu*yv), 1/(yu*yv), yu^(-1)}, yw] - 
     4*G[{1}, yu^(-1)]*G[{1, 1/(yu*yv), 1/(yu*yv), yu^(-1)}, yw] - 
     4*G[{1}, yv^(-1)]*G[{1, 1/(yu*yv), 1/(yu*yv), yu^(-1)}, yw] - 
     4*G[{yu^(-1)}, yw]*G[{1, 1/(yu*yv), 1/(yu*yv), yv^(-1)}, yw] + 
     4*G[{1/(yu*yv)}, yw]*G[{1, 1/(yu*yv), 1/(yu*yv), yv^(-1)}, yw] - 
     4*G[{0}, yu^(-1)]*G[{1, 1/(yu*yv), 1/(yu*yv), 1/(yu*yv)}, yw] - 
     4*G[{0}, yv^(-1)]*G[{1, 1/(yu*yv), 1/(yu*yv), 1/(yu*yv)}, yw] + 
     4*G[{0}, yw]*G[{1, 1/(yu*yv), 1/(yu*yv), 1/(yu*yv)}, yw] + 
     4*G[{1}, yu^(-1)]*G[{1, 1/(yu*yv), 1/(yu*yv), 1/(yu*yv)}, yw] + 
     4*G[{1}, yv^(-1)]*G[{1, 1/(yu*yv), 1/(yu*yv), 1/(yu*yv)}, yw] - 
     8*G[{1}, yu^(-1)]*G[{yu^(-1), yu^(-1), yu^(-1), 1/(yu*yv)}, yw] - 
     8*G[{1}, yw]*G[{yu^(-1), yu^(-1), yu^(-1), 1/(yu*yv)}, yw] + 
     8*G[{yu}, yv^(-1)]*G[{yu^(-1), yu^(-1), yu^(-1), 1/(yu*yv)}, yw] - 
     8*G[{1/(yu*yv)}, yw]*G[{yu^(-1), yu^(-1), yu^(-1), 1/(yu*yv)}, yw] - 
     4*G[{0}, yu^(-1)]*G[{yu^(-1), yu^(-1), 1/(yu*yv), yv^(-1)}, yw] - 
     4*G[{0}, yv^(-1)]*G[{yu^(-1), yu^(-1), 1/(yu*yv), yv^(-1)}, yw] + 
     4*G[{0}, yw]*G[{yu^(-1), yu^(-1), 1/(yu*yv), yv^(-1)}, yw] + 
     8*G[{1}, yu^(-1)]*G[{yu^(-1), yu^(-1), 1/(yu*yv), yv^(-1)}, yw] + 
     4*G[{1}, yv^(-1)]*G[{yu^(-1), yu^(-1), 1/(yu*yv), yv^(-1)}, yw] + 
     4*G[{1}, yw]*G[{yu^(-1), yu^(-1), 1/(yu*yv), yv^(-1)}, yw] - 
     4*G[{yu^(-1)}, yw]*G[{yu^(-1), yu^(-1), 1/(yu*yv), yv^(-1)}, yw] - 
     4*G[{yu}, yv^(-1)]*G[{yu^(-1), yu^(-1), 1/(yu*yv), yv^(-1)}, yw] - 
     4*G[{1/(yu*yv)}, yw]*G[{yu^(-1), yu^(-1), 1/(yu*yv), yv^(-1)}, yw] - 
     4*G[{1/(yu*yv)}, yw]*G[{yu^(-1), yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] + 
     4*G[{0}, yu^(-1)]*G[{yu^(-1), 1/(yu*yv), yv^(-1), yv^(-1)}, yw] + 
     4*G[{0}, yv^(-1)]*G[{yu^(-1), 1/(yu*yv), yv^(-1), yv^(-1)}, yw] - 
     4*G[{0}, yw]*G[{yu^(-1), 1/(yu*yv), yv^(-1), yv^(-1)}, yw] - 
     8*G[{1}, yu^(-1)]*G[{yu^(-1), 1/(yu*yv), yv^(-1), yv^(-1)}, yw] - 
     4*G[{1}, yv^(-1)]*G[{yu^(-1), 1/(yu*yv), yv^(-1), yv^(-1)}, yw] - 
     4*G[{1}, yw]*G[{yu^(-1), 1/(yu*yv), yv^(-1), yv^(-1)}, yw] + 
     4*G[{yu^(-1)}, yw]*G[{yu^(-1), 1/(yu*yv), yv^(-1), yv^(-1)}, yw] + 
     4*G[{yu}, yv^(-1)]*G[{yu^(-1), 1/(yu*yv), yv^(-1), yv^(-1)}, yw] + 
     4*G[{1/(yu*yv)}, yw]*G[{yu^(-1), 1/(yu*yv), yv^(-1), yv^(-1)}, yw] - 
     4*G[{0}, yu^(-1)]*G[{yu^(-1), 1/(yu*yv), yv^(-1), 1/(yu*yv)}, yw] - 
     4*G[{0}, yv^(-1)]*G[{yu^(-1), 1/(yu*yv), yv^(-1), 1/(yu*yv)}, yw] + 
     4*G[{0}, yw]*G[{yu^(-1), 1/(yu*yv), yv^(-1), 1/(yu*yv)}, yw] + 
     8*G[{1}, yu^(-1)]*G[{yu^(-1), 1/(yu*yv), yv^(-1), 1/(yu*yv)}, yw] + 
     4*G[{1}, yv^(-1)]*G[{yu^(-1), 1/(yu*yv), yv^(-1), 1/(yu*yv)}, yw] + 
     4*G[{1}, yw]*G[{yu^(-1), 1/(yu*yv), yv^(-1), 1/(yu*yv)}, yw] - 
     4*G[{yu^(-1)}, yw]*G[{yu^(-1), 1/(yu*yv), yv^(-1), 1/(yu*yv)}, yw] - 
     4*G[{yu}, yv^(-1)]*G[{yu^(-1), 1/(yu*yv), yv^(-1), 1/(yu*yv)}, yw] - 
     4*G[{0}, yu^(-1)]*G[{yu^(-1), 1/(yu*yv), 1/(yu*yv), yv^(-1)}, yw] - 
     4*G[{0}, yv^(-1)]*G[{yu^(-1), 1/(yu*yv), 1/(yu*yv), yv^(-1)}, yw] + 
     4*G[{0}, yw]*G[{yu^(-1), 1/(yu*yv), 1/(yu*yv), yv^(-1)}, yw] + 
     8*G[{1}, yu^(-1)]*G[{yu^(-1), 1/(yu*yv), 1/(yu*yv), yv^(-1)}, yw] + 
     4*G[{1}, yv^(-1)]*G[{yu^(-1), 1/(yu*yv), 1/(yu*yv), yv^(-1)}, yw] + 
     4*G[{1}, yw]*G[{yu^(-1), 1/(yu*yv), 1/(yu*yv), yv^(-1)}, yw] - 
     4*G[{yu^(-1)}, yw]*G[{yu^(-1), 1/(yu*yv), 1/(yu*yv), yv^(-1)}, yw] - 
     4*G[{yu}, yv^(-1)]*G[{yu^(-1), 1/(yu*yv), 1/(yu*yv), yv^(-1)}, yw] + 
     4*G[{1/(yu*yv)}, yw]*G[{yu^(-1), 1/(yu*yv), 1/(yu*yv), yv^(-1)}, yw] + 
     8*G[{1}, yu^(-1)]*G[{yu^(-1), 1/(yu*yv), 1/(yu*yv), 1/(yu*yv)}, yw] + 
     8*G[{1}, yw]*G[{yu^(-1), 1/(yu*yv), 1/(yu*yv), 1/(yu*yv)}, yw] - 
     8*G[{yu}, yv^(-1)]*G[{yu^(-1), 1/(yu*yv), 1/(yu*yv), 1/(yu*yv)}, yw] + 
     8*G[{1/(yu*yv)}, yw]*G[{yv^(-1), yv^(-1), yv^(-1), 1/(yu*yv)}, yw] + 
     4*G[{0}, yu^(-1)]*G[{yv^(-1), yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] + 
     4*G[{0}, yv^(-1)]*G[{yv^(-1), yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] - 
     4*G[{0}, yw]*G[{yv^(-1), yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] - 
     8*G[{1}, yu^(-1)]*G[{yv^(-1), yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] - 
     4*G[{1}, yv^(-1)]*G[{yv^(-1), yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] - 
     4*G[{1}, yw]*G[{yv^(-1), yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] + 
     4*G[{yu^(-1)}, yw]*G[{yv^(-1), yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] + 
     4*G[{yu}, yv^(-1)]*G[{yv^(-1), yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] + 
     8*G[{yv^(-1)}, yw]*G[{yv^(-1), yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] + 
     4*G[{1/(yu*yv)}, yw]*G[{yv^(-1), yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] + 
     4*G[{0}, yu^(-1)]*G[{yv^(-1), 1/(yu*yv), 1/(yu*yv), 1/(yu*yv)}, yw] + 
     4*G[{0}, yv^(-1)]*G[{yv^(-1), 1/(yu*yv), 1/(yu*yv), 1/(yu*yv)}, yw] - 
     4*G[{0}, yw]*G[{yv^(-1), 1/(yu*yv), 1/(yu*yv), 1/(yu*yv)}, yw] - 
     8*G[{1}, yu^(-1)]*G[{yv^(-1), 1/(yu*yv), 1/(yu*yv), 1/(yu*yv)}, yw] - 
     4*G[{1}, yv^(-1)]*G[{yv^(-1), 1/(yu*yv), 1/(yu*yv), 1/(yu*yv)}, yw] - 
     4*G[{1}, yw]*G[{yv^(-1), 1/(yu*yv), 1/(yu*yv), 1/(yu*yv)}, yw] + 
     4*G[{yu^(-1)}, yw]*G[{yv^(-1), 1/(yu*yv), 1/(yu*yv), 1/(yu*yv)}, yw] + 
     4*G[{yu}, yv^(-1)]*G[{yv^(-1), 1/(yu*yv), 1/(yu*yv), 1/(yu*yv)}, yw] + 
     8*G[{yv^(-1)}, yw]*G[{yv^(-1), 1/(yu*yv), 1/(yu*yv), 1/(yu*yv)}, yw] + 
     12*G[{0, 0, 0, 1, 1}, yv^(-1)] - 12*G[{0, 0, 0, yu, yu}, yv^(-1)] + 
     4*G[{0, 0, 1, 0, 1}, yv^(-1)] - 24*G[{0, 0, 1, 1, 1}, yu^(-1)] - 
     8*G[{0, 0, 1, yu^(-1), yu^(-1)}, yw] + 
     4*G[{0, 0, 1, yu^(-1), 1/(yu*yv)}, yw] + 
     12*G[{0, 0, 1, yu, yu}, yv^(-1)] + 4*G[{0, 0, 1, yv^(-1), 1/(yu*yv)}, 
       yw] + 4*G[{0, 0, 1, 1/(yu*yv), yu^(-1)}, yw] + 
     4*G[{0, 0, 1, 1/(yu*yv), yv^(-1)}, yw] - 
     8*G[{0, 0, 1, 1/(yu*yv), 1/(yu*yv)}, yw] - 
     4*G[{0, 0, yu^(-1), 1, yu^(-1)}, yw] + 
     4*G[{0, 0, yu^(-1), 1, 1/(yu*yv)}, yw] - 
     4*G[{0, 0, yu^(-1), yv^(-1), 1}, yw] + 
     8*G[{0, 0, yu^(-1), yv^(-1), yv^(-1)}, yw] + 
     4*G[{0, 0, yu^(-1), 1/(yu*yv), 1}, yw] - 
     4*G[{0, 0, yu, 0, yu}, yv^(-1)] + 8*G[{0, 0, yu, 1, yu}, yv^(-1)] + 
     4*G[{0, 0, yu, yu, yu}, yv^(-1)] - 4*G[{0, 0, yv^(-1), 1, yu^(-1)}, 
       yw] + 4*G[{0, 0, yv^(-1), 1, 1/(yu*yv)}, yw] - 
     4*G[{0, 0, yv^(-1), yu^(-1), 1}, yw] + 
     4*G[{0, 0, yv^(-1), yu^(-1), yv^(-1)}, yw] - 
     4*G[{0, 0, yv^(-1), 1/(yu*yv), yu^(-1)}, yw] + 
     8*G[{0, 0, yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] + 
     4*G[{0, 0, 1/(yu*yv), 1, yu^(-1)}, yw] - 
     4*G[{0, 0, 1/(yu*yv), 1, 1/(yu*yv)}, yw] + 
     4*G[{0, 0, 1/(yu*yv), yu^(-1), 1}, yw] - 
     4*G[{0, 0, 1/(yu*yv), yu^(-1), yv^(-1)}, yw] - 
     4*G[{0, 0, 1/(yu*yv), yv^(-1), yu^(-1)}, yw] + 
     4*G[{0, 0, 1/(yu*yv), yv^(-1), 1/(yu*yv)}, yw] - 
     8*G[{0, 1, 0, 1, 1}, yu^(-1)] - 2*G[{0, 1, 0, 1, yu^(-1)}, yw] + 
     2*G[{0, 1, 0, 1, 1/(yu*yv)}, yw] - 2*G[{0, 1, 0, yu^(-1), 1}, yw] - 
     4*G[{0, 1, 0, yu^(-1), yu^(-1)}, yw] + 
     2*G[{0, 1, 0, yu^(-1), yv^(-1)}, yw] + 
     2*G[{0, 1, 0, yu^(-1), 1/(yu*yv)}, yw] + 
     8*G[{0, 1, 0, yu, yu}, yv^(-1)] + 2*G[{0, 1, 0, yv^(-1), yu^(-1)}, yw] + 
     2*G[{0, 1, 0, 1/(yu*yv), 1}, yw] + 2*G[{0, 1, 0, 1/(yu*yv), yu^(-1)}, 
       yw] - 4*G[{0, 1, 0, 1/(yu*yv), 1/(yu*yv)}, yw] - 
     8*G[{0, 1, 1, 1, 1}, yu^(-1)] + 2*G[{0, 1, 1, 1, yu^(-1)}, yw] - 
     2*G[{0, 1, 1, 1, 1/(yu*yv)}, yw] + 2*G[{0, 1, 1, yu^(-1), 1}, yw] + 
     8*G[{0, 1, 1, yu^(-1), yu^(-1)}, yw] + 
     2*G[{0, 1, 1, yu^(-1), yv^(-1)}, yw] - 
     4*G[{0, 1, 1, yu^(-1), 1/(yu*yv)}, yw] - 
     8*G[{0, 1, 1, yu, yu}, yv^(-1)] + 2*G[{0, 1, 1, yv^(-1), yu^(-1)}, yw] - 
     2*G[{0, 1, 1, yv^(-1), 1/(yu*yv)}, yw] - 
     2*G[{0, 1, 1, 1/(yu*yv), 1}, yw] - 4*G[{0, 1, 1, 1/(yu*yv), yu^(-1)}, 
       yw] - 2*G[{0, 1, 1, 1/(yu*yv), yv^(-1)}, yw] - 
     2*G[{0, 1, yu^(-1), 0, yu^(-1)}, yw] - 
     2*G[{0, 1, yu^(-1), 0, yv^(-1)}, yw] + 
     2*G[{0, 1, yu^(-1), 0, 1/(yu*yv)}, yw] + 
     8*G[{0, 1, yu^(-1), 1, yu^(-1)}, yw] + 
     4*G[{0, 1, yu^(-1), 1, yv^(-1)}, yw] - 
     4*G[{0, 1, yu^(-1), 1, 1/(yu*yv)}, yw] + 
     4*G[{0, 1, yu^(-1), yu^(-1), 1}, yw] - 
     8*G[{0, 1, yu^(-1), yu^(-1), yu^(-1)}, yw] - 
     8*G[{0, 1, yu^(-1), yu^(-1), yv^(-1)}, yw] + 
     4*G[{0, 1, yu^(-1), yu^(-1), 1/(yu*yv)}, yw] + 
     4*G[{0, 1, yu^(-1), yv^(-1), 1}, yw] - 
     8*G[{0, 1, yu^(-1), yv^(-1), yu^(-1)}, yw] - 
     8*G[{0, 1, yu^(-1), yv^(-1), yv^(-1)}, yw] + 
     4*G[{0, 1, yu^(-1), yv^(-1), 1/(yu*yv)}, yw] - 
     4*G[{0, 1, yu^(-1), 1/(yu*yv), 1}, yw] + 
     4*G[{0, 1, yu^(-1), 1/(yu*yv), yu^(-1)}, yw] + 
     8*G[{0, 1, yu^(-1), 1/(yu*yv), yv^(-1)}, yw] + 
     4*G[{0, 1, yu, 0, yu}, yv^(-1)] - 8*G[{0, 1, yu, 1, yu}, yv^(-1)] + 
     8*G[{0, 1, yu, yu, yu}, yv^(-1)] + 2*G[{0, 1, yv^(-1), 0, yu^(-1)}, 
       yw] + 4*G[{0, 1, yv^(-1), 1, yu^(-1)}, yw] - 
     4*G[{0, 1, yv^(-1), 1, 1/(yu*yv)}, yw] + 
     4*G[{0, 1, yv^(-1), yu^(-1), 1}, yw] - 
     8*G[{0, 1, yv^(-1), yu^(-1), yu^(-1)}, yw] - 
     8*G[{0, 1, yv^(-1), yu^(-1), yv^(-1)}, yw] + 
     4*G[{0, 1, yv^(-1), yu^(-1), 1/(yu*yv)}, yw] - 
     8*G[{0, 1, yv^(-1), yv^(-1), yu^(-1)}, yw] + 
     8*G[{0, 1, yv^(-1), yv^(-1), 1/(yu*yv)}, yw] - 
     4*G[{0, 1, yv^(-1), 1/(yu*yv), 1}, yw] + 
     4*G[{0, 1, yv^(-1), 1/(yu*yv), yu^(-1)}, yw] + 
     8*G[{0, 1, yv^(-1), 1/(yu*yv), yv^(-1)}, yw] + 
     2*G[{0, 1, 1/(yu*yv), 0, yv^(-1)}, yw] - 
     2*G[{0, 1, 1/(yu*yv), 0, 1/(yu*yv)}, yw] - 
     6*G[{0, 1, 1/(yu*yv), 1, yu^(-1)}, yw] - 
     4*G[{0, 1, 1/(yu*yv), 1, yv^(-1)}, yw] + 
     2*G[{0, 1, 1/(yu*yv), 1, 1/(yu*yv)}, yw] - 
     2*G[{0, 1, 1/(yu*yv), yu^(-1), 1}, yw] + 
     8*G[{0, 1, 1/(yu*yv), yu^(-1), yu^(-1)}, yw] + 
     6*G[{0, 1, 1/(yu*yv), yu^(-1), yv^(-1)}, yw] - 
     4*G[{0, 1, 1/(yu*yv), yu^(-1), 1/(yu*yv)}, yw] - 
     4*G[{0, 1, 1/(yu*yv), yv^(-1), 1}, yw] + 
     6*G[{0, 1, 1/(yu*yv), yv^(-1), yu^(-1)}, yw] + 
     8*G[{0, 1, 1/(yu*yv), yv^(-1), yv^(-1)}, yw] - 
     2*G[{0, 1, 1/(yu*yv), yv^(-1), 1/(yu*yv)}, yw] + 
     2*G[{0, 1, 1/(yu*yv), 1/(yu*yv), 1}, yw] - 
     4*G[{0, 1, 1/(yu*yv), 1/(yu*yv), yu^(-1)}, yw] - 
     6*G[{0, 1, 1/(yu*yv), 1/(yu*yv), yv^(-1)}, yw] + 
     2*G[{0, yu^(-1), 0, yu^(-1), 1}, yw] - 
     2*G[{0, yu^(-1), 0, yu^(-1), yv^(-1)}, yw] - 
     2*G[{0, yu^(-1), 0, yv^(-1), 1}, yw] - 
     2*G[{0, yu^(-1), 0, yv^(-1), yu^(-1)}, yw] + 
     4*G[{0, yu^(-1), 0, yv^(-1), yv^(-1)}, yw] + 
     2*G[{0, yu^(-1), 0, yv^(-1), 1/(yu*yv)}, yw] + 
     2*G[{0, yu^(-1), 0, 1/(yu*yv), yv^(-1)}, yw] - 
     2*G[{0, yu^(-1), 1, 0, yv^(-1)}, yw] + 
     2*G[{0, yu^(-1), 1, 0, 1/(yu*yv)}, yw] + 
     6*G[{0, yu^(-1), 1, 1, yu^(-1)}, yw] + 
     4*G[{0, yu^(-1), 1, 1, yv^(-1)}, yw] - 
     2*G[{0, yu^(-1), 1, 1, 1/(yu*yv)}, yw] + 
     2*G[{0, yu^(-1), 1, yu^(-1), 1}, yw] - 
     8*G[{0, yu^(-1), 1, yu^(-1), yu^(-1)}, yw] - 
     6*G[{0, yu^(-1), 1, yu^(-1), yv^(-1)}, yw] + 
     4*G[{0, yu^(-1), 1, yu^(-1), 1/(yu*yv)}, yw] + 
     4*G[{0, yu^(-1), 1, yv^(-1), 1}, yw] - 
     6*G[{0, yu^(-1), 1, yv^(-1), yu^(-1)}, yw] - 
     8*G[{0, yu^(-1), 1, yv^(-1), yv^(-1)}, yw] + 
     2*G[{0, yu^(-1), 1, yv^(-1), 1/(yu*yv)}, yw] - 
     2*G[{0, yu^(-1), 1, 1/(yu*yv), 1}, yw] + 
     4*G[{0, yu^(-1), 1, 1/(yu*yv), yu^(-1)}, yw] + 
     6*G[{0, yu^(-1), 1, 1/(yu*yv), yv^(-1)}, yw] - 
     8*G[{0, yu^(-1), yu^(-1), 1, yu^(-1)}, yw] - 
     4*G[{0, yu^(-1), yu^(-1), 1, yv^(-1)}, yw] + 
     4*G[{0, yu^(-1), yu^(-1), 1, 1/(yu*yv)}, yw] - 
     8*G[{0, yu^(-1), yu^(-1), yu^(-1), 1}, yw] + 
     8*G[{0, yu^(-1), yu^(-1), yu^(-1), yv^(-1)}, yw] - 
     4*G[{0, yu^(-1), yu^(-1), yv^(-1), 1}, yw] + 
     8*G[{0, yu^(-1), yu^(-1), yv^(-1), yu^(-1)}, yw] + 
     8*G[{0, yu^(-1), yu^(-1), yv^(-1), yv^(-1)}, yw] - 
     4*G[{0, yu^(-1), yu^(-1), yv^(-1), 1/(yu*yv)}, yw] + 
     4*G[{0, yu^(-1), yu^(-1), 1/(yu*yv), 1}, yw] - 
     4*G[{0, yu^(-1), yu^(-1), 1/(yu*yv), yv^(-1)}, yw] + 
     2*G[{0, yu^(-1), yv^(-1), 0, yv^(-1)}, yw] - 
     2*G[{0, yu^(-1), yv^(-1), 0, 1/(yu*yv)}, yw] - 
     8*G[{0, yu^(-1), yv^(-1), 1, yu^(-1)}, yw] - 
     4*G[{0, yu^(-1), yv^(-1), 1, yv^(-1)}, yw] + 
     4*G[{0, yu^(-1), yv^(-1), 1, 1/(yu*yv)}, yw] - 
     4*G[{0, yu^(-1), yv^(-1), yu^(-1), 1}, yw] + 
     8*G[{0, yu^(-1), yv^(-1), yu^(-1), yu^(-1)}, yw] + 
     8*G[{0, yu^(-1), yv^(-1), yu^(-1), yv^(-1)}, yw] - 
     4*G[{0, yu^(-1), yv^(-1), yu^(-1), 1/(yu*yv)}, yw] - 
     4*G[{0, yu^(-1), yv^(-1), yv^(-1), 1}, yw] + 
     8*G[{0, yu^(-1), yv^(-1), yv^(-1), yu^(-1)}, yw] + 
     8*G[{0, yu^(-1), yv^(-1), yv^(-1), yv^(-1)}, yw] - 
     4*G[{0, yu^(-1), yv^(-1), yv^(-1), 1/(yu*yv)}, yw] + 
     4*G[{0, yu^(-1), yv^(-1), 1/(yu*yv), 1}, yw] - 
     4*G[{0, yu^(-1), yv^(-1), 1/(yu*yv), yu^(-1)}, yw] - 
     8*G[{0, yu^(-1), yv^(-1), 1/(yu*yv), yv^(-1)}, yw] + 
     2*G[{0, yu^(-1), 1/(yu*yv), 0, yv^(-1)}, yw] + 
     2*G[{0, yu^(-1), 1/(yu*yv), 1, yu^(-1)}, yw] + 
     4*G[{0, yu^(-1), 1/(yu*yv), 1, yv^(-1)}, yw] + 
     2*G[{0, yu^(-1), 1/(yu*yv), 1, 1/(yu*yv)}, yw] + 
     2*G[{0, yu^(-1), 1/(yu*yv), yu^(-1), 1}, yw] - 
     2*G[{0, yu^(-1), 1/(yu*yv), yu^(-1), yv^(-1)}, yw] + 
     4*G[{0, yu^(-1), 1/(yu*yv), yv^(-1), 1}, yw] - 
     2*G[{0, yu^(-1), 1/(yu*yv), yv^(-1), yu^(-1)}, yw] - 
     8*G[{0, yu^(-1), 1/(yu*yv), yv^(-1), yv^(-1)}, yw] - 
     2*G[{0, yu^(-1), 1/(yu*yv), yv^(-1), 1/(yu*yv)}, yw] + 
     2*G[{0, yu^(-1), 1/(yu*yv), 1/(yu*yv), 1}, yw] - 
     2*G[{0, yu^(-1), 1/(yu*yv), 1/(yu*yv), yv^(-1)}, yw] + 
     4*G[{0, yu, 0, yu, yu}, yv^(-1)] + 8*G[{0, yu, 1, yu, yu}, yv^(-1)] + 
     8*G[{0, yu, yu, 1, yu}, yv^(-1)] - 8*G[{0, yu, yu, yu, yu}, yv^(-1)] - 
     2*G[{0, yv^(-1), 0, yv^(-1), yu^(-1)}, yw] + 
     2*G[{0, yv^(-1), 0, yv^(-1), 1/(yu*yv)}, yw] - 
     2*G[{0, yv^(-1), 0, 1/(yu*yv), 1}, yw] - 
     2*G[{0, yv^(-1), 0, 1/(yu*yv), yu^(-1)}, yw] + 
     2*G[{0, yv^(-1), 0, 1/(yu*yv), yv^(-1)}, yw] + 
     4*G[{0, yv^(-1), 0, 1/(yu*yv), 1/(yu*yv)}, yw] - 
     2*G[{0, yv^(-1), 1, 1, yu^(-1)}, yw] + 
     2*G[{0, yv^(-1), 1, 1, 1/(yu*yv)}, yw] - 
     2*G[{0, yv^(-1), 1, yu^(-1), 1}, yw] - 
     8*G[{0, yv^(-1), 1, yu^(-1), yu^(-1)}, yw] - 
     2*G[{0, yv^(-1), 1, yu^(-1), yv^(-1)}, yw] + 
     4*G[{0, yv^(-1), 1, yu^(-1), 1/(yu*yv)}, yw] - 
     2*G[{0, yv^(-1), 1, yv^(-1), yu^(-1)}, yw] + 
     2*G[{0, yv^(-1), 1, yv^(-1), 1/(yu*yv)}, yw] + 
     2*G[{0, yv^(-1), 1, 1/(yu*yv), 1}, yw] + 
     4*G[{0, yv^(-1), 1, 1/(yu*yv), yu^(-1)}, yw] + 
     2*G[{0, yv^(-1), 1, 1/(yu*yv), yv^(-1)}, yw] - 
     2*G[{0, yv^(-1), yu^(-1), 0, 1/(yu*yv)}, yw] - 
     8*G[{0, yv^(-1), yu^(-1), 1, yu^(-1)}, yw] - 
     4*G[{0, yv^(-1), yu^(-1), 1, yv^(-1)}, yw] + 
     4*G[{0, yv^(-1), yu^(-1), 1, 1/(yu*yv)}, yw] - 
     4*G[{0, yv^(-1), yu^(-1), yu^(-1), 1}, yw] + 
     8*G[{0, yv^(-1), yu^(-1), yu^(-1), yu^(-1)}, yw] + 
     8*G[{0, yv^(-1), yu^(-1), yu^(-1), yv^(-1)}, yw] - 
     4*G[{0, yv^(-1), yu^(-1), yu^(-1), 1/(yu*yv)}, yw] - 
     4*G[{0, yv^(-1), yu^(-1), yv^(-1), 1}, yw] + 
     8*G[{0, yv^(-1), yu^(-1), yv^(-1), yu^(-1)}, yw] + 
     8*G[{0, yv^(-1), yu^(-1), yv^(-1), yv^(-1)}, yw] - 
     4*G[{0, yv^(-1), yu^(-1), yv^(-1), 1/(yu*yv)}, yw] + 
     4*G[{0, yv^(-1), yu^(-1), 1/(yu*yv), 1}, yw] - 
     4*G[{0, yv^(-1), yu^(-1), 1/(yu*yv), yu^(-1)}, yw] - 
     8*G[{0, yv^(-1), yu^(-1), 1/(yu*yv), yv^(-1)}, yw] - 
     4*G[{0, yv^(-1), yv^(-1), 1, yu^(-1)}, yw] + 
     4*G[{0, yv^(-1), yv^(-1), 1, 1/(yu*yv)}, yw] - 
     4*G[{0, yv^(-1), yv^(-1), yu^(-1), 1}, yw] + 
     8*G[{0, yv^(-1), yv^(-1), yu^(-1), yu^(-1)}, yw] + 
     8*G[{0, yv^(-1), yv^(-1), yu^(-1), yv^(-1)}, yw] - 
     4*G[{0, yv^(-1), yv^(-1), yu^(-1), 1/(yu*yv)}, yw] + 
     8*G[{0, yv^(-1), yv^(-1), yv^(-1), yu^(-1)}, yw] - 
     8*G[{0, yv^(-1), yv^(-1), yv^(-1), 1/(yu*yv)}, yw] + 
     4*G[{0, yv^(-1), yv^(-1), 1/(yu*yv), 1}, yw] - 
     4*G[{0, yv^(-1), yv^(-1), 1/(yu*yv), yu^(-1)}, yw] - 
     8*G[{0, yv^(-1), yv^(-1), 1/(yu*yv), yv^(-1)}, yw] + 
     2*G[{0, yv^(-1), 1/(yu*yv), 0, 1/(yu*yv)}, yw] + 
     6*G[{0, yv^(-1), 1/(yu*yv), 1, yu^(-1)}, yw] + 
     4*G[{0, yv^(-1), 1/(yu*yv), 1, yv^(-1)}, yw] - 
     2*G[{0, yv^(-1), 1/(yu*yv), 1, 1/(yu*yv)}, yw] + 
     2*G[{0, yv^(-1), 1/(yu*yv), yu^(-1), 1}, yw] - 
     8*G[{0, yv^(-1), 1/(yu*yv), yu^(-1), yu^(-1)}, yw] - 
     6*G[{0, yv^(-1), 1/(yu*yv), yu^(-1), yv^(-1)}, yw] + 
     4*G[{0, yv^(-1), 1/(yu*yv), yu^(-1), 1/(yu*yv)}, yw] + 
     4*G[{0, yv^(-1), 1/(yu*yv), yv^(-1), 1}, yw] - 
     6*G[{0, yv^(-1), 1/(yu*yv), yv^(-1), yu^(-1)}, yw] - 
     8*G[{0, yv^(-1), 1/(yu*yv), yv^(-1), yv^(-1)}, yw] + 
     2*G[{0, yv^(-1), 1/(yu*yv), yv^(-1), 1/(yu*yv)}, yw] - 
     2*G[{0, yv^(-1), 1/(yu*yv), 1/(yu*yv), 1}, yw] + 
     4*G[{0, yv^(-1), 1/(yu*yv), 1/(yu*yv), yu^(-1)}, yw] + 
     6*G[{0, yv^(-1), 1/(yu*yv), 1/(yu*yv), yv^(-1)}, yw] + 
     2*G[{0, 1/(yu*yv), 0, 1/(yu*yv), 1}, yw] - 
     2*G[{0, 1/(yu*yv), 0, 1/(yu*yv), yv^(-1)}, yw] - 
     6*G[{0, 1/(yu*yv), 1, 1, yu^(-1)}, yw] - 
     4*G[{0, 1/(yu*yv), 1, 1, yv^(-1)}, yw] + 
     2*G[{0, 1/(yu*yv), 1, 1, 1/(yu*yv)}, yw] - 
     2*G[{0, 1/(yu*yv), 1, yu^(-1), 1}, yw] + 
     8*G[{0, 1/(yu*yv), 1, yu^(-1), yu^(-1)}, yw] + 
     6*G[{0, 1/(yu*yv), 1, yu^(-1), yv^(-1)}, yw] - 
     4*G[{0, 1/(yu*yv), 1, yu^(-1), 1/(yu*yv)}, yw] - 
     4*G[{0, 1/(yu*yv), 1, yv^(-1), 1}, yw] + 
     6*G[{0, 1/(yu*yv), 1, yv^(-1), yu^(-1)}, yw] + 
     8*G[{0, 1/(yu*yv), 1, yv^(-1), yv^(-1)}, yw] - 
     2*G[{0, 1/(yu*yv), 1, yv^(-1), 1/(yu*yv)}, yw] + 
     2*G[{0, 1/(yu*yv), 1, 1/(yu*yv), 1}, yw] - 
     4*G[{0, 1/(yu*yv), 1, 1/(yu*yv), yu^(-1)}, yw] - 
     6*G[{0, 1/(yu*yv), 1, 1/(yu*yv), yv^(-1)}, yw] + 
     8*G[{0, 1/(yu*yv), yu^(-1), 1, yu^(-1)}, yw] + 
     4*G[{0, 1/(yu*yv), yu^(-1), 1, yv^(-1)}, yw] - 
     4*G[{0, 1/(yu*yv), yu^(-1), 1, 1/(yu*yv)}, yw] + 
     8*G[{0, 1/(yu*yv), yu^(-1), yu^(-1), 1}, yw] - 
     8*G[{0, 1/(yu*yv), yu^(-1), yu^(-1), yv^(-1)}, yw] + 
     4*G[{0, 1/(yu*yv), yu^(-1), yv^(-1), 1}, yw] - 
     8*G[{0, 1/(yu*yv), yu^(-1), yv^(-1), yu^(-1)}, yw] - 
     8*G[{0, 1/(yu*yv), yu^(-1), yv^(-1), yv^(-1)}, yw] + 
     4*G[{0, 1/(yu*yv), yu^(-1), yv^(-1), 1/(yu*yv)}, yw] - 
     4*G[{0, 1/(yu*yv), yu^(-1), 1/(yu*yv), 1}, yw] + 
     4*G[{0, 1/(yu*yv), yu^(-1), 1/(yu*yv), yv^(-1)}, yw] + 
     8*G[{0, 1/(yu*yv), yv^(-1), 1, yu^(-1)}, yw] + 
     4*G[{0, 1/(yu*yv), yv^(-1), 1, yv^(-1)}, yw] - 
     4*G[{0, 1/(yu*yv), yv^(-1), 1, 1/(yu*yv)}, yw] + 
     4*G[{0, 1/(yu*yv), yv^(-1), yu^(-1), 1}, yw] - 
     8*G[{0, 1/(yu*yv), yv^(-1), yu^(-1), yu^(-1)}, yw] - 
     8*G[{0, 1/(yu*yv), yv^(-1), yu^(-1), yv^(-1)}, yw] + 
     4*G[{0, 1/(yu*yv), yv^(-1), yu^(-1), 1/(yu*yv)}, yw] + 
     4*G[{0, 1/(yu*yv), yv^(-1), yv^(-1), 1}, yw] - 
     8*G[{0, 1/(yu*yv), yv^(-1), yv^(-1), yu^(-1)}, yw] - 
     8*G[{0, 1/(yu*yv), yv^(-1), yv^(-1), yv^(-1)}, yw] + 
     4*G[{0, 1/(yu*yv), yv^(-1), yv^(-1), 1/(yu*yv)}, yw] - 
     4*G[{0, 1/(yu*yv), yv^(-1), 1/(yu*yv), 1}, yw] + 
     4*G[{0, 1/(yu*yv), yv^(-1), 1/(yu*yv), yu^(-1)}, yw] + 
     8*G[{0, 1/(yu*yv), yv^(-1), 1/(yu*yv), yv^(-1)}, yw] - 
     2*G[{0, 1/(yu*yv), 1/(yu*yv), 1, yu^(-1)}, yw] - 
     4*G[{0, 1/(yu*yv), 1/(yu*yv), 1, yv^(-1)}, yw] - 
     2*G[{0, 1/(yu*yv), 1/(yu*yv), 1, 1/(yu*yv)}, yw] - 
     2*G[{0, 1/(yu*yv), 1/(yu*yv), yu^(-1), 1}, yw] + 
     2*G[{0, 1/(yu*yv), 1/(yu*yv), yu^(-1), yv^(-1)}, yw] - 
     4*G[{0, 1/(yu*yv), 1/(yu*yv), yv^(-1), 1}, yw] + 
     2*G[{0, 1/(yu*yv), 1/(yu*yv), yv^(-1), yu^(-1)}, yw] + 
     8*G[{0, 1/(yu*yv), 1/(yu*yv), yv^(-1), yv^(-1)}, yw] + 
     2*G[{0, 1/(yu*yv), 1/(yu*yv), yv^(-1), 1/(yu*yv)}, yw] - 
     2*G[{0, 1/(yu*yv), 1/(yu*yv), 1/(yu*yv), 1}, yw] + 
     2*G[{0, 1/(yu*yv), 1/(yu*yv), 1/(yu*yv), yv^(-1)}, yw] + 
     4*G[{1, 1, 1, yu^(-1), yu^(-1)}, yw] - 
     4*G[{1, 1, 1, yu^(-1), yv^(-1)}, yw] + 
     4*G[{1, 1, 1, yu^(-1), 1/(yu*yv)}, yw] - 
     4*G[{1, 1, 1, yv^(-1), yu^(-1)}, yw] + 
     4*G[{1, 1, 1, yv^(-1), 1/(yu*yv)}, yw] + 
     4*G[{1, 1, 1, 1/(yu*yv), yu^(-1)}, yw] + 
     4*G[{1, 1, 1, 1/(yu*yv), yv^(-1)}, yw] - 
     12*G[{1, 1, 1, 1/(yu*yv), 1/(yu*yv)}, yw] + 
     4*G[{1, 1, yu^(-1), 1, yu^(-1)}, yw] - 
     20*G[{1, 1, yu^(-1), yu^(-1), yu^(-1)}, yw] - 
     8*G[{1, 1, yu^(-1), yu^(-1), yv^(-1)}, yw] + 
     16*G[{1, 1, yu^(-1), yu^(-1), 1/(yu*yv)}, yw] - 
     8*G[{1, 1, yu^(-1), yv^(-1), yu^(-1)}, yw] + 
     4*G[{1, 1, yu^(-1), yv^(-1), 1/(yu*yv)}, yw] + 
     8*G[{1, 1, yu^(-1), 1/(yu*yv), yu^(-1)}, yw] - 
     4*G[{1, 1, yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] + 
     60*G[{1, 1, yu, yu, yu}, yv^(-1)] - 4*G[{1, 1, yv^(-1), 1, yu^(-1)}, 
       yw] + 4*G[{1, 1, yv^(-1), 1, 1/(yu*yv)}, yw] - 
     8*G[{1, 1, yv^(-1), yu^(-1), yu^(-1)}, yw] + 
     4*G[{1, 1, yv^(-1), yu^(-1), 1/(yu*yv)}, yw] + 
     8*G[{1, 1, yv^(-1), yv^(-1), 1/(yu*yv)}, yw] + 
     8*G[{1, 1, yv^(-1), 1/(yu*yv), yu^(-1)}, yw] + 
     8*G[{1, 1, yv^(-1), 1/(yu*yv), yv^(-1)}, yw] - 
     4*G[{1, 1, yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] - 
     4*G[{1, 1, 1/(yu*yv), 1, 1/(yu*yv)}, yw] + 
     4*G[{1, 1, 1/(yu*yv), yu^(-1), yu^(-1)}, yw] + 
     4*G[{1, 1, 1/(yu*yv), yu^(-1), yv^(-1)}, yw] - 
     4*G[{1, 1, 1/(yu*yv), yu^(-1), 1/(yu*yv)}, yw] + 
     4*G[{1, 1, 1/(yu*yv), yv^(-1), yu^(-1)}, yw] + 
     8*G[{1, 1, 1/(yu*yv), yv^(-1), yv^(-1)}, yw] + 
     4*G[{1, 1, 1/(yu*yv), 1/(yu*yv), yv^(-1)}, yw] - 
     4*G[{1, yu^(-1), 1, yu^(-1), yu^(-1)}, yw] + 
     4*G[{1, yu^(-1), 1, yu^(-1), 1/(yu*yv)}, yw] + 
     4*G[{1, yu^(-1), 1, yv^(-1), yv^(-1)}, yw] - 
     4*G[{1, yu^(-1), 1, 1/(yu*yv), yv^(-1)}, yw] + 
     4*G[{1, yu^(-1), yu^(-1), 1, yv^(-1)}, yw] - 
     8*G[{1, yu^(-1), yu^(-1), yu^(-1), yu^(-1)}, yw] - 
     8*G[{1, yu^(-1), yu^(-1), yu^(-1), yv^(-1)}, yw] + 
     8*G[{1, yu^(-1), yu^(-1), yu^(-1), 1/(yu*yv)}, yw] - 
     8*G[{1, yu^(-1), yu^(-1), yv^(-1), yu^(-1)}, yw] - 
     8*G[{1, yu^(-1), yu^(-1), yv^(-1), yv^(-1)}, yw] + 
     4*G[{1, yu^(-1), yu^(-1), yv^(-1), 1/(yu*yv)}, yw] + 
     4*G[{1, yu^(-1), yu^(-1), 1/(yu*yv), yu^(-1)}, yw] + 
     8*G[{1, yu^(-1), yu^(-1), 1/(yu*yv), yv^(-1)}, yw] - 
     4*G[{1, yu^(-1), yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] - 
     8*G[{1, yu^(-1), yv^(-1), yu^(-1), yu^(-1)}, yw] - 
     8*G[{1, yu^(-1), yv^(-1), yu^(-1), yv^(-1)}, yw] + 
     4*G[{1, yu^(-1), yv^(-1), yu^(-1), 1/(yu*yv)}, yw] - 
     8*G[{1, yu^(-1), yv^(-1), yv^(-1), yu^(-1)}, yw] - 
     8*G[{1, yu^(-1), yv^(-1), yv^(-1), yv^(-1)}, yw] + 
     4*G[{1, yu^(-1), yv^(-1), yv^(-1), 1/(yu*yv)}, yw] + 
     4*G[{1, yu^(-1), yv^(-1), 1/(yu*yv), yu^(-1)}, yw] + 
     8*G[{1, yu^(-1), yv^(-1), 1/(yu*yv), yv^(-1)}, yw] - 
     4*G[{1, yu^(-1), 1/(yu*yv), 1, yv^(-1)}, yw] + 
     4*G[{1, yu^(-1), 1/(yu*yv), yu^(-1), yu^(-1)}, yw] + 
     4*G[{1, yu^(-1), 1/(yu*yv), yu^(-1), yv^(-1)}, yw] - 
     4*G[{1, yu^(-1), 1/(yu*yv), yu^(-1), 1/(yu*yv)}, yw] + 
     4*G[{1, yu^(-1), 1/(yu*yv), yv^(-1), yu^(-1)}, yw] + 
     8*G[{1, yu^(-1), 1/(yu*yv), yv^(-1), yv^(-1)}, yw] - 
     4*G[{1, yu^(-1), 1/(yu*yv), 1/(yu*yv), yv^(-1)}, yw] + 
     20*G[{1, yu, 1, yu, yu}, yv^(-1)] + 24*G[{1, yu, yu, yu, yu}, yv^(-1)] + 
     4*G[{1, yv^(-1), 1, yv^(-1), 1/(yu*yv)}, yw] + 
     4*G[{1, yv^(-1), 1, 1/(yu*yv), yu^(-1)}, yw] + 
     4*G[{1, yv^(-1), 1, 1/(yu*yv), yv^(-1)}, yw] - 
     4*G[{1, yv^(-1), 1, 1/(yu*yv), 1/(yu*yv)}, yw] - 
     8*G[{1, yv^(-1), yu^(-1), yu^(-1), yu^(-1)}, yw] - 
     8*G[{1, yv^(-1), yu^(-1), yu^(-1), yv^(-1)}, yw] + 
     4*G[{1, yv^(-1), yu^(-1), yu^(-1), 1/(yu*yv)}, yw] - 
     8*G[{1, yv^(-1), yu^(-1), yv^(-1), yu^(-1)}, yw] - 
     8*G[{1, yv^(-1), yu^(-1), yv^(-1), yv^(-1)}, yw] + 
     4*G[{1, yv^(-1), yu^(-1), yv^(-1), 1/(yu*yv)}, yw] + 
     4*G[{1, yv^(-1), yu^(-1), 1/(yu*yv), yu^(-1)}, yw] + 
     8*G[{1, yv^(-1), yu^(-1), 1/(yu*yv), yv^(-1)}, yw] + 
     4*G[{1, yv^(-1), yv^(-1), 1, 1/(yu*yv)}, yw] - 
     8*G[{1, yv^(-1), yv^(-1), yu^(-1), yu^(-1)}, yw] - 
     8*G[{1, yv^(-1), yv^(-1), yu^(-1), yv^(-1)}, yw] + 
     4*G[{1, yv^(-1), yv^(-1), yu^(-1), 1/(yu*yv)}, yw] - 
     8*G[{1, yv^(-1), yv^(-1), yv^(-1), yu^(-1)}, yw] + 
     8*G[{1, yv^(-1), yv^(-1), yv^(-1), 1/(yu*yv)}, yw] + 
     8*G[{1, yv^(-1), yv^(-1), 1/(yu*yv), yv^(-1)}, yw] + 
     4*G[{1, yv^(-1), yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] + 
     8*G[{1, yv^(-1), 1/(yu*yv), yu^(-1), yu^(-1)}, yw] + 
     4*G[{1, yv^(-1), 1/(yu*yv), yu^(-1), yv^(-1)}, yw] - 
     4*G[{1, yv^(-1), 1/(yu*yv), yu^(-1), 1/(yu*yv)}, yw] + 
     4*G[{1, yv^(-1), 1/(yu*yv), yv^(-1), yu^(-1)}, yw] + 
     8*G[{1, yv^(-1), 1/(yu*yv), yv^(-1), yv^(-1)}, yw] - 
     4*G[{1, yv^(-1), 1/(yu*yv), 1/(yu*yv), yu^(-1)}, yw] - 
     4*G[{1, yv^(-1), 1/(yu*yv), 1/(yu*yv), yv^(-1)}, yw] + 
     4*G[{1, 1/(yu*yv), 1, 1/(yu*yv), yv^(-1)}, yw] - 
     4*G[{1, 1/(yu*yv), yu^(-1), yu^(-1), 1/(yu*yv)}, yw] + 
     4*G[{1, 1/(yu*yv), yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] + 
     8*G[{1, 1/(yu*yv), yv^(-1), yv^(-1), yv^(-1)}, yw] + 
     4*G[{1, 1/(yu*yv), yv^(-1), yv^(-1), 1/(yu*yv)}, yw] + 
     4*G[{1, 1/(yu*yv), yv^(-1), 1/(yu*yv), yu^(-1)}, yw] - 
     4*G[{1, 1/(yu*yv), yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] + 
     4*G[{1, 1/(yu*yv), 1/(yu*yv), yu^(-1), yu^(-1)}, yw] + 
     4*G[{1, 1/(yu*yv), 1/(yu*yv), yu^(-1), yv^(-1)}, yw] + 
     4*G[{1, 1/(yu*yv), 1/(yu*yv), yv^(-1), yu^(-1)}, yw] - 
     4*G[{1, 1/(yu*yv), 1/(yu*yv), yv^(-1), 1/(yu*yv)}, yw] - 
     4*G[{1, 1/(yu*yv), 1/(yu*yv), 1/(yu*yv), yu^(-1)}, yw] - 
     4*G[{1, 1/(yu*yv), 1/(yu*yv), 1/(yu*yv), yv^(-1)}, yw] + 
     8*G[{yu^(-1), yu^(-1), yu^(-1), yu^(-1), 1/(yu*yv)}, yw] + 
     8*G[{yu^(-1), yu^(-1), yu^(-1), 1/(yu*yv), yv^(-1)}, yw] - 
     4*G[{yu^(-1), yu^(-1), yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] - 
     4*G[{yu^(-1), yu^(-1), 1/(yu*yv), yu^(-1), 1/(yu*yv)}, yw] - 
     8*G[{yu^(-1), yu^(-1), 1/(yu*yv), yv^(-1), yv^(-1)}, yw] + 
     4*G[{yu^(-1), yu^(-1), 1/(yu*yv), yv^(-1), 1/(yu*yv)}, yw] + 
     12*G[{yu^(-1), yu^(-1), 1/(yu*yv), 1/(yu*yv), 1/(yu*yv)}, yw] + 
     4*G[{yu^(-1), 1/(yu*yv), yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] + 
     8*G[{yu^(-1), 1/(yu*yv), yv^(-1), yv^(-1), yv^(-1)}, yw] - 
     4*G[{yu^(-1), 1/(yu*yv), yv^(-1), yv^(-1), 1/(yu*yv)}, yw] - 
     8*G[{yu^(-1), 1/(yu*yv), yv^(-1), 1/(yu*yv), yv^(-1)}, yw] - 
     8*G[{yu^(-1), 1/(yu*yv), 1/(yu*yv), yv^(-1), yv^(-1)}, yw] - 
     4*G[{yu^(-1), 1/(yu*yv), 1/(yu*yv), yv^(-1), 1/(yu*yv)}, yw] - 
     8*G[{yu^(-1), 1/(yu*yv), 1/(yu*yv), 1/(yu*yv), yv^(-1)}, yw] - 
     8*G[{yv^(-1), yv^(-1), yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] + 
     4*G[{yv^(-1), yv^(-1), 1/(yu*yv), 1/(yu*yv), 1/(yu*yv)}, yw] + 
     4*G[{yv^(-1), 1/(yu*yv), yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] + 
     (2*Pi^2*Zeta[3])/3 - 4*G[{0}, yu^(-1)]*G[{yu^(-1)}, yw]*Zeta[3] - 
     4*G[{0}, yv^(-1)]*G[{yu^(-1)}, yw]*Zeta[3] + 
     4*G[{0}, yw]*G[{yu^(-1)}, yw]*Zeta[3] - 4*G[{1}, yu^(-1)]*
      G[{yu^(-1)}, yw]*Zeta[3] + 4*G[{1}, yv^(-1)]*G[{yu^(-1)}, yw]*Zeta[3] - 
     4*G[{1}, yw]*G[{yu^(-1)}, yw]*Zeta[3] - 2*G[{yu^(-1)}, yw]^2*Zeta[3] - 
     4*G[{1}, yv^(-1)]*G[{yu}, yv^(-1)]*Zeta[3] + 8*G[{yu^(-1)}, yw]*
      G[{yu}, yv^(-1)]*Zeta[3] + 2*G[{yu}, yv^(-1)]^2*Zeta[3] + 
     4*G[{0}, yu^(-1)]*G[{1/(yu*yv)}, yw]*Zeta[3] + 
     4*G[{0}, yv^(-1)]*G[{1/(yu*yv)}, yw]*Zeta[3] - 
     4*G[{0}, yw]*G[{1/(yu*yv)}, yw]*Zeta[3] + 4*G[{1}, yu^(-1)]*
      G[{1/(yu*yv)}, yw]*Zeta[3] - 4*G[{1}, yv^(-1)]*G[{1/(yu*yv)}, yw]*
      Zeta[3] + 4*G[{1}, yw]*G[{1/(yu*yv)}, yw]*Zeta[3] + 
     4*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*Zeta[3] - 
     8*G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw]*Zeta[3] - 
     4*G[{0, yu^(-1)}, yw]*Zeta[3] - 4*G[{0, yu}, yv^(-1)]*Zeta[3] + 
     4*G[{0, 1/(yu*yv)}, yw]*Zeta[3] + 4*G[{1, yu^(-1)}, yw]*Zeta[3] + 
     4*G[{1, yu}, yv^(-1)]*Zeta[3] - 4*G[{1, 1/(yu*yv)}, yw]*Zeta[3] - 
     4*G[{yu^(-1), 1/(yu*yv)}, yw]*Zeta[3]
 
M1vwuRegII = (17*Pi^4*G[{1}, yv^(-1)])/180 + 
     (2*Pi^2*G[{1}, yu^(-1)]*G[{1}, yv^(-1)]^2)/3 + 
     (Pi^2*G[{1}, yv^(-1)]^3)/18 - (G[{1}, yu^(-1)]*G[{1}, yv^(-1)]^4)/3 - 
     (17*Pi^4*G[{yu}, yv^(-1)])/180 - (4*Pi^2*G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*
       G[{yu}, yv^(-1)])/3 - (Pi^2*G[{1}, yv^(-1)]^2*G[{yu}, yv^(-1)])/6 + 
     (4*G[{1}, yu^(-1)]*G[{1}, yv^(-1)]^3*G[{yu}, yv^(-1)])/3 + 
     (2*Pi^2*G[{1}, yu^(-1)]*G[{yu}, yv^(-1)]^2)/3 - 
     (G[{1}, yu^(-1)]*G[{1}, yv^(-1)]^2*G[{yu}, yv^(-1)]^2)/2 - 
     (2*Pi^2*G[{yu}, yv^(-1)]^3)/9 - (2*G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*
       G[{yu}, yv^(-1)]^3)/3 + (G[{1}, yv^(-1)]^2*G[{yu}, yv^(-1)]^3)/3 + 
     (G[{1}, yu^(-1)]*G[{yu}, yv^(-1)]^4)/6 - G[{yu}, yv^(-1)]^5/30 - 
     (Pi^2*G[{0}, yu^(-1)]*G[{1}, yv^(-1)]*G[{yv^(-1)}, yw])/3 - 
     (Pi^2*G[{0}, yv^(-1)]*G[{1}, yv^(-1)]*G[{yv^(-1)}, yw])/3 + 
     (Pi^2*G[{0}, yw]*G[{1}, yv^(-1)]*G[{yv^(-1)}, yw])/3 - 
     (2*Pi^2*G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*G[{yv^(-1)}, yw])/3 + 
     (Pi^2*G[{1}, yv^(-1)]^2*G[{yv^(-1)}, yw])/6 - 
     (2*G[{1}, yu^(-1)]*G[{1}, yv^(-1)]^3*G[{yv^(-1)}, yw])/3 - 
     (Pi^2*G[{1}, yv^(-1)]*G[{1}, yw]*G[{yv^(-1)}, yw])/3 + 
     G[{1}, yu^(-1)]*G[{1}, yv^(-1)]^2*G[{1}, yw]*G[{yv^(-1)}, yw] - 
     (Pi^2*G[{1}, yw]^2*G[{yv^(-1)}, yw])/6 + G[{0}, yu^(-1)]*G[{1}, yv^(-1)]*
      G[{1}, yw]^2*G[{yv^(-1)}, yw] + G[{0}, yv^(-1)]*G[{1}, yv^(-1)]*
      G[{1}, yw]^2*G[{yv^(-1)}, yw] - G[{0}, yw]*G[{1}, yv^(-1)]*G[{1}, yw]^2*
      G[{yv^(-1)}, yw] - G[{1}, yv^(-1)]^2*G[{1}, yw]^2*G[{yv^(-1)}, yw] + 
     (2*G[{0}, yu^(-1)]*G[{1}, yw]^3*G[{yv^(-1)}, yw])/3 + 
     (2*G[{0}, yv^(-1)]*G[{1}, yw]^3*G[{yv^(-1)}, yw])/3 - 
     (2*G[{0}, yw]*G[{1}, yw]^3*G[{yv^(-1)}, yw])/3 - 
     (2*G[{1}, yu^(-1)]*G[{1}, yw]^3*G[{yv^(-1)}, yw])/3 - 
     (2*G[{1}, yv^(-1)]*G[{1}, yw]^3*G[{yv^(-1)}, yw])/3 + 
     (Pi^2*G[{0}, yu^(-1)]*G[{yu}, yv^(-1)]*G[{yv^(-1)}, yw])/3 + 
     (Pi^2*G[{0}, yv^(-1)]*G[{yu}, yv^(-1)]*G[{yv^(-1)}, yw])/3 - 
     (Pi^2*G[{0}, yw]*G[{yu}, yv^(-1)]*G[{yv^(-1)}, yw])/3 + 
     (2*Pi^2*G[{1}, yu^(-1)]*G[{yu}, yv^(-1)]*G[{yv^(-1)}, yw])/3 + 
     G[{1}, yu^(-1)]*G[{1}, yv^(-1)]^2*G[{yu}, yv^(-1)]*G[{yv^(-1)}, yw] + 
     (Pi^2*G[{1}, yw]*G[{yu}, yv^(-1)]*G[{yv^(-1)}, yw])/3 - 
     2*G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*G[{1}, yw]*G[{yu}, yv^(-1)]*
      G[{yv^(-1)}, yw] - G[{0}, yu^(-1)]*G[{1}, yw]^2*G[{yu}, yv^(-1)]*
      G[{yv^(-1)}, yw] - G[{0}, yv^(-1)]*G[{1}, yw]^2*G[{yu}, yv^(-1)]*
      G[{yv^(-1)}, yw] + G[{0}, yw]*G[{1}, yw]^2*G[{yu}, yv^(-1)]*
      G[{yv^(-1)}, yw] + 2*G[{1}, yv^(-1)]*G[{1}, yw]^2*G[{yu}, yv^(-1)]*
      G[{yv^(-1)}, yw] - (2*Pi^2*G[{yu}, yv^(-1)]^2*G[{yv^(-1)}, yw])/3 - 
     2*G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*G[{yu}, yv^(-1)]^2*G[{yv^(-1)}, yw] + 
     G[{1}, yv^(-1)]^2*G[{yu}, yv^(-1)]^2*G[{yv^(-1)}, yw] + 
     G[{1}, yu^(-1)]*G[{1}, yw]*G[{yu}, yv^(-1)]^2*G[{yv^(-1)}, yw] + 
     (2*G[{1}, yu^(-1)]*G[{yu}, yv^(-1)]^3*G[{yv^(-1)}, yw])/3 - 
     (G[{1}, yw]*G[{yu}, yv^(-1)]^3*G[{yv^(-1)}, yw])/3 - 
     (G[{yu}, yv^(-1)]^4*G[{yv^(-1)}, yw])/6 + 
     (Pi^2*G[{1}, yu^(-1)]*G[{yv^(-1)}, yw]^2)/3 + 
     2*G[{0}, yu^(-1)]*G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*G[{yv^(-1)}, yw]^2 + 
     2*G[{0}, yv^(-1)]*G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*G[{yv^(-1)}, yw]^2 - 
     2*G[{0}, yw]*G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*G[{yv^(-1)}, yw]^2 - 
     2*G[{1}, yu^(-1)]^2*G[{1}, yv^(-1)]*G[{yv^(-1)}, yw]^2 - 
     (G[{1}, yu^(-1)]*G[{1}, yv^(-1)]^2*G[{yv^(-1)}, yw]^2)/2 + 
     (Pi^2*G[{1}, yw]*G[{yv^(-1)}, yw]^2)/3 - 2*G[{0}, yu^(-1)]*
      G[{1}, yv^(-1)]*G[{1}, yw]*G[{yv^(-1)}, yw]^2 - 
     2*G[{0}, yv^(-1)]*G[{1}, yv^(-1)]*G[{1}, yw]*G[{yv^(-1)}, yw]^2 + 
     2*G[{0}, yw]*G[{1}, yv^(-1)]*G[{1}, yw]*G[{yv^(-1)}, yw]^2 + 
     3*G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*G[{1}, yw]*G[{yv^(-1)}, yw]^2 + 
     G[{1}, yv^(-1)]^2*G[{1}, yw]*G[{yv^(-1)}, yw]^2 - 
     G[{1}, yu^(-1)]*G[{1}, yw]^2*G[{yv^(-1)}, yw]^2 - 
     2*G[{1}, yv^(-1)]*G[{1}, yw]^2*G[{yv^(-1)}, yw]^2 - 
     G[{1}, yw]^3*G[{yv^(-1)}, yw]^2 - 
     (Pi^2*G[{yu}, yv^(-1)]*G[{yv^(-1)}, yw]^2)/3 - 
     2*G[{0}, yu^(-1)]*G[{1}, yu^(-1)]*G[{yu}, yv^(-1)]*G[{yv^(-1)}, yw]^2 - 
     2*G[{0}, yv^(-1)]*G[{1}, yu^(-1)]*G[{yu}, yv^(-1)]*G[{yv^(-1)}, yw]^2 + 
     2*G[{0}, yw]*G[{1}, yu^(-1)]*G[{yu}, yv^(-1)]*G[{yv^(-1)}, yw]^2 + 
     2*G[{1}, yu^(-1)]^2*G[{yu}, yv^(-1)]*G[{yv^(-1)}, yw]^2 + 
     2*G[{0}, yu^(-1)]*G[{1}, yv^(-1)]*G[{yu}, yv^(-1)]*G[{yv^(-1)}, yw]^2 + 
     2*G[{0}, yv^(-1)]*G[{1}, yv^(-1)]*G[{yu}, yv^(-1)]*G[{yv^(-1)}, yw]^2 - 
     2*G[{0}, yw]*G[{1}, yv^(-1)]*G[{yu}, yv^(-1)]*G[{yv^(-1)}, yw]^2 - 
     2*G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*G[{yu}, yv^(-1)]*G[{yv^(-1)}, yw]^2 - 
     G[{1}, yv^(-1)]^2*G[{yu}, yv^(-1)]*G[{yv^(-1)}, yw]^2 + 
     2*G[{0}, yu^(-1)]*G[{1}, yw]*G[{yu}, yv^(-1)]*G[{yv^(-1)}, yw]^2 + 
     2*G[{0}, yv^(-1)]*G[{1}, yw]*G[{yu}, yv^(-1)]*G[{yv^(-1)}, yw]^2 - 
     2*G[{0}, yw]*G[{1}, yw]*G[{yu}, yv^(-1)]*G[{yv^(-1)}, yw]^2 - 
     3*G[{1}, yu^(-1)]*G[{1}, yw]*G[{yu}, yv^(-1)]*G[{yv^(-1)}, yw]^2 + 
     2*G[{1}, yv^(-1)]*G[{1}, yw]*G[{yu}, yv^(-1)]*G[{yv^(-1)}, yw]^2 + 
     3*G[{1}, yw]^2*G[{yu}, yv^(-1)]*G[{yv^(-1)}, yw]^2 + 
     G[{1}, yu^(-1)]*G[{yu}, yv^(-1)]^2*G[{yv^(-1)}, yw]^2 - 
     (3*G[{1}, yw]*G[{yu}, yv^(-1)]^2*G[{yv^(-1)}, yw]^2)/2 - 
     (G[{yu}, yv^(-1)]^3*G[{yv^(-1)}, yw]^2)/3 - (Pi^2*G[{yv^(-1)}, yw]^3)/
      9 - 2*G[{0}, yu^(-1)]*G[{1}, yu^(-1)]*G[{yv^(-1)}, yw]^3 - 
     2*G[{0}, yv^(-1)]*G[{1}, yu^(-1)]*G[{yv^(-1)}, yw]^3 + 
     2*G[{0}, yw]*G[{1}, yu^(-1)]*G[{yv^(-1)}, yw]^3 + 
     2*G[{1}, yu^(-1)]^2*G[{yv^(-1)}, yw]^3 + 
     (2*G[{0}, yu^(-1)]*G[{1}, yv^(-1)]*G[{yv^(-1)}, yw]^3)/3 + 
     (2*G[{0}, yv^(-1)]*G[{1}, yv^(-1)]*G[{yv^(-1)}, yw]^3)/3 - 
     (2*G[{0}, yw]*G[{1}, yv^(-1)]*G[{yv^(-1)}, yw]^3)/3 + 
     2*G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*G[{yv^(-1)}, yw]^3 - 
     (G[{1}, yv^(-1)]^2*G[{yv^(-1)}, yw]^3)/3 - 2*G[{0}, yu^(-1)]*G[{1}, yw]*
      G[{yv^(-1)}, yw]^3 - 2*G[{0}, yv^(-1)]*G[{1}, yw]*G[{yv^(-1)}, yw]^3 + 
     2*G[{0}, yw]*G[{1}, yw]*G[{yv^(-1)}, yw]^3 + 
     (2*G[{1}, yv^(-1)]*G[{1}, yw]*G[{yv^(-1)}, yw]^3)/3 - 
     (5*G[{1}, yw]^2*G[{yv^(-1)}, yw]^3)/3 + 
     (4*G[{0}, yu^(-1)]*G[{yu}, yv^(-1)]*G[{yv^(-1)}, yw]^3)/3 + 
     (4*G[{0}, yv^(-1)]*G[{yu}, yv^(-1)]*G[{yv^(-1)}, yw]^3)/3 - 
     (4*G[{0}, yw]*G[{yu}, yv^(-1)]*G[{yv^(-1)}, yw]^3)/3 - 
     2*G[{1}, yu^(-1)]*G[{yu}, yv^(-1)]*G[{yv^(-1)}, yw]^3 + 
     (10*G[{1}, yw]*G[{yu}, yv^(-1)]*G[{yv^(-1)}, yw]^3)/3 - 
     (G[{yu}, yv^(-1)]^2*G[{yv^(-1)}, yw]^3)/3 + 
     (2*G[{0}, yu^(-1)]*G[{yv^(-1)}, yw]^4)/3 + 
     (2*G[{0}, yv^(-1)]*G[{yv^(-1)}, yw]^4)/3 - 
     (2*G[{0}, yw]*G[{yv^(-1)}, yw]^4)/3 - 
     (11*G[{1}, yu^(-1)]*G[{yv^(-1)}, yw]^4)/6 - 
     (G[{1}, yw]*G[{yv^(-1)}, yw]^4)/2 + 
     (G[{yu}, yv^(-1)]*G[{yv^(-1)}, yw]^4)/2 + (11*G[{yv^(-1)}, yw]^5)/30 + 
     (Pi^2*G[{0}, yu^(-1)]*G[{1}, yv^(-1)]*G[{1/(yu*yv)}, yw])/3 + 
     (Pi^2*G[{0}, yv^(-1)]*G[{1}, yv^(-1)]*G[{1/(yu*yv)}, yw])/3 - 
     (Pi^2*G[{0}, yw]*G[{1}, yv^(-1)]*G[{1/(yu*yv)}, yw])/3 + 
     (2*Pi^2*G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*G[{1/(yu*yv)}, yw])/3 - 
     (Pi^2*G[{1}, yv^(-1)]^2*G[{1/(yu*yv)}, yw])/6 + 
     (2*G[{1}, yu^(-1)]*G[{1}, yv^(-1)]^3*G[{1/(yu*yv)}, yw])/3 + 
     (Pi^2*G[{1}, yv^(-1)]*G[{1}, yw]*G[{1/(yu*yv)}, yw])/3 - 
     G[{1}, yu^(-1)]*G[{1}, yv^(-1)]^2*G[{1}, yw]*G[{1/(yu*yv)}, yw] + 
     (Pi^2*G[{1}, yw]^2*G[{1/(yu*yv)}, yw])/6 - G[{0}, yu^(-1)]*
      G[{1}, yv^(-1)]*G[{1}, yw]^2*G[{1/(yu*yv)}, yw] - 
     G[{0}, yv^(-1)]*G[{1}, yv^(-1)]*G[{1}, yw]^2*G[{1/(yu*yv)}, yw] + 
     G[{0}, yw]*G[{1}, yv^(-1)]*G[{1}, yw]^2*G[{1/(yu*yv)}, yw] + 
     G[{1}, yv^(-1)]^2*G[{1}, yw]^2*G[{1/(yu*yv)}, yw] - 
     (2*G[{0}, yu^(-1)]*G[{1}, yw]^3*G[{1/(yu*yv)}, yw])/3 - 
     (2*G[{0}, yv^(-1)]*G[{1}, yw]^3*G[{1/(yu*yv)}, yw])/3 + 
     (2*G[{0}, yw]*G[{1}, yw]^3*G[{1/(yu*yv)}, yw])/3 + 
     (2*G[{1}, yu^(-1)]*G[{1}, yw]^3*G[{1/(yu*yv)}, yw])/3 + 
     (2*G[{1}, yv^(-1)]*G[{1}, yw]^3*G[{1/(yu*yv)}, yw])/3 - 
     (Pi^2*G[{0}, yu^(-1)]*G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw])/3 - 
     (Pi^2*G[{0}, yv^(-1)]*G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw])/3 + 
     (Pi^2*G[{0}, yw]*G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw])/3 - 
     (2*Pi^2*G[{1}, yu^(-1)]*G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw])/3 - 
     G[{1}, yu^(-1)]*G[{1}, yv^(-1)]^2*G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw] - 
     (Pi^2*G[{1}, yw]*G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw])/3 + 
     2*G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*G[{1}, yw]*G[{yu}, yv^(-1)]*
      G[{1/(yu*yv)}, yw] + G[{0}, yu^(-1)]*G[{1}, yw]^2*G[{yu}, yv^(-1)]*
      G[{1/(yu*yv)}, yw] + G[{0}, yv^(-1)]*G[{1}, yw]^2*G[{yu}, yv^(-1)]*
      G[{1/(yu*yv)}, yw] - G[{0}, yw]*G[{1}, yw]^2*G[{yu}, yv^(-1)]*
      G[{1/(yu*yv)}, yw] - 2*G[{1}, yv^(-1)]*G[{1}, yw]^2*G[{yu}, yv^(-1)]*
      G[{1/(yu*yv)}, yw] + (2*Pi^2*G[{yu}, yv^(-1)]^2*G[{1/(yu*yv)}, yw])/3 + 
     2*G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*G[{yu}, yv^(-1)]^2*
      G[{1/(yu*yv)}, yw] - G[{1}, yv^(-1)]^2*G[{yu}, yv^(-1)]^2*
      G[{1/(yu*yv)}, yw] - G[{1}, yu^(-1)]*G[{1}, yw]*G[{yu}, yv^(-1)]^2*
      G[{1/(yu*yv)}, yw] - (2*G[{1}, yu^(-1)]*G[{yu}, yv^(-1)]^3*
       G[{1/(yu*yv)}, yw])/3 + (G[{1}, yw]*G[{yu}, yv^(-1)]^3*
       G[{1/(yu*yv)}, yw])/3 + (G[{yu}, yv^(-1)]^4*G[{1/(yu*yv)}, yw])/6 - 
     (2*Pi^2*G[{1}, yu^(-1)]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw])/3 - 
     4*G[{0}, yu^(-1)]*G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*G[{yv^(-1)}, yw]*
      G[{1/(yu*yv)}, yw] - 4*G[{0}, yv^(-1)]*G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*
      G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw] + 4*G[{0}, yw]*G[{1}, yu^(-1)]*
      G[{1}, yv^(-1)]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw] + 
     4*G[{1}, yu^(-1)]^2*G[{1}, yv^(-1)]*G[{yv^(-1)}, yw]*
      G[{1/(yu*yv)}, yw] + G[{1}, yu^(-1)]*G[{1}, yv^(-1)]^2*G[{yv^(-1)}, yw]*
      G[{1/(yu*yv)}, yw] - (2*Pi^2*G[{1}, yw]*G[{yv^(-1)}, yw]*
       G[{1/(yu*yv)}, yw])/3 + 4*G[{0}, yu^(-1)]*G[{1}, yv^(-1)]*G[{1}, yw]*
      G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw] + 4*G[{0}, yv^(-1)]*G[{1}, yv^(-1)]*
      G[{1}, yw]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw] - 
     4*G[{0}, yw]*G[{1}, yv^(-1)]*G[{1}, yw]*G[{yv^(-1)}, yw]*
      G[{1/(yu*yv)}, yw] - 6*G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*G[{1}, yw]*
      G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw] - 2*G[{1}, yv^(-1)]^2*G[{1}, yw]*
      G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw] + 2*G[{1}, yu^(-1)]*G[{1}, yw]^2*
      G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw] + 4*G[{1}, yv^(-1)]*G[{1}, yw]^2*
      G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw] + 2*G[{1}, yw]^3*G[{yv^(-1)}, yw]*
      G[{1/(yu*yv)}, yw] + (2*Pi^2*G[{yu}, yv^(-1)]*G[{yv^(-1)}, yw]*
       G[{1/(yu*yv)}, yw])/3 + 4*G[{0}, yu^(-1)]*G[{1}, yu^(-1)]*
      G[{yu}, yv^(-1)]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw] + 
     4*G[{0}, yv^(-1)]*G[{1}, yu^(-1)]*G[{yu}, yv^(-1)]*G[{yv^(-1)}, yw]*
      G[{1/(yu*yv)}, yw] - 4*G[{0}, yw]*G[{1}, yu^(-1)]*G[{yu}, yv^(-1)]*
      G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw] - 4*G[{1}, yu^(-1)]^2*
      G[{yu}, yv^(-1)]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw] - 
     4*G[{0}, yu^(-1)]*G[{1}, yv^(-1)]*G[{yu}, yv^(-1)]*G[{yv^(-1)}, yw]*
      G[{1/(yu*yv)}, yw] - 4*G[{0}, yv^(-1)]*G[{1}, yv^(-1)]*G[{yu}, yv^(-1)]*
      G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw] + 4*G[{0}, yw]*G[{1}, yv^(-1)]*
      G[{yu}, yv^(-1)]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw] + 
     4*G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*G[{yu}, yv^(-1)]*G[{yv^(-1)}, yw]*
      G[{1/(yu*yv)}, yw] + 2*G[{1}, yv^(-1)]^2*G[{yu}, yv^(-1)]*
      G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw] - 4*G[{0}, yu^(-1)]*G[{1}, yw]*
      G[{yu}, yv^(-1)]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw] - 
     4*G[{0}, yv^(-1)]*G[{1}, yw]*G[{yu}, yv^(-1)]*G[{yv^(-1)}, yw]*
      G[{1/(yu*yv)}, yw] + 4*G[{0}, yw]*G[{1}, yw]*G[{yu}, yv^(-1)]*
      G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw] + 6*G[{1}, yu^(-1)]*G[{1}, yw]*
      G[{yu}, yv^(-1)]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw] - 
     4*G[{1}, yv^(-1)]*G[{1}, yw]*G[{yu}, yv^(-1)]*G[{yv^(-1)}, yw]*
      G[{1/(yu*yv)}, yw] - 6*G[{1}, yw]^2*G[{yu}, yv^(-1)]*G[{yv^(-1)}, yw]*
      G[{1/(yu*yv)}, yw] - 2*G[{1}, yu^(-1)]*G[{yu}, yv^(-1)]^2*
      G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw] + 3*G[{1}, yw]*G[{yu}, yv^(-1)]^2*
      G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw] + 
     (2*G[{yu}, yv^(-1)]^3*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw])/3 + 
     (Pi^2*G[{yv^(-1)}, yw]^2*G[{1/(yu*yv)}, yw])/3 + 
     6*G[{0}, yu^(-1)]*G[{1}, yu^(-1)]*G[{yv^(-1)}, yw]^2*
      G[{1/(yu*yv)}, yw] + 6*G[{0}, yv^(-1)]*G[{1}, yu^(-1)]*
      G[{yv^(-1)}, yw]^2*G[{1/(yu*yv)}, yw] - 6*G[{0}, yw]*G[{1}, yu^(-1)]*
      G[{yv^(-1)}, yw]^2*G[{1/(yu*yv)}, yw] - 6*G[{1}, yu^(-1)]^2*
      G[{yv^(-1)}, yw]^2*G[{1/(yu*yv)}, yw] - 2*G[{0}, yu^(-1)]*
      G[{1}, yv^(-1)]*G[{yv^(-1)}, yw]^2*G[{1/(yu*yv)}, yw] - 
     2*G[{0}, yv^(-1)]*G[{1}, yv^(-1)]*G[{yv^(-1)}, yw]^2*
      G[{1/(yu*yv)}, yw] + 2*G[{0}, yw]*G[{1}, yv^(-1)]*G[{yv^(-1)}, yw]^2*
      G[{1/(yu*yv)}, yw] - 6*G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*
      G[{yv^(-1)}, yw]^2*G[{1/(yu*yv)}, yw] + G[{1}, yv^(-1)]^2*
      G[{yv^(-1)}, yw]^2*G[{1/(yu*yv)}, yw] + 6*G[{0}, yu^(-1)]*G[{1}, yw]*
      G[{yv^(-1)}, yw]^2*G[{1/(yu*yv)}, yw] + 6*G[{0}, yv^(-1)]*G[{1}, yw]*
      G[{yv^(-1)}, yw]^2*G[{1/(yu*yv)}, yw] - 6*G[{0}, yw]*G[{1}, yw]*
      G[{yv^(-1)}, yw]^2*G[{1/(yu*yv)}, yw] - 2*G[{1}, yv^(-1)]*G[{1}, yw]*
      G[{yv^(-1)}, yw]^2*G[{1/(yu*yv)}, yw] + 5*G[{1}, yw]^2*
      G[{yv^(-1)}, yw]^2*G[{1/(yu*yv)}, yw] - 4*G[{0}, yu^(-1)]*
      G[{yu}, yv^(-1)]*G[{yv^(-1)}, yw]^2*G[{1/(yu*yv)}, yw] - 
     4*G[{0}, yv^(-1)]*G[{yu}, yv^(-1)]*G[{yv^(-1)}, yw]^2*
      G[{1/(yu*yv)}, yw] + 4*G[{0}, yw]*G[{yu}, yv^(-1)]*G[{yv^(-1)}, yw]^2*
      G[{1/(yu*yv)}, yw] + 6*G[{1}, yu^(-1)]*G[{yu}, yv^(-1)]*
      G[{yv^(-1)}, yw]^2*G[{1/(yu*yv)}, yw] - 10*G[{1}, yw]*G[{yu}, yv^(-1)]*
      G[{yv^(-1)}, yw]^2*G[{1/(yu*yv)}, yw] + G[{yu}, yv^(-1)]^2*
      G[{yv^(-1)}, yw]^2*G[{1/(yu*yv)}, yw] - 
     (8*G[{0}, yu^(-1)]*G[{yv^(-1)}, yw]^3*G[{1/(yu*yv)}, yw])/3 - 
     (8*G[{0}, yv^(-1)]*G[{yv^(-1)}, yw]^3*G[{1/(yu*yv)}, yw])/3 + 
     (8*G[{0}, yw]*G[{yv^(-1)}, yw]^3*G[{1/(yu*yv)}, yw])/3 + 
     (22*G[{1}, yu^(-1)]*G[{yv^(-1)}, yw]^3*G[{1/(yu*yv)}, yw])/3 + 
     2*G[{1}, yw]*G[{yv^(-1)}, yw]^3*G[{1/(yu*yv)}, yw] - 
     2*G[{yu}, yv^(-1)]*G[{yv^(-1)}, yw]^3*G[{1/(yu*yv)}, yw] - 
     (11*G[{yv^(-1)}, yw]^4*G[{1/(yu*yv)}, yw])/6 + 
     (Pi^2*G[{1}, yu^(-1)]*G[{1/(yu*yv)}, yw]^2)/3 + 
     (Pi^2*G[{1}, yv^(-1)]*G[{1/(yu*yv)}, yw]^2)/6 + 
     2*G[{0}, yu^(-1)]*G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*G[{1/(yu*yv)}, yw]^2 + 
     2*G[{0}, yv^(-1)]*G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*G[{1/(yu*yv)}, yw]^2 - 
     2*G[{0}, yw]*G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*G[{1/(yu*yv)}, yw]^2 - 
     2*G[{1}, yu^(-1)]^2*G[{1}, yv^(-1)]*G[{1/(yu*yv)}, yw]^2 + 
     (Pi^2*G[{1}, yw]*G[{1/(yu*yv)}, yw]^2)/2 - 3*G[{0}, yu^(-1)]*
      G[{1}, yv^(-1)]*G[{1}, yw]*G[{1/(yu*yv)}, yw]^2 - 
     3*G[{0}, yv^(-1)]*G[{1}, yv^(-1)]*G[{1}, yw]*G[{1/(yu*yv)}, yw]^2 + 
     3*G[{0}, yw]*G[{1}, yv^(-1)]*G[{1}, yw]*G[{1/(yu*yv)}, yw]^2 + 
     3*G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*G[{1}, yw]*G[{1/(yu*yv)}, yw]^2 + 
     2*G[{1}, yv^(-1)]^2*G[{1}, yw]*G[{1/(yu*yv)}, yw]^2 - 
     G[{0}, yu^(-1)]*G[{1}, yw]^2*G[{1/(yu*yv)}, yw]^2 - 
     G[{0}, yv^(-1)]*G[{1}, yw]^2*G[{1/(yu*yv)}, yw]^2 + 
     G[{0}, yw]*G[{1}, yw]^2*G[{1/(yu*yv)}, yw]^2 - 
     G[{1}, yv^(-1)]*G[{1}, yw]^2*G[{1/(yu*yv)}, yw]^2 - 
     G[{1}, yw]^3*G[{1/(yu*yv)}, yw]^2 - 
     (Pi^2*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2)/6 + 
     G[{0}, yu^(-1)]*G[{1}, yv^(-1)]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2 + 
     G[{0}, yv^(-1)]*G[{1}, yv^(-1)]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2 - 
     G[{0}, yw]*G[{1}, yv^(-1)]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2 - 
     G[{1}, yv^(-1)]^2*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2 + 
     2*G[{0}, yu^(-1)]*G[{1}, yw]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2 + 
     2*G[{0}, yv^(-1)]*G[{1}, yw]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2 - 
     2*G[{0}, yw]*G[{1}, yw]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2 - 
     2*G[{1}, yu^(-1)]*G[{1}, yw]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2 - 
     2*G[{1}, yv^(-1)]*G[{1}, yw]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2 - 
     G[{0}, yu^(-1)]*G[{yu^(-1)}, yw]^2*G[{1/(yu*yv)}, yw]^2 - 
     G[{0}, yv^(-1)]*G[{yu^(-1)}, yw]^2*G[{1/(yu*yv)}, yw]^2 + 
     G[{0}, yw]*G[{yu^(-1)}, yw]^2*G[{1/(yu*yv)}, yw]^2 + 
     G[{1}, yu^(-1)]*G[{yu^(-1)}, yw]^2*G[{1/(yu*yv)}, yw]^2 + 
     2*G[{1}, yv^(-1)]*G[{yu^(-1)}, yw]^2*G[{1/(yu*yv)}, yw]^2 + 
     G[{1}, yw]*G[{yu^(-1)}, yw]^2*G[{1/(yu*yv)}, yw]^2 - 
     (2*G[{yu^(-1)}, yw]^3*G[{1/(yu*yv)}, yw]^2)/3 - 
     (Pi^2*G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw]^2)/2 - 
     2*G[{0}, yu^(-1)]*G[{1}, yu^(-1)]*G[{yu}, yv^(-1)]*
      G[{1/(yu*yv)}, yw]^2 - 2*G[{0}, yv^(-1)]*G[{1}, yu^(-1)]*
      G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw]^2 + 2*G[{0}, yw]*G[{1}, yu^(-1)]*
      G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw]^2 + 2*G[{1}, yu^(-1)]^2*
      G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw]^2 + 2*G[{0}, yu^(-1)]*
      G[{1}, yv^(-1)]*G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw]^2 + 
     2*G[{0}, yv^(-1)]*G[{1}, yv^(-1)]*G[{yu}, yv^(-1)]*
      G[{1/(yu*yv)}, yw]^2 - 2*G[{0}, yw]*G[{1}, yv^(-1)]*G[{yu}, yv^(-1)]*
      G[{1/(yu*yv)}, yw]^2 - 3*G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*
      G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw]^2 - G[{1}, yv^(-1)]^2*
      G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw]^2 + 3*G[{0}, yu^(-1)]*G[{1}, yw]*
      G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw]^2 + 3*G[{0}, yv^(-1)]*G[{1}, yw]*
      G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw]^2 - 3*G[{0}, yw]*G[{1}, yw]*
      G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw]^2 - 3*G[{1}, yu^(-1)]*G[{1}, yw]*
      G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw]^2 + 3*G[{1}, yw]^2*G[{yu}, yv^(-1)]*
      G[{1/(yu*yv)}, yw]^2 - G[{0}, yu^(-1)]*G[{yu^(-1)}, yw]*
      G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw]^2 - G[{0}, yv^(-1)]*
      G[{yu^(-1)}, yw]*G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw]^2 + 
     G[{0}, yw]*G[{yu^(-1)}, yw]*G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw]^2 + 
     2*G[{1}, yv^(-1)]*G[{yu^(-1)}, yw]*G[{yu}, yv^(-1)]*
      G[{1/(yu*yv)}, yw]^2 - G[{yu^(-1)}, yw]^2*G[{yu}, yv^(-1)]*
      G[{1/(yu*yv)}, yw]^2 + (3*G[{1}, yu^(-1)]*G[{yu}, yv^(-1)]^2*
       G[{1/(yu*yv)}, yw]^2)/2 - (3*G[{1}, yw]*G[{yu}, yv^(-1)]^2*
       G[{1/(yu*yv)}, yw]^2)/2 - (G[{yu}, yv^(-1)]^3*G[{1/(yu*yv)}, yw]^2)/
      2 - (Pi^2*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2)/3 - 
     6*G[{0}, yu^(-1)]*G[{1}, yu^(-1)]*G[{yv^(-1)}, yw]*
      G[{1/(yu*yv)}, yw]^2 - 6*G[{0}, yv^(-1)]*G[{1}, yu^(-1)]*
      G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2 + 6*G[{0}, yw]*G[{1}, yu^(-1)]*
      G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2 + 6*G[{1}, yu^(-1)]^2*
      G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2 + 3*G[{0}, yu^(-1)]*
      G[{1}, yv^(-1)]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2 + 
     3*G[{0}, yv^(-1)]*G[{1}, yv^(-1)]*G[{yv^(-1)}, yw]*
      G[{1/(yu*yv)}, yw]^2 - 3*G[{0}, yw]*G[{1}, yv^(-1)]*G[{yv^(-1)}, yw]*
      G[{1/(yu*yv)}, yw]^2 + 3*G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*
      G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2 - 2*G[{1}, yv^(-1)]^2*
      G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2 - 5*G[{0}, yu^(-1)]*G[{1}, yw]*
      G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2 - 5*G[{0}, yv^(-1)]*G[{1}, yw]*
      G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2 + 5*G[{0}, yw]*G[{1}, yw]*
      G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2 + 2*G[{1}, yv^(-1)]*G[{1}, yw]*
      G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2 - 4*G[{1}, yw]^2*G[{yv^(-1)}, yw]*
      G[{1/(yu*yv)}, yw]^2 - G[{0}, yu^(-1)]*G[{yu^(-1)}, yw]*
      G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2 - G[{0}, yv^(-1)]*
      G[{yu^(-1)}, yw]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2 + 
     G[{0}, yw]*G[{yu^(-1)}, yw]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2 + 
     2*G[{1}, yv^(-1)]*G[{yu^(-1)}, yw]*G[{yv^(-1)}, yw]*
      G[{1/(yu*yv)}, yw]^2 - G[{yu^(-1)}, yw]^2*G[{yv^(-1)}, yw]*
      G[{1/(yu*yv)}, yw]^2 + 3*G[{0}, yu^(-1)]*G[{yu}, yv^(-1)]*
      G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2 + 3*G[{0}, yv^(-1)]*
      G[{yu}, yv^(-1)]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2 - 
     3*G[{0}, yw]*G[{yu}, yv^(-1)]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2 - 
     3*G[{1}, yu^(-1)]*G[{yu}, yv^(-1)]*G[{yv^(-1)}, yw]*
      G[{1/(yu*yv)}, yw]^2 + 8*G[{1}, yw]*G[{yu}, yv^(-1)]*G[{yv^(-1)}, yw]*
      G[{1/(yu*yv)}, yw]^2 - (3*G[{yu}, yv^(-1)]^2*G[{yv^(-1)}, yw]*
       G[{1/(yu*yv)}, yw]^2)/2 + 4*G[{0}, yu^(-1)]*G[{yv^(-1)}, yw]^2*
      G[{1/(yu*yv)}, yw]^2 + 4*G[{0}, yv^(-1)]*G[{yv^(-1)}, yw]^2*
      G[{1/(yu*yv)}, yw]^2 - 4*G[{0}, yw]*G[{yv^(-1)}, yw]^2*
      G[{1/(yu*yv)}, yw]^2 - (19*G[{1}, yu^(-1)]*G[{yv^(-1)}, yw]^2*
       G[{1/(yu*yv)}, yw]^2)/2 - (3*G[{1}, yw]*G[{yv^(-1)}, yw]^2*
       G[{1/(yu*yv)}, yw]^2)/2 + (3*G[{yu}, yv^(-1)]*G[{yv^(-1)}, yw]^2*
       G[{1/(yu*yv)}, yw]^2)/2 + (19*G[{yv^(-1)}, yw]^3*G[{1/(yu*yv)}, yw]^2)/
      6 + 2*G[{0}, yu^(-1)]*G[{1}, yu^(-1)]*G[{1/(yu*yv)}, yw]^3 + 
     2*G[{0}, yv^(-1)]*G[{1}, yu^(-1)]*G[{1/(yu*yv)}, yw]^3 - 
     2*G[{0}, yw]*G[{1}, yu^(-1)]*G[{1/(yu*yv)}, yw]^3 - 
     2*G[{1}, yu^(-1)]^2*G[{1/(yu*yv)}, yw]^3 - 
     (G[{0}, yu^(-1)]*G[{1}, yv^(-1)]*G[{1/(yu*yv)}, yw]^3)/3 - 
     (G[{0}, yv^(-1)]*G[{1}, yv^(-1)]*G[{1/(yu*yv)}, yw]^3)/3 + 
     (G[{0}, yw]*G[{1}, yv^(-1)]*G[{1/(yu*yv)}, yw]^3)/3 - 
     (2*G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*G[{1/(yu*yv)}, yw]^3)/3 + 
     (G[{1}, yv^(-1)]^2*G[{1/(yu*yv)}, yw]^3)/3 + 
     (5*G[{0}, yu^(-1)]*G[{1}, yw]*G[{1/(yu*yv)}, yw]^3)/3 + 
     (5*G[{0}, yv^(-1)]*G[{1}, yw]*G[{1/(yu*yv)}, yw]^3)/3 - 
     (5*G[{0}, yw]*G[{1}, yw]*G[{1/(yu*yv)}, yw]^3)/3 - 
     (2*G[{1}, yu^(-1)]*G[{1}, yw]*G[{1/(yu*yv)}, yw]^3)/3 - 
     (2*G[{1}, yv^(-1)]*G[{1}, yw]*G[{1/(yu*yv)}, yw]^3)/3 + 
     G[{1}, yw]^2*G[{1/(yu*yv)}, yw]^3 + (G[{0}, yu^(-1)]*G[{yu^(-1)}, yw]*
       G[{1/(yu*yv)}, yw]^3)/3 + (G[{0}, yv^(-1)]*G[{yu^(-1)}, yw]*
       G[{1/(yu*yv)}, yw]^3)/3 - (G[{0}, yw]*G[{yu^(-1)}, yw]*
       G[{1/(yu*yv)}, yw]^3)/3 + (2*G[{1}, yu^(-1)]*G[{yu^(-1)}, yw]*
       G[{1/(yu*yv)}, yw]^3)/3 - (2*G[{1}, yv^(-1)]*G[{yu^(-1)}, yw]*
       G[{1/(yu*yv)}, yw]^3)/3 + (2*G[{1}, yw]*G[{yu^(-1)}, yw]*
       G[{1/(yu*yv)}, yw]^3)/3 + (G[{yu^(-1)}, yw]^2*G[{1/(yu*yv)}, yw]^3)/
      3 - (5*G[{0}, yu^(-1)]*G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw]^3)/3 - 
     (5*G[{0}, yv^(-1)]*G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw]^3)/3 + 
     (5*G[{0}, yw]*G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw]^3)/3 + 
     (2*G[{1}, yu^(-1)]*G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw]^3)/3 + 
     (2*G[{1}, yv^(-1)]*G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw]^3)/3 - 
     2*G[{1}, yw]*G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw]^3 - 
     (2*G[{yu^(-1)}, yw]*G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw]^3)/3 + 
     G[{yu}, yv^(-1)]^2*G[{1/(yu*yv)}, yw]^3 - 2*G[{0}, yu^(-1)]*
      G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]^3 - 2*G[{0}, yv^(-1)]*
      G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]^3 + 2*G[{0}, yw]*G[{yv^(-1)}, yw]*
      G[{1/(yu*yv)}, yw]^3 + 4*G[{1}, yu^(-1)]*G[{yv^(-1)}, yw]*
      G[{1/(yu*yv)}, yw]^3 + (2*G[{1}, yv^(-1)]*G[{yv^(-1)}, yw]*
       G[{1/(yu*yv)}, yw]^3)/3 + (2*G[{1}, yw]*G[{yv^(-1)}, yw]*
       G[{1/(yu*yv)}, yw]^3)/3 - (2*G[{yu^(-1)}, yw]*G[{yv^(-1)}, yw]*
       G[{1/(yu*yv)}, yw]^3)/3 - (2*G[{yu}, yv^(-1)]*G[{yv^(-1)}, yw]*
       G[{1/(yu*yv)}, yw]^3)/3 - 2*G[{yv^(-1)}, yw]^2*G[{1/(yu*yv)}, yw]^3 + 
     Pi^2*G[{1}, yv^(-1)]*G[{0, 1}, yu^(-1)] + G[{1}, yu^(-1)]*
      G[{1}, yv^(-1)]^2*G[{0, 1}, yu^(-1)] - 
     (G[{1}, yv^(-1)]^3*G[{0, 1}, yu^(-1)])/3 - Pi^2*G[{yu}, yv^(-1)]*
      G[{0, 1}, yu^(-1)] - 2*G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*G[{yu}, yv^(-1)]*
      G[{0, 1}, yu^(-1)] + G[{1}, yv^(-1)]^2*G[{yu}, yv^(-1)]*
      G[{0, 1}, yu^(-1)] + G[{1}, yu^(-1)]*G[{yu}, yv^(-1)]^2*
      G[{0, 1}, yu^(-1)] + G[{1}, yv^(-1)]*G[{yu}, yv^(-1)]^2*
      G[{0, 1}, yu^(-1)] - (2*G[{yu}, yv^(-1)]^3*G[{0, 1}, yu^(-1)])/3 - 
     (2*Pi^2*G[{yv^(-1)}, yw]*G[{0, 1}, yu^(-1)])/3 - 
     2*G[{0}, yu^(-1)]*G[{1}, yv^(-1)]*G[{yv^(-1)}, yw]*G[{0, 1}, yu^(-1)] - 
     2*G[{0}, yv^(-1)]*G[{1}, yv^(-1)]*G[{yv^(-1)}, yw]*G[{0, 1}, yu^(-1)] + 
     2*G[{0}, yw]*G[{1}, yv^(-1)]*G[{yv^(-1)}, yw]*G[{0, 1}, yu^(-1)] + 
     2*G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*G[{yv^(-1)}, yw]*G[{0, 1}, yu^(-1)] - 
     G[{1}, yv^(-1)]^2*G[{yv^(-1)}, yw]*G[{0, 1}, yu^(-1)] + 
     G[{1}, yw]^2*G[{yv^(-1)}, yw]*G[{0, 1}, yu^(-1)] + 
     2*G[{0}, yu^(-1)]*G[{yu}, yv^(-1)]*G[{yv^(-1)}, yw]*G[{0, 1}, yu^(-1)] + 
     2*G[{0}, yv^(-1)]*G[{yu}, yv^(-1)]*G[{yv^(-1)}, yw]*G[{0, 1}, yu^(-1)] - 
     2*G[{0}, yw]*G[{yu}, yv^(-1)]*G[{yv^(-1)}, yw]*G[{0, 1}, yu^(-1)] - 
     2*G[{1}, yu^(-1)]*G[{yu}, yv^(-1)]*G[{yv^(-1)}, yw]*G[{0, 1}, yu^(-1)] + 
     2*G[{1}, yv^(-1)]*G[{yu}, yv^(-1)]*G[{yv^(-1)}, yw]*G[{0, 1}, yu^(-1)] - 
     2*G[{yu}, yv^(-1)]^2*G[{yv^(-1)}, yw]*G[{0, 1}, yu^(-1)] + 
     4*G[{0}, yu^(-1)]*G[{yv^(-1)}, yw]^2*G[{0, 1}, yu^(-1)] + 
     4*G[{0}, yv^(-1)]*G[{yv^(-1)}, yw]^2*G[{0, 1}, yu^(-1)] - 
     4*G[{0}, yw]*G[{yv^(-1)}, yw]^2*G[{0, 1}, yu^(-1)] - 
     5*G[{1}, yu^(-1)]*G[{yv^(-1)}, yw]^2*G[{0, 1}, yu^(-1)] - 
     3*G[{1}, yv^(-1)]*G[{yv^(-1)}, yw]^2*G[{0, 1}, yu^(-1)] + 
     3*G[{1}, yw]*G[{yv^(-1)}, yw]^2*G[{0, 1}, yu^(-1)] + 
     (8*G[{yv^(-1)}, yw]^3*G[{0, 1}, yu^(-1)])/3 + 
     (2*Pi^2*G[{1/(yu*yv)}, yw]*G[{0, 1}, yu^(-1)])/3 + 
     2*G[{0}, yu^(-1)]*G[{1}, yv^(-1)]*G[{1/(yu*yv)}, yw]*
      G[{0, 1}, yu^(-1)] + 2*G[{0}, yv^(-1)]*G[{1}, yv^(-1)]*
      G[{1/(yu*yv)}, yw]*G[{0, 1}, yu^(-1)] - 2*G[{0}, yw]*G[{1}, yv^(-1)]*
      G[{1/(yu*yv)}, yw]*G[{0, 1}, yu^(-1)] - 2*G[{1}, yu^(-1)]*
      G[{1}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, 1}, yu^(-1)] + 
     G[{1}, yv^(-1)]^2*G[{1/(yu*yv)}, yw]*G[{0, 1}, yu^(-1)] - 
     G[{1}, yw]^2*G[{1/(yu*yv)}, yw]*G[{0, 1}, yu^(-1)] - 
     2*G[{0}, yu^(-1)]*G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw]*
      G[{0, 1}, yu^(-1)] - 2*G[{0}, yv^(-1)]*G[{yu}, yv^(-1)]*
      G[{1/(yu*yv)}, yw]*G[{0, 1}, yu^(-1)] + 2*G[{0}, yw]*G[{yu}, yv^(-1)]*
      G[{1/(yu*yv)}, yw]*G[{0, 1}, yu^(-1)] + 2*G[{1}, yu^(-1)]*
      G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, 1}, yu^(-1)] - 
     2*G[{1}, yv^(-1)]*G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw]*
      G[{0, 1}, yu^(-1)] + 2*G[{yu}, yv^(-1)]^2*G[{1/(yu*yv)}, yw]*
      G[{0, 1}, yu^(-1)] - 8*G[{0}, yu^(-1)]*G[{yv^(-1)}, yw]*
      G[{1/(yu*yv)}, yw]*G[{0, 1}, yu^(-1)] - 8*G[{0}, yv^(-1)]*
      G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1}, yu^(-1)] + 
     8*G[{0}, yw]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1}, yu^(-1)] + 
     10*G[{1}, yu^(-1)]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*
      G[{0, 1}, yu^(-1)] + 6*G[{1}, yv^(-1)]*G[{yv^(-1)}, yw]*
      G[{1/(yu*yv)}, yw]*G[{0, 1}, yu^(-1)] - 6*G[{1}, yw]*G[{yv^(-1)}, yw]*
      G[{1/(yu*yv)}, yw]*G[{0, 1}, yu^(-1)] - 8*G[{yv^(-1)}, yw]^2*
      G[{1/(yu*yv)}, yw]*G[{0, 1}, yu^(-1)] + 4*G[{0}, yu^(-1)]*
      G[{1/(yu*yv)}, yw]^2*G[{0, 1}, yu^(-1)] + 4*G[{0}, yv^(-1)]*
      G[{1/(yu*yv)}, yw]^2*G[{0, 1}, yu^(-1)] - 
     4*G[{0}, yw]*G[{1/(yu*yv)}, yw]^2*G[{0, 1}, yu^(-1)] - 
     5*G[{1}, yu^(-1)]*G[{1/(yu*yv)}, yw]^2*G[{0, 1}, yu^(-1)] - 
     G[{1}, yv^(-1)]*G[{1/(yu*yv)}, yw]^2*G[{0, 1}, yu^(-1)] + 
     2*G[{1}, yw]*G[{1/(yu*yv)}, yw]^2*G[{0, 1}, yu^(-1)] + 
     G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2*G[{0, 1}, yu^(-1)] - 
     2*G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw]^2*G[{0, 1}, yu^(-1)] + 
     5*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2*G[{0, 1}, yu^(-1)] - 
     G[{1}, yv^(-1)]*G[{0, 1}, yu^(-1)]^2 + G[{yu}, yv^(-1)]*
      G[{0, 1}, yu^(-1)]^2 - (Pi^2*G[{1}, yv^(-1)]*G[{0, 1}, yv^(-1)])/3 + 
     2*G[{1}, yu^(-1)]*G[{1}, yv^(-1)]^2*G[{0, 1}, yv^(-1)] + 
     (G[{1}, yv^(-1)]^3*G[{0, 1}, yv^(-1)])/3 + 
     (Pi^2*G[{yu}, yv^(-1)]*G[{0, 1}, yv^(-1)])/3 - 
     4*G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*G[{yu}, yv^(-1)]*G[{0, 1}, yv^(-1)] - 
     G[{1}, yv^(-1)]^2*G[{yu}, yv^(-1)]*G[{0, 1}, yv^(-1)] + 
     2*G[{1}, yu^(-1)]*G[{yu}, yv^(-1)]^2*G[{0, 1}, yv^(-1)] - 
     (2*G[{yu}, yv^(-1)]^3*G[{0, 1}, yv^(-1)])/3 - 
     2*G[{0}, yu^(-1)]*G[{1}, yv^(-1)]*G[{yv^(-1)}, yw]*G[{0, 1}, yv^(-1)] - 
     2*G[{0}, yv^(-1)]*G[{1}, yv^(-1)]*G[{yv^(-1)}, yw]*G[{0, 1}, yv^(-1)] + 
     2*G[{0}, yw]*G[{1}, yv^(-1)]*G[{yv^(-1)}, yw]*G[{0, 1}, yv^(-1)] + 
     G[{1}, yv^(-1)]^2*G[{yv^(-1)}, yw]*G[{0, 1}, yv^(-1)] - 
     2*G[{1}, yv^(-1)]*G[{1}, yw]*G[{yv^(-1)}, yw]*G[{0, 1}, yv^(-1)] - 
     G[{1}, yw]^2*G[{yv^(-1)}, yw]*G[{0, 1}, yv^(-1)] + 
     2*G[{0}, yu^(-1)]*G[{yu}, yv^(-1)]*G[{yv^(-1)}, yw]*G[{0, 1}, yv^(-1)] + 
     2*G[{0}, yv^(-1)]*G[{yu}, yv^(-1)]*G[{yv^(-1)}, yw]*G[{0, 1}, yv^(-1)] - 
     2*G[{0}, yw]*G[{yu}, yv^(-1)]*G[{yv^(-1)}, yw]*G[{0, 1}, yv^(-1)] + 
     2*G[{1}, yw]*G[{yu}, yv^(-1)]*G[{yv^(-1)}, yw]*G[{0, 1}, yv^(-1)] - 
     2*G[{yu}, yv^(-1)]^2*G[{yv^(-1)}, yw]*G[{0, 1}, yv^(-1)] + 
     2*G[{0}, yu^(-1)]*G[{1}, yv^(-1)]*G[{1/(yu*yv)}, yw]*
      G[{0, 1}, yv^(-1)] + 2*G[{0}, yv^(-1)]*G[{1}, yv^(-1)]*
      G[{1/(yu*yv)}, yw]*G[{0, 1}, yv^(-1)] - 2*G[{0}, yw]*G[{1}, yv^(-1)]*
      G[{1/(yu*yv)}, yw]*G[{0, 1}, yv^(-1)] - G[{1}, yv^(-1)]^2*
      G[{1/(yu*yv)}, yw]*G[{0, 1}, yv^(-1)] + 2*G[{1}, yv^(-1)]*G[{1}, yw]*
      G[{1/(yu*yv)}, yw]*G[{0, 1}, yv^(-1)] + G[{1}, yw]^2*G[{1/(yu*yv)}, yw]*
      G[{0, 1}, yv^(-1)] - 2*G[{0}, yu^(-1)]*G[{yu}, yv^(-1)]*
      G[{1/(yu*yv)}, yw]*G[{0, 1}, yv^(-1)] - 2*G[{0}, yv^(-1)]*
      G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, 1}, yv^(-1)] + 
     2*G[{0}, yw]*G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, 1}, yv^(-1)] - 
     2*G[{1}, yw]*G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, 1}, yv^(-1)] + 
     2*G[{yu}, yv^(-1)]^2*G[{1/(yu*yv)}, yw]*G[{0, 1}, yv^(-1)] + 
     G[{1}, yv^(-1)]*G[{1/(yu*yv)}, yw]^2*G[{0, 1}, yv^(-1)] + 
     G[{1}, yw]*G[{1/(yu*yv)}, yw]^2*G[{0, 1}, yv^(-1)] - 
     G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2*G[{0, 1}, yv^(-1)] - 
     G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw]^2*G[{0, 1}, yv^(-1)] + 
     2*G[{1}, yv^(-1)]*G[{0, 1}, yu^(-1)]*G[{0, 1}, yv^(-1)] - 
     2*G[{yu}, yv^(-1)]*G[{0, 1}, yu^(-1)]*G[{0, 1}, yv^(-1)] - 
     G[{1}, yv^(-1)]*G[{0, 1}, yv^(-1)]^2 + G[{yu}, yv^(-1)]*
      G[{0, 1}, yv^(-1)]^2 + (Pi^2*G[{yv^(-1)}, yw]*G[{0, 1}, yw])/3 - 
     2*G[{0}, yu^(-1)]*G[{1}, yv^(-1)]*G[{yv^(-1)}, yw]*G[{0, 1}, yw] - 
     2*G[{0}, yv^(-1)]*G[{1}, yv^(-1)]*G[{yv^(-1)}, yw]*G[{0, 1}, yw] + 
     2*G[{0}, yw]*G[{1}, yv^(-1)]*G[{yv^(-1)}, yw]*G[{0, 1}, yw] + 
     2*G[{1}, yv^(-1)]^2*G[{yv^(-1)}, yw]*G[{0, 1}, yw] + 
     2*G[{1}, yv^(-1)]*G[{1}, yw]*G[{yv^(-1)}, yw]*G[{0, 1}, yw] + 
     G[{1}, yw]^2*G[{yv^(-1)}, yw]*G[{0, 1}, yw] + 
     2*G[{0}, yu^(-1)]*G[{yu}, yv^(-1)]*G[{yv^(-1)}, yw]*G[{0, 1}, yw] + 
     2*G[{0}, yv^(-1)]*G[{yu}, yv^(-1)]*G[{yv^(-1)}, yw]*G[{0, 1}, yw] - 
     2*G[{0}, yw]*G[{yu}, yv^(-1)]*G[{yv^(-1)}, yw]*G[{0, 1}, yw] - 
     4*G[{1}, yv^(-1)]*G[{yu}, yv^(-1)]*G[{yv^(-1)}, yw]*G[{0, 1}, yw] - 
     2*G[{1}, yw]*G[{yu}, yv^(-1)]*G[{yv^(-1)}, yw]*G[{0, 1}, yw] + 
     2*G[{1}, yu^(-1)]*G[{yv^(-1)}, yw]^2*G[{0, 1}, yw] + 
     2*G[{1}, yw]*G[{yv^(-1)}, yw]^2*G[{0, 1}, yw] - 
     2*G[{yu}, yv^(-1)]*G[{yv^(-1)}, yw]^2*G[{0, 1}, yw] - 
     (2*G[{yv^(-1)}, yw]^3*G[{0, 1}, yw])/3 - 
     (Pi^2*G[{1/(yu*yv)}, yw]*G[{0, 1}, yw])/3 + 2*G[{0}, yu^(-1)]*
      G[{1}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, 1}, yw] + 
     2*G[{0}, yv^(-1)]*G[{1}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, 1}, yw] - 
     2*G[{0}, yw]*G[{1}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, 1}, yw] - 
     2*G[{1}, yv^(-1)]^2*G[{1/(yu*yv)}, yw]*G[{0, 1}, yw] - 
     2*G[{1}, yv^(-1)]*G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1}, yw] - 
     G[{1}, yw]^2*G[{1/(yu*yv)}, yw]*G[{0, 1}, yw] - 
     2*G[{0}, yu^(-1)]*G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, 1}, yw] - 
     2*G[{0}, yv^(-1)]*G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, 1}, yw] + 
     2*G[{0}, yw]*G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, 1}, yw] + 
     4*G[{1}, yv^(-1)]*G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, 1}, yw] + 
     2*G[{1}, yw]*G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, 1}, yw] - 
     4*G[{1}, yu^(-1)]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1}, yw] - 
     4*G[{1}, yw]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1}, yw] + 
     4*G[{yu}, yv^(-1)]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1}, yw] + 
     2*G[{yv^(-1)}, yw]^2*G[{1/(yu*yv)}, yw]*G[{0, 1}, yw] + 
     2*G[{1}, yu^(-1)]*G[{1/(yu*yv)}, yw]^2*G[{0, 1}, yw] - 
     G[{1}, yv^(-1)]*G[{1/(yu*yv)}, yw]^2*G[{0, 1}, yw] + 
     G[{1}, yw]*G[{1/(yu*yv)}, yw]^2*G[{0, 1}, yw] + 
     G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2*G[{0, 1}, yw] - 
     G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw]^2*G[{0, 1}, yw] - 
     2*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2*G[{0, 1}, yw] - 
     2*G[{yv^(-1)}, yw]*G[{0, 1}, yu^(-1)]*G[{0, 1}, yw] + 
     2*G[{1/(yu*yv)}, yw]*G[{0, 1}, yu^(-1)]*G[{0, 1}, yw] + 
     2*G[{yv^(-1)}, yw]*G[{0, 1}, yv^(-1)]*G[{0, 1}, yw] - 
     2*G[{1/(yu*yv)}, yw]*G[{0, 1}, yv^(-1)]*G[{0, 1}, yw] - 
     G[{yv^(-1)}, yw]*G[{0, 1}, yw]^2 + G[{1/(yu*yv)}, yw]*G[{0, 1}, yw]^2 - 
     (Pi^2*G[{yv^(-1)}, yw]*G[{0, yu^(-1)}, yw])/3 + 
     2*G[{0}, yu^(-1)]*G[{1}, yv^(-1)]*G[{yv^(-1)}, yw]*G[{0, yu^(-1)}, yw] + 
     2*G[{0}, yv^(-1)]*G[{1}, yv^(-1)]*G[{yv^(-1)}, yw]*G[{0, yu^(-1)}, yw] - 
     2*G[{0}, yw]*G[{1}, yv^(-1)]*G[{yv^(-1)}, yw]*G[{0, yu^(-1)}, yw] - 
     2*G[{1}, yv^(-1)]^2*G[{yv^(-1)}, yw]*G[{0, yu^(-1)}, yw] - 
     2*G[{1}, yv^(-1)]*G[{1}, yw]*G[{yv^(-1)}, yw]*G[{0, yu^(-1)}, yw] - 
     G[{1}, yw]^2*G[{yv^(-1)}, yw]*G[{0, yu^(-1)}, yw] - 
     2*G[{0}, yu^(-1)]*G[{yu}, yv^(-1)]*G[{yv^(-1)}, yw]*
      G[{0, yu^(-1)}, yw] - 2*G[{0}, yv^(-1)]*G[{yu}, yv^(-1)]*
      G[{yv^(-1)}, yw]*G[{0, yu^(-1)}, yw] + 2*G[{0}, yw]*G[{yu}, yv^(-1)]*
      G[{yv^(-1)}, yw]*G[{0, yu^(-1)}, yw] + 4*G[{1}, yv^(-1)]*
      G[{yu}, yv^(-1)]*G[{yv^(-1)}, yw]*G[{0, yu^(-1)}, yw] + 
     2*G[{1}, yw]*G[{yu}, yv^(-1)]*G[{yv^(-1)}, yw]*G[{0, yu^(-1)}, yw] - 
     2*G[{1}, yu^(-1)]*G[{yv^(-1)}, yw]^2*G[{0, yu^(-1)}, yw] - 
     2*G[{1}, yw]*G[{yv^(-1)}, yw]^2*G[{0, yu^(-1)}, yw] + 
     2*G[{yu}, yv^(-1)]*G[{yv^(-1)}, yw]^2*G[{0, yu^(-1)}, yw] + 
     (2*G[{yv^(-1)}, yw]^3*G[{0, yu^(-1)}, yw])/3 + 
     (Pi^2*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1)}, yw])/3 - 
     2*G[{0}, yu^(-1)]*G[{1}, yv^(-1)]*G[{1/(yu*yv)}, yw]*
      G[{0, yu^(-1)}, yw] - 2*G[{0}, yv^(-1)]*G[{1}, yv^(-1)]*
      G[{1/(yu*yv)}, yw]*G[{0, yu^(-1)}, yw] + 2*G[{0}, yw]*G[{1}, yv^(-1)]*
      G[{1/(yu*yv)}, yw]*G[{0, yu^(-1)}, yw] + 2*G[{1}, yv^(-1)]^2*
      G[{1/(yu*yv)}, yw]*G[{0, yu^(-1)}, yw] + 2*G[{1}, yv^(-1)]*G[{1}, yw]*
      G[{1/(yu*yv)}, yw]*G[{0, yu^(-1)}, yw] + 
     G[{1}, yw]^2*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1)}, yw] + 
     2*G[{0}, yu^(-1)]*G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw]*
      G[{0, yu^(-1)}, yw] + 2*G[{0}, yv^(-1)]*G[{yu}, yv^(-1)]*
      G[{1/(yu*yv)}, yw]*G[{0, yu^(-1)}, yw] - 2*G[{0}, yw]*G[{yu}, yv^(-1)]*
      G[{1/(yu*yv)}, yw]*G[{0, yu^(-1)}, yw] - 4*G[{1}, yv^(-1)]*
      G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1)}, yw] - 
     2*G[{1}, yw]*G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1)}, yw] + 
     4*G[{1}, yu^(-1)]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*
      G[{0, yu^(-1)}, yw] + 4*G[{1}, yw]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*
      G[{0, yu^(-1)}, yw] - 4*G[{yu}, yv^(-1)]*G[{yv^(-1)}, yw]*
      G[{1/(yu*yv)}, yw]*G[{0, yu^(-1)}, yw] - 2*G[{yv^(-1)}, yw]^2*
      G[{1/(yu*yv)}, yw]*G[{0, yu^(-1)}, yw] - 2*G[{1}, yu^(-1)]*
      G[{1/(yu*yv)}, yw]^2*G[{0, yu^(-1)}, yw] + 
     G[{1}, yv^(-1)]*G[{1/(yu*yv)}, yw]^2*G[{0, yu^(-1)}, yw] - 
     G[{1}, yw]*G[{1/(yu*yv)}, yw]^2*G[{0, yu^(-1)}, yw] - 
     G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2*G[{0, yu^(-1)}, yw] + 
     G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw]^2*G[{0, yu^(-1)}, yw] + 
     2*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2*G[{0, yu^(-1)}, yw] + 
     2*G[{yv^(-1)}, yw]*G[{0, 1}, yu^(-1)]*G[{0, yu^(-1)}, yw] - 
     2*G[{1/(yu*yv)}, yw]*G[{0, 1}, yu^(-1)]*G[{0, yu^(-1)}, yw] - 
     2*G[{yv^(-1)}, yw]*G[{0, 1}, yv^(-1)]*G[{0, yu^(-1)}, yw] + 
     2*G[{1/(yu*yv)}, yw]*G[{0, 1}, yv^(-1)]*G[{0, yu^(-1)}, yw] + 
     2*G[{yv^(-1)}, yw]*G[{0, 1}, yw]*G[{0, yu^(-1)}, yw] - 
     2*G[{1/(yu*yv)}, yw]*G[{0, 1}, yw]*G[{0, yu^(-1)}, yw] - 
     G[{yv^(-1)}, yw]*G[{0, yu^(-1)}, yw]^2 + G[{1/(yu*yv)}, yw]*
      G[{0, yu^(-1)}, yw]^2 + (Pi^2*G[{1}, yv^(-1)]*G[{0, yu}, yv^(-1)])/3 - 
     2*G[{1}, yu^(-1)]*G[{1}, yv^(-1)]^2*G[{0, yu}, yv^(-1)] - 
     (G[{1}, yv^(-1)]^3*G[{0, yu}, yv^(-1)])/3 - 
     (Pi^2*G[{yu}, yv^(-1)]*G[{0, yu}, yv^(-1)])/3 + 
     4*G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*G[{yu}, yv^(-1)]*G[{0, yu}, yv^(-1)] + 
     G[{1}, yv^(-1)]^2*G[{yu}, yv^(-1)]*G[{0, yu}, yv^(-1)] - 
     2*G[{1}, yu^(-1)]*G[{yu}, yv^(-1)]^2*G[{0, yu}, yv^(-1)] + 
     (2*G[{yu}, yv^(-1)]^3*G[{0, yu}, yv^(-1)])/3 + 
     2*G[{0}, yu^(-1)]*G[{1}, yv^(-1)]*G[{yv^(-1)}, yw]*G[{0, yu}, yv^(-1)] + 
     2*G[{0}, yv^(-1)]*G[{1}, yv^(-1)]*G[{yv^(-1)}, yw]*G[{0, yu}, yv^(-1)] - 
     2*G[{0}, yw]*G[{1}, yv^(-1)]*G[{yv^(-1)}, yw]*G[{0, yu}, yv^(-1)] - 
     G[{1}, yv^(-1)]^2*G[{yv^(-1)}, yw]*G[{0, yu}, yv^(-1)] + 
     2*G[{1}, yv^(-1)]*G[{1}, yw]*G[{yv^(-1)}, yw]*G[{0, yu}, yv^(-1)] + 
     G[{1}, yw]^2*G[{yv^(-1)}, yw]*G[{0, yu}, yv^(-1)] - 
     2*G[{0}, yu^(-1)]*G[{yu}, yv^(-1)]*G[{yv^(-1)}, yw]*
      G[{0, yu}, yv^(-1)] - 2*G[{0}, yv^(-1)]*G[{yu}, yv^(-1)]*
      G[{yv^(-1)}, yw]*G[{0, yu}, yv^(-1)] + 2*G[{0}, yw]*G[{yu}, yv^(-1)]*
      G[{yv^(-1)}, yw]*G[{0, yu}, yv^(-1)] - 2*G[{1}, yw]*G[{yu}, yv^(-1)]*
      G[{yv^(-1)}, yw]*G[{0, yu}, yv^(-1)] + 2*G[{yu}, yv^(-1)]^2*
      G[{yv^(-1)}, yw]*G[{0, yu}, yv^(-1)] - 2*G[{0}, yu^(-1)]*
      G[{1}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, yu}, yv^(-1)] - 
     2*G[{0}, yv^(-1)]*G[{1}, yv^(-1)]*G[{1/(yu*yv)}, yw]*
      G[{0, yu}, yv^(-1)] + 2*G[{0}, yw]*G[{1}, yv^(-1)]*G[{1/(yu*yv)}, yw]*
      G[{0, yu}, yv^(-1)] + G[{1}, yv^(-1)]^2*G[{1/(yu*yv)}, yw]*
      G[{0, yu}, yv^(-1)] - 2*G[{1}, yv^(-1)]*G[{1}, yw]*G[{1/(yu*yv)}, yw]*
      G[{0, yu}, yv^(-1)] - G[{1}, yw]^2*G[{1/(yu*yv)}, yw]*
      G[{0, yu}, yv^(-1)] + 2*G[{0}, yu^(-1)]*G[{yu}, yv^(-1)]*
      G[{1/(yu*yv)}, yw]*G[{0, yu}, yv^(-1)] + 2*G[{0}, yv^(-1)]*
      G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, yu}, yv^(-1)] - 
     2*G[{0}, yw]*G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, yu}, yv^(-1)] + 
     2*G[{1}, yw]*G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, yu}, yv^(-1)] - 
     2*G[{yu}, yv^(-1)]^2*G[{1/(yu*yv)}, yw]*G[{0, yu}, yv^(-1)] - 
     G[{1}, yv^(-1)]*G[{1/(yu*yv)}, yw]^2*G[{0, yu}, yv^(-1)] - 
     G[{1}, yw]*G[{1/(yu*yv)}, yw]^2*G[{0, yu}, yv^(-1)] + 
     G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2*G[{0, yu}, yv^(-1)] + 
     G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw]^2*G[{0, yu}, yv^(-1)] - 
     2*G[{1}, yv^(-1)]*G[{0, 1}, yu^(-1)]*G[{0, yu}, yv^(-1)] + 
     2*G[{yu}, yv^(-1)]*G[{0, 1}, yu^(-1)]*G[{0, yu}, yv^(-1)] + 
     2*G[{1}, yv^(-1)]*G[{0, 1}, yv^(-1)]*G[{0, yu}, yv^(-1)] - 
     2*G[{yu}, yv^(-1)]*G[{0, 1}, yv^(-1)]*G[{0, yu}, yv^(-1)] - 
     2*G[{yv^(-1)}, yw]*G[{0, 1}, yw]*G[{0, yu}, yv^(-1)] + 
     2*G[{1/(yu*yv)}, yw]*G[{0, 1}, yw]*G[{0, yu}, yv^(-1)] + 
     2*G[{yv^(-1)}, yw]*G[{0, yu^(-1)}, yw]*G[{0, yu}, yv^(-1)] - 
     2*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1)}, yw]*G[{0, yu}, yv^(-1)] - 
     G[{1}, yv^(-1)]*G[{0, yu}, yv^(-1)]^2 + G[{yu}, yv^(-1)]*
      G[{0, yu}, yv^(-1)]^2 - (Pi^2*G[{1}, yv^(-1)]*G[{0, yv^(-1)}, yw])/3 + 
     (Pi^2*G[{yu}, yv^(-1)]*G[{0, yv^(-1)}, yw])/3 + 
     2*G[{0}, yu^(-1)]*G[{1}, yv^(-1)]*G[{yv^(-1)}, yw]*G[{0, yv^(-1)}, yw] + 
     2*G[{0}, yv^(-1)]*G[{1}, yv^(-1)]*G[{yv^(-1)}, yw]*G[{0, yv^(-1)}, yw] - 
     2*G[{0}, yw]*G[{1}, yv^(-1)]*G[{yv^(-1)}, yw]*G[{0, yv^(-1)}, yw] - 
     2*G[{1}, yv^(-1)]^2*G[{yv^(-1)}, yw]*G[{0, yv^(-1)}, yw] - 
     2*G[{1}, yv^(-1)]*G[{1}, yw]*G[{yv^(-1)}, yw]*G[{0, yv^(-1)}, yw] - 
     G[{1}, yw]^2*G[{yv^(-1)}, yw]*G[{0, yv^(-1)}, yw] - 
     2*G[{0}, yu^(-1)]*G[{yu}, yv^(-1)]*G[{yv^(-1)}, yw]*
      G[{0, yv^(-1)}, yw] - 2*G[{0}, yv^(-1)]*G[{yu}, yv^(-1)]*
      G[{yv^(-1)}, yw]*G[{0, yv^(-1)}, yw] + 2*G[{0}, yw]*G[{yu}, yv^(-1)]*
      G[{yv^(-1)}, yw]*G[{0, yv^(-1)}, yw] + 4*G[{1}, yv^(-1)]*
      G[{yu}, yv^(-1)]*G[{yv^(-1)}, yw]*G[{0, yv^(-1)}, yw] + 
     2*G[{1}, yw]*G[{yu}, yv^(-1)]*G[{yv^(-1)}, yw]*G[{0, yv^(-1)}, yw] - 
     2*G[{1}, yu^(-1)]*G[{yv^(-1)}, yw]^2*G[{0, yv^(-1)}, yw] - 
     2*G[{1}, yw]*G[{yv^(-1)}, yw]^2*G[{0, yv^(-1)}, yw] + 
     2*G[{yu}, yv^(-1)]*G[{yv^(-1)}, yw]^2*G[{0, yv^(-1)}, yw] + 
     (2*G[{yv^(-1)}, yw]^3*G[{0, yv^(-1)}, yw])/3 - 
     2*G[{0}, yu^(-1)]*G[{1}, yv^(-1)]*G[{1/(yu*yv)}, yw]*
      G[{0, yv^(-1)}, yw] - 2*G[{0}, yv^(-1)]*G[{1}, yv^(-1)]*
      G[{1/(yu*yv)}, yw]*G[{0, yv^(-1)}, yw] + 2*G[{0}, yw]*G[{1}, yv^(-1)]*
      G[{1/(yu*yv)}, yw]*G[{0, yv^(-1)}, yw] + 2*G[{1}, yv^(-1)]^2*
      G[{1/(yu*yv)}, yw]*G[{0, yv^(-1)}, yw] + 2*G[{1}, yv^(-1)]*G[{1}, yw]*
      G[{1/(yu*yv)}, yw]*G[{0, yv^(-1)}, yw] + 
     G[{1}, yw]^2*G[{1/(yu*yv)}, yw]*G[{0, yv^(-1)}, yw] + 
     2*G[{0}, yu^(-1)]*G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw]*
      G[{0, yv^(-1)}, yw] + 2*G[{0}, yv^(-1)]*G[{yu}, yv^(-1)]*
      G[{1/(yu*yv)}, yw]*G[{0, yv^(-1)}, yw] - 2*G[{0}, yw]*G[{yu}, yv^(-1)]*
      G[{1/(yu*yv)}, yw]*G[{0, yv^(-1)}, yw] - 4*G[{1}, yv^(-1)]*
      G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, yv^(-1)}, yw] - 
     2*G[{1}, yw]*G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, yv^(-1)}, yw] + 
     4*G[{1}, yu^(-1)]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*
      G[{0, yv^(-1)}, yw] + 4*G[{1}, yw]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*
      G[{0, yv^(-1)}, yw] - 4*G[{yu}, yv^(-1)]*G[{yv^(-1)}, yw]*
      G[{1/(yu*yv)}, yw]*G[{0, yv^(-1)}, yw] - 2*G[{yv^(-1)}, yw]^2*
      G[{1/(yu*yv)}, yw]*G[{0, yv^(-1)}, yw] - 2*G[{1}, yu^(-1)]*
      G[{1/(yu*yv)}, yw]^2*G[{0, yv^(-1)}, yw] + 
     G[{1}, yv^(-1)]*G[{1/(yu*yv)}, yw]^2*G[{0, yv^(-1)}, yw] - 
     G[{1}, yw]*G[{1/(yu*yv)}, yw]^2*G[{0, yv^(-1)}, yw] - 
     G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2*G[{0, yv^(-1)}, yw] + 
     G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw]^2*G[{0, yv^(-1)}, yw] + 
     2*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2*G[{0, yv^(-1)}, yw] - 
     2*G[{1}, yv^(-1)]*G[{0, 1}, yu^(-1)]*G[{0, yv^(-1)}, yw] + 
     2*G[{yu}, yv^(-1)]*G[{0, 1}, yu^(-1)]*G[{0, yv^(-1)}, yw] + 
     4*G[{yv^(-1)}, yw]*G[{0, 1}, yu^(-1)]*G[{0, yv^(-1)}, yw] - 
     4*G[{1/(yu*yv)}, yw]*G[{0, 1}, yu^(-1)]*G[{0, yv^(-1)}, yw] - 
     2*G[{1}, yv^(-1)]*G[{0, 1}, yv^(-1)]*G[{0, yv^(-1)}, yw] + 
     2*G[{yu}, yv^(-1)]*G[{0, 1}, yv^(-1)]*G[{0, yv^(-1)}, yw] + 
     2*G[{1}, yv^(-1)]*G[{0, 1}, yw]*G[{0, yv^(-1)}, yw] - 
     2*G[{yu}, yv^(-1)]*G[{0, 1}, yw]*G[{0, yv^(-1)}, yw] - 
     2*G[{1}, yv^(-1)]*G[{0, yu^(-1)}, yw]*G[{0, yv^(-1)}, yw] + 
     2*G[{yu}, yv^(-1)]*G[{0, yu^(-1)}, yw]*G[{0, yv^(-1)}, yw] + 
     2*G[{1}, yv^(-1)]*G[{0, yu}, yv^(-1)]*G[{0, yv^(-1)}, yw] - 
     2*G[{yu}, yv^(-1)]*G[{0, yu}, yv^(-1)]*G[{0, yv^(-1)}, yw] - 
     G[{1}, yv^(-1)]*G[{0, yv^(-1)}, yw]^2 + G[{yu}, yv^(-1)]*
      G[{0, yv^(-1)}, yw]^2 + (Pi^2*G[{1}, yv^(-1)]*G[{0, 1/(yu*yv)}, yw])/
      3 - (Pi^2*G[{yu}, yv^(-1)]*G[{0, 1/(yu*yv)}, yw])/3 - 
     2*G[{0}, yu^(-1)]*G[{1}, yv^(-1)]*G[{yv^(-1)}, yw]*
      G[{0, 1/(yu*yv)}, yw] - 2*G[{0}, yv^(-1)]*G[{1}, yv^(-1)]*
      G[{yv^(-1)}, yw]*G[{0, 1/(yu*yv)}, yw] + 2*G[{0}, yw]*G[{1}, yv^(-1)]*
      G[{yv^(-1)}, yw]*G[{0, 1/(yu*yv)}, yw] + 2*G[{1}, yv^(-1)]^2*
      G[{yv^(-1)}, yw]*G[{0, 1/(yu*yv)}, yw] + 2*G[{1}, yv^(-1)]*G[{1}, yw]*
      G[{yv^(-1)}, yw]*G[{0, 1/(yu*yv)}, yw] + G[{1}, yw]^2*G[{yv^(-1)}, yw]*
      G[{0, 1/(yu*yv)}, yw] + 2*G[{0}, yu^(-1)]*G[{yu}, yv^(-1)]*
      G[{yv^(-1)}, yw]*G[{0, 1/(yu*yv)}, yw] + 2*G[{0}, yv^(-1)]*
      G[{yu}, yv^(-1)]*G[{yv^(-1)}, yw]*G[{0, 1/(yu*yv)}, yw] - 
     2*G[{0}, yw]*G[{yu}, yv^(-1)]*G[{yv^(-1)}, yw]*G[{0, 1/(yu*yv)}, yw] - 
     4*G[{1}, yv^(-1)]*G[{yu}, yv^(-1)]*G[{yv^(-1)}, yw]*
      G[{0, 1/(yu*yv)}, yw] - 2*G[{1}, yw]*G[{yu}, yv^(-1)]*G[{yv^(-1)}, yw]*
      G[{0, 1/(yu*yv)}, yw] + 2*G[{1}, yu^(-1)]*G[{yv^(-1)}, yw]^2*
      G[{0, 1/(yu*yv)}, yw] + 2*G[{1}, yw]*G[{yv^(-1)}, yw]^2*
      G[{0, 1/(yu*yv)}, yw] - 2*G[{yu}, yv^(-1)]*G[{yv^(-1)}, yw]^2*
      G[{0, 1/(yu*yv)}, yw] - (2*G[{yv^(-1)}, yw]^3*G[{0, 1/(yu*yv)}, yw])/
      3 + 2*G[{0}, yu^(-1)]*G[{1}, yv^(-1)]*G[{1/(yu*yv)}, yw]*
      G[{0, 1/(yu*yv)}, yw] + 2*G[{0}, yv^(-1)]*G[{1}, yv^(-1)]*
      G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv)}, yw] - 2*G[{0}, yw]*G[{1}, yv^(-1)]*
      G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv)}, yw] - 2*G[{1}, yv^(-1)]^2*
      G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv)}, yw] - 2*G[{1}, yv^(-1)]*G[{1}, yw]*
      G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv)}, yw] - 
     G[{1}, yw]^2*G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv)}, yw] - 
     2*G[{0}, yu^(-1)]*G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw]*
      G[{0, 1/(yu*yv)}, yw] - 2*G[{0}, yv^(-1)]*G[{yu}, yv^(-1)]*
      G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv)}, yw] + 
     2*G[{0}, yw]*G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv)}, yw] + 
     4*G[{1}, yv^(-1)]*G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw]*
      G[{0, 1/(yu*yv)}, yw] + 2*G[{1}, yw]*G[{yu}, yv^(-1)]*
      G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv)}, yw] - 4*G[{1}, yu^(-1)]*
      G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv)}, yw] - 
     4*G[{1}, yw]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv)}, yw] + 
     4*G[{yu}, yv^(-1)]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*
      G[{0, 1/(yu*yv)}, yw] + 2*G[{yv^(-1)}, yw]^2*G[{1/(yu*yv)}, yw]*
      G[{0, 1/(yu*yv)}, yw] + 2*G[{1}, yu^(-1)]*G[{1/(yu*yv)}, yw]^2*
      G[{0, 1/(yu*yv)}, yw] - G[{1}, yv^(-1)]*G[{1/(yu*yv)}, yw]^2*
      G[{0, 1/(yu*yv)}, yw] + G[{1}, yw]*G[{1/(yu*yv)}, yw]^2*
      G[{0, 1/(yu*yv)}, yw] + G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2*
      G[{0, 1/(yu*yv)}, yw] - G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw]^2*
      G[{0, 1/(yu*yv)}, yw] - 2*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2*
      G[{0, 1/(yu*yv)}, yw] + 2*G[{1}, yv^(-1)]*G[{0, 1}, yu^(-1)]*
      G[{0, 1/(yu*yv)}, yw] - 2*G[{yu}, yv^(-1)]*G[{0, 1}, yu^(-1)]*
      G[{0, 1/(yu*yv)}, yw] - 4*G[{yv^(-1)}, yw]*G[{0, 1}, yu^(-1)]*
      G[{0, 1/(yu*yv)}, yw] + 4*G[{1/(yu*yv)}, yw]*G[{0, 1}, yu^(-1)]*
      G[{0, 1/(yu*yv)}, yw] + 2*G[{1}, yv^(-1)]*G[{0, 1}, yv^(-1)]*
      G[{0, 1/(yu*yv)}, yw] - 2*G[{yu}, yv^(-1)]*G[{0, 1}, yv^(-1)]*
      G[{0, 1/(yu*yv)}, yw] - 2*G[{1}, yv^(-1)]*G[{0, 1}, yw]*
      G[{0, 1/(yu*yv)}, yw] + 2*G[{yu}, yv^(-1)]*G[{0, 1}, yw]*
      G[{0, 1/(yu*yv)}, yw] + 2*G[{1}, yv^(-1)]*G[{0, yu^(-1)}, yw]*
      G[{0, 1/(yu*yv)}, yw] - 2*G[{yu}, yv^(-1)]*G[{0, yu^(-1)}, yw]*
      G[{0, 1/(yu*yv)}, yw] - 2*G[{1}, yv^(-1)]*G[{0, yu}, yv^(-1)]*
      G[{0, 1/(yu*yv)}, yw] + 2*G[{yu}, yv^(-1)]*G[{0, yu}, yv^(-1)]*
      G[{0, 1/(yu*yv)}, yw] + 2*G[{1}, yv^(-1)]*G[{0, yv^(-1)}, yw]*
      G[{0, 1/(yu*yv)}, yw] - 2*G[{yu}, yv^(-1)]*G[{0, yv^(-1)}, yw]*
      G[{0, 1/(yu*yv)}, yw] - G[{1}, yv^(-1)]*G[{0, 1/(yu*yv)}, yw]^2 + 
     G[{yu}, yv^(-1)]*G[{0, 1/(yu*yv)}, yw]^2 + 
     (Pi^2*G[{yv^(-1)}, yw]*G[{1, yu^(-1)}, yw])/3 - 
     2*G[{0}, yu^(-1)]*G[{1}, yv^(-1)]*G[{yv^(-1)}, yw]*G[{1, yu^(-1)}, yw] - 
     2*G[{0}, yv^(-1)]*G[{1}, yv^(-1)]*G[{yv^(-1)}, yw]*G[{1, yu^(-1)}, yw] + 
     2*G[{0}, yw]*G[{1}, yv^(-1)]*G[{yv^(-1)}, yw]*G[{1, yu^(-1)}, yw] + 
     2*G[{1}, yv^(-1)]^2*G[{yv^(-1)}, yw]*G[{1, yu^(-1)}, yw] - 
     4*G[{0}, yu^(-1)]*G[{1}, yw]*G[{yv^(-1)}, yw]*G[{1, yu^(-1)}, yw] - 
     4*G[{0}, yv^(-1)]*G[{1}, yw]*G[{yv^(-1)}, yw]*G[{1, yu^(-1)}, yw] + 
     4*G[{0}, yw]*G[{1}, yw]*G[{yv^(-1)}, yw]*G[{1, yu^(-1)}, yw] + 
     4*G[{1}, yu^(-1)]*G[{1}, yw]*G[{yv^(-1)}, yw]*G[{1, yu^(-1)}, yw] + 
     4*G[{1}, yv^(-1)]*G[{1}, yw]*G[{yv^(-1)}, yw]*G[{1, yu^(-1)}, yw] + 
     2*G[{0}, yu^(-1)]*G[{yu}, yv^(-1)]*G[{yv^(-1)}, yw]*
      G[{1, yu^(-1)}, yw] + 2*G[{0}, yv^(-1)]*G[{yu}, yv^(-1)]*
      G[{yv^(-1)}, yw]*G[{1, yu^(-1)}, yw] - 2*G[{0}, yw]*G[{yu}, yv^(-1)]*
      G[{yv^(-1)}, yw]*G[{1, yu^(-1)}, yw] - 4*G[{1}, yv^(-1)]*
      G[{yu}, yv^(-1)]*G[{yv^(-1)}, yw]*G[{1, yu^(-1)}, yw] + 
     2*G[{1}, yu^(-1)]*G[{yv^(-1)}, yw]^2*G[{1, yu^(-1)}, yw] + 
     2*G[{1}, yw]*G[{yv^(-1)}, yw]^2*G[{1, yu^(-1)}, yw] - 
     2*G[{yu}, yv^(-1)]*G[{yv^(-1)}, yw]^2*G[{1, yu^(-1)}, yw] - 
     (2*G[{yv^(-1)}, yw]^3*G[{1, yu^(-1)}, yw])/3 - 
     (Pi^2*G[{1/(yu*yv)}, yw]*G[{1, yu^(-1)}, yw])/3 + 
     2*G[{0}, yu^(-1)]*G[{1}, yv^(-1)]*G[{1/(yu*yv)}, yw]*
      G[{1, yu^(-1)}, yw] + 2*G[{0}, yv^(-1)]*G[{1}, yv^(-1)]*
      G[{1/(yu*yv)}, yw]*G[{1, yu^(-1)}, yw] - 2*G[{0}, yw]*G[{1}, yv^(-1)]*
      G[{1/(yu*yv)}, yw]*G[{1, yu^(-1)}, yw] - 2*G[{1}, yv^(-1)]^2*
      G[{1/(yu*yv)}, yw]*G[{1, yu^(-1)}, yw] + 4*G[{0}, yu^(-1)]*G[{1}, yw]*
      G[{1/(yu*yv)}, yw]*G[{1, yu^(-1)}, yw] + 4*G[{0}, yv^(-1)]*G[{1}, yw]*
      G[{1/(yu*yv)}, yw]*G[{1, yu^(-1)}, yw] - 4*G[{0}, yw]*G[{1}, yw]*
      G[{1/(yu*yv)}, yw]*G[{1, yu^(-1)}, yw] - 4*G[{1}, yu^(-1)]*G[{1}, yw]*
      G[{1/(yu*yv)}, yw]*G[{1, yu^(-1)}, yw] - 4*G[{1}, yv^(-1)]*G[{1}, yw]*
      G[{1/(yu*yv)}, yw]*G[{1, yu^(-1)}, yw] - 2*G[{0}, yu^(-1)]*
      G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{1, yu^(-1)}, yw] - 
     2*G[{0}, yv^(-1)]*G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw]*
      G[{1, yu^(-1)}, yw] + 2*G[{0}, yw]*G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw]*
      G[{1, yu^(-1)}, yw] + 4*G[{1}, yv^(-1)]*G[{yu}, yv^(-1)]*
      G[{1/(yu*yv)}, yw]*G[{1, yu^(-1)}, yw] - 4*G[{1}, yu^(-1)]*
      G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{1, yu^(-1)}, yw] - 
     4*G[{1}, yw]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{1, yu^(-1)}, yw] + 
     4*G[{yu}, yv^(-1)]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*
      G[{1, yu^(-1)}, yw] + 2*G[{yv^(-1)}, yw]^2*G[{1/(yu*yv)}, yw]*
      G[{1, yu^(-1)}, yw] + 2*G[{1}, yu^(-1)]*G[{1/(yu*yv)}, yw]^2*
      G[{1, yu^(-1)}, yw] - 2*G[{1}, yv^(-1)]*G[{1/(yu*yv)}, yw]^2*
      G[{1, yu^(-1)}, yw] - 2*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2*
      G[{1, yu^(-1)}, yw] - 2*G[{yv^(-1)}, yw]*G[{0, 1}, yu^(-1)]*
      G[{1, yu^(-1)}, yw] + 2*G[{1/(yu*yv)}, yw]*G[{0, 1}, yu^(-1)]*
      G[{1, yu^(-1)}, yw] + 2*G[{yv^(-1)}, yw]*G[{0, 1}, yv^(-1)]*
      G[{1, yu^(-1)}, yw] - 2*G[{1/(yu*yv)}, yw]*G[{0, 1}, yv^(-1)]*
      G[{1, yu^(-1)}, yw] - 2*G[{yv^(-1)}, yw]*G[{0, 1}, yw]*
      G[{1, yu^(-1)}, yw] + 2*G[{1/(yu*yv)}, yw]*G[{0, 1}, yw]*
      G[{1, yu^(-1)}, yw] + 2*G[{yv^(-1)}, yw]*G[{0, yu^(-1)}, yw]*
      G[{1, yu^(-1)}, yw] - 2*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1)}, yw]*
      G[{1, yu^(-1)}, yw] - 2*G[{yv^(-1)}, yw]*G[{0, yu}, yv^(-1)]*
      G[{1, yu^(-1)}, yw] + 2*G[{1/(yu*yv)}, yw]*G[{0, yu}, yv^(-1)]*
      G[{1, yu^(-1)}, yw] + 2*G[{yv^(-1)}, yw]*G[{0, yv^(-1)}, yw]*
      G[{1, yu^(-1)}, yw] - 2*G[{1/(yu*yv)}, yw]*G[{0, yv^(-1)}, yw]*
      G[{1, yu^(-1)}, yw] - 2*G[{yv^(-1)}, yw]*G[{0, 1/(yu*yv)}, yw]*
      G[{1, yu^(-1)}, yw] + 2*G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv)}, yw]*
      G[{1, yu^(-1)}, yw] + (Pi^2*G[{1}, yv^(-1)]*G[{1, yu}, yv^(-1)])/3 - 
     3*G[{1}, yu^(-1)]*G[{1}, yv^(-1)]^2*G[{1, yu}, yv^(-1)] + 
     (5*Pi^2*G[{yu}, yv^(-1)]*G[{1, yu}, yv^(-1)])/3 - 
     2*G[{1}, yv^(-1)]^2*G[{yu}, yv^(-1)]*G[{1, yu}, yv^(-1)] + 
     3*G[{1}, yu^(-1)]*G[{yu}, yv^(-1)]^2*G[{1, yu}, yv^(-1)] + 
     Pi^2*G[{yv^(-1)}, yw]*G[{1, yu}, yv^(-1)] + 4*G[{1}, yu^(-1)]*
      G[{1}, yv^(-1)]*G[{yv^(-1)}, yw]*G[{1, yu}, yv^(-1)] - 
     2*G[{1}, yv^(-1)]^2*G[{yv^(-1)}, yw]*G[{1, yu}, yv^(-1)] - 
     2*G[{1}, yw]^2*G[{yv^(-1)}, yw]*G[{1, yu}, yv^(-1)] + 
     2*G[{1}, yu^(-1)]*G[{yu}, yv^(-1)]*G[{yv^(-1)}, yw]*
      G[{1, yu}, yv^(-1)] - 4*G[{1}, yv^(-1)]*G[{yu}, yv^(-1)]*
      G[{yv^(-1)}, yw]*G[{1, yu}, yv^(-1)] + 2*G[{1}, yw]*G[{yu}, yv^(-1)]*
      G[{yv^(-1)}, yw]*G[{1, yu}, yv^(-1)] - 4*G[{0}, yu^(-1)]*
      G[{yv^(-1)}, yw]^2*G[{1, yu}, yv^(-1)] - 4*G[{0}, yv^(-1)]*
      G[{yv^(-1)}, yw]^2*G[{1, yu}, yv^(-1)] + 
     4*G[{0}, yw]*G[{yv^(-1)}, yw]^2*G[{1, yu}, yv^(-1)] + 
     3*G[{1}, yu^(-1)]*G[{yv^(-1)}, yw]^2*G[{1, yu}, yv^(-1)] - 
     3*G[{1}, yw]*G[{yv^(-1)}, yw]^2*G[{1, yu}, yv^(-1)] - 
     (8*G[{yv^(-1)}, yw]^3*G[{1, yu}, yv^(-1)])/3 - 
     Pi^2*G[{1/(yu*yv)}, yw]*G[{1, yu}, yv^(-1)] - 
     4*G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*G[{1/(yu*yv)}, yw]*
      G[{1, yu}, yv^(-1)] + 2*G[{1}, yv^(-1)]^2*G[{1/(yu*yv)}, yw]*
      G[{1, yu}, yv^(-1)] + 2*G[{1}, yw]^2*G[{1/(yu*yv)}, yw]*
      G[{1, yu}, yv^(-1)] - 2*G[{1}, yu^(-1)]*G[{yu}, yv^(-1)]*
      G[{1/(yu*yv)}, yw]*G[{1, yu}, yv^(-1)] + 4*G[{1}, yv^(-1)]*
      G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{1, yu}, yv^(-1)] - 
     2*G[{1}, yw]*G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{1, yu}, yv^(-1)] + 
     8*G[{0}, yu^(-1)]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*
      G[{1, yu}, yv^(-1)] + 8*G[{0}, yv^(-1)]*G[{yv^(-1)}, yw]*
      G[{1/(yu*yv)}, yw]*G[{1, yu}, yv^(-1)] - 8*G[{0}, yw]*G[{yv^(-1)}, yw]*
      G[{1/(yu*yv)}, yw]*G[{1, yu}, yv^(-1)] - 6*G[{1}, yu^(-1)]*
      G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{1, yu}, yv^(-1)] + 
     6*G[{1}, yw]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{1, yu}, yv^(-1)] + 
     8*G[{yv^(-1)}, yw]^2*G[{1/(yu*yv)}, yw]*G[{1, yu}, yv^(-1)] - 
     4*G[{0}, yu^(-1)]*G[{1/(yu*yv)}, yw]^2*G[{1, yu}, yv^(-1)] - 
     4*G[{0}, yv^(-1)]*G[{1/(yu*yv)}, yw]^2*G[{1, yu}, yv^(-1)] + 
     4*G[{0}, yw]*G[{1/(yu*yv)}, yw]^2*G[{1, yu}, yv^(-1)] + 
     3*G[{1}, yu^(-1)]*G[{1/(yu*yv)}, yw]^2*G[{1, yu}, yv^(-1)] - 
     G[{1}, yw]*G[{1/(yu*yv)}, yw]^2*G[{1, yu}, yv^(-1)] - 
     2*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2*G[{1, yu}, yv^(-1)] + 
     G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw]^2*G[{1, yu}, yv^(-1)] - 
     5*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2*G[{1, yu}, yv^(-1)] - 
     4*G[{1}, yv^(-1)]*G[{0, 1}, yu^(-1)]*G[{1, yu}, yv^(-1)] - 
     2*G[{yu}, yv^(-1)]*G[{0, 1}, yu^(-1)]*G[{1, yu}, yv^(-1)] + 
     2*G[{yv^(-1)}, yw]*G[{0, 1}, yu^(-1)]*G[{1, yu}, yv^(-1)] - 
     2*G[{1/(yu*yv)}, yw]*G[{0, 1}, yu^(-1)]*G[{1, yu}, yv^(-1)] + 
     2*G[{1}, yv^(-1)]*G[{0, 1}, yv^(-1)]*G[{1, yu}, yv^(-1)] + 
     6*G[{yu}, yv^(-1)]*G[{0, 1}, yv^(-1)]*G[{1, yu}, yv^(-1)] + 
     2*G[{yv^(-1)}, yw]*G[{0, 1}, yv^(-1)]*G[{1, yu}, yv^(-1)] - 
     2*G[{1/(yu*yv)}, yw]*G[{0, 1}, yv^(-1)]*G[{1, yu}, yv^(-1)] + 
     4*G[{yv^(-1)}, yw]*G[{0, 1}, yw]*G[{1, yu}, yv^(-1)] - 
     4*G[{1/(yu*yv)}, yw]*G[{0, 1}, yw]*G[{1, yu}, yv^(-1)] - 
     4*G[{yv^(-1)}, yw]*G[{0, yu^(-1)}, yw]*G[{1, yu}, yv^(-1)] + 
     4*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1)}, yw]*G[{1, yu}, yv^(-1)] - 
     2*G[{1}, yv^(-1)]*G[{0, yu}, yv^(-1)]*G[{1, yu}, yv^(-1)] - 
     6*G[{yu}, yv^(-1)]*G[{0, yu}, yv^(-1)]*G[{1, yu}, yv^(-1)] - 
     2*G[{yv^(-1)}, yw]*G[{0, yu}, yv^(-1)]*G[{1, yu}, yv^(-1)] + 
     2*G[{1/(yu*yv)}, yw]*G[{0, yu}, yv^(-1)]*G[{1, yu}, yv^(-1)] - 
     4*G[{yv^(-1)}, yw]*G[{0, yv^(-1)}, yw]*G[{1, yu}, yv^(-1)] + 
     4*G[{1/(yu*yv)}, yw]*G[{0, yv^(-1)}, yw]*G[{1, yu}, yv^(-1)] + 
     4*G[{yv^(-1)}, yw]*G[{0, 1/(yu*yv)}, yw]*G[{1, yu}, yv^(-1)] - 
     4*G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv)}, yw]*G[{1, yu}, yv^(-1)] + 
     4*G[{yv^(-1)}, yw]*G[{1, yu^(-1)}, yw]*G[{1, yu}, yv^(-1)] - 
     4*G[{1/(yu*yv)}, yw]*G[{1, yu^(-1)}, yw]*G[{1, yu}, yv^(-1)] + 
     4*G[{yu}, yv^(-1)]*G[{1, yu}, yv^(-1)]^2 + 
     (Pi^2*G[{1}, yv^(-1)]*G[{1, yv^(-1)}, yw])/3 - 
     G[{1}, yu^(-1)]*G[{1}, yv^(-1)]^2*G[{1, yv^(-1)}, yw] + 
     (Pi^2*G[{1}, yw]*G[{1, yv^(-1)}, yw])/3 - 2*G[{0}, yu^(-1)]*
      G[{1}, yv^(-1)]*G[{1}, yw]*G[{1, yv^(-1)}, yw] - 
     2*G[{0}, yv^(-1)]*G[{1}, yv^(-1)]*G[{1}, yw]*G[{1, yv^(-1)}, yw] + 
     2*G[{0}, yw]*G[{1}, yv^(-1)]*G[{1}, yw]*G[{1, yv^(-1)}, yw] + 
     2*G[{1}, yv^(-1)]^2*G[{1}, yw]*G[{1, yv^(-1)}, yw] - 
     2*G[{0}, yu^(-1)]*G[{1}, yw]^2*G[{1, yv^(-1)}, yw] - 
     2*G[{0}, yv^(-1)]*G[{1}, yw]^2*G[{1, yv^(-1)}, yw] + 
     2*G[{0}, yw]*G[{1}, yw]^2*G[{1, yv^(-1)}, yw] + 
     2*G[{1}, yu^(-1)]*G[{1}, yw]^2*G[{1, yv^(-1)}, yw] + 
     2*G[{1}, yv^(-1)]*G[{1}, yw]^2*G[{1, yv^(-1)}, yw] - 
     (Pi^2*G[{yu}, yv^(-1)]*G[{1, yv^(-1)}, yw])/3 + 
     2*G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*G[{yu}, yv^(-1)]*G[{1, yv^(-1)}, yw] + 
     2*G[{0}, yu^(-1)]*G[{1}, yw]*G[{yu}, yv^(-1)]*G[{1, yv^(-1)}, yw] + 
     2*G[{0}, yv^(-1)]*G[{1}, yw]*G[{yu}, yv^(-1)]*G[{1, yv^(-1)}, yw] - 
     2*G[{0}, yw]*G[{1}, yw]*G[{yu}, yv^(-1)]*G[{1, yv^(-1)}, yw] - 
     4*G[{1}, yv^(-1)]*G[{1}, yw]*G[{yu}, yv^(-1)]*G[{1, yv^(-1)}, yw] - 
     G[{1}, yu^(-1)]*G[{yu}, yv^(-1)]^2*G[{1, yv^(-1)}, yw] + 
     (G[{yu}, yv^(-1)]^3*G[{1, yv^(-1)}, yw])/3 - 
     (2*Pi^2*G[{yv^(-1)}, yw]*G[{1, yv^(-1)}, yw])/3 + 
     2*G[{0}, yu^(-1)]*G[{1}, yv^(-1)]*G[{yv^(-1)}, yw]*G[{1, yv^(-1)}, yw] + 
     2*G[{0}, yv^(-1)]*G[{1}, yv^(-1)]*G[{yv^(-1)}, yw]*G[{1, yv^(-1)}, yw] - 
     2*G[{0}, yw]*G[{1}, yv^(-1)]*G[{yv^(-1)}, yw]*G[{1, yv^(-1)}, yw] - 
     4*G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*G[{yv^(-1)}, yw]*G[{1, yv^(-1)}, yw] - 
     2*G[{0}, yu^(-1)]*G[{1}, yw]*G[{yv^(-1)}, yw]*G[{1, yv^(-1)}, yw] - 
     2*G[{0}, yv^(-1)]*G[{1}, yw]*G[{yv^(-1)}, yw]*G[{1, yv^(-1)}, yw] + 
     2*G[{0}, yw]*G[{1}, yw]*G[{yv^(-1)}, yw]*G[{1, yv^(-1)}, yw] + 
     4*G[{1}, yu^(-1)]*G[{1}, yw]*G[{yv^(-1)}, yw]*G[{1, yv^(-1)}, yw] + 
     8*G[{1}, yv^(-1)]*G[{1}, yw]*G[{yv^(-1)}, yw]*G[{1, yv^(-1)}, yw] + 
     4*G[{1}, yw]^2*G[{yv^(-1)}, yw]*G[{1, yv^(-1)}, yw] - 
     2*G[{0}, yu^(-1)]*G[{yu}, yv^(-1)]*G[{yv^(-1)}, yw]*
      G[{1, yv^(-1)}, yw] - 2*G[{0}, yv^(-1)]*G[{yu}, yv^(-1)]*
      G[{yv^(-1)}, yw]*G[{1, yv^(-1)}, yw] + 2*G[{0}, yw]*G[{yu}, yv^(-1)]*
      G[{yv^(-1)}, yw]*G[{1, yv^(-1)}, yw] + 4*G[{1}, yu^(-1)]*
      G[{yu}, yv^(-1)]*G[{yv^(-1)}, yw]*G[{1, yv^(-1)}, yw] - 
     4*G[{1}, yv^(-1)]*G[{yu}, yv^(-1)]*G[{yv^(-1)}, yw]*
      G[{1, yv^(-1)}, yw] - 8*G[{1}, yw]*G[{yu}, yv^(-1)]*G[{yv^(-1)}, yw]*
      G[{1, yv^(-1)}, yw] + 2*G[{yu}, yv^(-1)]^2*G[{yv^(-1)}, yw]*
      G[{1, yv^(-1)}, yw] + 4*G[{0}, yu^(-1)]*G[{yv^(-1)}, yw]^2*
      G[{1, yv^(-1)}, yw] + 4*G[{0}, yv^(-1)]*G[{yv^(-1)}, yw]^2*
      G[{1, yv^(-1)}, yw] - 4*G[{0}, yw]*G[{yv^(-1)}, yw]^2*
      G[{1, yv^(-1)}, yw] - G[{1}, yu^(-1)]*G[{yv^(-1)}, yw]^2*
      G[{1, yv^(-1)}, yw] + 7*G[{1}, yw]*G[{yv^(-1)}, yw]^2*
      G[{1, yv^(-1)}, yw] - 7*G[{yu}, yv^(-1)]*G[{yv^(-1)}, yw]^2*
      G[{1, yv^(-1)}, yw] + 2*G[{yv^(-1)}, yw]^3*G[{1, yv^(-1)}, yw] + 
     (2*Pi^2*G[{1/(yu*yv)}, yw]*G[{1, yv^(-1)}, yw])/3 - 
     2*G[{0}, yu^(-1)]*G[{1}, yv^(-1)]*G[{1/(yu*yv)}, yw]*
      G[{1, yv^(-1)}, yw] - 2*G[{0}, yv^(-1)]*G[{1}, yv^(-1)]*
      G[{1/(yu*yv)}, yw]*G[{1, yv^(-1)}, yw] + 2*G[{0}, yw]*G[{1}, yv^(-1)]*
      G[{1/(yu*yv)}, yw]*G[{1, yv^(-1)}, yw] + 4*G[{1}, yu^(-1)]*
      G[{1}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{1, yv^(-1)}, yw] + 
     2*G[{0}, yu^(-1)]*G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{1, yv^(-1)}, yw] + 
     2*G[{0}, yv^(-1)]*G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{1, yv^(-1)}, yw] - 
     2*G[{0}, yw]*G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{1, yv^(-1)}, yw] - 
     4*G[{1}, yu^(-1)]*G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{1, yv^(-1)}, yw] - 
     8*G[{1}, yv^(-1)]*G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{1, yv^(-1)}, yw] - 
     4*G[{1}, yw]^2*G[{1/(yu*yv)}, yw]*G[{1, yv^(-1)}, yw] + 
     2*G[{0}, yu^(-1)]*G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw]*
      G[{1, yv^(-1)}, yw] + 2*G[{0}, yv^(-1)]*G[{yu}, yv^(-1)]*
      G[{1/(yu*yv)}, yw]*G[{1, yv^(-1)}, yw] - 2*G[{0}, yw]*G[{yu}, yv^(-1)]*
      G[{1/(yu*yv)}, yw]*G[{1, yv^(-1)}, yw] - 4*G[{1}, yu^(-1)]*
      G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{1, yv^(-1)}, yw] + 
     4*G[{1}, yv^(-1)]*G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw]*
      G[{1, yv^(-1)}, yw] + 8*G[{1}, yw]*G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw]*
      G[{1, yv^(-1)}, yw] - 2*G[{yu}, yv^(-1)]^2*G[{1/(yu*yv)}, yw]*
      G[{1, yv^(-1)}, yw] - 8*G[{0}, yu^(-1)]*G[{yv^(-1)}, yw]*
      G[{1/(yu*yv)}, yw]*G[{1, yv^(-1)}, yw] - 8*G[{0}, yv^(-1)]*
      G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{1, yv^(-1)}, yw] + 
     8*G[{0}, yw]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{1, yv^(-1)}, yw] + 
     2*G[{1}, yu^(-1)]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*
      G[{1, yv^(-1)}, yw] - 14*G[{1}, yw]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*
      G[{1, yv^(-1)}, yw] + 14*G[{yu}, yv^(-1)]*G[{yv^(-1)}, yw]*
      G[{1/(yu*yv)}, yw]*G[{1, yv^(-1)}, yw] - 6*G[{yv^(-1)}, yw]^2*
      G[{1/(yu*yv)}, yw]*G[{1, yv^(-1)}, yw] + 4*G[{0}, yu^(-1)]*
      G[{1/(yu*yv)}, yw]^2*G[{1, yv^(-1)}, yw] + 4*G[{0}, yv^(-1)]*
      G[{1/(yu*yv)}, yw]^2*G[{1, yv^(-1)}, yw] - 
     4*G[{0}, yw]*G[{1/(yu*yv)}, yw]^2*G[{1, yv^(-1)}, yw] - 
     G[{1}, yu^(-1)]*G[{1/(yu*yv)}, yw]^2*G[{1, yv^(-1)}, yw] - 
     2*G[{1}, yv^(-1)]*G[{1/(yu*yv)}, yw]^2*G[{1, yv^(-1)}, yw] + 
     5*G[{1}, yw]*G[{1/(yu*yv)}, yw]^2*G[{1, yv^(-1)}, yw] + 
     2*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2*G[{1, yv^(-1)}, yw] - 
     5*G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw]^2*G[{1, yv^(-1)}, yw] + 
     3*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2*G[{1, yv^(-1)}, yw] - 
     2*G[{1}, yw]*G[{0, 1}, yu^(-1)]*G[{1, yv^(-1)}, yw] - 
     4*G[{yv^(-1)}, yw]*G[{0, 1}, yu^(-1)]*G[{1, yv^(-1)}, yw] + 
     4*G[{1/(yu*yv)}, yw]*G[{0, 1}, yu^(-1)]*G[{1, yv^(-1)}, yw] + 
     2*G[{1}, yv^(-1)]*G[{0, 1}, yv^(-1)]*G[{1, yv^(-1)}, yw] + 
     2*G[{1}, yw]*G[{0, 1}, yv^(-1)]*G[{1, yv^(-1)}, yw] - 
     2*G[{yu}, yv^(-1)]*G[{0, 1}, yv^(-1)]*G[{1, yv^(-1)}, yw] - 
     2*G[{1}, yv^(-1)]*G[{0, 1}, yw]*G[{1, yv^(-1)}, yw] - 
     2*G[{1}, yw]*G[{0, 1}, yw]*G[{1, yv^(-1)}, yw] + 
     2*G[{yu}, yv^(-1)]*G[{0, 1}, yw]*G[{1, yv^(-1)}, yw] - 
     4*G[{yv^(-1)}, yw]*G[{0, 1}, yw]*G[{1, yv^(-1)}, yw] + 
     4*G[{1/(yu*yv)}, yw]*G[{0, 1}, yw]*G[{1, yv^(-1)}, yw] + 
     2*G[{1}, yv^(-1)]*G[{0, yu^(-1)}, yw]*G[{1, yv^(-1)}, yw] + 
     2*G[{1}, yw]*G[{0, yu^(-1)}, yw]*G[{1, yv^(-1)}, yw] - 
     2*G[{yu}, yv^(-1)]*G[{0, yu^(-1)}, yw]*G[{1, yv^(-1)}, yw] + 
     4*G[{yv^(-1)}, yw]*G[{0, yu^(-1)}, yw]*G[{1, yv^(-1)}, yw] - 
     4*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1)}, yw]*G[{1, yv^(-1)}, yw] - 
     2*G[{1}, yv^(-1)]*G[{0, yu}, yv^(-1)]*G[{1, yv^(-1)}, yw] - 
     2*G[{1}, yw]*G[{0, yu}, yv^(-1)]*G[{1, yv^(-1)}, yw] + 
     2*G[{yu}, yv^(-1)]*G[{0, yu}, yv^(-1)]*G[{1, yv^(-1)}, yw] + 
     2*G[{1}, yv^(-1)]*G[{0, yv^(-1)}, yw]*G[{1, yv^(-1)}, yw] + 
     2*G[{1}, yw]*G[{0, yv^(-1)}, yw]*G[{1, yv^(-1)}, yw] - 
     2*G[{yu}, yv^(-1)]*G[{0, yv^(-1)}, yw]*G[{1, yv^(-1)}, yw] + 
     4*G[{yv^(-1)}, yw]*G[{0, yv^(-1)}, yw]*G[{1, yv^(-1)}, yw] - 
     4*G[{1/(yu*yv)}, yw]*G[{0, yv^(-1)}, yw]*G[{1, yv^(-1)}, yw] - 
     2*G[{1}, yv^(-1)]*G[{0, 1/(yu*yv)}, yw]*G[{1, yv^(-1)}, yw] - 
     2*G[{1}, yw]*G[{0, 1/(yu*yv)}, yw]*G[{1, yv^(-1)}, yw] + 
     2*G[{yu}, yv^(-1)]*G[{0, 1/(yu*yv)}, yw]*G[{1, yv^(-1)}, yw] - 
     4*G[{yv^(-1)}, yw]*G[{0, 1/(yu*yv)}, yw]*G[{1, yv^(-1)}, yw] + 
     4*G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv)}, yw]*G[{1, yv^(-1)}, yw] - 
     4*G[{1}, yv^(-1)]*G[{1, yu^(-1)}, yw]*G[{1, yv^(-1)}, yw] - 
     4*G[{1}, yw]*G[{1, yu^(-1)}, yw]*G[{1, yv^(-1)}, yw] + 
     4*G[{yu}, yv^(-1)]*G[{1, yu^(-1)}, yw]*G[{1, yv^(-1)}, yw] - 
     4*G[{yv^(-1)}, yw]*G[{1, yu^(-1)}, yw]*G[{1, yv^(-1)}, yw] + 
     4*G[{1/(yu*yv)}, yw]*G[{1, yu^(-1)}, yw]*G[{1, yv^(-1)}, yw] + 
     4*G[{1}, yw]*G[{1, yu}, yv^(-1)]*G[{1, yv^(-1)}, yw] - 
     2*G[{yu}, yv^(-1)]*G[{1, yu}, yv^(-1)]*G[{1, yv^(-1)}, yw] + 
     4*G[{yv^(-1)}, yw]*G[{1, yu}, yv^(-1)]*G[{1, yv^(-1)}, yw] - 
     4*G[{1/(yu*yv)}, yw]*G[{1, yu}, yv^(-1)]*G[{1, yv^(-1)}, yw] - 
     2*G[{1}, yv^(-1)]*G[{1, yv^(-1)}, yw]^2 - 
     2*G[{1}, yw]*G[{1, yv^(-1)}, yw]^2 + 2*G[{yu}, yv^(-1)]*
      G[{1, yv^(-1)}, yw]^2 - 4*G[{yv^(-1)}, yw]*G[{1, yv^(-1)}, yw]^2 + 
     4*G[{1/(yu*yv)}, yw]*G[{1, yv^(-1)}, yw]^2 - 
     (Pi^2*G[{1}, yv^(-1)]*G[{1, 1/(yu*yv)}, yw])/3 + 
     G[{1}, yu^(-1)]*G[{1}, yv^(-1)]^2*G[{1, 1/(yu*yv)}, yw] - 
     (Pi^2*G[{1}, yw]*G[{1, 1/(yu*yv)}, yw])/3 + 2*G[{0}, yu^(-1)]*
      G[{1}, yv^(-1)]*G[{1}, yw]*G[{1, 1/(yu*yv)}, yw] + 
     2*G[{0}, yv^(-1)]*G[{1}, yv^(-1)]*G[{1}, yw]*G[{1, 1/(yu*yv)}, yw] - 
     2*G[{0}, yw]*G[{1}, yv^(-1)]*G[{1}, yw]*G[{1, 1/(yu*yv)}, yw] - 
     2*G[{1}, yv^(-1)]^2*G[{1}, yw]*G[{1, 1/(yu*yv)}, yw] + 
     2*G[{0}, yu^(-1)]*G[{1}, yw]^2*G[{1, 1/(yu*yv)}, yw] + 
     2*G[{0}, yv^(-1)]*G[{1}, yw]^2*G[{1, 1/(yu*yv)}, yw] - 
     2*G[{0}, yw]*G[{1}, yw]^2*G[{1, 1/(yu*yv)}, yw] - 
     2*G[{1}, yu^(-1)]*G[{1}, yw]^2*G[{1, 1/(yu*yv)}, yw] - 
     2*G[{1}, yv^(-1)]*G[{1}, yw]^2*G[{1, 1/(yu*yv)}, yw] + 
     (Pi^2*G[{yu}, yv^(-1)]*G[{1, 1/(yu*yv)}, yw])/3 - 
     2*G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*G[{yu}, yv^(-1)]*
      G[{1, 1/(yu*yv)}, yw] - 2*G[{0}, yu^(-1)]*G[{1}, yw]*G[{yu}, yv^(-1)]*
      G[{1, 1/(yu*yv)}, yw] - 2*G[{0}, yv^(-1)]*G[{1}, yw]*G[{yu}, yv^(-1)]*
      G[{1, 1/(yu*yv)}, yw] + 2*G[{0}, yw]*G[{1}, yw]*G[{yu}, yv^(-1)]*
      G[{1, 1/(yu*yv)}, yw] + 4*G[{1}, yv^(-1)]*G[{1}, yw]*G[{yu}, yv^(-1)]*
      G[{1, 1/(yu*yv)}, yw] + G[{1}, yu^(-1)]*G[{yu}, yv^(-1)]^2*
      G[{1, 1/(yu*yv)}, yw] - (G[{yu}, yv^(-1)]^3*G[{1, 1/(yu*yv)}, yw])/3 + 
     Pi^2*G[{yv^(-1)}, yw]*G[{1, 1/(yu*yv)}, yw] - 
     4*G[{0}, yu^(-1)]*G[{1}, yv^(-1)]*G[{yv^(-1)}, yw]*
      G[{1, 1/(yu*yv)}, yw] - 4*G[{0}, yv^(-1)]*G[{1}, yv^(-1)]*
      G[{yv^(-1)}, yw]*G[{1, 1/(yu*yv)}, yw] + 4*G[{0}, yw]*G[{1}, yv^(-1)]*
      G[{yv^(-1)}, yw]*G[{1, 1/(yu*yv)}, yw] + 4*G[{1}, yu^(-1)]*
      G[{1}, yv^(-1)]*G[{yv^(-1)}, yw]*G[{1, 1/(yu*yv)}, yw] + 
     2*G[{1}, yv^(-1)]^2*G[{yv^(-1)}, yw]*G[{1, 1/(yu*yv)}, yw] - 
     2*G[{0}, yu^(-1)]*G[{1}, yw]*G[{yv^(-1)}, yw]*G[{1, 1/(yu*yv)}, yw] - 
     2*G[{0}, yv^(-1)]*G[{1}, yw]*G[{yv^(-1)}, yw]*G[{1, 1/(yu*yv)}, yw] + 
     2*G[{0}, yw]*G[{1}, yw]*G[{yv^(-1)}, yw]*G[{1, 1/(yu*yv)}, yw] - 
     4*G[{1}, yv^(-1)]*G[{1}, yw]*G[{yv^(-1)}, yw]*G[{1, 1/(yu*yv)}, yw] - 
     4*G[{1}, yw]^2*G[{yv^(-1)}, yw]*G[{1, 1/(yu*yv)}, yw] + 
     4*G[{0}, yu^(-1)]*G[{yu}, yv^(-1)]*G[{yv^(-1)}, yw]*
      G[{1, 1/(yu*yv)}, yw] + 4*G[{0}, yv^(-1)]*G[{yu}, yv^(-1)]*
      G[{yv^(-1)}, yw]*G[{1, 1/(yu*yv)}, yw] - 4*G[{0}, yw]*G[{yu}, yv^(-1)]*
      G[{yv^(-1)}, yw]*G[{1, 1/(yu*yv)}, yw] - 4*G[{1}, yu^(-1)]*
      G[{yu}, yv^(-1)]*G[{yv^(-1)}, yw]*G[{1, 1/(yu*yv)}, yw] + 
     8*G[{1}, yw]*G[{yu}, yv^(-1)]*G[{yv^(-1)}, yw]*G[{1, 1/(yu*yv)}, yw] - 
     2*G[{yu}, yv^(-1)]^2*G[{yv^(-1)}, yw]*G[{1, 1/(yu*yv)}, yw] - 
     4*G[{0}, yu^(-1)]*G[{yv^(-1)}, yw]^2*G[{1, 1/(yu*yv)}, yw] - 
     4*G[{0}, yv^(-1)]*G[{yv^(-1)}, yw]^2*G[{1, 1/(yu*yv)}, yw] + 
     4*G[{0}, yw]*G[{yv^(-1)}, yw]^2*G[{1, 1/(yu*yv)}, yw] + 
     3*G[{1}, yu^(-1)]*G[{yv^(-1)}, yw]^2*G[{1, 1/(yu*yv)}, yw] - 
     5*G[{1}, yw]*G[{yv^(-1)}, yw]^2*G[{1, 1/(yu*yv)}, yw] + 
     5*G[{yu}, yv^(-1)]*G[{yv^(-1)}, yw]^2*G[{1, 1/(yu*yv)}, yw] - 
     (8*G[{yv^(-1)}, yw]^3*G[{1, 1/(yu*yv)}, yw])/3 - 
     Pi^2*G[{1/(yu*yv)}, yw]*G[{1, 1/(yu*yv)}, yw] + 
     4*G[{0}, yu^(-1)]*G[{1}, yv^(-1)]*G[{1/(yu*yv)}, yw]*
      G[{1, 1/(yu*yv)}, yw] + 4*G[{0}, yv^(-1)]*G[{1}, yv^(-1)]*
      G[{1/(yu*yv)}, yw]*G[{1, 1/(yu*yv)}, yw] - 4*G[{0}, yw]*G[{1}, yv^(-1)]*
      G[{1/(yu*yv)}, yw]*G[{1, 1/(yu*yv)}, yw] - 4*G[{1}, yu^(-1)]*
      G[{1}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{1, 1/(yu*yv)}, yw] - 
     2*G[{1}, yv^(-1)]^2*G[{1/(yu*yv)}, yw]*G[{1, 1/(yu*yv)}, yw] + 
     2*G[{0}, yu^(-1)]*G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{1, 1/(yu*yv)}, yw] + 
     2*G[{0}, yv^(-1)]*G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{1, 1/(yu*yv)}, yw] - 
     2*G[{0}, yw]*G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{1, 1/(yu*yv)}, yw] + 
     4*G[{1}, yv^(-1)]*G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{1, 1/(yu*yv)}, yw] + 
     4*G[{1}, yw]^2*G[{1/(yu*yv)}, yw]*G[{1, 1/(yu*yv)}, yw] - 
     4*G[{0}, yu^(-1)]*G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw]*
      G[{1, 1/(yu*yv)}, yw] - 4*G[{0}, yv^(-1)]*G[{yu}, yv^(-1)]*
      G[{1/(yu*yv)}, yw]*G[{1, 1/(yu*yv)}, yw] + 
     4*G[{0}, yw]*G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{1, 1/(yu*yv)}, yw] + 
     4*G[{1}, yu^(-1)]*G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw]*
      G[{1, 1/(yu*yv)}, yw] - 8*G[{1}, yw]*G[{yu}, yv^(-1)]*
      G[{1/(yu*yv)}, yw]*G[{1, 1/(yu*yv)}, yw] + 2*G[{yu}, yv^(-1)]^2*
      G[{1/(yu*yv)}, yw]*G[{1, 1/(yu*yv)}, yw] + 8*G[{0}, yu^(-1)]*
      G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{1, 1/(yu*yv)}, yw] + 
     8*G[{0}, yv^(-1)]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*
      G[{1, 1/(yu*yv)}, yw] - 8*G[{0}, yw]*G[{yv^(-1)}, yw]*
      G[{1/(yu*yv)}, yw]*G[{1, 1/(yu*yv)}, yw] - 6*G[{1}, yu^(-1)]*
      G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{1, 1/(yu*yv)}, yw] + 
     10*G[{1}, yw]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*
      G[{1, 1/(yu*yv)}, yw] - 10*G[{yu}, yv^(-1)]*G[{yv^(-1)}, yw]*
      G[{1/(yu*yv)}, yw]*G[{1, 1/(yu*yv)}, yw] + 8*G[{yv^(-1)}, yw]^2*
      G[{1/(yu*yv)}, yw]*G[{1, 1/(yu*yv)}, yw] - 4*G[{0}, yu^(-1)]*
      G[{1/(yu*yv)}, yw]^2*G[{1, 1/(yu*yv)}, yw] - 
     4*G[{0}, yv^(-1)]*G[{1/(yu*yv)}, yw]^2*G[{1, 1/(yu*yv)}, yw] + 
     4*G[{0}, yw]*G[{1/(yu*yv)}, yw]^2*G[{1, 1/(yu*yv)}, yw] + 
     3*G[{1}, yu^(-1)]*G[{1/(yu*yv)}, yw]^2*G[{1, 1/(yu*yv)}, yw] + 
     2*G[{1}, yv^(-1)]*G[{1/(yu*yv)}, yw]^2*G[{1, 1/(yu*yv)}, yw] - 
     3*G[{1}, yw]*G[{1/(yu*yv)}, yw]^2*G[{1, 1/(yu*yv)}, yw] + 
     3*G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw]^2*G[{1, 1/(yu*yv)}, yw] - 
     5*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2*G[{1, 1/(yu*yv)}, yw] + 
     2*G[{1}, yw]*G[{0, 1}, yu^(-1)]*G[{1, 1/(yu*yv)}, yw] + 
     2*G[{yv^(-1)}, yw]*G[{0, 1}, yu^(-1)]*G[{1, 1/(yu*yv)}, yw] - 
     2*G[{1/(yu*yv)}, yw]*G[{0, 1}, yu^(-1)]*G[{1, 1/(yu*yv)}, yw] - 
     2*G[{1}, yv^(-1)]*G[{0, 1}, yv^(-1)]*G[{1, 1/(yu*yv)}, yw] - 
     2*G[{1}, yw]*G[{0, 1}, yv^(-1)]*G[{1, 1/(yu*yv)}, yw] + 
     2*G[{yu}, yv^(-1)]*G[{0, 1}, yv^(-1)]*G[{1, 1/(yu*yv)}, yw] + 
     2*G[{yv^(-1)}, yw]*G[{0, 1}, yv^(-1)]*G[{1, 1/(yu*yv)}, yw] - 
     2*G[{1/(yu*yv)}, yw]*G[{0, 1}, yv^(-1)]*G[{1, 1/(yu*yv)}, yw] + 
     2*G[{1}, yv^(-1)]*G[{0, 1}, yw]*G[{1, 1/(yu*yv)}, yw] + 
     2*G[{1}, yw]*G[{0, 1}, yw]*G[{1, 1/(yu*yv)}, yw] - 
     2*G[{yu}, yv^(-1)]*G[{0, 1}, yw]*G[{1, 1/(yu*yv)}, yw] + 
     2*G[{yv^(-1)}, yw]*G[{0, 1}, yw]*G[{1, 1/(yu*yv)}, yw] - 
     2*G[{1/(yu*yv)}, yw]*G[{0, 1}, yw]*G[{1, 1/(yu*yv)}, yw] - 
     2*G[{1}, yv^(-1)]*G[{0, yu^(-1)}, yw]*G[{1, 1/(yu*yv)}, yw] - 
     2*G[{1}, yw]*G[{0, yu^(-1)}, yw]*G[{1, 1/(yu*yv)}, yw] + 
     2*G[{yu}, yv^(-1)]*G[{0, yu^(-1)}, yw]*G[{1, 1/(yu*yv)}, yw] - 
     2*G[{yv^(-1)}, yw]*G[{0, yu^(-1)}, yw]*G[{1, 1/(yu*yv)}, yw] + 
     2*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1)}, yw]*G[{1, 1/(yu*yv)}, yw] + 
     2*G[{1}, yv^(-1)]*G[{0, yu}, yv^(-1)]*G[{1, 1/(yu*yv)}, yw] + 
     2*G[{1}, yw]*G[{0, yu}, yv^(-1)]*G[{1, 1/(yu*yv)}, yw] - 
     2*G[{yu}, yv^(-1)]*G[{0, yu}, yv^(-1)]*G[{1, 1/(yu*yv)}, yw] - 
     2*G[{yv^(-1)}, yw]*G[{0, yu}, yv^(-1)]*G[{1, 1/(yu*yv)}, yw] + 
     2*G[{1/(yu*yv)}, yw]*G[{0, yu}, yv^(-1)]*G[{1, 1/(yu*yv)}, yw] - 
     2*G[{1}, yv^(-1)]*G[{0, yv^(-1)}, yw]*G[{1, 1/(yu*yv)}, yw] - 
     2*G[{1}, yw]*G[{0, yv^(-1)}, yw]*G[{1, 1/(yu*yv)}, yw] + 
     2*G[{yu}, yv^(-1)]*G[{0, yv^(-1)}, yw]*G[{1, 1/(yu*yv)}, yw] - 
     2*G[{yv^(-1)}, yw]*G[{0, yv^(-1)}, yw]*G[{1, 1/(yu*yv)}, yw] + 
     2*G[{1/(yu*yv)}, yw]*G[{0, yv^(-1)}, yw]*G[{1, 1/(yu*yv)}, yw] + 
     2*G[{1}, yv^(-1)]*G[{0, 1/(yu*yv)}, yw]*G[{1, 1/(yu*yv)}, yw] + 
     2*G[{1}, yw]*G[{0, 1/(yu*yv)}, yw]*G[{1, 1/(yu*yv)}, yw] - 
     2*G[{yu}, yv^(-1)]*G[{0, 1/(yu*yv)}, yw]*G[{1, 1/(yu*yv)}, yw] + 
     2*G[{yv^(-1)}, yw]*G[{0, 1/(yu*yv)}, yw]*G[{1, 1/(yu*yv)}, yw] - 
     2*G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv)}, yw]*G[{1, 1/(yu*yv)}, yw] + 
     4*G[{1}, yv^(-1)]*G[{1, yu^(-1)}, yw]*G[{1, 1/(yu*yv)}, yw] + 
     4*G[{1}, yw]*G[{1, yu^(-1)}, yw]*G[{1, 1/(yu*yv)}, yw] - 
     4*G[{yu}, yv^(-1)]*G[{1, yu^(-1)}, yw]*G[{1, 1/(yu*yv)}, yw] + 
     4*G[{yv^(-1)}, yw]*G[{1, yu^(-1)}, yw]*G[{1, 1/(yu*yv)}, yw] - 
     4*G[{1/(yu*yv)}, yw]*G[{1, yu^(-1)}, yw]*G[{1, 1/(yu*yv)}, yw] - 
     4*G[{1}, yw]*G[{1, yu}, yv^(-1)]*G[{1, 1/(yu*yv)}, yw] + 
     2*G[{yu}, yv^(-1)]*G[{1, yu}, yv^(-1)]*G[{1, 1/(yu*yv)}, yw] + 
     4*G[{1}, yv^(-1)]*G[{1, yv^(-1)}, yw]*G[{1, 1/(yu*yv)}, yw] + 
     4*G[{1}, yw]*G[{1, yv^(-1)}, yw]*G[{1, 1/(yu*yv)}, yw] - 
     4*G[{yu}, yv^(-1)]*G[{1, yv^(-1)}, yw]*G[{1, 1/(yu*yv)}, yw] + 
     4*G[{yv^(-1)}, yw]*G[{1, yv^(-1)}, yw]*G[{1, 1/(yu*yv)}, yw] - 
     4*G[{1/(yu*yv)}, yw]*G[{1, yv^(-1)}, yw]*G[{1, 1/(yu*yv)}, yw] - 
     2*G[{1}, yv^(-1)]*G[{1, 1/(yu*yv)}, yw]^2 - 
     2*G[{1}, yw]*G[{1, 1/(yu*yv)}, yw]^2 + 2*G[{yu}, yv^(-1)]*
      G[{1, 1/(yu*yv)}, yw]^2 - 2*G[{yv^(-1)}, yw]*G[{1, 1/(yu*yv)}, yw]^2 + 
     2*G[{1/(yu*yv)}, yw]*G[{1, 1/(yu*yv)}, yw]^2 - 
     (Pi^2*G[{yv^(-1)}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw])/3 + 
     2*G[{0}, yu^(-1)]*G[{1}, yv^(-1)]*G[{yv^(-1)}, yw]*
      G[{yu^(-1), 1/(yu*yv)}, yw] + 2*G[{0}, yv^(-1)]*G[{1}, yv^(-1)]*
      G[{yv^(-1)}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw] - 
     2*G[{0}, yw]*G[{1}, yv^(-1)]*G[{yv^(-1)}, yw]*G[{yu^(-1), 1/(yu*yv)}, 
       yw] - 2*G[{1}, yv^(-1)]^2*G[{yv^(-1)}, yw]*G[{yu^(-1), 1/(yu*yv)}, 
       yw] + 4*G[{0}, yu^(-1)]*G[{1}, yw]*G[{yv^(-1)}, yw]*
      G[{yu^(-1), 1/(yu*yv)}, yw] + 4*G[{0}, yv^(-1)]*G[{1}, yw]*
      G[{yv^(-1)}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw] - 
     4*G[{0}, yw]*G[{1}, yw]*G[{yv^(-1)}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw] - 
     4*G[{1}, yu^(-1)]*G[{1}, yw]*G[{yv^(-1)}, yw]*G[{yu^(-1), 1/(yu*yv)}, 
       yw] - 4*G[{1}, yv^(-1)]*G[{1}, yw]*G[{yv^(-1)}, yw]*
      G[{yu^(-1), 1/(yu*yv)}, yw] - 4*G[{0}, yu^(-1)]*G[{yu^(-1)}, yw]*
      G[{yv^(-1)}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw] - 
     4*G[{0}, yv^(-1)]*G[{yu^(-1)}, yw]*G[{yv^(-1)}, yw]*
      G[{yu^(-1), 1/(yu*yv)}, yw] + 4*G[{0}, yw]*G[{yu^(-1)}, yw]*
      G[{yv^(-1)}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw] + 
     4*G[{1}, yu^(-1)]*G[{yu^(-1)}, yw]*G[{yv^(-1)}, yw]*
      G[{yu^(-1), 1/(yu*yv)}, yw] + 8*G[{1}, yv^(-1)]*G[{yu^(-1)}, yw]*
      G[{yv^(-1)}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw] + 
     4*G[{1}, yw]*G[{yu^(-1)}, yw]*G[{yv^(-1)}, yw]*G[{yu^(-1), 1/(yu*yv)}, 
       yw] - 4*G[{yu^(-1)}, yw]^2*G[{yv^(-1)}, yw]*G[{yu^(-1), 1/(yu*yv)}, 
       yw] - 2*G[{0}, yu^(-1)]*G[{yu}, yv^(-1)]*G[{yv^(-1)}, yw]*
      G[{yu^(-1), 1/(yu*yv)}, yw] - 2*G[{0}, yv^(-1)]*G[{yu}, yv^(-1)]*
      G[{yv^(-1)}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw] + 
     2*G[{0}, yw]*G[{yu}, yv^(-1)]*G[{yv^(-1)}, yw]*G[{yu^(-1), 1/(yu*yv)}, 
       yw] + 4*G[{1}, yv^(-1)]*G[{yu}, yv^(-1)]*G[{yv^(-1)}, yw]*
      G[{yu^(-1), 1/(yu*yv)}, yw] - 4*G[{yu^(-1)}, yw]*G[{yu}, yv^(-1)]*
      G[{yv^(-1)}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw] - 
     2*G[{1}, yu^(-1)]*G[{yv^(-1)}, yw]^2*G[{yu^(-1), 1/(yu*yv)}, yw] - 
     2*G[{1}, yw]*G[{yv^(-1)}, yw]^2*G[{yu^(-1), 1/(yu*yv)}, yw] + 
     2*G[{yu}, yv^(-1)]*G[{yv^(-1)}, yw]^2*G[{yu^(-1), 1/(yu*yv)}, yw] + 
     (2*G[{yv^(-1)}, yw]^3*G[{yu^(-1), 1/(yu*yv)}, yw])/3 + 
     (Pi^2*G[{1/(yu*yv)}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw])/3 - 
     2*G[{0}, yu^(-1)]*G[{1}, yv^(-1)]*G[{1/(yu*yv)}, yw]*
      G[{yu^(-1), 1/(yu*yv)}, yw] - 2*G[{0}, yv^(-1)]*G[{1}, yv^(-1)]*
      G[{1/(yu*yv)}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw] + 
     2*G[{0}, yw]*G[{1}, yv^(-1)]*G[{1/(yu*yv)}, yw]*
      G[{yu^(-1), 1/(yu*yv)}, yw] + 2*G[{1}, yv^(-1)]^2*G[{1/(yu*yv)}, yw]*
      G[{yu^(-1), 1/(yu*yv)}, yw] - 4*G[{0}, yu^(-1)]*G[{1}, yw]*
      G[{1/(yu*yv)}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw] - 
     4*G[{0}, yv^(-1)]*G[{1}, yw]*G[{1/(yu*yv)}, yw]*
      G[{yu^(-1), 1/(yu*yv)}, yw] + 4*G[{0}, yw]*G[{1}, yw]*
      G[{1/(yu*yv)}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw] + 
     4*G[{1}, yu^(-1)]*G[{1}, yw]*G[{1/(yu*yv)}, yw]*
      G[{yu^(-1), 1/(yu*yv)}, yw] + 4*G[{1}, yv^(-1)]*G[{1}, yw]*
      G[{1/(yu*yv)}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw] + 
     4*G[{0}, yu^(-1)]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*
      G[{yu^(-1), 1/(yu*yv)}, yw] + 4*G[{0}, yv^(-1)]*G[{yu^(-1)}, yw]*
      G[{1/(yu*yv)}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw] - 
     4*G[{0}, yw]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*
      G[{yu^(-1), 1/(yu*yv)}, yw] - 4*G[{1}, yu^(-1)]*G[{yu^(-1)}, yw]*
      G[{1/(yu*yv)}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw] - 
     8*G[{1}, yv^(-1)]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*
      G[{yu^(-1), 1/(yu*yv)}, yw] - 4*G[{1}, yw]*G[{yu^(-1)}, yw]*
      G[{1/(yu*yv)}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw] + 
     4*G[{yu^(-1)}, yw]^2*G[{1/(yu*yv)}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw] + 
     2*G[{0}, yu^(-1)]*G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw]*
      G[{yu^(-1), 1/(yu*yv)}, yw] + 2*G[{0}, yv^(-1)]*G[{yu}, yv^(-1)]*
      G[{1/(yu*yv)}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw] - 
     2*G[{0}, yw]*G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw]*
      G[{yu^(-1), 1/(yu*yv)}, yw] - 4*G[{1}, yv^(-1)]*G[{yu}, yv^(-1)]*
      G[{1/(yu*yv)}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw] + 
     4*G[{yu^(-1)}, yw]*G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw]*
      G[{yu^(-1), 1/(yu*yv)}, yw] + 4*G[{1}, yu^(-1)]*G[{yv^(-1)}, yw]*
      G[{1/(yu*yv)}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw] + 
     4*G[{1}, yw]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*
      G[{yu^(-1), 1/(yu*yv)}, yw] - 4*G[{yu}, yv^(-1)]*G[{yv^(-1)}, yw]*
      G[{1/(yu*yv)}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw] - 
     2*G[{yv^(-1)}, yw]^2*G[{1/(yu*yv)}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw] - 
     2*G[{1}, yu^(-1)]*G[{1/(yu*yv)}, yw]^2*G[{yu^(-1), 1/(yu*yv)}, yw] - 
     2*G[{1}, yw]*G[{1/(yu*yv)}, yw]^2*G[{yu^(-1), 1/(yu*yv)}, yw] + 
     2*G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw]^2*G[{yu^(-1), 1/(yu*yv)}, yw] + 
     2*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2*G[{yu^(-1), 1/(yu*yv)}, yw] + 
     2*G[{yv^(-1)}, yw]*G[{0, 1}, yu^(-1)]*G[{yu^(-1), 1/(yu*yv)}, yw] - 
     2*G[{1/(yu*yv)}, yw]*G[{0, 1}, yu^(-1)]*G[{yu^(-1), 1/(yu*yv)}, yw] - 
     2*G[{yv^(-1)}, yw]*G[{0, 1}, yv^(-1)]*G[{yu^(-1), 1/(yu*yv)}, yw] + 
     2*G[{1/(yu*yv)}, yw]*G[{0, 1}, yv^(-1)]*G[{yu^(-1), 1/(yu*yv)}, yw] + 
     2*G[{yv^(-1)}, yw]*G[{0, 1}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw] - 
     2*G[{1/(yu*yv)}, yw]*G[{0, 1}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw] - 
     2*G[{yv^(-1)}, yw]*G[{0, yu^(-1)}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw] + 
     2*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1)}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw] + 
     2*G[{yv^(-1)}, yw]*G[{0, yu}, yv^(-1)]*G[{yu^(-1), 1/(yu*yv)}, yw] - 
     2*G[{1/(yu*yv)}, yw]*G[{0, yu}, yv^(-1)]*G[{yu^(-1), 1/(yu*yv)}, yw] - 
     2*G[{yv^(-1)}, yw]*G[{0, yv^(-1)}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw] + 
     2*G[{1/(yu*yv)}, yw]*G[{0, yv^(-1)}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw] + 
     2*G[{yv^(-1)}, yw]*G[{0, 1/(yu*yv)}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw] - 
     2*G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv)}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw] - 
     4*G[{yv^(-1)}, yw]*G[{1, yu}, yv^(-1)]*G[{yu^(-1), 1/(yu*yv)}, yw] + 
     4*G[{1/(yu*yv)}, yw]*G[{1, yu}, yv^(-1)]*G[{yu^(-1), 1/(yu*yv)}, yw] + 
     4*G[{yv^(-1)}, yw]*G[{1, yv^(-1)}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw] - 
     4*G[{1/(yu*yv)}, yw]*G[{1, yv^(-1)}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw] - 
     2*G[{yv^(-1)}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw]^2 + 
     2*G[{1/(yu*yv)}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw]^2 - 
     (Pi^2*G[{1}, yv^(-1)]*G[{yv^(-1), 1/(yu*yv)}, yw])/3 - 
     G[{1}, yu^(-1)]*G[{1}, yv^(-1)]^2*G[{yv^(-1), 1/(yu*yv)}, yw] - 
     (Pi^2*G[{1}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw])/3 + 
     2*G[{0}, yu^(-1)]*G[{1}, yv^(-1)]*G[{1}, yw]*G[{yv^(-1), 1/(yu*yv)}, 
       yw] + 2*G[{0}, yv^(-1)]*G[{1}, yv^(-1)]*G[{1}, yw]*
      G[{yv^(-1), 1/(yu*yv)}, yw] - 2*G[{0}, yw]*G[{1}, yv^(-1)]*G[{1}, yw]*
      G[{yv^(-1), 1/(yu*yv)}, yw] - 2*G[{1}, yv^(-1)]^2*G[{1}, yw]*
      G[{yv^(-1), 1/(yu*yv)}, yw] + 2*G[{0}, yu^(-1)]*G[{1}, yw]^2*
      G[{yv^(-1), 1/(yu*yv)}, yw] + 2*G[{0}, yv^(-1)]*G[{1}, yw]^2*
      G[{yv^(-1), 1/(yu*yv)}, yw] - 2*G[{0}, yw]*G[{1}, yw]^2*
      G[{yv^(-1), 1/(yu*yv)}, yw] - 2*G[{1}, yu^(-1)]*G[{1}, yw]^2*
      G[{yv^(-1), 1/(yu*yv)}, yw] - 2*G[{1}, yv^(-1)]*G[{1}, yw]^2*
      G[{yv^(-1), 1/(yu*yv)}, yw] + (Pi^2*G[{yu^(-1)}, yw]*
       G[{yv^(-1), 1/(yu*yv)}, yw])/3 - 2*G[{0}, yu^(-1)]*G[{1}, yv^(-1)]*
      G[{yu^(-1)}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw] - 
     2*G[{0}, yv^(-1)]*G[{1}, yv^(-1)]*G[{yu^(-1)}, yw]*
      G[{yv^(-1), 1/(yu*yv)}, yw] + 2*G[{0}, yw]*G[{1}, yv^(-1)]*
      G[{yu^(-1)}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw] + 
     2*G[{1}, yv^(-1)]^2*G[{yu^(-1)}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw] - 
     4*G[{0}, yu^(-1)]*G[{1}, yw]*G[{yu^(-1)}, yw]*G[{yv^(-1), 1/(yu*yv)}, 
       yw] - 4*G[{0}, yv^(-1)]*G[{1}, yw]*G[{yu^(-1)}, yw]*
      G[{yv^(-1), 1/(yu*yv)}, yw] + 4*G[{0}, yw]*G[{1}, yw]*G[{yu^(-1)}, yw]*
      G[{yv^(-1), 1/(yu*yv)}, yw] + 4*G[{1}, yu^(-1)]*G[{1}, yw]*
      G[{yu^(-1)}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw] + 
     4*G[{1}, yv^(-1)]*G[{1}, yw]*G[{yu^(-1)}, yw]*G[{yv^(-1), 1/(yu*yv)}, 
       yw] + 2*G[{0}, yu^(-1)]*G[{yu^(-1)}, yw]^2*G[{yv^(-1), 1/(yu*yv)}, 
       yw] + 2*G[{0}, yv^(-1)]*G[{yu^(-1)}, yw]^2*G[{yv^(-1), 1/(yu*yv)}, 
       yw] - 2*G[{0}, yw]*G[{yu^(-1)}, yw]^2*G[{yv^(-1), 1/(yu*yv)}, yw] - 
     2*G[{1}, yu^(-1)]*G[{yu^(-1)}, yw]^2*G[{yv^(-1), 1/(yu*yv)}, yw] - 
     4*G[{1}, yv^(-1)]*G[{yu^(-1)}, yw]^2*G[{yv^(-1), 1/(yu*yv)}, yw] - 
     2*G[{1}, yw]*G[{yu^(-1)}, yw]^2*G[{yv^(-1), 1/(yu*yv)}, yw] + 
     (4*G[{yu^(-1)}, yw]^3*G[{yv^(-1), 1/(yu*yv)}, yw])/3 + 
     (Pi^2*G[{yu}, yv^(-1)]*G[{yv^(-1), 1/(yu*yv)}, yw])/3 + 
     2*G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*G[{yu}, yv^(-1)]*
      G[{yv^(-1), 1/(yu*yv)}, yw] - 2*G[{0}, yu^(-1)]*G[{1}, yw]*
      G[{yu}, yv^(-1)]*G[{yv^(-1), 1/(yu*yv)}, yw] - 
     2*G[{0}, yv^(-1)]*G[{1}, yw]*G[{yu}, yv^(-1)]*G[{yv^(-1), 1/(yu*yv)}, 
       yw] + 2*G[{0}, yw]*G[{1}, yw]*G[{yu}, yv^(-1)]*
      G[{yv^(-1), 1/(yu*yv)}, yw] + 4*G[{1}, yv^(-1)]*G[{1}, yw]*
      G[{yu}, yv^(-1)]*G[{yv^(-1), 1/(yu*yv)}, yw] + 
     2*G[{0}, yu^(-1)]*G[{yu^(-1)}, yw]*G[{yu}, yv^(-1)]*
      G[{yv^(-1), 1/(yu*yv)}, yw] + 2*G[{0}, yv^(-1)]*G[{yu^(-1)}, yw]*
      G[{yu}, yv^(-1)]*G[{yv^(-1), 1/(yu*yv)}, yw] - 
     2*G[{0}, yw]*G[{yu^(-1)}, yw]*G[{yu}, yv^(-1)]*G[{yv^(-1), 1/(yu*yv)}, 
       yw] - 4*G[{1}, yv^(-1)]*G[{yu^(-1)}, yw]*G[{yu}, yv^(-1)]*
      G[{yv^(-1), 1/(yu*yv)}, yw] + 2*G[{yu^(-1)}, yw]^2*G[{yu}, yv^(-1)]*
      G[{yv^(-1), 1/(yu*yv)}, yw] - G[{1}, yu^(-1)]*G[{yu}, yv^(-1)]^2*
      G[{yv^(-1), 1/(yu*yv)}, yw] + 
     (G[{yu}, yv^(-1)]^3*G[{yv^(-1), 1/(yu*yv)}, yw])/3 - 
     2*G[{0}, yu^(-1)]*G[{1}, yv^(-1)]*G[{yv^(-1)}, yw]*
      G[{yv^(-1), 1/(yu*yv)}, yw] - 2*G[{0}, yv^(-1)]*G[{1}, yv^(-1)]*
      G[{yv^(-1)}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw] + 
     2*G[{0}, yw]*G[{1}, yv^(-1)]*G[{yv^(-1)}, yw]*G[{yv^(-1), 1/(yu*yv)}, 
       yw] + 6*G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*G[{yv^(-1)}, yw]*
      G[{yv^(-1), 1/(yu*yv)}, yw] + 2*G[{1}, yv^(-1)]^2*G[{yv^(-1)}, yw]*
      G[{yv^(-1), 1/(yu*yv)}, yw] - 2*G[{0}, yu^(-1)]*G[{1}, yw]*
      G[{yv^(-1)}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw] - 
     2*G[{0}, yv^(-1)]*G[{1}, yw]*G[{yv^(-1)}, yw]*G[{yv^(-1), 1/(yu*yv)}, 
       yw] + 2*G[{0}, yw]*G[{1}, yw]*G[{yv^(-1)}, yw]*
      G[{yv^(-1), 1/(yu*yv)}, yw] - 2*G[{1}, yw]^2*G[{yv^(-1)}, yw]*
      G[{yv^(-1), 1/(yu*yv)}, yw] + 2*G[{0}, yu^(-1)]*G[{yu^(-1)}, yw]*
      G[{yv^(-1)}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw] + 
     2*G[{0}, yv^(-1)]*G[{yu^(-1)}, yw]*G[{yv^(-1)}, yw]*
      G[{yv^(-1), 1/(yu*yv)}, yw] - 2*G[{0}, yw]*G[{yu^(-1)}, yw]*
      G[{yv^(-1)}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw] - 
     4*G[{1}, yv^(-1)]*G[{yu^(-1)}, yw]*G[{yv^(-1)}, yw]*
      G[{yv^(-1), 1/(yu*yv)}, yw] + 2*G[{yu^(-1)}, yw]^2*G[{yv^(-1)}, yw]*
      G[{yv^(-1), 1/(yu*yv)}, yw] + 2*G[{0}, yu^(-1)]*G[{yu}, yv^(-1)]*
      G[{yv^(-1)}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw] + 
     2*G[{0}, yv^(-1)]*G[{yu}, yv^(-1)]*G[{yv^(-1)}, yw]*
      G[{yv^(-1), 1/(yu*yv)}, yw] - 2*G[{0}, yw]*G[{yu}, yv^(-1)]*
      G[{yv^(-1)}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw] - 
     6*G[{1}, yu^(-1)]*G[{yu}, yv^(-1)]*G[{yv^(-1)}, yw]*
      G[{yv^(-1), 1/(yu*yv)}, yw] + 4*G[{1}, yw]*G[{yu}, yv^(-1)]*
      G[{yv^(-1)}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw] + 
     G[{yu}, yv^(-1)]^2*G[{yv^(-1)}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw] - 
     3*G[{1}, yu^(-1)]*G[{yv^(-1)}, yw]^2*G[{yv^(-1), 1/(yu*yv)}, yw] - 
     3*G[{1}, yw]*G[{yv^(-1)}, yw]^2*G[{yv^(-1), 1/(yu*yv)}, yw] + 
     3*G[{yu}, yv^(-1)]*G[{yv^(-1)}, yw]^2*G[{yv^(-1), 1/(yu*yv)}, yw] + 
     G[{yv^(-1)}, yw]^3*G[{yv^(-1), 1/(yu*yv)}, yw] + 
     (2*Pi^2*G[{1/(yu*yv)}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw])/3 - 
     6*G[{0}, yu^(-1)]*G[{1}, yv^(-1)]*G[{1/(yu*yv)}, yw]*
      G[{yv^(-1), 1/(yu*yv)}, yw] - 6*G[{0}, yv^(-1)]*G[{1}, yv^(-1)]*
      G[{1/(yu*yv)}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw] + 
     6*G[{0}, yw]*G[{1}, yv^(-1)]*G[{1/(yu*yv)}, yw]*
      G[{yv^(-1), 1/(yu*yv)}, yw] + 4*G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*
      G[{1/(yu*yv)}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw] + 
     4*G[{1}, yv^(-1)]^2*G[{1/(yu*yv)}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw] - 
     2*G[{0}, yu^(-1)]*G[{1}, yw]*G[{1/(yu*yv)}, yw]*
      G[{yv^(-1), 1/(yu*yv)}, yw] - 2*G[{0}, yv^(-1)]*G[{1}, yw]*
      G[{1/(yu*yv)}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw] + 
     2*G[{0}, yw]*G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw] + 
     4*G[{1}, yu^(-1)]*G[{1}, yw]*G[{1/(yu*yv)}, yw]*
      G[{yv^(-1), 1/(yu*yv)}, yw] + 2*G[{0}, yu^(-1)]*G[{yu^(-1)}, yw]*
      G[{1/(yu*yv)}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw] + 
     2*G[{0}, yv^(-1)]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*
      G[{yv^(-1), 1/(yu*yv)}, yw] - 2*G[{0}, yw]*G[{yu^(-1)}, yw]*
      G[{1/(yu*yv)}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw] - 
     4*G[{1}, yu^(-1)]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*
      G[{yv^(-1), 1/(yu*yv)}, yw] - 4*G[{1}, yv^(-1)]*G[{yu^(-1)}, yw]*
      G[{1/(yu*yv)}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw] - 
     4*G[{1}, yw]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*
      G[{yv^(-1), 1/(yu*yv)}, yw] + 2*G[{yu^(-1)}, yw]^2*G[{1/(yu*yv)}, yw]*
      G[{yv^(-1), 1/(yu*yv)}, yw] + 6*G[{0}, yu^(-1)]*G[{yu}, yv^(-1)]*
      G[{1/(yu*yv)}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw] + 
     6*G[{0}, yv^(-1)]*G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw]*
      G[{yv^(-1), 1/(yu*yv)}, yw] - 6*G[{0}, yw]*G[{yu}, yv^(-1)]*
      G[{1/(yu*yv)}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw] - 
     4*G[{1}, yu^(-1)]*G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw]*
      G[{yv^(-1), 1/(yu*yv)}, yw] - 4*G[{1}, yv^(-1)]*G[{yu}, yv^(-1)]*
      G[{1/(yu*yv)}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw] + 
     4*G[{yu^(-1)}, yw]*G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw]*
      G[{yv^(-1), 1/(yu*yv)}, yw] - 2*G[{yu}, yv^(-1)]^2*G[{1/(yu*yv)}, yw]*
      G[{yv^(-1), 1/(yu*yv)}, yw] - 4*G[{0}, yu^(-1)]*G[{yv^(-1)}, yw]*
      G[{1/(yu*yv)}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw] - 
     4*G[{0}, yv^(-1)]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*
      G[{yv^(-1), 1/(yu*yv)}, yw] + 4*G[{0}, yw]*G[{yv^(-1)}, yw]*
      G[{1/(yu*yv)}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw] + 
     8*G[{1}, yu^(-1)]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*
      G[{yv^(-1), 1/(yu*yv)}, yw] - 4*G[{1}, yv^(-1)]*G[{yv^(-1)}, yw]*
      G[{1/(yu*yv)}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw] - 
     4*G[{1}, yw]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*
      G[{yv^(-1), 1/(yu*yv)}, yw] + 4*G[{yu^(-1)}, yw]*G[{yv^(-1)}, yw]*
      G[{1/(yu*yv)}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw] + 
     4*G[{yu}, yv^(-1)]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*
      G[{yv^(-1), 1/(yu*yv)}, yw] - 4*G[{yv^(-1)}, yw]^2*G[{1/(yu*yv)}, yw]*
      G[{yv^(-1), 1/(yu*yv)}, yw] + 4*G[{0}, yu^(-1)]*G[{1/(yu*yv)}, yw]^2*
      G[{yv^(-1), 1/(yu*yv)}, yw] + 4*G[{0}, yv^(-1)]*G[{1/(yu*yv)}, yw]^2*
      G[{yv^(-1), 1/(yu*yv)}, yw] - 4*G[{0}, yw]*G[{1/(yu*yv)}, yw]^2*
      G[{yv^(-1), 1/(yu*yv)}, yw] - 5*G[{1}, yu^(-1)]*G[{1/(yu*yv)}, yw]^2*
      G[{yv^(-1), 1/(yu*yv)}, yw] + 3*G[{1}, yw]*G[{1/(yu*yv)}, yw]^2*
      G[{yv^(-1), 1/(yu*yv)}, yw] - 3*G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw]^2*
      G[{yv^(-1), 1/(yu*yv)}, yw] + 5*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2*
      G[{yv^(-1), 1/(yu*yv)}, yw] - 4*G[{1}, yv^(-1)]*G[{0, 1}, yu^(-1)]*
      G[{yv^(-1), 1/(yu*yv)}, yw] + 2*G[{1}, yw]*G[{0, 1}, yu^(-1)]*
      G[{yv^(-1), 1/(yu*yv)}, yw] - 2*G[{yu^(-1)}, yw]*G[{0, 1}, yu^(-1)]*
      G[{yv^(-1), 1/(yu*yv)}, yw] + 4*G[{yu}, yv^(-1)]*G[{0, 1}, yu^(-1)]*
      G[{yv^(-1), 1/(yu*yv)}, yw] + 6*G[{yv^(-1)}, yw]*G[{0, 1}, yu^(-1)]*
      G[{yv^(-1), 1/(yu*yv)}, yw] - 4*G[{1/(yu*yv)}, yw]*G[{0, 1}, yu^(-1)]*
      G[{yv^(-1), 1/(yu*yv)}, yw] - 2*G[{1}, yv^(-1)]*G[{0, 1}, yv^(-1)]*
      G[{yv^(-1), 1/(yu*yv)}, yw] - 2*G[{1}, yw]*G[{0, 1}, yv^(-1)]*
      G[{yv^(-1), 1/(yu*yv)}, yw] + 2*G[{yu^(-1)}, yw]*G[{0, 1}, yv^(-1)]*
      G[{yv^(-1), 1/(yu*yv)}, yw] + 2*G[{yu}, yv^(-1)]*G[{0, 1}, yv^(-1)]*
      G[{yv^(-1), 1/(yu*yv)}, yw] + 2*G[{1}, yv^(-1)]*G[{0, 1}, yw]*
      G[{yv^(-1), 1/(yu*yv)}, yw] + 2*G[{1}, yw]*G[{0, 1}, yw]*
      G[{yv^(-1), 1/(yu*yv)}, yw] - 2*G[{yu^(-1)}, yw]*G[{0, 1}, yw]*
      G[{yv^(-1), 1/(yu*yv)}, yw] - 2*G[{yu}, yv^(-1)]*G[{0, 1}, yw]*
      G[{yv^(-1), 1/(yu*yv)}, yw] + 4*G[{1/(yu*yv)}, yw]*G[{0, 1}, yw]*
      G[{yv^(-1), 1/(yu*yv)}, yw] - 2*G[{1}, yv^(-1)]*G[{0, yu^(-1)}, yw]*
      G[{yv^(-1), 1/(yu*yv)}, yw] - 2*G[{1}, yw]*G[{0, yu^(-1)}, yw]*
      G[{yv^(-1), 1/(yu*yv)}, yw] + 2*G[{yu^(-1)}, yw]*G[{0, yu^(-1)}, yw]*
      G[{yv^(-1), 1/(yu*yv)}, yw] + 2*G[{yu}, yv^(-1)]*G[{0, yu^(-1)}, yw]*
      G[{yv^(-1), 1/(yu*yv)}, yw] - 4*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1)}, yw]*
      G[{yv^(-1), 1/(yu*yv)}, yw] + 2*G[{1}, yv^(-1)]*G[{0, yu}, yv^(-1)]*
      G[{yv^(-1), 1/(yu*yv)}, yw] + 2*G[{1}, yw]*G[{0, yu}, yv^(-1)]*
      G[{yv^(-1), 1/(yu*yv)}, yw] - 2*G[{yu^(-1)}, yw]*G[{0, yu}, yv^(-1)]*
      G[{yv^(-1), 1/(yu*yv)}, yw] - 2*G[{yu}, yv^(-1)]*G[{0, yu}, yv^(-1)]*
      G[{yv^(-1), 1/(yu*yv)}, yw] - 2*G[{1}, yv^(-1)]*G[{0, yv^(-1)}, yw]*
      G[{yv^(-1), 1/(yu*yv)}, yw] - 2*G[{1}, yw]*G[{0, yv^(-1)}, yw]*
      G[{yv^(-1), 1/(yu*yv)}, yw] + 2*G[{yu^(-1)}, yw]*G[{0, yv^(-1)}, yw]*
      G[{yv^(-1), 1/(yu*yv)}, yw] + 2*G[{yu}, yv^(-1)]*G[{0, yv^(-1)}, yw]*
      G[{yv^(-1), 1/(yu*yv)}, yw] - 4*G[{1/(yu*yv)}, yw]*G[{0, yv^(-1)}, yw]*
      G[{yv^(-1), 1/(yu*yv)}, yw] + 2*G[{1}, yv^(-1)]*G[{0, 1/(yu*yv)}, yw]*
      G[{yv^(-1), 1/(yu*yv)}, yw] + 2*G[{1}, yw]*G[{0, 1/(yu*yv)}, yw]*
      G[{yv^(-1), 1/(yu*yv)}, yw] - 2*G[{yu^(-1)}, yw]*G[{0, 1/(yu*yv)}, yw]*
      G[{yv^(-1), 1/(yu*yv)}, yw] - 2*G[{yu}, yv^(-1)]*G[{0, 1/(yu*yv)}, yw]*
      G[{yv^(-1), 1/(yu*yv)}, yw] + 4*G[{1/(yu*yv)}, yw]*
      G[{0, 1/(yu*yv)}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw] + 
     4*G[{1}, yv^(-1)]*G[{1, yu^(-1)}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw] + 
     4*G[{1}, yw]*G[{1, yu^(-1)}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw] - 
     4*G[{yu}, yv^(-1)]*G[{1, yu^(-1)}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw] + 
     4*G[{1/(yu*yv)}, yw]*G[{1, yu^(-1)}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw] - 
     4*G[{1}, yw]*G[{1, yu}, yv^(-1)]*G[{yv^(-1), 1/(yu*yv)}, yw] + 
     4*G[{yu^(-1)}, yw]*G[{1, yu}, yv^(-1)]*G[{yv^(-1), 1/(yu*yv)}, yw] - 
     2*G[{yu}, yv^(-1)]*G[{1, yu}, yv^(-1)]*G[{yv^(-1), 1/(yu*yv)}, yw] - 
     6*G[{yv^(-1)}, yw]*G[{1, yu}, yv^(-1)]*G[{yv^(-1), 1/(yu*yv)}, yw] + 
     4*G[{1/(yu*yv)}, yw]*G[{1, yu}, yv^(-1)]*G[{yv^(-1), 1/(yu*yv)}, yw] + 
     4*G[{1}, yv^(-1)]*G[{1, yv^(-1)}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw] + 
     4*G[{1}, yw]*G[{1, yv^(-1)}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw] - 
     4*G[{yu^(-1)}, yw]*G[{1, yv^(-1)}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw] - 
     4*G[{yu}, yv^(-1)]*G[{1, yv^(-1)}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw] + 
     6*G[{yv^(-1)}, yw]*G[{1, yv^(-1)}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw] - 
     4*G[{1}, yv^(-1)]*G[{1, 1/(yu*yv)}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw] - 
     4*G[{1}, yw]*G[{1, 1/(yu*yv)}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw] + 
     4*G[{yu}, yv^(-1)]*G[{1, 1/(yu*yv)}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw] - 
     6*G[{yv^(-1)}, yw]*G[{1, 1/(yu*yv)}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw] + 
     4*G[{1/(yu*yv)}, yw]*G[{1, 1/(yu*yv)}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw] - 
     4*G[{1/(yu*yv)}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw]*
      G[{yv^(-1), 1/(yu*yv)}, yw] - 4*G[{1/(yu*yv)}, yw]*
      G[{yv^(-1), 1/(yu*yv)}, yw]^2 + (2*Pi^2*G[{0, 0, 1}, yu^(-1)])/3 + 
     2*G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*G[{0, 0, 1}, yu^(-1)] - 
     2*G[{1}, yu^(-1)]*G[{yu}, yv^(-1)]*G[{0, 0, 1}, yu^(-1)] + 
     G[{yu}, yv^(-1)]^2*G[{0, 0, 1}, yu^(-1)] - 4*G[{0}, yu^(-1)]*
      G[{yv^(-1)}, yw]*G[{0, 0, 1}, yu^(-1)] - 4*G[{0}, yv^(-1)]*
      G[{yv^(-1)}, yw]*G[{0, 0, 1}, yu^(-1)] + 4*G[{0}, yw]*G[{yv^(-1)}, yw]*
      G[{0, 0, 1}, yu^(-1)] + 6*G[{1}, yu^(-1)]*G[{yv^(-1)}, yw]*
      G[{0, 0, 1}, yu^(-1)] - 2*G[{1}, yw]*G[{yv^(-1)}, yw]*
      G[{0, 0, 1}, yu^(-1)] + 2*G[{yu}, yv^(-1)]*G[{yv^(-1)}, yw]*
      G[{0, 0, 1}, yu^(-1)] - 3*G[{yv^(-1)}, yw]^2*G[{0, 0, 1}, yu^(-1)] + 
     4*G[{0}, yu^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, 0, 1}, yu^(-1)] + 
     4*G[{0}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, 0, 1}, yu^(-1)] - 
     4*G[{0}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 0, 1}, yu^(-1)] - 
     6*G[{1}, yu^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, 0, 1}, yu^(-1)] + 
     2*G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 0, 1}, yu^(-1)] - 
     2*G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, 0, 1}, yu^(-1)] + 
     6*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 0, 1}, yu^(-1)] - 
     2*G[{0, 1}, yu^(-1)]*G[{0, 0, 1}, yu^(-1)] - 4*G[{0, yv^(-1)}, yw]*
      G[{0, 0, 1}, yu^(-1)] + 4*G[{0, 1/(yu*yv)}, yw]*G[{0, 0, 1}, yu^(-1)] - 
     2*G[{1, yu}, yv^(-1)]*G[{0, 0, 1}, yu^(-1)] + 2*G[{1, yv^(-1)}, yw]*
      G[{0, 0, 1}, yu^(-1)] - 2*G[{1, 1/(yu*yv)}, yw]*G[{0, 0, 1}, yu^(-1)] - 
     6*G[{yv^(-1), 1/(yu*yv)}, yw]*G[{0, 0, 1}, yu^(-1)] - 
     4*G[{1}, yv^(-1)]*G[{yv^(-1)}, yw]*G[{0, 0, 1}, yw] + 
     4*G[{yu}, yv^(-1)]*G[{yv^(-1)}, yw]*G[{0, 0, 1}, yw] + 
     4*G[{1}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, 0, 1}, yw] - 
     4*G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, 0, 1}, yw] + 
     4*G[{1}, yv^(-1)]*G[{yv^(-1)}, yw]*G[{0, 0, yu^(-1)}, yw] - 
     4*G[{yu}, yv^(-1)]*G[{yv^(-1)}, yw]*G[{0, 0, yu^(-1)}, yw] - 
     4*G[{1}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, 0, yu^(-1)}, yw] + 
     4*G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, 0, yu^(-1)}, yw] + 
     4*G[{1}, yv^(-1)]*G[{yv^(-1)}, yw]*G[{0, 0, yv^(-1)}, yw] - 
     4*G[{yu}, yv^(-1)]*G[{yv^(-1)}, yw]*G[{0, 0, yv^(-1)}, yw] - 
     4*G[{1}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, 0, yv^(-1)}, yw] + 
     4*G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, 0, yv^(-1)}, yw] - 
     4*G[{1}, yv^(-1)]*G[{yv^(-1)}, yw]*G[{0, 0, 1/(yu*yv)}, yw] + 
     4*G[{yu}, yv^(-1)]*G[{yv^(-1)}, yw]*G[{0, 0, 1/(yu*yv)}, yw] + 
     4*G[{1}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, 0, 1/(yu*yv)}, yw] - 
     4*G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, 0, 1/(yu*yv)}, yw] - 
     2*G[{1}, yv^(-1)]^2*G[{0, 1, 1}, yu^(-1)] + 4*G[{1}, yv^(-1)]*
      G[{yu}, yv^(-1)]*G[{0, 1, 1}, yu^(-1)] - 2*G[{yu}, yv^(-1)]^2*
      G[{0, 1, 1}, yu^(-1)] + 2*G[{yv^(-1)}, yw]^2*G[{0, 1, 1}, yu^(-1)] - 
     4*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1, 1}, yu^(-1)] + 
     2*G[{1/(yu*yv)}, yw]^2*G[{0, 1, 1}, yu^(-1)] + 
     (2*Pi^2*G[{0, 1, 1}, yv^(-1)])/3 - 4*G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*
      G[{0, 1, 1}, yv^(-1)] - 2*G[{1}, yv^(-1)]^2*G[{0, 1, 1}, yv^(-1)] + 
     4*G[{1}, yu^(-1)]*G[{yu}, yv^(-1)]*G[{0, 1, 1}, yv^(-1)] + 
     4*G[{1}, yv^(-1)]*G[{yu}, yv^(-1)]*G[{0, 1, 1}, yv^(-1)] + 
     4*G[{0}, yu^(-1)]*G[{yv^(-1)}, yw]*G[{0, 1, 1}, yv^(-1)] + 
     4*G[{0}, yv^(-1)]*G[{yv^(-1)}, yw]*G[{0, 1, 1}, yv^(-1)] - 
     4*G[{0}, yw]*G[{yv^(-1)}, yw]*G[{0, 1, 1}, yv^(-1)] + 
     4*G[{1}, yw]*G[{yv^(-1)}, yw]*G[{0, 1, 1}, yv^(-1)] - 
     4*G[{yu}, yv^(-1)]*G[{yv^(-1)}, yw]*G[{0, 1, 1}, yv^(-1)] - 
     4*G[{0}, yu^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, 1, 1}, yv^(-1)] - 
     4*G[{0}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, 1, 1}, yv^(-1)] + 
     4*G[{0}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1, 1}, yv^(-1)] - 
     4*G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1, 1}, yv^(-1)] + 
     4*G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, 1, 1}, yv^(-1)] - 
     2*G[{1/(yu*yv)}, yw]^2*G[{0, 1, 1}, yv^(-1)] - 
     4*G[{0, 1}, yu^(-1)]*G[{0, 1, 1}, yv^(-1)] + 4*G[{0, 1}, yv^(-1)]*
      G[{0, 1, 1}, yv^(-1)] + 4*G[{0, yu}, yv^(-1)]*G[{0, 1, 1}, yv^(-1)] + 
     4*G[{0, yv^(-1)}, yw]*G[{0, 1, 1}, yv^(-1)] - 4*G[{0, 1/(yu*yv)}, yw]*
      G[{0, 1, 1}, yv^(-1)] - 4*G[{1, yu}, yv^(-1)]*G[{0, 1, 1}, yv^(-1)] - 
     4*G[{1, yv^(-1)}, yw]*G[{0, 1, 1}, yv^(-1)] + 4*G[{1, 1/(yu*yv)}, yw]*
      G[{0, 1, 1}, yv^(-1)] + 4*G[{yv^(-1), 1/(yu*yv)}, yw]*
      G[{0, 1, 1}, yv^(-1)] - 4*G[{0}, yu^(-1)]*G[{yv^(-1)}, yw]*
      G[{0, 1, 1}, yw] - 4*G[{0}, yv^(-1)]*G[{yv^(-1)}, yw]*
      G[{0, 1, 1}, yw] + 4*G[{0}, yw]*G[{yv^(-1)}, yw]*G[{0, 1, 1}, yw] + 
     4*G[{1}, yu^(-1)]*G[{yv^(-1)}, yw]*G[{0, 1, 1}, yw] + 
     2*G[{1}, yv^(-1)]*G[{yv^(-1)}, yw]*G[{0, 1, 1}, yw] + 
     2*G[{yu}, yv^(-1)]*G[{yv^(-1)}, yw]*G[{0, 1, 1}, yw] + 
     4*G[{0}, yu^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, 1, 1}, yw] + 
     4*G[{0}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, 1, 1}, yw] - 
     4*G[{0}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1, 1}, yw] - 
     4*G[{1}, yu^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, 1, 1}, yw] - 
     2*G[{1}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, 1, 1}, yw] - 
     2*G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, 1, 1}, yw] + 
     4*G[{0}, yu^(-1)]*G[{yv^(-1)}, yw]*G[{0, 1, yu^(-1)}, yw] + 
     4*G[{0}, yv^(-1)]*G[{yv^(-1)}, yw]*G[{0, 1, yu^(-1)}, yw] - 
     4*G[{0}, yw]*G[{yv^(-1)}, yw]*G[{0, 1, yu^(-1)}, yw] - 
     4*G[{1}, yu^(-1)]*G[{yv^(-1)}, yw]*G[{0, 1, yu^(-1)}, yw] - 
     8*G[{1}, yv^(-1)]*G[{yv^(-1)}, yw]*G[{0, 1, yu^(-1)}, yw] + 
     4*G[{yu}, yv^(-1)]*G[{yv^(-1)}, yw]*G[{0, 1, yu^(-1)}, yw] - 
     4*G[{0}, yu^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, 1, yu^(-1)}, yw] - 
     4*G[{0}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, 1, yu^(-1)}, yw] + 
     4*G[{0}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1, yu^(-1)}, yw] + 
     4*G[{1}, yu^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, 1, yu^(-1)}, yw] + 
     8*G[{1}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, 1, yu^(-1)}, yw] - 
     4*G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, 1, yu^(-1)}, yw] - 
     (2*Pi^2*G[{0, 1, yu}, yv^(-1)])/3 + 4*G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*
      G[{0, 1, yu}, yv^(-1)] + 2*G[{1}, yv^(-1)]^2*G[{0, 1, yu}, yv^(-1)] - 
     4*G[{1}, yu^(-1)]*G[{yu}, yv^(-1)]*G[{0, 1, yu}, yv^(-1)] - 
     4*G[{1}, yv^(-1)]*G[{yu}, yv^(-1)]*G[{0, 1, yu}, yv^(-1)] - 
     4*G[{0}, yu^(-1)]*G[{yv^(-1)}, yw]*G[{0, 1, yu}, yv^(-1)] - 
     4*G[{0}, yv^(-1)]*G[{yv^(-1)}, yw]*G[{0, 1, yu}, yv^(-1)] + 
     4*G[{0}, yw]*G[{yv^(-1)}, yw]*G[{0, 1, yu}, yv^(-1)] - 
     4*G[{1}, yw]*G[{yv^(-1)}, yw]*G[{0, 1, yu}, yv^(-1)] + 
     4*G[{yu}, yv^(-1)]*G[{yv^(-1)}, yw]*G[{0, 1, yu}, yv^(-1)] + 
     4*G[{0}, yu^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, 1, yu}, yv^(-1)] + 
     4*G[{0}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, 1, yu}, yv^(-1)] - 
     4*G[{0}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1, yu}, yv^(-1)] + 
     4*G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1, yu}, yv^(-1)] - 
     4*G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, 1, yu}, yv^(-1)] + 
     2*G[{1/(yu*yv)}, yw]^2*G[{0, 1, yu}, yv^(-1)] + 
     4*G[{0, 1}, yu^(-1)]*G[{0, 1, yu}, yv^(-1)] - 4*G[{0, 1}, yv^(-1)]*
      G[{0, 1, yu}, yv^(-1)] - 4*G[{0, yu}, yv^(-1)]*G[{0, 1, yu}, yv^(-1)] - 
     4*G[{0, yv^(-1)}, yw]*G[{0, 1, yu}, yv^(-1)] + 
     4*G[{0, 1/(yu*yv)}, yw]*G[{0, 1, yu}, yv^(-1)] + 
     4*G[{1, yu}, yv^(-1)]*G[{0, 1, yu}, yv^(-1)] + 
     4*G[{1, yv^(-1)}, yw]*G[{0, 1, yu}, yv^(-1)] - 
     4*G[{1, 1/(yu*yv)}, yw]*G[{0, 1, yu}, yv^(-1)] - 
     4*G[{yv^(-1), 1/(yu*yv)}, yw]*G[{0, 1, yu}, yv^(-1)] - 
     (Pi^2*G[{0, 1, yv^(-1)}, yw])/3 + 2*G[{0}, yu^(-1)]*G[{1}, yv^(-1)]*
      G[{0, 1, yv^(-1)}, yw] + 2*G[{0}, yv^(-1)]*G[{1}, yv^(-1)]*
      G[{0, 1, yv^(-1)}, yw] - 2*G[{0}, yw]*G[{1}, yv^(-1)]*
      G[{0, 1, yv^(-1)}, yw] - 2*G[{1}, yv^(-1)]^2*G[{0, 1, yv^(-1)}, yw] - 
     2*G[{0}, yu^(-1)]*G[{yu}, yv^(-1)]*G[{0, 1, yv^(-1)}, yw] - 
     2*G[{0}, yv^(-1)]*G[{yu}, yv^(-1)]*G[{0, 1, yv^(-1)}, yw] + 
     2*G[{0}, yw]*G[{yu}, yv^(-1)]*G[{0, 1, yv^(-1)}, yw] + 
     4*G[{1}, yv^(-1)]*G[{yu}, yv^(-1)]*G[{0, 1, yv^(-1)}, yw] + 
     2*G[{0}, yu^(-1)]*G[{yv^(-1)}, yw]*G[{0, 1, yv^(-1)}, yw] + 
     2*G[{0}, yv^(-1)]*G[{yv^(-1)}, yw]*G[{0, 1, yv^(-1)}, yw] - 
     2*G[{0}, yw]*G[{yv^(-1)}, yw]*G[{0, 1, yv^(-1)}, yw] - 
     4*G[{1}, yu^(-1)]*G[{yv^(-1)}, yw]*G[{0, 1, yv^(-1)}, yw] - 
     4*G[{1}, yv^(-1)]*G[{yv^(-1)}, yw]*G[{0, 1, yv^(-1)}, yw] + 
     4*G[{yu}, yv^(-1)]*G[{yv^(-1)}, yw]*G[{0, 1, yv^(-1)}, yw] - 
     2*G[{0}, yu^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, 1, yv^(-1)}, yw] - 
     2*G[{0}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, 1, yv^(-1)}, yw] + 
     2*G[{0}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1, yv^(-1)}, yw] + 
     4*G[{1}, yu^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, 1, yv^(-1)}, yw] + 
     4*G[{1}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, 1, yv^(-1)}, yw] - 
     4*G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, 1, yv^(-1)}, yw] + 
     2*G[{0, 1}, yu^(-1)]*G[{0, 1, yv^(-1)}, yw] - 2*G[{0, 1}, yv^(-1)]*
      G[{0, 1, yv^(-1)}, yw] + 2*G[{0, 1}, yw]*G[{0, 1, yv^(-1)}, yw] + 
     2*G[{0, yu}, yv^(-1)]*G[{0, 1, yv^(-1)}, yw] - 
     4*G[{1, yu}, yv^(-1)]*G[{0, 1, yv^(-1)}, yw] + 
     (Pi^2*G[{0, 1, 1/(yu*yv)}, yw])/3 - 2*G[{0}, yu^(-1)]*G[{1}, yv^(-1)]*
      G[{0, 1, 1/(yu*yv)}, yw] - 2*G[{0}, yv^(-1)]*G[{1}, yv^(-1)]*
      G[{0, 1, 1/(yu*yv)}, yw] + 2*G[{0}, yw]*G[{1}, yv^(-1)]*
      G[{0, 1, 1/(yu*yv)}, yw] + 2*G[{1}, yv^(-1)]^2*
      G[{0, 1, 1/(yu*yv)}, yw] + 2*G[{0}, yu^(-1)]*G[{yu}, yv^(-1)]*
      G[{0, 1, 1/(yu*yv)}, yw] + 2*G[{0}, yv^(-1)]*G[{yu}, yv^(-1)]*
      G[{0, 1, 1/(yu*yv)}, yw] - 2*G[{0}, yw]*G[{yu}, yv^(-1)]*
      G[{0, 1, 1/(yu*yv)}, yw] - 4*G[{1}, yv^(-1)]*G[{yu}, yv^(-1)]*
      G[{0, 1, 1/(yu*yv)}, yw] - 2*G[{0}, yu^(-1)]*G[{yv^(-1)}, yw]*
      G[{0, 1, 1/(yu*yv)}, yw] - 2*G[{0}, yv^(-1)]*G[{yv^(-1)}, yw]*
      G[{0, 1, 1/(yu*yv)}, yw] + 2*G[{0}, yw]*G[{yv^(-1)}, yw]*
      G[{0, 1, 1/(yu*yv)}, yw] + 4*G[{1}, yu^(-1)]*G[{yv^(-1)}, yw]*
      G[{0, 1, 1/(yu*yv)}, yw] + 2*G[{1}, yv^(-1)]*G[{yv^(-1)}, yw]*
      G[{0, 1, 1/(yu*yv)}, yw] - 2*G[{yu}, yv^(-1)]*G[{yv^(-1)}, yw]*
      G[{0, 1, 1/(yu*yv)}, yw] + 2*G[{0}, yu^(-1)]*G[{1/(yu*yv)}, yw]*
      G[{0, 1, 1/(yu*yv)}, yw] + 2*G[{0}, yv^(-1)]*G[{1/(yu*yv)}, yw]*
      G[{0, 1, 1/(yu*yv)}, yw] - 2*G[{0}, yw]*G[{1/(yu*yv)}, yw]*
      G[{0, 1, 1/(yu*yv)}, yw] - 4*G[{1}, yu^(-1)]*G[{1/(yu*yv)}, yw]*
      G[{0, 1, 1/(yu*yv)}, yw] - 2*G[{1}, yv^(-1)]*G[{1/(yu*yv)}, yw]*
      G[{0, 1, 1/(yu*yv)}, yw] + 2*G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw]*
      G[{0, 1, 1/(yu*yv)}, yw] - 2*G[{0, 1}, yu^(-1)]*
      G[{0, 1, 1/(yu*yv)}, yw] + 2*G[{0, 1}, yv^(-1)]*
      G[{0, 1, 1/(yu*yv)}, yw] - 2*G[{0, 1}, yw]*G[{0, 1, 1/(yu*yv)}, yw] - 
     2*G[{0, yu}, yv^(-1)]*G[{0, 1, 1/(yu*yv)}, yw] + 
     2*G[{0, yv^(-1)}, yw]*G[{0, 1, 1/(yu*yv)}, yw] + 
     4*G[{1, yu}, yv^(-1)]*G[{0, 1, 1/(yu*yv)}, yw] + 
     4*G[{0}, yu^(-1)]*G[{yv^(-1)}, yw]*G[{0, yu^(-1), 1}, yw] + 
     4*G[{0}, yv^(-1)]*G[{yv^(-1)}, yw]*G[{0, yu^(-1), 1}, yw] - 
     4*G[{0}, yw]*G[{yv^(-1)}, yw]*G[{0, yu^(-1), 1}, yw] - 
     4*G[{1}, yu^(-1)]*G[{yv^(-1)}, yw]*G[{0, yu^(-1), 1}, yw] - 
     2*G[{1}, yv^(-1)]*G[{yv^(-1)}, yw]*G[{0, yu^(-1), 1}, yw] - 
     2*G[{yu}, yv^(-1)]*G[{yv^(-1)}, yw]*G[{0, yu^(-1), 1}, yw] - 
     4*G[{0}, yu^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1), 1}, yw] - 
     4*G[{0}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1), 1}, yw] + 
     4*G[{0}, yw]*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1), 1}, yw] + 
     4*G[{1}, yu^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1), 1}, yw] + 
     2*G[{1}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1), 1}, yw] + 
     2*G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1), 1}, yw] - 
     4*G[{0}, yu^(-1)]*G[{yv^(-1)}, yw]*G[{0, yu^(-1), yu^(-1)}, yw] - 
     4*G[{0}, yv^(-1)]*G[{yv^(-1)}, yw]*G[{0, yu^(-1), yu^(-1)}, yw] + 
     4*G[{0}, yw]*G[{yv^(-1)}, yw]*G[{0, yu^(-1), yu^(-1)}, yw] + 
     4*G[{1}, yu^(-1)]*G[{yv^(-1)}, yw]*G[{0, yu^(-1), yu^(-1)}, yw] + 
     8*G[{1}, yv^(-1)]*G[{yv^(-1)}, yw]*G[{0, yu^(-1), yu^(-1)}, yw] - 
     4*G[{yu}, yv^(-1)]*G[{yv^(-1)}, yw]*G[{0, yu^(-1), yu^(-1)}, yw] + 
     4*G[{0}, yu^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1), yu^(-1)}, yw] + 
     4*G[{0}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1), yu^(-1)}, yw] - 
     4*G[{0}, yw]*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1), yu^(-1)}, yw] - 
     4*G[{1}, yu^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1), yu^(-1)}, yw] - 
     8*G[{1}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1), yu^(-1)}, yw] + 
     4*G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1), yu^(-1)}, yw] + 
     (Pi^2*G[{0, yu^(-1), yv^(-1)}, yw])/3 - 2*G[{0}, yu^(-1)]*
      G[{1}, yv^(-1)]*G[{0, yu^(-1), yv^(-1)}, yw] - 
     2*G[{0}, yv^(-1)]*G[{1}, yv^(-1)]*G[{0, yu^(-1), yv^(-1)}, yw] + 
     2*G[{0}, yw]*G[{1}, yv^(-1)]*G[{0, yu^(-1), yv^(-1)}, yw] + 
     2*G[{1}, yv^(-1)]^2*G[{0, yu^(-1), yv^(-1)}, yw] + 
     2*G[{0}, yu^(-1)]*G[{yu}, yv^(-1)]*G[{0, yu^(-1), yv^(-1)}, yw] + 
     2*G[{0}, yv^(-1)]*G[{yu}, yv^(-1)]*G[{0, yu^(-1), yv^(-1)}, yw] - 
     2*G[{0}, yw]*G[{yu}, yv^(-1)]*G[{0, yu^(-1), yv^(-1)}, yw] - 
     4*G[{1}, yv^(-1)]*G[{yu}, yv^(-1)]*G[{0, yu^(-1), yv^(-1)}, yw] - 
     2*G[{0}, yu^(-1)]*G[{yv^(-1)}, yw]*G[{0, yu^(-1), yv^(-1)}, yw] - 
     2*G[{0}, yv^(-1)]*G[{yv^(-1)}, yw]*G[{0, yu^(-1), yv^(-1)}, yw] + 
     2*G[{0}, yw]*G[{yv^(-1)}, yw]*G[{0, yu^(-1), yv^(-1)}, yw] + 
     4*G[{1}, yu^(-1)]*G[{yv^(-1)}, yw]*G[{0, yu^(-1), yv^(-1)}, yw] + 
     4*G[{1}, yv^(-1)]*G[{yv^(-1)}, yw]*G[{0, yu^(-1), yv^(-1)}, yw] - 
     4*G[{yu}, yv^(-1)]*G[{yv^(-1)}, yw]*G[{0, yu^(-1), yv^(-1)}, yw] + 
     2*G[{0}, yu^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1), yv^(-1)}, yw] + 
     2*G[{0}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1), yv^(-1)}, yw] - 
     2*G[{0}, yw]*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1), yv^(-1)}, yw] - 
     4*G[{1}, yu^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1), yv^(-1)}, yw] - 
     4*G[{1}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1), yv^(-1)}, yw] + 
     4*G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1), yv^(-1)}, yw] - 
     2*G[{0, 1}, yu^(-1)]*G[{0, yu^(-1), yv^(-1)}, yw] + 
     2*G[{0, 1}, yv^(-1)]*G[{0, yu^(-1), yv^(-1)}, yw] - 
     2*G[{0, 1}, yw]*G[{0, yu^(-1), yv^(-1)}, yw] + 
     2*G[{0, yu^(-1)}, yw]*G[{0, yu^(-1), yv^(-1)}, yw] - 
     2*G[{0, yu}, yv^(-1)]*G[{0, yu^(-1), yv^(-1)}, yw] + 
     4*G[{1, yu}, yv^(-1)]*G[{0, yu^(-1), yv^(-1)}, yw] - 
     (Pi^2*G[{0, yu^(-1), 1/(yu*yv)}, yw])/3 + 2*G[{0}, yu^(-1)]*
      G[{1}, yv^(-1)]*G[{0, yu^(-1), 1/(yu*yv)}, yw] + 
     2*G[{0}, yv^(-1)]*G[{1}, yv^(-1)]*G[{0, yu^(-1), 1/(yu*yv)}, yw] - 
     2*G[{0}, yw]*G[{1}, yv^(-1)]*G[{0, yu^(-1), 1/(yu*yv)}, yw] - 
     2*G[{1}, yv^(-1)]^2*G[{0, yu^(-1), 1/(yu*yv)}, yw] - 
     2*G[{0}, yu^(-1)]*G[{yu}, yv^(-1)]*G[{0, yu^(-1), 1/(yu*yv)}, yw] - 
     2*G[{0}, yv^(-1)]*G[{yu}, yv^(-1)]*G[{0, yu^(-1), 1/(yu*yv)}, yw] + 
     2*G[{0}, yw]*G[{yu}, yv^(-1)]*G[{0, yu^(-1), 1/(yu*yv)}, yw] + 
     4*G[{1}, yv^(-1)]*G[{yu}, yv^(-1)]*G[{0, yu^(-1), 1/(yu*yv)}, yw] + 
     2*G[{0}, yu^(-1)]*G[{yv^(-1)}, yw]*G[{0, yu^(-1), 1/(yu*yv)}, yw] + 
     2*G[{0}, yv^(-1)]*G[{yv^(-1)}, yw]*G[{0, yu^(-1), 1/(yu*yv)}, yw] - 
     2*G[{0}, yw]*G[{yv^(-1)}, yw]*G[{0, yu^(-1), 1/(yu*yv)}, yw] - 
     4*G[{1}, yu^(-1)]*G[{yv^(-1)}, yw]*G[{0, yu^(-1), 1/(yu*yv)}, yw] - 
     2*G[{1}, yv^(-1)]*G[{yv^(-1)}, yw]*G[{0, yu^(-1), 1/(yu*yv)}, yw] + 
     2*G[{yu}, yv^(-1)]*G[{yv^(-1)}, yw]*G[{0, yu^(-1), 1/(yu*yv)}, yw] - 
     2*G[{0}, yu^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1), 1/(yu*yv)}, yw] - 
     2*G[{0}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1), 1/(yu*yv)}, yw] + 
     2*G[{0}, yw]*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1), 1/(yu*yv)}, yw] + 
     4*G[{1}, yu^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1), 1/(yu*yv)}, yw] + 
     2*G[{1}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1), 1/(yu*yv)}, yw] - 
     2*G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1), 1/(yu*yv)}, yw] + 
     2*G[{0, 1}, yu^(-1)]*G[{0, yu^(-1), 1/(yu*yv)}, yw] - 
     2*G[{0, 1}, yv^(-1)]*G[{0, yu^(-1), 1/(yu*yv)}, yw] + 
     2*G[{0, 1}, yw]*G[{0, yu^(-1), 1/(yu*yv)}, yw] - 
     2*G[{0, yu^(-1)}, yw]*G[{0, yu^(-1), 1/(yu*yv)}, yw] + 
     2*G[{0, yu}, yv^(-1)]*G[{0, yu^(-1), 1/(yu*yv)}, yw] - 
     2*G[{0, yv^(-1)}, yw]*G[{0, yu^(-1), 1/(yu*yv)}, yw] - 
     4*G[{1, yu}, yv^(-1)]*G[{0, yu^(-1), 1/(yu*yv)}, yw] - 
     (2*Pi^2*G[{0, yu, 1}, yv^(-1)])/3 + 4*G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*
      G[{0, yu, 1}, yv^(-1)] + 2*G[{1}, yv^(-1)]^2*G[{0, yu, 1}, yv^(-1)] - 
     4*G[{1}, yu^(-1)]*G[{yu}, yv^(-1)]*G[{0, yu, 1}, yv^(-1)] - 
     4*G[{1}, yv^(-1)]*G[{yu}, yv^(-1)]*G[{0, yu, 1}, yv^(-1)] - 
     4*G[{0}, yu^(-1)]*G[{yv^(-1)}, yw]*G[{0, yu, 1}, yv^(-1)] - 
     4*G[{0}, yv^(-1)]*G[{yv^(-1)}, yw]*G[{0, yu, 1}, yv^(-1)] + 
     4*G[{0}, yw]*G[{yv^(-1)}, yw]*G[{0, yu, 1}, yv^(-1)] - 
     4*G[{1}, yw]*G[{yv^(-1)}, yw]*G[{0, yu, 1}, yv^(-1)] + 
     4*G[{yu}, yv^(-1)]*G[{yv^(-1)}, yw]*G[{0, yu, 1}, yv^(-1)] + 
     4*G[{0}, yu^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, yu, 1}, yv^(-1)] + 
     4*G[{0}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, yu, 1}, yv^(-1)] - 
     4*G[{0}, yw]*G[{1/(yu*yv)}, yw]*G[{0, yu, 1}, yv^(-1)] + 
     4*G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{0, yu, 1}, yv^(-1)] - 
     4*G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, yu, 1}, yv^(-1)] + 
     2*G[{1/(yu*yv)}, yw]^2*G[{0, yu, 1}, yv^(-1)] + 
     4*G[{0, 1}, yu^(-1)]*G[{0, yu, 1}, yv^(-1)] - 4*G[{0, 1}, yv^(-1)]*
      G[{0, yu, 1}, yv^(-1)] + 4*G[{0, yu}, yv^(-1)]*G[{0, yu, 1}, yv^(-1)] - 
     4*G[{0, yv^(-1)}, yw]*G[{0, yu, 1}, yv^(-1)] + 
     4*G[{0, 1/(yu*yv)}, yw]*G[{0, yu, 1}, yv^(-1)] + 
     4*G[{1, yu}, yv^(-1)]*G[{0, yu, 1}, yv^(-1)] + 
     4*G[{1, yv^(-1)}, yw]*G[{0, yu, 1}, yv^(-1)] - 
     4*G[{1, 1/(yu*yv)}, yw]*G[{0, yu, 1}, yv^(-1)] - 
     4*G[{yv^(-1), 1/(yu*yv)}, yw]*G[{0, yu, 1}, yv^(-1)] + 
     (2*Pi^2*G[{0, yu, yu}, yv^(-1)])/3 - 4*G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*
      G[{0, yu, yu}, yv^(-1)] - 2*G[{1}, yv^(-1)]^2*G[{0, yu, yu}, yv^(-1)] + 
     4*G[{1}, yu^(-1)]*G[{yu}, yv^(-1)]*G[{0, yu, yu}, yv^(-1)] + 
     4*G[{1}, yv^(-1)]*G[{yu}, yv^(-1)]*G[{0, yu, yu}, yv^(-1)] + 
     4*G[{0}, yu^(-1)]*G[{yv^(-1)}, yw]*G[{0, yu, yu}, yv^(-1)] + 
     4*G[{0}, yv^(-1)]*G[{yv^(-1)}, yw]*G[{0, yu, yu}, yv^(-1)] - 
     4*G[{0}, yw]*G[{yv^(-1)}, yw]*G[{0, yu, yu}, yv^(-1)] + 
     4*G[{1}, yw]*G[{yv^(-1)}, yw]*G[{0, yu, yu}, yv^(-1)] - 
     4*G[{yu}, yv^(-1)]*G[{yv^(-1)}, yw]*G[{0, yu, yu}, yv^(-1)] - 
     4*G[{0}, yu^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, yu, yu}, yv^(-1)] - 
     4*G[{0}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, yu, yu}, yv^(-1)] + 
     4*G[{0}, yw]*G[{1/(yu*yv)}, yw]*G[{0, yu, yu}, yv^(-1)] - 
     4*G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{0, yu, yu}, yv^(-1)] + 
     4*G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, yu, yu}, yv^(-1)] - 
     2*G[{1/(yu*yv)}, yw]^2*G[{0, yu, yu}, yv^(-1)] - 
     4*G[{0, 1}, yu^(-1)]*G[{0, yu, yu}, yv^(-1)] + 
     4*G[{0, 1}, yv^(-1)]*G[{0, yu, yu}, yv^(-1)] - 
     4*G[{0, yu}, yv^(-1)]*G[{0, yu, yu}, yv^(-1)] + 
     4*G[{0, yv^(-1)}, yw]*G[{0, yu, yu}, yv^(-1)] - 
     4*G[{0, 1/(yu*yv)}, yw]*G[{0, yu, yu}, yv^(-1)] - 
     4*G[{1, yu}, yv^(-1)]*G[{0, yu, yu}, yv^(-1)] - 
     4*G[{1, yv^(-1)}, yw]*G[{0, yu, yu}, yv^(-1)] + 
     4*G[{1, 1/(yu*yv)}, yw]*G[{0, yu, yu}, yv^(-1)] + 
     4*G[{yv^(-1), 1/(yu*yv)}, yw]*G[{0, yu, yu}, yv^(-1)] - 
     (Pi^2*G[{0, yv^(-1), 1}, yw])/3 + 2*G[{0}, yu^(-1)]*G[{1}, yv^(-1)]*
      G[{0, yv^(-1), 1}, yw] + 2*G[{0}, yv^(-1)]*G[{1}, yv^(-1)]*
      G[{0, yv^(-1), 1}, yw] - 2*G[{0}, yw]*G[{1}, yv^(-1)]*
      G[{0, yv^(-1), 1}, yw] - 2*G[{1}, yv^(-1)]^2*G[{0, yv^(-1), 1}, yw] - 
     2*G[{0}, yu^(-1)]*G[{yu}, yv^(-1)]*G[{0, yv^(-1), 1}, yw] - 
     2*G[{0}, yv^(-1)]*G[{yu}, yv^(-1)]*G[{0, yv^(-1), 1}, yw] + 
     2*G[{0}, yw]*G[{yu}, yv^(-1)]*G[{0, yv^(-1), 1}, yw] + 
     4*G[{1}, yv^(-1)]*G[{yu}, yv^(-1)]*G[{0, yv^(-1), 1}, yw] + 
     2*G[{0}, yu^(-1)]*G[{yv^(-1)}, yw]*G[{0, yv^(-1), 1}, yw] + 
     2*G[{0}, yv^(-1)]*G[{yv^(-1)}, yw]*G[{0, yv^(-1), 1}, yw] - 
     2*G[{0}, yw]*G[{yv^(-1)}, yw]*G[{0, yv^(-1), 1}, yw] - 
     4*G[{1}, yu^(-1)]*G[{yv^(-1)}, yw]*G[{0, yv^(-1), 1}, yw] - 
     2*G[{1}, yv^(-1)]*G[{yv^(-1)}, yw]*G[{0, yv^(-1), 1}, yw] + 
     2*G[{yu}, yv^(-1)]*G[{yv^(-1)}, yw]*G[{0, yv^(-1), 1}, yw] - 
     2*G[{0}, yu^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, yv^(-1), 1}, yw] - 
     2*G[{0}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, yv^(-1), 1}, yw] + 
     2*G[{0}, yw]*G[{1/(yu*yv)}, yw]*G[{0, yv^(-1), 1}, yw] + 
     4*G[{1}, yu^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, yv^(-1), 1}, yw] + 
     2*G[{1}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, yv^(-1), 1}, yw] - 
     2*G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, yv^(-1), 1}, yw] + 
     2*G[{0, 1}, yu^(-1)]*G[{0, yv^(-1), 1}, yw] - 2*G[{0, 1}, yv^(-1)]*
      G[{0, yv^(-1), 1}, yw] + 2*G[{0, 1}, yw]*G[{0, yv^(-1), 1}, yw] - 
     2*G[{0, yu^(-1)}, yw]*G[{0, yv^(-1), 1}, yw] + 
     2*G[{0, yu}, yv^(-1)]*G[{0, yv^(-1), 1}, yw] - 
     2*G[{0, yv^(-1)}, yw]*G[{0, yv^(-1), 1}, yw] - 
     4*G[{1, yu}, yv^(-1)]*G[{0, yv^(-1), 1}, yw] + 
     (Pi^2*G[{0, yv^(-1), yu^(-1)}, yw])/3 - 2*G[{0}, yu^(-1)]*
      G[{1}, yv^(-1)]*G[{0, yv^(-1), yu^(-1)}, yw] - 
     2*G[{0}, yv^(-1)]*G[{1}, yv^(-1)]*G[{0, yv^(-1), yu^(-1)}, yw] + 
     2*G[{0}, yw]*G[{1}, yv^(-1)]*G[{0, yv^(-1), yu^(-1)}, yw] + 
     2*G[{1}, yv^(-1)]^2*G[{0, yv^(-1), yu^(-1)}, yw] + 
     2*G[{0}, yu^(-1)]*G[{yu}, yv^(-1)]*G[{0, yv^(-1), yu^(-1)}, yw] + 
     2*G[{0}, yv^(-1)]*G[{yu}, yv^(-1)]*G[{0, yv^(-1), yu^(-1)}, yw] - 
     2*G[{0}, yw]*G[{yu}, yv^(-1)]*G[{0, yv^(-1), yu^(-1)}, yw] - 
     4*G[{1}, yv^(-1)]*G[{yu}, yv^(-1)]*G[{0, yv^(-1), yu^(-1)}, yw] - 
     2*G[{0}, yu^(-1)]*G[{yv^(-1)}, yw]*G[{0, yv^(-1), yu^(-1)}, yw] - 
     2*G[{0}, yv^(-1)]*G[{yv^(-1)}, yw]*G[{0, yv^(-1), yu^(-1)}, yw] + 
     2*G[{0}, yw]*G[{yv^(-1)}, yw]*G[{0, yv^(-1), yu^(-1)}, yw] + 
     4*G[{1}, yu^(-1)]*G[{yv^(-1)}, yw]*G[{0, yv^(-1), yu^(-1)}, yw] + 
     4*G[{1}, yv^(-1)]*G[{yv^(-1)}, yw]*G[{0, yv^(-1), yu^(-1)}, yw] - 
     4*G[{yu}, yv^(-1)]*G[{yv^(-1)}, yw]*G[{0, yv^(-1), yu^(-1)}, yw] + 
     2*G[{0}, yu^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, yv^(-1), yu^(-1)}, yw] + 
     2*G[{0}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, yv^(-1), yu^(-1)}, yw] - 
     2*G[{0}, yw]*G[{1/(yu*yv)}, yw]*G[{0, yv^(-1), yu^(-1)}, yw] - 
     4*G[{1}, yu^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, yv^(-1), yu^(-1)}, yw] - 
     4*G[{1}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, yv^(-1), yu^(-1)}, yw] + 
     4*G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, yv^(-1), yu^(-1)}, yw] - 
     2*G[{0, 1}, yu^(-1)]*G[{0, yv^(-1), yu^(-1)}, yw] + 
     2*G[{0, 1}, yv^(-1)]*G[{0, yv^(-1), yu^(-1)}, yw] - 
     2*G[{0, 1}, yw]*G[{0, yv^(-1), yu^(-1)}, yw] + 
     2*G[{0, yu^(-1)}, yw]*G[{0, yv^(-1), yu^(-1)}, yw] - 
     2*G[{0, yu}, yv^(-1)]*G[{0, yv^(-1), yu^(-1)}, yw] + 
     2*G[{0, yv^(-1)}, yw]*G[{0, yv^(-1), yu^(-1)}, yw] + 
     4*G[{1, yu}, yv^(-1)]*G[{0, yv^(-1), yu^(-1)}, yw] - 
     4*G[{0}, yu^(-1)]*G[{1}, yv^(-1)]*G[{0, yv^(-1), yv^(-1)}, yw] - 
     4*G[{0}, yv^(-1)]*G[{1}, yv^(-1)]*G[{0, yv^(-1), yv^(-1)}, yw] + 
     4*G[{0}, yw]*G[{1}, yv^(-1)]*G[{0, yv^(-1), yv^(-1)}, yw] + 
     4*G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*G[{0, yv^(-1), yv^(-1)}, yw] + 
     4*G[{1}, yv^(-1)]^2*G[{0, yv^(-1), yv^(-1)}, yw] + 
     4*G[{0}, yu^(-1)]*G[{yu}, yv^(-1)]*G[{0, yv^(-1), yv^(-1)}, yw] + 
     4*G[{0}, yv^(-1)]*G[{yu}, yv^(-1)]*G[{0, yv^(-1), yv^(-1)}, yw] - 
     4*G[{0}, yw]*G[{yu}, yv^(-1)]*G[{0, yv^(-1), yv^(-1)}, yw] - 
     4*G[{1}, yu^(-1)]*G[{yu}, yv^(-1)]*G[{0, yv^(-1), yv^(-1)}, yw] - 
     4*G[{1}, yv^(-1)]*G[{yu}, yv^(-1)]*G[{0, yv^(-1), yv^(-1)}, yw] + 
     4*G[{1}, yv^(-1)]*G[{yv^(-1)}, yw]*G[{0, yv^(-1), yv^(-1)}, yw] - 
     4*G[{yu}, yv^(-1)]*G[{yv^(-1)}, yw]*G[{0, yv^(-1), yv^(-1)}, yw] - 
     4*G[{1}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, yv^(-1), yv^(-1)}, yw] + 
     4*G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, yv^(-1), yv^(-1)}, yw] + 
     4*G[{0}, yu^(-1)]*G[{1}, yv^(-1)]*G[{0, yv^(-1), 1/(yu*yv)}, yw] + 
     4*G[{0}, yv^(-1)]*G[{1}, yv^(-1)]*G[{0, yv^(-1), 1/(yu*yv)}, yw] - 
     4*G[{0}, yw]*G[{1}, yv^(-1)]*G[{0, yv^(-1), 1/(yu*yv)}, yw] - 
     4*G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*G[{0, yv^(-1), 1/(yu*yv)}, yw] - 
     4*G[{1}, yv^(-1)]^2*G[{0, yv^(-1), 1/(yu*yv)}, yw] - 
     4*G[{0}, yu^(-1)]*G[{yu}, yv^(-1)]*G[{0, yv^(-1), 1/(yu*yv)}, yw] - 
     4*G[{0}, yv^(-1)]*G[{yu}, yv^(-1)]*G[{0, yv^(-1), 1/(yu*yv)}, yw] + 
     4*G[{0}, yw]*G[{yu}, yv^(-1)]*G[{0, yv^(-1), 1/(yu*yv)}, yw] + 
     4*G[{1}, yu^(-1)]*G[{yu}, yv^(-1)]*G[{0, yv^(-1), 1/(yu*yv)}, yw] + 
     4*G[{1}, yv^(-1)]*G[{yu}, yv^(-1)]*G[{0, yv^(-1), 1/(yu*yv)}, yw] + 
     2*G[{1}, yv^(-1)]*G[{yv^(-1)}, yw]*G[{0, yv^(-1), 1/(yu*yv)}, yw] - 
     2*G[{yu}, yv^(-1)]*G[{yv^(-1)}, yw]*G[{0, yv^(-1), 1/(yu*yv)}, yw] - 
     2*G[{1}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, yv^(-1), 1/(yu*yv)}, yw] + 
     2*G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, yv^(-1), 1/(yu*yv)}, yw] + 
     (Pi^2*G[{0, 1/(yu*yv), 1}, yw])/3 - 2*G[{0}, yu^(-1)]*G[{1}, yv^(-1)]*
      G[{0, 1/(yu*yv), 1}, yw] - 2*G[{0}, yv^(-1)]*G[{1}, yv^(-1)]*
      G[{0, 1/(yu*yv), 1}, yw] + 2*G[{0}, yw]*G[{1}, yv^(-1)]*
      G[{0, 1/(yu*yv), 1}, yw] + 2*G[{1}, yv^(-1)]^2*
      G[{0, 1/(yu*yv), 1}, yw] + 2*G[{0}, yu^(-1)]*G[{yu}, yv^(-1)]*
      G[{0, 1/(yu*yv), 1}, yw] + 2*G[{0}, yv^(-1)]*G[{yu}, yv^(-1)]*
      G[{0, 1/(yu*yv), 1}, yw] - 2*G[{0}, yw]*G[{yu}, yv^(-1)]*
      G[{0, 1/(yu*yv), 1}, yw] - 4*G[{1}, yv^(-1)]*G[{yu}, yv^(-1)]*
      G[{0, 1/(yu*yv), 1}, yw] - 2*G[{0}, yu^(-1)]*G[{yv^(-1)}, yw]*
      G[{0, 1/(yu*yv), 1}, yw] - 2*G[{0}, yv^(-1)]*G[{yv^(-1)}, yw]*
      G[{0, 1/(yu*yv), 1}, yw] + 2*G[{0}, yw]*G[{yv^(-1)}, yw]*
      G[{0, 1/(yu*yv), 1}, yw] + 4*G[{1}, yu^(-1)]*G[{yv^(-1)}, yw]*
      G[{0, 1/(yu*yv), 1}, yw] + 2*G[{1}, yv^(-1)]*G[{yv^(-1)}, yw]*
      G[{0, 1/(yu*yv), 1}, yw] - 2*G[{yu}, yv^(-1)]*G[{yv^(-1)}, yw]*
      G[{0, 1/(yu*yv), 1}, yw] + 2*G[{0}, yu^(-1)]*G[{1/(yu*yv)}, yw]*
      G[{0, 1/(yu*yv), 1}, yw] + 2*G[{0}, yv^(-1)]*G[{1/(yu*yv)}, yw]*
      G[{0, 1/(yu*yv), 1}, yw] - 2*G[{0}, yw]*G[{1/(yu*yv)}, yw]*
      G[{0, 1/(yu*yv), 1}, yw] - 4*G[{1}, yu^(-1)]*G[{1/(yu*yv)}, yw]*
      G[{0, 1/(yu*yv), 1}, yw] - 2*G[{1}, yv^(-1)]*G[{1/(yu*yv)}, yw]*
      G[{0, 1/(yu*yv), 1}, yw] + 2*G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw]*
      G[{0, 1/(yu*yv), 1}, yw] - 2*G[{0, 1}, yu^(-1)]*
      G[{0, 1/(yu*yv), 1}, yw] + 2*G[{0, 1}, yv^(-1)]*
      G[{0, 1/(yu*yv), 1}, yw] - 2*G[{0, 1}, yw]*G[{0, 1/(yu*yv), 1}, yw] + 
     2*G[{0, yu^(-1)}, yw]*G[{0, 1/(yu*yv), 1}, yw] - 
     2*G[{0, yu}, yv^(-1)]*G[{0, 1/(yu*yv), 1}, yw] + 
     2*G[{0, yv^(-1)}, yw]*G[{0, 1/(yu*yv), 1}, yw] - 
     2*G[{0, 1/(yu*yv)}, yw]*G[{0, 1/(yu*yv), 1}, yw] + 
     4*G[{1, yu}, yv^(-1)]*G[{0, 1/(yu*yv), 1}, yw] - 
     (Pi^2*G[{0, 1/(yu*yv), yu^(-1)}, yw])/3 + 2*G[{0}, yu^(-1)]*
      G[{1}, yv^(-1)]*G[{0, 1/(yu*yv), yu^(-1)}, yw] + 
     2*G[{0}, yv^(-1)]*G[{1}, yv^(-1)]*G[{0, 1/(yu*yv), yu^(-1)}, yw] - 
     2*G[{0}, yw]*G[{1}, yv^(-1)]*G[{0, 1/(yu*yv), yu^(-1)}, yw] - 
     2*G[{1}, yv^(-1)]^2*G[{0, 1/(yu*yv), yu^(-1)}, yw] - 
     2*G[{0}, yu^(-1)]*G[{yu}, yv^(-1)]*G[{0, 1/(yu*yv), yu^(-1)}, yw] - 
     2*G[{0}, yv^(-1)]*G[{yu}, yv^(-1)]*G[{0, 1/(yu*yv), yu^(-1)}, yw] + 
     2*G[{0}, yw]*G[{yu}, yv^(-1)]*G[{0, 1/(yu*yv), yu^(-1)}, yw] + 
     4*G[{1}, yv^(-1)]*G[{yu}, yv^(-1)]*G[{0, 1/(yu*yv), yu^(-1)}, yw] + 
     2*G[{0}, yu^(-1)]*G[{yv^(-1)}, yw]*G[{0, 1/(yu*yv), yu^(-1)}, yw] + 
     2*G[{0}, yv^(-1)]*G[{yv^(-1)}, yw]*G[{0, 1/(yu*yv), yu^(-1)}, yw] - 
     2*G[{0}, yw]*G[{yv^(-1)}, yw]*G[{0, 1/(yu*yv), yu^(-1)}, yw] - 
     4*G[{1}, yu^(-1)]*G[{yv^(-1)}, yw]*G[{0, 1/(yu*yv), yu^(-1)}, yw] - 
     4*G[{1}, yv^(-1)]*G[{yv^(-1)}, yw]*G[{0, 1/(yu*yv), yu^(-1)}, yw] + 
     4*G[{yu}, yv^(-1)]*G[{yv^(-1)}, yw]*G[{0, 1/(yu*yv), yu^(-1)}, yw] - 
     2*G[{0}, yu^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv), yu^(-1)}, yw] - 
     2*G[{0}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv), yu^(-1)}, yw] + 
     2*G[{0}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv), yu^(-1)}, yw] + 
     4*G[{1}, yu^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv), yu^(-1)}, yw] + 
     4*G[{1}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv), yu^(-1)}, yw] - 
     4*G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv), yu^(-1)}, yw] + 
     2*G[{0, 1}, yu^(-1)]*G[{0, 1/(yu*yv), yu^(-1)}, yw] - 
     2*G[{0, 1}, yv^(-1)]*G[{0, 1/(yu*yv), yu^(-1)}, yw] + 
     2*G[{0, 1}, yw]*G[{0, 1/(yu*yv), yu^(-1)}, yw] - 
     2*G[{0, yu^(-1)}, yw]*G[{0, 1/(yu*yv), yu^(-1)}, yw] + 
     2*G[{0, yu}, yv^(-1)]*G[{0, 1/(yu*yv), yu^(-1)}, yw] - 
     2*G[{0, yv^(-1)}, yw]*G[{0, 1/(yu*yv), yu^(-1)}, yw] + 
     2*G[{0, 1/(yu*yv)}, yw]*G[{0, 1/(yu*yv), yu^(-1)}, yw] - 
     4*G[{1, yu}, yv^(-1)]*G[{0, 1/(yu*yv), yu^(-1)}, yw] + 
     4*G[{0}, yu^(-1)]*G[{1}, yv^(-1)]*G[{0, 1/(yu*yv), yv^(-1)}, yw] + 
     4*G[{0}, yv^(-1)]*G[{1}, yv^(-1)]*G[{0, 1/(yu*yv), yv^(-1)}, yw] - 
     4*G[{0}, yw]*G[{1}, yv^(-1)]*G[{0, 1/(yu*yv), yv^(-1)}, yw] - 
     4*G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*G[{0, 1/(yu*yv), yv^(-1)}, yw] - 
     4*G[{1}, yv^(-1)]^2*G[{0, 1/(yu*yv), yv^(-1)}, yw] - 
     4*G[{0}, yu^(-1)]*G[{yu}, yv^(-1)]*G[{0, 1/(yu*yv), yv^(-1)}, yw] - 
     4*G[{0}, yv^(-1)]*G[{yu}, yv^(-1)]*G[{0, 1/(yu*yv), yv^(-1)}, yw] + 
     4*G[{0}, yw]*G[{yu}, yv^(-1)]*G[{0, 1/(yu*yv), yv^(-1)}, yw] + 
     4*G[{1}, yu^(-1)]*G[{yu}, yv^(-1)]*G[{0, 1/(yu*yv), yv^(-1)}, yw] + 
     4*G[{1}, yv^(-1)]*G[{yu}, yv^(-1)]*G[{0, 1/(yu*yv), yv^(-1)}, yw] - 
     4*G[{1}, yv^(-1)]*G[{yv^(-1)}, yw]*G[{0, 1/(yu*yv), yv^(-1)}, yw] + 
     4*G[{yu}, yv^(-1)]*G[{yv^(-1)}, yw]*G[{0, 1/(yu*yv), yv^(-1)}, yw] + 
     4*G[{1}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv), yv^(-1)}, yw] - 
     4*G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv), yv^(-1)}, yw] - 
     4*G[{0}, yu^(-1)]*G[{1}, yv^(-1)]*G[{0, 1/(yu*yv), 1/(yu*yv)}, yw] - 
     4*G[{0}, yv^(-1)]*G[{1}, yv^(-1)]*G[{0, 1/(yu*yv), 1/(yu*yv)}, yw] + 
     4*G[{0}, yw]*G[{1}, yv^(-1)]*G[{0, 1/(yu*yv), 1/(yu*yv)}, yw] + 
     4*G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*G[{0, 1/(yu*yv), 1/(yu*yv)}, yw] + 
     4*G[{1}, yv^(-1)]^2*G[{0, 1/(yu*yv), 1/(yu*yv)}, yw] + 
     4*G[{0}, yu^(-1)]*G[{yu}, yv^(-1)]*G[{0, 1/(yu*yv), 1/(yu*yv)}, yw] + 
     4*G[{0}, yv^(-1)]*G[{yu}, yv^(-1)]*G[{0, 1/(yu*yv), 1/(yu*yv)}, yw] - 
     4*G[{0}, yw]*G[{yu}, yv^(-1)]*G[{0, 1/(yu*yv), 1/(yu*yv)}, yw] - 
     4*G[{1}, yu^(-1)]*G[{yu}, yv^(-1)]*G[{0, 1/(yu*yv), 1/(yu*yv)}, yw] - 
     4*G[{1}, yv^(-1)]*G[{yu}, yv^(-1)]*G[{0, 1/(yu*yv), 1/(yu*yv)}, yw] - 
     2*G[{1}, yv^(-1)]*G[{yv^(-1)}, yw]*G[{0, 1/(yu*yv), 1/(yu*yv)}, yw] + 
     2*G[{yu}, yv^(-1)]*G[{yv^(-1)}, yw]*G[{0, 1/(yu*yv), 1/(yu*yv)}, yw] + 
     2*G[{1}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv), 1/(yu*yv)}, yw] - 
     2*G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv), 1/(yu*yv)}, yw] + 
     4*G[{0}, yu^(-1)]*G[{yv^(-1)}, yw]*G[{1, 1, yu^(-1)}, yw] + 
     4*G[{0}, yv^(-1)]*G[{yv^(-1)}, yw]*G[{1, 1, yu^(-1)}, yw] - 
     4*G[{0}, yw]*G[{yv^(-1)}, yw]*G[{1, 1, yu^(-1)}, yw] - 
     4*G[{1}, yu^(-1)]*G[{yv^(-1)}, yw]*G[{1, 1, yu^(-1)}, yw] + 
     4*G[{1}, yw]*G[{yv^(-1)}, yw]*G[{1, 1, yu^(-1)}, yw] - 
     4*G[{yu}, yv^(-1)]*G[{yv^(-1)}, yw]*G[{1, 1, yu^(-1)}, yw] - 
     4*G[{0}, yu^(-1)]*G[{1/(yu*yv)}, yw]*G[{1, 1, yu^(-1)}, yw] - 
     4*G[{0}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{1, 1, yu^(-1)}, yw] + 
     4*G[{0}, yw]*G[{1/(yu*yv)}, yw]*G[{1, 1, yu^(-1)}, yw] + 
     4*G[{1}, yu^(-1)]*G[{1/(yu*yv)}, yw]*G[{1, 1, yu^(-1)}, yw] - 
     4*G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{1, 1, yu^(-1)}, yw] + 
     4*G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{1, 1, yu^(-1)}, yw] + 
     2*G[{1/(yu*yv)}, yw]^2*G[{1, 1, yu^(-1)}, yw] + 
     4*G[{1, yv^(-1)}, yw]*G[{1, 1, yu^(-1)}, yw] - 
     4*G[{1, 1/(yu*yv)}, yw]*G[{1, 1, yu^(-1)}, yw] - 
     4*G[{yv^(-1), 1/(yu*yv)}, yw]*G[{1, 1, yu^(-1)}, yw] - 
     2*Pi^2*G[{1, 1, yu}, yv^(-1)] + 6*G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*
      G[{1, 1, yu}, yv^(-1)] + 2*G[{1}, yv^(-1)]^2*G[{1, 1, yu}, yv^(-1)] - 
     6*G[{1}, yu^(-1)]*G[{yu}, yv^(-1)]*G[{1, 1, yu}, yv^(-1)] + 
     4*G[{1}, yv^(-1)]*G[{yu}, yv^(-1)]*G[{1, 1, yu}, yv^(-1)] - 
     G[{yu}, yv^(-1)]^2*G[{1, 1, yu}, yv^(-1)] - 6*G[{1}, yu^(-1)]*
      G[{yv^(-1)}, yw]*G[{1, 1, yu}, yv^(-1)] + 8*G[{1}, yv^(-1)]*
      G[{yv^(-1)}, yw]*G[{1, 1, yu}, yv^(-1)] - 2*G[{1}, yw]*G[{yv^(-1)}, yw]*
      G[{1, 1, yu}, yv^(-1)] + 2*G[{yu}, yv^(-1)]*G[{yv^(-1)}, yw]*
      G[{1, 1, yu}, yv^(-1)] + 3*G[{yv^(-1)}, yw]^2*G[{1, 1, yu}, yv^(-1)] + 
     6*G[{1}, yu^(-1)]*G[{1/(yu*yv)}, yw]*G[{1, 1, yu}, yv^(-1)] - 
     8*G[{1}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{1, 1, yu}, yv^(-1)] + 
     2*G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{1, 1, yu}, yv^(-1)] - 
     2*G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{1, 1, yu}, yv^(-1)] - 
     6*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{1, 1, yu}, yv^(-1)] + 
     2*G[{1/(yu*yv)}, yw]^2*G[{1, 1, yu}, yv^(-1)] + 
     6*G[{0, 1}, yu^(-1)]*G[{1, 1, yu}, yv^(-1)] - 8*G[{0, 1}, yv^(-1)]*
      G[{1, 1, yu}, yv^(-1)] + 8*G[{0, yu}, yv^(-1)]*G[{1, 1, yu}, yv^(-1)] + 
     6*G[{1, yu}, yv^(-1)]*G[{1, 1, yu}, yv^(-1)] + 
     2*G[{1, yv^(-1)}, yw]*G[{1, 1, yu}, yv^(-1)] - 
     2*G[{1, 1/(yu*yv)}, yw]*G[{1, 1, yu}, yv^(-1)] + 
     2*G[{yv^(-1), 1/(yu*yv)}, yw]*G[{1, 1, yu}, yv^(-1)] - 
     (Pi^2*G[{1, 1, yv^(-1)}, yw])/3 + 2*G[{0}, yu^(-1)]*G[{1}, yv^(-1)]*
      G[{1, 1, yv^(-1)}, yw] + 2*G[{0}, yv^(-1)]*G[{1}, yv^(-1)]*
      G[{1, 1, yv^(-1)}, yw] - 2*G[{0}, yw]*G[{1}, yv^(-1)]*
      G[{1, 1, yv^(-1)}, yw] - 2*G[{1}, yv^(-1)]^2*G[{1, 1, yv^(-1)}, yw] + 
     4*G[{0}, yu^(-1)]*G[{1}, yw]*G[{1, 1, yv^(-1)}, yw] + 
     4*G[{0}, yv^(-1)]*G[{1}, yw]*G[{1, 1, yv^(-1)}, yw] - 
     4*G[{0}, yw]*G[{1}, yw]*G[{1, 1, yv^(-1)}, yw] - 
     4*G[{1}, yu^(-1)]*G[{1}, yw]*G[{1, 1, yv^(-1)}, yw] - 
     4*G[{1}, yv^(-1)]*G[{1}, yw]*G[{1, 1, yv^(-1)}, yw] - 
     2*G[{0}, yu^(-1)]*G[{yu}, yv^(-1)]*G[{1, 1, yv^(-1)}, yw] - 
     2*G[{0}, yv^(-1)]*G[{yu}, yv^(-1)]*G[{1, 1, yv^(-1)}, yw] + 
     2*G[{0}, yw]*G[{yu}, yv^(-1)]*G[{1, 1, yv^(-1)}, yw] + 
     4*G[{1}, yv^(-1)]*G[{yu}, yv^(-1)]*G[{1, 1, yv^(-1)}, yw] + 
     2*G[{0}, yu^(-1)]*G[{yv^(-1)}, yw]*G[{1, 1, yv^(-1)}, yw] + 
     2*G[{0}, yv^(-1)]*G[{yv^(-1)}, yw]*G[{1, 1, yv^(-1)}, yw] - 
     2*G[{0}, yw]*G[{yv^(-1)}, yw]*G[{1, 1, yv^(-1)}, yw] - 
     4*G[{1}, yu^(-1)]*G[{yv^(-1)}, yw]*G[{1, 1, yv^(-1)}, yw] - 
     4*G[{1}, yv^(-1)]*G[{yv^(-1)}, yw]*G[{1, 1, yv^(-1)}, yw] - 
     4*G[{1}, yw]*G[{yv^(-1)}, yw]*G[{1, 1, yv^(-1)}, yw] + 
     4*G[{yu}, yv^(-1)]*G[{yv^(-1)}, yw]*G[{1, 1, yv^(-1)}, yw] - 
     2*G[{yv^(-1)}, yw]^2*G[{1, 1, yv^(-1)}, yw] - 
     2*G[{0}, yu^(-1)]*G[{1/(yu*yv)}, yw]*G[{1, 1, yv^(-1)}, yw] - 
     2*G[{0}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{1, 1, yv^(-1)}, yw] + 
     2*G[{0}, yw]*G[{1/(yu*yv)}, yw]*G[{1, 1, yv^(-1)}, yw] + 
     4*G[{1}, yu^(-1)]*G[{1/(yu*yv)}, yw]*G[{1, 1, yv^(-1)}, yw] + 
     4*G[{1}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{1, 1, yv^(-1)}, yw] + 
     4*G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{1, 1, yv^(-1)}, yw] - 
     4*G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{1, 1, yv^(-1)}, yw] + 
     4*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{1, 1, yv^(-1)}, yw] - 
     2*G[{1/(yu*yv)}, yw]^2*G[{1, 1, yv^(-1)}, yw] + 
     2*G[{0, 1}, yu^(-1)]*G[{1, 1, yv^(-1)}, yw] - 2*G[{0, 1}, yv^(-1)]*
      G[{1, 1, yv^(-1)}, yw] + 2*G[{0, 1}, yw]*G[{1, 1, yv^(-1)}, yw] - 
     2*G[{0, yu^(-1)}, yw]*G[{1, 1, yv^(-1)}, yw] + 
     2*G[{0, yu}, yv^(-1)]*G[{1, 1, yv^(-1)}, yw] - 
     2*G[{0, yv^(-1)}, yw]*G[{1, 1, yv^(-1)}, yw] + 
     2*G[{0, 1/(yu*yv)}, yw]*G[{1, 1, yv^(-1)}, yw] - 
     4*G[{1, yu}, yv^(-1)]*G[{1, 1, yv^(-1)}, yw] + 
     (Pi^2*G[{1, 1, 1/(yu*yv)}, yw])/3 - 2*G[{0}, yu^(-1)]*G[{1}, yv^(-1)]*
      G[{1, 1, 1/(yu*yv)}, yw] - 2*G[{0}, yv^(-1)]*G[{1}, yv^(-1)]*
      G[{1, 1, 1/(yu*yv)}, yw] + 2*G[{0}, yw]*G[{1}, yv^(-1)]*
      G[{1, 1, 1/(yu*yv)}, yw] + 2*G[{1}, yv^(-1)]^2*
      G[{1, 1, 1/(yu*yv)}, yw] - 4*G[{0}, yu^(-1)]*G[{1}, yw]*
      G[{1, 1, 1/(yu*yv)}, yw] - 4*G[{0}, yv^(-1)]*G[{1}, yw]*
      G[{1, 1, 1/(yu*yv)}, yw] + 4*G[{0}, yw]*G[{1}, yw]*
      G[{1, 1, 1/(yu*yv)}, yw] + 4*G[{1}, yu^(-1)]*G[{1}, yw]*
      G[{1, 1, 1/(yu*yv)}, yw] + 4*G[{1}, yv^(-1)]*G[{1}, yw]*
      G[{1, 1, 1/(yu*yv)}, yw] + 2*G[{0}, yu^(-1)]*G[{yu}, yv^(-1)]*
      G[{1, 1, 1/(yu*yv)}, yw] + 2*G[{0}, yv^(-1)]*G[{yu}, yv^(-1)]*
      G[{1, 1, 1/(yu*yv)}, yw] - 2*G[{0}, yw]*G[{yu}, yv^(-1)]*
      G[{1, 1, 1/(yu*yv)}, yw] - 4*G[{1}, yv^(-1)]*G[{yu}, yv^(-1)]*
      G[{1, 1, 1/(yu*yv)}, yw] + 2*G[{0}, yu^(-1)]*G[{yv^(-1)}, yw]*
      G[{1, 1, 1/(yu*yv)}, yw] + 2*G[{0}, yv^(-1)]*G[{yv^(-1)}, yw]*
      G[{1, 1, 1/(yu*yv)}, yw] - 2*G[{0}, yw]*G[{yv^(-1)}, yw]*
      G[{1, 1, 1/(yu*yv)}, yw] + 4*G[{1}, yw]*G[{yv^(-1)}, yw]*
      G[{1, 1, 1/(yu*yv)}, yw] - 4*G[{yu}, yv^(-1)]*G[{yv^(-1)}, yw]*
      G[{1, 1, 1/(yu*yv)}, yw] + 2*G[{yv^(-1)}, yw]^2*
      G[{1, 1, 1/(yu*yv)}, yw] - 2*G[{0}, yu^(-1)]*G[{1/(yu*yv)}, yw]*
      G[{1, 1, 1/(yu*yv)}, yw] - 2*G[{0}, yv^(-1)]*G[{1/(yu*yv)}, yw]*
      G[{1, 1, 1/(yu*yv)}, yw] + 2*G[{0}, yw]*G[{1/(yu*yv)}, yw]*
      G[{1, 1, 1/(yu*yv)}, yw] - 4*G[{1}, yw]*G[{1/(yu*yv)}, yw]*
      G[{1, 1, 1/(yu*yv)}, yw] + 4*G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw]*
      G[{1, 1, 1/(yu*yv)}, yw] - 4*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*
      G[{1, 1, 1/(yu*yv)}, yw] - 2*G[{0, 1}, yu^(-1)]*
      G[{1, 1, 1/(yu*yv)}, yw] + 2*G[{0, 1}, yv^(-1)]*
      G[{1, 1, 1/(yu*yv)}, yw] - 2*G[{0, 1}, yw]*G[{1, 1, 1/(yu*yv)}, yw] + 
     2*G[{0, yu^(-1)}, yw]*G[{1, 1, 1/(yu*yv)}, yw] - 
     2*G[{0, yu}, yv^(-1)]*G[{1, 1, 1/(yu*yv)}, yw] + 
     2*G[{0, yv^(-1)}, yw]*G[{1, 1, 1/(yu*yv)}, yw] - 
     2*G[{0, 1/(yu*yv)}, yw]*G[{1, 1, 1/(yu*yv)}, yw] + 
     4*G[{1, yu}, yv^(-1)]*G[{1, 1, 1/(yu*yv)}, yw] - 
     4*G[{1, yv^(-1)}, yw]*G[{1, 1, 1/(yu*yv)}, yw] + 
     4*G[{1, 1/(yu*yv)}, yw]*G[{1, 1, 1/(yu*yv)}, yw] + 
     4*G[{yv^(-1), 1/(yu*yv)}, yw]*G[{1, 1, 1/(yu*yv)}, yw] + 
     4*G[{0}, yu^(-1)]*G[{yv^(-1)}, yw]*G[{1, yu^(-1), yu^(-1)}, yw] + 
     4*G[{0}, yv^(-1)]*G[{yv^(-1)}, yw]*G[{1, yu^(-1), yu^(-1)}, yw] - 
     4*G[{0}, yw]*G[{yv^(-1)}, yw]*G[{1, yu^(-1), yu^(-1)}, yw] - 
     4*G[{1}, yu^(-1)]*G[{yv^(-1)}, yw]*G[{1, yu^(-1), yu^(-1)}, yw] - 
     8*G[{1}, yv^(-1)]*G[{yv^(-1)}, yw]*G[{1, yu^(-1), yu^(-1)}, yw] - 
     4*G[{1}, yw]*G[{yv^(-1)}, yw]*G[{1, yu^(-1), yu^(-1)}, yw] + 
     4*G[{yu}, yv^(-1)]*G[{yv^(-1)}, yw]*G[{1, yu^(-1), yu^(-1)}, yw] - 
     4*G[{0}, yu^(-1)]*G[{1/(yu*yv)}, yw]*G[{1, yu^(-1), yu^(-1)}, yw] - 
     4*G[{0}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{1, yu^(-1), yu^(-1)}, yw] + 
     4*G[{0}, yw]*G[{1/(yu*yv)}, yw]*G[{1, yu^(-1), yu^(-1)}, yw] + 
     4*G[{1}, yu^(-1)]*G[{1/(yu*yv)}, yw]*G[{1, yu^(-1), yu^(-1)}, yw] + 
     8*G[{1}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{1, yu^(-1), yu^(-1)}, yw] + 
     4*G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{1, yu^(-1), yu^(-1)}, yw] - 
     4*G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{1, yu^(-1), yu^(-1)}, yw] + 
     2*G[{1/(yu*yv)}, yw]^2*G[{1, yu^(-1), yu^(-1)}, yw] + 
     4*G[{1, yv^(-1)}, yw]*G[{1, yu^(-1), yu^(-1)}, yw] - 
     4*G[{1, 1/(yu*yv)}, yw]*G[{1, yu^(-1), yu^(-1)}, yw] - 
     4*G[{yv^(-1), 1/(yu*yv)}, yw]*G[{1, yu^(-1), yu^(-1)}, yw] - 
     (Pi^2*G[{1, yu^(-1), yv^(-1)}, yw])/3 + 2*G[{0}, yu^(-1)]*
      G[{1}, yv^(-1)]*G[{1, yu^(-1), yv^(-1)}, yw] + 
     2*G[{0}, yv^(-1)]*G[{1}, yv^(-1)]*G[{1, yu^(-1), yv^(-1)}, yw] - 
     2*G[{0}, yw]*G[{1}, yv^(-1)]*G[{1, yu^(-1), yv^(-1)}, yw] - 
     2*G[{1}, yv^(-1)]^2*G[{1, yu^(-1), yv^(-1)}, yw] + 
     4*G[{0}, yu^(-1)]*G[{1}, yw]*G[{1, yu^(-1), yv^(-1)}, yw] + 
     4*G[{0}, yv^(-1)]*G[{1}, yw]*G[{1, yu^(-1), yv^(-1)}, yw] - 
     4*G[{0}, yw]*G[{1}, yw]*G[{1, yu^(-1), yv^(-1)}, yw] - 
     4*G[{1}, yu^(-1)]*G[{1}, yw]*G[{1, yu^(-1), yv^(-1)}, yw] - 
     4*G[{1}, yv^(-1)]*G[{1}, yw]*G[{1, yu^(-1), yv^(-1)}, yw] - 
     2*G[{0}, yu^(-1)]*G[{yu}, yv^(-1)]*G[{1, yu^(-1), yv^(-1)}, yw] - 
     2*G[{0}, yv^(-1)]*G[{yu}, yv^(-1)]*G[{1, yu^(-1), yv^(-1)}, yw] + 
     2*G[{0}, yw]*G[{yu}, yv^(-1)]*G[{1, yu^(-1), yv^(-1)}, yw] + 
     4*G[{1}, yv^(-1)]*G[{yu}, yv^(-1)]*G[{1, yu^(-1), yv^(-1)}, yw] + 
     2*G[{0}, yu^(-1)]*G[{yv^(-1)}, yw]*G[{1, yu^(-1), yv^(-1)}, yw] + 
     2*G[{0}, yv^(-1)]*G[{yv^(-1)}, yw]*G[{1, yu^(-1), yv^(-1)}, yw] - 
     2*G[{0}, yw]*G[{yv^(-1)}, yw]*G[{1, yu^(-1), yv^(-1)}, yw] - 
     4*G[{1}, yu^(-1)]*G[{yv^(-1)}, yw]*G[{1, yu^(-1), yv^(-1)}, yw] - 
     4*G[{1}, yv^(-1)]*G[{yv^(-1)}, yw]*G[{1, yu^(-1), yv^(-1)}, yw] - 
     4*G[{1}, yw]*G[{yv^(-1)}, yw]*G[{1, yu^(-1), yv^(-1)}, yw] + 
     4*G[{yu}, yv^(-1)]*G[{yv^(-1)}, yw]*G[{1, yu^(-1), yv^(-1)}, yw] - 
     2*G[{0}, yu^(-1)]*G[{1/(yu*yv)}, yw]*G[{1, yu^(-1), yv^(-1)}, yw] - 
     2*G[{0}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{1, yu^(-1), yv^(-1)}, yw] + 
     2*G[{0}, yw]*G[{1/(yu*yv)}, yw]*G[{1, yu^(-1), yv^(-1)}, yw] + 
     4*G[{1}, yu^(-1)]*G[{1/(yu*yv)}, yw]*G[{1, yu^(-1), yv^(-1)}, yw] + 
     4*G[{1}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{1, yu^(-1), yv^(-1)}, yw] + 
     4*G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{1, yu^(-1), yv^(-1)}, yw] - 
     4*G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{1, yu^(-1), yv^(-1)}, yw] + 
     2*G[{0, 1}, yu^(-1)]*G[{1, yu^(-1), yv^(-1)}, yw] - 
     2*G[{0, 1}, yv^(-1)]*G[{1, yu^(-1), yv^(-1)}, yw] + 
     2*G[{0, 1}, yw]*G[{1, yu^(-1), yv^(-1)}, yw] - 
     2*G[{0, yu^(-1)}, yw]*G[{1, yu^(-1), yv^(-1)}, yw] + 
     2*G[{0, yu}, yv^(-1)]*G[{1, yu^(-1), yv^(-1)}, yw] - 
     2*G[{0, yv^(-1)}, yw]*G[{1, yu^(-1), yv^(-1)}, yw] + 
     2*G[{0, 1/(yu*yv)}, yw]*G[{1, yu^(-1), yv^(-1)}, yw] - 
     4*G[{1, yu}, yv^(-1)]*G[{1, yu^(-1), yv^(-1)}, yw] + 
     (Pi^2*G[{1, yu^(-1), 1/(yu*yv)}, yw])/3 - 2*G[{0}, yu^(-1)]*
      G[{1}, yv^(-1)]*G[{1, yu^(-1), 1/(yu*yv)}, yw] - 
     2*G[{0}, yv^(-1)]*G[{1}, yv^(-1)]*G[{1, yu^(-1), 1/(yu*yv)}, yw] + 
     2*G[{0}, yw]*G[{1}, yv^(-1)]*G[{1, yu^(-1), 1/(yu*yv)}, yw] + 
     2*G[{1}, yv^(-1)]^2*G[{1, yu^(-1), 1/(yu*yv)}, yw] - 
     4*G[{0}, yu^(-1)]*G[{1}, yw]*G[{1, yu^(-1), 1/(yu*yv)}, yw] - 
     4*G[{0}, yv^(-1)]*G[{1}, yw]*G[{1, yu^(-1), 1/(yu*yv)}, yw] + 
     4*G[{0}, yw]*G[{1}, yw]*G[{1, yu^(-1), 1/(yu*yv)}, yw] + 
     4*G[{1}, yu^(-1)]*G[{1}, yw]*G[{1, yu^(-1), 1/(yu*yv)}, yw] + 
     4*G[{1}, yv^(-1)]*G[{1}, yw]*G[{1, yu^(-1), 1/(yu*yv)}, yw] + 
     2*G[{0}, yu^(-1)]*G[{yu}, yv^(-1)]*G[{1, yu^(-1), 1/(yu*yv)}, yw] + 
     2*G[{0}, yv^(-1)]*G[{yu}, yv^(-1)]*G[{1, yu^(-1), 1/(yu*yv)}, yw] - 
     2*G[{0}, yw]*G[{yu}, yv^(-1)]*G[{1, yu^(-1), 1/(yu*yv)}, yw] - 
     4*G[{1}, yv^(-1)]*G[{yu}, yv^(-1)]*G[{1, yu^(-1), 1/(yu*yv)}, yw] - 
     2*G[{0}, yu^(-1)]*G[{yv^(-1)}, yw]*G[{1, yu^(-1), 1/(yu*yv)}, yw] - 
     2*G[{0}, yv^(-1)]*G[{yv^(-1)}, yw]*G[{1, yu^(-1), 1/(yu*yv)}, yw] + 
     2*G[{0}, yw]*G[{yv^(-1)}, yw]*G[{1, yu^(-1), 1/(yu*yv)}, yw] + 
     4*G[{1}, yu^(-1)]*G[{yv^(-1)}, yw]*G[{1, yu^(-1), 1/(yu*yv)}, yw] + 
     2*G[{0}, yu^(-1)]*G[{1/(yu*yv)}, yw]*G[{1, yu^(-1), 1/(yu*yv)}, yw] + 
     2*G[{0}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{1, yu^(-1), 1/(yu*yv)}, yw] - 
     2*G[{0}, yw]*G[{1/(yu*yv)}, yw]*G[{1, yu^(-1), 1/(yu*yv)}, yw] - 
     4*G[{1}, yu^(-1)]*G[{1/(yu*yv)}, yw]*G[{1, yu^(-1), 1/(yu*yv)}, yw] - 
     2*G[{0, 1}, yu^(-1)]*G[{1, yu^(-1), 1/(yu*yv)}, yw] + 
     2*G[{0, 1}, yv^(-1)]*G[{1, yu^(-1), 1/(yu*yv)}, yw] - 
     2*G[{0, 1}, yw]*G[{1, yu^(-1), 1/(yu*yv)}, yw] + 
     2*G[{0, yu^(-1)}, yw]*G[{1, yu^(-1), 1/(yu*yv)}, yw] - 
     2*G[{0, yu}, yv^(-1)]*G[{1, yu^(-1), 1/(yu*yv)}, yw] + 
     2*G[{0, yv^(-1)}, yw]*G[{1, yu^(-1), 1/(yu*yv)}, yw] - 
     2*G[{0, 1/(yu*yv)}, yw]*G[{1, yu^(-1), 1/(yu*yv)}, yw] + 
     4*G[{1, yu}, yv^(-1)]*G[{1, yu^(-1), 1/(yu*yv)}, yw] - 
     2*Pi^2*G[{1, yu, yu}, yv^(-1)] + 6*G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*
      G[{1, yu, yu}, yv^(-1)] + 2*G[{1}, yv^(-1)]^2*G[{1, yu, yu}, yv^(-1)] - 
     6*G[{1}, yu^(-1)]*G[{yu}, yv^(-1)]*G[{1, yu, yu}, yv^(-1)] - 
     4*G[{1}, yv^(-1)]*G[{yu}, yv^(-1)]*G[{1, yu, yu}, yv^(-1)] - 
     3*G[{yu}, yv^(-1)]^2*G[{1, yu, yu}, yv^(-1)] - 
     6*G[{1}, yu^(-1)]*G[{yv^(-1)}, yw]*G[{1, yu, yu}, yv^(-1)] + 
     4*G[{1}, yv^(-1)]*G[{yv^(-1)}, yw]*G[{1, yu, yu}, yv^(-1)] - 
     2*G[{1}, yw]*G[{yv^(-1)}, yw]*G[{1, yu, yu}, yv^(-1)] + 
     2*G[{yu}, yv^(-1)]*G[{yv^(-1)}, yw]*G[{1, yu, yu}, yv^(-1)] + 
     5*G[{yv^(-1)}, yw]^2*G[{1, yu, yu}, yv^(-1)] + 
     6*G[{1}, yu^(-1)]*G[{1/(yu*yv)}, yw]*G[{1, yu, yu}, yv^(-1)] - 
     4*G[{1}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{1, yu, yu}, yv^(-1)] + 
     2*G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{1, yu, yu}, yv^(-1)] - 
     2*G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{1, yu, yu}, yv^(-1)] - 
     10*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{1, yu, yu}, yv^(-1)] + 
     4*G[{1/(yu*yv)}, yw]^2*G[{1, yu, yu}, yv^(-1)] + 
     6*G[{0, 1}, yu^(-1)]*G[{1, yu, yu}, yv^(-1)] - 
     8*G[{0, 1}, yv^(-1)]*G[{1, yu, yu}, yv^(-1)] + 
     8*G[{0, yu}, yv^(-1)]*G[{1, yu, yu}, yv^(-1)] - 
     14*G[{1, yu}, yv^(-1)]*G[{1, yu, yu}, yv^(-1)] + 
     2*G[{1, yv^(-1)}, yw]*G[{1, yu, yu}, yv^(-1)] - 
     2*G[{1, 1/(yu*yv)}, yw]*G[{1, yu, yu}, yv^(-1)] + 
     2*G[{yv^(-1), 1/(yu*yv)}, yw]*G[{1, yu, yu}, yv^(-1)] - 
     (Pi^2*G[{1, yv^(-1), yu^(-1)}, yw])/3 + 2*G[{0}, yu^(-1)]*
      G[{1}, yv^(-1)]*G[{1, yv^(-1), yu^(-1)}, yw] + 
     2*G[{0}, yv^(-1)]*G[{1}, yv^(-1)]*G[{1, yv^(-1), yu^(-1)}, yw] - 
     2*G[{0}, yw]*G[{1}, yv^(-1)]*G[{1, yv^(-1), yu^(-1)}, yw] - 
     2*G[{1}, yv^(-1)]^2*G[{1, yv^(-1), yu^(-1)}, yw] + 
     4*G[{0}, yu^(-1)]*G[{1}, yw]*G[{1, yv^(-1), yu^(-1)}, yw] + 
     4*G[{0}, yv^(-1)]*G[{1}, yw]*G[{1, yv^(-1), yu^(-1)}, yw] - 
     4*G[{0}, yw]*G[{1}, yw]*G[{1, yv^(-1), yu^(-1)}, yw] - 
     4*G[{1}, yu^(-1)]*G[{1}, yw]*G[{1, yv^(-1), yu^(-1)}, yw] - 
     4*G[{1}, yv^(-1)]*G[{1}, yw]*G[{1, yv^(-1), yu^(-1)}, yw] - 
     2*G[{0}, yu^(-1)]*G[{yu}, yv^(-1)]*G[{1, yv^(-1), yu^(-1)}, yw] - 
     2*G[{0}, yv^(-1)]*G[{yu}, yv^(-1)]*G[{1, yv^(-1), yu^(-1)}, yw] + 
     2*G[{0}, yw]*G[{yu}, yv^(-1)]*G[{1, yv^(-1), yu^(-1)}, yw] + 
     4*G[{1}, yv^(-1)]*G[{yu}, yv^(-1)]*G[{1, yv^(-1), yu^(-1)}, yw] + 
     2*G[{0}, yu^(-1)]*G[{yv^(-1)}, yw]*G[{1, yv^(-1), yu^(-1)}, yw] + 
     2*G[{0}, yv^(-1)]*G[{yv^(-1)}, yw]*G[{1, yv^(-1), yu^(-1)}, yw] - 
     2*G[{0}, yw]*G[{yv^(-1)}, yw]*G[{1, yv^(-1), yu^(-1)}, yw] - 
     4*G[{1}, yu^(-1)]*G[{yv^(-1)}, yw]*G[{1, yv^(-1), yu^(-1)}, yw] - 
     4*G[{1}, yv^(-1)]*G[{yv^(-1)}, yw]*G[{1, yv^(-1), yu^(-1)}, yw] - 
     4*G[{1}, yw]*G[{yv^(-1)}, yw]*G[{1, yv^(-1), yu^(-1)}, yw] + 
     4*G[{yu}, yv^(-1)]*G[{yv^(-1)}, yw]*G[{1, yv^(-1), yu^(-1)}, yw] - 
     2*G[{0}, yu^(-1)]*G[{1/(yu*yv)}, yw]*G[{1, yv^(-1), yu^(-1)}, yw] - 
     2*G[{0}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{1, yv^(-1), yu^(-1)}, yw] + 
     2*G[{0}, yw]*G[{1/(yu*yv)}, yw]*G[{1, yv^(-1), yu^(-1)}, yw] + 
     4*G[{1}, yu^(-1)]*G[{1/(yu*yv)}, yw]*G[{1, yv^(-1), yu^(-1)}, yw] + 
     4*G[{1}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{1, yv^(-1), yu^(-1)}, yw] + 
     4*G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{1, yv^(-1), yu^(-1)}, yw] - 
     4*G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{1, yv^(-1), yu^(-1)}, yw] + 
     2*G[{0, 1}, yu^(-1)]*G[{1, yv^(-1), yu^(-1)}, yw] - 
     2*G[{0, 1}, yv^(-1)]*G[{1, yv^(-1), yu^(-1)}, yw] + 
     2*G[{0, 1}, yw]*G[{1, yv^(-1), yu^(-1)}, yw] - 
     2*G[{0, yu^(-1)}, yw]*G[{1, yv^(-1), yu^(-1)}, yw] + 
     2*G[{0, yu}, yv^(-1)]*G[{1, yv^(-1), yu^(-1)}, yw] - 
     2*G[{0, yv^(-1)}, yw]*G[{1, yv^(-1), yu^(-1)}, yw] + 
     2*G[{0, 1/(yu*yv)}, yw]*G[{1, yv^(-1), yu^(-1)}, yw] - 
     4*G[{1, yu}, yv^(-1)]*G[{1, yv^(-1), yu^(-1)}, yw] + 
     4*G[{1, yv^(-1)}, yw]*G[{1, yv^(-1), yu^(-1)}, yw] + 
     (2*Pi^2*G[{1, yv^(-1), yv^(-1)}, yw])/3 + 2*G[{1}, yu^(-1)]*
      G[{1}, yv^(-1)]*G[{1, yv^(-1), yv^(-1)}, yw] - 
     2*G[{1}, yv^(-1)]^2*G[{1, yv^(-1), yv^(-1)}, yw] + 
     4*G[{0}, yu^(-1)]*G[{1}, yw]*G[{1, yv^(-1), yv^(-1)}, yw] + 
     4*G[{0}, yv^(-1)]*G[{1}, yw]*G[{1, yv^(-1), yv^(-1)}, yw] - 
     4*G[{0}, yw]*G[{1}, yw]*G[{1, yv^(-1), yv^(-1)}, yw] - 
     4*G[{1}, yu^(-1)]*G[{1}, yw]*G[{1, yv^(-1), yv^(-1)}, yw] - 
     8*G[{1}, yv^(-1)]*G[{1}, yw]*G[{1, yv^(-1), yv^(-1)}, yw] - 
     2*G[{1}, yw]^2*G[{1, yv^(-1), yv^(-1)}, yw] - 
     2*G[{1}, yu^(-1)]*G[{yu}, yv^(-1)]*G[{1, yv^(-1), yv^(-1)}, yw] + 
     4*G[{1}, yv^(-1)]*G[{yu}, yv^(-1)]*G[{1, yv^(-1), yv^(-1)}, yw] + 
     4*G[{1}, yw]*G[{yu}, yv^(-1)]*G[{1, yv^(-1), yv^(-1)}, yw] - 
     G[{yu}, yv^(-1)]^2*G[{1, yv^(-1), yv^(-1)}, yw] - 
     4*G[{0}, yu^(-1)]*G[{yv^(-1)}, yw]*G[{1, yv^(-1), yv^(-1)}, yw] - 
     4*G[{0}, yv^(-1)]*G[{yv^(-1)}, yw]*G[{1, yv^(-1), yv^(-1)}, yw] + 
     4*G[{0}, yw]*G[{yv^(-1)}, yw]*G[{1, yv^(-1), yv^(-1)}, yw] + 
     2*G[{1}, yu^(-1)]*G[{yv^(-1)}, yw]*G[{1, yv^(-1), yv^(-1)}, yw] - 
     4*G[{1}, yv^(-1)]*G[{yv^(-1)}, yw]*G[{1, yv^(-1), yv^(-1)}, yw] - 
     10*G[{1}, yw]*G[{yv^(-1)}, yw]*G[{1, yv^(-1), yv^(-1)}, yw] + 
     10*G[{yu}, yv^(-1)]*G[{yv^(-1)}, yw]*G[{1, yv^(-1), yv^(-1)}, yw] - 
     5*G[{yv^(-1)}, yw]^2*G[{1, yv^(-1), yv^(-1)}, yw] + 
     4*G[{0}, yu^(-1)]*G[{1/(yu*yv)}, yw]*G[{1, yv^(-1), yv^(-1)}, yw] + 
     4*G[{0}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{1, yv^(-1), yv^(-1)}, yw] - 
     4*G[{0}, yw]*G[{1/(yu*yv)}, yw]*G[{1, yv^(-1), yv^(-1)}, yw] - 
     2*G[{1}, yu^(-1)]*G[{1/(yu*yv)}, yw]*G[{1, yv^(-1), yv^(-1)}, yw] + 
     4*G[{1}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{1, yv^(-1), yv^(-1)}, yw] + 
     10*G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{1, yv^(-1), yv^(-1)}, yw] - 
     10*G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{1, yv^(-1), yv^(-1)}, yw] + 
     10*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{1, yv^(-1), yv^(-1)}, yw] - 
     2*G[{1/(yu*yv)}, yw]^2*G[{1, yv^(-1), yv^(-1)}, yw] + 
     2*G[{0, 1}, yu^(-1)]*G[{1, yv^(-1), yv^(-1)}, yw] + 
     4*G[{0, 1}, yw]*G[{1, yv^(-1), yv^(-1)}, yw] - 
     4*G[{0, yu^(-1)}, yw]*G[{1, yv^(-1), yv^(-1)}, yw] - 
     4*G[{0, yv^(-1)}, yw]*G[{1, yv^(-1), yv^(-1)}, yw] + 
     4*G[{0, 1/(yu*yv)}, yw]*G[{1, yv^(-1), yv^(-1)}, yw] + 
     4*G[{1, yu^(-1)}, yw]*G[{1, yv^(-1), yv^(-1)}, yw] - 
     2*G[{1, yu}, yv^(-1)]*G[{1, yv^(-1), yv^(-1)}, yw] + 
     6*G[{1, yv^(-1)}, yw]*G[{1, yv^(-1), yv^(-1)}, yw] - 
     2*G[{1, 1/(yu*yv)}, yw]*G[{1, yv^(-1), yv^(-1)}, yw] - 
     6*G[{yv^(-1), 1/(yu*yv)}, yw]*G[{1, yv^(-1), yv^(-1)}, yw] - 
     (2*Pi^2*G[{1, yv^(-1), 1/(yu*yv)}, yw])/3 - 2*G[{1}, yu^(-1)]*
      G[{1}, yv^(-1)]*G[{1, yv^(-1), 1/(yu*yv)}, yw] + 
     2*G[{1}, yv^(-1)]^2*G[{1, yv^(-1), 1/(yu*yv)}, yw] - 
     4*G[{0}, yu^(-1)]*G[{1}, yw]*G[{1, yv^(-1), 1/(yu*yv)}, yw] - 
     4*G[{0}, yv^(-1)]*G[{1}, yw]*G[{1, yv^(-1), 1/(yu*yv)}, yw] + 
     4*G[{0}, yw]*G[{1}, yw]*G[{1, yv^(-1), 1/(yu*yv)}, yw] + 
     4*G[{1}, yu^(-1)]*G[{1}, yw]*G[{1, yv^(-1), 1/(yu*yv)}, yw] + 
     8*G[{1}, yv^(-1)]*G[{1}, yw]*G[{1, yv^(-1), 1/(yu*yv)}, yw] + 
     2*G[{1}, yw]^2*G[{1, yv^(-1), 1/(yu*yv)}, yw] + 
     2*G[{1}, yu^(-1)]*G[{yu}, yv^(-1)]*G[{1, yv^(-1), 1/(yu*yv)}, yw] - 
     4*G[{1}, yv^(-1)]*G[{yu}, yv^(-1)]*G[{1, yv^(-1), 1/(yu*yv)}, yw] - 
     4*G[{1}, yw]*G[{yu}, yv^(-1)]*G[{1, yv^(-1), 1/(yu*yv)}, yw] + 
     G[{yu}, yv^(-1)]^2*G[{1, yv^(-1), 1/(yu*yv)}, yw] + 
     4*G[{0}, yu^(-1)]*G[{yv^(-1)}, yw]*G[{1, yv^(-1), 1/(yu*yv)}, yw] + 
     4*G[{0}, yv^(-1)]*G[{yv^(-1)}, yw]*G[{1, yv^(-1), 1/(yu*yv)}, yw] - 
     4*G[{0}, yw]*G[{yv^(-1)}, yw]*G[{1, yv^(-1), 1/(yu*yv)}, yw] - 
     2*G[{1}, yu^(-1)]*G[{yv^(-1)}, yw]*G[{1, yv^(-1), 1/(yu*yv)}, yw] + 
     6*G[{1}, yw]*G[{yv^(-1)}, yw]*G[{1, yv^(-1), 1/(yu*yv)}, yw] - 
     6*G[{yu}, yv^(-1)]*G[{yv^(-1)}, yw]*G[{1, yv^(-1), 1/(yu*yv)}, yw] + 
     3*G[{yv^(-1)}, yw]^2*G[{1, yv^(-1), 1/(yu*yv)}, yw] - 
     4*G[{0}, yu^(-1)]*G[{1/(yu*yv)}, yw]*G[{1, yv^(-1), 1/(yu*yv)}, yw] - 
     4*G[{0}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{1, yv^(-1), 1/(yu*yv)}, yw] + 
     4*G[{0}, yw]*G[{1/(yu*yv)}, yw]*G[{1, yv^(-1), 1/(yu*yv)}, yw] + 
     2*G[{1}, yu^(-1)]*G[{1/(yu*yv)}, yw]*G[{1, yv^(-1), 1/(yu*yv)}, yw] - 
     6*G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{1, yv^(-1), 1/(yu*yv)}, yw] + 
     6*G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{1, yv^(-1), 1/(yu*yv)}, yw] - 
     6*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{1, yv^(-1), 1/(yu*yv)}, yw] - 
     2*G[{0, 1}, yu^(-1)]*G[{1, yv^(-1), 1/(yu*yv)}, yw] - 
     4*G[{0, 1}, yw]*G[{1, yv^(-1), 1/(yu*yv)}, yw] + 
     4*G[{0, yu^(-1)}, yw]*G[{1, yv^(-1), 1/(yu*yv)}, yw] + 
     4*G[{0, yv^(-1)}, yw]*G[{1, yv^(-1), 1/(yu*yv)}, yw] - 
     4*G[{0, 1/(yu*yv)}, yw]*G[{1, yv^(-1), 1/(yu*yv)}, yw] - 
     4*G[{1, yu^(-1)}, yw]*G[{1, yv^(-1), 1/(yu*yv)}, yw] + 
     2*G[{1, yu}, yv^(-1)]*G[{1, yv^(-1), 1/(yu*yv)}, yw] - 
     6*G[{1, yv^(-1)}, yw]*G[{1, yv^(-1), 1/(yu*yv)}, yw] + 
     2*G[{1, 1/(yu*yv)}, yw]*G[{1, yv^(-1), 1/(yu*yv)}, yw] + 
     6*G[{yv^(-1), 1/(yu*yv)}, yw]*G[{1, yv^(-1), 1/(yu*yv)}, yw] + 
     (Pi^2*G[{1, 1/(yu*yv), yu^(-1)}, yw])/3 - 2*G[{0}, yu^(-1)]*
      G[{1}, yv^(-1)]*G[{1, 1/(yu*yv), yu^(-1)}, yw] - 
     2*G[{0}, yv^(-1)]*G[{1}, yv^(-1)]*G[{1, 1/(yu*yv), yu^(-1)}, yw] + 
     2*G[{0}, yw]*G[{1}, yv^(-1)]*G[{1, 1/(yu*yv), yu^(-1)}, yw] + 
     2*G[{1}, yv^(-1)]^2*G[{1, 1/(yu*yv), yu^(-1)}, yw] - 
     4*G[{0}, yu^(-1)]*G[{1}, yw]*G[{1, 1/(yu*yv), yu^(-1)}, yw] - 
     4*G[{0}, yv^(-1)]*G[{1}, yw]*G[{1, 1/(yu*yv), yu^(-1)}, yw] + 
     4*G[{0}, yw]*G[{1}, yw]*G[{1, 1/(yu*yv), yu^(-1)}, yw] + 
     4*G[{1}, yu^(-1)]*G[{1}, yw]*G[{1, 1/(yu*yv), yu^(-1)}, yw] + 
     4*G[{1}, yv^(-1)]*G[{1}, yw]*G[{1, 1/(yu*yv), yu^(-1)}, yw] + 
     2*G[{0}, yu^(-1)]*G[{yu}, yv^(-1)]*G[{1, 1/(yu*yv), yu^(-1)}, yw] + 
     2*G[{0}, yv^(-1)]*G[{yu}, yv^(-1)]*G[{1, 1/(yu*yv), yu^(-1)}, yw] - 
     2*G[{0}, yw]*G[{yu}, yv^(-1)]*G[{1, 1/(yu*yv), yu^(-1)}, yw] - 
     4*G[{1}, yv^(-1)]*G[{yu}, yv^(-1)]*G[{1, 1/(yu*yv), yu^(-1)}, yw] + 
     2*G[{0}, yu^(-1)]*G[{yv^(-1)}, yw]*G[{1, 1/(yu*yv), yu^(-1)}, yw] + 
     2*G[{0}, yv^(-1)]*G[{yv^(-1)}, yw]*G[{1, 1/(yu*yv), yu^(-1)}, yw] - 
     2*G[{0}, yw]*G[{yv^(-1)}, yw]*G[{1, 1/(yu*yv), yu^(-1)}, yw] - 
     4*G[{1}, yv^(-1)]*G[{yv^(-1)}, yw]*G[{1, 1/(yu*yv), yu^(-1)}, yw] - 
     2*G[{0}, yu^(-1)]*G[{1/(yu*yv)}, yw]*G[{1, 1/(yu*yv), yu^(-1)}, yw] - 
     2*G[{0}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{1, 1/(yu*yv), yu^(-1)}, yw] + 
     2*G[{0}, yw]*G[{1/(yu*yv)}, yw]*G[{1, 1/(yu*yv), yu^(-1)}, yw] + 
     4*G[{1}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{1, 1/(yu*yv), yu^(-1)}, yw] - 
     2*G[{1/(yu*yv)}, yw]^2*G[{1, 1/(yu*yv), yu^(-1)}, yw] - 
     2*G[{0, 1}, yu^(-1)]*G[{1, 1/(yu*yv), yu^(-1)}, yw] + 
     2*G[{0, 1}, yv^(-1)]*G[{1, 1/(yu*yv), yu^(-1)}, yw] - 
     2*G[{0, 1}, yw]*G[{1, 1/(yu*yv), yu^(-1)}, yw] + 
     2*G[{0, yu^(-1)}, yw]*G[{1, 1/(yu*yv), yu^(-1)}, yw] - 
     2*G[{0, yu}, yv^(-1)]*G[{1, 1/(yu*yv), yu^(-1)}, yw] + 
     2*G[{0, yv^(-1)}, yw]*G[{1, 1/(yu*yv), yu^(-1)}, yw] - 
     2*G[{0, 1/(yu*yv)}, yw]*G[{1, 1/(yu*yv), yu^(-1)}, yw] + 
     4*G[{1, yu}, yv^(-1)]*G[{1, 1/(yu*yv), yu^(-1)}, yw] - 
     4*G[{1, yv^(-1)}, yw]*G[{1, 1/(yu*yv), yu^(-1)}, yw] + 
     4*G[{yv^(-1), 1/(yu*yv)}, yw]*G[{1, 1/(yu*yv), yu^(-1)}, yw] - 
     Pi^2*G[{1, 1/(yu*yv), yv^(-1)}, yw] + 2*G[{0}, yu^(-1)]*G[{1}, yv^(-1)]*
      G[{1, 1/(yu*yv), yv^(-1)}, yw] + 2*G[{0}, yv^(-1)]*G[{1}, yv^(-1)]*
      G[{1, 1/(yu*yv), yv^(-1)}, yw] - 2*G[{0}, yw]*G[{1}, yv^(-1)]*
      G[{1, 1/(yu*yv), yv^(-1)}, yw] - 2*G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*
      G[{1, 1/(yu*yv), yv^(-1)}, yw] + 4*G[{1}, yv^(-1)]*G[{1}, yw]*
      G[{1, 1/(yu*yv), yv^(-1)}, yw] + 2*G[{1}, yw]^2*
      G[{1, 1/(yu*yv), yv^(-1)}, yw] - 2*G[{0}, yu^(-1)]*G[{yu}, yv^(-1)]*
      G[{1, 1/(yu*yv), yv^(-1)}, yw] - 2*G[{0}, yv^(-1)]*G[{yu}, yv^(-1)]*
      G[{1, 1/(yu*yv), yv^(-1)}, yw] + 2*G[{0}, yw]*G[{yu}, yv^(-1)]*
      G[{1, 1/(yu*yv), yv^(-1)}, yw] + 2*G[{1}, yu^(-1)]*G[{yu}, yv^(-1)]*
      G[{1, 1/(yu*yv), yv^(-1)}, yw] - 4*G[{1}, yw]*G[{yu}, yv^(-1)]*
      G[{1, 1/(yu*yv), yv^(-1)}, yw] + G[{yu}, yv^(-1)]^2*
      G[{1, 1/(yu*yv), yv^(-1)}, yw] + 6*G[{0}, yu^(-1)]*G[{yv^(-1)}, yw]*
      G[{1, 1/(yu*yv), yv^(-1)}, yw] + 6*G[{0}, yv^(-1)]*G[{yv^(-1)}, yw]*
      G[{1, 1/(yu*yv), yv^(-1)}, yw] - 6*G[{0}, yw]*G[{yv^(-1)}, yw]*
      G[{1, 1/(yu*yv), yv^(-1)}, yw] - 6*G[{1}, yu^(-1)]*G[{yv^(-1)}, yw]*
      G[{1, 1/(yu*yv), yv^(-1)}, yw] + 6*G[{1}, yw]*G[{yv^(-1)}, yw]*
      G[{1, 1/(yu*yv), yv^(-1)}, yw] - 6*G[{yu}, yv^(-1)]*G[{yv^(-1)}, yw]*
      G[{1, 1/(yu*yv), yv^(-1)}, yw] + 5*G[{yv^(-1)}, yw]^2*
      G[{1, 1/(yu*yv), yv^(-1)}, yw] - 6*G[{0}, yu^(-1)]*G[{1/(yu*yv)}, yw]*
      G[{1, 1/(yu*yv), yv^(-1)}, yw] - 6*G[{0}, yv^(-1)]*G[{1/(yu*yv)}, yw]*
      G[{1, 1/(yu*yv), yv^(-1)}, yw] + 6*G[{0}, yw]*G[{1/(yu*yv)}, yw]*
      G[{1, 1/(yu*yv), yv^(-1)}, yw] + 6*G[{1}, yu^(-1)]*G[{1/(yu*yv)}, yw]*
      G[{1, 1/(yu*yv), yv^(-1)}, yw] - 6*G[{1}, yw]*G[{1/(yu*yv)}, yw]*
      G[{1, 1/(yu*yv), yv^(-1)}, yw] + 6*G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw]*
      G[{1, 1/(yu*yv), yv^(-1)}, yw] - 10*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*
      G[{1, 1/(yu*yv), yv^(-1)}, yw] + 2*G[{1/(yu*yv)}, yw]^2*
      G[{1, 1/(yu*yv), yv^(-1)}, yw] - 2*G[{0, 1}, yv^(-1)]*
      G[{1, 1/(yu*yv), yv^(-1)}, yw] - 2*G[{0, 1}, yw]*
      G[{1, 1/(yu*yv), yv^(-1)}, yw] + 2*G[{0, yu^(-1)}, yw]*
      G[{1, 1/(yu*yv), yv^(-1)}, yw] + 2*G[{0, yu}, yv^(-1)]*
      G[{1, 1/(yu*yv), yv^(-1)}, yw] + 2*G[{0, yv^(-1)}, yw]*
      G[{1, 1/(yu*yv), yv^(-1)}, yw] - 2*G[{0, 1/(yu*yv)}, yw]*
      G[{1, 1/(yu*yv), yv^(-1)}, yw] - 4*G[{1, yu^(-1)}, yw]*
      G[{1, 1/(yu*yv), yv^(-1)}, yw] - 2*G[{1, yu}, yv^(-1)]*
      G[{1, 1/(yu*yv), yv^(-1)}, yw] - 2*G[{1, yv^(-1)}, yw]*
      G[{1, 1/(yu*yv), yv^(-1)}, yw] + 2*G[{1, 1/(yu*yv)}, yw]*
      G[{1, 1/(yu*yv), yv^(-1)}, yw] + 6*G[{yv^(-1), 1/(yu*yv)}, yw]*
      G[{1, 1/(yu*yv), yv^(-1)}, yw] + Pi^2*G[{1, 1/(yu*yv), 1/(yu*yv)}, 
       yw] - 2*G[{0}, yu^(-1)]*G[{1}, yv^(-1)]*G[{1, 1/(yu*yv), 1/(yu*yv)}, 
       yw] - 2*G[{0}, yv^(-1)]*G[{1}, yv^(-1)]*G[{1, 1/(yu*yv), 1/(yu*yv)}, 
       yw] + 2*G[{0}, yw]*G[{1}, yv^(-1)]*G[{1, 1/(yu*yv), 1/(yu*yv)}, yw] + 
     2*G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*G[{1, 1/(yu*yv), 1/(yu*yv)}, yw] - 
     4*G[{1}, yv^(-1)]*G[{1}, yw]*G[{1, 1/(yu*yv), 1/(yu*yv)}, yw] - 
     2*G[{1}, yw]^2*G[{1, 1/(yu*yv), 1/(yu*yv)}, yw] + 
     2*G[{0}, yu^(-1)]*G[{yu}, yv^(-1)]*G[{1, 1/(yu*yv), 1/(yu*yv)}, yw] + 
     2*G[{0}, yv^(-1)]*G[{yu}, yv^(-1)]*G[{1, 1/(yu*yv), 1/(yu*yv)}, yw] - 
     2*G[{0}, yw]*G[{yu}, yv^(-1)]*G[{1, 1/(yu*yv), 1/(yu*yv)}, yw] - 
     2*G[{1}, yu^(-1)]*G[{yu}, yv^(-1)]*G[{1, 1/(yu*yv), 1/(yu*yv)}, yw] + 
     4*G[{1}, yw]*G[{yu}, yv^(-1)]*G[{1, 1/(yu*yv), 1/(yu*yv)}, yw] - 
     G[{yu}, yv^(-1)]^2*G[{1, 1/(yu*yv), 1/(yu*yv)}, yw] - 
     6*G[{0}, yu^(-1)]*G[{yv^(-1)}, yw]*G[{1, 1/(yu*yv), 1/(yu*yv)}, yw] - 
     6*G[{0}, yv^(-1)]*G[{yv^(-1)}, yw]*G[{1, 1/(yu*yv), 1/(yu*yv)}, yw] + 
     6*G[{0}, yw]*G[{yv^(-1)}, yw]*G[{1, 1/(yu*yv), 1/(yu*yv)}, yw] + 
     6*G[{1}, yu^(-1)]*G[{yv^(-1)}, yw]*G[{1, 1/(yu*yv), 1/(yu*yv)}, yw] + 
     4*G[{1}, yv^(-1)]*G[{yv^(-1)}, yw]*G[{1, 1/(yu*yv), 1/(yu*yv)}, yw] - 
     2*G[{1}, yw]*G[{yv^(-1)}, yw]*G[{1, 1/(yu*yv), 1/(yu*yv)}, yw] + 
     2*G[{yu}, yv^(-1)]*G[{yv^(-1)}, yw]*G[{1, 1/(yu*yv), 1/(yu*yv)}, yw] - 
     3*G[{yv^(-1)}, yw]^2*G[{1, 1/(yu*yv), 1/(yu*yv)}, yw] + 
     6*G[{0}, yu^(-1)]*G[{1/(yu*yv)}, yw]*G[{1, 1/(yu*yv), 1/(yu*yv)}, yw] + 
     6*G[{0}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{1, 1/(yu*yv), 1/(yu*yv)}, yw] - 
     6*G[{0}, yw]*G[{1/(yu*yv)}, yw]*G[{1, 1/(yu*yv), 1/(yu*yv)}, yw] - 
     6*G[{1}, yu^(-1)]*G[{1/(yu*yv)}, yw]*G[{1, 1/(yu*yv), 1/(yu*yv)}, yw] - 
     4*G[{1}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{1, 1/(yu*yv), 1/(yu*yv)}, yw] + 
     2*G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{1, 1/(yu*yv), 1/(yu*yv)}, yw] - 
     2*G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{1, 1/(yu*yv), 1/(yu*yv)}, yw] + 
     6*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{1, 1/(yu*yv), 1/(yu*yv)}, yw] + 
     2*G[{0, 1}, yv^(-1)]*G[{1, 1/(yu*yv), 1/(yu*yv)}, yw] + 
     2*G[{0, 1}, yw]*G[{1, 1/(yu*yv), 1/(yu*yv)}, yw] - 
     2*G[{0, yu^(-1)}, yw]*G[{1, 1/(yu*yv), 1/(yu*yv)}, yw] - 
     2*G[{0, yu}, yv^(-1)]*G[{1, 1/(yu*yv), 1/(yu*yv)}, yw] - 
     2*G[{0, yv^(-1)}, yw]*G[{1, 1/(yu*yv), 1/(yu*yv)}, yw] + 
     2*G[{0, 1/(yu*yv)}, yw]*G[{1, 1/(yu*yv), 1/(yu*yv)}, yw] + 
     4*G[{1, yu^(-1)}, yw]*G[{1, 1/(yu*yv), 1/(yu*yv)}, yw] + 
     2*G[{1, yu}, yv^(-1)]*G[{1, 1/(yu*yv), 1/(yu*yv)}, yw] + 
     2*G[{1, yv^(-1)}, yw]*G[{1, 1/(yu*yv), 1/(yu*yv)}, yw] - 
     2*G[{1, 1/(yu*yv)}, yw]*G[{1, 1/(yu*yv), 1/(yu*yv)}, yw] - 
     6*G[{yv^(-1), 1/(yu*yv)}, yw]*G[{1, 1/(yu*yv), 1/(yu*yv)}, yw] + 
     4*G[{0}, yu^(-1)]*G[{yv^(-1)}, yw]*G[{yu^(-1), yu^(-1), 1/(yu*yv)}, 
       yw] + 4*G[{0}, yv^(-1)]*G[{yv^(-1)}, yw]*
      G[{yu^(-1), yu^(-1), 1/(yu*yv)}, yw] - 4*G[{0}, yw]*G[{yv^(-1)}, yw]*
      G[{yu^(-1), yu^(-1), 1/(yu*yv)}, yw] - 4*G[{1}, yu^(-1)]*
      G[{yv^(-1)}, yw]*G[{yu^(-1), yu^(-1), 1/(yu*yv)}, yw] - 
     8*G[{1}, yv^(-1)]*G[{yv^(-1)}, yw]*G[{yu^(-1), yu^(-1), 1/(yu*yv)}, 
       yw] - 4*G[{1}, yw]*G[{yv^(-1)}, yw]*G[{yu^(-1), yu^(-1), 1/(yu*yv)}, 
       yw] + 8*G[{yu^(-1)}, yw]*G[{yv^(-1)}, yw]*
      G[{yu^(-1), yu^(-1), 1/(yu*yv)}, yw] + 4*G[{yu}, yv^(-1)]*
      G[{yv^(-1)}, yw]*G[{yu^(-1), yu^(-1), 1/(yu*yv)}, yw] - 
     4*G[{0}, yu^(-1)]*G[{1/(yu*yv)}, yw]*G[{yu^(-1), yu^(-1), 1/(yu*yv)}, 
       yw] - 4*G[{0}, yv^(-1)]*G[{1/(yu*yv)}, yw]*
      G[{yu^(-1), yu^(-1), 1/(yu*yv)}, yw] + 4*G[{0}, yw]*G[{1/(yu*yv)}, yw]*
      G[{yu^(-1), yu^(-1), 1/(yu*yv)}, yw] + 4*G[{1}, yu^(-1)]*
      G[{1/(yu*yv)}, yw]*G[{yu^(-1), yu^(-1), 1/(yu*yv)}, yw] + 
     8*G[{1}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{yu^(-1), yu^(-1), 1/(yu*yv)}, 
       yw] + 4*G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{yu^(-1), yu^(-1), 1/(yu*yv)}, 
       yw] - 8*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*
      G[{yu^(-1), yu^(-1), 1/(yu*yv)}, yw] - 4*G[{yu}, yv^(-1)]*
      G[{1/(yu*yv)}, yw]*G[{yu^(-1), yu^(-1), 1/(yu*yv)}, yw] - 
     2*G[{1/(yu*yv)}, yw]^2*G[{yu^(-1), yu^(-1), 1/(yu*yv)}, yw] + 
     4*G[{yv^(-1), 1/(yu*yv)}, yw]*G[{yu^(-1), yu^(-1), 1/(yu*yv)}, yw] + 
     (Pi^2*G[{yu^(-1), 1/(yu*yv), yv^(-1)}, yw])/3 - 
     2*G[{0}, yu^(-1)]*G[{1}, yv^(-1)]*G[{yu^(-1), 1/(yu*yv), yv^(-1)}, yw] - 
     2*G[{0}, yv^(-1)]*G[{1}, yv^(-1)]*G[{yu^(-1), 1/(yu*yv), yv^(-1)}, yw] + 
     2*G[{0}, yw]*G[{1}, yv^(-1)]*G[{yu^(-1), 1/(yu*yv), yv^(-1)}, yw] + 
     2*G[{1}, yv^(-1)]^2*G[{yu^(-1), 1/(yu*yv), yv^(-1)}, yw] - 
     4*G[{0}, yu^(-1)]*G[{1}, yw]*G[{yu^(-1), 1/(yu*yv), yv^(-1)}, yw] - 
     4*G[{0}, yv^(-1)]*G[{1}, yw]*G[{yu^(-1), 1/(yu*yv), yv^(-1)}, yw] + 
     4*G[{0}, yw]*G[{1}, yw]*G[{yu^(-1), 1/(yu*yv), yv^(-1)}, yw] + 
     4*G[{1}, yu^(-1)]*G[{1}, yw]*G[{yu^(-1), 1/(yu*yv), yv^(-1)}, yw] + 
     4*G[{1}, yv^(-1)]*G[{1}, yw]*G[{yu^(-1), 1/(yu*yv), yv^(-1)}, yw] + 
     4*G[{0}, yu^(-1)]*G[{yu^(-1)}, yw]*G[{yu^(-1), 1/(yu*yv), yv^(-1)}, 
       yw] + 4*G[{0}, yv^(-1)]*G[{yu^(-1)}, yw]*
      G[{yu^(-1), 1/(yu*yv), yv^(-1)}, yw] - 4*G[{0}, yw]*G[{yu^(-1)}, yw]*
      G[{yu^(-1), 1/(yu*yv), yv^(-1)}, yw] - 4*G[{1}, yu^(-1)]*
      G[{yu^(-1)}, yw]*G[{yu^(-1), 1/(yu*yv), yv^(-1)}, yw] - 
     8*G[{1}, yv^(-1)]*G[{yu^(-1)}, yw]*G[{yu^(-1), 1/(yu*yv), yv^(-1)}, 
       yw] - 4*G[{1}, yw]*G[{yu^(-1)}, yw]*G[{yu^(-1), 1/(yu*yv), yv^(-1)}, 
       yw] + 4*G[{yu^(-1)}, yw]^2*G[{yu^(-1), 1/(yu*yv), yv^(-1)}, yw] + 
     2*G[{0}, yu^(-1)]*G[{yu}, yv^(-1)]*G[{yu^(-1), 1/(yu*yv), yv^(-1)}, 
       yw] + 2*G[{0}, yv^(-1)]*G[{yu}, yv^(-1)]*
      G[{yu^(-1), 1/(yu*yv), yv^(-1)}, yw] - 2*G[{0}, yw]*G[{yu}, yv^(-1)]*
      G[{yu^(-1), 1/(yu*yv), yv^(-1)}, yw] - 4*G[{1}, yv^(-1)]*
      G[{yu}, yv^(-1)]*G[{yu^(-1), 1/(yu*yv), yv^(-1)}, yw] + 
     4*G[{yu^(-1)}, yw]*G[{yu}, yv^(-1)]*G[{yu^(-1), 1/(yu*yv), yv^(-1)}, 
       yw] - 2*G[{0}, yu^(-1)]*G[{yv^(-1)}, yw]*
      G[{yu^(-1), 1/(yu*yv), yv^(-1)}, yw] - 2*G[{0}, yv^(-1)]*
      G[{yv^(-1)}, yw]*G[{yu^(-1), 1/(yu*yv), yv^(-1)}, yw] + 
     2*G[{0}, yw]*G[{yv^(-1)}, yw]*G[{yu^(-1), 1/(yu*yv), yv^(-1)}, yw] + 
     4*G[{1}, yu^(-1)]*G[{yv^(-1)}, yw]*G[{yu^(-1), 1/(yu*yv), yv^(-1)}, 
       yw] + 4*G[{1}, yv^(-1)]*G[{yv^(-1)}, yw]*
      G[{yu^(-1), 1/(yu*yv), yv^(-1)}, yw] + 4*G[{1}, yw]*G[{yv^(-1)}, yw]*
      G[{yu^(-1), 1/(yu*yv), yv^(-1)}, yw] - 4*G[{yu^(-1)}, yw]*
      G[{yv^(-1)}, yw]*G[{yu^(-1), 1/(yu*yv), yv^(-1)}, yw] - 
     4*G[{yu}, yv^(-1)]*G[{yv^(-1)}, yw]*G[{yu^(-1), 1/(yu*yv), yv^(-1)}, 
       yw] + 2*G[{0}, yu^(-1)]*G[{1/(yu*yv)}, yw]*
      G[{yu^(-1), 1/(yu*yv), yv^(-1)}, yw] + 2*G[{0}, yv^(-1)]*
      G[{1/(yu*yv)}, yw]*G[{yu^(-1), 1/(yu*yv), yv^(-1)}, yw] - 
     2*G[{0}, yw]*G[{1/(yu*yv)}, yw]*G[{yu^(-1), 1/(yu*yv), yv^(-1)}, yw] - 
     4*G[{1}, yu^(-1)]*G[{1/(yu*yv)}, yw]*G[{yu^(-1), 1/(yu*yv), yv^(-1)}, 
       yw] - 4*G[{1}, yv^(-1)]*G[{1/(yu*yv)}, yw]*
      G[{yu^(-1), 1/(yu*yv), yv^(-1)}, yw] - 4*G[{1}, yw]*G[{1/(yu*yv)}, yw]*
      G[{yu^(-1), 1/(yu*yv), yv^(-1)}, yw] + 4*G[{yu^(-1)}, yw]*
      G[{1/(yu*yv)}, yw]*G[{yu^(-1), 1/(yu*yv), yv^(-1)}, yw] + 
     4*G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{yu^(-1), 1/(yu*yv), yv^(-1)}, 
       yw] - 2*G[{0, 1}, yu^(-1)]*G[{yu^(-1), 1/(yu*yv), yv^(-1)}, yw] + 
     2*G[{0, 1}, yv^(-1)]*G[{yu^(-1), 1/(yu*yv), yv^(-1)}, yw] - 
     2*G[{0, 1}, yw]*G[{yu^(-1), 1/(yu*yv), yv^(-1)}, yw] + 
     2*G[{0, yu^(-1)}, yw]*G[{yu^(-1), 1/(yu*yv), yv^(-1)}, yw] - 
     2*G[{0, yu}, yv^(-1)]*G[{yu^(-1), 1/(yu*yv), yv^(-1)}, yw] + 
     2*G[{0, yv^(-1)}, yw]*G[{yu^(-1), 1/(yu*yv), yv^(-1)}, yw] - 
     2*G[{0, 1/(yu*yv)}, yw]*G[{yu^(-1), 1/(yu*yv), yv^(-1)}, yw] + 
     4*G[{1, yu}, yv^(-1)]*G[{yu^(-1), 1/(yu*yv), yv^(-1)}, yw] - 
     4*G[{1, yv^(-1)}, yw]*G[{yu^(-1), 1/(yu*yv), yv^(-1)}, yw] + 
     4*G[{yu^(-1), 1/(yu*yv)}, yw]*G[{yu^(-1), 1/(yu*yv), yv^(-1)}, yw] - 
     (Pi^2*G[{yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/3 + 
     2*G[{0}, yu^(-1)]*G[{1}, yv^(-1)]*G[{yu^(-1), 1/(yu*yv), 1/(yu*yv)}, 
       yw] + 2*G[{0}, yv^(-1)]*G[{1}, yv^(-1)]*
      G[{yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] - 2*G[{0}, yw]*G[{1}, yv^(-1)]*
      G[{yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] - 2*G[{1}, yv^(-1)]^2*
      G[{yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] + 4*G[{0}, yu^(-1)]*G[{1}, yw]*
      G[{yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] + 4*G[{0}, yv^(-1)]*G[{1}, yw]*
      G[{yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] - 4*G[{0}, yw]*G[{1}, yw]*
      G[{yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] - 4*G[{1}, yu^(-1)]*G[{1}, yw]*
      G[{yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] - 4*G[{1}, yv^(-1)]*G[{1}, yw]*
      G[{yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] - 4*G[{0}, yu^(-1)]*
      G[{yu^(-1)}, yw]*G[{yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] - 
     4*G[{0}, yv^(-1)]*G[{yu^(-1)}, yw]*G[{yu^(-1), 1/(yu*yv), 1/(yu*yv)}, 
       yw] + 4*G[{0}, yw]*G[{yu^(-1)}, yw]*G[{yu^(-1), 1/(yu*yv), 1/(yu*yv)}, 
       yw] + 4*G[{1}, yu^(-1)]*G[{yu^(-1)}, yw]*
      G[{yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] + 8*G[{1}, yv^(-1)]*
      G[{yu^(-1)}, yw]*G[{yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] + 
     4*G[{1}, yw]*G[{yu^(-1)}, yw]*G[{yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] - 
     4*G[{yu^(-1)}, yw]^2*G[{yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] - 
     2*G[{0}, yu^(-1)]*G[{yu}, yv^(-1)]*G[{yu^(-1), 1/(yu*yv), 1/(yu*yv)}, 
       yw] - 2*G[{0}, yv^(-1)]*G[{yu}, yv^(-1)]*
      G[{yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] + 2*G[{0}, yw]*G[{yu}, yv^(-1)]*
      G[{yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] + 4*G[{1}, yv^(-1)]*
      G[{yu}, yv^(-1)]*G[{yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] - 
     4*G[{yu^(-1)}, yw]*G[{yu}, yv^(-1)]*G[{yu^(-1), 1/(yu*yv), 1/(yu*yv)}, 
       yw] + 2*G[{0}, yu^(-1)]*G[{yv^(-1)}, yw]*
      G[{yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] + 2*G[{0}, yv^(-1)]*
      G[{yv^(-1)}, yw]*G[{yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] - 
     2*G[{0}, yw]*G[{yv^(-1)}, yw]*G[{yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] - 
     4*G[{1}, yu^(-1)]*G[{yv^(-1)}, yw]*G[{yu^(-1), 1/(yu*yv), 1/(yu*yv)}, 
       yw] - 4*G[{1}, yv^(-1)]*G[{yv^(-1)}, yw]*
      G[{yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] - 4*G[{1}, yw]*G[{yv^(-1)}, yw]*
      G[{yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] + 4*G[{yu^(-1)}, yw]*
      G[{yv^(-1)}, yw]*G[{yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] + 
     4*G[{yu}, yv^(-1)]*G[{yv^(-1)}, yw]*G[{yu^(-1), 1/(yu*yv), 1/(yu*yv)}, 
       yw] - 2*G[{0}, yu^(-1)]*G[{1/(yu*yv)}, yw]*
      G[{yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] - 2*G[{0}, yv^(-1)]*
      G[{1/(yu*yv)}, yw]*G[{yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] + 
     2*G[{0}, yw]*G[{1/(yu*yv)}, yw]*G[{yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] + 
     4*G[{1}, yu^(-1)]*G[{1/(yu*yv)}, yw]*G[{yu^(-1), 1/(yu*yv), 1/(yu*yv)}, 
       yw] + 4*G[{1}, yv^(-1)]*G[{1/(yu*yv)}, yw]*
      G[{yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] + 
     4*G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] - 
     4*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{yu^(-1), 1/(yu*yv), 1/(yu*yv)}, 
       yw] - 4*G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw]*
      G[{yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] + 2*G[{0, 1}, yu^(-1)]*
      G[{yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] - 2*G[{0, 1}, yv^(-1)]*
      G[{yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] + 2*G[{0, 1}, yw]*
      G[{yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] - 2*G[{0, yu^(-1)}, yw]*
      G[{yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] + 2*G[{0, yu}, yv^(-1)]*
      G[{yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] - 2*G[{0, yv^(-1)}, yw]*
      G[{yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] + 2*G[{0, 1/(yu*yv)}, yw]*
      G[{yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] - 4*G[{1, yu}, yv^(-1)]*
      G[{yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] + 4*G[{1, yv^(-1)}, yw]*
      G[{yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] - 4*G[{yu^(-1), 1/(yu*yv)}, yw]*
      G[{yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] - 
     (2*Pi^2*G[{yv^(-1), yv^(-1), 1/(yu*yv)}, yw])/3 + 
     8*G[{0}, yu^(-1)]*G[{1}, yv^(-1)]*G[{yv^(-1), yv^(-1), 1/(yu*yv)}, yw] + 
     8*G[{0}, yv^(-1)]*G[{1}, yv^(-1)]*G[{yv^(-1), yv^(-1), 1/(yu*yv)}, yw] - 
     8*G[{0}, yw]*G[{1}, yv^(-1)]*G[{yv^(-1), yv^(-1), 1/(yu*yv)}, yw] - 
     10*G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*G[{yv^(-1), yv^(-1), 1/(yu*yv)}, 
       yw] - 6*G[{1}, yv^(-1)]^2*G[{yv^(-1), yv^(-1), 1/(yu*yv)}, yw] + 
     4*G[{0}, yu^(-1)]*G[{1}, yw]*G[{yv^(-1), yv^(-1), 1/(yu*yv)}, yw] + 
     4*G[{0}, yv^(-1)]*G[{1}, yw]*G[{yv^(-1), yv^(-1), 1/(yu*yv)}, yw] - 
     4*G[{0}, yw]*G[{1}, yw]*G[{yv^(-1), yv^(-1), 1/(yu*yv)}, yw] - 
     4*G[{1}, yu^(-1)]*G[{1}, yw]*G[{yv^(-1), yv^(-1), 1/(yu*yv)}, yw] + 
     2*G[{1}, yw]^2*G[{yv^(-1), yv^(-1), 1/(yu*yv)}, yw] - 
     4*G[{0}, yu^(-1)]*G[{yu^(-1)}, yw]*G[{yv^(-1), yv^(-1), 1/(yu*yv)}, 
       yw] - 4*G[{0}, yv^(-1)]*G[{yu^(-1)}, yw]*
      G[{yv^(-1), yv^(-1), 1/(yu*yv)}, yw] + 4*G[{0}, yw]*G[{yu^(-1)}, yw]*
      G[{yv^(-1), yv^(-1), 1/(yu*yv)}, yw] + 4*G[{1}, yu^(-1)]*
      G[{yu^(-1)}, yw]*G[{yv^(-1), yv^(-1), 1/(yu*yv)}, yw] + 
     8*G[{1}, yv^(-1)]*G[{yu^(-1)}, yw]*G[{yv^(-1), yv^(-1), 1/(yu*yv)}, 
       yw] + 4*G[{1}, yw]*G[{yu^(-1)}, yw]*G[{yv^(-1), yv^(-1), 1/(yu*yv)}, 
       yw] - 4*G[{yu^(-1)}, yw]^2*G[{yv^(-1), yv^(-1), 1/(yu*yv)}, yw] - 
     8*G[{0}, yu^(-1)]*G[{yu}, yv^(-1)]*G[{yv^(-1), yv^(-1), 1/(yu*yv)}, 
       yw] - 8*G[{0}, yv^(-1)]*G[{yu}, yv^(-1)]*
      G[{yv^(-1), yv^(-1), 1/(yu*yv)}, yw] + 8*G[{0}, yw]*G[{yu}, yv^(-1)]*
      G[{yv^(-1), yv^(-1), 1/(yu*yv)}, yw] + 10*G[{1}, yu^(-1)]*
      G[{yu}, yv^(-1)]*G[{yv^(-1), yv^(-1), 1/(yu*yv)}, yw] + 
     4*G[{1}, yv^(-1)]*G[{yu}, yv^(-1)]*G[{yv^(-1), yv^(-1), 1/(yu*yv)}, 
       yw] - 4*G[{1}, yw]*G[{yu}, yv^(-1)]*G[{yv^(-1), yv^(-1), 1/(yu*yv)}, 
       yw] - 4*G[{yu^(-1)}, yw]*G[{yu}, yv^(-1)]*
      G[{yv^(-1), yv^(-1), 1/(yu*yv)}, yw] + G[{yu}, yv^(-1)]^2*
      G[{yv^(-1), yv^(-1), 1/(yu*yv)}, yw] + 4*G[{0}, yu^(-1)]*
      G[{yv^(-1)}, yw]*G[{yv^(-1), yv^(-1), 1/(yu*yv)}, yw] + 
     4*G[{0}, yv^(-1)]*G[{yv^(-1)}, yw]*G[{yv^(-1), yv^(-1), 1/(yu*yv)}, 
       yw] - 4*G[{0}, yw]*G[{yv^(-1)}, yw]*G[{yv^(-1), yv^(-1), 1/(yu*yv)}, 
       yw] - 2*G[{1}, yu^(-1)]*G[{yv^(-1)}, yw]*
      G[{yv^(-1), yv^(-1), 1/(yu*yv)}, yw] + 4*G[{1}, yv^(-1)]*
      G[{yv^(-1)}, yw]*G[{yv^(-1), yv^(-1), 1/(yu*yv)}, yw] + 
     10*G[{1}, yw]*G[{yv^(-1)}, yw]*G[{yv^(-1), yv^(-1), 1/(yu*yv)}, yw] - 
     4*G[{yu^(-1)}, yw]*G[{yv^(-1)}, yw]*G[{yv^(-1), yv^(-1), 1/(yu*yv)}, 
       yw] - 10*G[{yu}, yv^(-1)]*G[{yv^(-1)}, yw]*
      G[{yv^(-1), yv^(-1), 1/(yu*yv)}, yw] + G[{yv^(-1)}, yw]^2*
      G[{yv^(-1), yv^(-1), 1/(yu*yv)}, yw] - 4*G[{0}, yu^(-1)]*
      G[{1/(yu*yv)}, yw]*G[{yv^(-1), yv^(-1), 1/(yu*yv)}, yw] - 
     4*G[{0}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{yv^(-1), yv^(-1), 1/(yu*yv)}, 
       yw] + 4*G[{0}, yw]*G[{1/(yu*yv)}, yw]*G[{yv^(-1), yv^(-1), 1/(yu*yv)}, 
       yw] + 2*G[{1}, yu^(-1)]*G[{1/(yu*yv)}, yw]*
      G[{yv^(-1), yv^(-1), 1/(yu*yv)}, yw] + 4*G[{1}, yv^(-1)]*
      G[{1/(yu*yv)}, yw]*G[{yv^(-1), yv^(-1), 1/(yu*yv)}, yw] - 
     2*G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{yv^(-1), yv^(-1), 1/(yu*yv)}, yw] - 
     4*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{yv^(-1), yv^(-1), 1/(yu*yv)}, 
       yw] + 2*G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw]*
      G[{yv^(-1), yv^(-1), 1/(yu*yv)}, yw] - 2*G[{yv^(-1)}, yw]*
      G[{1/(yu*yv)}, yw]*G[{yv^(-1), yv^(-1), 1/(yu*yv)}, yw] + 
     2*G[{1/(yu*yv)}, yw]^2*G[{yv^(-1), yv^(-1), 1/(yu*yv)}, yw] - 
     2*G[{0, 1}, yu^(-1)]*G[{yv^(-1), yv^(-1), 1/(yu*yv)}, yw] - 
     4*G[{0, 1}, yw]*G[{yv^(-1), yv^(-1), 1/(yu*yv)}, yw] + 
     4*G[{0, yu^(-1)}, yw]*G[{yv^(-1), yv^(-1), 1/(yu*yv)}, yw] + 
     4*G[{0, yv^(-1)}, yw]*G[{yv^(-1), yv^(-1), 1/(yu*yv)}, yw] - 
     4*G[{0, 1/(yu*yv)}, yw]*G[{yv^(-1), yv^(-1), 1/(yu*yv)}, yw] - 
     4*G[{1, yu^(-1)}, yw]*G[{yv^(-1), yv^(-1), 1/(yu*yv)}, yw] + 
     2*G[{1, yu}, yv^(-1)]*G[{yv^(-1), yv^(-1), 1/(yu*yv)}, yw] - 
     6*G[{1, yv^(-1)}, yw]*G[{yv^(-1), yv^(-1), 1/(yu*yv)}, yw] + 
     2*G[{1, 1/(yu*yv)}, yw]*G[{yv^(-1), yv^(-1), 1/(yu*yv)}, yw] + 
     4*G[{yu^(-1), 1/(yu*yv)}, yw]*G[{yv^(-1), yv^(-1), 1/(yu*yv)}, yw] + 
     6*G[{yv^(-1), 1/(yu*yv)}, yw]*G[{yv^(-1), yv^(-1), 1/(yu*yv)}, yw] - 
     (2*Pi^2*G[{yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/3 + 
     8*G[{0}, yu^(-1)]*G[{1}, yv^(-1)]*G[{yv^(-1), 1/(yu*yv), 1/(yu*yv)}, 
       yw] + 8*G[{0}, yv^(-1)]*G[{1}, yv^(-1)]*
      G[{yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] - 8*G[{0}, yw]*G[{1}, yv^(-1)]*
      G[{yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] - 10*G[{1}, yu^(-1)]*
      G[{1}, yv^(-1)]*G[{yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] - 
     6*G[{1}, yv^(-1)]^2*G[{yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] + 
     4*G[{0}, yu^(-1)]*G[{1}, yw]*G[{yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] + 
     4*G[{0}, yv^(-1)]*G[{1}, yw]*G[{yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] - 
     4*G[{0}, yw]*G[{1}, yw]*G[{yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] - 
     4*G[{1}, yu^(-1)]*G[{1}, yw]*G[{yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] + 
     2*G[{1}, yw]^2*G[{yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] - 
     4*G[{0}, yu^(-1)]*G[{yu^(-1)}, yw]*G[{yv^(-1), 1/(yu*yv), 1/(yu*yv)}, 
       yw] - 4*G[{0}, yv^(-1)]*G[{yu^(-1)}, yw]*
      G[{yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] + 4*G[{0}, yw]*G[{yu^(-1)}, yw]*
      G[{yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] + 4*G[{1}, yu^(-1)]*
      G[{yu^(-1)}, yw]*G[{yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] + 
     8*G[{1}, yv^(-1)]*G[{yu^(-1)}, yw]*G[{yv^(-1), 1/(yu*yv), 1/(yu*yv)}, 
       yw] + 4*G[{1}, yw]*G[{yu^(-1)}, yw]*G[{yv^(-1), 1/(yu*yv), 1/(yu*yv)}, 
       yw] - 4*G[{yu^(-1)}, yw]^2*G[{yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] - 
     8*G[{0}, yu^(-1)]*G[{yu}, yv^(-1)]*G[{yv^(-1), 1/(yu*yv), 1/(yu*yv)}, 
       yw] - 8*G[{0}, yv^(-1)]*G[{yu}, yv^(-1)]*
      G[{yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] + 8*G[{0}, yw]*G[{yu}, yv^(-1)]*
      G[{yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] + 10*G[{1}, yu^(-1)]*
      G[{yu}, yv^(-1)]*G[{yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] + 
     4*G[{1}, yv^(-1)]*G[{yu}, yv^(-1)]*G[{yv^(-1), 1/(yu*yv), 1/(yu*yv)}, 
       yw] - 4*G[{1}, yw]*G[{yu}, yv^(-1)]*G[{yv^(-1), 1/(yu*yv), 1/(yu*yv)}, 
       yw] - 4*G[{yu^(-1)}, yw]*G[{yu}, yv^(-1)]*
      G[{yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] + G[{yu}, yv^(-1)]^2*
      G[{yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] + 4*G[{0}, yu^(-1)]*
      G[{yv^(-1)}, yw]*G[{yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] + 
     4*G[{0}, yv^(-1)]*G[{yv^(-1)}, yw]*G[{yv^(-1), 1/(yu*yv), 1/(yu*yv)}, 
       yw] - 4*G[{0}, yw]*G[{yv^(-1)}, yw]*G[{yv^(-1), 1/(yu*yv), 1/(yu*yv)}, 
       yw] - 2*G[{1}, yu^(-1)]*G[{yv^(-1)}, yw]*
      G[{yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] + 4*G[{1}, yv^(-1)]*
      G[{yv^(-1)}, yw]*G[{yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] + 
     10*G[{1}, yw]*G[{yv^(-1)}, yw]*G[{yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] - 
     4*G[{yu^(-1)}, yw]*G[{yv^(-1)}, yw]*G[{yv^(-1), 1/(yu*yv), 1/(yu*yv)}, 
       yw] - 10*G[{yu}, yv^(-1)]*G[{yv^(-1)}, yw]*
      G[{yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] + G[{yv^(-1)}, yw]^2*
      G[{yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] - 4*G[{0}, yu^(-1)]*
      G[{1/(yu*yv)}, yw]*G[{yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] - 
     4*G[{0}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{yv^(-1), 1/(yu*yv), 1/(yu*yv)}, 
       yw] + 4*G[{0}, yw]*G[{1/(yu*yv)}, yw]*
      G[{yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] + 2*G[{1}, yu^(-1)]*
      G[{1/(yu*yv)}, yw]*G[{yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] - 
     4*G[{1}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{yv^(-1), 1/(yu*yv), 1/(yu*yv)}, 
       yw] - 10*G[{1}, yw]*G[{1/(yu*yv)}, yw]*
      G[{yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] + 4*G[{yu^(-1)}, yw]*
      G[{1/(yu*yv)}, yw]*G[{yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] + 
     10*G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw]*
      G[{yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] - 2*G[{yv^(-1)}, yw]*
      G[{1/(yu*yv)}, yw]*G[{yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] - 
     2*G[{0, 1}, yu^(-1)]*G[{yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] - 
     4*G[{0, 1}, yw]*G[{yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] + 
     4*G[{0, yu^(-1)}, yw]*G[{yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] + 
     4*G[{0, yv^(-1)}, yw]*G[{yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] - 
     4*G[{0, 1/(yu*yv)}, yw]*G[{yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] - 
     4*G[{1, yu^(-1)}, yw]*G[{yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] + 
     2*G[{1, yu}, yv^(-1)]*G[{yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] - 
     6*G[{1, yv^(-1)}, yw]*G[{yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] + 
     2*G[{1, 1/(yu*yv)}, yw]*G[{yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] + 
     4*G[{yu^(-1), 1/(yu*yv)}, yw]*G[{yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] + 
     2*G[{yv^(-1), 1/(yu*yv)}, yw]*G[{yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] - 
     4*G[{yv^(-1)}, yw]*G[{0, 0, 1, 1}, yu^(-1)] + 4*G[{1/(yu*yv)}, yw]*
      G[{0, 0, 1, 1}, yu^(-1)] + 4*G[{1}, yv^(-1)]*G[{0, 0, 1, 1}, yv^(-1)] - 
     4*G[{yu}, yv^(-1)]*G[{0, 0, 1, 1}, yv^(-1)] - 
     4*G[{yv^(-1)}, yw]*G[{0, 0, 1, 1}, yw] + 4*G[{1/(yu*yv)}, yw]*
      G[{0, 0, 1, 1}, yw] + 4*G[{yv^(-1)}, yw]*G[{0, 0, 1, yu^(-1)}, yw] - 
     4*G[{1/(yu*yv)}, yw]*G[{0, 0, 1, yu^(-1)}, yw] - 
     4*G[{1}, yv^(-1)]*G[{0, 0, 1, yu}, yv^(-1)] + 
     4*G[{yu}, yv^(-1)]*G[{0, 0, 1, yu}, yv^(-1)] + 
     4*G[{yv^(-1)}, yw]*G[{0, 0, 1, yv^(-1)}, yw] - 
     4*G[{1/(yu*yv)}, yw]*G[{0, 0, 1, yv^(-1)}, yw] - 
     4*G[{yv^(-1)}, yw]*G[{0, 0, 1, 1/(yu*yv)}, yw] + 
     4*G[{1/(yu*yv)}, yw]*G[{0, 0, 1, 1/(yu*yv)}, yw] + 
     4*G[{yv^(-1)}, yw]*G[{0, 0, yu^(-1), 1}, yw] - 
     4*G[{1/(yu*yv)}, yw]*G[{0, 0, yu^(-1), 1}, yw] - 
     4*G[{yv^(-1)}, yw]*G[{0, 0, yu^(-1), yu^(-1)}, yw] + 
     4*G[{1/(yu*yv)}, yw]*G[{0, 0, yu^(-1), yu^(-1)}, yw] - 
     4*G[{yv^(-1)}, yw]*G[{0, 0, yu^(-1), yv^(-1)}, yw] + 
     4*G[{1/(yu*yv)}, yw]*G[{0, 0, yu^(-1), yv^(-1)}, yw] + 
     4*G[{yv^(-1)}, yw]*G[{0, 0, yu^(-1), 1/(yu*yv)}, yw] - 
     4*G[{1/(yu*yv)}, yw]*G[{0, 0, yu^(-1), 1/(yu*yv)}, yw] - 
     4*G[{1}, yv^(-1)]*G[{0, 0, yu, 1}, yv^(-1)] + 
     4*G[{yu}, yv^(-1)]*G[{0, 0, yu, 1}, yv^(-1)] + 
     4*G[{1}, yv^(-1)]*G[{0, 0, yu, yu}, yv^(-1)] - 
     4*G[{yu}, yv^(-1)]*G[{0, 0, yu, yu}, yv^(-1)] + 
     4*G[{yv^(-1)}, yw]*G[{0, 0, yv^(-1), 1}, yw] - 
     4*G[{1/(yu*yv)}, yw]*G[{0, 0, yv^(-1), 1}, yw] - 
     4*G[{yv^(-1)}, yw]*G[{0, 0, yv^(-1), yu^(-1)}, yw] + 
     4*G[{1/(yu*yv)}, yw]*G[{0, 0, yv^(-1), yu^(-1)}, yw] - 
     4*G[{1}, yv^(-1)]*G[{0, 0, yv^(-1), yv^(-1)}, yw] + 
     4*G[{yu}, yv^(-1)]*G[{0, 0, yv^(-1), yv^(-1)}, yw] + 
     4*G[{1}, yv^(-1)]*G[{0, 0, yv^(-1), 1/(yu*yv)}, yw] - 
     4*G[{yu}, yv^(-1)]*G[{0, 0, yv^(-1), 1/(yu*yv)}, yw] - 
     4*G[{yv^(-1)}, yw]*G[{0, 0, 1/(yu*yv), 1}, yw] + 
     4*G[{1/(yu*yv)}, yw]*G[{0, 0, 1/(yu*yv), 1}, yw] + 
     4*G[{yv^(-1)}, yw]*G[{0, 0, 1/(yu*yv), yu^(-1)}, yw] - 
     4*G[{1/(yu*yv)}, yw]*G[{0, 0, 1/(yu*yv), yu^(-1)}, yw] + 
     4*G[{1}, yv^(-1)]*G[{0, 0, 1/(yu*yv), yv^(-1)}, yw] - 
     4*G[{yu}, yv^(-1)]*G[{0, 0, 1/(yu*yv), yv^(-1)}, yw] - 
     4*G[{1}, yv^(-1)]*G[{0, 0, 1/(yu*yv), 1/(yu*yv)}, yw] + 
     4*G[{yu}, yv^(-1)]*G[{0, 0, 1/(yu*yv), 1/(yu*yv)}, yw] - 
     2*G[{1}, yv^(-1)]*G[{0, 1, 0, yv^(-1)}, yw] + 
     2*G[{yu}, yv^(-1)]*G[{0, 1, 0, yv^(-1)}, yw] + 
     2*G[{yv^(-1)}, yw]*G[{0, 1, 0, yv^(-1)}, yw] - 
     2*G[{1/(yu*yv)}, yw]*G[{0, 1, 0, yv^(-1)}, yw] + 
     2*G[{1}, yv^(-1)]*G[{0, 1, 0, 1/(yu*yv)}, yw] - 
     2*G[{yu}, yv^(-1)]*G[{0, 1, 0, 1/(yu*yv)}, yw] - 
     2*G[{yv^(-1)}, yw]*G[{0, 1, 0, 1/(yu*yv)}, yw] + 
     2*G[{1/(yu*yv)}, yw]*G[{0, 1, 0, 1/(yu*yv)}, yw] + 
     6*G[{1}, yv^(-1)]*G[{0, 1, 1, 1}, yv^(-1)] - 6*G[{yu}, yv^(-1)]*
      G[{0, 1, 1, 1}, yv^(-1)] - 6*G[{yv^(-1)}, yw]*
      G[{0, 1, 1, 1}, yv^(-1)] + 6*G[{1/(yu*yv)}, yw]*
      G[{0, 1, 1, 1}, yv^(-1)] - 2*G[{yv^(-1)}, yw]*G[{0, 1, 1, 1}, yw] + 
     2*G[{1/(yu*yv)}, yw]*G[{0, 1, 1, 1}, yw] - 2*G[{yv^(-1)}, yw]*
      G[{0, 1, 1, yu^(-1)}, yw] + 2*G[{1/(yu*yv)}, yw]*
      G[{0, 1, 1, yu^(-1)}, yw] + 2*G[{1}, yv^(-1)]*
      G[{0, 1, 1, yu}, yv^(-1)] - 2*G[{yu}, yv^(-1)]*
      G[{0, 1, 1, yu}, yv^(-1)] + 2*G[{yv^(-1)}, yw]*
      G[{0, 1, 1, yu}, yv^(-1)] - 2*G[{1/(yu*yv)}, yw]*
      G[{0, 1, 1, yu}, yv^(-1)] + 4*G[{0}, yu^(-1)]*G[{0, 1, 1, yv^(-1)}, 
       yw] + 4*G[{0}, yv^(-1)]*G[{0, 1, 1, yv^(-1)}, yw] - 
     4*G[{0}, yw]*G[{0, 1, 1, yv^(-1)}, yw] - 4*G[{1}, yu^(-1)]*
      G[{0, 1, 1, yv^(-1)}, yw] - 2*G[{1}, yv^(-1)]*G[{0, 1, 1, yv^(-1)}, 
       yw] - 2*G[{yu}, yv^(-1)]*G[{0, 1, 1, yv^(-1)}, yw] - 
     4*G[{yv^(-1)}, yw]*G[{0, 1, 1, yv^(-1)}, yw] + 
     4*G[{1/(yu*yv)}, yw]*G[{0, 1, 1, yv^(-1)}, yw] - 
     4*G[{0}, yu^(-1)]*G[{0, 1, 1, 1/(yu*yv)}, yw] - 
     4*G[{0}, yv^(-1)]*G[{0, 1, 1, 1/(yu*yv)}, yw] + 
     4*G[{0}, yw]*G[{0, 1, 1, 1/(yu*yv)}, yw] + 4*G[{1}, yu^(-1)]*
      G[{0, 1, 1, 1/(yu*yv)}, yw] + 2*G[{1}, yv^(-1)]*
      G[{0, 1, 1, 1/(yu*yv)}, yw] + 2*G[{yu}, yv^(-1)]*
      G[{0, 1, 1, 1/(yu*yv)}, yw] - 4*G[{yv^(-1)}, yw]*
      G[{0, 1, yu^(-1), 1}, yw] + 4*G[{1/(yu*yv)}, yw]*
      G[{0, 1, yu^(-1), 1}, yw] + 8*G[{yv^(-1)}, yw]*
      G[{0, 1, yu^(-1), yu^(-1)}, yw] - 8*G[{1/(yu*yv)}, yw]*
      G[{0, 1, yu^(-1), yu^(-1)}, yw] - 4*G[{0}, yu^(-1)]*
      G[{0, 1, yu^(-1), yv^(-1)}, yw] - 4*G[{0}, yv^(-1)]*
      G[{0, 1, yu^(-1), yv^(-1)}, yw] + 4*G[{0}, yw]*
      G[{0, 1, yu^(-1), yv^(-1)}, yw] + 4*G[{1}, yu^(-1)]*
      G[{0, 1, yu^(-1), yv^(-1)}, yw] + 8*G[{1}, yv^(-1)]*
      G[{0, 1, yu^(-1), yv^(-1)}, yw] - 4*G[{yu}, yv^(-1)]*
      G[{0, 1, yu^(-1), yv^(-1)}, yw] + 4*G[{yv^(-1)}, yw]*
      G[{0, 1, yu^(-1), yv^(-1)}, yw] - 4*G[{1/(yu*yv)}, yw]*
      G[{0, 1, yu^(-1), yv^(-1)}, yw] + 4*G[{0}, yu^(-1)]*
      G[{0, 1, yu^(-1), 1/(yu*yv)}, yw] + 4*G[{0}, yv^(-1)]*
      G[{0, 1, yu^(-1), 1/(yu*yv)}, yw] - 4*G[{0}, yw]*
      G[{0, 1, yu^(-1), 1/(yu*yv)}, yw] - 4*G[{1}, yu^(-1)]*
      G[{0, 1, yu^(-1), 1/(yu*yv)}, yw] - 8*G[{1}, yv^(-1)]*
      G[{0, 1, yu^(-1), 1/(yu*yv)}, yw] + 4*G[{yu}, yv^(-1)]*
      G[{0, 1, yu^(-1), 1/(yu*yv)}, yw] + 4*G[{yv^(-1)}, yw]*
      G[{0, 1, yu, 1}, yv^(-1)] - 4*G[{1/(yu*yv)}, yw]*
      G[{0, 1, yu, 1}, yv^(-1)] - 8*G[{1}, yv^(-1)]*
      G[{0, 1, yu, yu}, yv^(-1)] + 8*G[{yu}, yv^(-1)]*
      G[{0, 1, yu, yu}, yv^(-1)] + 4*G[{0}, yu^(-1)]*
      G[{0, 1, yv^(-1), 1}, yw] + 4*G[{0}, yv^(-1)]*G[{0, 1, yv^(-1), 1}, 
       yw] - 4*G[{0}, yw]*G[{0, 1, yv^(-1), 1}, yw] - 
     4*G[{1}, yu^(-1)]*G[{0, 1, yv^(-1), 1}, yw] - 
     4*G[{1}, yv^(-1)]*G[{0, 1, yv^(-1), 1}, yw] - 
     4*G[{yv^(-1)}, yw]*G[{0, 1, yv^(-1), 1}, yw] + 
     4*G[{1/(yu*yv)}, yw]*G[{0, 1, yv^(-1), 1}, yw] - 
     4*G[{0}, yu^(-1)]*G[{0, 1, yv^(-1), yu^(-1)}, yw] - 
     4*G[{0}, yv^(-1)]*G[{0, 1, yv^(-1), yu^(-1)}, yw] + 
     4*G[{0}, yw]*G[{0, 1, yv^(-1), yu^(-1)}, yw] + 
     4*G[{1}, yu^(-1)]*G[{0, 1, yv^(-1), yu^(-1)}, yw] + 
     8*G[{1}, yv^(-1)]*G[{0, 1, yv^(-1), yu^(-1)}, yw] - 
     4*G[{yu}, yv^(-1)]*G[{0, 1, yv^(-1), yu^(-1)}, yw] + 
     4*G[{yv^(-1)}, yw]*G[{0, 1, yv^(-1), yu^(-1)}, yw] - 
     4*G[{1/(yu*yv)}, yw]*G[{0, 1, yv^(-1), yu^(-1)}, yw] - 
     4*G[{0}, yu^(-1)]*G[{0, 1, yv^(-1), yv^(-1)}, yw] - 
     4*G[{0}, yv^(-1)]*G[{0, 1, yv^(-1), yv^(-1)}, yw] + 
     4*G[{0}, yw]*G[{0, 1, yv^(-1), yv^(-1)}, yw] + 
     4*G[{1}, yu^(-1)]*G[{0, 1, yv^(-1), yv^(-1)}, yw] + 
     8*G[{1}, yv^(-1)]*G[{0, 1, yv^(-1), yv^(-1)}, yw] - 
     4*G[{yu}, yv^(-1)]*G[{0, 1, yv^(-1), yv^(-1)}, yw] + 
     4*G[{yv^(-1)}, yw]*G[{0, 1, yv^(-1), yv^(-1)}, yw] - 
     4*G[{1/(yu*yv)}, yw]*G[{0, 1, yv^(-1), yv^(-1)}, yw] + 
     4*G[{0}, yu^(-1)]*G[{0, 1, yv^(-1), 1/(yu*yv)}, yw] + 
     4*G[{0}, yv^(-1)]*G[{0, 1, yv^(-1), 1/(yu*yv)}, yw] - 
     4*G[{0}, yw]*G[{0, 1, yv^(-1), 1/(yu*yv)}, yw] - 
     4*G[{1}, yu^(-1)]*G[{0, 1, yv^(-1), 1/(yu*yv)}, yw] - 
     8*G[{1}, yv^(-1)]*G[{0, 1, yv^(-1), 1/(yu*yv)}, yw] + 
     4*G[{yu}, yv^(-1)]*G[{0, 1, yv^(-1), 1/(yu*yv)}, yw] - 
     4*G[{0}, yu^(-1)]*G[{0, 1, 1/(yu*yv), 1}, yw] - 
     4*G[{0}, yv^(-1)]*G[{0, 1, 1/(yu*yv), 1}, yw] + 
     4*G[{0}, yw]*G[{0, 1, 1/(yu*yv), 1}, yw] + 4*G[{1}, yu^(-1)]*
      G[{0, 1, 1/(yu*yv), 1}, yw] + 4*G[{1}, yv^(-1)]*
      G[{0, 1, 1/(yu*yv), 1}, yw] + 2*G[{yv^(-1)}, yw]*
      G[{0, 1, 1/(yu*yv), 1}, yw] - 2*G[{1/(yu*yv)}, yw]*
      G[{0, 1, 1/(yu*yv), 1}, yw] + 4*G[{0}, yu^(-1)]*
      G[{0, 1, 1/(yu*yv), yu^(-1)}, yw] + 4*G[{0}, yv^(-1)]*
      G[{0, 1, 1/(yu*yv), yu^(-1)}, yw] - 4*G[{0}, yw]*
      G[{0, 1, 1/(yu*yv), yu^(-1)}, yw] - 4*G[{1}, yu^(-1)]*
      G[{0, 1, 1/(yu*yv), yu^(-1)}, yw] - 8*G[{1}, yv^(-1)]*
      G[{0, 1, 1/(yu*yv), yu^(-1)}, yw] + 4*G[{yu}, yv^(-1)]*
      G[{0, 1, 1/(yu*yv), yu^(-1)}, yw] - 2*G[{yv^(-1)}, yw]*
      G[{0, 1, 1/(yu*yv), yu^(-1)}, yw] + 2*G[{1/(yu*yv)}, yw]*
      G[{0, 1, 1/(yu*yv), yu^(-1)}, yw] + 4*G[{0}, yu^(-1)]*
      G[{0, 1, 1/(yu*yv), yv^(-1)}, yw] + 4*G[{0}, yv^(-1)]*
      G[{0, 1, 1/(yu*yv), yv^(-1)}, yw] - 4*G[{0}, yw]*
      G[{0, 1, 1/(yu*yv), yv^(-1)}, yw] - 4*G[{1}, yu^(-1)]*
      G[{0, 1, 1/(yu*yv), yv^(-1)}, yw] - 6*G[{1}, yv^(-1)]*
      G[{0, 1, 1/(yu*yv), yv^(-1)}, yw] + 2*G[{yu}, yv^(-1)]*
      G[{0, 1, 1/(yu*yv), yv^(-1)}, yw] - 4*G[{yv^(-1)}, yw]*
      G[{0, 1, 1/(yu*yv), yv^(-1)}, yw] + 4*G[{1/(yu*yv)}, yw]*
      G[{0, 1, 1/(yu*yv), yv^(-1)}, yw] - 4*G[{0}, yu^(-1)]*
      G[{0, 1, 1/(yu*yv), 1/(yu*yv)}, yw] - 4*G[{0}, yv^(-1)]*
      G[{0, 1, 1/(yu*yv), 1/(yu*yv)}, yw] + 4*G[{0}, yw]*
      G[{0, 1, 1/(yu*yv), 1/(yu*yv)}, yw] + 4*G[{1}, yu^(-1)]*
      G[{0, 1, 1/(yu*yv), 1/(yu*yv)}, yw] + 6*G[{1}, yv^(-1)]*
      G[{0, 1, 1/(yu*yv), 1/(yu*yv)}, yw] - 2*G[{yu}, yv^(-1)]*
      G[{0, 1, 1/(yu*yv), 1/(yu*yv)}, yw] + 2*G[{1}, yv^(-1)]*
      G[{0, yu^(-1), 0, yv^(-1)}, yw] - 2*G[{yu}, yv^(-1)]*
      G[{0, yu^(-1), 0, yv^(-1)}, yw] - 2*G[{yv^(-1)}, yw]*
      G[{0, yu^(-1), 0, yv^(-1)}, yw] + 2*G[{1/(yu*yv)}, yw]*
      G[{0, yu^(-1), 0, yv^(-1)}, yw] - 2*G[{1}, yv^(-1)]*
      G[{0, yu^(-1), 0, 1/(yu*yv)}, yw] + 2*G[{yu}, yv^(-1)]*
      G[{0, yu^(-1), 0, 1/(yu*yv)}, yw] + 2*G[{yv^(-1)}, yw]*
      G[{0, yu^(-1), 0, 1/(yu*yv)}, yw] - 2*G[{1/(yu*yv)}, yw]*
      G[{0, yu^(-1), 0, 1/(yu*yv)}, yw] + 2*G[{yv^(-1)}, yw]*
      G[{0, yu^(-1), 1, 1}, yw] - 2*G[{1/(yu*yv)}, yw]*
      G[{0, yu^(-1), 1, 1}, yw] + 2*G[{yv^(-1)}, yw]*
      G[{0, yu^(-1), 1, yu^(-1)}, yw] - 2*G[{1/(yu*yv)}, yw]*
      G[{0, yu^(-1), 1, yu^(-1)}, yw] - 4*G[{0}, yu^(-1)]*
      G[{0, yu^(-1), 1, yv^(-1)}, yw] - 4*G[{0}, yv^(-1)]*
      G[{0, yu^(-1), 1, yv^(-1)}, yw] + 4*G[{0}, yw]*
      G[{0, yu^(-1), 1, yv^(-1)}, yw] + 4*G[{1}, yu^(-1)]*
      G[{0, yu^(-1), 1, yv^(-1)}, yw] + 2*G[{1}, yv^(-1)]*
      G[{0, yu^(-1), 1, yv^(-1)}, yw] + 2*G[{yu}, yv^(-1)]*
      G[{0, yu^(-1), 1, yv^(-1)}, yw] + 4*G[{yv^(-1)}, yw]*
      G[{0, yu^(-1), 1, yv^(-1)}, yw] - 4*G[{1/(yu*yv)}, yw]*
      G[{0, yu^(-1), 1, yv^(-1)}, yw] + 4*G[{0}, yu^(-1)]*
      G[{0, yu^(-1), 1, 1/(yu*yv)}, yw] + 4*G[{0}, yv^(-1)]*
      G[{0, yu^(-1), 1, 1/(yu*yv)}, yw] - 4*G[{0}, yw]*
      G[{0, yu^(-1), 1, 1/(yu*yv)}, yw] - 4*G[{1}, yu^(-1)]*
      G[{0, yu^(-1), 1, 1/(yu*yv)}, yw] - 2*G[{1}, yv^(-1)]*
      G[{0, yu^(-1), 1, 1/(yu*yv)}, yw] - 2*G[{yu}, yv^(-1)]*
      G[{0, yu^(-1), 1, 1/(yu*yv)}, yw] + 4*G[{yv^(-1)}, yw]*
      G[{0, yu^(-1), yu^(-1), 1}, yw] - 4*G[{1/(yu*yv)}, yw]*
      G[{0, yu^(-1), yu^(-1), 1}, yw] - 8*G[{yv^(-1)}, yw]*
      G[{0, yu^(-1), yu^(-1), yu^(-1)}, yw] + 8*G[{1/(yu*yv)}, yw]*
      G[{0, yu^(-1), yu^(-1), yu^(-1)}, yw] + 4*G[{0}, yu^(-1)]*
      G[{0, yu^(-1), yu^(-1), yv^(-1)}, yw] + 4*G[{0}, yv^(-1)]*
      G[{0, yu^(-1), yu^(-1), yv^(-1)}, yw] - 
     4*G[{0}, yw]*G[{0, yu^(-1), yu^(-1), yv^(-1)}, yw] - 
     4*G[{1}, yu^(-1)]*G[{0, yu^(-1), yu^(-1), yv^(-1)}, yw] - 
     8*G[{1}, yv^(-1)]*G[{0, yu^(-1), yu^(-1), yv^(-1)}, yw] + 
     4*G[{yu}, yv^(-1)]*G[{0, yu^(-1), yu^(-1), yv^(-1)}, yw] - 
     4*G[{yv^(-1)}, yw]*G[{0, yu^(-1), yu^(-1), yv^(-1)}, yw] + 
     4*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1), yu^(-1), yv^(-1)}, yw] - 
     4*G[{0}, yu^(-1)]*G[{0, yu^(-1), yu^(-1), 1/(yu*yv)}, yw] - 
     4*G[{0}, yv^(-1)]*G[{0, yu^(-1), yu^(-1), 1/(yu*yv)}, yw] + 
     4*G[{0}, yw]*G[{0, yu^(-1), yu^(-1), 1/(yu*yv)}, yw] + 
     4*G[{1}, yu^(-1)]*G[{0, yu^(-1), yu^(-1), 1/(yu*yv)}, yw] + 
     8*G[{1}, yv^(-1)]*G[{0, yu^(-1), yu^(-1), 1/(yu*yv)}, yw] - 
     4*G[{yu}, yv^(-1)]*G[{0, yu^(-1), yu^(-1), 1/(yu*yv)}, yw] - 
     4*G[{0}, yu^(-1)]*G[{0, yu^(-1), yv^(-1), 1}, yw] - 
     4*G[{0}, yv^(-1)]*G[{0, yu^(-1), yv^(-1), 1}, yw] + 
     4*G[{0}, yw]*G[{0, yu^(-1), yv^(-1), 1}, yw] + 
     4*G[{1}, yu^(-1)]*G[{0, yu^(-1), yv^(-1), 1}, yw] + 
     4*G[{1}, yv^(-1)]*G[{0, yu^(-1), yv^(-1), 1}, yw] + 
     4*G[{yv^(-1)}, yw]*G[{0, yu^(-1), yv^(-1), 1}, yw] - 
     4*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1), yv^(-1), 1}, yw] + 
     4*G[{0}, yu^(-1)]*G[{0, yu^(-1), yv^(-1), yu^(-1)}, yw] + 
     4*G[{0}, yv^(-1)]*G[{0, yu^(-1), yv^(-1), yu^(-1)}, yw] - 
     4*G[{0}, yw]*G[{0, yu^(-1), yv^(-1), yu^(-1)}, yw] - 
     4*G[{1}, yu^(-1)]*G[{0, yu^(-1), yv^(-1), yu^(-1)}, yw] - 
     8*G[{1}, yv^(-1)]*G[{0, yu^(-1), yv^(-1), yu^(-1)}, yw] + 
     4*G[{yu}, yv^(-1)]*G[{0, yu^(-1), yv^(-1), yu^(-1)}, yw] - 
     4*G[{yv^(-1)}, yw]*G[{0, yu^(-1), yv^(-1), yu^(-1)}, yw] + 
     4*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1), yv^(-1), yu^(-1)}, yw] + 
     4*G[{0}, yu^(-1)]*G[{0, yu^(-1), yv^(-1), yv^(-1)}, yw] + 
     4*G[{0}, yv^(-1)]*G[{0, yu^(-1), yv^(-1), yv^(-1)}, yw] - 
     4*G[{0}, yw]*G[{0, yu^(-1), yv^(-1), yv^(-1)}, yw] - 
     4*G[{1}, yu^(-1)]*G[{0, yu^(-1), yv^(-1), yv^(-1)}, yw] - 
     8*G[{1}, yv^(-1)]*G[{0, yu^(-1), yv^(-1), yv^(-1)}, yw] + 
     4*G[{yu}, yv^(-1)]*G[{0, yu^(-1), yv^(-1), yv^(-1)}, yw] - 
     4*G[{yv^(-1)}, yw]*G[{0, yu^(-1), yv^(-1), yv^(-1)}, yw] + 
     4*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1), yv^(-1), yv^(-1)}, yw] - 
     4*G[{0}, yu^(-1)]*G[{0, yu^(-1), yv^(-1), 1/(yu*yv)}, yw] - 
     4*G[{0}, yv^(-1)]*G[{0, yu^(-1), yv^(-1), 1/(yu*yv)}, yw] + 
     4*G[{0}, yw]*G[{0, yu^(-1), yv^(-1), 1/(yu*yv)}, yw] + 
     4*G[{1}, yu^(-1)]*G[{0, yu^(-1), yv^(-1), 1/(yu*yv)}, yw] + 
     8*G[{1}, yv^(-1)]*G[{0, yu^(-1), yv^(-1), 1/(yu*yv)}, yw] - 
     4*G[{yu}, yv^(-1)]*G[{0, yu^(-1), yv^(-1), 1/(yu*yv)}, yw] + 
     4*G[{0}, yu^(-1)]*G[{0, yu^(-1), 1/(yu*yv), 1}, yw] + 
     4*G[{0}, yv^(-1)]*G[{0, yu^(-1), 1/(yu*yv), 1}, yw] - 
     4*G[{0}, yw]*G[{0, yu^(-1), 1/(yu*yv), 1}, yw] - 
     4*G[{1}, yu^(-1)]*G[{0, yu^(-1), 1/(yu*yv), 1}, yw] - 
     4*G[{1}, yv^(-1)]*G[{0, yu^(-1), 1/(yu*yv), 1}, yw] - 
     2*G[{yv^(-1)}, yw]*G[{0, yu^(-1), 1/(yu*yv), 1}, yw] + 
     2*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1), 1/(yu*yv), 1}, yw] - 
     4*G[{0}, yu^(-1)]*G[{0, yu^(-1), 1/(yu*yv), yu^(-1)}, yw] - 
     4*G[{0}, yv^(-1)]*G[{0, yu^(-1), 1/(yu*yv), yu^(-1)}, yw] + 
     4*G[{0}, yw]*G[{0, yu^(-1), 1/(yu*yv), yu^(-1)}, yw] + 
     4*G[{1}, yu^(-1)]*G[{0, yu^(-1), 1/(yu*yv), yu^(-1)}, yw] + 
     8*G[{1}, yv^(-1)]*G[{0, yu^(-1), 1/(yu*yv), yu^(-1)}, yw] - 
     4*G[{yu}, yv^(-1)]*G[{0, yu^(-1), 1/(yu*yv), yu^(-1)}, yw] + 
     2*G[{yv^(-1)}, yw]*G[{0, yu^(-1), 1/(yu*yv), yu^(-1)}, yw] - 
     2*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1), 1/(yu*yv), yu^(-1)}, yw] - 
     4*G[{0}, yu^(-1)]*G[{0, yu^(-1), 1/(yu*yv), yv^(-1)}, yw] - 
     4*G[{0}, yv^(-1)]*G[{0, yu^(-1), 1/(yu*yv), yv^(-1)}, yw] + 
     4*G[{0}, yw]*G[{0, yu^(-1), 1/(yu*yv), yv^(-1)}, yw] + 
     4*G[{1}, yu^(-1)]*G[{0, yu^(-1), 1/(yu*yv), yv^(-1)}, yw] + 
     6*G[{1}, yv^(-1)]*G[{0, yu^(-1), 1/(yu*yv), yv^(-1)}, yw] - 
     2*G[{yu}, yv^(-1)]*G[{0, yu^(-1), 1/(yu*yv), yv^(-1)}, yw] + 
     4*G[{yv^(-1)}, yw]*G[{0, yu^(-1), 1/(yu*yv), yv^(-1)}, yw] - 
     4*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1), 1/(yu*yv), yv^(-1)}, yw] + 
     4*G[{0}, yu^(-1)]*G[{0, yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] + 
     4*G[{0}, yv^(-1)]*G[{0, yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] - 
     4*G[{0}, yw]*G[{0, yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] - 
     4*G[{1}, yu^(-1)]*G[{0, yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] - 
     6*G[{1}, yv^(-1)]*G[{0, yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] + 
     2*G[{yu}, yv^(-1)]*G[{0, yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] - 
     6*G[{1}, yv^(-1)]*G[{0, yu, 1, 1}, yv^(-1)] + 
     6*G[{yu}, yv^(-1)]*G[{0, yu, 1, 1}, yv^(-1)] + 
     6*G[{yv^(-1)}, yw]*G[{0, yu, 1, 1}, yv^(-1)] - 
     6*G[{1/(yu*yv)}, yw]*G[{0, yu, 1, 1}, yv^(-1)] - 
     2*G[{1}, yv^(-1)]*G[{0, yu, 1, yu}, yv^(-1)] + 
     2*G[{yu}, yv^(-1)]*G[{0, yu, 1, yu}, yv^(-1)] - 
     2*G[{yv^(-1)}, yw]*G[{0, yu, 1, yu}, yv^(-1)] + 
     2*G[{1/(yu*yv)}, yw]*G[{0, yu, 1, yu}, yv^(-1)] - 
     4*G[{yv^(-1)}, yw]*G[{0, yu, yu, 1}, yv^(-1)] + 
     4*G[{1/(yu*yv)}, yw]*G[{0, yu, yu, 1}, yv^(-1)] + 
     8*G[{1}, yv^(-1)]*G[{0, yu, yu, yu}, yv^(-1)] - 
     8*G[{yu}, yv^(-1)]*G[{0, yu, yu, yu}, yv^(-1)] + 
     4*G[{0}, yu^(-1)]*G[{0, yv^(-1), 1, 1}, yw] + 
     4*G[{0}, yv^(-1)]*G[{0, yv^(-1), 1, 1}, yw] - 
     4*G[{0}, yw]*G[{0, yv^(-1), 1, 1}, yw] - 4*G[{1}, yu^(-1)]*
      G[{0, yv^(-1), 1, 1}, yw] - 4*G[{1}, yv^(-1)]*G[{0, yv^(-1), 1, 1}, 
       yw] - 2*G[{yv^(-1)}, yw]*G[{0, yv^(-1), 1, 1}, yw] + 
     2*G[{1/(yu*yv)}, yw]*G[{0, yv^(-1), 1, 1}, yw] - 
     4*G[{0}, yu^(-1)]*G[{0, yv^(-1), 1, yu^(-1)}, yw] - 
     4*G[{0}, yv^(-1)]*G[{0, yv^(-1), 1, yu^(-1)}, yw] + 
     4*G[{0}, yw]*G[{0, yv^(-1), 1, yu^(-1)}, yw] + 
     4*G[{1}, yu^(-1)]*G[{0, yv^(-1), 1, yu^(-1)}, yw] + 
     8*G[{1}, yv^(-1)]*G[{0, yv^(-1), 1, yu^(-1)}, yw] - 
     4*G[{yu}, yv^(-1)]*G[{0, yv^(-1), 1, yu^(-1)}, yw] + 
     2*G[{yv^(-1)}, yw]*G[{0, yv^(-1), 1, yu^(-1)}, yw] - 
     2*G[{1/(yu*yv)}, yw]*G[{0, yv^(-1), 1, yu^(-1)}, yw] - 
     4*G[{0}, yu^(-1)]*G[{0, yv^(-1), 1, yv^(-1)}, yw] - 
     4*G[{0}, yv^(-1)]*G[{0, yv^(-1), 1, yv^(-1)}, yw] + 
     4*G[{0}, yw]*G[{0, yv^(-1), 1, yv^(-1)}, yw] + 
     4*G[{1}, yu^(-1)]*G[{0, yv^(-1), 1, yv^(-1)}, yw] + 
     6*G[{1}, yv^(-1)]*G[{0, yv^(-1), 1, yv^(-1)}, yw] - 
     2*G[{yu}, yv^(-1)]*G[{0, yv^(-1), 1, yv^(-1)}, yw] + 
     4*G[{yv^(-1)}, yw]*G[{0, yv^(-1), 1, yv^(-1)}, yw] - 
     4*G[{1/(yu*yv)}, yw]*G[{0, yv^(-1), 1, yv^(-1)}, yw] + 
     4*G[{0}, yu^(-1)]*G[{0, yv^(-1), 1, 1/(yu*yv)}, yw] + 
     4*G[{0}, yv^(-1)]*G[{0, yv^(-1), 1, 1/(yu*yv)}, yw] - 
     4*G[{0}, yw]*G[{0, yv^(-1), 1, 1/(yu*yv)}, yw] - 
     4*G[{1}, yu^(-1)]*G[{0, yv^(-1), 1, 1/(yu*yv)}, yw] - 
     6*G[{1}, yv^(-1)]*G[{0, yv^(-1), 1, 1/(yu*yv)}, yw] + 
     2*G[{yu}, yv^(-1)]*G[{0, yv^(-1), 1, 1/(yu*yv)}, yw] - 
     4*G[{0}, yu^(-1)]*G[{0, yv^(-1), yu^(-1), 1}, yw] - 
     4*G[{0}, yv^(-1)]*G[{0, yv^(-1), yu^(-1), 1}, yw] + 
     4*G[{0}, yw]*G[{0, yv^(-1), yu^(-1), 1}, yw] + 
     4*G[{1}, yu^(-1)]*G[{0, yv^(-1), yu^(-1), 1}, yw] + 
     4*G[{1}, yv^(-1)]*G[{0, yv^(-1), yu^(-1), 1}, yw] + 
     4*G[{yv^(-1)}, yw]*G[{0, yv^(-1), yu^(-1), 1}, yw] - 
     4*G[{1/(yu*yv)}, yw]*G[{0, yv^(-1), yu^(-1), 1}, yw] + 
     4*G[{0}, yu^(-1)]*G[{0, yv^(-1), yu^(-1), yu^(-1)}, yw] + 
     4*G[{0}, yv^(-1)]*G[{0, yv^(-1), yu^(-1), yu^(-1)}, yw] - 
     4*G[{0}, yw]*G[{0, yv^(-1), yu^(-1), yu^(-1)}, yw] - 
     4*G[{1}, yu^(-1)]*G[{0, yv^(-1), yu^(-1), yu^(-1)}, yw] - 
     8*G[{1}, yv^(-1)]*G[{0, yv^(-1), yu^(-1), yu^(-1)}, yw] + 
     4*G[{yu}, yv^(-1)]*G[{0, yv^(-1), yu^(-1), yu^(-1)}, yw] - 
     4*G[{yv^(-1)}, yw]*G[{0, yv^(-1), yu^(-1), yu^(-1)}, yw] + 
     4*G[{1/(yu*yv)}, yw]*G[{0, yv^(-1), yu^(-1), yu^(-1)}, yw] + 
     4*G[{0}, yu^(-1)]*G[{0, yv^(-1), yu^(-1), yv^(-1)}, yw] + 
     4*G[{0}, yv^(-1)]*G[{0, yv^(-1), yu^(-1), yv^(-1)}, yw] - 
     4*G[{0}, yw]*G[{0, yv^(-1), yu^(-1), yv^(-1)}, yw] - 
     4*G[{1}, yu^(-1)]*G[{0, yv^(-1), yu^(-1), yv^(-1)}, yw] - 
     8*G[{1}, yv^(-1)]*G[{0, yv^(-1), yu^(-1), yv^(-1)}, yw] + 
     4*G[{yu}, yv^(-1)]*G[{0, yv^(-1), yu^(-1), yv^(-1)}, yw] - 
     4*G[{yv^(-1)}, yw]*G[{0, yv^(-1), yu^(-1), yv^(-1)}, yw] + 
     4*G[{1/(yu*yv)}, yw]*G[{0, yv^(-1), yu^(-1), yv^(-1)}, yw] - 
     4*G[{0}, yu^(-1)]*G[{0, yv^(-1), yu^(-1), 1/(yu*yv)}, yw] - 
     4*G[{0}, yv^(-1)]*G[{0, yv^(-1), yu^(-1), 1/(yu*yv)}, yw] + 
     4*G[{0}, yw]*G[{0, yv^(-1), yu^(-1), 1/(yu*yv)}, yw] + 
     4*G[{1}, yu^(-1)]*G[{0, yv^(-1), yu^(-1), 1/(yu*yv)}, yw] + 
     8*G[{1}, yv^(-1)]*G[{0, yv^(-1), yu^(-1), 1/(yu*yv)}, yw] - 
     4*G[{yu}, yv^(-1)]*G[{0, yv^(-1), yu^(-1), 1/(yu*yv)}, yw] - 
     4*G[{0}, yu^(-1)]*G[{0, yv^(-1), yv^(-1), 1}, yw] - 
     4*G[{0}, yv^(-1)]*G[{0, yv^(-1), yv^(-1), 1}, yw] + 
     4*G[{0}, yw]*G[{0, yv^(-1), yv^(-1), 1}, yw] + 
     4*G[{1}, yu^(-1)]*G[{0, yv^(-1), yv^(-1), 1}, yw] + 
     4*G[{1}, yv^(-1)]*G[{0, yv^(-1), yv^(-1), 1}, yw] + 
     4*G[{yv^(-1)}, yw]*G[{0, yv^(-1), yv^(-1), 1}, yw] - 
     4*G[{1/(yu*yv)}, yw]*G[{0, yv^(-1), yv^(-1), 1}, yw] + 
     4*G[{0}, yu^(-1)]*G[{0, yv^(-1), yv^(-1), yu^(-1)}, yw] + 
     4*G[{0}, yv^(-1)]*G[{0, yv^(-1), yv^(-1), yu^(-1)}, yw] - 
     4*G[{0}, yw]*G[{0, yv^(-1), yv^(-1), yu^(-1)}, yw] - 
     4*G[{1}, yu^(-1)]*G[{0, yv^(-1), yv^(-1), yu^(-1)}, yw] - 
     8*G[{1}, yv^(-1)]*G[{0, yv^(-1), yv^(-1), yu^(-1)}, yw] + 
     4*G[{yu}, yv^(-1)]*G[{0, yv^(-1), yv^(-1), yu^(-1)}, yw] - 
     4*G[{yv^(-1)}, yw]*G[{0, yv^(-1), yv^(-1), yu^(-1)}, yw] + 
     4*G[{1/(yu*yv)}, yw]*G[{0, yv^(-1), yv^(-1), yu^(-1)}, yw] - 
     8*G[{1}, yv^(-1)]*G[{0, yv^(-1), yv^(-1), yv^(-1)}, yw] + 
     8*G[{yu}, yv^(-1)]*G[{0, yv^(-1), yv^(-1), yv^(-1)}, yw] + 
     4*G[{1}, yv^(-1)]*G[{0, yv^(-1), yv^(-1), 1/(yu*yv)}, yw] - 
     4*G[{yu}, yv^(-1)]*G[{0, yv^(-1), yv^(-1), 1/(yu*yv)}, yw] + 
     4*G[{0}, yu^(-1)]*G[{0, yv^(-1), 1/(yu*yv), 1}, yw] + 
     4*G[{0}, yv^(-1)]*G[{0, yv^(-1), 1/(yu*yv), 1}, yw] - 
     4*G[{0}, yw]*G[{0, yv^(-1), 1/(yu*yv), 1}, yw] - 
     4*G[{1}, yu^(-1)]*G[{0, yv^(-1), 1/(yu*yv), 1}, yw] - 
     4*G[{1}, yv^(-1)]*G[{0, yv^(-1), 1/(yu*yv), 1}, yw] + 
     2*G[{yv^(-1)}, yw]*G[{0, yv^(-1), 1/(yu*yv), 1}, yw] - 
     2*G[{1/(yu*yv)}, yw]*G[{0, yv^(-1), 1/(yu*yv), 1}, yw] - 
     4*G[{0}, yu^(-1)]*G[{0, yv^(-1), 1/(yu*yv), yu^(-1)}, yw] - 
     4*G[{0}, yv^(-1)]*G[{0, yv^(-1), 1/(yu*yv), yu^(-1)}, yw] + 
     4*G[{0}, yw]*G[{0, yv^(-1), 1/(yu*yv), yu^(-1)}, yw] + 
     4*G[{1}, yu^(-1)]*G[{0, yv^(-1), 1/(yu*yv), yu^(-1)}, yw] + 
     8*G[{1}, yv^(-1)]*G[{0, yv^(-1), 1/(yu*yv), yu^(-1)}, yw] - 
     4*G[{yu}, yv^(-1)]*G[{0, yv^(-1), 1/(yu*yv), yu^(-1)}, yw] - 
     2*G[{yv^(-1)}, yw]*G[{0, yv^(-1), 1/(yu*yv), yu^(-1)}, yw] + 
     2*G[{1/(yu*yv)}, yw]*G[{0, yv^(-1), 1/(yu*yv), yu^(-1)}, yw] + 
     2*G[{1}, yv^(-1)]*G[{0, yv^(-1), 1/(yu*yv), yv^(-1)}, yw] - 
     2*G[{yu}, yv^(-1)]*G[{0, yv^(-1), 1/(yu*yv), yv^(-1)}, yw] + 
     2*G[{1}, yv^(-1)]*G[{0, yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] - 
     2*G[{yu}, yv^(-1)]*G[{0, yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] - 
     4*G[{0}, yu^(-1)]*G[{0, 1/(yu*yv), 1, 1}, yw] - 
     4*G[{0}, yv^(-1)]*G[{0, 1/(yu*yv), 1, 1}, yw] + 
     4*G[{0}, yw]*G[{0, 1/(yu*yv), 1, 1}, yw] + 4*G[{1}, yu^(-1)]*
      G[{0, 1/(yu*yv), 1, 1}, yw] + 4*G[{1}, yv^(-1)]*
      G[{0, 1/(yu*yv), 1, 1}, yw] + 2*G[{yv^(-1)}, yw]*
      G[{0, 1/(yu*yv), 1, 1}, yw] - 2*G[{1/(yu*yv)}, yw]*
      G[{0, 1/(yu*yv), 1, 1}, yw] + 4*G[{0}, yu^(-1)]*
      G[{0, 1/(yu*yv), 1, yu^(-1)}, yw] + 4*G[{0}, yv^(-1)]*
      G[{0, 1/(yu*yv), 1, yu^(-1)}, yw] - 4*G[{0}, yw]*
      G[{0, 1/(yu*yv), 1, yu^(-1)}, yw] - 4*G[{1}, yu^(-1)]*
      G[{0, 1/(yu*yv), 1, yu^(-1)}, yw] - 8*G[{1}, yv^(-1)]*
      G[{0, 1/(yu*yv), 1, yu^(-1)}, yw] + 4*G[{yu}, yv^(-1)]*
      G[{0, 1/(yu*yv), 1, yu^(-1)}, yw] - 2*G[{yv^(-1)}, yw]*
      G[{0, 1/(yu*yv), 1, yu^(-1)}, yw] + 2*G[{1/(yu*yv)}, yw]*
      G[{0, 1/(yu*yv), 1, yu^(-1)}, yw] + 4*G[{0}, yu^(-1)]*
      G[{0, 1/(yu*yv), 1, yv^(-1)}, yw] + 4*G[{0}, yv^(-1)]*
      G[{0, 1/(yu*yv), 1, yv^(-1)}, yw] - 4*G[{0}, yw]*
      G[{0, 1/(yu*yv), 1, yv^(-1)}, yw] - 4*G[{1}, yu^(-1)]*
      G[{0, 1/(yu*yv), 1, yv^(-1)}, yw] - 6*G[{1}, yv^(-1)]*
      G[{0, 1/(yu*yv), 1, yv^(-1)}, yw] + 2*G[{yu}, yv^(-1)]*
      G[{0, 1/(yu*yv), 1, yv^(-1)}, yw] - 4*G[{yv^(-1)}, yw]*
      G[{0, 1/(yu*yv), 1, yv^(-1)}, yw] + 4*G[{1/(yu*yv)}, yw]*
      G[{0, 1/(yu*yv), 1, yv^(-1)}, yw] - 4*G[{0}, yu^(-1)]*
      G[{0, 1/(yu*yv), 1, 1/(yu*yv)}, yw] - 4*G[{0}, yv^(-1)]*
      G[{0, 1/(yu*yv), 1, 1/(yu*yv)}, yw] + 4*G[{0}, yw]*
      G[{0, 1/(yu*yv), 1, 1/(yu*yv)}, yw] + 4*G[{1}, yu^(-1)]*
      G[{0, 1/(yu*yv), 1, 1/(yu*yv)}, yw] + 6*G[{1}, yv^(-1)]*
      G[{0, 1/(yu*yv), 1, 1/(yu*yv)}, yw] - 2*G[{yu}, yv^(-1)]*
      G[{0, 1/(yu*yv), 1, 1/(yu*yv)}, yw] + 4*G[{0}, yu^(-1)]*
      G[{0, 1/(yu*yv), yu^(-1), 1}, yw] + 4*G[{0}, yv^(-1)]*
      G[{0, 1/(yu*yv), yu^(-1), 1}, yw] - 4*G[{0}, yw]*
      G[{0, 1/(yu*yv), yu^(-1), 1}, yw] - 4*G[{1}, yu^(-1)]*
      G[{0, 1/(yu*yv), yu^(-1), 1}, yw] - 4*G[{1}, yv^(-1)]*
      G[{0, 1/(yu*yv), yu^(-1), 1}, yw] - 4*G[{yv^(-1)}, yw]*
      G[{0, 1/(yu*yv), yu^(-1), 1}, yw] + 4*G[{1/(yu*yv)}, yw]*
      G[{0, 1/(yu*yv), yu^(-1), 1}, yw] - 4*G[{0}, yu^(-1)]*
      G[{0, 1/(yu*yv), yu^(-1), yu^(-1)}, yw] - 4*G[{0}, yv^(-1)]*
      G[{0, 1/(yu*yv), yu^(-1), yu^(-1)}, yw] + 
     4*G[{0}, yw]*G[{0, 1/(yu*yv), yu^(-1), yu^(-1)}, yw] + 
     4*G[{1}, yu^(-1)]*G[{0, 1/(yu*yv), yu^(-1), yu^(-1)}, yw] + 
     8*G[{1}, yv^(-1)]*G[{0, 1/(yu*yv), yu^(-1), yu^(-1)}, yw] - 
     4*G[{yu}, yv^(-1)]*G[{0, 1/(yu*yv), yu^(-1), yu^(-1)}, yw] + 
     4*G[{yv^(-1)}, yw]*G[{0, 1/(yu*yv), yu^(-1), yu^(-1)}, yw] - 
     4*G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv), yu^(-1), yu^(-1)}, yw] - 
     4*G[{0}, yu^(-1)]*G[{0, 1/(yu*yv), yu^(-1), yv^(-1)}, yw] - 
     4*G[{0}, yv^(-1)]*G[{0, 1/(yu*yv), yu^(-1), yv^(-1)}, yw] + 
     4*G[{0}, yw]*G[{0, 1/(yu*yv), yu^(-1), yv^(-1)}, yw] + 
     4*G[{1}, yu^(-1)]*G[{0, 1/(yu*yv), yu^(-1), yv^(-1)}, yw] + 
     8*G[{1}, yv^(-1)]*G[{0, 1/(yu*yv), yu^(-1), yv^(-1)}, yw] - 
     4*G[{yu}, yv^(-1)]*G[{0, 1/(yu*yv), yu^(-1), yv^(-1)}, yw] + 
     4*G[{yv^(-1)}, yw]*G[{0, 1/(yu*yv), yu^(-1), yv^(-1)}, yw] - 
     4*G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv), yu^(-1), yv^(-1)}, yw] + 
     4*G[{0}, yu^(-1)]*G[{0, 1/(yu*yv), yu^(-1), 1/(yu*yv)}, yw] + 
     4*G[{0}, yv^(-1)]*G[{0, 1/(yu*yv), yu^(-1), 1/(yu*yv)}, yw] - 
     4*G[{0}, yw]*G[{0, 1/(yu*yv), yu^(-1), 1/(yu*yv)}, yw] - 
     4*G[{1}, yu^(-1)]*G[{0, 1/(yu*yv), yu^(-1), 1/(yu*yv)}, yw] - 
     8*G[{1}, yv^(-1)]*G[{0, 1/(yu*yv), yu^(-1), 1/(yu*yv)}, yw] + 
     4*G[{yu}, yv^(-1)]*G[{0, 1/(yu*yv), yu^(-1), 1/(yu*yv)}, yw] + 
     4*G[{0}, yu^(-1)]*G[{0, 1/(yu*yv), yv^(-1), 1}, yw] + 
     4*G[{0}, yv^(-1)]*G[{0, 1/(yu*yv), yv^(-1), 1}, yw] - 
     4*G[{0}, yw]*G[{0, 1/(yu*yv), yv^(-1), 1}, yw] - 
     4*G[{1}, yu^(-1)]*G[{0, 1/(yu*yv), yv^(-1), 1}, yw] - 
     4*G[{1}, yv^(-1)]*G[{0, 1/(yu*yv), yv^(-1), 1}, yw] - 
     4*G[{yv^(-1)}, yw]*G[{0, 1/(yu*yv), yv^(-1), 1}, yw] + 
     4*G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv), yv^(-1), 1}, yw] - 
     4*G[{0}, yu^(-1)]*G[{0, 1/(yu*yv), yv^(-1), yu^(-1)}, yw] - 
     4*G[{0}, yv^(-1)]*G[{0, 1/(yu*yv), yv^(-1), yu^(-1)}, yw] + 
     4*G[{0}, yw]*G[{0, 1/(yu*yv), yv^(-1), yu^(-1)}, yw] + 
     4*G[{1}, yu^(-1)]*G[{0, 1/(yu*yv), yv^(-1), yu^(-1)}, yw] + 
     8*G[{1}, yv^(-1)]*G[{0, 1/(yu*yv), yv^(-1), yu^(-1)}, yw] - 
     4*G[{yu}, yv^(-1)]*G[{0, 1/(yu*yv), yv^(-1), yu^(-1)}, yw] + 
     4*G[{yv^(-1)}, yw]*G[{0, 1/(yu*yv), yv^(-1), yu^(-1)}, yw] - 
     4*G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv), yv^(-1), yu^(-1)}, yw] + 
     8*G[{1}, yv^(-1)]*G[{0, 1/(yu*yv), yv^(-1), yv^(-1)}, yw] - 
     8*G[{yu}, yv^(-1)]*G[{0, 1/(yu*yv), yv^(-1), yv^(-1)}, yw] - 
     4*G[{1}, yv^(-1)]*G[{0, 1/(yu*yv), yv^(-1), 1/(yu*yv)}, yw] + 
     4*G[{yu}, yv^(-1)]*G[{0, 1/(yu*yv), yv^(-1), 1/(yu*yv)}, yw] - 
     4*G[{0}, yu^(-1)]*G[{0, 1/(yu*yv), 1/(yu*yv), 1}, yw] - 
     4*G[{0}, yv^(-1)]*G[{0, 1/(yu*yv), 1/(yu*yv), 1}, yw] + 
     4*G[{0}, yw]*G[{0, 1/(yu*yv), 1/(yu*yv), 1}, yw] + 
     4*G[{1}, yu^(-1)]*G[{0, 1/(yu*yv), 1/(yu*yv), 1}, yw] + 
     4*G[{1}, yv^(-1)]*G[{0, 1/(yu*yv), 1/(yu*yv), 1}, yw] - 
     2*G[{yv^(-1)}, yw]*G[{0, 1/(yu*yv), 1/(yu*yv), 1}, yw] + 
     2*G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv), 1/(yu*yv), 1}, yw] + 
     4*G[{0}, yu^(-1)]*G[{0, 1/(yu*yv), 1/(yu*yv), yu^(-1)}, yw] + 
     4*G[{0}, yv^(-1)]*G[{0, 1/(yu*yv), 1/(yu*yv), yu^(-1)}, yw] - 
     4*G[{0}, yw]*G[{0, 1/(yu*yv), 1/(yu*yv), yu^(-1)}, yw] - 
     4*G[{1}, yu^(-1)]*G[{0, 1/(yu*yv), 1/(yu*yv), yu^(-1)}, yw] - 
     8*G[{1}, yv^(-1)]*G[{0, 1/(yu*yv), 1/(yu*yv), yu^(-1)}, yw] + 
     4*G[{yu}, yv^(-1)]*G[{0, 1/(yu*yv), 1/(yu*yv), yu^(-1)}, yw] + 
     2*G[{yv^(-1)}, yw]*G[{0, 1/(yu*yv), 1/(yu*yv), yu^(-1)}, yw] - 
     2*G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv), 1/(yu*yv), yu^(-1)}, yw] - 
     2*G[{1}, yv^(-1)]*G[{0, 1/(yu*yv), 1/(yu*yv), yv^(-1)}, yw] + 
     2*G[{yu}, yv^(-1)]*G[{0, 1/(yu*yv), 1/(yu*yv), yv^(-1)}, yw] - 
     2*G[{1}, yv^(-1)]*G[{0, 1/(yu*yv), 1/(yu*yv), 1/(yu*yv)}, yw] + 
     2*G[{yu}, yv^(-1)]*G[{0, 1/(yu*yv), 1/(yu*yv), 1/(yu*yv)}, yw] - 
     8*G[{yv^(-1)}, yw]*G[{1, 1, 1, yu^(-1)}, yw] + 
     8*G[{1/(yu*yv)}, yw]*G[{1, 1, 1, yu^(-1)}, yw] - 
     8*G[{1}, yv^(-1)]*G[{1, 1, 1, yu}, yv^(-1)] - 
     8*G[{yu}, yv^(-1)]*G[{1, 1, 1, yu}, yv^(-1)] - 
     8*G[{yv^(-1)}, yw]*G[{1, 1, 1, yu}, yv^(-1)] + 
     8*G[{1/(yu*yv)}, yw]*G[{1, 1, 1, yu}, yv^(-1)] - 
     4*G[{0}, yu^(-1)]*G[{1, 1, 1, yv^(-1)}, yw] - 
     4*G[{0}, yv^(-1)]*G[{1, 1, 1, yv^(-1)}, yw] + 
     4*G[{0}, yw]*G[{1, 1, 1, yv^(-1)}, yw] + 4*G[{1}, yu^(-1)]*
      G[{1, 1, 1, yv^(-1)}, yw] + 4*G[{1}, yv^(-1)]*G[{1, 1, 1, yv^(-1)}, 
       yw] + 4*G[{yv^(-1)}, yw]*G[{1, 1, 1, yv^(-1)}, yw] - 
     4*G[{1/(yu*yv)}, yw]*G[{1, 1, 1, yv^(-1)}, yw] + 
     4*G[{0}, yu^(-1)]*G[{1, 1, 1, 1/(yu*yv)}, yw] + 
     4*G[{0}, yv^(-1)]*G[{1, 1, 1, 1/(yu*yv)}, yw] - 
     4*G[{0}, yw]*G[{1, 1, 1, 1/(yu*yv)}, yw] - 4*G[{1}, yu^(-1)]*
      G[{1, 1, 1, 1/(yu*yv)}, yw] - 4*G[{1}, yv^(-1)]*
      G[{1, 1, 1, 1/(yu*yv)}, yw] - 4*G[{0}, yu^(-1)]*
      G[{1, 1, yu^(-1), yv^(-1)}, yw] - 4*G[{0}, yv^(-1)]*
      G[{1, 1, yu^(-1), yv^(-1)}, yw] + 4*G[{0}, yw]*
      G[{1, 1, yu^(-1), yv^(-1)}, yw] + 4*G[{1}, yu^(-1)]*
      G[{1, 1, yu^(-1), yv^(-1)}, yw] + 8*G[{1}, yv^(-1)]*
      G[{1, 1, yu^(-1), yv^(-1)}, yw] + 4*G[{1}, yw]*
      G[{1, 1, yu^(-1), yv^(-1)}, yw] - 4*G[{yu}, yv^(-1)]*
      G[{1, 1, yu^(-1), yv^(-1)}, yw] + 4*G[{yv^(-1)}, yw]*
      G[{1, 1, yu^(-1), yv^(-1)}, yw] - 4*G[{1/(yu*yv)}, yw]*
      G[{1, 1, yu^(-1), yv^(-1)}, yw] + 4*G[{0}, yu^(-1)]*
      G[{1, 1, yu^(-1), 1/(yu*yv)}, yw] + 4*G[{0}, yv^(-1)]*
      G[{1, 1, yu^(-1), 1/(yu*yv)}, yw] - 4*G[{0}, yw]*
      G[{1, 1, yu^(-1), 1/(yu*yv)}, yw] - 4*G[{1}, yu^(-1)]*
      G[{1, 1, yu^(-1), 1/(yu*yv)}, yw] - 8*G[{1}, yv^(-1)]*
      G[{1, 1, yu^(-1), 1/(yu*yv)}, yw] - 4*G[{1}, yw]*
      G[{1, 1, yu^(-1), 1/(yu*yv)}, yw] + 4*G[{yu}, yv^(-1)]*
      G[{1, 1, yu^(-1), 1/(yu*yv)}, yw] - 4*G[{yv^(-1)}, yw]*
      G[{1, 1, yu^(-1), 1/(yu*yv)}, yw] + 4*G[{1/(yu*yv)}, yw]*
      G[{1, 1, yu^(-1), 1/(yu*yv)}, yw] + 4*G[{yu}, yv^(-1)]*
      G[{1, 1, yu, yu}, yv^(-1)] - 4*G[{yv^(-1)}, yw]*
      G[{1, 1, yu, yu}, yv^(-1)] + 4*G[{1/(yu*yv)}, yw]*
      G[{1, 1, yu, yu}, yv^(-1)] - 4*G[{0}, yu^(-1)]*
      G[{1, 1, yv^(-1), yu^(-1)}, yw] - 4*G[{0}, yv^(-1)]*
      G[{1, 1, yv^(-1), yu^(-1)}, yw] + 4*G[{0}, yw]*
      G[{1, 1, yv^(-1), yu^(-1)}, yw] + 4*G[{1}, yu^(-1)]*
      G[{1, 1, yv^(-1), yu^(-1)}, yw] + 8*G[{1}, yv^(-1)]*
      G[{1, 1, yv^(-1), yu^(-1)}, yw] + 4*G[{1}, yw]*
      G[{1, 1, yv^(-1), yu^(-1)}, yw] - 4*G[{yu}, yv^(-1)]*
      G[{1, 1, yv^(-1), yu^(-1)}, yw] + 4*G[{yv^(-1)}, yw]*
      G[{1, 1, yv^(-1), yu^(-1)}, yw] - 4*G[{1/(yu*yv)}, yw]*
      G[{1, 1, yv^(-1), yu^(-1)}, yw] - 4*G[{0}, yu^(-1)]*
      G[{1, 1, yv^(-1), yv^(-1)}, yw] - 4*G[{0}, yv^(-1)]*
      G[{1, 1, yv^(-1), yv^(-1)}, yw] + 4*G[{0}, yw]*
      G[{1, 1, yv^(-1), yv^(-1)}, yw] + 4*G[{1}, yu^(-1)]*
      G[{1, 1, yv^(-1), yv^(-1)}, yw] + 8*G[{1}, yv^(-1)]*
      G[{1, 1, yv^(-1), yv^(-1)}, yw] + 4*G[{1}, yw]*
      G[{1, 1, yv^(-1), yv^(-1)}, yw] - 4*G[{yu}, yv^(-1)]*
      G[{1, 1, yv^(-1), yv^(-1)}, yw] + 8*G[{yv^(-1)}, yw]*
      G[{1, 1, yv^(-1), yv^(-1)}, yw] - 8*G[{1/(yu*yv)}, yw]*
      G[{1, 1, yv^(-1), yv^(-1)}, yw] + 4*G[{0}, yu^(-1)]*
      G[{1, 1, yv^(-1), 1/(yu*yv)}, yw] + 4*G[{0}, yv^(-1)]*
      G[{1, 1, yv^(-1), 1/(yu*yv)}, yw] - 4*G[{0}, yw]*
      G[{1, 1, yv^(-1), 1/(yu*yv)}, yw] - 4*G[{1}, yu^(-1)]*
      G[{1, 1, yv^(-1), 1/(yu*yv)}, yw] - 8*G[{1}, yv^(-1)]*
      G[{1, 1, yv^(-1), 1/(yu*yv)}, yw] - 4*G[{1}, yw]*
      G[{1, 1, yv^(-1), 1/(yu*yv)}, yw] + 4*G[{yu}, yv^(-1)]*
      G[{1, 1, yv^(-1), 1/(yu*yv)}, yw] - 4*G[{yv^(-1)}, yw]*
      G[{1, 1, yv^(-1), 1/(yu*yv)}, yw] + 4*G[{1/(yu*yv)}, yw]*
      G[{1, 1, yv^(-1), 1/(yu*yv)}, yw] + 4*G[{0}, yu^(-1)]*
      G[{1, 1, 1/(yu*yv), yu^(-1)}, yw] + 4*G[{0}, yv^(-1)]*
      G[{1, 1, 1/(yu*yv), yu^(-1)}, yw] - 4*G[{0}, yw]*
      G[{1, 1, 1/(yu*yv), yu^(-1)}, yw] - 4*G[{1}, yu^(-1)]*
      G[{1, 1, 1/(yu*yv), yu^(-1)}, yw] - 8*G[{1}, yv^(-1)]*
      G[{1, 1, 1/(yu*yv), yu^(-1)}, yw] - 4*G[{1}, yw]*
      G[{1, 1, 1/(yu*yv), yu^(-1)}, yw] + 4*G[{yu}, yv^(-1)]*
      G[{1, 1, 1/(yu*yv), yu^(-1)}, yw] - 4*G[{1}, yv^(-1)]*
      G[{1, 1, 1/(yu*yv), yv^(-1)}, yw] - 4*G[{1}, yw]*
      G[{1, 1, 1/(yu*yv), yv^(-1)}, yw] + 4*G[{yu}, yv^(-1)]*
      G[{1, 1, 1/(yu*yv), yv^(-1)}, yw] - 4*G[{yv^(-1)}, yw]*
      G[{1, 1, 1/(yu*yv), yv^(-1)}, yw] + 4*G[{1/(yu*yv)}, yw]*
      G[{1, 1, 1/(yu*yv), yv^(-1)}, yw] + 4*G[{1}, yv^(-1)]*
      G[{1, 1, 1/(yu*yv), 1/(yu*yv)}, yw] + 4*G[{1}, yw]*
      G[{1, 1, 1/(yu*yv), 1/(yu*yv)}, yw] - 4*G[{yu}, yv^(-1)]*
      G[{1, 1, 1/(yu*yv), 1/(yu*yv)}, yw] + 4*G[{1}, yv^(-1)]*
      G[{1, yu^(-1), 1, yv^(-1)}, yw] + 4*G[{1}, yw]*
      G[{1, yu^(-1), 1, yv^(-1)}, yw] - 4*G[{yu}, yv^(-1)]*
      G[{1, yu^(-1), 1, yv^(-1)}, yw] - 4*G[{1}, yv^(-1)]*
      G[{1, yu^(-1), 1, 1/(yu*yv)}, yw] - 4*G[{1}, yw]*
      G[{1, yu^(-1), 1, 1/(yu*yv)}, yw] + 4*G[{yu}, yv^(-1)]*
      G[{1, yu^(-1), 1, 1/(yu*yv)}, yw] - 4*G[{yv^(-1)}, yw]*
      G[{1, yu^(-1), 1, 1/(yu*yv)}, yw] + 4*G[{1/(yu*yv)}, yw]*
      G[{1, yu^(-1), 1, 1/(yu*yv)}, yw] + 8*G[{yv^(-1)}, yw]*
      G[{1, yu^(-1), yu^(-1), yu^(-1)}, yw] - 8*G[{1/(yu*yv)}, yw]*
      G[{1, yu^(-1), yu^(-1), yu^(-1)}, yw] - 4*G[{0}, yu^(-1)]*
      G[{1, yu^(-1), yu^(-1), yv^(-1)}, yw] - 4*G[{0}, yv^(-1)]*
      G[{1, yu^(-1), yu^(-1), yv^(-1)}, yw] + 
     4*G[{0}, yw]*G[{1, yu^(-1), yu^(-1), yv^(-1)}, yw] + 
     4*G[{1}, yu^(-1)]*G[{1, yu^(-1), yu^(-1), yv^(-1)}, yw] + 
     8*G[{1}, yv^(-1)]*G[{1, yu^(-1), yu^(-1), yv^(-1)}, yw] + 
     4*G[{1}, yw]*G[{1, yu^(-1), yu^(-1), yv^(-1)}, yw] - 
     4*G[{yu}, yv^(-1)]*G[{1, yu^(-1), yu^(-1), yv^(-1)}, yw] + 
     4*G[{yv^(-1)}, yw]*G[{1, yu^(-1), yu^(-1), yv^(-1)}, yw] - 
     4*G[{1/(yu*yv)}, yw]*G[{1, yu^(-1), yu^(-1), yv^(-1)}, yw] + 
     4*G[{0}, yu^(-1)]*G[{1, yu^(-1), yu^(-1), 1/(yu*yv)}, yw] + 
     4*G[{0}, yv^(-1)]*G[{1, yu^(-1), yu^(-1), 1/(yu*yv)}, yw] - 
     4*G[{0}, yw]*G[{1, yu^(-1), yu^(-1), 1/(yu*yv)}, yw] - 
     4*G[{1}, yu^(-1)]*G[{1, yu^(-1), yu^(-1), 1/(yu*yv)}, yw] - 
     8*G[{1}, yv^(-1)]*G[{1, yu^(-1), yu^(-1), 1/(yu*yv)}, yw] - 
     4*G[{1}, yw]*G[{1, yu^(-1), yu^(-1), 1/(yu*yv)}, yw] + 
     4*G[{yu}, yv^(-1)]*G[{1, yu^(-1), yu^(-1), 1/(yu*yv)}, yw] + 
     4*G[{yv^(-1)}, yw]*G[{1, yu^(-1), yu^(-1), 1/(yu*yv)}, yw] - 
     4*G[{1/(yu*yv)}, yw]*G[{1, yu^(-1), yu^(-1), 1/(yu*yv)}, yw] - 
     4*G[{0}, yu^(-1)]*G[{1, yu^(-1), yv^(-1), yu^(-1)}, yw] - 
     4*G[{0}, yv^(-1)]*G[{1, yu^(-1), yv^(-1), yu^(-1)}, yw] + 
     4*G[{0}, yw]*G[{1, yu^(-1), yv^(-1), yu^(-1)}, yw] + 
     4*G[{1}, yu^(-1)]*G[{1, yu^(-1), yv^(-1), yu^(-1)}, yw] + 
     8*G[{1}, yv^(-1)]*G[{1, yu^(-1), yv^(-1), yu^(-1)}, yw] + 
     4*G[{1}, yw]*G[{1, yu^(-1), yv^(-1), yu^(-1)}, yw] - 
     4*G[{yu}, yv^(-1)]*G[{1, yu^(-1), yv^(-1), yu^(-1)}, yw] + 
     4*G[{yv^(-1)}, yw]*G[{1, yu^(-1), yv^(-1), yu^(-1)}, yw] - 
     4*G[{1/(yu*yv)}, yw]*G[{1, yu^(-1), yv^(-1), yu^(-1)}, yw] - 
     4*G[{0}, yu^(-1)]*G[{1, yu^(-1), yv^(-1), yv^(-1)}, yw] - 
     4*G[{0}, yv^(-1)]*G[{1, yu^(-1), yv^(-1), yv^(-1)}, yw] + 
     4*G[{0}, yw]*G[{1, yu^(-1), yv^(-1), yv^(-1)}, yw] + 
     4*G[{1}, yu^(-1)]*G[{1, yu^(-1), yv^(-1), yv^(-1)}, yw] + 
     8*G[{1}, yv^(-1)]*G[{1, yu^(-1), yv^(-1), yv^(-1)}, yw] + 
     4*G[{1}, yw]*G[{1, yu^(-1), yv^(-1), yv^(-1)}, yw] - 
     4*G[{yu}, yv^(-1)]*G[{1, yu^(-1), yv^(-1), yv^(-1)}, yw] + 
     4*G[{yv^(-1)}, yw]*G[{1, yu^(-1), yv^(-1), yv^(-1)}, yw] - 
     4*G[{1/(yu*yv)}, yw]*G[{1, yu^(-1), yv^(-1), yv^(-1)}, yw] + 
     4*G[{0}, yu^(-1)]*G[{1, yu^(-1), yv^(-1), 1/(yu*yv)}, yw] + 
     4*G[{0}, yv^(-1)]*G[{1, yu^(-1), yv^(-1), 1/(yu*yv)}, yw] - 
     4*G[{0}, yw]*G[{1, yu^(-1), yv^(-1), 1/(yu*yv)}, yw] - 
     4*G[{1}, yu^(-1)]*G[{1, yu^(-1), yv^(-1), 1/(yu*yv)}, yw] - 
     8*G[{1}, yv^(-1)]*G[{1, yu^(-1), yv^(-1), 1/(yu*yv)}, yw] - 
     4*G[{1}, yw]*G[{1, yu^(-1), yv^(-1), 1/(yu*yv)}, yw] + 
     4*G[{yu}, yv^(-1)]*G[{1, yu^(-1), yv^(-1), 1/(yu*yv)}, yw] + 
     4*G[{0}, yu^(-1)]*G[{1, yu^(-1), 1/(yu*yv), yu^(-1)}, yw] + 
     4*G[{0}, yv^(-1)]*G[{1, yu^(-1), 1/(yu*yv), yu^(-1)}, yw] - 
     4*G[{0}, yw]*G[{1, yu^(-1), 1/(yu*yv), yu^(-1)}, yw] - 
     4*G[{1}, yu^(-1)]*G[{1, yu^(-1), 1/(yu*yv), yu^(-1)}, yw] - 
     8*G[{1}, yv^(-1)]*G[{1, yu^(-1), 1/(yu*yv), yu^(-1)}, yw] - 
     4*G[{1}, yw]*G[{1, yu^(-1), 1/(yu*yv), yu^(-1)}, yw] + 
     4*G[{yu}, yv^(-1)]*G[{1, yu^(-1), 1/(yu*yv), yu^(-1)}, yw] + 
     4*G[{0}, yu^(-1)]*G[{1, yu^(-1), 1/(yu*yv), yv^(-1)}, yw] + 
     4*G[{0}, yv^(-1)]*G[{1, yu^(-1), 1/(yu*yv), yv^(-1)}, yw] - 
     4*G[{0}, yw]*G[{1, yu^(-1), 1/(yu*yv), yv^(-1)}, yw] - 
     4*G[{1}, yu^(-1)]*G[{1, yu^(-1), 1/(yu*yv), yv^(-1)}, yw] - 
     4*G[{1}, yv^(-1)]*G[{1, yu^(-1), 1/(yu*yv), yv^(-1)}, yw] - 
     4*G[{yv^(-1)}, yw]*G[{1, yu^(-1), 1/(yu*yv), yv^(-1)}, yw] + 
     4*G[{1/(yu*yv)}, yw]*G[{1, yu^(-1), 1/(yu*yv), yv^(-1)}, yw] - 
     4*G[{0}, yu^(-1)]*G[{1, yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] - 
     4*G[{0}, yv^(-1)]*G[{1, yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] + 
     4*G[{0}, yw]*G[{1, yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] + 
     4*G[{1}, yu^(-1)]*G[{1, yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] + 
     4*G[{1}, yv^(-1)]*G[{1, yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] + 
     8*G[{1}, yv^(-1)]*G[{1, yu, yu, yu}, yv^(-1)] + 
     16*G[{yu}, yv^(-1)]*G[{1, yu, yu, yu}, yv^(-1)] - 
     4*G[{0}, yu^(-1)]*G[{1, yv^(-1), yu^(-1), yu^(-1)}, yw] - 
     4*G[{0}, yv^(-1)]*G[{1, yv^(-1), yu^(-1), yu^(-1)}, yw] + 
     4*G[{0}, yw]*G[{1, yv^(-1), yu^(-1), yu^(-1)}, yw] + 
     4*G[{1}, yu^(-1)]*G[{1, yv^(-1), yu^(-1), yu^(-1)}, yw] + 
     8*G[{1}, yv^(-1)]*G[{1, yv^(-1), yu^(-1), yu^(-1)}, yw] + 
     4*G[{1}, yw]*G[{1, yv^(-1), yu^(-1), yu^(-1)}, yw] - 
     4*G[{yu}, yv^(-1)]*G[{1, yv^(-1), yu^(-1), yu^(-1)}, yw] + 
     4*G[{yv^(-1)}, yw]*G[{1, yv^(-1), yu^(-1), yu^(-1)}, yw] - 
     4*G[{1/(yu*yv)}, yw]*G[{1, yv^(-1), yu^(-1), yu^(-1)}, yw] - 
     4*G[{0}, yu^(-1)]*G[{1, yv^(-1), yu^(-1), yv^(-1)}, yw] - 
     4*G[{0}, yv^(-1)]*G[{1, yv^(-1), yu^(-1), yv^(-1)}, yw] + 
     4*G[{0}, yw]*G[{1, yv^(-1), yu^(-1), yv^(-1)}, yw] + 
     4*G[{1}, yu^(-1)]*G[{1, yv^(-1), yu^(-1), yv^(-1)}, yw] + 
     8*G[{1}, yv^(-1)]*G[{1, yv^(-1), yu^(-1), yv^(-1)}, yw] + 
     4*G[{1}, yw]*G[{1, yv^(-1), yu^(-1), yv^(-1)}, yw] - 
     4*G[{yu}, yv^(-1)]*G[{1, yv^(-1), yu^(-1), yv^(-1)}, yw] + 
     4*G[{yv^(-1)}, yw]*G[{1, yv^(-1), yu^(-1), yv^(-1)}, yw] - 
     4*G[{1/(yu*yv)}, yw]*G[{1, yv^(-1), yu^(-1), yv^(-1)}, yw] + 
     4*G[{0}, yu^(-1)]*G[{1, yv^(-1), yu^(-1), 1/(yu*yv)}, yw] + 
     4*G[{0}, yv^(-1)]*G[{1, yv^(-1), yu^(-1), 1/(yu*yv)}, yw] - 
     4*G[{0}, yw]*G[{1, yv^(-1), yu^(-1), 1/(yu*yv)}, yw] - 
     4*G[{1}, yu^(-1)]*G[{1, yv^(-1), yu^(-1), 1/(yu*yv)}, yw] - 
     8*G[{1}, yv^(-1)]*G[{1, yv^(-1), yu^(-1), 1/(yu*yv)}, yw] - 
     4*G[{1}, yw]*G[{1, yv^(-1), yu^(-1), 1/(yu*yv)}, yw] + 
     4*G[{yu}, yv^(-1)]*G[{1, yv^(-1), yu^(-1), 1/(yu*yv)}, yw] - 
     4*G[{0}, yu^(-1)]*G[{1, yv^(-1), yv^(-1), yu^(-1)}, yw] - 
     4*G[{0}, yv^(-1)]*G[{1, yv^(-1), yv^(-1), yu^(-1)}, yw] + 
     4*G[{0}, yw]*G[{1, yv^(-1), yv^(-1), yu^(-1)}, yw] + 
     4*G[{1}, yu^(-1)]*G[{1, yv^(-1), yv^(-1), yu^(-1)}, yw] + 
     8*G[{1}, yv^(-1)]*G[{1, yv^(-1), yv^(-1), yu^(-1)}, yw] + 
     4*G[{1}, yw]*G[{1, yv^(-1), yv^(-1), yu^(-1)}, yw] - 
     4*G[{yu}, yv^(-1)]*G[{1, yv^(-1), yv^(-1), yu^(-1)}, yw] + 
     4*G[{yv^(-1)}, yw]*G[{1, yv^(-1), yv^(-1), yu^(-1)}, yw] - 
     4*G[{1/(yu*yv)}, yw]*G[{1, yv^(-1), yv^(-1), yu^(-1)}, yw] + 
     8*G[{1}, yv^(-1)]*G[{1, yv^(-1), yv^(-1), yv^(-1)}, yw] + 
     8*G[{1}, yw]*G[{1, yv^(-1), yv^(-1), yv^(-1)}, yw] - 
     8*G[{yu}, yv^(-1)]*G[{1, yv^(-1), yv^(-1), yv^(-1)}, yw] + 
     8*G[{yv^(-1)}, yw]*G[{1, yv^(-1), yv^(-1), yv^(-1)}, yw] - 
     8*G[{1/(yu*yv)}, yw]*G[{1, yv^(-1), yv^(-1), yv^(-1)}, yw] - 
     8*G[{1}, yv^(-1)]*G[{1, yv^(-1), yv^(-1), 1/(yu*yv)}, yw] - 
     8*G[{1}, yw]*G[{1, yv^(-1), yv^(-1), 1/(yu*yv)}, yw] + 
     8*G[{yu}, yv^(-1)]*G[{1, yv^(-1), yv^(-1), 1/(yu*yv)}, yw] - 
     4*G[{yv^(-1)}, yw]*G[{1, yv^(-1), yv^(-1), 1/(yu*yv)}, yw] + 
     4*G[{1/(yu*yv)}, yw]*G[{1, yv^(-1), yv^(-1), 1/(yu*yv)}, yw] + 
     4*G[{0}, yu^(-1)]*G[{1, yv^(-1), 1/(yu*yv), yu^(-1)}, yw] + 
     4*G[{0}, yv^(-1)]*G[{1, yv^(-1), 1/(yu*yv), yu^(-1)}, yw] - 
     4*G[{0}, yw]*G[{1, yv^(-1), 1/(yu*yv), yu^(-1)}, yw] - 
     4*G[{1}, yu^(-1)]*G[{1, yv^(-1), 1/(yu*yv), yu^(-1)}, yw] - 
     8*G[{1}, yv^(-1)]*G[{1, yv^(-1), 1/(yu*yv), yu^(-1)}, yw] - 
     4*G[{1}, yw]*G[{1, yv^(-1), 1/(yu*yv), yu^(-1)}, yw] + 
     4*G[{yu}, yv^(-1)]*G[{1, yv^(-1), 1/(yu*yv), yu^(-1)}, yw] - 
     4*G[{1}, yv^(-1)]*G[{1, yv^(-1), 1/(yu*yv), yv^(-1)}, yw] - 
     4*G[{1}, yw]*G[{1, yv^(-1), 1/(yu*yv), yv^(-1)}, yw] + 
     4*G[{yu}, yv^(-1)]*G[{1, yv^(-1), 1/(yu*yv), yv^(-1)}, yw] - 
     4*G[{yv^(-1)}, yw]*G[{1, yv^(-1), 1/(yu*yv), yv^(-1)}, yw] + 
     4*G[{1/(yu*yv)}, yw]*G[{1, yv^(-1), 1/(yu*yv), yv^(-1)}, yw] + 
     4*G[{1}, yv^(-1)]*G[{1, yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] + 
     4*G[{1}, yw]*G[{1, yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] - 
     4*G[{yu}, yv^(-1)]*G[{1, yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] + 
     4*G[{0}, yu^(-1)]*G[{1, 1/(yu*yv), yu^(-1), yu^(-1)}, yw] + 
     4*G[{0}, yv^(-1)]*G[{1, 1/(yu*yv), yu^(-1), yu^(-1)}, yw] - 
     4*G[{0}, yw]*G[{1, 1/(yu*yv), yu^(-1), yu^(-1)}, yw] - 
     4*G[{1}, yu^(-1)]*G[{1, 1/(yu*yv), yu^(-1), yu^(-1)}, yw] - 
     8*G[{1}, yv^(-1)]*G[{1, 1/(yu*yv), yu^(-1), yu^(-1)}, yw] - 
     4*G[{1}, yw]*G[{1, 1/(yu*yv), yu^(-1), yu^(-1)}, yw] + 
     4*G[{yu}, yv^(-1)]*G[{1, 1/(yu*yv), yu^(-1), yu^(-1)}, yw] + 
     4*G[{yv^(-1)}, yw]*G[{1, 1/(yu*yv), yu^(-1), yu^(-1)}, yw] - 
     4*G[{1/(yu*yv)}, yw]*G[{1, 1/(yu*yv), yu^(-1), yu^(-1)}, yw] - 
     4*G[{yv^(-1)}, yw]*G[{1, 1/(yu*yv), yu^(-1), 1/(yu*yv)}, yw] + 
     4*G[{1/(yu*yv)}, yw]*G[{1, 1/(yu*yv), yu^(-1), 1/(yu*yv)}, yw] - 
     4*G[{0}, yu^(-1)]*G[{1, 1/(yu*yv), yv^(-1), yv^(-1)}, yw] - 
     4*G[{0}, yv^(-1)]*G[{1, 1/(yu*yv), yv^(-1), yv^(-1)}, yw] + 
     4*G[{0}, yw]*G[{1, 1/(yu*yv), yv^(-1), yv^(-1)}, yw] + 
     4*G[{1}, yu^(-1)]*G[{1, 1/(yu*yv), yv^(-1), yv^(-1)}, yw] - 
     4*G[{1}, yw]*G[{1, 1/(yu*yv), yv^(-1), yv^(-1)}, yw] + 
     4*G[{yu}, yv^(-1)]*G[{1, 1/(yu*yv), yv^(-1), yv^(-1)}, yw] - 
     4*G[{yv^(-1)}, yw]*G[{1, 1/(yu*yv), yv^(-1), yv^(-1)}, yw] + 
     4*G[{1/(yu*yv)}, yw]*G[{1, 1/(yu*yv), yv^(-1), yv^(-1)}, yw] + 
     4*G[{0}, yu^(-1)]*G[{1, 1/(yu*yv), yv^(-1), 1/(yu*yv)}, yw] + 
     4*G[{0}, yv^(-1)]*G[{1, 1/(yu*yv), yv^(-1), 1/(yu*yv)}, yw] - 
     4*G[{0}, yw]*G[{1, 1/(yu*yv), yv^(-1), 1/(yu*yv)}, yw] - 
     4*G[{1}, yu^(-1)]*G[{1, 1/(yu*yv), yv^(-1), 1/(yu*yv)}, yw] + 
     4*G[{1}, yw]*G[{1, 1/(yu*yv), yv^(-1), 1/(yu*yv)}, yw] - 
     4*G[{yu}, yv^(-1)]*G[{1, 1/(yu*yv), yv^(-1), 1/(yu*yv)}, yw] + 
     4*G[{yv^(-1)}, yw]*G[{1, 1/(yu*yv), yv^(-1), 1/(yu*yv)}, yw] - 
     4*G[{1/(yu*yv)}, yw]*G[{1, 1/(yu*yv), yv^(-1), 1/(yu*yv)}, yw] - 
     4*G[{yv^(-1)}, yw]*G[{1, 1/(yu*yv), 1/(yu*yv), yu^(-1)}, yw] + 
     4*G[{1/(yu*yv)}, yw]*G[{1, 1/(yu*yv), 1/(yu*yv), yu^(-1)}, yw] + 
     4*G[{0}, yu^(-1)]*G[{1, 1/(yu*yv), 1/(yu*yv), yv^(-1)}, yw] + 
     4*G[{0}, yv^(-1)]*G[{1, 1/(yu*yv), 1/(yu*yv), yv^(-1)}, yw] - 
     4*G[{0}, yw]*G[{1, 1/(yu*yv), 1/(yu*yv), yv^(-1)}, yw] - 
     4*G[{1}, yu^(-1)]*G[{1, 1/(yu*yv), 1/(yu*yv), yv^(-1)}, yw] - 
     4*G[{1}, yv^(-1)]*G[{1, 1/(yu*yv), 1/(yu*yv), yv^(-1)}, yw] - 
     4*G[{0}, yu^(-1)]*G[{1, 1/(yu*yv), 1/(yu*yv), 1/(yu*yv)}, yw] - 
     4*G[{0}, yv^(-1)]*G[{1, 1/(yu*yv), 1/(yu*yv), 1/(yu*yv)}, yw] + 
     4*G[{0}, yw]*G[{1, 1/(yu*yv), 1/(yu*yv), 1/(yu*yv)}, yw] + 
     4*G[{1}, yu^(-1)]*G[{1, 1/(yu*yv), 1/(yu*yv), 1/(yu*yv)}, yw] + 
     4*G[{1}, yv^(-1)]*G[{1, 1/(yu*yv), 1/(yu*yv), 1/(yu*yv)}, yw] - 
     8*G[{yv^(-1)}, yw]*G[{yu^(-1), yu^(-1), yu^(-1), 1/(yu*yv)}, yw] + 
     8*G[{1/(yu*yv)}, yw]*G[{yu^(-1), yu^(-1), yu^(-1), 1/(yu*yv)}, yw] - 
     4*G[{0}, yu^(-1)]*G[{yu^(-1), yu^(-1), 1/(yu*yv), yv^(-1)}, yw] - 
     4*G[{0}, yv^(-1)]*G[{yu^(-1), yu^(-1), 1/(yu*yv), yv^(-1)}, yw] + 
     4*G[{0}, yw]*G[{yu^(-1), yu^(-1), 1/(yu*yv), yv^(-1)}, yw] + 
     4*G[{1}, yu^(-1)]*G[{yu^(-1), yu^(-1), 1/(yu*yv), yv^(-1)}, yw] + 
     8*G[{1}, yv^(-1)]*G[{yu^(-1), yu^(-1), 1/(yu*yv), yv^(-1)}, yw] + 
     4*G[{1}, yw]*G[{yu^(-1), yu^(-1), 1/(yu*yv), yv^(-1)}, yw] - 
     8*G[{yu^(-1)}, yw]*G[{yu^(-1), yu^(-1), 1/(yu*yv), yv^(-1)}, yw] - 
     4*G[{yu}, yv^(-1)]*G[{yu^(-1), yu^(-1), 1/(yu*yv), yv^(-1)}, yw] + 
     4*G[{yv^(-1)}, yw]*G[{yu^(-1), yu^(-1), 1/(yu*yv), yv^(-1)}, yw] - 
     4*G[{1/(yu*yv)}, yw]*G[{yu^(-1), yu^(-1), 1/(yu*yv), yv^(-1)}, yw] + 
     4*G[{0}, yu^(-1)]*G[{yu^(-1), yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] + 
     4*G[{0}, yv^(-1)]*G[{yu^(-1), yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] - 
     4*G[{0}, yw]*G[{yu^(-1), yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] - 
     4*G[{1}, yu^(-1)]*G[{yu^(-1), yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] - 
     8*G[{1}, yv^(-1)]*G[{yu^(-1), yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] - 
     4*G[{1}, yw]*G[{yu^(-1), yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] + 
     8*G[{yu^(-1)}, yw]*G[{yu^(-1), yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] + 
     4*G[{yu}, yv^(-1)]*G[{yu^(-1), yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] - 
     4*G[{yv^(-1)}, yw]*G[{yu^(-1), yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] + 
     4*G[{1/(yu*yv)}, yw]*G[{yu^(-1), yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] + 
     4*G[{0}, yu^(-1)]*G[{yu^(-1), 1/(yu*yv), yv^(-1), yv^(-1)}, yw] + 
     4*G[{0}, yv^(-1)]*G[{yu^(-1), 1/(yu*yv), yv^(-1), yv^(-1)}, yw] - 
     4*G[{0}, yw]*G[{yu^(-1), 1/(yu*yv), yv^(-1), yv^(-1)}, yw] - 
     4*G[{1}, yu^(-1)]*G[{yu^(-1), 1/(yu*yv), yv^(-1), yv^(-1)}, yw] - 
     8*G[{1}, yv^(-1)]*G[{yu^(-1), 1/(yu*yv), yv^(-1), yv^(-1)}, yw] - 
     4*G[{1}, yw]*G[{yu^(-1), 1/(yu*yv), yv^(-1), yv^(-1)}, yw] + 
     8*G[{yu^(-1)}, yw]*G[{yu^(-1), 1/(yu*yv), yv^(-1), yv^(-1)}, yw] + 
     4*G[{yu}, yv^(-1)]*G[{yu^(-1), 1/(yu*yv), yv^(-1), yv^(-1)}, yw] - 
     4*G[{yv^(-1)}, yw]*G[{yu^(-1), 1/(yu*yv), yv^(-1), yv^(-1)}, yw] + 
     4*G[{1/(yu*yv)}, yw]*G[{yu^(-1), 1/(yu*yv), yv^(-1), yv^(-1)}, yw] - 
     4*G[{0}, yu^(-1)]*G[{yu^(-1), 1/(yu*yv), yv^(-1), 1/(yu*yv)}, yw] - 
     4*G[{0}, yv^(-1)]*G[{yu^(-1), 1/(yu*yv), yv^(-1), 1/(yu*yv)}, yw] + 
     4*G[{0}, yw]*G[{yu^(-1), 1/(yu*yv), yv^(-1), 1/(yu*yv)}, yw] + 
     4*G[{1}, yu^(-1)]*G[{yu^(-1), 1/(yu*yv), yv^(-1), 1/(yu*yv)}, yw] + 
     8*G[{1}, yv^(-1)]*G[{yu^(-1), 1/(yu*yv), yv^(-1), 1/(yu*yv)}, yw] + 
     4*G[{1}, yw]*G[{yu^(-1), 1/(yu*yv), yv^(-1), 1/(yu*yv)}, yw] - 
     8*G[{yu^(-1)}, yw]*G[{yu^(-1), 1/(yu*yv), yv^(-1), 1/(yu*yv)}, yw] - 
     4*G[{yu}, yv^(-1)]*G[{yu^(-1), 1/(yu*yv), yv^(-1), 1/(yu*yv)}, yw] - 
     4*G[{0}, yu^(-1)]*G[{yu^(-1), 1/(yu*yv), 1/(yu*yv), yv^(-1)}, yw] - 
     4*G[{0}, yv^(-1)]*G[{yu^(-1), 1/(yu*yv), 1/(yu*yv), yv^(-1)}, yw] + 
     4*G[{0}, yw]*G[{yu^(-1), 1/(yu*yv), 1/(yu*yv), yv^(-1)}, yw] + 
     4*G[{1}, yu^(-1)]*G[{yu^(-1), 1/(yu*yv), 1/(yu*yv), yv^(-1)}, yw] + 
     8*G[{1}, yv^(-1)]*G[{yu^(-1), 1/(yu*yv), 1/(yu*yv), yv^(-1)}, yw] + 
     4*G[{1}, yw]*G[{yu^(-1), 1/(yu*yv), 1/(yu*yv), yv^(-1)}, yw] - 
     8*G[{yu^(-1)}, yw]*G[{yu^(-1), 1/(yu*yv), 1/(yu*yv), yv^(-1)}, yw] - 
     4*G[{yu}, yv^(-1)]*G[{yu^(-1), 1/(yu*yv), 1/(yu*yv), yv^(-1)}, yw] + 
     4*G[{yv^(-1)}, yw]*G[{yu^(-1), 1/(yu*yv), 1/(yu*yv), yv^(-1)}, yw] - 
     4*G[{1/(yu*yv)}, yw]*G[{yu^(-1), 1/(yu*yv), 1/(yu*yv), yv^(-1)}, yw] + 
     4*G[{0}, yu^(-1)]*G[{yu^(-1), 1/(yu*yv), 1/(yu*yv), 1/(yu*yv)}, yw] + 
     4*G[{0}, yv^(-1)]*G[{yu^(-1), 1/(yu*yv), 1/(yu*yv), 1/(yu*yv)}, yw] - 
     4*G[{0}, yw]*G[{yu^(-1), 1/(yu*yv), 1/(yu*yv), 1/(yu*yv)}, yw] - 
     4*G[{1}, yu^(-1)]*G[{yu^(-1), 1/(yu*yv), 1/(yu*yv), 1/(yu*yv)}, yw] - 
     8*G[{1}, yv^(-1)]*G[{yu^(-1), 1/(yu*yv), 1/(yu*yv), 1/(yu*yv)}, yw] - 
     4*G[{1}, yw]*G[{yu^(-1), 1/(yu*yv), 1/(yu*yv), 1/(yu*yv)}, yw] + 
     8*G[{yu^(-1)}, yw]*G[{yu^(-1), 1/(yu*yv), 1/(yu*yv), 1/(yu*yv)}, yw] + 
     4*G[{yu}, yv^(-1)]*G[{yu^(-1), 1/(yu*yv), 1/(yu*yv), 1/(yu*yv)}, yw] - 
     8*G[{1}, yv^(-1)]*G[{yv^(-1), yv^(-1), yv^(-1), 1/(yu*yv)}, yw] - 
     8*G[{1}, yw]*G[{yv^(-1), yv^(-1), yv^(-1), 1/(yu*yv)}, yw] + 
     8*G[{yu^(-1)}, yw]*G[{yv^(-1), yv^(-1), yv^(-1), 1/(yu*yv)}, yw] + 
     8*G[{yu}, yv^(-1)]*G[{yv^(-1), yv^(-1), yv^(-1), 1/(yu*yv)}, yw] - 
     8*G[{1/(yu*yv)}, yw]*G[{yv^(-1), yv^(-1), yv^(-1), 1/(yu*yv)}, yw] - 
     4*G[{1/(yu*yv)}, yw]*G[{yv^(-1), yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] + 
     8*G[{1}, yv^(-1)]*G[{yv^(-1), 1/(yu*yv), 1/(yu*yv), 1/(yu*yv)}, yw] + 
     8*G[{1}, yw]*G[{yv^(-1), 1/(yu*yv), 1/(yu*yv), 1/(yu*yv)}, yw] - 
     8*G[{yu^(-1)}, yw]*G[{yv^(-1), 1/(yu*yv), 1/(yu*yv), 1/(yu*yv)}, yw] - 
     8*G[{yu}, yv^(-1)]*G[{yv^(-1), 1/(yu*yv), 1/(yu*yv), 1/(yu*yv)}, yw] + 
     12*G[{0, 0, 0, 1, 1}, yu^(-1)] + 4*G[{0, 0, 1, 0, 1}, yu^(-1)] - 
     24*G[{0, 0, 1, 1, 1}, yv^(-1)] + 8*G[{0, 0, 1, 1, yu}, yv^(-1)] - 
     4*G[{0, 0, 1, yu^(-1), yv^(-1)}, yw] + 
     4*G[{0, 0, 1, yu^(-1), 1/(yu*yv)}, yw] + 
     8*G[{0, 0, 1, yu, 1}, yv^(-1)] + 8*G[{0, 0, 1, yu, yu}, yv^(-1)] - 
     4*G[{0, 0, 1, yv^(-1), yu^(-1)}, yw] - 
     8*G[{0, 0, 1, yv^(-1), yv^(-1)}, yw] + 
     4*G[{0, 0, 1, yv^(-1), 1/(yu*yv)}, yw] + 
     4*G[{0, 0, 1, 1/(yu*yv), yu^(-1)}, yw] + 
     4*G[{0, 0, 1, 1/(yu*yv), yv^(-1)}, yw] - 
     8*G[{0, 0, 1, 1/(yu*yv), 1/(yu*yv)}, yw] - 
     4*G[{0, 0, yu^(-1), 1, yv^(-1)}, yw] + 
     4*G[{0, 0, yu^(-1), 1, 1/(yu*yv)}, yw] + 
     8*G[{0, 0, yu^(-1), yv^(-1), yv^(-1)}, yw] - 
     4*G[{0, 0, yu^(-1), yv^(-1), 1/(yu*yv)}, yw] - 
     4*G[{0, 0, yu^(-1), 1/(yu*yv), yv^(-1)}, yw] + 
     8*G[{0, 0, yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] + 
     8*G[{0, 0, yu, 1, 1}, yv^(-1)] - 8*G[{0, 0, yu, 1, yu}, yv^(-1)] - 
     24*G[{0, 0, yu, yu, 1}, yv^(-1)] + 24*G[{0, 0, yu, yu, yu}, yv^(-1)] - 
     4*G[{0, 0, yv^(-1), 1, yv^(-1)}, yw] + 
     4*G[{0, 0, yv^(-1), 1, 1/(yu*yv)}, yw] + 
     4*G[{0, 0, yv^(-1), yu^(-1), yv^(-1)}, yw] - 
     4*G[{0, 0, yv^(-1), yu^(-1), 1/(yu*yv)}, yw] + 
     4*G[{0, 0, yv^(-1), 1/(yu*yv), 1}, yw] - 
     4*G[{0, 0, yv^(-1), 1/(yu*yv), yu^(-1)}, yw] + 
     4*G[{0, 0, 1/(yu*yv), 1, yv^(-1)}, yw] - 
     4*G[{0, 0, 1/(yu*yv), 1, 1/(yu*yv)}, yw] - 
     4*G[{0, 0, 1/(yu*yv), yu^(-1), yv^(-1)}, yw] + 
     4*G[{0, 0, 1/(yu*yv), yu^(-1), 1/(yu*yv)}, yw] + 
     4*G[{0, 0, 1/(yu*yv), yv^(-1), 1}, yw] - 
     4*G[{0, 0, 1/(yu*yv), yv^(-1), yu^(-1)}, yw] - 
     8*G[{0, 1, 0, 1, 1}, yv^(-1)] - 2*G[{0, 1, 0, 1, yv^(-1)}, yw] + 
     2*G[{0, 1, 0, 1, 1/(yu*yv)}, yw] + 8*G[{0, 1, 0, yu, yu}, yv^(-1)] - 
     2*G[{0, 1, 0, yv^(-1), 1}, yw] - 4*G[{0, 1, 0, yv^(-1), yv^(-1)}, yw] + 
     2*G[{0, 1, 0, yv^(-1), 1/(yu*yv)}, yw] + 
     2*G[{0, 1, 0, 1/(yu*yv), 1}, yw] + 2*G[{0, 1, 0, 1/(yu*yv), yv^(-1)}, 
       yw] - 4*G[{0, 1, 0, 1/(yu*yv), 1/(yu*yv)}, yw] - 
     8*G[{0, 1, 1, 0, yu}, yv^(-1)] - 8*G[{0, 1, 1, 1, 1}, yv^(-1)] + 
     8*G[{0, 1, 1, 1, yu}, yv^(-1)] + 2*G[{0, 1, 1, 1, yv^(-1)}, yw] - 
     2*G[{0, 1, 1, 1, 1/(yu*yv)}, yw] + 2*G[{0, 1, 1, yu^(-1), yv^(-1)}, 
       yw] - 2*G[{0, 1, 1, yu^(-1), 1/(yu*yv)}, yw] - 
     4*G[{0, 1, 1, yu, 1}, yv^(-1)] + 4*G[{0, 1, 1, yu, yu}, yv^(-1)] + 
     2*G[{0, 1, 1, yv^(-1), 1}, yw] + 2*G[{0, 1, 1, yv^(-1), yu^(-1)}, yw] + 
     8*G[{0, 1, 1, yv^(-1), yv^(-1)}, yw] - 
     4*G[{0, 1, 1, yv^(-1), 1/(yu*yv)}, yw] - 
     2*G[{0, 1, 1, 1/(yu*yv), 1}, yw] - 2*G[{0, 1, 1, 1/(yu*yv), yu^(-1)}, 
       yw] - 4*G[{0, 1, 1, 1/(yu*yv), yv^(-1)}, yw] + 
     4*G[{0, 1, yu^(-1), 1, yv^(-1)}, yw] - 
     4*G[{0, 1, yu^(-1), 1, 1/(yu*yv)}, yw] - 
     8*G[{0, 1, yu^(-1), yu^(-1), yv^(-1)}, yw] + 
     8*G[{0, 1, yu^(-1), yu^(-1), 1/(yu*yv)}, yw] + 
     4*G[{0, 1, yu^(-1), yv^(-1), 1}, yw] - 
     8*G[{0, 1, yu^(-1), yv^(-1), yu^(-1)}, yw] - 
     8*G[{0, 1, yu^(-1), yv^(-1), yv^(-1)}, yw] + 
     4*G[{0, 1, yu^(-1), yv^(-1), 1/(yu*yv)}, yw] - 
     4*G[{0, 1, yu^(-1), 1/(yu*yv), 1}, yw] + 
     8*G[{0, 1, yu^(-1), 1/(yu*yv), yu^(-1)}, yw] + 
     4*G[{0, 1, yu^(-1), 1/(yu*yv), yv^(-1)}, yw] + 
     8*G[{0, 1, yu, 0, yu}, yv^(-1)] - 4*G[{0, 1, yu, 1, 1}, yv^(-1)] + 
     4*G[{0, 1, yu, 1, yu}, yv^(-1)] + 16*G[{0, 1, yu, yu, 1}, yv^(-1)] - 
     16*G[{0, 1, yu, yu, yu}, yv^(-1)] - 2*G[{0, 1, yv^(-1), 0, yu^(-1)}, 
       yw] - 2*G[{0, 1, yv^(-1), 0, yv^(-1)}, yw] + 
     2*G[{0, 1, yv^(-1), 0, 1/(yu*yv)}, yw] + 
     4*G[{0, 1, yv^(-1), 1, yu^(-1)}, yw] + 
     8*G[{0, 1, yv^(-1), 1, yv^(-1)}, yw] - 
     4*G[{0, 1, yv^(-1), 1, 1/(yu*yv)}, yw] + 
     4*G[{0, 1, yv^(-1), yu^(-1), 1}, yw] - 
     8*G[{0, 1, yv^(-1), yu^(-1), yu^(-1)}, yw] - 
     8*G[{0, 1, yv^(-1), yu^(-1), yv^(-1)}, yw] + 
     4*G[{0, 1, yv^(-1), yu^(-1), 1/(yu*yv)}, yw] + 
     4*G[{0, 1, yv^(-1), yv^(-1), 1}, yw] - 
     8*G[{0, 1, yv^(-1), yv^(-1), yu^(-1)}, yw] - 
     8*G[{0, 1, yv^(-1), yv^(-1), yv^(-1)}, yw] + 
     4*G[{0, 1, yv^(-1), yv^(-1), 1/(yu*yv)}, yw] - 
     4*G[{0, 1, yv^(-1), 1/(yu*yv), 1}, yw] + 
     8*G[{0, 1, yv^(-1), 1/(yu*yv), yu^(-1)}, yw] + 
     4*G[{0, 1, yv^(-1), 1/(yu*yv), yv^(-1)}, yw] + 
     2*G[{0, 1, 1/(yu*yv), 0, yu^(-1)}, yw] - 
     2*G[{0, 1, 1/(yu*yv), 0, 1/(yu*yv)}, yw] - 
     4*G[{0, 1, 1/(yu*yv), 1, yu^(-1)}, yw] - 
     6*G[{0, 1, 1/(yu*yv), 1, yv^(-1)}, yw] + 
     2*G[{0, 1, 1/(yu*yv), 1, 1/(yu*yv)}, yw] - 
     4*G[{0, 1, 1/(yu*yv), yu^(-1), 1}, yw] + 
     8*G[{0, 1, 1/(yu*yv), yu^(-1), yu^(-1)}, yw] + 
     6*G[{0, 1, 1/(yu*yv), yu^(-1), yv^(-1)}, yw] - 
     2*G[{0, 1, 1/(yu*yv), yu^(-1), 1/(yu*yv)}, yw] - 
     2*G[{0, 1, 1/(yu*yv), yv^(-1), 1}, yw] + 
     6*G[{0, 1, 1/(yu*yv), yv^(-1), yu^(-1)}, yw] + 
     8*G[{0, 1, 1/(yu*yv), yv^(-1), yv^(-1)}, yw] - 
     4*G[{0, 1, 1/(yu*yv), yv^(-1), 1/(yu*yv)}, yw] + 
     2*G[{0, 1, 1/(yu*yv), 1/(yu*yv), 1}, yw] - 
     6*G[{0, 1, 1/(yu*yv), 1/(yu*yv), yu^(-1)}, yw] - 
     4*G[{0, 1, 1/(yu*yv), 1/(yu*yv), yv^(-1)}, yw] - 
     2*G[{0, yu^(-1), 0, yu^(-1), yv^(-1)}, yw] + 
     2*G[{0, yu^(-1), 0, yu^(-1), 1/(yu*yv)}, yw] + 
     2*G[{0, yu^(-1), 0, yv^(-1), 1}, yw] - 
     2*G[{0, yu^(-1), 0, yv^(-1), yu^(-1)}, yw] + 
     4*G[{0, yu^(-1), 0, yv^(-1), yv^(-1)}, yw] - 
     2*G[{0, yu^(-1), 0, yv^(-1), 1/(yu*yv)}, yw] - 
     2*G[{0, yu^(-1), 0, 1/(yu*yv), 1}, yw] + 
     2*G[{0, yu^(-1), 0, 1/(yu*yv), yu^(-1)}, yw] - 
     2*G[{0, yu^(-1), 0, 1/(yu*yv), yv^(-1)}, yw] + 
     4*G[{0, yu^(-1), 0, 1/(yu*yv), 1/(yu*yv)}, yw] - 
     2*G[{0, yu^(-1), 1, 1, yv^(-1)}, yw] + 
     2*G[{0, yu^(-1), 1, 1, 1/(yu*yv)}, yw] - 
     2*G[{0, yu^(-1), 1, yu^(-1), yv^(-1)}, yw] + 
     2*G[{0, yu^(-1), 1, yu^(-1), 1/(yu*yv)}, yw] - 
     2*G[{0, yu^(-1), 1, yv^(-1), 1}, yw] - 
     2*G[{0, yu^(-1), 1, yv^(-1), yu^(-1)}, yw] - 
     8*G[{0, yu^(-1), 1, yv^(-1), yv^(-1)}, yw] + 
     4*G[{0, yu^(-1), 1, yv^(-1), 1/(yu*yv)}, yw] + 
     2*G[{0, yu^(-1), 1, 1/(yu*yv), 1}, yw] + 
     2*G[{0, yu^(-1), 1, 1/(yu*yv), yu^(-1)}, yw] + 
     4*G[{0, yu^(-1), 1, 1/(yu*yv), yv^(-1)}, yw] - 
     4*G[{0, yu^(-1), yu^(-1), 1, yv^(-1)}, yw] + 
     4*G[{0, yu^(-1), yu^(-1), 1, 1/(yu*yv)}, yw] + 
     8*G[{0, yu^(-1), yu^(-1), yu^(-1), yv^(-1)}, yw] - 
     8*G[{0, yu^(-1), yu^(-1), yu^(-1), 1/(yu*yv)}, yw] - 
     4*G[{0, yu^(-1), yu^(-1), yv^(-1), 1}, yw] + 
     8*G[{0, yu^(-1), yu^(-1), yv^(-1), yu^(-1)}, yw] + 
     8*G[{0, yu^(-1), yu^(-1), yv^(-1), yv^(-1)}, yw] - 
     4*G[{0, yu^(-1), yu^(-1), yv^(-1), 1/(yu*yv)}, yw] + 
     4*G[{0, yu^(-1), yu^(-1), 1/(yu*yv), 1}, yw] - 
     8*G[{0, yu^(-1), yu^(-1), 1/(yu*yv), yu^(-1)}, yw] - 
     4*G[{0, yu^(-1), yu^(-1), 1/(yu*yv), yv^(-1)}, yw] + 
     2*G[{0, yu^(-1), yv^(-1), 0, yv^(-1)}, yw] - 
     2*G[{0, yu^(-1), yv^(-1), 0, 1/(yu*yv)}, yw] - 
     4*G[{0, yu^(-1), yv^(-1), 1, yu^(-1)}, yw] - 
     8*G[{0, yu^(-1), yv^(-1), 1, yv^(-1)}, yw] + 
     4*G[{0, yu^(-1), yv^(-1), 1, 1/(yu*yv)}, yw] - 
     4*G[{0, yu^(-1), yv^(-1), yu^(-1), 1}, yw] + 
     8*G[{0, yu^(-1), yv^(-1), yu^(-1), yu^(-1)}, yw] + 
     8*G[{0, yu^(-1), yv^(-1), yu^(-1), yv^(-1)}, yw] - 
     4*G[{0, yu^(-1), yv^(-1), yu^(-1), 1/(yu*yv)}, yw] - 
     4*G[{0, yu^(-1), yv^(-1), yv^(-1), 1}, yw] + 
     8*G[{0, yu^(-1), yv^(-1), yv^(-1), yu^(-1)}, yw] + 
     8*G[{0, yu^(-1), yv^(-1), yv^(-1), yv^(-1)}, yw] - 
     4*G[{0, yu^(-1), yv^(-1), yv^(-1), 1/(yu*yv)}, yw] + 
     4*G[{0, yu^(-1), yv^(-1), 1/(yu*yv), 1}, yw] - 
     8*G[{0, yu^(-1), yv^(-1), 1/(yu*yv), yu^(-1)}, yw] - 
     4*G[{0, yu^(-1), yv^(-1), 1/(yu*yv), yv^(-1)}, yw] + 
     2*G[{0, yu^(-1), 1/(yu*yv), 0, 1/(yu*yv)}, yw] + 
     4*G[{0, yu^(-1), 1/(yu*yv), 1, yu^(-1)}, yw] + 
     6*G[{0, yu^(-1), 1/(yu*yv), 1, yv^(-1)}, yw] - 
     2*G[{0, yu^(-1), 1/(yu*yv), 1, 1/(yu*yv)}, yw] + 
     4*G[{0, yu^(-1), 1/(yu*yv), yu^(-1), 1}, yw] - 
     8*G[{0, yu^(-1), 1/(yu*yv), yu^(-1), yu^(-1)}, yw] - 
     6*G[{0, yu^(-1), 1/(yu*yv), yu^(-1), yv^(-1)}, yw] + 
     2*G[{0, yu^(-1), 1/(yu*yv), yu^(-1), 1/(yu*yv)}, yw] + 
     2*G[{0, yu^(-1), 1/(yu*yv), yv^(-1), 1}, yw] - 
     6*G[{0, yu^(-1), 1/(yu*yv), yv^(-1), yu^(-1)}, yw] - 
     8*G[{0, yu^(-1), 1/(yu*yv), yv^(-1), yv^(-1)}, yw] + 
     4*G[{0, yu^(-1), 1/(yu*yv), yv^(-1), 1/(yu*yv)}, yw] - 
     2*G[{0, yu^(-1), 1/(yu*yv), 1/(yu*yv), 1}, yw] + 
     6*G[{0, yu^(-1), 1/(yu*yv), 1/(yu*yv), yu^(-1)}, yw] + 
     4*G[{0, yu^(-1), 1/(yu*yv), 1/(yu*yv), yv^(-1)}, yw] - 
     8*G[{0, yu, 0, yu, 1}, yv^(-1)] + 8*G[{0, yu, 0, yu, yu}, yv^(-1)] + 
     8*G[{0, yu, 1, 1, 1}, yv^(-1)] - 8*G[{0, yu, 1, 1, yu}, yv^(-1)] + 
     4*G[{0, yu, 1, yu, 1}, yv^(-1)] - 4*G[{0, yu, 1, yu, yu}, yv^(-1)] + 
     4*G[{0, yu, yu, 1, 1}, yv^(-1)] - 4*G[{0, yu, yu, 1, yu}, yv^(-1)] - 
     16*G[{0, yu, yu, yu, 1}, yv^(-1)] + 16*G[{0, yu, yu, yu, yu}, yv^(-1)] + 
     2*G[{0, yv^(-1), 0, yv^(-1), 1}, yw] - 
     2*G[{0, yv^(-1), 0, yv^(-1), yu^(-1)}, yw] + 
     2*G[{0, yv^(-1), 1, 0, 1/(yu*yv)}, yw] + 
     4*G[{0, yv^(-1), 1, 1, yu^(-1)}, yw] + 
     6*G[{0, yv^(-1), 1, 1, yv^(-1)}, yw] - 
     2*G[{0, yv^(-1), 1, 1, 1/(yu*yv)}, yw] + 
     4*G[{0, yv^(-1), 1, yu^(-1), 1}, yw] - 
     8*G[{0, yv^(-1), 1, yu^(-1), yu^(-1)}, yw] - 
     6*G[{0, yv^(-1), 1, yu^(-1), yv^(-1)}, yw] + 
     2*G[{0, yv^(-1), 1, yu^(-1), 1/(yu*yv)}, yw] + 
     2*G[{0, yv^(-1), 1, yv^(-1), 1}, yw] - 
     6*G[{0, yv^(-1), 1, yv^(-1), yu^(-1)}, yw] - 
     8*G[{0, yv^(-1), 1, yv^(-1), yv^(-1)}, yw] + 
     4*G[{0, yv^(-1), 1, yv^(-1), 1/(yu*yv)}, yw] - 
     2*G[{0, yv^(-1), 1, 1/(yu*yv), 1}, yw] + 
     6*G[{0, yv^(-1), 1, 1/(yu*yv), yu^(-1)}, yw] + 
     4*G[{0, yv^(-1), 1, 1/(yu*yv), yv^(-1)}, yw] - 
     2*G[{0, yv^(-1), yu^(-1), 0, 1/(yu*yv)}, yw] - 
     4*G[{0, yv^(-1), yu^(-1), 1, yu^(-1)}, yw] - 
     8*G[{0, yv^(-1), yu^(-1), 1, yv^(-1)}, yw] + 
     4*G[{0, yv^(-1), yu^(-1), 1, 1/(yu*yv)}, yw] - 
     4*G[{0, yv^(-1), yu^(-1), yu^(-1), 1}, yw] + 
     8*G[{0, yv^(-1), yu^(-1), yu^(-1), yu^(-1)}, yw] + 
     8*G[{0, yv^(-1), yu^(-1), yu^(-1), yv^(-1)}, yw] - 
     4*G[{0, yv^(-1), yu^(-1), yu^(-1), 1/(yu*yv)}, yw] - 
     4*G[{0, yv^(-1), yu^(-1), yv^(-1), 1}, yw] + 
     8*G[{0, yv^(-1), yu^(-1), yv^(-1), yu^(-1)}, yw] + 
     8*G[{0, yv^(-1), yu^(-1), yv^(-1), yv^(-1)}, yw] - 
     4*G[{0, yv^(-1), yu^(-1), yv^(-1), 1/(yu*yv)}, yw] + 
     4*G[{0, yv^(-1), yu^(-1), 1/(yu*yv), 1}, yw] - 
     8*G[{0, yv^(-1), yu^(-1), 1/(yu*yv), yu^(-1)}, yw] - 
     4*G[{0, yv^(-1), yu^(-1), 1/(yu*yv), yv^(-1)}, yw] - 
     4*G[{0, yv^(-1), yv^(-1), 1, yu^(-1)}, yw] - 
     8*G[{0, yv^(-1), yv^(-1), 1, yv^(-1)}, yw] + 
     4*G[{0, yv^(-1), yv^(-1), 1, 1/(yu*yv)}, yw] - 
     4*G[{0, yv^(-1), yv^(-1), yu^(-1), 1}, yw] + 
     8*G[{0, yv^(-1), yv^(-1), yu^(-1), yu^(-1)}, yw] + 
     8*G[{0, yv^(-1), yv^(-1), yu^(-1), yv^(-1)}, yw] - 
     4*G[{0, yv^(-1), yv^(-1), yu^(-1), 1/(yu*yv)}, yw] - 
     8*G[{0, yv^(-1), yv^(-1), yv^(-1), 1}, yw] + 
     8*G[{0, yv^(-1), yv^(-1), yv^(-1), yu^(-1)}, yw] + 
     4*G[{0, yv^(-1), yv^(-1), 1/(yu*yv), 1}, yw] - 
     4*G[{0, yv^(-1), yv^(-1), 1/(yu*yv), yu^(-1)}, yw] + 
     4*G[{0, yv^(-1), 1/(yu*yv), 1, yu^(-1)}, yw] + 
     2*G[{0, yv^(-1), 1/(yu*yv), 1, yv^(-1)}, yw] + 
     2*G[{0, yv^(-1), 1/(yu*yv), 1, 1/(yu*yv)}, yw] + 
     4*G[{0, yv^(-1), 1/(yu*yv), yu^(-1), 1}, yw] - 
     8*G[{0, yv^(-1), 1/(yu*yv), yu^(-1), yu^(-1)}, yw] - 
     2*G[{0, yv^(-1), 1/(yu*yv), yu^(-1), yv^(-1)}, yw] - 
     2*G[{0, yv^(-1), 1/(yu*yv), yu^(-1), 1/(yu*yv)}, yw] + 
     2*G[{0, yv^(-1), 1/(yu*yv), yv^(-1), 1}, yw] - 
     2*G[{0, yv^(-1), 1/(yu*yv), yv^(-1), yu^(-1)}, yw] + 
     2*G[{0, yv^(-1), 1/(yu*yv), 1/(yu*yv), 1}, yw] - 
     2*G[{0, yv^(-1), 1/(yu*yv), 1/(yu*yv), yu^(-1)}, yw] + 
     2*G[{0, 1/(yu*yv), 0, 1/(yu*yv), 1}, yw] - 
     2*G[{0, 1/(yu*yv), 0, 1/(yu*yv), yu^(-1)}, yw] - 
     4*G[{0, 1/(yu*yv), 1, 1, yu^(-1)}, yw] - 
     6*G[{0, 1/(yu*yv), 1, 1, yv^(-1)}, yw] + 
     2*G[{0, 1/(yu*yv), 1, 1, 1/(yu*yv)}, yw] - 
     4*G[{0, 1/(yu*yv), 1, yu^(-1), 1}, yw] + 
     8*G[{0, 1/(yu*yv), 1, yu^(-1), yu^(-1)}, yw] + 
     6*G[{0, 1/(yu*yv), 1, yu^(-1), yv^(-1)}, yw] - 
     2*G[{0, 1/(yu*yv), 1, yu^(-1), 1/(yu*yv)}, yw] - 
     2*G[{0, 1/(yu*yv), 1, yv^(-1), 1}, yw] + 
     6*G[{0, 1/(yu*yv), 1, yv^(-1), yu^(-1)}, yw] + 
     8*G[{0, 1/(yu*yv), 1, yv^(-1), yv^(-1)}, yw] - 
     4*G[{0, 1/(yu*yv), 1, yv^(-1), 1/(yu*yv)}, yw] + 
     2*G[{0, 1/(yu*yv), 1, 1/(yu*yv), 1}, yw] - 
     6*G[{0, 1/(yu*yv), 1, 1/(yu*yv), yu^(-1)}, yw] - 
     4*G[{0, 1/(yu*yv), 1, 1/(yu*yv), yv^(-1)}, yw] + 
     4*G[{0, 1/(yu*yv), yu^(-1), 1, yu^(-1)}, yw] + 
     8*G[{0, 1/(yu*yv), yu^(-1), 1, yv^(-1)}, yw] - 
     4*G[{0, 1/(yu*yv), yu^(-1), 1, 1/(yu*yv)}, yw] + 
     4*G[{0, 1/(yu*yv), yu^(-1), yu^(-1), 1}, yw] - 
     8*G[{0, 1/(yu*yv), yu^(-1), yu^(-1), yu^(-1)}, yw] - 
     8*G[{0, 1/(yu*yv), yu^(-1), yu^(-1), yv^(-1)}, yw] + 
     4*G[{0, 1/(yu*yv), yu^(-1), yu^(-1), 1/(yu*yv)}, yw] + 
     4*G[{0, 1/(yu*yv), yu^(-1), yv^(-1), 1}, yw] - 
     8*G[{0, 1/(yu*yv), yu^(-1), yv^(-1), yu^(-1)}, yw] - 
     8*G[{0, 1/(yu*yv), yu^(-1), yv^(-1), yv^(-1)}, yw] + 
     4*G[{0, 1/(yu*yv), yu^(-1), yv^(-1), 1/(yu*yv)}, yw] - 
     4*G[{0, 1/(yu*yv), yu^(-1), 1/(yu*yv), 1}, yw] + 
     8*G[{0, 1/(yu*yv), yu^(-1), 1/(yu*yv), yu^(-1)}, yw] + 
     4*G[{0, 1/(yu*yv), yu^(-1), 1/(yu*yv), yv^(-1)}, yw] + 
     4*G[{0, 1/(yu*yv), yv^(-1), 1, yu^(-1)}, yw] + 
     8*G[{0, 1/(yu*yv), yv^(-1), 1, yv^(-1)}, yw] - 
     4*G[{0, 1/(yu*yv), yv^(-1), 1, 1/(yu*yv)}, yw] + 
     4*G[{0, 1/(yu*yv), yv^(-1), yu^(-1), 1}, yw] - 
     8*G[{0, 1/(yu*yv), yv^(-1), yu^(-1), yu^(-1)}, yw] - 
     8*G[{0, 1/(yu*yv), yv^(-1), yu^(-1), yv^(-1)}, yw] + 
     4*G[{0, 1/(yu*yv), yv^(-1), yu^(-1), 1/(yu*yv)}, yw] + 
     8*G[{0, 1/(yu*yv), yv^(-1), yv^(-1), 1}, yw] - 
     8*G[{0, 1/(yu*yv), yv^(-1), yv^(-1), yu^(-1)}, yw] - 
     4*G[{0, 1/(yu*yv), yv^(-1), 1/(yu*yv), 1}, yw] + 
     4*G[{0, 1/(yu*yv), yv^(-1), 1/(yu*yv), yu^(-1)}, yw] - 
     4*G[{0, 1/(yu*yv), 1/(yu*yv), 1, yu^(-1)}, yw] - 
     2*G[{0, 1/(yu*yv), 1/(yu*yv), 1, yv^(-1)}, yw] - 
     2*G[{0, 1/(yu*yv), 1/(yu*yv), 1, 1/(yu*yv)}, yw] - 
     4*G[{0, 1/(yu*yv), 1/(yu*yv), yu^(-1), 1}, yw] + 
     8*G[{0, 1/(yu*yv), 1/(yu*yv), yu^(-1), yu^(-1)}, yw] + 
     2*G[{0, 1/(yu*yv), 1/(yu*yv), yu^(-1), yv^(-1)}, yw] + 
     2*G[{0, 1/(yu*yv), 1/(yu*yv), yu^(-1), 1/(yu*yv)}, yw] - 
     2*G[{0, 1/(yu*yv), 1/(yu*yv), yv^(-1), 1}, yw] + 
     2*G[{0, 1/(yu*yv), 1/(yu*yv), yv^(-1), yu^(-1)}, yw] - 
     2*G[{0, 1/(yu*yv), 1/(yu*yv), 1/(yu*yv), 1}, yw] + 
     2*G[{0, 1/(yu*yv), 1/(yu*yv), 1/(yu*yv), yu^(-1)}, yw] + 
     16*G[{1, 1, 1, 1, yu}, yv^(-1)] - 4*G[{1, 1, 1, yu^(-1), yv^(-1)}, yw] + 
     4*G[{1, 1, 1, yu^(-1), 1/(yu*yv)}, yw] - 
     44*G[{1, 1, 1, yu, yu}, yv^(-1)] - 4*G[{1, 1, 1, yv^(-1), yu^(-1)}, 
       yw] + 4*G[{1, 1, 1, yv^(-1), yv^(-1)}, yw] + 
     4*G[{1, 1, 1, yv^(-1), 1/(yu*yv)}, yw] + 
     4*G[{1, 1, 1, 1/(yu*yv), yu^(-1)}, yw] + 
     4*G[{1, 1, 1, 1/(yu*yv), yv^(-1)}, yw] - 
     12*G[{1, 1, 1, 1/(yu*yv), 1/(yu*yv)}, yw] - 
     4*G[{1, 1, yu^(-1), 1, yv^(-1)}, yw] + 
     4*G[{1, 1, yu^(-1), 1, 1/(yu*yv)}, yw] - 
     8*G[{1, 1, yu^(-1), yu^(-1), yv^(-1)}, yw] + 
     8*G[{1, 1, yu^(-1), yu^(-1), 1/(yu*yv)}, yw] - 
     8*G[{1, 1, yu^(-1), yv^(-1), yu^(-1)}, yw] + 
     4*G[{1, 1, yu^(-1), yv^(-1), 1/(yu*yv)}, yw] + 
     8*G[{1, 1, yu^(-1), 1/(yu*yv), yu^(-1)}, yw] - 
     4*G[{1, 1, yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] - 
     20*G[{1, 1, yu, 1, yu}, yv^(-1)] + 36*G[{1, 1, yu, yu, yu}, yv^(-1)] + 
     4*G[{1, 1, yv^(-1), 1, yv^(-1)}, yw] - 
     8*G[{1, 1, yv^(-1), yu^(-1), yu^(-1)}, yw] - 
     8*G[{1, 1, yv^(-1), yu^(-1), yv^(-1)}, yw] + 
     4*G[{1, 1, yv^(-1), yu^(-1), 1/(yu*yv)}, yw] - 
     16*G[{1, 1, yv^(-1), yv^(-1), yu^(-1)}, yw] - 
     20*G[{1, 1, yv^(-1), yv^(-1), yv^(-1)}, yw] + 
     16*G[{1, 1, yv^(-1), yv^(-1), 1/(yu*yv)}, yw] + 
     8*G[{1, 1, yv^(-1), 1/(yu*yv), yu^(-1)}, yw] + 
     8*G[{1, 1, yv^(-1), 1/(yu*yv), yv^(-1)}, yw] - 
     4*G[{1, 1, yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] - 
     4*G[{1, 1, 1/(yu*yv), 1, 1/(yu*yv)}, yw] + 
     8*G[{1, 1, 1/(yu*yv), yu^(-1), yu^(-1)}, yw] + 
     4*G[{1, 1, 1/(yu*yv), yu^(-1), yv^(-1)}, yw] + 
     4*G[{1, 1, 1/(yu*yv), yv^(-1), yu^(-1)}, yw] + 
     4*G[{1, 1, 1/(yu*yv), yv^(-1), yv^(-1)}, yw] - 
     4*G[{1, 1, 1/(yu*yv), yv^(-1), 1/(yu*yv)}, yw] + 
     4*G[{1, 1, 1/(yu*yv), 1/(yu*yv), yu^(-1)}, yw] - 
     4*G[{1, yu^(-1), 1, yu^(-1), yv^(-1)}, yw] + 
     4*G[{1, yu^(-1), 1, yu^(-1), 1/(yu*yv)}, yw] - 
     4*G[{1, yu^(-1), 1, yv^(-1), yu^(-1)}, yw] + 
     4*G[{1, yu^(-1), 1, yv^(-1), yv^(-1)}, yw] + 
     4*G[{1, yu^(-1), 1, 1/(yu*yv), yu^(-1)}, yw] - 
     4*G[{1, yu^(-1), 1, 1/(yu*yv), 1/(yu*yv)}, yw] - 
     4*G[{1, yu^(-1), yu^(-1), 1, yv^(-1)}, yw] + 
     4*G[{1, yu^(-1), yu^(-1), 1, 1/(yu*yv)}, yw] - 
     8*G[{1, yu^(-1), yu^(-1), yu^(-1), yv^(-1)}, yw] + 
     8*G[{1, yu^(-1), yu^(-1), yu^(-1), 1/(yu*yv)}, yw] - 
     8*G[{1, yu^(-1), yu^(-1), yv^(-1), yu^(-1)}, yw] - 
     8*G[{1, yu^(-1), yu^(-1), yv^(-1), yv^(-1)}, yw] + 
     4*G[{1, yu^(-1), yu^(-1), yv^(-1), 1/(yu*yv)}, yw] + 
     8*G[{1, yu^(-1), yu^(-1), 1/(yu*yv), yu^(-1)}, yw] + 
     4*G[{1, yu^(-1), yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] + 
     4*G[{1, yu^(-1), yv^(-1), 1, yv^(-1)}, yw] - 
     8*G[{1, yu^(-1), yv^(-1), yu^(-1), yu^(-1)}, yw] - 
     8*G[{1, yu^(-1), yv^(-1), yu^(-1), yv^(-1)}, yw] + 
     4*G[{1, yu^(-1), yv^(-1), yu^(-1), 1/(yu*yv)}, yw] - 
     8*G[{1, yu^(-1), yv^(-1), yv^(-1), yu^(-1)}, yw] - 
     8*G[{1, yu^(-1), yv^(-1), yv^(-1), yv^(-1)}, yw] + 
     4*G[{1, yu^(-1), yv^(-1), yv^(-1), 1/(yu*yv)}, yw] + 
     8*G[{1, yu^(-1), yv^(-1), 1/(yu*yv), yu^(-1)}, yw] + 
     4*G[{1, yu^(-1), yv^(-1), 1/(yu*yv), yv^(-1)}, yw] - 
     4*G[{1, yu^(-1), 1/(yu*yv), 1, yv^(-1)}, yw] + 
     8*G[{1, yu^(-1), 1/(yu*yv), yu^(-1), yu^(-1)}, yw] + 
     4*G[{1, yu^(-1), 1/(yu*yv), yu^(-1), yv^(-1)}, yw] + 
     4*G[{1, yu^(-1), 1/(yu*yv), yv^(-1), yu^(-1)}, yw] + 
     8*G[{1, yu^(-1), 1/(yu*yv), yv^(-1), yv^(-1)}, yw] - 
     4*G[{1, yu^(-1), 1/(yu*yv), yv^(-1), 1/(yu*yv)}, yw] - 
     4*G[{1, yu^(-1), 1/(yu*yv), 1/(yu*yv), yu^(-1)}, yw] - 
     4*G[{1, yu^(-1), 1/(yu*yv), 1/(yu*yv), yv^(-1)}, yw] + 
     20*G[{1, yu, 1, yu, yu}, yv^(-1)] - 24*G[{1, yu, yu, yu, yu}, yv^(-1)] - 
     4*G[{1, yv^(-1), 1, yv^(-1), yu^(-1)}, yw] - 
     4*G[{1, yv^(-1), 1, yv^(-1), yv^(-1)}, yw] + 
     4*G[{1, yv^(-1), 1, yv^(-1), 1/(yu*yv)}, yw] - 
     8*G[{1, yv^(-1), yu^(-1), yu^(-1), yu^(-1)}, yw] - 
     8*G[{1, yv^(-1), yu^(-1), yu^(-1), yv^(-1)}, yw] + 
     4*G[{1, yv^(-1), yu^(-1), yu^(-1), 1/(yu*yv)}, yw] - 
     8*G[{1, yv^(-1), yu^(-1), yv^(-1), yu^(-1)}, yw] - 
     8*G[{1, yv^(-1), yu^(-1), yv^(-1), yv^(-1)}, yw] + 
     4*G[{1, yv^(-1), yu^(-1), yv^(-1), 1/(yu*yv)}, yw] + 
     8*G[{1, yv^(-1), yu^(-1), 1/(yu*yv), yu^(-1)}, yw] + 
     4*G[{1, yv^(-1), yu^(-1), 1/(yu*yv), yv^(-1)}, yw] - 
     8*G[{1, yv^(-1), yv^(-1), yu^(-1), yu^(-1)}, yw] - 
     8*G[{1, yv^(-1), yv^(-1), yu^(-1), yv^(-1)}, yw] + 
     4*G[{1, yv^(-1), yv^(-1), yu^(-1), 1/(yu*yv)}, yw] - 
     8*G[{1, yv^(-1), yv^(-1), yv^(-1), yu^(-1)}, yw] - 
     8*G[{1, yv^(-1), yv^(-1), yv^(-1), yv^(-1)}, yw] + 
     8*G[{1, yv^(-1), yv^(-1), yv^(-1), 1/(yu*yv)}, yw] + 
     8*G[{1, yv^(-1), yv^(-1), 1/(yu*yv), yu^(-1)}, yw] + 
     4*G[{1, yv^(-1), yv^(-1), 1/(yu*yv), yv^(-1)}, yw] - 
     4*G[{1, yv^(-1), yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] + 
     8*G[{1, yv^(-1), 1/(yu*yv), yu^(-1), yu^(-1)}, yw] + 
     4*G[{1, yv^(-1), 1/(yu*yv), yu^(-1), yv^(-1)}, yw] + 
     4*G[{1, yv^(-1), 1/(yu*yv), yv^(-1), yu^(-1)}, yw] + 
     4*G[{1, yv^(-1), 1/(yu*yv), yv^(-1), yv^(-1)}, yw] - 
     4*G[{1, yv^(-1), 1/(yu*yv), yv^(-1), 1/(yu*yv)}, yw] - 
     4*G[{1, yv^(-1), 1/(yu*yv), 1/(yu*yv), yu^(-1)}, yw] + 
     4*G[{1, 1/(yu*yv), 1, 1/(yu*yv), yu^(-1)}, yw] + 
     8*G[{1, 1/(yu*yv), yu^(-1), yu^(-1), yu^(-1)}, yw] + 
     4*G[{1, 1/(yu*yv), yu^(-1), yu^(-1), 1/(yu*yv)}, yw] + 
     4*G[{1, 1/(yu*yv), yu^(-1), 1/(yu*yv), yv^(-1)}, yw] - 
     4*G[{1, 1/(yu*yv), yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] - 
     4*G[{1, 1/(yu*yv), yv^(-1), yv^(-1), 1/(yu*yv)}, yw] + 
     4*G[{1, 1/(yu*yv), yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] + 
     4*G[{1, 1/(yu*yv), 1/(yu*yv), yu^(-1), yv^(-1)}, yw] - 
     4*G[{1, 1/(yu*yv), 1/(yu*yv), yu^(-1), 1/(yu*yv)}, yw] + 
     4*G[{1, 1/(yu*yv), 1/(yu*yv), yv^(-1), yu^(-1)}, yw] + 
     4*G[{1, 1/(yu*yv), 1/(yu*yv), yv^(-1), yv^(-1)}, yw] - 
     4*G[{1, 1/(yu*yv), 1/(yu*yv), 1/(yu*yv), yu^(-1)}, yw] - 
     4*G[{1, 1/(yu*yv), 1/(yu*yv), 1/(yu*yv), yv^(-1)}, yw] + 
     8*G[{yu^(-1), yu^(-1), yu^(-1), 1/(yu*yv), yv^(-1)}, yw] - 
     8*G[{yu^(-1), yu^(-1), yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] - 
     8*G[{yu^(-1), yu^(-1), 1/(yu*yv), yv^(-1), yv^(-1)}, yw] + 
     4*G[{yu^(-1), yu^(-1), 1/(yu*yv), yv^(-1), 1/(yu*yv)}, yw] + 
     4*G[{yu^(-1), yu^(-1), 1/(yu*yv), 1/(yu*yv), 1/(yu*yv)}, yw] - 
     4*G[{yu^(-1), 1/(yu*yv), yu^(-1), 1/(yu*yv), yv^(-1)}, yw] + 
     4*G[{yu^(-1), 1/(yu*yv), yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] + 
     8*G[{yu^(-1), 1/(yu*yv), yv^(-1), yv^(-1), yv^(-1)}, yw] - 
     4*G[{yu^(-1), 1/(yu*yv), yv^(-1), yv^(-1), 1/(yu*yv)}, yw] - 
     4*G[{yu^(-1), 1/(yu*yv), yv^(-1), 1/(yu*yv), yv^(-1)}, yw] - 
     8*G[{yu^(-1), 1/(yu*yv), 1/(yu*yv), yv^(-1), yv^(-1)}, yw] + 
     4*G[{yu^(-1), 1/(yu*yv), 1/(yu*yv), yv^(-1), 1/(yu*yv)}, yw] + 
     4*G[{yu^(-1), 1/(yu*yv), 1/(yu*yv), 1/(yu*yv), yv^(-1)}, yw] + 
     8*G[{yv^(-1), yv^(-1), yv^(-1), yv^(-1), 1/(yu*yv)}, yw] - 
     4*G[{yv^(-1), yv^(-1), yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] - 
     4*G[{yv^(-1), yv^(-1), 1/(yu*yv), yv^(-1), 1/(yu*yv)}, yw] + 
     12*G[{yv^(-1), yv^(-1), 1/(yu*yv), 1/(yu*yv), 1/(yu*yv)}, yw] + 
     4*G[{yv^(-1), 1/(yu*yv), yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] + 
     (2*Pi^2*Zeta[3])/3 + 4*G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*Zeta[3] - 
     4*G[{1}, yu^(-1)]*G[{yu}, yv^(-1)]*Zeta[3] + 2*G[{yu}, yv^(-1)]^2*
      Zeta[3] - 4*G[{0}, yu^(-1)]*G[{yv^(-1)}, yw]*Zeta[3] - 
     4*G[{0}, yv^(-1)]*G[{yv^(-1)}, yw]*Zeta[3] + 
     4*G[{0}, yw]*G[{yv^(-1)}, yw]*Zeta[3] + 4*G[{1}, yu^(-1)]*
      G[{yv^(-1)}, yw]*Zeta[3] - 4*G[{1}, yv^(-1)]*G[{yv^(-1)}, yw]*Zeta[3] - 
     4*G[{1}, yw]*G[{yv^(-1)}, yw]*Zeta[3] + 8*G[{yu}, yv^(-1)]*
      G[{yv^(-1)}, yw]*Zeta[3] - 2*G[{yv^(-1)}, yw]^2*Zeta[3] + 
     4*G[{0}, yu^(-1)]*G[{1/(yu*yv)}, yw]*Zeta[3] + 
     4*G[{0}, yv^(-1)]*G[{1/(yu*yv)}, yw]*Zeta[3] - 
     4*G[{0}, yw]*G[{1/(yu*yv)}, yw]*Zeta[3] - 4*G[{1}, yu^(-1)]*
      G[{1/(yu*yv)}, yw]*Zeta[3] + 4*G[{1}, yv^(-1)]*G[{1/(yu*yv)}, yw]*
      Zeta[3] + 4*G[{1}, yw]*G[{1/(yu*yv)}, yw]*Zeta[3] - 
     8*G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw]*Zeta[3] + 
     4*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*Zeta[3] - 
     4*G[{0, yv^(-1)}, yw]*Zeta[3] + 4*G[{0, 1/(yu*yv)}, yw]*Zeta[3] - 
     4*G[{1, yu}, yv^(-1)]*Zeta[3] + 4*G[{1, yv^(-1)}, yw]*Zeta[3] - 
     4*G[{1, 1/(yu*yv)}, yw]*Zeta[3] - 4*G[{yv^(-1), 1/(yu*yv)}, yw]*Zeta[3]
 
M1vuwRegII = (-17*Pi^4*G[{0}, yu^(-1)])/180 - (17*Pi^4*G[{0}, yv^(-1)])/180 + 
     (17*Pi^4*G[{0}, yw])/180 - (Pi^2*G[{0}, yu^(-1)]*G[{1}, yu^(-1)]*
       G[{1}, yv^(-1)])/3 - (Pi^2*G[{0}, yv^(-1)]*G[{1}, yu^(-1)]*
       G[{1}, yv^(-1)])/3 + (Pi^2*G[{0}, yw]*G[{1}, yu^(-1)]*G[{1}, yv^(-1)])/
      3 + (Pi^2*G[{1}, yu^(-1)]^2*G[{1}, yv^(-1)])/6 - 
     (Pi^2*G[{0}, yu^(-1)]*G[{1}, yv^(-1)]^2)/6 - 
     (Pi^2*G[{0}, yv^(-1)]*G[{1}, yv^(-1)]^2)/6 + 
     (Pi^2*G[{0}, yw]*G[{1}, yv^(-1)]^2)/6 + 
     (Pi^2*G[{1}, yu^(-1)]*G[{1}, yv^(-1)]^2)/2 - 
     G[{0}, yu^(-1)]^2*G[{1}, yu^(-1)]*G[{1}, yv^(-1)]^2 - 
     2*G[{0}, yu^(-1)]*G[{0}, yv^(-1)]*G[{1}, yu^(-1)]*G[{1}, yv^(-1)]^2 - 
     G[{0}, yv^(-1)]^2*G[{1}, yu^(-1)]*G[{1}, yv^(-1)]^2 + 
     2*G[{0}, yu^(-1)]*G[{0}, yw]*G[{1}, yu^(-1)]*G[{1}, yv^(-1)]^2 + 
     2*G[{0}, yv^(-1)]*G[{0}, yw]*G[{1}, yu^(-1)]*G[{1}, yv^(-1)]^2 - 
     G[{0}, yw]^2*G[{1}, yu^(-1)]*G[{1}, yv^(-1)]^2 + 
     2*G[{0}, yu^(-1)]*G[{1}, yu^(-1)]^2*G[{1}, yv^(-1)]^2 + 
     2*G[{0}, yv^(-1)]*G[{1}, yu^(-1)]^2*G[{1}, yv^(-1)]^2 - 
     2*G[{0}, yw]*G[{1}, yu^(-1)]^2*G[{1}, yv^(-1)]^2 - 
     G[{1}, yu^(-1)]^3*G[{1}, yv^(-1)]^2 + (Pi^2*G[{1}, yv^(-1)]^3)/18 + 
     G[{0}, yu^(-1)]*G[{1}, yu^(-1)]*G[{1}, yv^(-1)]^3 + 
     G[{0}, yv^(-1)]*G[{1}, yu^(-1)]*G[{1}, yv^(-1)]^3 - 
     G[{0}, yw]*G[{1}, yu^(-1)]*G[{1}, yv^(-1)]^3 - 
     G[{1}, yu^(-1)]^2*G[{1}, yv^(-1)]^3 - 
     (G[{1}, yu^(-1)]*G[{1}, yv^(-1)]^4)/3 + (17*Pi^4*G[{yu}, yv^(-1)])/180 + 
     (Pi^2*G[{0}, yu^(-1)]*G[{1}, yu^(-1)]*G[{yu}, yv^(-1)])/3 + 
     (Pi^2*G[{0}, yv^(-1)]*G[{1}, yu^(-1)]*G[{yu}, yv^(-1)])/3 - 
     (Pi^2*G[{0}, yw]*G[{1}, yu^(-1)]*G[{yu}, yv^(-1)])/3 - 
     (Pi^2*G[{1}, yu^(-1)]^2*G[{yu}, yv^(-1)])/6 - 
     (Pi^2*G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*G[{yu}, yv^(-1)])/3 + 
     2*G[{0}, yu^(-1)]^2*G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*G[{yu}, yv^(-1)] + 
     4*G[{0}, yu^(-1)]*G[{0}, yv^(-1)]*G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*
      G[{yu}, yv^(-1)] + 2*G[{0}, yv^(-1)]^2*G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*
      G[{yu}, yv^(-1)] - 4*G[{0}, yu^(-1)]*G[{0}, yw]*G[{1}, yu^(-1)]*
      G[{1}, yv^(-1)]*G[{yu}, yv^(-1)] - 4*G[{0}, yv^(-1)]*G[{0}, yw]*
      G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*G[{yu}, yv^(-1)] + 
     2*G[{0}, yw]^2*G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*G[{yu}, yv^(-1)] - 
     4*G[{0}, yu^(-1)]*G[{1}, yu^(-1)]^2*G[{1}, yv^(-1)]*G[{yu}, yv^(-1)] - 
     4*G[{0}, yv^(-1)]*G[{1}, yu^(-1)]^2*G[{1}, yv^(-1)]*G[{yu}, yv^(-1)] + 
     4*G[{0}, yw]*G[{1}, yu^(-1)]^2*G[{1}, yv^(-1)]*G[{yu}, yv^(-1)] + 
     2*G[{1}, yu^(-1)]^3*G[{1}, yv^(-1)]*G[{yu}, yv^(-1)] + 
     (Pi^2*G[{1}, yv^(-1)]^2*G[{yu}, yv^(-1)])/6 + 
     G[{0}, yu^(-1)]*G[{1}, yu^(-1)]*G[{1}, yv^(-1)]^2*G[{yu}, yv^(-1)] + 
     G[{0}, yv^(-1)]*G[{1}, yu^(-1)]*G[{1}, yv^(-1)]^2*G[{yu}, yv^(-1)] - 
     G[{0}, yw]*G[{1}, yu^(-1)]*G[{1}, yv^(-1)]^2*G[{yu}, yv^(-1)] - 
     G[{1}, yu^(-1)]^2*G[{1}, yv^(-1)]^2*G[{yu}, yv^(-1)] - 
     (2*G[{1}, yu^(-1)]*G[{1}, yv^(-1)]^3*G[{yu}, yv^(-1)])/3 - 
     G[{0}, yu^(-1)]^2*G[{1}, yu^(-1)]*G[{yu}, yv^(-1)]^2 - 
     2*G[{0}, yu^(-1)]*G[{0}, yv^(-1)]*G[{1}, yu^(-1)]*G[{yu}, yv^(-1)]^2 - 
     G[{0}, yv^(-1)]^2*G[{1}, yu^(-1)]*G[{yu}, yv^(-1)]^2 + 
     2*G[{0}, yu^(-1)]*G[{0}, yw]*G[{1}, yu^(-1)]*G[{yu}, yv^(-1)]^2 + 
     2*G[{0}, yv^(-1)]*G[{0}, yw]*G[{1}, yu^(-1)]*G[{yu}, yv^(-1)]^2 - 
     G[{0}, yw]^2*G[{1}, yu^(-1)]*G[{yu}, yv^(-1)]^2 + 
     2*G[{0}, yu^(-1)]*G[{1}, yu^(-1)]^2*G[{yu}, yv^(-1)]^2 + 
     2*G[{0}, yv^(-1)]*G[{1}, yu^(-1)]^2*G[{yu}, yv^(-1)]^2 - 
     2*G[{0}, yw]*G[{1}, yu^(-1)]^2*G[{yu}, yv^(-1)]^2 - 
     G[{1}, yu^(-1)]^3*G[{yu}, yv^(-1)]^2 - 4*G[{0}, yu^(-1)]*G[{1}, yu^(-1)]*
      G[{1}, yv^(-1)]*G[{yu}, yv^(-1)]^2 - 4*G[{0}, yv^(-1)]*G[{1}, yu^(-1)]*
      G[{1}, yv^(-1)]*G[{yu}, yv^(-1)]^2 + 4*G[{0}, yw]*G[{1}, yu^(-1)]*
      G[{1}, yv^(-1)]*G[{yu}, yv^(-1)]^2 + 4*G[{1}, yu^(-1)]^2*
      G[{1}, yv^(-1)]*G[{yu}, yv^(-1)]^2 - 
     (G[{1}, yu^(-1)]*G[{1}, yv^(-1)]^2*G[{yu}, yv^(-1)]^2)/2 + 
     (G[{0}, yu^(-1)]^2*G[{yu}, yv^(-1)]^3)/3 + 
     (2*G[{0}, yu^(-1)]*G[{0}, yv^(-1)]*G[{yu}, yv^(-1)]^3)/3 + 
     (G[{0}, yv^(-1)]^2*G[{yu}, yv^(-1)]^3)/3 - 
     (2*G[{0}, yu^(-1)]*G[{0}, yw]*G[{yu}, yv^(-1)]^3)/3 - 
     (2*G[{0}, yv^(-1)]*G[{0}, yw]*G[{yu}, yv^(-1)]^3)/3 + 
     (G[{0}, yw]^2*G[{yu}, yv^(-1)]^3)/3 + 
     (4*G[{0}, yu^(-1)]*G[{1}, yu^(-1)]*G[{yu}, yv^(-1)]^3)/3 + 
     (4*G[{0}, yv^(-1)]*G[{1}, yu^(-1)]*G[{yu}, yv^(-1)]^3)/3 - 
     (4*G[{0}, yw]*G[{1}, yu^(-1)]*G[{yu}, yv^(-1)]^3)/3 - 
     (5*G[{1}, yu^(-1)]^2*G[{yu}, yv^(-1)]^3)/3 + 
     (8*G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*G[{yu}, yv^(-1)]^3)/3 - 
     (G[{1}, yv^(-1)]^2*G[{yu}, yv^(-1)]^3)/3 - 
     (2*G[{0}, yu^(-1)]*G[{yu}, yv^(-1)]^4)/3 - 
     (2*G[{0}, yv^(-1)]*G[{yu}, yv^(-1)]^4)/3 + 
     (2*G[{0}, yw]*G[{yu}, yv^(-1)]^4)/3 - 
     (G[{1}, yu^(-1)]*G[{yu}, yv^(-1)]^4)/2 + (11*G[{yu}, yv^(-1)]^5)/30 + 
     (Pi^2*G[{0}, yu^(-1)]*G[{1}, yu^(-1)]*G[{yv^(-1)}, yw])/3 + 
     (Pi^2*G[{0}, yv^(-1)]*G[{1}, yu^(-1)]*G[{yv^(-1)}, yw])/3 - 
     (Pi^2*G[{0}, yw]*G[{1}, yu^(-1)]*G[{yv^(-1)}, yw])/3 - 
     (Pi^2*G[{1}, yu^(-1)]^2*G[{yv^(-1)}, yw])/6 + 
     (Pi^2*G[{0}, yu^(-1)]*G[{1}, yv^(-1)]*G[{yv^(-1)}, yw])/3 + 
     (Pi^2*G[{0}, yv^(-1)]*G[{1}, yv^(-1)]*G[{yv^(-1)}, yw])/3 - 
     (Pi^2*G[{0}, yw]*G[{1}, yv^(-1)]*G[{yv^(-1)}, yw])/3 - 
     Pi^2*G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*G[{yv^(-1)}, yw] + 
     2*G[{0}, yu^(-1)]^2*G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*G[{yv^(-1)}, yw] + 
     4*G[{0}, yu^(-1)]*G[{0}, yv^(-1)]*G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*
      G[{yv^(-1)}, yw] + 2*G[{0}, yv^(-1)]^2*G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*
      G[{yv^(-1)}, yw] - 4*G[{0}, yu^(-1)]*G[{0}, yw]*G[{1}, yu^(-1)]*
      G[{1}, yv^(-1)]*G[{yv^(-1)}, yw] - 4*G[{0}, yv^(-1)]*G[{0}, yw]*
      G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*G[{yv^(-1)}, yw] + 
     2*G[{0}, yw]^2*G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*G[{yv^(-1)}, yw] - 
     4*G[{0}, yu^(-1)]*G[{1}, yu^(-1)]^2*G[{1}, yv^(-1)]*G[{yv^(-1)}, yw] - 
     4*G[{0}, yv^(-1)]*G[{1}, yu^(-1)]^2*G[{1}, yv^(-1)]*G[{yv^(-1)}, yw] + 
     4*G[{0}, yw]*G[{1}, yu^(-1)]^2*G[{1}, yv^(-1)]*G[{yv^(-1)}, yw] + 
     2*G[{1}, yu^(-1)]^3*G[{1}, yv^(-1)]*G[{yv^(-1)}, yw] - 
     (Pi^2*G[{1}, yv^(-1)]^2*G[{yv^(-1)}, yw])/6 - 
     3*G[{0}, yu^(-1)]*G[{1}, yu^(-1)]*G[{1}, yv^(-1)]^2*G[{yv^(-1)}, yw] - 
     3*G[{0}, yv^(-1)]*G[{1}, yu^(-1)]*G[{1}, yv^(-1)]^2*G[{yv^(-1)}, yw] + 
     3*G[{0}, yw]*G[{1}, yu^(-1)]*G[{1}, yv^(-1)]^2*G[{yv^(-1)}, yw] + 
     3*G[{1}, yu^(-1)]^2*G[{1}, yv^(-1)]^2*G[{yv^(-1)}, yw] + 
     (4*G[{1}, yu^(-1)]*G[{1}, yv^(-1)]^3*G[{yv^(-1)}, yw])/3 - 
     (Pi^2*G[{0}, yu^(-1)]*G[{1}, yw]*G[{yv^(-1)}, yw])/3 - 
     (Pi^2*G[{0}, yv^(-1)]*G[{1}, yw]*G[{yv^(-1)}, yw])/3 + 
     (Pi^2*G[{0}, yw]*G[{1}, yw]*G[{yv^(-1)}, yw])/3 + 
     (Pi^2*G[{1}, yu^(-1)]*G[{1}, yw]*G[{yv^(-1)}, yw])/3 + 
     (Pi^2*G[{1}, yv^(-1)]*G[{1}, yw]*G[{yv^(-1)}, yw])/3 + 
     2*G[{0}, yu^(-1)]*G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*G[{1}, yw]*
      G[{yv^(-1)}, yw] + 2*G[{0}, yv^(-1)]*G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*
      G[{1}, yw]*G[{yv^(-1)}, yw] - 2*G[{0}, yw]*G[{1}, yu^(-1)]*
      G[{1}, yv^(-1)]*G[{1}, yw]*G[{yv^(-1)}, yw] - 
     2*G[{1}, yu^(-1)]^2*G[{1}, yv^(-1)]*G[{1}, yw]*G[{yv^(-1)}, yw] - 
     3*G[{1}, yu^(-1)]*G[{1}, yv^(-1)]^2*G[{1}, yw]*G[{yv^(-1)}, yw] - 
     (Pi^2*G[{0}, yu^(-1)]*G[{yu}, yv^(-1)]*G[{yv^(-1)}, yw])/3 - 
     (Pi^2*G[{0}, yv^(-1)]*G[{yu}, yv^(-1)]*G[{yv^(-1)}, yw])/3 + 
     (Pi^2*G[{0}, yw]*G[{yu}, yv^(-1)]*G[{yv^(-1)}, yw])/3 + 
     (2*Pi^2*G[{1}, yu^(-1)]*G[{yu}, yv^(-1)]*G[{yv^(-1)}, yw])/3 - 
     2*G[{0}, yu^(-1)]^2*G[{1}, yu^(-1)]*G[{yu}, yv^(-1)]*G[{yv^(-1)}, yw] - 
     4*G[{0}, yu^(-1)]*G[{0}, yv^(-1)]*G[{1}, yu^(-1)]*G[{yu}, yv^(-1)]*
      G[{yv^(-1)}, yw] - 2*G[{0}, yv^(-1)]^2*G[{1}, yu^(-1)]*G[{yu}, yv^(-1)]*
      G[{yv^(-1)}, yw] + 4*G[{0}, yu^(-1)]*G[{0}, yw]*G[{1}, yu^(-1)]*
      G[{yu}, yv^(-1)]*G[{yv^(-1)}, yw] + 4*G[{0}, yv^(-1)]*G[{0}, yw]*
      G[{1}, yu^(-1)]*G[{yu}, yv^(-1)]*G[{yv^(-1)}, yw] - 
     2*G[{0}, yw]^2*G[{1}, yu^(-1)]*G[{yu}, yv^(-1)]*G[{yv^(-1)}, yw] + 
     4*G[{0}, yu^(-1)]*G[{1}, yu^(-1)]^2*G[{yu}, yv^(-1)]*G[{yv^(-1)}, yw] + 
     4*G[{0}, yv^(-1)]*G[{1}, yu^(-1)]^2*G[{yu}, yv^(-1)]*G[{yv^(-1)}, yw] - 
     4*G[{0}, yw]*G[{1}, yu^(-1)]^2*G[{yu}, yv^(-1)]*G[{yv^(-1)}, yw] - 
     2*G[{1}, yu^(-1)]^3*G[{yu}, yv^(-1)]*G[{yv^(-1)}, yw] + 
     G[{1}, yu^(-1)]*G[{1}, yv^(-1)]^2*G[{yu}, yv^(-1)]*G[{yv^(-1)}, yw] - 
     2*G[{0}, yu^(-1)]*G[{1}, yu^(-1)]*G[{1}, yw]*G[{yu}, yv^(-1)]*
      G[{yv^(-1)}, yw] - 2*G[{0}, yv^(-1)]*G[{1}, yu^(-1)]*G[{1}, yw]*
      G[{yu}, yv^(-1)]*G[{yv^(-1)}, yw] + 2*G[{0}, yw]*G[{1}, yu^(-1)]*
      G[{1}, yw]*G[{yu}, yv^(-1)]*G[{yv^(-1)}, yw] + 
     2*G[{1}, yu^(-1)]^2*G[{1}, yw]*G[{yu}, yv^(-1)]*G[{yv^(-1)}, yw] + 
     2*G[{0}, yu^(-1)]*G[{1}, yv^(-1)]*G[{1}, yw]*G[{yu}, yv^(-1)]*
      G[{yv^(-1)}, yw] + 2*G[{0}, yv^(-1)]*G[{1}, yv^(-1)]*G[{1}, yw]*
      G[{yu}, yv^(-1)]*G[{yv^(-1)}, yw] - 2*G[{0}, yw]*G[{1}, yv^(-1)]*
      G[{1}, yw]*G[{yu}, yv^(-1)]*G[{yv^(-1)}, yw] + 
     2*G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*G[{1}, yw]*G[{yu}, yv^(-1)]*
      G[{yv^(-1)}, yw] - 2*G[{1}, yv^(-1)]^2*G[{1}, yw]*G[{yu}, yv^(-1)]*
      G[{yv^(-1)}, yw] + G[{0}, yu^(-1)]^2*G[{yu}, yv^(-1)]^2*
      G[{yv^(-1)}, yw] + 2*G[{0}, yu^(-1)]*G[{0}, yv^(-1)]*G[{yu}, yv^(-1)]^2*
      G[{yv^(-1)}, yw] + G[{0}, yv^(-1)]^2*G[{yu}, yv^(-1)]^2*
      G[{yv^(-1)}, yw] - 2*G[{0}, yu^(-1)]*G[{0}, yw]*G[{yu}, yv^(-1)]^2*
      G[{yv^(-1)}, yw] - 2*G[{0}, yv^(-1)]*G[{0}, yw]*G[{yu}, yv^(-1)]^2*
      G[{yv^(-1)}, yw] + G[{0}, yw]^2*G[{yu}, yv^(-1)]^2*G[{yv^(-1)}, yw] - 
     G[{1}, yu^(-1)]^2*G[{yu}, yv^(-1)]^2*G[{yv^(-1)}, yw] - 
     G[{1}, yv^(-1)]^2*G[{yu}, yv^(-1)]^2*G[{yv^(-1)}, yw] - 
     G[{1}, yu^(-1)]*G[{1}, yw]*G[{yu}, yv^(-1)]^2*G[{yv^(-1)}, yw] - 
     (4*G[{0}, yu^(-1)]*G[{yu}, yv^(-1)]^3*G[{yv^(-1)}, yw])/3 - 
     (4*G[{0}, yv^(-1)]*G[{yu}, yv^(-1)]^3*G[{yv^(-1)}, yw])/3 + 
     (4*G[{0}, yw]*G[{yu}, yv^(-1)]^3*G[{yv^(-1)}, yw])/3 + 
     (2*G[{1}, yu^(-1)]*G[{yu}, yv^(-1)]^3*G[{yv^(-1)}, yw])/3 + 
     (G[{1}, yw]*G[{yu}, yv^(-1)]^3*G[{yv^(-1)}, yw])/3 + 
     (G[{yu}, yv^(-1)]^4*G[{yv^(-1)}, yw])/2 + 
     (Pi^2*G[{1}, yu^(-1)]*G[{yv^(-1)}, yw]^2)/3 - 
     G[{0}, yu^(-1)]^2*G[{1}, yu^(-1)]*G[{yv^(-1)}, yw]^2 - 
     2*G[{0}, yu^(-1)]*G[{0}, yv^(-1)]*G[{1}, yu^(-1)]*G[{yv^(-1)}, yw]^2 - 
     G[{0}, yv^(-1)]^2*G[{1}, yu^(-1)]*G[{yv^(-1)}, yw]^2 + 
     2*G[{0}, yu^(-1)]*G[{0}, yw]*G[{1}, yu^(-1)]*G[{yv^(-1)}, yw]^2 + 
     2*G[{0}, yv^(-1)]*G[{0}, yw]*G[{1}, yu^(-1)]*G[{yv^(-1)}, yw]^2 - 
     G[{0}, yw]^2*G[{1}, yu^(-1)]*G[{yv^(-1)}, yw]^2 + 
     2*G[{0}, yu^(-1)]*G[{1}, yu^(-1)]^2*G[{yv^(-1)}, yw]^2 + 
     2*G[{0}, yv^(-1)]*G[{1}, yu^(-1)]^2*G[{yv^(-1)}, yw]^2 - 
     2*G[{0}, yw]*G[{1}, yu^(-1)]^2*G[{yv^(-1)}, yw]^2 - 
     G[{1}, yu^(-1)]^3*G[{yv^(-1)}, yw]^2 + 2*G[{0}, yu^(-1)]*G[{1}, yu^(-1)]*
      G[{1}, yv^(-1)]*G[{yv^(-1)}, yw]^2 + 2*G[{0}, yv^(-1)]*G[{1}, yu^(-1)]*
      G[{1}, yv^(-1)]*G[{yv^(-1)}, yw]^2 - 2*G[{0}, yw]*G[{1}, yu^(-1)]*
      G[{1}, yv^(-1)]*G[{yv^(-1)}, yw]^2 - 2*G[{1}, yu^(-1)]^2*
      G[{1}, yv^(-1)]*G[{yv^(-1)}, yw]^2 - 
     (G[{1}, yu^(-1)]*G[{1}, yv^(-1)]^2*G[{yv^(-1)}, yw]^2)/2 + 
     (Pi^2*G[{1}, yw]*G[{yv^(-1)}, yw]^2)/3 - G[{0}, yu^(-1)]^2*G[{1}, yw]*
      G[{yv^(-1)}, yw]^2 - 2*G[{0}, yu^(-1)]*G[{0}, yv^(-1)]*G[{1}, yw]*
      G[{yv^(-1)}, yw]^2 - G[{0}, yv^(-1)]^2*G[{1}, yw]*G[{yv^(-1)}, yw]^2 + 
     2*G[{0}, yu^(-1)]*G[{0}, yw]*G[{1}, yw]*G[{yv^(-1)}, yw]^2 + 
     2*G[{0}, yv^(-1)]*G[{0}, yw]*G[{1}, yw]*G[{yv^(-1)}, yw]^2 - 
     G[{0}, yw]^2*G[{1}, yw]*G[{yv^(-1)}, yw]^2 + 
     G[{1}, yu^(-1)]^2*G[{1}, yw]*G[{yv^(-1)}, yw]^2 + 
     2*G[{0}, yu^(-1)]*G[{1}, yv^(-1)]*G[{1}, yw]*G[{yv^(-1)}, yw]^2 + 
     2*G[{0}, yv^(-1)]*G[{1}, yv^(-1)]*G[{1}, yw]*G[{yv^(-1)}, yw]^2 - 
     2*G[{0}, yw]*G[{1}, yv^(-1)]*G[{1}, yw]*G[{yv^(-1)}, yw]^2 + 
     G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*G[{1}, yw]*G[{yv^(-1)}, yw]^2 - 
     G[{1}, yv^(-1)]^2*G[{1}, yw]*G[{yv^(-1)}, yw]^2 - 
     2*G[{0}, yu^(-1)]*G[{1}, yw]^2*G[{yv^(-1)}, yw]^2 - 
     2*G[{0}, yv^(-1)]*G[{1}, yw]^2*G[{yv^(-1)}, yw]^2 + 
     2*G[{0}, yw]*G[{1}, yw]^2*G[{yv^(-1)}, yw]^2 + 
     2*G[{1}, yu^(-1)]*G[{1}, yw]^2*G[{yv^(-1)}, yw]^2 + 
     2*G[{1}, yv^(-1)]*G[{1}, yw]^2*G[{yv^(-1)}, yw]^2 - 
     (Pi^2*G[{yu}, yv^(-1)]*G[{yv^(-1)}, yw]^2)/3 + 
     G[{0}, yu^(-1)]^2*G[{yu}, yv^(-1)]*G[{yv^(-1)}, yw]^2 + 
     2*G[{0}, yu^(-1)]*G[{0}, yv^(-1)]*G[{yu}, yv^(-1)]*G[{yv^(-1)}, yw]^2 + 
     G[{0}, yv^(-1)]^2*G[{yu}, yv^(-1)]*G[{yv^(-1)}, yw]^2 - 
     2*G[{0}, yu^(-1)]*G[{0}, yw]*G[{yu}, yv^(-1)]*G[{yv^(-1)}, yw]^2 - 
     2*G[{0}, yv^(-1)]*G[{0}, yw]*G[{yu}, yv^(-1)]*G[{yv^(-1)}, yw]^2 + 
     G[{0}, yw]^2*G[{yu}, yv^(-1)]*G[{yv^(-1)}, yw]^2 - 
     2*G[{0}, yu^(-1)]*G[{1}, yu^(-1)]*G[{yu}, yv^(-1)]*G[{yv^(-1)}, yw]^2 - 
     2*G[{0}, yv^(-1)]*G[{1}, yu^(-1)]*G[{yu}, yv^(-1)]*G[{yv^(-1)}, yw]^2 + 
     2*G[{0}, yw]*G[{1}, yu^(-1)]*G[{yu}, yv^(-1)]*G[{yv^(-1)}, yw]^2 + 
     G[{1}, yu^(-1)]^2*G[{yu}, yv^(-1)]*G[{yv^(-1)}, yw]^2 - 
     2*G[{0}, yu^(-1)]*G[{1}, yv^(-1)]*G[{yu}, yv^(-1)]*G[{yv^(-1)}, yw]^2 - 
     2*G[{0}, yv^(-1)]*G[{1}, yv^(-1)]*G[{yu}, yv^(-1)]*G[{yv^(-1)}, yw]^2 + 
     2*G[{0}, yw]*G[{1}, yv^(-1)]*G[{yu}, yv^(-1)]*G[{yv^(-1)}, yw]^2 + 
     G[{1}, yv^(-1)]^2*G[{yu}, yv^(-1)]*G[{yv^(-1)}, yw]^2 + 
     2*G[{0}, yu^(-1)]*G[{1}, yw]*G[{yu}, yv^(-1)]*G[{yv^(-1)}, yw]^2 + 
     2*G[{0}, yv^(-1)]*G[{1}, yw]*G[{yu}, yv^(-1)]*G[{yv^(-1)}, yw]^2 - 
     2*G[{0}, yw]*G[{1}, yw]*G[{yu}, yv^(-1)]*G[{yv^(-1)}, yw]^2 - 
     3*G[{1}, yu^(-1)]*G[{1}, yw]*G[{yu}, yv^(-1)]*G[{yv^(-1)}, yw]^2 - 
     2*G[{1}, yv^(-1)]*G[{1}, yw]*G[{yu}, yv^(-1)]*G[{yv^(-1)}, yw]^2 + 
     G[{1}, yu^(-1)]*G[{yu}, yv^(-1)]^2*G[{yv^(-1)}, yw]^2 + 
     (G[{1}, yw]*G[{yu}, yv^(-1)]^2*G[{yv^(-1)}, yw]^2)/2 - 
     (G[{yu}, yv^(-1)]^3*G[{yv^(-1)}, yw]^2)/3 - (Pi^2*G[{yv^(-1)}, yw]^3)/
      9 + (G[{0}, yu^(-1)]^2*G[{yv^(-1)}, yw]^3)/3 + 
     (2*G[{0}, yu^(-1)]*G[{0}, yv^(-1)]*G[{yv^(-1)}, yw]^3)/3 + 
     (G[{0}, yv^(-1)]^2*G[{yv^(-1)}, yw]^3)/3 - 
     (2*G[{0}, yu^(-1)]*G[{0}, yw]*G[{yv^(-1)}, yw]^3)/3 - 
     (2*G[{0}, yv^(-1)]*G[{0}, yw]*G[{yv^(-1)}, yw]^3)/3 + 
     (G[{0}, yw]^2*G[{yv^(-1)}, yw]^3)/3 - 
     (2*G[{0}, yu^(-1)]*G[{1}, yu^(-1)]*G[{yv^(-1)}, yw]^3)/3 - 
     (2*G[{0}, yv^(-1)]*G[{1}, yu^(-1)]*G[{yv^(-1)}, yw]^3)/3 + 
     (2*G[{0}, yw]*G[{1}, yu^(-1)]*G[{yv^(-1)}, yw]^3)/3 + 
     (G[{1}, yu^(-1)]^2*G[{yv^(-1)}, yw]^3)/3 - 
     (2*G[{0}, yu^(-1)]*G[{1}, yv^(-1)]*G[{yv^(-1)}, yw]^3)/3 - 
     (2*G[{0}, yv^(-1)]*G[{1}, yv^(-1)]*G[{yv^(-1)}, yw]^3)/3 + 
     (2*G[{0}, yw]*G[{1}, yv^(-1)]*G[{yv^(-1)}, yw]^3)/3 + 
     (G[{1}, yv^(-1)]^2*G[{yv^(-1)}, yw]^3)/3 + 
     (2*G[{0}, yu^(-1)]*G[{1}, yw]*G[{yv^(-1)}, yw]^3)/3 + 
     (2*G[{0}, yv^(-1)]*G[{1}, yw]*G[{yv^(-1)}, yw]^3)/3 - 
     (2*G[{0}, yw]*G[{1}, yw]*G[{yv^(-1)}, yw]^3)/3 - 
     (2*G[{1}, yu^(-1)]*G[{1}, yw]*G[{yv^(-1)}, yw]^3)/3 - 
     (2*G[{1}, yv^(-1)]*G[{1}, yw]*G[{yv^(-1)}, yw]^3)/3 + 
     (2*G[{1}, yu^(-1)]*G[{yu}, yv^(-1)]*G[{yv^(-1)}, yw]^3)/3 - 
     (G[{yu}, yv^(-1)]^2*G[{yv^(-1)}, yw]^3)/3 + 
     (G[{1}, yu^(-1)]*G[{yv^(-1)}, yw]^4)/6 + (G[{1}, yw]*G[{yv^(-1)}, yw]^4)/
      6 - (G[{yu}, yv^(-1)]*G[{yv^(-1)}, yw]^4)/6 - G[{yv^(-1)}, yw]^5/30 - 
     (17*Pi^4*G[{1/(yu*yv)}, yw])/180 - (Pi^2*G[{0}, yu^(-1)]*G[{1}, yu^(-1)]*
       G[{1/(yu*yv)}, yw])/3 - (Pi^2*G[{0}, yv^(-1)]*G[{1}, yu^(-1)]*
       G[{1/(yu*yv)}, yw])/3 + (Pi^2*G[{0}, yw]*G[{1}, yu^(-1)]*
       G[{1/(yu*yv)}, yw])/3 + (Pi^2*G[{1}, yu^(-1)]^2*G[{1/(yu*yv)}, yw])/
      6 + (Pi^2*G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*G[{1/(yu*yv)}, yw])/3 - 
     2*G[{0}, yu^(-1)]^2*G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*G[{1/(yu*yv)}, yw] - 
     4*G[{0}, yu^(-1)]*G[{0}, yv^(-1)]*G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*
      G[{1/(yu*yv)}, yw] - 2*G[{0}, yv^(-1)]^2*G[{1}, yu^(-1)]*
      G[{1}, yv^(-1)]*G[{1/(yu*yv)}, yw] + 4*G[{0}, yu^(-1)]*G[{0}, yw]*
      G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*G[{1/(yu*yv)}, yw] + 
     4*G[{0}, yv^(-1)]*G[{0}, yw]*G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*
      G[{1/(yu*yv)}, yw] - 2*G[{0}, yw]^2*G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*
      G[{1/(yu*yv)}, yw] + 4*G[{0}, yu^(-1)]*G[{1}, yu^(-1)]^2*
      G[{1}, yv^(-1)]*G[{1/(yu*yv)}, yw] + 4*G[{0}, yv^(-1)]*
      G[{1}, yu^(-1)]^2*G[{1}, yv^(-1)]*G[{1/(yu*yv)}, yw] - 
     4*G[{0}, yw]*G[{1}, yu^(-1)]^2*G[{1}, yv^(-1)]*G[{1/(yu*yv)}, yw] - 
     2*G[{1}, yu^(-1)]^3*G[{1}, yv^(-1)]*G[{1/(yu*yv)}, yw] - 
     (Pi^2*G[{1}, yv^(-1)]^2*G[{1/(yu*yv)}, yw])/6 - 
     G[{0}, yu^(-1)]*G[{1}, yu^(-1)]*G[{1}, yv^(-1)]^2*G[{1/(yu*yv)}, yw] - 
     G[{0}, yv^(-1)]*G[{1}, yu^(-1)]*G[{1}, yv^(-1)]^2*G[{1/(yu*yv)}, yw] + 
     G[{0}, yw]*G[{1}, yu^(-1)]*G[{1}, yv^(-1)]^2*G[{1/(yu*yv)}, yw] + 
     G[{1}, yu^(-1)]^2*G[{1}, yv^(-1)]^2*G[{1/(yu*yv)}, yw] + 
     (2*G[{1}, yu^(-1)]*G[{1}, yv^(-1)]^3*G[{1/(yu*yv)}, yw])/3 + 
     (Pi^2*G[{0}, yu^(-1)]*G[{1}, yw]*G[{1/(yu*yv)}, yw])/3 + 
     (Pi^2*G[{0}, yv^(-1)]*G[{1}, yw]*G[{1/(yu*yv)}, yw])/3 - 
     (Pi^2*G[{0}, yw]*G[{1}, yw]*G[{1/(yu*yv)}, yw])/3 - 
     (Pi^2*G[{1}, yu^(-1)]*G[{1}, yw]*G[{1/(yu*yv)}, yw])/3 - 
     (Pi^2*G[{1}, yv^(-1)]*G[{1}, yw]*G[{1/(yu*yv)}, yw])/3 - 
     2*G[{0}, yu^(-1)]*G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*G[{1}, yw]*
      G[{1/(yu*yv)}, yw] - 2*G[{0}, yv^(-1)]*G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*
      G[{1}, yw]*G[{1/(yu*yv)}, yw] + 2*G[{0}, yw]*G[{1}, yu^(-1)]*
      G[{1}, yv^(-1)]*G[{1}, yw]*G[{1/(yu*yv)}, yw] + 
     2*G[{1}, yu^(-1)]^2*G[{1}, yv^(-1)]*G[{1}, yw]*G[{1/(yu*yv)}, yw] - 
     G[{1}, yu^(-1)]*G[{1}, yv^(-1)]^2*G[{1}, yw]*G[{1/(yu*yv)}, yw] + 
     2*G[{0}, yu^(-1)]^2*G[{1}, yu^(-1)]*G[{yu}, yv^(-1)]*
      G[{1/(yu*yv)}, yw] + 4*G[{0}, yu^(-1)]*G[{0}, yv^(-1)]*G[{1}, yu^(-1)]*
      G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw] + 2*G[{0}, yv^(-1)]^2*
      G[{1}, yu^(-1)]*G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw] - 
     4*G[{0}, yu^(-1)]*G[{0}, yw]*G[{1}, yu^(-1)]*G[{yu}, yv^(-1)]*
      G[{1/(yu*yv)}, yw] - 4*G[{0}, yv^(-1)]*G[{0}, yw]*G[{1}, yu^(-1)]*
      G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw] + 2*G[{0}, yw]^2*G[{1}, yu^(-1)]*
      G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw] - 4*G[{0}, yu^(-1)]*
      G[{1}, yu^(-1)]^2*G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw] - 
     4*G[{0}, yv^(-1)]*G[{1}, yu^(-1)]^2*G[{yu}, yv^(-1)]*
      G[{1/(yu*yv)}, yw] + 4*G[{0}, yw]*G[{1}, yu^(-1)]^2*G[{yu}, yv^(-1)]*
      G[{1/(yu*yv)}, yw] + 2*G[{1}, yu^(-1)]^3*G[{yu}, yv^(-1)]*
      G[{1/(yu*yv)}, yw] + 8*G[{0}, yu^(-1)]*G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*
      G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw] + 8*G[{0}, yv^(-1)]*G[{1}, yu^(-1)]*
      G[{1}, yv^(-1)]*G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw] - 
     8*G[{0}, yw]*G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*G[{yu}, yv^(-1)]*
      G[{1/(yu*yv)}, yw] - 8*G[{1}, yu^(-1)]^2*G[{1}, yv^(-1)]*
      G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw] + G[{1}, yu^(-1)]*G[{1}, yv^(-1)]^2*
      G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw] + 2*G[{0}, yu^(-1)]*G[{1}, yu^(-1)]*
      G[{1}, yw]*G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw] + 
     2*G[{0}, yv^(-1)]*G[{1}, yu^(-1)]*G[{1}, yw]*G[{yu}, yv^(-1)]*
      G[{1/(yu*yv)}, yw] - 2*G[{0}, yw]*G[{1}, yu^(-1)]*G[{1}, yw]*
      G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw] - 2*G[{1}, yu^(-1)]^2*G[{1}, yw]*
      G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw] - 2*G[{0}, yu^(-1)]*G[{1}, yv^(-1)]*
      G[{1}, yw]*G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw] - 
     2*G[{0}, yv^(-1)]*G[{1}, yv^(-1)]*G[{1}, yw]*G[{yu}, yv^(-1)]*
      G[{1/(yu*yv)}, yw] + 2*G[{0}, yw]*G[{1}, yv^(-1)]*G[{1}, yw]*
      G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw] + 6*G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*
      G[{1}, yw]*G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw] + 
     2*G[{1}, yv^(-1)]^2*G[{1}, yw]*G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw] - 
     G[{0}, yu^(-1)]^2*G[{yu}, yv^(-1)]^2*G[{1/(yu*yv)}, yw] - 
     2*G[{0}, yu^(-1)]*G[{0}, yv^(-1)]*G[{yu}, yv^(-1)]^2*
      G[{1/(yu*yv)}, yw] - G[{0}, yv^(-1)]^2*G[{yu}, yv^(-1)]^2*
      G[{1/(yu*yv)}, yw] + 2*G[{0}, yu^(-1)]*G[{0}, yw]*G[{yu}, yv^(-1)]^2*
      G[{1/(yu*yv)}, yw] + 2*G[{0}, yv^(-1)]*G[{0}, yw]*G[{yu}, yv^(-1)]^2*
      G[{1/(yu*yv)}, yw] - G[{0}, yw]^2*G[{yu}, yv^(-1)]^2*
      G[{1/(yu*yv)}, yw] - 4*G[{0}, yu^(-1)]*G[{1}, yu^(-1)]*
      G[{yu}, yv^(-1)]^2*G[{1/(yu*yv)}, yw] - 4*G[{0}, yv^(-1)]*
      G[{1}, yu^(-1)]*G[{yu}, yv^(-1)]^2*G[{1/(yu*yv)}, yw] + 
     4*G[{0}, yw]*G[{1}, yu^(-1)]*G[{yu}, yv^(-1)]^2*G[{1/(yu*yv)}, yw] + 
     5*G[{1}, yu^(-1)]^2*G[{yu}, yv^(-1)]^2*G[{1/(yu*yv)}, yw] - 
     8*G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*G[{yu}, yv^(-1)]^2*
      G[{1/(yu*yv)}, yw] + G[{1}, yv^(-1)]^2*G[{yu}, yv^(-1)]^2*
      G[{1/(yu*yv)}, yw] - 3*G[{1}, yu^(-1)]*G[{1}, yw]*G[{yu}, yv^(-1)]^2*
      G[{1/(yu*yv)}, yw] + (8*G[{0}, yu^(-1)]*G[{yu}, yv^(-1)]^3*
       G[{1/(yu*yv)}, yw])/3 + (8*G[{0}, yv^(-1)]*G[{yu}, yv^(-1)]^3*
       G[{1/(yu*yv)}, yw])/3 - (8*G[{0}, yw]*G[{yu}, yv^(-1)]^3*
       G[{1/(yu*yv)}, yw])/3 + 2*G[{1}, yu^(-1)]*G[{yu}, yv^(-1)]^3*
      G[{1/(yu*yv)}, yw] + G[{1}, yw]*G[{yu}, yv^(-1)]^3*G[{1/(yu*yv)}, yw] - 
     (11*G[{yu}, yv^(-1)]^4*G[{1/(yu*yv)}, yw])/6 + 
     (Pi^2*G[{0}, yu^(-1)]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw])/3 + 
     (Pi^2*G[{0}, yv^(-1)]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw])/3 - 
     (Pi^2*G[{0}, yw]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw])/3 - 
     (2*Pi^2*G[{1}, yu^(-1)]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw])/3 + 
     2*G[{0}, yu^(-1)]^2*G[{1}, yu^(-1)]*G[{yv^(-1)}, yw]*
      G[{1/(yu*yv)}, yw] + 4*G[{0}, yu^(-1)]*G[{0}, yv^(-1)]*G[{1}, yu^(-1)]*
      G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw] + 2*G[{0}, yv^(-1)]^2*
      G[{1}, yu^(-1)]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw] - 
     4*G[{0}, yu^(-1)]*G[{0}, yw]*G[{1}, yu^(-1)]*G[{yv^(-1)}, yw]*
      G[{1/(yu*yv)}, yw] - 4*G[{0}, yv^(-1)]*G[{0}, yw]*G[{1}, yu^(-1)]*
      G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw] + 2*G[{0}, yw]^2*G[{1}, yu^(-1)]*
      G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw] - 4*G[{0}, yu^(-1)]*
      G[{1}, yu^(-1)]^2*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw] - 
     4*G[{0}, yv^(-1)]*G[{1}, yu^(-1)]^2*G[{yv^(-1)}, yw]*
      G[{1/(yu*yv)}, yw] + 4*G[{0}, yw]*G[{1}, yu^(-1)]^2*G[{yv^(-1)}, yw]*
      G[{1/(yu*yv)}, yw] + 2*G[{1}, yu^(-1)]^3*G[{yv^(-1)}, yw]*
      G[{1/(yu*yv)}, yw] - G[{1}, yu^(-1)]*G[{1}, yv^(-1)]^2*G[{yv^(-1)}, yw]*
      G[{1/(yu*yv)}, yw] + 2*G[{0}, yu^(-1)]^2*G[{1}, yw]*G[{yv^(-1)}, yw]*
      G[{1/(yu*yv)}, yw] + 4*G[{0}, yu^(-1)]*G[{0}, yv^(-1)]*G[{1}, yw]*
      G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw] + 2*G[{0}, yv^(-1)]^2*G[{1}, yw]*
      G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw] - 4*G[{0}, yu^(-1)]*G[{0}, yw]*
      G[{1}, yw]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw] - 
     4*G[{0}, yv^(-1)]*G[{0}, yw]*G[{1}, yw]*G[{yv^(-1)}, yw]*
      G[{1/(yu*yv)}, yw] + 2*G[{0}, yw]^2*G[{1}, yw]*G[{yv^(-1)}, yw]*
      G[{1/(yu*yv)}, yw] - 2*G[{1}, yu^(-1)]^2*G[{1}, yw]*G[{yv^(-1)}, yw]*
      G[{1/(yu*yv)}, yw] - 4*G[{0}, yu^(-1)]*G[{1}, yv^(-1)]*G[{1}, yw]*
      G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw] - 4*G[{0}, yv^(-1)]*G[{1}, yv^(-1)]*
      G[{1}, yw]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw] + 
     4*G[{0}, yw]*G[{1}, yv^(-1)]*G[{1}, yw]*G[{yv^(-1)}, yw]*
      G[{1/(yu*yv)}, yw] + 2*G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*G[{1}, yw]*
      G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw] + 2*G[{1}, yv^(-1)]^2*G[{1}, yw]*
      G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw] + 2*G[{0}, yu^(-1)]*G[{1}, yw]^2*
      G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw] + 2*G[{0}, yv^(-1)]*G[{1}, yw]^2*
      G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw] - 2*G[{0}, yw]*G[{1}, yw]^2*
      G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw] - 2*G[{1}, yu^(-1)]*G[{1}, yw]^2*
      G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw] - 2*G[{1}, yv^(-1)]*G[{1}, yw]^2*
      G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw] - 2*G[{0}, yu^(-1)]^2*
      G[{yu}, yv^(-1)]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw] - 
     4*G[{0}, yu^(-1)]*G[{0}, yv^(-1)]*G[{yu}, yv^(-1)]*G[{yv^(-1)}, yw]*
      G[{1/(yu*yv)}, yw] - 2*G[{0}, yv^(-1)]^2*G[{yu}, yv^(-1)]*
      G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw] + 4*G[{0}, yu^(-1)]*G[{0}, yw]*
      G[{yu}, yv^(-1)]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw] + 
     4*G[{0}, yv^(-1)]*G[{0}, yw]*G[{yu}, yv^(-1)]*G[{yv^(-1)}, yw]*
      G[{1/(yu*yv)}, yw] - 2*G[{0}, yw]^2*G[{yu}, yv^(-1)]*G[{yv^(-1)}, yw]*
      G[{1/(yu*yv)}, yw] + 2*G[{1}, yu^(-1)]^2*G[{yu}, yv^(-1)]*
      G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw] + 2*G[{1}, yv^(-1)]^2*
      G[{yu}, yv^(-1)]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw] - 
     4*G[{0}, yu^(-1)]*G[{1}, yw]*G[{yu}, yv^(-1)]*G[{yv^(-1)}, yw]*
      G[{1/(yu*yv)}, yw] - 4*G[{0}, yv^(-1)]*G[{1}, yw]*G[{yu}, yv^(-1)]*
      G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw] + 4*G[{0}, yw]*G[{1}, yw]*
      G[{yu}, yv^(-1)]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw] + 
     2*G[{1}, yu^(-1)]*G[{1}, yw]*G[{yu}, yv^(-1)]*G[{yv^(-1)}, yw]*
      G[{1/(yu*yv)}, yw] + 4*G[{0}, yu^(-1)]*G[{yu}, yv^(-1)]^2*
      G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw] + 4*G[{0}, yv^(-1)]*
      G[{yu}, yv^(-1)]^2*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw] - 
     4*G[{0}, yw]*G[{yu}, yv^(-1)]^2*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw] - 
     2*G[{1}, yu^(-1)]*G[{yu}, yv^(-1)]^2*G[{yv^(-1)}, yw]*
      G[{1/(yu*yv)}, yw] + 3*G[{1}, yw]*G[{yu}, yv^(-1)]^2*G[{yv^(-1)}, yw]*
      G[{1/(yu*yv)}, yw] - 2*G[{yu}, yv^(-1)]^3*G[{yv^(-1)}, yw]*
      G[{1/(yu*yv)}, yw] + (Pi^2*G[{yv^(-1)}, yw]^2*G[{1/(yu*yv)}, yw])/3 - 
     G[{0}, yu^(-1)]^2*G[{yv^(-1)}, yw]^2*G[{1/(yu*yv)}, yw] - 
     2*G[{0}, yu^(-1)]*G[{0}, yv^(-1)]*G[{yv^(-1)}, yw]^2*
      G[{1/(yu*yv)}, yw] - G[{0}, yv^(-1)]^2*G[{yv^(-1)}, yw]^2*
      G[{1/(yu*yv)}, yw] + 2*G[{0}, yu^(-1)]*G[{0}, yw]*G[{yv^(-1)}, yw]^2*
      G[{1/(yu*yv)}, yw] + 2*G[{0}, yv^(-1)]*G[{0}, yw]*G[{yv^(-1)}, yw]^2*
      G[{1/(yu*yv)}, yw] - G[{0}, yw]^2*G[{yv^(-1)}, yw]^2*
      G[{1/(yu*yv)}, yw] + 2*G[{0}, yu^(-1)]*G[{1}, yu^(-1)]*
      G[{yv^(-1)}, yw]^2*G[{1/(yu*yv)}, yw] + 2*G[{0}, yv^(-1)]*
      G[{1}, yu^(-1)]*G[{yv^(-1)}, yw]^2*G[{1/(yu*yv)}, yw] - 
     2*G[{0}, yw]*G[{1}, yu^(-1)]*G[{yv^(-1)}, yw]^2*G[{1/(yu*yv)}, yw] - 
     G[{1}, yu^(-1)]^2*G[{yv^(-1)}, yw]^2*G[{1/(yu*yv)}, yw] + 
     2*G[{0}, yu^(-1)]*G[{1}, yv^(-1)]*G[{yv^(-1)}, yw]^2*
      G[{1/(yu*yv)}, yw] + 2*G[{0}, yv^(-1)]*G[{1}, yv^(-1)]*
      G[{yv^(-1)}, yw]^2*G[{1/(yu*yv)}, yw] - 2*G[{0}, yw]*G[{1}, yv^(-1)]*
      G[{yv^(-1)}, yw]^2*G[{1/(yu*yv)}, yw] - G[{1}, yv^(-1)]^2*
      G[{yv^(-1)}, yw]^2*G[{1/(yu*yv)}, yw] - 2*G[{0}, yu^(-1)]*G[{1}, yw]*
      G[{yv^(-1)}, yw]^2*G[{1/(yu*yv)}, yw] - 2*G[{0}, yv^(-1)]*G[{1}, yw]*
      G[{yv^(-1)}, yw]^2*G[{1/(yu*yv)}, yw] + 2*G[{0}, yw]*G[{1}, yw]*
      G[{yv^(-1)}, yw]^2*G[{1/(yu*yv)}, yw] + 2*G[{1}, yu^(-1)]*G[{1}, yw]*
      G[{yv^(-1)}, yw]^2*G[{1/(yu*yv)}, yw] + 2*G[{1}, yv^(-1)]*G[{1}, yw]*
      G[{yv^(-1)}, yw]^2*G[{1/(yu*yv)}, yw] - 2*G[{1}, yu^(-1)]*
      G[{yu}, yv^(-1)]*G[{yv^(-1)}, yw]^2*G[{1/(yu*yv)}, yw] + 
     G[{yu}, yv^(-1)]^2*G[{yv^(-1)}, yw]^2*G[{1/(yu*yv)}, yw] - 
     (2*G[{1}, yu^(-1)]*G[{yv^(-1)}, yw]^3*G[{1/(yu*yv)}, yw])/3 - 
     (2*G[{1}, yw]*G[{yv^(-1)}, yw]^3*G[{1/(yu*yv)}, yw])/3 + 
     (2*G[{yu}, yv^(-1)]*G[{yv^(-1)}, yw]^3*G[{1/(yu*yv)}, yw])/3 + 
     (G[{yv^(-1)}, yw]^4*G[{1/(yu*yv)}, yw])/6 - 
     (Pi^2*G[{0}, yu^(-1)]*G[{1/(yu*yv)}, yw]^2)/6 - 
     (Pi^2*G[{0}, yv^(-1)]*G[{1/(yu*yv)}, yw]^2)/6 + 
     (Pi^2*G[{0}, yw]*G[{1/(yu*yv)}, yw]^2)/6 + 
     (Pi^2*G[{1}, yu^(-1)]*G[{1/(yu*yv)}, yw]^2)/6 - 
     G[{0}, yu^(-1)]^2*G[{1}, yu^(-1)]*G[{1/(yu*yv)}, yw]^2 - 
     2*G[{0}, yu^(-1)]*G[{0}, yv^(-1)]*G[{1}, yu^(-1)]*G[{1/(yu*yv)}, yw]^2 - 
     G[{0}, yv^(-1)]^2*G[{1}, yu^(-1)]*G[{1/(yu*yv)}, yw]^2 + 
     2*G[{0}, yu^(-1)]*G[{0}, yw]*G[{1}, yu^(-1)]*G[{1/(yu*yv)}, yw]^2 + 
     2*G[{0}, yv^(-1)]*G[{0}, yw]*G[{1}, yu^(-1)]*G[{1/(yu*yv)}, yw]^2 - 
     G[{0}, yw]^2*G[{1}, yu^(-1)]*G[{1/(yu*yv)}, yw]^2 + 
     2*G[{0}, yu^(-1)]*G[{1}, yu^(-1)]^2*G[{1/(yu*yv)}, yw]^2 + 
     2*G[{0}, yv^(-1)]*G[{1}, yu^(-1)]^2*G[{1/(yu*yv)}, yw]^2 - 
     2*G[{0}, yw]*G[{1}, yu^(-1)]^2*G[{1/(yu*yv)}, yw]^2 - 
     G[{1}, yu^(-1)]^3*G[{1/(yu*yv)}, yw]^2 + 
     (Pi^2*G[{1}, yv^(-1)]*G[{1/(yu*yv)}, yw]^2)/6 - 
     3*G[{0}, yu^(-1)]*G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*G[{1/(yu*yv)}, yw]^2 - 
     3*G[{0}, yv^(-1)]*G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*G[{1/(yu*yv)}, yw]^2 + 
     3*G[{0}, yw]*G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*G[{1/(yu*yv)}, yw]^2 + 
     3*G[{1}, yu^(-1)]^2*G[{1}, yv^(-1)]*G[{1/(yu*yv)}, yw]^2 - 
     G[{0}, yu^(-1)]^2*G[{1}, yw]*G[{1/(yu*yv)}, yw]^2 - 
     2*G[{0}, yu^(-1)]*G[{0}, yv^(-1)]*G[{1}, yw]*G[{1/(yu*yv)}, yw]^2 - 
     G[{0}, yv^(-1)]^2*G[{1}, yw]*G[{1/(yu*yv)}, yw]^2 + 
     2*G[{0}, yu^(-1)]*G[{0}, yw]*G[{1}, yw]*G[{1/(yu*yv)}, yw]^2 + 
     2*G[{0}, yv^(-1)]*G[{0}, yw]*G[{1}, yw]*G[{1/(yu*yv)}, yw]^2 - 
     G[{0}, yw]^2*G[{1}, yw]*G[{1/(yu*yv)}, yw]^2 + 
     G[{1}, yu^(-1)]^2*G[{1}, yw]*G[{1/(yu*yv)}, yw]^2 - 
     3*G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*G[{1}, yw]*G[{1/(yu*yv)}, yw]^2 + 
     G[{1}, yv^(-1)]^2*G[{1}, yw]*G[{1/(yu*yv)}, yw]^2 - 
     2*G[{0}, yu^(-1)]*G[{1}, yw]^2*G[{1/(yu*yv)}, yw]^2 - 
     2*G[{0}, yv^(-1)]*G[{1}, yw]^2*G[{1/(yu*yv)}, yw]^2 + 
     2*G[{0}, yw]*G[{1}, yw]^2*G[{1/(yu*yv)}, yw]^2 + 
     2*G[{1}, yu^(-1)]*G[{1}, yw]^2*G[{1/(yu*yv)}, yw]^2 + 
     2*G[{1}, yv^(-1)]*G[{1}, yw]^2*G[{1/(yu*yv)}, yw]^2 - 
     (Pi^2*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2)/6 + 
     G[{0}, yu^(-1)]*G[{1}, yv^(-1)]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2 + 
     G[{0}, yv^(-1)]*G[{1}, yv^(-1)]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2 - 
     G[{0}, yw]*G[{1}, yv^(-1)]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2 - 
     G[{1}, yv^(-1)]^2*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2 + 
     2*G[{0}, yu^(-1)]*G[{1}, yw]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2 + 
     2*G[{0}, yv^(-1)]*G[{1}, yw]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2 - 
     2*G[{0}, yw]*G[{1}, yw]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2 - 
     2*G[{1}, yu^(-1)]*G[{1}, yw]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2 - 
     2*G[{1}, yv^(-1)]*G[{1}, yw]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2 - 
     G[{0}, yu^(-1)]*G[{yu^(-1)}, yw]^2*G[{1/(yu*yv)}, yw]^2 - 
     G[{0}, yv^(-1)]*G[{yu^(-1)}, yw]^2*G[{1/(yu*yv)}, yw]^2 + 
     G[{0}, yw]*G[{yu^(-1)}, yw]^2*G[{1/(yu*yv)}, yw]^2 + 
     G[{1}, yu^(-1)]*G[{yu^(-1)}, yw]^2*G[{1/(yu*yv)}, yw]^2 + 
     2*G[{1}, yv^(-1)]*G[{yu^(-1)}, yw]^2*G[{1/(yu*yv)}, yw]^2 + 
     G[{1}, yw]*G[{yu^(-1)}, yw]^2*G[{1/(yu*yv)}, yw]^2 - 
     (2*G[{yu^(-1)}, yw]^3*G[{1/(yu*yv)}, yw]^2)/3 + 
     G[{0}, yu^(-1)]^2*G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw]^2 + 
     2*G[{0}, yu^(-1)]*G[{0}, yv^(-1)]*G[{yu}, yv^(-1)]*
      G[{1/(yu*yv)}, yw]^2 + G[{0}, yv^(-1)]^2*G[{yu}, yv^(-1)]*
      G[{1/(yu*yv)}, yw]^2 - 2*G[{0}, yu^(-1)]*G[{0}, yw]*G[{yu}, yv^(-1)]*
      G[{1/(yu*yv)}, yw]^2 - 2*G[{0}, yv^(-1)]*G[{0}, yw]*G[{yu}, yv^(-1)]*
      G[{1/(yu*yv)}, yw]^2 + G[{0}, yw]^2*G[{yu}, yv^(-1)]*
      G[{1/(yu*yv)}, yw]^2 + 3*G[{0}, yu^(-1)]*G[{1}, yu^(-1)]*
      G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw]^2 + 3*G[{0}, yv^(-1)]*
      G[{1}, yu^(-1)]*G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw]^2 - 
     3*G[{0}, yw]*G[{1}, yu^(-1)]*G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw]^2 - 
     4*G[{1}, yu^(-1)]^2*G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw]^2 + 
     G[{0}, yu^(-1)]*G[{1}, yv^(-1)]*G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw]^2 + 
     G[{0}, yv^(-1)]*G[{1}, yv^(-1)]*G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw]^2 - 
     G[{0}, yw]*G[{1}, yv^(-1)]*G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw]^2 + 
     5*G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*G[{yu}, yv^(-1)]*
      G[{1/(yu*yv)}, yw]^2 - 2*G[{1}, yv^(-1)]^2*G[{yu}, yv^(-1)]*
      G[{1/(yu*yv)}, yw]^2 + 4*G[{0}, yu^(-1)]*G[{1}, yw]*G[{yu}, yv^(-1)]*
      G[{1/(yu*yv)}, yw]^2 + 4*G[{0}, yv^(-1)]*G[{1}, yw]*G[{yu}, yv^(-1)]*
      G[{1/(yu*yv)}, yw]^2 - 4*G[{0}, yw]*G[{1}, yw]*G[{yu}, yv^(-1)]*
      G[{1/(yu*yv)}, yw]^2 + G[{1}, yu^(-1)]*G[{1}, yw]*G[{yu}, yv^(-1)]*
      G[{1/(yu*yv)}, yw]^2 - 2*G[{1}, yv^(-1)]*G[{1}, yw]*G[{yu}, yv^(-1)]*
      G[{1/(yu*yv)}, yw]^2 - G[{0}, yu^(-1)]*G[{yu^(-1)}, yw]*
      G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw]^2 - G[{0}, yv^(-1)]*
      G[{yu^(-1)}, yw]*G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw]^2 + 
     G[{0}, yw]*G[{yu^(-1)}, yw]*G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw]^2 + 
     2*G[{1}, yv^(-1)]*G[{yu^(-1)}, yw]*G[{yu}, yv^(-1)]*
      G[{1/(yu*yv)}, yw]^2 - G[{yu^(-1)}, yw]^2*G[{yu}, yv^(-1)]*
      G[{1/(yu*yv)}, yw]^2 - 4*G[{0}, yu^(-1)]*G[{yu}, yv^(-1)]^2*
      G[{1/(yu*yv)}, yw]^2 - 4*G[{0}, yv^(-1)]*G[{yu}, yv^(-1)]^2*
      G[{1/(yu*yv)}, yw]^2 + 4*G[{0}, yw]*G[{yu}, yv^(-1)]^2*
      G[{1/(yu*yv)}, yw]^2 - (3*G[{1}, yu^(-1)]*G[{yu}, yv^(-1)]^2*
       G[{1/(yu*yv)}, yw]^2)/2 - (7*G[{1}, yw]*G[{yu}, yv^(-1)]^2*
       G[{1/(yu*yv)}, yw]^2)/2 + (19*G[{yu}, yv^(-1)]^3*G[{1/(yu*yv)}, yw]^2)/
      6 - (Pi^2*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2)/6 + 
     G[{0}, yu^(-1)]^2*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2 + 
     2*G[{0}, yu^(-1)]*G[{0}, yv^(-1)]*G[{yv^(-1)}, yw]*
      G[{1/(yu*yv)}, yw]^2 + G[{0}, yv^(-1)]^2*G[{yv^(-1)}, yw]*
      G[{1/(yu*yv)}, yw]^2 - 2*G[{0}, yu^(-1)]*G[{0}, yw]*G[{yv^(-1)}, yw]*
      G[{1/(yu*yv)}, yw]^2 - 2*G[{0}, yv^(-1)]*G[{0}, yw]*G[{yv^(-1)}, yw]*
      G[{1/(yu*yv)}, yw]^2 + G[{0}, yw]^2*G[{yv^(-1)}, yw]*
      G[{1/(yu*yv)}, yw]^2 - G[{0}, yu^(-1)]*G[{1}, yu^(-1)]*G[{yv^(-1)}, yw]*
      G[{1/(yu*yv)}, yw]^2 - G[{0}, yv^(-1)]*G[{1}, yu^(-1)]*G[{yv^(-1)}, yw]*
      G[{1/(yu*yv)}, yw]^2 + G[{0}, yw]*G[{1}, yu^(-1)]*G[{yv^(-1)}, yw]*
      G[{1/(yu*yv)}, yw]^2 - G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*G[{yv^(-1)}, yw]*
      G[{1/(yu*yv)}, yw]^2 - G[{1}, yv^(-1)]^2*G[{yv^(-1)}, yw]*
      G[{1/(yu*yv)}, yw]^2 + 4*G[{0}, yu^(-1)]*G[{1}, yw]*G[{yv^(-1)}, yw]*
      G[{1/(yu*yv)}, yw]^2 + 4*G[{0}, yv^(-1)]*G[{1}, yw]*G[{yv^(-1)}, yw]*
      G[{1/(yu*yv)}, yw]^2 - 4*G[{0}, yw]*G[{1}, yw]*G[{yv^(-1)}, yw]*
      G[{1/(yu*yv)}, yw]^2 - 2*G[{1}, yu^(-1)]*G[{1}, yw]*G[{yv^(-1)}, yw]*
      G[{1/(yu*yv)}, yw]^2 - 2*G[{1}, yv^(-1)]*G[{1}, yw]*G[{yv^(-1)}, yw]*
      G[{1/(yu*yv)}, yw]^2 + 2*G[{1}, yw]^2*G[{yv^(-1)}, yw]*
      G[{1/(yu*yv)}, yw]^2 - G[{0}, yu^(-1)]*G[{yu^(-1)}, yw]*
      G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2 - G[{0}, yv^(-1)]*
      G[{yu^(-1)}, yw]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2 + 
     G[{0}, yw]*G[{yu^(-1)}, yw]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2 + 
     2*G[{1}, yv^(-1)]*G[{yu^(-1)}, yw]*G[{yv^(-1)}, yw]*
      G[{1/(yu*yv)}, yw]^2 - G[{yu^(-1)}, yw]^2*G[{yv^(-1)}, yw]*
      G[{1/(yu*yv)}, yw]^2 - 3*G[{0}, yu^(-1)]*G[{yu}, yv^(-1)]*
      G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2 - 3*G[{0}, yv^(-1)]*
      G[{yu}, yv^(-1)]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2 + 
     3*G[{0}, yw]*G[{yu}, yv^(-1)]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2 + 
     3*G[{1}, yu^(-1)]*G[{yu}, yv^(-1)]*G[{yv^(-1)}, yw]*
      G[{1/(yu*yv)}, yw]^2 - 4*G[{1}, yw]*G[{yu}, yv^(-1)]*G[{yv^(-1)}, yw]*
      G[{1/(yu*yv)}, yw]^2 + (3*G[{yu}, yv^(-1)]^2*G[{yv^(-1)}, yw]*
       G[{1/(yu*yv)}, yw]^2)/2 + (3*G[{1}, yu^(-1)]*G[{yv^(-1)}, yw]^2*
       G[{1/(yu*yv)}, yw]^2)/2 + (3*G[{1}, yw]*G[{yv^(-1)}, yw]^2*
       G[{1/(yu*yv)}, yw]^2)/2 - (3*G[{yu}, yv^(-1)]*G[{yv^(-1)}, yw]^2*
       G[{1/(yu*yv)}, yw]^2)/2 - (G[{yv^(-1)}, yw]^3*G[{1/(yu*yv)}, yw]^2)/
      2 - G[{0}, yu^(-1)]*G[{1}, yu^(-1)]*G[{1/(yu*yv)}, yw]^3 - 
     G[{0}, yv^(-1)]*G[{1}, yu^(-1)]*G[{1/(yu*yv)}, yw]^3 + 
     G[{0}, yw]*G[{1}, yu^(-1)]*G[{1/(yu*yv)}, yw]^3 + 
     G[{1}, yu^(-1)]^2*G[{1/(yu*yv)}, yw]^3 - 
     (G[{0}, yu^(-1)]*G[{1}, yv^(-1)]*G[{1/(yu*yv)}, yw]^3)/3 - 
     (G[{0}, yv^(-1)]*G[{1}, yv^(-1)]*G[{1/(yu*yv)}, yw]^3)/3 + 
     (G[{0}, yw]*G[{1}, yv^(-1)]*G[{1/(yu*yv)}, yw]^3)/3 - 
     (2*G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*G[{1/(yu*yv)}, yw]^3)/3 + 
     (G[{1}, yv^(-1)]^2*G[{1/(yu*yv)}, yw]^3)/3 - 
     (4*G[{0}, yu^(-1)]*G[{1}, yw]*G[{1/(yu*yv)}, yw]^3)/3 - 
     (4*G[{0}, yv^(-1)]*G[{1}, yw]*G[{1/(yu*yv)}, yw]^3)/3 + 
     (4*G[{0}, yw]*G[{1}, yw]*G[{1/(yu*yv)}, yw]^3)/3 - 
     (2*G[{1}, yu^(-1)]*G[{1}, yw]*G[{1/(yu*yv)}, yw]^3)/3 - 
     (2*G[{1}, yv^(-1)]*G[{1}, yw]*G[{1/(yu*yv)}, yw]^3)/3 - 
     2*G[{1}, yw]^2*G[{1/(yu*yv)}, yw]^3 + 
     (G[{0}, yu^(-1)]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]^3)/3 + 
     (G[{0}, yv^(-1)]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]^3)/3 - 
     (G[{0}, yw]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]^3)/3 + 
     (2*G[{1}, yu^(-1)]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]^3)/3 - 
     (2*G[{1}, yv^(-1)]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]^3)/3 + 
     (2*G[{1}, yw]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]^3)/3 + 
     (G[{yu^(-1)}, yw]^2*G[{1/(yu*yv)}, yw]^3)/3 + 
     (4*G[{0}, yu^(-1)]*G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw]^3)/3 + 
     (4*G[{0}, yv^(-1)]*G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw]^3)/3 - 
     (4*G[{0}, yw]*G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw]^3)/3 + 
     (2*G[{1}, yu^(-1)]*G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw]^3)/3 + 
     (2*G[{1}, yv^(-1)]*G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw]^3)/3 + 
     4*G[{1}, yw]*G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw]^3 - 
     (2*G[{yu^(-1)}, yw]*G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw]^3)/3 - 
     2*G[{yu}, yv^(-1)]^2*G[{1/(yu*yv)}, yw]^3 + 
     G[{0}, yu^(-1)]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]^3 + 
     G[{0}, yv^(-1)]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]^3 - 
     G[{0}, yw]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]^3 - 
     2*G[{1}, yu^(-1)]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]^3 + 
     (2*G[{1}, yv^(-1)]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]^3)/3 + 
     (2*G[{1}, yw]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]^3)/3 - 
     (2*G[{yu^(-1)}, yw]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]^3)/3 - 
     (2*G[{yu}, yv^(-1)]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]^3)/3 + 
     G[{yv^(-1)}, yw]^2*G[{1/(yu*yv)}, yw]^3 - 
     (Pi^2*G[{0}, yu^(-1)]*G[{0, 1}, yu^(-1)])/3 - 
     (Pi^2*G[{0}, yv^(-1)]*G[{0, 1}, yu^(-1)])/3 + 
     (Pi^2*G[{0}, yw]*G[{0, 1}, yu^(-1)])/3 + 
     (2*Pi^2*G[{1}, yv^(-1)]*G[{0, 1}, yu^(-1)])/3 - 
     2*G[{0}, yu^(-1)]^2*G[{1}, yv^(-1)]*G[{0, 1}, yu^(-1)] - 
     4*G[{0}, yu^(-1)]*G[{0}, yv^(-1)]*G[{1}, yv^(-1)]*G[{0, 1}, yu^(-1)] - 
     2*G[{0}, yv^(-1)]^2*G[{1}, yv^(-1)]*G[{0, 1}, yu^(-1)] + 
     4*G[{0}, yu^(-1)]*G[{0}, yw]*G[{1}, yv^(-1)]*G[{0, 1}, yu^(-1)] + 
     4*G[{0}, yv^(-1)]*G[{0}, yw]*G[{1}, yv^(-1)]*G[{0, 1}, yu^(-1)] - 
     2*G[{0}, yw]^2*G[{1}, yv^(-1)]*G[{0, 1}, yu^(-1)] + 
     2*G[{0}, yu^(-1)]*G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*G[{0, 1}, yu^(-1)] + 
     2*G[{0}, yv^(-1)]*G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*G[{0, 1}, yu^(-1)] - 
     2*G[{0}, yw]*G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*G[{0, 1}, yu^(-1)] - 
     G[{1}, yu^(-1)]^2*G[{1}, yv^(-1)]*G[{0, 1}, yu^(-1)] + 
     G[{0}, yu^(-1)]*G[{1}, yv^(-1)]^2*G[{0, 1}, yu^(-1)] + 
     G[{0}, yv^(-1)]*G[{1}, yv^(-1)]^2*G[{0, 1}, yu^(-1)] - 
     G[{0}, yw]*G[{1}, yv^(-1)]^2*G[{0, 1}, yu^(-1)] - 
     (G[{1}, yv^(-1)]^3*G[{0, 1}, yu^(-1)])/3 - 
     (Pi^2*G[{yu}, yv^(-1)]*G[{0, 1}, yu^(-1)])/3 + 
     2*G[{0}, yu^(-1)]^2*G[{yu}, yv^(-1)]*G[{0, 1}, yu^(-1)] + 
     4*G[{0}, yu^(-1)]*G[{0}, yv^(-1)]*G[{yu}, yv^(-1)]*G[{0, 1}, yu^(-1)] + 
     2*G[{0}, yv^(-1)]^2*G[{yu}, yv^(-1)]*G[{0, 1}, yu^(-1)] - 
     4*G[{0}, yu^(-1)]*G[{0}, yw]*G[{yu}, yv^(-1)]*G[{0, 1}, yu^(-1)] - 
     4*G[{0}, yv^(-1)]*G[{0}, yw]*G[{yu}, yv^(-1)]*G[{0, 1}, yu^(-1)] + 
     2*G[{0}, yw]^2*G[{yu}, yv^(-1)]*G[{0, 1}, yu^(-1)] - 
     2*G[{0}, yu^(-1)]*G[{1}, yu^(-1)]*G[{yu}, yv^(-1)]*G[{0, 1}, yu^(-1)] - 
     2*G[{0}, yv^(-1)]*G[{1}, yu^(-1)]*G[{yu}, yv^(-1)]*G[{0, 1}, yu^(-1)] + 
     2*G[{0}, yw]*G[{1}, yu^(-1)]*G[{yu}, yv^(-1)]*G[{0, 1}, yu^(-1)] + 
     G[{1}, yu^(-1)]^2*G[{yu}, yv^(-1)]*G[{0, 1}, yu^(-1)] + 
     4*G[{0}, yu^(-1)]*G[{1}, yv^(-1)]*G[{yu}, yv^(-1)]*G[{0, 1}, yu^(-1)] + 
     4*G[{0}, yv^(-1)]*G[{1}, yv^(-1)]*G[{yu}, yv^(-1)]*G[{0, 1}, yu^(-1)] - 
     4*G[{0}, yw]*G[{1}, yv^(-1)]*G[{yu}, yv^(-1)]*G[{0, 1}, yu^(-1)] - 
     4*G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*G[{yu}, yv^(-1)]*G[{0, 1}, yu^(-1)] - 
     G[{1}, yv^(-1)]^2*G[{yu}, yv^(-1)]*G[{0, 1}, yu^(-1)] - 
     4*G[{0}, yu^(-1)]*G[{yu}, yv^(-1)]^2*G[{0, 1}, yu^(-1)] - 
     4*G[{0}, yv^(-1)]*G[{yu}, yv^(-1)]^2*G[{0, 1}, yu^(-1)] + 
     4*G[{0}, yw]*G[{yu}, yv^(-1)]^2*G[{0, 1}, yu^(-1)] + 
     3*G[{1}, yu^(-1)]*G[{yu}, yv^(-1)]^2*G[{0, 1}, yu^(-1)] - 
     3*G[{1}, yv^(-1)]*G[{yu}, yv^(-1)]^2*G[{0, 1}, yu^(-1)] + 
     (8*G[{yu}, yv^(-1)]^3*G[{0, 1}, yu^(-1)])/3 - 
     (2*Pi^2*G[{yv^(-1)}, yw]*G[{0, 1}, yu^(-1)])/3 + 
     2*G[{0}, yu^(-1)]^2*G[{yv^(-1)}, yw]*G[{0, 1}, yu^(-1)] + 
     4*G[{0}, yu^(-1)]*G[{0}, yv^(-1)]*G[{yv^(-1)}, yw]*G[{0, 1}, yu^(-1)] + 
     2*G[{0}, yv^(-1)]^2*G[{yv^(-1)}, yw]*G[{0, 1}, yu^(-1)] - 
     4*G[{0}, yu^(-1)]*G[{0}, yw]*G[{yv^(-1)}, yw]*G[{0, 1}, yu^(-1)] - 
     4*G[{0}, yv^(-1)]*G[{0}, yw]*G[{yv^(-1)}, yw]*G[{0, 1}, yu^(-1)] + 
     2*G[{0}, yw]^2*G[{yv^(-1)}, yw]*G[{0, 1}, yu^(-1)] - 
     2*G[{0}, yu^(-1)]*G[{1}, yu^(-1)]*G[{yv^(-1)}, yw]*G[{0, 1}, yu^(-1)] - 
     2*G[{0}, yv^(-1)]*G[{1}, yu^(-1)]*G[{yv^(-1)}, yw]*G[{0, 1}, yu^(-1)] + 
     2*G[{0}, yw]*G[{1}, yu^(-1)]*G[{yv^(-1)}, yw]*G[{0, 1}, yu^(-1)] + 
     G[{1}, yu^(-1)]^2*G[{yv^(-1)}, yw]*G[{0, 1}, yu^(-1)] - 
     2*G[{0}, yu^(-1)]*G[{1}, yv^(-1)]*G[{yv^(-1)}, yw]*G[{0, 1}, yu^(-1)] - 
     2*G[{0}, yv^(-1)]*G[{1}, yv^(-1)]*G[{yv^(-1)}, yw]*G[{0, 1}, yu^(-1)] + 
     2*G[{0}, yw]*G[{1}, yv^(-1)]*G[{yv^(-1)}, yw]*G[{0, 1}, yu^(-1)] + 
     G[{1}, yv^(-1)]^2*G[{yv^(-1)}, yw]*G[{0, 1}, yu^(-1)] + 
     2*G[{0}, yu^(-1)]*G[{1}, yw]*G[{yv^(-1)}, yw]*G[{0, 1}, yu^(-1)] + 
     2*G[{0}, yv^(-1)]*G[{1}, yw]*G[{yv^(-1)}, yw]*G[{0, 1}, yu^(-1)] - 
     2*G[{0}, yw]*G[{1}, yw]*G[{yv^(-1)}, yw]*G[{0, 1}, yu^(-1)] - 
     2*G[{1}, yu^(-1)]*G[{1}, yw]*G[{yv^(-1)}, yw]*G[{0, 1}, yu^(-1)] - 
     4*G[{1}, yv^(-1)]*G[{1}, yw]*G[{yv^(-1)}, yw]*G[{0, 1}, yu^(-1)] - 
     2*G[{0}, yu^(-1)]*G[{yu}, yv^(-1)]*G[{yv^(-1)}, yw]*G[{0, 1}, yu^(-1)] - 
     2*G[{0}, yv^(-1)]*G[{yu}, yv^(-1)]*G[{yv^(-1)}, yw]*G[{0, 1}, yu^(-1)] + 
     2*G[{0}, yw]*G[{yu}, yv^(-1)]*G[{yv^(-1)}, yw]*G[{0, 1}, yu^(-1)] + 
     2*G[{1}, yu^(-1)]*G[{yu}, yv^(-1)]*G[{yv^(-1)}, yw]*G[{0, 1}, yu^(-1)] + 
     2*G[{1}, yv^(-1)]*G[{yu}, yv^(-1)]*G[{yv^(-1)}, yw]*G[{0, 1}, yu^(-1)] + 
     2*G[{1}, yw]*G[{yu}, yv^(-1)]*G[{yv^(-1)}, yw]*G[{0, 1}, yu^(-1)] + 
     G[{1}, yu^(-1)]*G[{yv^(-1)}, yw]^2*G[{0, 1}, yu^(-1)] + 
     G[{1}, yv^(-1)]*G[{yv^(-1)}, yw]^2*G[{0, 1}, yu^(-1)] + 
     G[{1}, yw]*G[{yv^(-1)}, yw]^2*G[{0, 1}, yu^(-1)] - 
     2*G[{yu}, yv^(-1)]*G[{yv^(-1)}, yw]^2*G[{0, 1}, yu^(-1)] - 
     (2*G[{yv^(-1)}, yw]^3*G[{0, 1}, yu^(-1)])/3 + 
     (Pi^2*G[{1/(yu*yv)}, yw]*G[{0, 1}, yu^(-1)])/3 - 
     2*G[{0}, yu^(-1)]^2*G[{1/(yu*yv)}, yw]*G[{0, 1}, yu^(-1)] - 
     4*G[{0}, yu^(-1)]*G[{0}, yv^(-1)]*G[{1/(yu*yv)}, yw]*
      G[{0, 1}, yu^(-1)] - 2*G[{0}, yv^(-1)]^2*G[{1/(yu*yv)}, yw]*
      G[{0, 1}, yu^(-1)] + 4*G[{0}, yu^(-1)]*G[{0}, yw]*G[{1/(yu*yv)}, yw]*
      G[{0, 1}, yu^(-1)] + 4*G[{0}, yv^(-1)]*G[{0}, yw]*G[{1/(yu*yv)}, yw]*
      G[{0, 1}, yu^(-1)] - 2*G[{0}, yw]^2*G[{1/(yu*yv)}, yw]*
      G[{0, 1}, yu^(-1)] + 2*G[{0}, yu^(-1)]*G[{1}, yu^(-1)]*
      G[{1/(yu*yv)}, yw]*G[{0, 1}, yu^(-1)] + 2*G[{0}, yv^(-1)]*
      G[{1}, yu^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, 1}, yu^(-1)] - 
     2*G[{0}, yw]*G[{1}, yu^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, 1}, yu^(-1)] - 
     G[{1}, yu^(-1)]^2*G[{1/(yu*yv)}, yw]*G[{0, 1}, yu^(-1)] - 
     4*G[{0}, yu^(-1)]*G[{1}, yv^(-1)]*G[{1/(yu*yv)}, yw]*
      G[{0, 1}, yu^(-1)] - 4*G[{0}, yv^(-1)]*G[{1}, yv^(-1)]*
      G[{1/(yu*yv)}, yw]*G[{0, 1}, yu^(-1)] + 4*G[{0}, yw]*G[{1}, yv^(-1)]*
      G[{1/(yu*yv)}, yw]*G[{0, 1}, yu^(-1)] + 4*G[{1}, yu^(-1)]*
      G[{1}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, 1}, yu^(-1)] + 
     G[{1}, yv^(-1)]^2*G[{1/(yu*yv)}, yw]*G[{0, 1}, yu^(-1)] - 
     2*G[{0}, yu^(-1)]*G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1}, yu^(-1)] - 
     2*G[{0}, yv^(-1)]*G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1}, yu^(-1)] + 
     2*G[{0}, yw]*G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1}, yu^(-1)] + 
     2*G[{1}, yu^(-1)]*G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1}, yu^(-1)] - 
     4*G[{1}, yv^(-1)]*G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1}, yu^(-1)] + 
     8*G[{0}, yu^(-1)]*G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw]*
      G[{0, 1}, yu^(-1)] + 8*G[{0}, yv^(-1)]*G[{yu}, yv^(-1)]*
      G[{1/(yu*yv)}, yw]*G[{0, 1}, yu^(-1)] - 8*G[{0}, yw]*G[{yu}, yv^(-1)]*
      G[{1/(yu*yv)}, yw]*G[{0, 1}, yu^(-1)] - 6*G[{1}, yu^(-1)]*
      G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, 1}, yu^(-1)] + 
     6*G[{1}, yv^(-1)]*G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw]*
      G[{0, 1}, yu^(-1)] + 6*G[{1}, yw]*G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw]*
      G[{0, 1}, yu^(-1)] - 8*G[{yu}, yv^(-1)]^2*G[{1/(yu*yv)}, yw]*
      G[{0, 1}, yu^(-1)] + 2*G[{0}, yu^(-1)]*G[{yv^(-1)}, yw]*
      G[{1/(yu*yv)}, yw]*G[{0, 1}, yu^(-1)] + 2*G[{0}, yv^(-1)]*
      G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1}, yu^(-1)] - 
     2*G[{0}, yw]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1}, yu^(-1)] - 
     2*G[{1}, yu^(-1)]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*
      G[{0, 1}, yu^(-1)] - 2*G[{1}, yv^(-1)]*G[{yv^(-1)}, yw]*
      G[{1/(yu*yv)}, yw]*G[{0, 1}, yu^(-1)] + 2*G[{1}, yw]*G[{yv^(-1)}, yw]*
      G[{1/(yu*yv)}, yw]*G[{0, 1}, yu^(-1)] + 2*G[{yv^(-1)}, yw]^2*
      G[{1/(yu*yv)}, yw]*G[{0, 1}, yu^(-1)] - 3*G[{0}, yu^(-1)]*
      G[{1/(yu*yv)}, yw]^2*G[{0, 1}, yu^(-1)] - 3*G[{0}, yv^(-1)]*
      G[{1/(yu*yv)}, yw]^2*G[{0, 1}, yu^(-1)] + 
     3*G[{0}, yw]*G[{1/(yu*yv)}, yw]^2*G[{0, 1}, yu^(-1)] + 
     2*G[{1}, yu^(-1)]*G[{1/(yu*yv)}, yw]^2*G[{0, 1}, yu^(-1)] - 
     G[{1}, yv^(-1)]*G[{1/(yu*yv)}, yw]^2*G[{0, 1}, yu^(-1)] - 
     5*G[{1}, yw]*G[{1/(yu*yv)}, yw]^2*G[{0, 1}, yu^(-1)] + 
     G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2*G[{0, 1}, yu^(-1)] + 
     5*G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw]^2*G[{0, 1}, yu^(-1)] - 
     2*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2*G[{0, 1}, yu^(-1)] + 
     G[{0}, yu^(-1)]*G[{0, 1}, yu^(-1)]^2 + G[{0}, yv^(-1)]*
      G[{0, 1}, yu^(-1)]^2 - G[{0}, yw]*G[{0, 1}, yu^(-1)]^2 - 
     G[{yu}, yv^(-1)]*G[{0, 1}, yu^(-1)]^2 + G[{1/(yu*yv)}, yw]*
      G[{0, 1}, yu^(-1)]^2 + (Pi^2*G[{0}, yu^(-1)]*G[{0, 1}, yv^(-1)])/3 + 
     (Pi^2*G[{0}, yv^(-1)]*G[{0, 1}, yv^(-1)])/3 - 
     (Pi^2*G[{0}, yw]*G[{0, 1}, yv^(-1)])/3 - 
     (Pi^2*G[{1}, yu^(-1)]*G[{0, 1}, yv^(-1)])/3 - 
     2*G[{0}, yu^(-1)]*G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*G[{0, 1}, yv^(-1)] - 
     2*G[{0}, yv^(-1)]*G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*G[{0, 1}, yv^(-1)] + 
     2*G[{0}, yw]*G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*G[{0, 1}, yv^(-1)] + 
     2*G[{1}, yu^(-1)]^2*G[{1}, yv^(-1)]*G[{0, 1}, yv^(-1)] - 
     G[{0}, yu^(-1)]*G[{1}, yv^(-1)]^2*G[{0, 1}, yv^(-1)] - 
     G[{0}, yv^(-1)]*G[{1}, yv^(-1)]^2*G[{0, 1}, yv^(-1)] + 
     G[{0}, yw]*G[{1}, yv^(-1)]^2*G[{0, 1}, yv^(-1)] + 
     G[{1}, yu^(-1)]*G[{1}, yv^(-1)]^2*G[{0, 1}, yv^(-1)] + 
     (G[{1}, yv^(-1)]^3*G[{0, 1}, yv^(-1)])/3 - 
     (Pi^2*G[{yu}, yv^(-1)]*G[{0, 1}, yv^(-1)])/3 + 
     2*G[{0}, yu^(-1)]*G[{1}, yu^(-1)]*G[{yu}, yv^(-1)]*G[{0, 1}, yv^(-1)] + 
     2*G[{0}, yv^(-1)]*G[{1}, yu^(-1)]*G[{yu}, yv^(-1)]*G[{0, 1}, yv^(-1)] - 
     2*G[{0}, yw]*G[{1}, yu^(-1)]*G[{yu}, yv^(-1)]*G[{0, 1}, yv^(-1)] - 
     2*G[{1}, yu^(-1)]^2*G[{yu}, yv^(-1)]*G[{0, 1}, yv^(-1)] + 
     2*G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*G[{yu}, yv^(-1)]*G[{0, 1}, yv^(-1)] + 
     G[{1}, yv^(-1)]^2*G[{yu}, yv^(-1)]*G[{0, 1}, yv^(-1)] - 
     2*G[{1}, yu^(-1)]*G[{yu}, yv^(-1)]^2*G[{0, 1}, yv^(-1)] + 
     (2*G[{yu}, yv^(-1)]^3*G[{0, 1}, yv^(-1)])/3 + 
     2*G[{0}, yu^(-1)]*G[{1}, yu^(-1)]*G[{yv^(-1)}, yw]*G[{0, 1}, yv^(-1)] + 
     2*G[{0}, yv^(-1)]*G[{1}, yu^(-1)]*G[{yv^(-1)}, yw]*G[{0, 1}, yv^(-1)] - 
     2*G[{0}, yw]*G[{1}, yu^(-1)]*G[{yv^(-1)}, yw]*G[{0, 1}, yv^(-1)] - 
     2*G[{1}, yu^(-1)]^2*G[{yv^(-1)}, yw]*G[{0, 1}, yv^(-1)] + 
     2*G[{0}, yu^(-1)]*G[{1}, yv^(-1)]*G[{yv^(-1)}, yw]*G[{0, 1}, yv^(-1)] + 
     2*G[{0}, yv^(-1)]*G[{1}, yv^(-1)]*G[{yv^(-1)}, yw]*G[{0, 1}, yv^(-1)] - 
     2*G[{0}, yw]*G[{1}, yv^(-1)]*G[{yv^(-1)}, yw]*G[{0, 1}, yv^(-1)] - 
     2*G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*G[{yv^(-1)}, yw]*G[{0, 1}, yv^(-1)] - 
     G[{1}, yv^(-1)]^2*G[{yv^(-1)}, yw]*G[{0, 1}, yv^(-1)] - 
     2*G[{0}, yu^(-1)]*G[{1}, yw]*G[{yv^(-1)}, yw]*G[{0, 1}, yv^(-1)] - 
     2*G[{0}, yv^(-1)]*G[{1}, yw]*G[{yv^(-1)}, yw]*G[{0, 1}, yv^(-1)] + 
     2*G[{0}, yw]*G[{1}, yw]*G[{yv^(-1)}, yw]*G[{0, 1}, yv^(-1)] + 
     2*G[{1}, yu^(-1)]*G[{1}, yw]*G[{yv^(-1)}, yw]*G[{0, 1}, yv^(-1)] + 
     2*G[{1}, yv^(-1)]*G[{1}, yw]*G[{yv^(-1)}, yw]*G[{0, 1}, yv^(-1)] - 
     2*G[{0}, yu^(-1)]*G[{yu}, yv^(-1)]*G[{yv^(-1)}, yw]*G[{0, 1}, yv^(-1)] - 
     2*G[{0}, yv^(-1)]*G[{yu}, yv^(-1)]*G[{yv^(-1)}, yw]*G[{0, 1}, yv^(-1)] + 
     2*G[{0}, yw]*G[{yu}, yv^(-1)]*G[{yv^(-1)}, yw]*G[{0, 1}, yv^(-1)] + 
     2*G[{yu}, yv^(-1)]^2*G[{yv^(-1)}, yw]*G[{0, 1}, yv^(-1)] + 
     (Pi^2*G[{1/(yu*yv)}, yw]*G[{0, 1}, yv^(-1)])/3 - 
     2*G[{0}, yu^(-1)]*G[{1}, yu^(-1)]*G[{1/(yu*yv)}, yw]*
      G[{0, 1}, yv^(-1)] - 2*G[{0}, yv^(-1)]*G[{1}, yu^(-1)]*
      G[{1/(yu*yv)}, yw]*G[{0, 1}, yv^(-1)] + 2*G[{0}, yw]*G[{1}, yu^(-1)]*
      G[{1/(yu*yv)}, yw]*G[{0, 1}, yv^(-1)] + 2*G[{1}, yu^(-1)]^2*
      G[{1/(yu*yv)}, yw]*G[{0, 1}, yv^(-1)] - 2*G[{1}, yu^(-1)]*
      G[{1}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, 1}, yv^(-1)] - 
     G[{1}, yv^(-1)]^2*G[{1/(yu*yv)}, yw]*G[{0, 1}, yv^(-1)] + 
     2*G[{0}, yu^(-1)]*G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1}, yv^(-1)] + 
     2*G[{0}, yv^(-1)]*G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1}, yv^(-1)] - 
     2*G[{0}, yw]*G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1}, yv^(-1)] - 
     2*G[{1}, yu^(-1)]*G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1}, yv^(-1)] - 
     2*G[{1}, yv^(-1)]*G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1}, yv^(-1)] + 
     4*G[{1}, yu^(-1)]*G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw]*
      G[{0, 1}, yv^(-1)] - 2*G[{yu}, yv^(-1)]^2*G[{1/(yu*yv)}, yw]*
      G[{0, 1}, yv^(-1)] + 2*G[{0}, yu^(-1)]*G[{yv^(-1)}, yw]*
      G[{1/(yu*yv)}, yw]*G[{0, 1}, yv^(-1)] + 2*G[{0}, yv^(-1)]*
      G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1}, yv^(-1)] - 
     2*G[{0}, yw]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1}, yv^(-1)] + 
     4*G[{1}, yw]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1}, yv^(-1)] - 
     4*G[{yu}, yv^(-1)]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*
      G[{0, 1}, yv^(-1)] - G[{0}, yu^(-1)]*G[{1/(yu*yv)}, yw]^2*
      G[{0, 1}, yv^(-1)] - G[{0}, yv^(-1)]*G[{1/(yu*yv)}, yw]^2*
      G[{0, 1}, yv^(-1)] + G[{0}, yw]*G[{1/(yu*yv)}, yw]^2*
      G[{0, 1}, yv^(-1)] - G[{1}, yu^(-1)]*G[{1/(yu*yv)}, yw]^2*
      G[{0, 1}, yv^(-1)] + G[{1}, yv^(-1)]*G[{1/(yu*yv)}, yw]^2*
      G[{0, 1}, yv^(-1)] - 2*G[{1}, yw]*G[{1/(yu*yv)}, yw]^2*
      G[{0, 1}, yv^(-1)] - G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2*
      G[{0, 1}, yv^(-1)] + 2*G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw]^2*
      G[{0, 1}, yv^(-1)] + G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2*
      G[{0, 1}, yv^(-1)] - 2*G[{0}, yu^(-1)]*G[{0, 1}, yu^(-1)]*
      G[{0, 1}, yv^(-1)] - 2*G[{0}, yv^(-1)]*G[{0, 1}, yu^(-1)]*
      G[{0, 1}, yv^(-1)] + 2*G[{0}, yw]*G[{0, 1}, yu^(-1)]*
      G[{0, 1}, yv^(-1)] + 2*G[{1}, yu^(-1)]*G[{0, 1}, yu^(-1)]*
      G[{0, 1}, yv^(-1)] + 2*G[{yu}, yv^(-1)]*G[{0, 1}, yu^(-1)]*
      G[{0, 1}, yv^(-1)] - 2*G[{1/(yu*yv)}, yw]*G[{0, 1}, yu^(-1)]*
      G[{0, 1}, yv^(-1)] + G[{0}, yu^(-1)]*G[{0, 1}, yv^(-1)]^2 + 
     G[{0}, yv^(-1)]*G[{0, 1}, yv^(-1)]^2 - G[{0}, yw]*G[{0, 1}, yv^(-1)]^2 - 
     G[{1}, yu^(-1)]*G[{0, 1}, yv^(-1)]^2 - G[{yu}, yv^(-1)]*
      G[{0, 1}, yv^(-1)]^2 + G[{1/(yu*yv)}, yw]*G[{0, 1}, yv^(-1)]^2 + 
     2*G[{1}, yu^(-1)]*G[{1}, yv^(-1)]^2*G[{0, 1}, yw] - 
     4*G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*G[{yu}, yv^(-1)]*G[{0, 1}, yw] + 
     2*G[{1}, yu^(-1)]*G[{yu}, yv^(-1)]^2*G[{0, 1}, yw] - 
     (2*G[{yu}, yv^(-1)]^3*G[{0, 1}, yw])/3 - 
     (2*Pi^2*G[{yv^(-1)}, yw]*G[{0, 1}, yw])/3 - 2*G[{0}, yu^(-1)]*G[{1}, yw]*
      G[{yv^(-1)}, yw]*G[{0, 1}, yw] - 2*G[{0}, yv^(-1)]*G[{1}, yw]*
      G[{yv^(-1)}, yw]*G[{0, 1}, yw] + 2*G[{0}, yw]*G[{1}, yw]*
      G[{yv^(-1)}, yw]*G[{0, 1}, yw] + 2*G[{1}, yu^(-1)]*G[{1}, yw]*
      G[{yv^(-1)}, yw]*G[{0, 1}, yw] + 2*G[{1}, yv^(-1)]*G[{1}, yw]*
      G[{yv^(-1)}, yw]*G[{0, 1}, yw] + 4*G[{1}, yv^(-1)]*G[{yu}, yv^(-1)]*
      G[{yv^(-1)}, yw]*G[{0, 1}, yw] - 2*G[{yu}, yv^(-1)]^2*G[{yv^(-1)}, yw]*
      G[{0, 1}, yw] - 2*G[{1}, yu^(-1)]*G[{yv^(-1)}, yw]^2*G[{0, 1}, yw] - 
     2*G[{1}, yw]*G[{yv^(-1)}, yw]^2*G[{0, 1}, yw] + 
     2*G[{yu}, yv^(-1)]*G[{yv^(-1)}, yw]^2*G[{0, 1}, yw] + 
     (2*G[{yv^(-1)}, yw]^3*G[{0, 1}, yw])/3 + 
     (Pi^2*G[{1/(yu*yv)}, yw]*G[{0, 1}, yw])/3 + 2*G[{0}, yu^(-1)]*
      G[{1}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, 1}, yw] + 
     2*G[{0}, yv^(-1)]*G[{1}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, 1}, yw] - 
     2*G[{0}, yw]*G[{1}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, 1}, yw] - 
     2*G[{1}, yv^(-1)]^2*G[{1/(yu*yv)}, yw]*G[{0, 1}, yw] + 
     2*G[{0}, yu^(-1)]*G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1}, yw] + 
     2*G[{0}, yv^(-1)]*G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1}, yw] - 
     2*G[{0}, yw]*G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1}, yw] - 
     2*G[{1}, yu^(-1)]*G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1}, yw] - 
     2*G[{1}, yv^(-1)]*G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1}, yw] - 
     2*G[{0}, yu^(-1)]*G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, 1}, yw] - 
     2*G[{0}, yv^(-1)]*G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, 1}, yw] + 
     2*G[{0}, yw]*G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, 1}, yw] + 
     2*G[{yu}, yv^(-1)]^2*G[{1/(yu*yv)}, yw]*G[{0, 1}, yw] + 
     2*G[{0}, yu^(-1)]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1}, yw] + 
     2*G[{0}, yv^(-1)]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1}, yw] - 
     2*G[{0}, yw]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1}, yw] - 
     4*G[{1}, yv^(-1)]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1}, yw] - 
     2*G[{yv^(-1)}, yw]^2*G[{1/(yu*yv)}, yw]*G[{0, 1}, yw] - 
     G[{0}, yu^(-1)]*G[{1/(yu*yv)}, yw]^2*G[{0, 1}, yw] - 
     G[{0}, yv^(-1)]*G[{1/(yu*yv)}, yw]^2*G[{0, 1}, yw] + 
     G[{0}, yw]*G[{1/(yu*yv)}, yw]^2*G[{0, 1}, yw] + 
     G[{1}, yu^(-1)]*G[{1/(yu*yv)}, yw]^2*G[{0, 1}, yw] + 
     G[{1}, yv^(-1)]*G[{1/(yu*yv)}, yw]^2*G[{0, 1}, yw] + 
     G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2*G[{0, 1}, yw] + 
     G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2*G[{0, 1}, yw] + 
     4*G[{1}, yv^(-1)]*G[{0, 1}, yu^(-1)]*G[{0, 1}, yw] - 
     4*G[{yu}, yv^(-1)]*G[{0, 1}, yu^(-1)]*G[{0, 1}, yw] + 
     2*G[{1/(yu*yv)}, yw]*G[{0, 1}, yu^(-1)]*G[{0, 1}, yw] - 
     4*G[{yv^(-1)}, yw]*G[{0, 1}, yv^(-1)]*G[{0, 1}, yw] + 
     2*G[{1/(yu*yv)}, yw]*G[{0, 1}, yv^(-1)]*G[{0, 1}, yw] + 
     2*G[{yv^(-1)}, yw]*G[{0, 1}, yw]^2 - G[{1/(yu*yv)}, yw]*
      G[{0, 1}, yw]^2 + (Pi^2*G[{yv^(-1)}, yw]*G[{0, yu^(-1)}, yw])/3 - 
     2*G[{0}, yu^(-1)]*G[{1}, yv^(-1)]*G[{yv^(-1)}, yw]*G[{0, yu^(-1)}, yw] - 
     2*G[{0}, yv^(-1)]*G[{1}, yv^(-1)]*G[{yv^(-1)}, yw]*G[{0, yu^(-1)}, yw] + 
     2*G[{0}, yw]*G[{1}, yv^(-1)]*G[{yv^(-1)}, yw]*G[{0, yu^(-1)}, yw] + 
     2*G[{1}, yv^(-1)]^2*G[{yv^(-1)}, yw]*G[{0, yu^(-1)}, yw] + 
     2*G[{0}, yu^(-1)]*G[{1}, yw]*G[{yv^(-1)}, yw]*G[{0, yu^(-1)}, yw] + 
     2*G[{0}, yv^(-1)]*G[{1}, yw]*G[{yv^(-1)}, yw]*G[{0, yu^(-1)}, yw] - 
     2*G[{0}, yw]*G[{1}, yw]*G[{yv^(-1)}, yw]*G[{0, yu^(-1)}, yw] - 
     2*G[{1}, yu^(-1)]*G[{1}, yw]*G[{yv^(-1)}, yw]*G[{0, yu^(-1)}, yw] - 
     2*G[{1}, yv^(-1)]*G[{1}, yw]*G[{yv^(-1)}, yw]*G[{0, yu^(-1)}, yw] + 
     2*G[{0}, yu^(-1)]*G[{yu}, yv^(-1)]*G[{yv^(-1)}, yw]*
      G[{0, yu^(-1)}, yw] + 2*G[{0}, yv^(-1)]*G[{yu}, yv^(-1)]*
      G[{yv^(-1)}, yw]*G[{0, yu^(-1)}, yw] - 2*G[{0}, yw]*G[{yu}, yv^(-1)]*
      G[{yv^(-1)}, yw]*G[{0, yu^(-1)}, yw] - 4*G[{1}, yv^(-1)]*
      G[{yu}, yv^(-1)]*G[{yv^(-1)}, yw]*G[{0, yu^(-1)}, yw] + 
     2*G[{1}, yu^(-1)]*G[{yv^(-1)}, yw]^2*G[{0, yu^(-1)}, yw] + 
     2*G[{1}, yw]*G[{yv^(-1)}, yw]^2*G[{0, yu^(-1)}, yw] - 
     2*G[{yu}, yv^(-1)]*G[{yv^(-1)}, yw]^2*G[{0, yu^(-1)}, yw] - 
     (2*G[{yv^(-1)}, yw]^3*G[{0, yu^(-1)}, yw])/3 - 
     2*G[{0}, yu^(-1)]*G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1)}, yw] - 
     2*G[{0}, yv^(-1)]*G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1)}, yw] + 
     2*G[{0}, yw]*G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1)}, yw] + 
     2*G[{1}, yu^(-1)]*G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1)}, yw] + 
     2*G[{1}, yv^(-1)]*G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1)}, yw] - 
     2*G[{0}, yu^(-1)]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*
      G[{0, yu^(-1)}, yw] - 2*G[{0}, yv^(-1)]*G[{yv^(-1)}, yw]*
      G[{1/(yu*yv)}, yw]*G[{0, yu^(-1)}, yw] + 2*G[{0}, yw]*G[{yv^(-1)}, yw]*
      G[{1/(yu*yv)}, yw]*G[{0, yu^(-1)}, yw] + 4*G[{1}, yv^(-1)]*
      G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1)}, yw] + 
     2*G[{yv^(-1)}, yw]^2*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1)}, yw] + 
     G[{0}, yu^(-1)]*G[{1/(yu*yv)}, yw]^2*G[{0, yu^(-1)}, yw] + 
     G[{0}, yv^(-1)]*G[{1/(yu*yv)}, yw]^2*G[{0, yu^(-1)}, yw] - 
     G[{0}, yw]*G[{1/(yu*yv)}, yw]^2*G[{0, yu^(-1)}, yw] - 
     G[{1}, yu^(-1)]*G[{1/(yu*yv)}, yw]^2*G[{0, yu^(-1)}, yw] - 
     G[{1}, yv^(-1)]*G[{1/(yu*yv)}, yw]^2*G[{0, yu^(-1)}, yw] - 
     G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2*G[{0, yu^(-1)}, yw] - 
     G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2*G[{0, yu^(-1)}, yw] - 
     2*G[{yv^(-1)}, yw]*G[{0, 1}, yu^(-1)]*G[{0, yu^(-1)}, yw] + 
     2*G[{yv^(-1)}, yw]*G[{0, 1}, yv^(-1)]*G[{0, yu^(-1)}, yw] - 
     2*G[{yv^(-1)}, yw]*G[{0, 1}, yw]*G[{0, yu^(-1)}, yw] + 
     G[{yv^(-1)}, yw]*G[{0, yu^(-1)}, yw]^2 - 
     (Pi^2*G[{0}, yu^(-1)]*G[{0, yu}, yv^(-1)])/3 - 
     (Pi^2*G[{0}, yv^(-1)]*G[{0, yu}, yv^(-1)])/3 + 
     (Pi^2*G[{0}, yw]*G[{0, yu}, yv^(-1)])/3 + 
     (Pi^2*G[{1}, yu^(-1)]*G[{0, yu}, yv^(-1)])/3 + 
     (Pi^2*G[{1}, yv^(-1)]*G[{0, yu}, yv^(-1)])/3 + 
     2*G[{0}, yu^(-1)]*G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*G[{0, yu}, yv^(-1)] + 
     2*G[{0}, yv^(-1)]*G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*G[{0, yu}, yv^(-1)] - 
     2*G[{0}, yw]*G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*G[{0, yu}, yv^(-1)] - 
     2*G[{1}, yu^(-1)]^2*G[{1}, yv^(-1)]*G[{0, yu}, yv^(-1)] + 
     G[{0}, yu^(-1)]*G[{1}, yv^(-1)]^2*G[{0, yu}, yv^(-1)] + 
     G[{0}, yv^(-1)]*G[{1}, yv^(-1)]^2*G[{0, yu}, yv^(-1)] - 
     G[{0}, yw]*G[{1}, yv^(-1)]^2*G[{0, yu}, yv^(-1)] - 
     G[{1}, yu^(-1)]*G[{1}, yv^(-1)]^2*G[{0, yu}, yv^(-1)] - 
     (G[{1}, yv^(-1)]^3*G[{0, yu}, yv^(-1)])/3 - 2*G[{0}, yu^(-1)]*
      G[{1}, yu^(-1)]*G[{yu}, yv^(-1)]*G[{0, yu}, yv^(-1)] - 
     2*G[{0}, yv^(-1)]*G[{1}, yu^(-1)]*G[{yu}, yv^(-1)]*G[{0, yu}, yv^(-1)] + 
     2*G[{0}, yw]*G[{1}, yu^(-1)]*G[{yu}, yv^(-1)]*G[{0, yu}, yv^(-1)] + 
     2*G[{1}, yu^(-1)]^2*G[{yu}, yv^(-1)]*G[{0, yu}, yv^(-1)] - 
     2*G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*G[{yu}, yv^(-1)]*G[{0, yu}, yv^(-1)] - 
     G[{1}, yv^(-1)]^2*G[{yu}, yv^(-1)]*G[{0, yu}, yv^(-1)] + 
     2*G[{1}, yu^(-1)]*G[{yu}, yv^(-1)]^2*G[{0, yu}, yv^(-1)] - 
     (2*G[{yu}, yv^(-1)]^3*G[{0, yu}, yv^(-1)])/3 - 
     (Pi^2*G[{yv^(-1)}, yw]*G[{0, yu}, yv^(-1)])/3 - 
     2*G[{0}, yu^(-1)]*G[{1}, yu^(-1)]*G[{yv^(-1)}, yw]*G[{0, yu}, yv^(-1)] - 
     2*G[{0}, yv^(-1)]*G[{1}, yu^(-1)]*G[{yv^(-1)}, yw]*G[{0, yu}, yv^(-1)] + 
     2*G[{0}, yw]*G[{1}, yu^(-1)]*G[{yv^(-1)}, yw]*G[{0, yu}, yv^(-1)] + 
     2*G[{1}, yu^(-1)]^2*G[{yv^(-1)}, yw]*G[{0, yu}, yv^(-1)] - 
     2*G[{0}, yu^(-1)]*G[{1}, yv^(-1)]*G[{yv^(-1)}, yw]*G[{0, yu}, yv^(-1)] - 
     2*G[{0}, yv^(-1)]*G[{1}, yv^(-1)]*G[{yv^(-1)}, yw]*G[{0, yu}, yv^(-1)] + 
     2*G[{0}, yw]*G[{1}, yv^(-1)]*G[{yv^(-1)}, yw]*G[{0, yu}, yv^(-1)] + 
     2*G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*G[{yv^(-1)}, yw]*G[{0, yu}, yv^(-1)] + 
     G[{1}, yv^(-1)]^2*G[{yv^(-1)}, yw]*G[{0, yu}, yv^(-1)] + 
     2*G[{0}, yu^(-1)]*G[{1}, yw]*G[{yv^(-1)}, yw]*G[{0, yu}, yv^(-1)] + 
     2*G[{0}, yv^(-1)]*G[{1}, yw]*G[{yv^(-1)}, yw]*G[{0, yu}, yv^(-1)] - 
     2*G[{0}, yw]*G[{1}, yw]*G[{yv^(-1)}, yw]*G[{0, yu}, yv^(-1)] - 
     2*G[{1}, yu^(-1)]*G[{1}, yw]*G[{yv^(-1)}, yw]*G[{0, yu}, yv^(-1)] - 
     2*G[{1}, yv^(-1)]*G[{1}, yw]*G[{yv^(-1)}, yw]*G[{0, yu}, yv^(-1)] + 
     2*G[{0}, yu^(-1)]*G[{yu}, yv^(-1)]*G[{yv^(-1)}, yw]*
      G[{0, yu}, yv^(-1)] + 2*G[{0}, yv^(-1)]*G[{yu}, yv^(-1)]*
      G[{yv^(-1)}, yw]*G[{0, yu}, yv^(-1)] - 2*G[{0}, yw]*G[{yu}, yv^(-1)]*
      G[{yv^(-1)}, yw]*G[{0, yu}, yv^(-1)] - 2*G[{yu}, yv^(-1)]^2*
      G[{yv^(-1)}, yw]*G[{0, yu}, yv^(-1)] + 2*G[{0}, yu^(-1)]*
      G[{1}, yu^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, yu}, yv^(-1)] + 
     2*G[{0}, yv^(-1)]*G[{1}, yu^(-1)]*G[{1/(yu*yv)}, yw]*
      G[{0, yu}, yv^(-1)] - 2*G[{0}, yw]*G[{1}, yu^(-1)]*G[{1/(yu*yv)}, yw]*
      G[{0, yu}, yv^(-1)] - 2*G[{1}, yu^(-1)]^2*G[{1/(yu*yv)}, yw]*
      G[{0, yu}, yv^(-1)] + 2*G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*
      G[{1/(yu*yv)}, yw]*G[{0, yu}, yv^(-1)] + G[{1}, yv^(-1)]^2*
      G[{1/(yu*yv)}, yw]*G[{0, yu}, yv^(-1)] - 2*G[{0}, yu^(-1)]*G[{1}, yw]*
      G[{1/(yu*yv)}, yw]*G[{0, yu}, yv^(-1)] - 2*G[{0}, yv^(-1)]*G[{1}, yw]*
      G[{1/(yu*yv)}, yw]*G[{0, yu}, yv^(-1)] + 2*G[{0}, yw]*G[{1}, yw]*
      G[{1/(yu*yv)}, yw]*G[{0, yu}, yv^(-1)] + 2*G[{1}, yu^(-1)]*G[{1}, yw]*
      G[{1/(yu*yv)}, yw]*G[{0, yu}, yv^(-1)] + 2*G[{1}, yv^(-1)]*G[{1}, yw]*
      G[{1/(yu*yv)}, yw]*G[{0, yu}, yv^(-1)] - 4*G[{1}, yu^(-1)]*
      G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, yu}, yv^(-1)] + 
     2*G[{yu}, yv^(-1)]^2*G[{1/(yu*yv)}, yw]*G[{0, yu}, yv^(-1)] - 
     2*G[{0}, yu^(-1)]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*
      G[{0, yu}, yv^(-1)] - 2*G[{0}, yv^(-1)]*G[{yv^(-1)}, yw]*
      G[{1/(yu*yv)}, yw]*G[{0, yu}, yv^(-1)] + 2*G[{0}, yw]*G[{yv^(-1)}, yw]*
      G[{1/(yu*yv)}, yw]*G[{0, yu}, yv^(-1)] - 4*G[{1}, yw]*G[{yv^(-1)}, yw]*
      G[{1/(yu*yv)}, yw]*G[{0, yu}, yv^(-1)] + 4*G[{yu}, yv^(-1)]*
      G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{0, yu}, yv^(-1)] + 
     G[{0}, yu^(-1)]*G[{1/(yu*yv)}, yw]^2*G[{0, yu}, yv^(-1)] + 
     G[{0}, yv^(-1)]*G[{1/(yu*yv)}, yw]^2*G[{0, yu}, yv^(-1)] - 
     G[{0}, yw]*G[{1/(yu*yv)}, yw]^2*G[{0, yu}, yv^(-1)] + 
     G[{1}, yu^(-1)]*G[{1/(yu*yv)}, yw]^2*G[{0, yu}, yv^(-1)] - 
     G[{1}, yv^(-1)]*G[{1/(yu*yv)}, yw]^2*G[{0, yu}, yv^(-1)] + 
     2*G[{1}, yw]*G[{1/(yu*yv)}, yw]^2*G[{0, yu}, yv^(-1)] + 
     G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2*G[{0, yu}, yv^(-1)] - 
     2*G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw]^2*G[{0, yu}, yv^(-1)] - 
     G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2*G[{0, yu}, yv^(-1)] + 
     2*G[{0}, yu^(-1)]*G[{0, 1}, yu^(-1)]*G[{0, yu}, yv^(-1)] + 
     2*G[{0}, yv^(-1)]*G[{0, 1}, yu^(-1)]*G[{0, yu}, yv^(-1)] - 
     2*G[{0}, yw]*G[{0, 1}, yu^(-1)]*G[{0, yu}, yv^(-1)] - 
     2*G[{1}, yu^(-1)]*G[{0, 1}, yu^(-1)]*G[{0, yu}, yv^(-1)] + 
     2*G[{1}, yv^(-1)]*G[{0, 1}, yu^(-1)]*G[{0, yu}, yv^(-1)] - 
     4*G[{yu}, yv^(-1)]*G[{0, 1}, yu^(-1)]*G[{0, yu}, yv^(-1)] - 
     2*G[{yv^(-1)}, yw]*G[{0, 1}, yu^(-1)]*G[{0, yu}, yv^(-1)] + 
     4*G[{1/(yu*yv)}, yw]*G[{0, 1}, yu^(-1)]*G[{0, yu}, yv^(-1)] - 
     2*G[{0}, yu^(-1)]*G[{0, 1}, yv^(-1)]*G[{0, yu}, yv^(-1)] - 
     2*G[{0}, yv^(-1)]*G[{0, 1}, yv^(-1)]*G[{0, yu}, yv^(-1)] + 
     2*G[{0}, yw]*G[{0, 1}, yv^(-1)]*G[{0, yu}, yv^(-1)] + 
     2*G[{1}, yu^(-1)]*G[{0, 1}, yv^(-1)]*G[{0, yu}, yv^(-1)] + 
     2*G[{1}, yv^(-1)]*G[{0, 1}, yv^(-1)]*G[{0, yu}, yv^(-1)] - 
     2*G[{yv^(-1)}, yw]*G[{0, 1}, yv^(-1)]*G[{0, yu}, yv^(-1)] + 
     4*G[{yv^(-1)}, yw]*G[{0, 1}, yw]*G[{0, yu}, yv^(-1)] - 
     2*G[{1/(yu*yv)}, yw]*G[{0, 1}, yw]*G[{0, yu}, yv^(-1)] - 
     2*G[{yv^(-1)}, yw]*G[{0, yu^(-1)}, yw]*G[{0, yu}, yv^(-1)] + 
     G[{0}, yu^(-1)]*G[{0, yu}, yv^(-1)]^2 + G[{0}, yv^(-1)]*
      G[{0, yu}, yv^(-1)]^2 - G[{0}, yw]*G[{0, yu}, yv^(-1)]^2 - 
     G[{1}, yu^(-1)]*G[{0, yu}, yv^(-1)]^2 - G[{1}, yv^(-1)]*
      G[{0, yu}, yv^(-1)]^2 + G[{yv^(-1)}, yw]*G[{0, yu}, yv^(-1)]^2 - 
     (Pi^2*G[{0}, yu^(-1)]*G[{0, yv^(-1)}, yw])/3 - 
     (Pi^2*G[{0}, yv^(-1)]*G[{0, yv^(-1)}, yw])/3 + 
     (Pi^2*G[{0}, yw]*G[{0, yv^(-1)}, yw])/3 + 
     (Pi^2*G[{1}, yu^(-1)]*G[{0, yv^(-1)}, yw])/3 + 
     (Pi^2*G[{1}, yv^(-1)]*G[{0, yv^(-1)}, yw])/3 + 
     2*G[{0}, yu^(-1)]*G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*G[{0, yv^(-1)}, yw] + 
     2*G[{0}, yv^(-1)]*G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*G[{0, yv^(-1)}, yw] - 
     2*G[{0}, yw]*G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*G[{0, yv^(-1)}, yw] - 
     2*G[{1}, yu^(-1)]^2*G[{1}, yv^(-1)]*G[{0, yv^(-1)}, yw] - 
     2*G[{1}, yu^(-1)]*G[{1}, yv^(-1)]^2*G[{0, yv^(-1)}, yw] - 
     2*G[{0}, yu^(-1)]*G[{1}, yu^(-1)]*G[{yu}, yv^(-1)]*G[{0, yv^(-1)}, yw] - 
     2*G[{0}, yv^(-1)]*G[{1}, yu^(-1)]*G[{yu}, yv^(-1)]*G[{0, yv^(-1)}, yw] + 
     2*G[{0}, yw]*G[{1}, yu^(-1)]*G[{yu}, yv^(-1)]*G[{0, yv^(-1)}, yw] + 
     2*G[{1}, yu^(-1)]^2*G[{yu}, yv^(-1)]*G[{0, yv^(-1)}, yw] + 
     2*G[{0}, yu^(-1)]*G[{1}, yv^(-1)]*G[{yu}, yv^(-1)]*G[{0, yv^(-1)}, yw] + 
     2*G[{0}, yv^(-1)]*G[{1}, yv^(-1)]*G[{yu}, yv^(-1)]*G[{0, yv^(-1)}, yw] - 
     2*G[{0}, yw]*G[{1}, yv^(-1)]*G[{yu}, yv^(-1)]*G[{0, yv^(-1)}, yw] - 
     2*G[{1}, yv^(-1)]^2*G[{yu}, yv^(-1)]*G[{0, yv^(-1)}, yw] + 
     (Pi^2*G[{yv^(-1)}, yw]*G[{0, yv^(-1)}, yw])/3 - 
     2*G[{0}, yu^(-1)]*G[{1}, yu^(-1)]*G[{yv^(-1)}, yw]*G[{0, yv^(-1)}, yw] - 
     2*G[{0}, yv^(-1)]*G[{1}, yu^(-1)]*G[{yv^(-1)}, yw]*G[{0, yv^(-1)}, yw] + 
     2*G[{0}, yw]*G[{1}, yu^(-1)]*G[{yv^(-1)}, yw]*G[{0, yv^(-1)}, yw] + 
     2*G[{1}, yu^(-1)]^2*G[{yv^(-1)}, yw]*G[{0, yv^(-1)}, yw] + 
     2*G[{0}, yu^(-1)]*G[{1}, yw]*G[{yv^(-1)}, yw]*G[{0, yv^(-1)}, yw] + 
     2*G[{0}, yv^(-1)]*G[{1}, yw]*G[{yv^(-1)}, yw]*G[{0, yv^(-1)}, yw] - 
     2*G[{0}, yw]*G[{1}, yw]*G[{yv^(-1)}, yw]*G[{0, yv^(-1)}, yw] - 
     2*G[{1}, yu^(-1)]*G[{1}, yw]*G[{yv^(-1)}, yw]*G[{0, yv^(-1)}, yw] - 
     2*G[{1}, yv^(-1)]*G[{1}, yw]*G[{yv^(-1)}, yw]*G[{0, yv^(-1)}, yw] + 
     2*G[{0}, yu^(-1)]*G[{yu}, yv^(-1)]*G[{yv^(-1)}, yw]*
      G[{0, yv^(-1)}, yw] + 2*G[{0}, yv^(-1)]*G[{yu}, yv^(-1)]*
      G[{yv^(-1)}, yw]*G[{0, yv^(-1)}, yw] - 2*G[{0}, yw]*G[{yu}, yv^(-1)]*
      G[{yv^(-1)}, yw]*G[{0, yv^(-1)}, yw] - 4*G[{1}, yv^(-1)]*
      G[{yu}, yv^(-1)]*G[{yv^(-1)}, yw]*G[{0, yv^(-1)}, yw] + 
     2*G[{1}, yu^(-1)]*G[{yv^(-1)}, yw]^2*G[{0, yv^(-1)}, yw] + 
     2*G[{1}, yw]*G[{yv^(-1)}, yw]^2*G[{0, yv^(-1)}, yw] - 
     2*G[{yu}, yv^(-1)]*G[{yv^(-1)}, yw]^2*G[{0, yv^(-1)}, yw] - 
     (2*G[{yv^(-1)}, yw]^3*G[{0, yv^(-1)}, yw])/3 + 
     2*G[{0}, yu^(-1)]*G[{1}, yu^(-1)]*G[{1/(yu*yv)}, yw]*
      G[{0, yv^(-1)}, yw] + 2*G[{0}, yv^(-1)]*G[{1}, yu^(-1)]*
      G[{1/(yu*yv)}, yw]*G[{0, yv^(-1)}, yw] - 2*G[{0}, yw]*G[{1}, yu^(-1)]*
      G[{1/(yu*yv)}, yw]*G[{0, yv^(-1)}, yw] - 2*G[{1}, yu^(-1)]^2*
      G[{1/(yu*yv)}, yw]*G[{0, yv^(-1)}, yw] - 2*G[{0}, yu^(-1)]*
      G[{1}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, yv^(-1)}, yw] - 
     2*G[{0}, yv^(-1)]*G[{1}, yv^(-1)]*G[{1/(yu*yv)}, yw]*
      G[{0, yv^(-1)}, yw] + 2*G[{0}, yw]*G[{1}, yv^(-1)]*G[{1/(yu*yv)}, yw]*
      G[{0, yv^(-1)}, yw] + 2*G[{1}, yv^(-1)]^2*G[{1/(yu*yv)}, yw]*
      G[{0, yv^(-1)}, yw] - 2*G[{0}, yu^(-1)]*G[{1}, yw]*G[{1/(yu*yv)}, yw]*
      G[{0, yv^(-1)}, yw] - 2*G[{0}, yv^(-1)]*G[{1}, yw]*G[{1/(yu*yv)}, yw]*
      G[{0, yv^(-1)}, yw] + 2*G[{0}, yw]*G[{1}, yw]*G[{1/(yu*yv)}, yw]*
      G[{0, yv^(-1)}, yw] + 2*G[{1}, yu^(-1)]*G[{1}, yw]*G[{1/(yu*yv)}, yw]*
      G[{0, yv^(-1)}, yw] + 2*G[{1}, yv^(-1)]*G[{1}, yw]*G[{1/(yu*yv)}, yw]*
      G[{0, yv^(-1)}, yw] - 2*G[{0}, yu^(-1)]*G[{yv^(-1)}, yw]*
      G[{1/(yu*yv)}, yw]*G[{0, yv^(-1)}, yw] - 2*G[{0}, yv^(-1)]*
      G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{0, yv^(-1)}, yw] + 
     2*G[{0}, yw]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{0, yv^(-1)}, yw] + 
     4*G[{1}, yv^(-1)]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*
      G[{0, yv^(-1)}, yw] + 2*G[{yv^(-1)}, yw]^2*G[{1/(yu*yv)}, yw]*
      G[{0, yv^(-1)}, yw] + G[{0}, yu^(-1)]*G[{1/(yu*yv)}, yw]^2*
      G[{0, yv^(-1)}, yw] + G[{0}, yv^(-1)]*G[{1/(yu*yv)}, yw]^2*
      G[{0, yv^(-1)}, yw] - G[{0}, yw]*G[{1/(yu*yv)}, yw]^2*
      G[{0, yv^(-1)}, yw] - G[{1}, yu^(-1)]*G[{1/(yu*yv)}, yw]^2*
      G[{0, yv^(-1)}, yw] - G[{1}, yv^(-1)]*G[{1/(yu*yv)}, yw]^2*
      G[{0, yv^(-1)}, yw] - G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2*
      G[{0, yv^(-1)}, yw] - G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2*
      G[{0, yv^(-1)}, yw] + 2*G[{0}, yu^(-1)]*G[{0, 1}, yu^(-1)]*
      G[{0, yv^(-1)}, yw] + 2*G[{0}, yv^(-1)]*G[{0, 1}, yu^(-1)]*
      G[{0, yv^(-1)}, yw] - 2*G[{0}, yw]*G[{0, 1}, yu^(-1)]*
      G[{0, yv^(-1)}, yw] - 2*G[{1}, yu^(-1)]*G[{0, 1}, yu^(-1)]*
      G[{0, yv^(-1)}, yw] - 2*G[{1}, yv^(-1)]*G[{0, 1}, yu^(-1)]*
      G[{0, yv^(-1)}, yw] - 2*G[{yv^(-1)}, yw]*G[{0, 1}, yu^(-1)]*
      G[{0, yv^(-1)}, yw] - 2*G[{0}, yu^(-1)]*G[{0, 1}, yv^(-1)]*
      G[{0, yv^(-1)}, yw] - 2*G[{0}, yv^(-1)]*G[{0, 1}, yv^(-1)]*
      G[{0, yv^(-1)}, yw] + 2*G[{0}, yw]*G[{0, 1}, yv^(-1)]*
      G[{0, yv^(-1)}, yw] + 2*G[{1}, yu^(-1)]*G[{0, 1}, yv^(-1)]*
      G[{0, yv^(-1)}, yw] + 2*G[{1}, yv^(-1)]*G[{0, 1}, yv^(-1)]*
      G[{0, yv^(-1)}, yw] + 2*G[{yv^(-1)}, yw]*G[{0, 1}, yv^(-1)]*
      G[{0, yv^(-1)}, yw] - 2*G[{0}, yu^(-1)]*G[{0, 1}, yw]*
      G[{0, yv^(-1)}, yw] - 2*G[{0}, yv^(-1)]*G[{0, 1}, yw]*
      G[{0, yv^(-1)}, yw] + 2*G[{0}, yw]*G[{0, 1}, yw]*G[{0, yv^(-1)}, yw] + 
     2*G[{1}, yu^(-1)]*G[{0, 1}, yw]*G[{0, yv^(-1)}, yw] + 
     2*G[{1}, yv^(-1)]*G[{0, 1}, yw]*G[{0, yv^(-1)}, yw] - 
     2*G[{yv^(-1)}, yw]*G[{0, 1}, yw]*G[{0, yv^(-1)}, yw] + 
     2*G[{0}, yu^(-1)]*G[{0, yu^(-1)}, yw]*G[{0, yv^(-1)}, yw] + 
     2*G[{0}, yv^(-1)]*G[{0, yu^(-1)}, yw]*G[{0, yv^(-1)}, yw] - 
     2*G[{0}, yw]*G[{0, yu^(-1)}, yw]*G[{0, yv^(-1)}, yw] - 
     2*G[{1}, yu^(-1)]*G[{0, yu^(-1)}, yw]*G[{0, yv^(-1)}, yw] - 
     2*G[{1}, yv^(-1)]*G[{0, yu^(-1)}, yw]*G[{0, yv^(-1)}, yw] + 
     2*G[{yv^(-1)}, yw]*G[{0, yu^(-1)}, yw]*G[{0, yv^(-1)}, yw] + 
     2*G[{0}, yu^(-1)]*G[{0, yu}, yv^(-1)]*G[{0, yv^(-1)}, yw] + 
     2*G[{0}, yv^(-1)]*G[{0, yu}, yv^(-1)]*G[{0, yv^(-1)}, yw] - 
     2*G[{0}, yw]*G[{0, yu}, yv^(-1)]*G[{0, yv^(-1)}, yw] - 
     2*G[{1}, yu^(-1)]*G[{0, yu}, yv^(-1)]*G[{0, yv^(-1)}, yw] - 
     2*G[{1}, yv^(-1)]*G[{0, yu}, yv^(-1)]*G[{0, yv^(-1)}, yw] - 
     2*G[{yv^(-1)}, yw]*G[{0, yu}, yv^(-1)]*G[{0, yv^(-1)}, yw] + 
     G[{0}, yu^(-1)]*G[{0, yv^(-1)}, yw]^2 + G[{0}, yv^(-1)]*
      G[{0, yv^(-1)}, yw]^2 - G[{0}, yw]*G[{0, yv^(-1)}, yw]^2 - 
     G[{1}, yu^(-1)]*G[{0, yv^(-1)}, yw]^2 - G[{1}, yv^(-1)]*
      G[{0, yv^(-1)}, yw]^2 + G[{yv^(-1)}, yw]*G[{0, yv^(-1)}, yw]^2 + 
     (Pi^2*G[{0}, yu^(-1)]*G[{0, 1/(yu*yv)}, yw])/3 + 
     (Pi^2*G[{0}, yv^(-1)]*G[{0, 1/(yu*yv)}, yw])/3 - 
     (Pi^2*G[{0}, yw]*G[{0, 1/(yu*yv)}, yw])/3 - 
     (Pi^2*G[{1}, yu^(-1)]*G[{0, 1/(yu*yv)}, yw])/3 - 
     (Pi^2*G[{1}, yv^(-1)]*G[{0, 1/(yu*yv)}, yw])/3 - 
     2*G[{0}, yu^(-1)]*G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*
      G[{0, 1/(yu*yv)}, yw] - 2*G[{0}, yv^(-1)]*G[{1}, yu^(-1)]*
      G[{1}, yv^(-1)]*G[{0, 1/(yu*yv)}, yw] + 2*G[{0}, yw]*G[{1}, yu^(-1)]*
      G[{1}, yv^(-1)]*G[{0, 1/(yu*yv)}, yw] + 2*G[{1}, yu^(-1)]^2*
      G[{1}, yv^(-1)]*G[{0, 1/(yu*yv)}, yw] + 2*G[{0}, yu^(-1)]*
      G[{1}, yu^(-1)]*G[{yu}, yv^(-1)]*G[{0, 1/(yu*yv)}, yw] + 
     2*G[{0}, yv^(-1)]*G[{1}, yu^(-1)]*G[{yu}, yv^(-1)]*
      G[{0, 1/(yu*yv)}, yw] - 2*G[{0}, yw]*G[{1}, yu^(-1)]*G[{yu}, yv^(-1)]*
      G[{0, 1/(yu*yv)}, yw] - 2*G[{1}, yu^(-1)]^2*G[{yu}, yv^(-1)]*
      G[{0, 1/(yu*yv)}, yw] - 2*G[{0}, yu^(-1)]*G[{1}, yv^(-1)]*
      G[{yu}, yv^(-1)]*G[{0, 1/(yu*yv)}, yw] - 2*G[{0}, yv^(-1)]*
      G[{1}, yv^(-1)]*G[{yu}, yv^(-1)]*G[{0, 1/(yu*yv)}, yw] + 
     2*G[{0}, yw]*G[{1}, yv^(-1)]*G[{yu}, yv^(-1)]*G[{0, 1/(yu*yv)}, yw] + 
     4*G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*G[{yu}, yv^(-1)]*
      G[{0, 1/(yu*yv)}, yw] + 2*G[{1}, yv^(-1)]^2*G[{yu}, yv^(-1)]*
      G[{0, 1/(yu*yv)}, yw] - 2*G[{1}, yu^(-1)]*G[{yu}, yv^(-1)]^2*
      G[{0, 1/(yu*yv)}, yw] + (2*G[{yu}, yv^(-1)]^3*G[{0, 1/(yu*yv)}, yw])/
      3 + 2*G[{0}, yu^(-1)]*G[{1}, yu^(-1)]*G[{yv^(-1)}, yw]*
      G[{0, 1/(yu*yv)}, yw] + 2*G[{0}, yv^(-1)]*G[{1}, yu^(-1)]*
      G[{yv^(-1)}, yw]*G[{0, 1/(yu*yv)}, yw] - 2*G[{0}, yw]*G[{1}, yu^(-1)]*
      G[{yv^(-1)}, yw]*G[{0, 1/(yu*yv)}, yw] - 2*G[{1}, yu^(-1)]^2*
      G[{yv^(-1)}, yw]*G[{0, 1/(yu*yv)}, yw] + 2*G[{0}, yu^(-1)]*
      G[{1}, yv^(-1)]*G[{yv^(-1)}, yw]*G[{0, 1/(yu*yv)}, yw] + 
     2*G[{0}, yv^(-1)]*G[{1}, yv^(-1)]*G[{yv^(-1)}, yw]*
      G[{0, 1/(yu*yv)}, yw] - 2*G[{0}, yw]*G[{1}, yv^(-1)]*G[{yv^(-1)}, yw]*
      G[{0, 1/(yu*yv)}, yw] - 2*G[{1}, yv^(-1)]^2*G[{yv^(-1)}, yw]*
      G[{0, 1/(yu*yv)}, yw] - 2*G[{0}, yu^(-1)]*G[{1}, yw]*G[{yv^(-1)}, yw]*
      G[{0, 1/(yu*yv)}, yw] - 2*G[{0}, yv^(-1)]*G[{1}, yw]*G[{yv^(-1)}, yw]*
      G[{0, 1/(yu*yv)}, yw] + 2*G[{0}, yw]*G[{1}, yw]*G[{yv^(-1)}, yw]*
      G[{0, 1/(yu*yv)}, yw] + 2*G[{1}, yu^(-1)]*G[{1}, yw]*G[{yv^(-1)}, yw]*
      G[{0, 1/(yu*yv)}, yw] + 2*G[{1}, yv^(-1)]*G[{1}, yw]*G[{yv^(-1)}, yw]*
      G[{0, 1/(yu*yv)}, yw] - 4*G[{0}, yu^(-1)]*G[{yu}, yv^(-1)]*
      G[{yv^(-1)}, yw]*G[{0, 1/(yu*yv)}, yw] - 4*G[{0}, yv^(-1)]*
      G[{yu}, yv^(-1)]*G[{yv^(-1)}, yw]*G[{0, 1/(yu*yv)}, yw] + 
     4*G[{0}, yw]*G[{yu}, yv^(-1)]*G[{yv^(-1)}, yw]*G[{0, 1/(yu*yv)}, yw] + 
     4*G[{1}, yv^(-1)]*G[{yu}, yv^(-1)]*G[{yv^(-1)}, yw]*
      G[{0, 1/(yu*yv)}, yw] + 2*G[{yu}, yv^(-1)]^2*G[{yv^(-1)}, yw]*
      G[{0, 1/(yu*yv)}, yw] - 2*G[{1}, yu^(-1)]*G[{yv^(-1)}, yw]^2*
      G[{0, 1/(yu*yv)}, yw] - 2*G[{1}, yw]*G[{yv^(-1)}, yw]^2*
      G[{0, 1/(yu*yv)}, yw] + 2*G[{yu}, yv^(-1)]*G[{yv^(-1)}, yw]^2*
      G[{0, 1/(yu*yv)}, yw] + (2*G[{yv^(-1)}, yw]^3*G[{0, 1/(yu*yv)}, yw])/
      3 - (Pi^2*G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv)}, yw])/3 - 
     2*G[{0}, yu^(-1)]*G[{1}, yu^(-1)]*G[{1/(yu*yv)}, yw]*
      G[{0, 1/(yu*yv)}, yw] - 2*G[{0}, yv^(-1)]*G[{1}, yu^(-1)]*
      G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv)}, yw] + 2*G[{0}, yw]*G[{1}, yu^(-1)]*
      G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv)}, yw] + 2*G[{1}, yu^(-1)]^2*
      G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv)}, yw] + 2*G[{0}, yu^(-1)]*G[{1}, yw]*
      G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv)}, yw] + 2*G[{0}, yv^(-1)]*G[{1}, yw]*
      G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv)}, yw] - 2*G[{0}, yw]*G[{1}, yw]*
      G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv)}, yw] - 2*G[{1}, yu^(-1)]*G[{1}, yw]*
      G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv)}, yw] - 2*G[{1}, yv^(-1)]*G[{1}, yw]*
      G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv)}, yw] + 2*G[{0}, yu^(-1)]*
      G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv)}, yw] + 
     2*G[{0}, yv^(-1)]*G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw]*
      G[{0, 1/(yu*yv)}, yw] - 2*G[{0}, yw]*G[{yu}, yv^(-1)]*
      G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv)}, yw] - 2*G[{yu}, yv^(-1)]^2*
      G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv)}, yw] + 2*G[{0}, yu^(-1)]*
      G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv)}, yw] + 
     2*G[{0}, yv^(-1)]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*
      G[{0, 1/(yu*yv)}, yw] - 2*G[{0}, yw]*G[{yv^(-1)}, yw]*
      G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv)}, yw] - 4*G[{1}, yv^(-1)]*
      G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv)}, yw] - 
     2*G[{yv^(-1)}, yw]^2*G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv)}, yw] - 
     G[{0}, yu^(-1)]*G[{1/(yu*yv)}, yw]^2*G[{0, 1/(yu*yv)}, yw] - 
     G[{0}, yv^(-1)]*G[{1/(yu*yv)}, yw]^2*G[{0, 1/(yu*yv)}, yw] + 
     G[{0}, yw]*G[{1/(yu*yv)}, yw]^2*G[{0, 1/(yu*yv)}, yw] + 
     G[{1}, yu^(-1)]*G[{1/(yu*yv)}, yw]^2*G[{0, 1/(yu*yv)}, yw] + 
     G[{1}, yv^(-1)]*G[{1/(yu*yv)}, yw]^2*G[{0, 1/(yu*yv)}, yw] + 
     G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2*G[{0, 1/(yu*yv)}, yw] + 
     G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2*G[{0, 1/(yu*yv)}, yw] - 
     2*G[{0}, yu^(-1)]*G[{0, 1}, yu^(-1)]*G[{0, 1/(yu*yv)}, yw] - 
     2*G[{0}, yv^(-1)]*G[{0, 1}, yu^(-1)]*G[{0, 1/(yu*yv)}, yw] + 
     2*G[{0}, yw]*G[{0, 1}, yu^(-1)]*G[{0, 1/(yu*yv)}, yw] + 
     2*G[{1}, yu^(-1)]*G[{0, 1}, yu^(-1)]*G[{0, 1/(yu*yv)}, yw] - 
     2*G[{1}, yv^(-1)]*G[{0, 1}, yu^(-1)]*G[{0, 1/(yu*yv)}, yw] + 
     4*G[{yu}, yv^(-1)]*G[{0, 1}, yu^(-1)]*G[{0, 1/(yu*yv)}, yw] + 
     4*G[{yv^(-1)}, yw]*G[{0, 1}, yu^(-1)]*G[{0, 1/(yu*yv)}, yw] - 
     2*G[{1/(yu*yv)}, yw]*G[{0, 1}, yu^(-1)]*G[{0, 1/(yu*yv)}, yw] + 
     2*G[{0}, yu^(-1)]*G[{0, 1}, yv^(-1)]*G[{0, 1/(yu*yv)}, yw] + 
     2*G[{0}, yv^(-1)]*G[{0, 1}, yv^(-1)]*G[{0, 1/(yu*yv)}, yw] - 
     2*G[{0}, yw]*G[{0, 1}, yv^(-1)]*G[{0, 1/(yu*yv)}, yw] - 
     2*G[{1}, yu^(-1)]*G[{0, 1}, yv^(-1)]*G[{0, 1/(yu*yv)}, yw] - 
     2*G[{1}, yv^(-1)]*G[{0, 1}, yv^(-1)]*G[{0, 1/(yu*yv)}, yw] - 
     2*G[{1/(yu*yv)}, yw]*G[{0, 1}, yv^(-1)]*G[{0, 1/(yu*yv)}, yw] + 
     2*G[{0}, yu^(-1)]*G[{0, 1}, yw]*G[{0, 1/(yu*yv)}, yw] + 
     2*G[{0}, yv^(-1)]*G[{0, 1}, yw]*G[{0, 1/(yu*yv)}, yw] - 
     2*G[{0}, yw]*G[{0, 1}, yw]*G[{0, 1/(yu*yv)}, yw] - 
     2*G[{1}, yu^(-1)]*G[{0, 1}, yw]*G[{0, 1/(yu*yv)}, yw] - 
     2*G[{1}, yv^(-1)]*G[{0, 1}, yw]*G[{0, 1/(yu*yv)}, yw] + 
     2*G[{1/(yu*yv)}, yw]*G[{0, 1}, yw]*G[{0, 1/(yu*yv)}, yw] - 
     2*G[{0}, yu^(-1)]*G[{0, yu^(-1)}, yw]*G[{0, 1/(yu*yv)}, yw] - 
     2*G[{0}, yv^(-1)]*G[{0, yu^(-1)}, yw]*G[{0, 1/(yu*yv)}, yw] + 
     2*G[{0}, yw]*G[{0, yu^(-1)}, yw]*G[{0, 1/(yu*yv)}, yw] + 
     2*G[{1}, yu^(-1)]*G[{0, yu^(-1)}, yw]*G[{0, 1/(yu*yv)}, yw] + 
     2*G[{1}, yv^(-1)]*G[{0, yu^(-1)}, yw]*G[{0, 1/(yu*yv)}, yw] - 
     2*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1)}, yw]*G[{0, 1/(yu*yv)}, yw] - 
     2*G[{0}, yu^(-1)]*G[{0, yu}, yv^(-1)]*G[{0, 1/(yu*yv)}, yw] - 
     2*G[{0}, yv^(-1)]*G[{0, yu}, yv^(-1)]*G[{0, 1/(yu*yv)}, yw] + 
     2*G[{0}, yw]*G[{0, yu}, yv^(-1)]*G[{0, 1/(yu*yv)}, yw] + 
     2*G[{1}, yu^(-1)]*G[{0, yu}, yv^(-1)]*G[{0, 1/(yu*yv)}, yw] + 
     2*G[{1}, yv^(-1)]*G[{0, yu}, yv^(-1)]*G[{0, 1/(yu*yv)}, yw] + 
     2*G[{1/(yu*yv)}, yw]*G[{0, yu}, yv^(-1)]*G[{0, 1/(yu*yv)}, yw] - 
     2*G[{0}, yu^(-1)]*G[{0, yv^(-1)}, yw]*G[{0, 1/(yu*yv)}, yw] - 
     2*G[{0}, yv^(-1)]*G[{0, yv^(-1)}, yw]*G[{0, 1/(yu*yv)}, yw] + 
     2*G[{0}, yw]*G[{0, yv^(-1)}, yw]*G[{0, 1/(yu*yv)}, yw] + 
     2*G[{1}, yu^(-1)]*G[{0, yv^(-1)}, yw]*G[{0, 1/(yu*yv)}, yw] + 
     2*G[{1}, yv^(-1)]*G[{0, yv^(-1)}, yw]*G[{0, 1/(yu*yv)}, yw] - 
     2*G[{1/(yu*yv)}, yw]*G[{0, yv^(-1)}, yw]*G[{0, 1/(yu*yv)}, yw] + 
     G[{0}, yu^(-1)]*G[{0, 1/(yu*yv)}, yw]^2 + G[{0}, yv^(-1)]*
      G[{0, 1/(yu*yv)}, yw]^2 - G[{0}, yw]*G[{0, 1/(yu*yv)}, yw]^2 - 
     G[{1}, yu^(-1)]*G[{0, 1/(yu*yv)}, yw]^2 - G[{1}, yv^(-1)]*
      G[{0, 1/(yu*yv)}, yw]^2 + G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv)}, yw]^2 - 
     (Pi^2*G[{yv^(-1)}, yw]*G[{1, yu^(-1)}, yw])/3 + 
     2*G[{0}, yu^(-1)]*G[{1}, yv^(-1)]*G[{yv^(-1)}, yw]*G[{1, yu^(-1)}, yw] + 
     2*G[{0}, yv^(-1)]*G[{1}, yv^(-1)]*G[{yv^(-1)}, yw]*G[{1, yu^(-1)}, yw] - 
     2*G[{0}, yw]*G[{1}, yv^(-1)]*G[{yv^(-1)}, yw]*G[{1, yu^(-1)}, yw] - 
     2*G[{1}, yv^(-1)]^2*G[{yv^(-1)}, yw]*G[{1, yu^(-1)}, yw] + 
     4*G[{0}, yu^(-1)]*G[{1}, yw]*G[{yv^(-1)}, yw]*G[{1, yu^(-1)}, yw] + 
     4*G[{0}, yv^(-1)]*G[{1}, yw]*G[{yv^(-1)}, yw]*G[{1, yu^(-1)}, yw] - 
     4*G[{0}, yw]*G[{1}, yw]*G[{yv^(-1)}, yw]*G[{1, yu^(-1)}, yw] - 
     4*G[{1}, yu^(-1)]*G[{1}, yw]*G[{yv^(-1)}, yw]*G[{1, yu^(-1)}, yw] - 
     4*G[{1}, yv^(-1)]*G[{1}, yw]*G[{yv^(-1)}, yw]*G[{1, yu^(-1)}, yw] - 
     2*G[{0}, yu^(-1)]*G[{yu}, yv^(-1)]*G[{yv^(-1)}, yw]*
      G[{1, yu^(-1)}, yw] - 2*G[{0}, yv^(-1)]*G[{yu}, yv^(-1)]*
      G[{yv^(-1)}, yw]*G[{1, yu^(-1)}, yw] + 2*G[{0}, yw]*G[{yu}, yv^(-1)]*
      G[{yv^(-1)}, yw]*G[{1, yu^(-1)}, yw] + 4*G[{1}, yv^(-1)]*
      G[{yu}, yv^(-1)]*G[{yv^(-1)}, yw]*G[{1, yu^(-1)}, yw] - 
     2*G[{1}, yu^(-1)]*G[{yv^(-1)}, yw]^2*G[{1, yu^(-1)}, yw] - 
     2*G[{1}, yw]*G[{yv^(-1)}, yw]^2*G[{1, yu^(-1)}, yw] + 
     2*G[{yu}, yv^(-1)]*G[{yv^(-1)}, yw]^2*G[{1, yu^(-1)}, yw] + 
     (2*G[{yv^(-1)}, yw]^3*G[{1, yu^(-1)}, yw])/3 + 
     (Pi^2*G[{1/(yu*yv)}, yw]*G[{1, yu^(-1)}, yw])/3 - 
     2*G[{0}, yu^(-1)]*G[{1}, yv^(-1)]*G[{1/(yu*yv)}, yw]*
      G[{1, yu^(-1)}, yw] - 2*G[{0}, yv^(-1)]*G[{1}, yv^(-1)]*
      G[{1/(yu*yv)}, yw]*G[{1, yu^(-1)}, yw] + 2*G[{0}, yw]*G[{1}, yv^(-1)]*
      G[{1/(yu*yv)}, yw]*G[{1, yu^(-1)}, yw] + 2*G[{1}, yv^(-1)]^2*
      G[{1/(yu*yv)}, yw]*G[{1, yu^(-1)}, yw] - 4*G[{0}, yu^(-1)]*G[{1}, yw]*
      G[{1/(yu*yv)}, yw]*G[{1, yu^(-1)}, yw] - 4*G[{0}, yv^(-1)]*G[{1}, yw]*
      G[{1/(yu*yv)}, yw]*G[{1, yu^(-1)}, yw] + 4*G[{0}, yw]*G[{1}, yw]*
      G[{1/(yu*yv)}, yw]*G[{1, yu^(-1)}, yw] + 4*G[{1}, yu^(-1)]*G[{1}, yw]*
      G[{1/(yu*yv)}, yw]*G[{1, yu^(-1)}, yw] + 4*G[{1}, yv^(-1)]*G[{1}, yw]*
      G[{1/(yu*yv)}, yw]*G[{1, yu^(-1)}, yw] + 2*G[{0}, yu^(-1)]*
      G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{1, yu^(-1)}, yw] + 
     2*G[{0}, yv^(-1)]*G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw]*
      G[{1, yu^(-1)}, yw] - 2*G[{0}, yw]*G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw]*
      G[{1, yu^(-1)}, yw] - 4*G[{1}, yv^(-1)]*G[{yu}, yv^(-1)]*
      G[{1/(yu*yv)}, yw]*G[{1, yu^(-1)}, yw] + 4*G[{0}, yu^(-1)]*
      G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{1, yu^(-1)}, yw] + 
     4*G[{0}, yv^(-1)]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*
      G[{1, yu^(-1)}, yw] - 4*G[{0}, yw]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*
      G[{1, yu^(-1)}, yw] - 8*G[{1}, yv^(-1)]*G[{yv^(-1)}, yw]*
      G[{1/(yu*yv)}, yw]*G[{1, yu^(-1)}, yw] - 2*G[{yv^(-1)}, yw]^2*
      G[{1/(yu*yv)}, yw]*G[{1, yu^(-1)}, yw] - 2*G[{0}, yu^(-1)]*
      G[{1/(yu*yv)}, yw]^2*G[{1, yu^(-1)}, yw] - 2*G[{0}, yv^(-1)]*
      G[{1/(yu*yv)}, yw]^2*G[{1, yu^(-1)}, yw] + 
     2*G[{0}, yw]*G[{1/(yu*yv)}, yw]^2*G[{1, yu^(-1)}, yw] + 
     2*G[{1}, yv^(-1)]*G[{1/(yu*yv)}, yw]^2*G[{1, yu^(-1)}, yw] - 
     2*G[{1}, yw]*G[{1/(yu*yv)}, yw]^2*G[{1, yu^(-1)}, yw] + 
     2*G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw]^2*G[{1, yu^(-1)}, yw] + 
     2*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2*G[{1, yu^(-1)}, yw] + 
     2*G[{yv^(-1)}, yw]*G[{0, 1}, yu^(-1)]*G[{1, yu^(-1)}, yw] - 
     2*G[{1/(yu*yv)}, yw]*G[{0, 1}, yu^(-1)]*G[{1, yu^(-1)}, yw] - 
     2*G[{yv^(-1)}, yw]*G[{0, 1}, yv^(-1)]*G[{1, yu^(-1)}, yw] + 
     2*G[{1/(yu*yv)}, yw]*G[{0, 1}, yv^(-1)]*G[{1, yu^(-1)}, yw] + 
     2*G[{yv^(-1)}, yw]*G[{0, 1}, yw]*G[{1, yu^(-1)}, yw] - 
     2*G[{1/(yu*yv)}, yw]*G[{0, 1}, yw]*G[{1, yu^(-1)}, yw] - 
     2*G[{yv^(-1)}, yw]*G[{0, yu^(-1)}, yw]*G[{1, yu^(-1)}, yw] + 
     2*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1)}, yw]*G[{1, yu^(-1)}, yw] + 
     2*G[{yv^(-1)}, yw]*G[{0, yu}, yv^(-1)]*G[{1, yu^(-1)}, yw] - 
     2*G[{1/(yu*yv)}, yw]*G[{0, yu}, yv^(-1)]*G[{1, yu^(-1)}, yw] - 
     2*G[{yv^(-1)}, yw]*G[{0, yv^(-1)}, yw]*G[{1, yu^(-1)}, yw] + 
     2*G[{1/(yu*yv)}, yw]*G[{0, yv^(-1)}, yw]*G[{1, yu^(-1)}, yw] + 
     2*G[{yv^(-1)}, yw]*G[{0, 1/(yu*yv)}, yw]*G[{1, yu^(-1)}, yw] - 
     2*G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv)}, yw]*G[{1, yu^(-1)}, yw] + 
     (Pi^2*G[{0}, yu^(-1)]*G[{1, yu}, yv^(-1)])/3 + 
     (Pi^2*G[{0}, yv^(-1)]*G[{1, yu}, yv^(-1)])/3 - 
     (Pi^2*G[{0}, yw]*G[{1, yu}, yv^(-1)])/3 - 
     (Pi^2*G[{1}, yu^(-1)]*G[{1, yu}, yv^(-1)])/3 - 
     (Pi^2*G[{1}, yv^(-1)]*G[{1, yu}, yv^(-1)])/3 - 
     2*G[{0}, yu^(-1)]*G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*G[{1, yu}, yv^(-1)] - 
     2*G[{0}, yv^(-1)]*G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*G[{1, yu}, yv^(-1)] + 
     2*G[{0}, yw]*G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*G[{1, yu}, yv^(-1)] + 
     2*G[{1}, yu^(-1)]^2*G[{1}, yv^(-1)]*G[{1, yu}, yv^(-1)] + 
     G[{1}, yu^(-1)]*G[{1}, yv^(-1)]^2*G[{1, yu}, yv^(-1)] - 
     2*G[{0}, yu^(-1)]^2*G[{yu}, yv^(-1)]*G[{1, yu}, yv^(-1)] - 
     4*G[{0}, yu^(-1)]*G[{0}, yv^(-1)]*G[{yu}, yv^(-1)]*G[{1, yu}, yv^(-1)] - 
     2*G[{0}, yv^(-1)]^2*G[{yu}, yv^(-1)]*G[{1, yu}, yv^(-1)] + 
     4*G[{0}, yu^(-1)]*G[{0}, yw]*G[{yu}, yv^(-1)]*G[{1, yu}, yv^(-1)] + 
     4*G[{0}, yv^(-1)]*G[{0}, yw]*G[{yu}, yv^(-1)]*G[{1, yu}, yv^(-1)] - 
     2*G[{0}, yw]^2*G[{yu}, yv^(-1)]*G[{1, yu}, yv^(-1)] + 
     6*G[{0}, yu^(-1)]*G[{1}, yu^(-1)]*G[{yu}, yv^(-1)]*G[{1, yu}, yv^(-1)] + 
     6*G[{0}, yv^(-1)]*G[{1}, yu^(-1)]*G[{yu}, yv^(-1)]*G[{1, yu}, yv^(-1)] - 
     6*G[{0}, yw]*G[{1}, yu^(-1)]*G[{yu}, yv^(-1)]*G[{1, yu}, yv^(-1)] - 
     4*G[{1}, yu^(-1)]^2*G[{yu}, yv^(-1)]*G[{1, yu}, yv^(-1)] + 
     2*G[{0}, yu^(-1)]*G[{1}, yv^(-1)]*G[{yu}, yv^(-1)]*G[{1, yu}, yv^(-1)] + 
     2*G[{0}, yv^(-1)]*G[{1}, yv^(-1)]*G[{yu}, yv^(-1)]*G[{1, yu}, yv^(-1)] - 
     2*G[{0}, yw]*G[{1}, yv^(-1)]*G[{yu}, yv^(-1)]*G[{1, yu}, yv^(-1)] + 
     4*G[{0}, yu^(-1)]*G[{yu}, yv^(-1)]^2*G[{1, yu}, yv^(-1)] + 
     4*G[{0}, yv^(-1)]*G[{yu}, yv^(-1)]^2*G[{1, yu}, yv^(-1)] - 
     4*G[{0}, yw]*G[{yu}, yv^(-1)]^2*G[{1, yu}, yv^(-1)] - 
     7*G[{1}, yu^(-1)]*G[{yu}, yv^(-1)]^2*G[{1, yu}, yv^(-1)] - 
     2*G[{yu}, yv^(-1)]^3*G[{1, yu}, yv^(-1)] + 
     (2*Pi^2*G[{yv^(-1)}, yw]*G[{1, yu}, yv^(-1)])/3 - 
     2*G[{0}, yu^(-1)]^2*G[{yv^(-1)}, yw]*G[{1, yu}, yv^(-1)] - 
     4*G[{0}, yu^(-1)]*G[{0}, yv^(-1)]*G[{yv^(-1)}, yw]*G[{1, yu}, yv^(-1)] - 
     2*G[{0}, yv^(-1)]^2*G[{yv^(-1)}, yw]*G[{1, yu}, yv^(-1)] + 
     4*G[{0}, yu^(-1)]*G[{0}, yw]*G[{yv^(-1)}, yw]*G[{1, yu}, yv^(-1)] + 
     4*G[{0}, yv^(-1)]*G[{0}, yw]*G[{yv^(-1)}, yw]*G[{1, yu}, yv^(-1)] - 
     2*G[{0}, yw]^2*G[{yv^(-1)}, yw]*G[{1, yu}, yv^(-1)] + 
     6*G[{0}, yu^(-1)]*G[{1}, yu^(-1)]*G[{yv^(-1)}, yw]*G[{1, yu}, yv^(-1)] + 
     6*G[{0}, yv^(-1)]*G[{1}, yu^(-1)]*G[{yv^(-1)}, yw]*G[{1, yu}, yv^(-1)] - 
     6*G[{0}, yw]*G[{1}, yu^(-1)]*G[{yv^(-1)}, yw]*G[{1, yu}, yv^(-1)] - 
     4*G[{1}, yu^(-1)]^2*G[{yv^(-1)}, yw]*G[{1, yu}, yv^(-1)] + 
     2*G[{0}, yu^(-1)]*G[{1}, yv^(-1)]*G[{yv^(-1)}, yw]*G[{1, yu}, yv^(-1)] + 
     2*G[{0}, yv^(-1)]*G[{1}, yv^(-1)]*G[{yv^(-1)}, yw]*G[{1, yu}, yv^(-1)] - 
     2*G[{0}, yw]*G[{1}, yv^(-1)]*G[{yv^(-1)}, yw]*G[{1, yu}, yv^(-1)] - 
     4*G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*G[{yv^(-1)}, yw]*G[{1, yu}, yv^(-1)] - 
     4*G[{0}, yu^(-1)]*G[{1}, yw]*G[{yv^(-1)}, yw]*G[{1, yu}, yv^(-1)] - 
     4*G[{0}, yv^(-1)]*G[{1}, yw]*G[{yv^(-1)}, yw]*G[{1, yu}, yv^(-1)] + 
     4*G[{0}, yw]*G[{1}, yw]*G[{yv^(-1)}, yw]*G[{1, yu}, yv^(-1)] + 
     4*G[{1}, yu^(-1)]*G[{1}, yw]*G[{yv^(-1)}, yw]*G[{1, yu}, yv^(-1)] + 
     4*G[{1}, yv^(-1)]*G[{1}, yw]*G[{yv^(-1)}, yw]*G[{1, yu}, yv^(-1)] - 
     2*G[{1}, yu^(-1)]*G[{yu}, yv^(-1)]*G[{yv^(-1)}, yw]*
      G[{1, yu}, yv^(-1)] + 4*G[{1}, yv^(-1)]*G[{yu}, yv^(-1)]*
      G[{yv^(-1)}, yw]*G[{1, yu}, yv^(-1)] - 2*G[{1}, yw]*G[{yu}, yv^(-1)]*
      G[{yv^(-1)}, yw]*G[{1, yu}, yv^(-1)] + 2*G[{yu}, yv^(-1)]^2*
      G[{yv^(-1)}, yw]*G[{1, yu}, yv^(-1)] + G[{1}, yu^(-1)]*
      G[{yv^(-1)}, yw]^2*G[{1, yu}, yv^(-1)] - G[{1}, yw]*G[{yv^(-1)}, yw]^2*
      G[{1, yu}, yv^(-1)] + 2*G[{yu}, yv^(-1)]*G[{yv^(-1)}, yw]^2*
      G[{1, yu}, yv^(-1)] + (2*G[{yv^(-1)}, yw]^3*G[{1, yu}, yv^(-1)])/3 + 
     2*G[{0}, yu^(-1)]^2*G[{1/(yu*yv)}, yw]*G[{1, yu}, yv^(-1)] + 
     4*G[{0}, yu^(-1)]*G[{0}, yv^(-1)]*G[{1/(yu*yv)}, yw]*
      G[{1, yu}, yv^(-1)] + 2*G[{0}, yv^(-1)]^2*G[{1/(yu*yv)}, yw]*
      G[{1, yu}, yv^(-1)] - 4*G[{0}, yu^(-1)]*G[{0}, yw]*G[{1/(yu*yv)}, yw]*
      G[{1, yu}, yv^(-1)] - 4*G[{0}, yv^(-1)]*G[{0}, yw]*G[{1/(yu*yv)}, yw]*
      G[{1, yu}, yv^(-1)] + 2*G[{0}, yw]^2*G[{1/(yu*yv)}, yw]*
      G[{1, yu}, yv^(-1)] - 6*G[{0}, yu^(-1)]*G[{1}, yu^(-1)]*
      G[{1/(yu*yv)}, yw]*G[{1, yu}, yv^(-1)] - 6*G[{0}, yv^(-1)]*
      G[{1}, yu^(-1)]*G[{1/(yu*yv)}, yw]*G[{1, yu}, yv^(-1)] + 
     6*G[{0}, yw]*G[{1}, yu^(-1)]*G[{1/(yu*yv)}, yw]*G[{1, yu}, yv^(-1)] + 
     4*G[{1}, yu^(-1)]^2*G[{1/(yu*yv)}, yw]*G[{1, yu}, yv^(-1)] - 
     2*G[{0}, yu^(-1)]*G[{1}, yv^(-1)]*G[{1/(yu*yv)}, yw]*
      G[{1, yu}, yv^(-1)] - 2*G[{0}, yv^(-1)]*G[{1}, yv^(-1)]*
      G[{1/(yu*yv)}, yw]*G[{1, yu}, yv^(-1)] + 2*G[{0}, yw]*G[{1}, yv^(-1)]*
      G[{1/(yu*yv)}, yw]*G[{1, yu}, yv^(-1)] + 4*G[{0}, yu^(-1)]*G[{1}, yw]*
      G[{1/(yu*yv)}, yw]*G[{1, yu}, yv^(-1)] + 4*G[{0}, yv^(-1)]*G[{1}, yw]*
      G[{1/(yu*yv)}, yw]*G[{1, yu}, yv^(-1)] - 4*G[{0}, yw]*G[{1}, yw]*
      G[{1/(yu*yv)}, yw]*G[{1, yu}, yv^(-1)] - 4*G[{1}, yu^(-1)]*G[{1}, yw]*
      G[{1/(yu*yv)}, yw]*G[{1, yu}, yv^(-1)] - 4*G[{1}, yv^(-1)]*G[{1}, yw]*
      G[{1/(yu*yv)}, yw]*G[{1, yu}, yv^(-1)] - 8*G[{0}, yu^(-1)]*
      G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{1, yu}, yv^(-1)] - 
     8*G[{0}, yv^(-1)]*G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw]*
      G[{1, yu}, yv^(-1)] + 8*G[{0}, yw]*G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw]*
      G[{1, yu}, yv^(-1)] + 14*G[{1}, yu^(-1)]*G[{yu}, yv^(-1)]*
      G[{1/(yu*yv)}, yw]*G[{1, yu}, yv^(-1)] - 6*G[{1}, yw]*G[{yu}, yv^(-1)]*
      G[{1/(yu*yv)}, yw]*G[{1, yu}, yv^(-1)] + 6*G[{yu}, yv^(-1)]^2*
      G[{1/(yu*yv)}, yw]*G[{1, yu}, yv^(-1)] + 2*G[{1}, yu^(-1)]*
      G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{1, yu}, yv^(-1)] - 
     4*G[{1}, yv^(-1)]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*
      G[{1, yu}, yv^(-1)] + 2*G[{1}, yw]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*
      G[{1, yu}, yv^(-1)] - 4*G[{yu}, yv^(-1)]*G[{yv^(-1)}, yw]*
      G[{1/(yu*yv)}, yw]*G[{1, yu}, yv^(-1)] - 2*G[{yv^(-1)}, yw]^2*
      G[{1/(yu*yv)}, yw]*G[{1, yu}, yv^(-1)] + 2*G[{0}, yu^(-1)]*
      G[{1/(yu*yv)}, yw]^2*G[{1, yu}, yv^(-1)] + 2*G[{0}, yv^(-1)]*
      G[{1/(yu*yv)}, yw]^2*G[{1, yu}, yv^(-1)] - 
     2*G[{0}, yw]*G[{1/(yu*yv)}, yw]^2*G[{1, yu}, yv^(-1)] - 
     5*G[{1}, yu^(-1)]*G[{1/(yu*yv)}, yw]^2*G[{1, yu}, yv^(-1)] + 
     2*G[{1}, yv^(-1)]*G[{1/(yu*yv)}, yw]^2*G[{1, yu}, yv^(-1)] + 
     3*G[{1}, yw]*G[{1/(yu*yv)}, yw]^2*G[{1, yu}, yv^(-1)] - 
     2*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2*G[{1, yu}, yv^(-1)] - 
     3*G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw]^2*G[{1, yu}, yv^(-1)] + 
     3*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2*G[{1, yu}, yv^(-1)] - 
     2*G[{0}, yu^(-1)]*G[{0, 1}, yu^(-1)]*G[{1, yu}, yv^(-1)] - 
     2*G[{0}, yv^(-1)]*G[{0, 1}, yu^(-1)]*G[{1, yu}, yv^(-1)] + 
     2*G[{0}, yw]*G[{0, 1}, yu^(-1)]*G[{1, yu}, yv^(-1)] + 
     2*G[{1}, yu^(-1)]*G[{0, 1}, yu^(-1)]*G[{1, yu}, yv^(-1)] + 
     4*G[{yu}, yv^(-1)]*G[{0, 1}, yu^(-1)]*G[{1, yu}, yv^(-1)] - 
     4*G[{1/(yu*yv)}, yw]*G[{0, 1}, yu^(-1)]*G[{1, yu}, yv^(-1)] + 
     2*G[{0}, yu^(-1)]*G[{0, 1}, yv^(-1)]*G[{1, yu}, yv^(-1)] + 
     2*G[{0}, yv^(-1)]*G[{0, 1}, yv^(-1)]*G[{1, yu}, yv^(-1)] - 
     2*G[{0}, yw]*G[{0, 1}, yv^(-1)]*G[{1, yu}, yv^(-1)] - 
     2*G[{1}, yu^(-1)]*G[{0, 1}, yv^(-1)]*G[{1, yu}, yv^(-1)] - 
     2*G[{1}, yv^(-1)]*G[{0, 1}, yv^(-1)]*G[{1, yu}, yv^(-1)] - 
     4*G[{yu}, yv^(-1)]*G[{0, 1}, yv^(-1)]*G[{1, yu}, yv^(-1)] + 
     4*G[{1/(yu*yv)}, yw]*G[{0, 1}, yv^(-1)]*G[{1, yu}, yv^(-1)] + 
     4*G[{yu}, yv^(-1)]*G[{0, 1}, yw]*G[{1, yu}, yv^(-1)] - 
     4*G[{yv^(-1)}, yw]*G[{0, 1}, yw]*G[{1, yu}, yv^(-1)] + 
     4*G[{yv^(-1)}, yw]*G[{0, yu^(-1)}, yw]*G[{1, yu}, yv^(-1)] - 
     2*G[{0}, yu^(-1)]*G[{0, yu}, yv^(-1)]*G[{1, yu}, yv^(-1)] - 
     2*G[{0}, yv^(-1)]*G[{0, yu}, yv^(-1)]*G[{1, yu}, yv^(-1)] + 
     2*G[{0}, yw]*G[{0, yu}, yv^(-1)]*G[{1, yu}, yv^(-1)] + 
     2*G[{1}, yu^(-1)]*G[{0, yu}, yv^(-1)]*G[{1, yu}, yv^(-1)] + 
     2*G[{1}, yv^(-1)]*G[{0, yu}, yv^(-1)]*G[{1, yu}, yv^(-1)] + 
     4*G[{yu}, yv^(-1)]*G[{0, yu}, yv^(-1)]*G[{1, yu}, yv^(-1)] - 
     4*G[{1/(yu*yv)}, yw]*G[{0, yu}, yv^(-1)]*G[{1, yu}, yv^(-1)] - 
     4*G[{0}, yu^(-1)]*G[{0, yv^(-1)}, yw]*G[{1, yu}, yv^(-1)] - 
     4*G[{0}, yv^(-1)]*G[{0, yv^(-1)}, yw]*G[{1, yu}, yv^(-1)] + 
     4*G[{0}, yw]*G[{0, yv^(-1)}, yw]*G[{1, yu}, yv^(-1)] + 
     4*G[{1}, yu^(-1)]*G[{0, yv^(-1)}, yw]*G[{1, yu}, yv^(-1)] + 
     4*G[{1}, yv^(-1)]*G[{0, yv^(-1)}, yw]*G[{1, yu}, yv^(-1)] + 
     4*G[{yv^(-1)}, yw]*G[{0, yv^(-1)}, yw]*G[{1, yu}, yv^(-1)] + 
     4*G[{0}, yu^(-1)]*G[{0, 1/(yu*yv)}, yw]*G[{1, yu}, yv^(-1)] + 
     4*G[{0}, yv^(-1)]*G[{0, 1/(yu*yv)}, yw]*G[{1, yu}, yv^(-1)] - 
     4*G[{0}, yw]*G[{0, 1/(yu*yv)}, yw]*G[{1, yu}, yv^(-1)] - 
     4*G[{1}, yu^(-1)]*G[{0, 1/(yu*yv)}, yw]*G[{1, yu}, yv^(-1)] - 
     4*G[{1}, yv^(-1)]*G[{0, 1/(yu*yv)}, yw]*G[{1, yu}, yv^(-1)] - 
     4*G[{yu}, yv^(-1)]*G[{0, 1/(yu*yv)}, yw]*G[{1, yu}, yv^(-1)] - 
     4*G[{yv^(-1)}, yw]*G[{0, 1/(yu*yv)}, yw]*G[{1, yu}, yv^(-1)] - 
     4*G[{yv^(-1)}, yw]*G[{1, yu^(-1)}, yw]*G[{1, yu}, yv^(-1)] + 
     4*G[{1/(yu*yv)}, yw]*G[{1, yu^(-1)}, yw]*G[{1, yu}, yv^(-1)] + 
     2*G[{0}, yu^(-1)]*G[{1, yu}, yv^(-1)]^2 + 2*G[{0}, yv^(-1)]*
      G[{1, yu}, yv^(-1)]^2 - 2*G[{0}, yw]*G[{1, yu}, yv^(-1)]^2 - 
     2*G[{1}, yu^(-1)]*G[{1, yu}, yv^(-1)]^2 - 2*G[{1}, yv^(-1)]*
      G[{1, yu}, yv^(-1)]^2 - 4*G[{yu}, yv^(-1)]*G[{1, yu}, yv^(-1)]^2 + 
     4*G[{1/(yu*yv)}, yw]*G[{1, yu}, yv^(-1)]^2 + 
     (Pi^2*G[{0}, yu^(-1)]*G[{1, yv^(-1)}, yw])/3 + 
     (Pi^2*G[{0}, yv^(-1)]*G[{1, yv^(-1)}, yw])/3 - 
     (Pi^2*G[{0}, yw]*G[{1, yv^(-1)}, yw])/3 - 
     (Pi^2*G[{1}, yu^(-1)]*G[{1, yv^(-1)}, yw])/3 - 
     (Pi^2*G[{1}, yv^(-1)]*G[{1, yv^(-1)}, yw])/3 - 
     2*G[{0}, yu^(-1)]*G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*G[{1, yv^(-1)}, yw] - 
     2*G[{0}, yv^(-1)]*G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*G[{1, yv^(-1)}, yw] + 
     2*G[{0}, yw]*G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*G[{1, yv^(-1)}, yw] + 
     2*G[{1}, yu^(-1)]^2*G[{1}, yv^(-1)]*G[{1, yv^(-1)}, yw] + 
     3*G[{1}, yu^(-1)]*G[{1}, yv^(-1)]^2*G[{1, yv^(-1)}, yw] + 
     2*G[{0}, yu^(-1)]*G[{1}, yu^(-1)]*G[{yu}, yv^(-1)]*G[{1, yv^(-1)}, yw] + 
     2*G[{0}, yv^(-1)]*G[{1}, yu^(-1)]*G[{yu}, yv^(-1)]*G[{1, yv^(-1)}, yw] - 
     2*G[{0}, yw]*G[{1}, yu^(-1)]*G[{yu}, yv^(-1)]*G[{1, yv^(-1)}, yw] - 
     2*G[{1}, yu^(-1)]^2*G[{yu}, yv^(-1)]*G[{1, yv^(-1)}, yw] - 
     2*G[{0}, yu^(-1)]*G[{1}, yv^(-1)]*G[{yu}, yv^(-1)]*G[{1, yv^(-1)}, yw] - 
     2*G[{0}, yv^(-1)]*G[{1}, yv^(-1)]*G[{yu}, yv^(-1)]*G[{1, yv^(-1)}, yw] + 
     2*G[{0}, yw]*G[{1}, yv^(-1)]*G[{yu}, yv^(-1)]*G[{1, yv^(-1)}, yw] - 
     2*G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*G[{yu}, yv^(-1)]*G[{1, yv^(-1)}, yw] + 
     2*G[{1}, yv^(-1)]^2*G[{yu}, yv^(-1)]*G[{1, yv^(-1)}, yw] + 
     G[{1}, yu^(-1)]*G[{yu}, yv^(-1)]^2*G[{1, yv^(-1)}, yw] - 
     (G[{yu}, yv^(-1)]^3*G[{1, yv^(-1)}, yw])/3 - Pi^2*G[{yv^(-1)}, yw]*
      G[{1, yv^(-1)}, yw] + 2*G[{0}, yu^(-1)]^2*G[{yv^(-1)}, yw]*
      G[{1, yv^(-1)}, yw] + 4*G[{0}, yu^(-1)]*G[{0}, yv^(-1)]*
      G[{yv^(-1)}, yw]*G[{1, yv^(-1)}, yw] + 2*G[{0}, yv^(-1)]^2*
      G[{yv^(-1)}, yw]*G[{1, yv^(-1)}, yw] - 4*G[{0}, yu^(-1)]*G[{0}, yw]*
      G[{yv^(-1)}, yw]*G[{1, yv^(-1)}, yw] - 4*G[{0}, yv^(-1)]*G[{0}, yw]*
      G[{yv^(-1)}, yw]*G[{1, yv^(-1)}, yw] + 2*G[{0}, yw]^2*G[{yv^(-1)}, yw]*
      G[{1, yv^(-1)}, yw] - 2*G[{0}, yu^(-1)]*G[{1}, yu^(-1)]*
      G[{yv^(-1)}, yw]*G[{1, yv^(-1)}, yw] - 2*G[{0}, yv^(-1)]*
      G[{1}, yu^(-1)]*G[{yv^(-1)}, yw]*G[{1, yv^(-1)}, yw] + 
     2*G[{0}, yw]*G[{1}, yu^(-1)]*G[{yv^(-1)}, yw]*G[{1, yv^(-1)}, yw] - 
     4*G[{0}, yu^(-1)]*G[{1}, yv^(-1)]*G[{yv^(-1)}, yw]*G[{1, yv^(-1)}, yw] - 
     4*G[{0}, yv^(-1)]*G[{1}, yv^(-1)]*G[{yv^(-1)}, yw]*G[{1, yv^(-1)}, yw] + 
     4*G[{0}, yw]*G[{1}, yv^(-1)]*G[{yv^(-1)}, yw]*G[{1, yv^(-1)}, yw] + 
     4*G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*G[{yv^(-1)}, yw]*G[{1, yv^(-1)}, yw] + 
     2*G[{1}, yv^(-1)]^2*G[{yv^(-1)}, yw]*G[{1, yv^(-1)}, yw] + 
     8*G[{0}, yu^(-1)]*G[{1}, yw]*G[{yv^(-1)}, yw]*G[{1, yv^(-1)}, yw] + 
     8*G[{0}, yv^(-1)]*G[{1}, yw]*G[{yv^(-1)}, yw]*G[{1, yv^(-1)}, yw] - 
     8*G[{0}, yw]*G[{1}, yw]*G[{yv^(-1)}, yw]*G[{1, yv^(-1)}, yw] - 
     8*G[{1}, yu^(-1)]*G[{1}, yw]*G[{yv^(-1)}, yw]*G[{1, yv^(-1)}, yw] - 
     8*G[{1}, yv^(-1)]*G[{1}, yw]*G[{yv^(-1)}, yw]*G[{1, yv^(-1)}, yw] - 
     2*G[{0}, yu^(-1)]*G[{yu}, yv^(-1)]*G[{yv^(-1)}, yw]*
      G[{1, yv^(-1)}, yw] - 2*G[{0}, yv^(-1)]*G[{yu}, yv^(-1)]*
      G[{yv^(-1)}, yw]*G[{1, yv^(-1)}, yw] + 2*G[{0}, yw]*G[{yu}, yv^(-1)]*
      G[{yv^(-1)}, yw]*G[{1, yv^(-1)}, yw] + 4*G[{1}, yv^(-1)]*
      G[{yu}, yv^(-1)]*G[{yv^(-1)}, yw]*G[{1, yv^(-1)}, yw] - 
     3*G[{1}, yu^(-1)]*G[{yv^(-1)}, yw]^2*G[{1, yv^(-1)}, yw] - 
     3*G[{1}, yw]*G[{yv^(-1)}, yw]^2*G[{1, yv^(-1)}, yw] + 
     3*G[{yu}, yv^(-1)]*G[{yv^(-1)}, yw]^2*G[{1, yv^(-1)}, yw] + 
     (Pi^2*G[{1/(yu*yv)}, yw]*G[{1, yv^(-1)}, yw])/3 - 
     2*G[{0}, yu^(-1)]^2*G[{1/(yu*yv)}, yw]*G[{1, yv^(-1)}, yw] - 
     4*G[{0}, yu^(-1)]*G[{0}, yv^(-1)]*G[{1/(yu*yv)}, yw]*
      G[{1, yv^(-1)}, yw] - 2*G[{0}, yv^(-1)]^2*G[{1/(yu*yv)}, yw]*
      G[{1, yv^(-1)}, yw] + 4*G[{0}, yu^(-1)]*G[{0}, yw]*G[{1/(yu*yv)}, yw]*
      G[{1, yv^(-1)}, yw] + 4*G[{0}, yv^(-1)]*G[{0}, yw]*G[{1/(yu*yv)}, yw]*
      G[{1, yv^(-1)}, yw] - 2*G[{0}, yw]^2*G[{1/(yu*yv)}, yw]*
      G[{1, yv^(-1)}, yw] + 2*G[{0}, yu^(-1)]*G[{1}, yu^(-1)]*
      G[{1/(yu*yv)}, yw]*G[{1, yv^(-1)}, yw] + 2*G[{0}, yv^(-1)]*
      G[{1}, yu^(-1)]*G[{1/(yu*yv)}, yw]*G[{1, yv^(-1)}, yw] - 
     2*G[{0}, yw]*G[{1}, yu^(-1)]*G[{1/(yu*yv)}, yw]*G[{1, yv^(-1)}, yw] + 
     4*G[{0}, yu^(-1)]*G[{1}, yv^(-1)]*G[{1/(yu*yv)}, yw]*
      G[{1, yv^(-1)}, yw] + 4*G[{0}, yv^(-1)]*G[{1}, yv^(-1)]*
      G[{1/(yu*yv)}, yw]*G[{1, yv^(-1)}, yw] - 4*G[{0}, yw]*G[{1}, yv^(-1)]*
      G[{1/(yu*yv)}, yw]*G[{1, yv^(-1)}, yw] - 2*G[{1}, yv^(-1)]^2*
      G[{1/(yu*yv)}, yw]*G[{1, yv^(-1)}, yw] - 4*G[{0}, yu^(-1)]*G[{1}, yw]*
      G[{1/(yu*yv)}, yw]*G[{1, yv^(-1)}, yw] - 4*G[{0}, yv^(-1)]*G[{1}, yw]*
      G[{1/(yu*yv)}, yw]*G[{1, yv^(-1)}, yw] + 4*G[{0}, yw]*G[{1}, yw]*
      G[{1/(yu*yv)}, yw]*G[{1, yv^(-1)}, yw] + 4*G[{1}, yu^(-1)]*G[{1}, yw]*
      G[{1/(yu*yv)}, yw]*G[{1, yv^(-1)}, yw] + 4*G[{1}, yv^(-1)]*G[{1}, yw]*
      G[{1/(yu*yv)}, yw]*G[{1, yv^(-1)}, yw] + 2*G[{0}, yu^(-1)]*
      G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{1, yv^(-1)}, yw] + 
     2*G[{0}, yv^(-1)]*G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw]*
      G[{1, yv^(-1)}, yw] - 2*G[{0}, yw]*G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw]*
      G[{1, yv^(-1)}, yw] - 4*G[{1}, yu^(-1)]*G[{yu}, yv^(-1)]*
      G[{1/(yu*yv)}, yw]*G[{1, yv^(-1)}, yw] + 4*G[{0}, yu^(-1)]*
      G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{1, yv^(-1)}, yw] + 
     4*G[{0}, yv^(-1)]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*
      G[{1, yv^(-1)}, yw] - 4*G[{0}, yw]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*
      G[{1, yv^(-1)}, yw] - 2*G[{1}, yu^(-1)]*G[{yv^(-1)}, yw]*
      G[{1/(yu*yv)}, yw]*G[{1, yv^(-1)}, yw] - 4*G[{1}, yv^(-1)]*
      G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{1, yv^(-1)}, yw] + 
     2*G[{1}, yw]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{1, yv^(-1)}, yw] - 
     2*G[{yu}, yv^(-1)]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*
      G[{1, yv^(-1)}, yw] - 4*G[{0}, yu^(-1)]*G[{1/(yu*yv)}, yw]^2*
      G[{1, yv^(-1)}, yw] - 4*G[{0}, yv^(-1)]*G[{1/(yu*yv)}, yw]^2*
      G[{1, yv^(-1)}, yw] + 4*G[{0}, yw]*G[{1/(yu*yv)}, yw]^2*
      G[{1, yv^(-1)}, yw] + 5*G[{1}, yu^(-1)]*G[{1/(yu*yv)}, yw]^2*
      G[{1, yv^(-1)}, yw] - 3*G[{1}, yw]*G[{1/(yu*yv)}, yw]^2*
      G[{1, yv^(-1)}, yw] + 2*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2*
      G[{1, yv^(-1)}, yw] + 3*G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw]^2*
      G[{1, yv^(-1)}, yw] - G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2*
      G[{1, yv^(-1)}, yw] - 2*G[{0}, yu^(-1)]*G[{0, 1}, yu^(-1)]*
      G[{1, yv^(-1)}, yw] - 2*G[{0}, yv^(-1)]*G[{0, 1}, yu^(-1)]*
      G[{1, yv^(-1)}, yw] + 2*G[{0}, yw]*G[{0, 1}, yu^(-1)]*
      G[{1, yv^(-1)}, yw] + 2*G[{1}, yu^(-1)]*G[{0, 1}, yu^(-1)]*
      G[{1, yv^(-1)}, yw] + 4*G[{1}, yv^(-1)]*G[{0, 1}, yu^(-1)]*
      G[{1, yv^(-1)}, yw] - 2*G[{yu}, yv^(-1)]*G[{0, 1}, yu^(-1)]*
      G[{1, yv^(-1)}, yw] + 2*G[{yv^(-1)}, yw]*G[{0, 1}, yu^(-1)]*
      G[{1, yv^(-1)}, yw] + 2*G[{1/(yu*yv)}, yw]*G[{0, 1}, yu^(-1)]*
      G[{1, yv^(-1)}, yw] + 2*G[{0}, yu^(-1)]*G[{0, 1}, yv^(-1)]*
      G[{1, yv^(-1)}, yw] + 2*G[{0}, yv^(-1)]*G[{0, 1}, yv^(-1)]*
      G[{1, yv^(-1)}, yw] - 2*G[{0}, yw]*G[{0, 1}, yv^(-1)]*
      G[{1, yv^(-1)}, yw] - 2*G[{1}, yu^(-1)]*G[{0, 1}, yv^(-1)]*
      G[{1, yv^(-1)}, yw] - 2*G[{1}, yv^(-1)]*G[{0, 1}, yv^(-1)]*
      G[{1, yv^(-1)}, yw] - 2*G[{yv^(-1)}, yw]*G[{0, 1}, yv^(-1)]*
      G[{1, yv^(-1)}, yw] - 2*G[{1/(yu*yv)}, yw]*G[{0, 1}, yv^(-1)]*
      G[{1, yv^(-1)}, yw] + 2*G[{0}, yu^(-1)]*G[{0, 1}, yw]*
      G[{1, yv^(-1)}, yw] + 2*G[{0}, yv^(-1)]*G[{0, 1}, yw]*
      G[{1, yv^(-1)}, yw] - 2*G[{0}, yw]*G[{0, 1}, yw]*G[{1, yv^(-1)}, yw] - 
     2*G[{1}, yu^(-1)]*G[{0, 1}, yw]*G[{1, yv^(-1)}, yw] - 
     2*G[{1}, yv^(-1)]*G[{0, 1}, yw]*G[{1, yv^(-1)}, yw] + 
     6*G[{yv^(-1)}, yw]*G[{0, 1}, yw]*G[{1, yv^(-1)}, yw] - 
     2*G[{1/(yu*yv)}, yw]*G[{0, 1}, yw]*G[{1, yv^(-1)}, yw] - 
     2*G[{0}, yu^(-1)]*G[{0, yu^(-1)}, yw]*G[{1, yv^(-1)}, yw] - 
     2*G[{0}, yv^(-1)]*G[{0, yu^(-1)}, yw]*G[{1, yv^(-1)}, yw] + 
     2*G[{0}, yw]*G[{0, yu^(-1)}, yw]*G[{1, yv^(-1)}, yw] + 
     2*G[{1}, yu^(-1)]*G[{0, yu^(-1)}, yw]*G[{1, yv^(-1)}, yw] + 
     2*G[{1}, yv^(-1)]*G[{0, yu^(-1)}, yw]*G[{1, yv^(-1)}, yw] - 
     6*G[{yv^(-1)}, yw]*G[{0, yu^(-1)}, yw]*G[{1, yv^(-1)}, yw] + 
     2*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1)}, yw]*G[{1, yv^(-1)}, yw] - 
     2*G[{0}, yu^(-1)]*G[{0, yu}, yv^(-1)]*G[{1, yv^(-1)}, yw] - 
     2*G[{0}, yv^(-1)]*G[{0, yu}, yv^(-1)]*G[{1, yv^(-1)}, yw] + 
     2*G[{0}, yw]*G[{0, yu}, yv^(-1)]*G[{1, yv^(-1)}, yw] + 
     2*G[{1}, yu^(-1)]*G[{0, yu}, yv^(-1)]*G[{1, yv^(-1)}, yw] + 
     2*G[{1}, yv^(-1)]*G[{0, yu}, yv^(-1)]*G[{1, yv^(-1)}, yw] + 
     2*G[{yv^(-1)}, yw]*G[{0, yu}, yv^(-1)]*G[{1, yv^(-1)}, yw] + 
     2*G[{1/(yu*yv)}, yw]*G[{0, yu}, yv^(-1)]*G[{1, yv^(-1)}, yw] - 
     2*G[{0}, yu^(-1)]*G[{0, yv^(-1)}, yw]*G[{1, yv^(-1)}, yw] - 
     2*G[{0}, yv^(-1)]*G[{0, yv^(-1)}, yw]*G[{1, yv^(-1)}, yw] + 
     2*G[{0}, yw]*G[{0, yv^(-1)}, yw]*G[{1, yv^(-1)}, yw] + 
     2*G[{1}, yu^(-1)]*G[{0, yv^(-1)}, yw]*G[{1, yv^(-1)}, yw] + 
     2*G[{1}, yv^(-1)]*G[{0, yv^(-1)}, yw]*G[{1, yv^(-1)}, yw] - 
     6*G[{yv^(-1)}, yw]*G[{0, yv^(-1)}, yw]*G[{1, yv^(-1)}, yw] + 
     2*G[{1/(yu*yv)}, yw]*G[{0, yv^(-1)}, yw]*G[{1, yv^(-1)}, yw] + 
     2*G[{0}, yu^(-1)]*G[{0, 1/(yu*yv)}, yw]*G[{1, yv^(-1)}, yw] + 
     2*G[{0}, yv^(-1)]*G[{0, 1/(yu*yv)}, yw]*G[{1, yv^(-1)}, yw] - 
     2*G[{0}, yw]*G[{0, 1/(yu*yv)}, yw]*G[{1, yv^(-1)}, yw] - 
     2*G[{1}, yu^(-1)]*G[{0, 1/(yu*yv)}, yw]*G[{1, yv^(-1)}, yw] - 
     2*G[{1}, yv^(-1)]*G[{0, 1/(yu*yv)}, yw]*G[{1, yv^(-1)}, yw] + 
     6*G[{yv^(-1)}, yw]*G[{0, 1/(yu*yv)}, yw]*G[{1, yv^(-1)}, yw] - 
     2*G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv)}, yw]*G[{1, yv^(-1)}, yw] + 
     4*G[{0}, yu^(-1)]*G[{1, yu^(-1)}, yw]*G[{1, yv^(-1)}, yw] + 
     4*G[{0}, yv^(-1)]*G[{1, yu^(-1)}, yw]*G[{1, yv^(-1)}, yw] - 
     4*G[{0}, yw]*G[{1, yu^(-1)}, yw]*G[{1, yv^(-1)}, yw] - 
     4*G[{1}, yu^(-1)]*G[{1, yu^(-1)}, yw]*G[{1, yv^(-1)}, yw] - 
     4*G[{1}, yv^(-1)]*G[{1, yu^(-1)}, yw]*G[{1, yv^(-1)}, yw] + 
     4*G[{yv^(-1)}, yw]*G[{1, yu^(-1)}, yw]*G[{1, yv^(-1)}, yw] - 
     4*G[{1/(yu*yv)}, yw]*G[{1, yu^(-1)}, yw]*G[{1, yv^(-1)}, yw] + 
     4*G[{0}, yu^(-1)]*G[{1, yu}, yv^(-1)]*G[{1, yv^(-1)}, yw] + 
     4*G[{0}, yv^(-1)]*G[{1, yu}, yv^(-1)]*G[{1, yv^(-1)}, yw] - 
     4*G[{0}, yw]*G[{1, yu}, yv^(-1)]*G[{1, yv^(-1)}, yw] - 
     4*G[{1}, yu^(-1)]*G[{1, yu}, yv^(-1)]*G[{1, yv^(-1)}, yw] - 
     4*G[{1}, yv^(-1)]*G[{1, yu}, yv^(-1)]*G[{1, yv^(-1)}, yw] + 
     2*G[{yu}, yv^(-1)]*G[{1, yu}, yv^(-1)]*G[{1, yv^(-1)}, yw] - 
     4*G[{yv^(-1)}, yw]*G[{1, yu}, yv^(-1)]*G[{1, yv^(-1)}, yw] - 
     4*G[{1/(yu*yv)}, yw]*G[{1, yu}, yv^(-1)]*G[{1, yv^(-1)}, yw] + 
     4*G[{yv^(-1)}, yw]*G[{1, yv^(-1)}, yw]^2 - 
     (Pi^2*G[{0}, yu^(-1)]*G[{1, 1/(yu*yv)}, yw])/3 - 
     (Pi^2*G[{0}, yv^(-1)]*G[{1, 1/(yu*yv)}, yw])/3 + 
     (Pi^2*G[{0}, yw]*G[{1, 1/(yu*yv)}, yw])/3 + 
     (Pi^2*G[{1}, yu^(-1)]*G[{1, 1/(yu*yv)}, yw])/3 + 
     (Pi^2*G[{1}, yv^(-1)]*G[{1, 1/(yu*yv)}, yw])/3 + 
     2*G[{0}, yu^(-1)]*G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*
      G[{1, 1/(yu*yv)}, yw] + 2*G[{0}, yv^(-1)]*G[{1}, yu^(-1)]*
      G[{1}, yv^(-1)]*G[{1, 1/(yu*yv)}, yw] - 2*G[{0}, yw]*G[{1}, yu^(-1)]*
      G[{1}, yv^(-1)]*G[{1, 1/(yu*yv)}, yw] - 2*G[{1}, yu^(-1)]^2*
      G[{1}, yv^(-1)]*G[{1, 1/(yu*yv)}, yw] + G[{1}, yu^(-1)]*
      G[{1}, yv^(-1)]^2*G[{1, 1/(yu*yv)}, yw] - 2*G[{0}, yu^(-1)]*
      G[{1}, yu^(-1)]*G[{yu}, yv^(-1)]*G[{1, 1/(yu*yv)}, yw] - 
     2*G[{0}, yv^(-1)]*G[{1}, yu^(-1)]*G[{yu}, yv^(-1)]*
      G[{1, 1/(yu*yv)}, yw] + 2*G[{0}, yw]*G[{1}, yu^(-1)]*G[{yu}, yv^(-1)]*
      G[{1, 1/(yu*yv)}, yw] + 2*G[{1}, yu^(-1)]^2*G[{yu}, yv^(-1)]*
      G[{1, 1/(yu*yv)}, yw] + 2*G[{0}, yu^(-1)]*G[{1}, yv^(-1)]*
      G[{yu}, yv^(-1)]*G[{1, 1/(yu*yv)}, yw] + 2*G[{0}, yv^(-1)]*
      G[{1}, yv^(-1)]*G[{yu}, yv^(-1)]*G[{1, 1/(yu*yv)}, yw] - 
     2*G[{0}, yw]*G[{1}, yv^(-1)]*G[{yu}, yv^(-1)]*G[{1, 1/(yu*yv)}, yw] - 
     6*G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*G[{yu}, yv^(-1)]*
      G[{1, 1/(yu*yv)}, yw] - 2*G[{1}, yv^(-1)]^2*G[{yu}, yv^(-1)]*
      G[{1, 1/(yu*yv)}, yw] + 3*G[{1}, yu^(-1)]*G[{yu}, yv^(-1)]^2*
      G[{1, 1/(yu*yv)}, yw] - G[{yu}, yv^(-1)]^3*G[{1, 1/(yu*yv)}, yw] - 
     2*G[{0}, yu^(-1)]^2*G[{yv^(-1)}, yw]*G[{1, 1/(yu*yv)}, yw] - 
     4*G[{0}, yu^(-1)]*G[{0}, yv^(-1)]*G[{yv^(-1)}, yw]*
      G[{1, 1/(yu*yv)}, yw] - 2*G[{0}, yv^(-1)]^2*G[{yv^(-1)}, yw]*
      G[{1, 1/(yu*yv)}, yw] + 4*G[{0}, yu^(-1)]*G[{0}, yw]*G[{yv^(-1)}, yw]*
      G[{1, 1/(yu*yv)}, yw] + 4*G[{0}, yv^(-1)]*G[{0}, yw]*G[{yv^(-1)}, yw]*
      G[{1, 1/(yu*yv)}, yw] - 2*G[{0}, yw]^2*G[{yv^(-1)}, yw]*
      G[{1, 1/(yu*yv)}, yw] + 2*G[{0}, yu^(-1)]*G[{1}, yu^(-1)]*
      G[{yv^(-1)}, yw]*G[{1, 1/(yu*yv)}, yw] + 2*G[{0}, yv^(-1)]*
      G[{1}, yu^(-1)]*G[{yv^(-1)}, yw]*G[{1, 1/(yu*yv)}, yw] - 
     2*G[{0}, yw]*G[{1}, yu^(-1)]*G[{yv^(-1)}, yw]*G[{1, 1/(yu*yv)}, yw] + 
     2*G[{0}, yu^(-1)]*G[{1}, yv^(-1)]*G[{yv^(-1)}, yw]*
      G[{1, 1/(yu*yv)}, yw] + 2*G[{0}, yv^(-1)]*G[{1}, yv^(-1)]*
      G[{yv^(-1)}, yw]*G[{1, 1/(yu*yv)}, yw] - 2*G[{0}, yw]*G[{1}, yv^(-1)]*
      G[{yv^(-1)}, yw]*G[{1, 1/(yu*yv)}, yw] - 4*G[{1}, yu^(-1)]*
      G[{1}, yv^(-1)]*G[{yv^(-1)}, yw]*G[{1, 1/(yu*yv)}, yw] - 
     4*G[{0}, yu^(-1)]*G[{1}, yw]*G[{yv^(-1)}, yw]*G[{1, 1/(yu*yv)}, yw] - 
     4*G[{0}, yv^(-1)]*G[{1}, yw]*G[{yv^(-1)}, yw]*G[{1, 1/(yu*yv)}, yw] + 
     4*G[{0}, yw]*G[{1}, yw]*G[{yv^(-1)}, yw]*G[{1, 1/(yu*yv)}, yw] + 
     4*G[{1}, yu^(-1)]*G[{1}, yw]*G[{yv^(-1)}, yw]*G[{1, 1/(yu*yv)}, yw] + 
     4*G[{1}, yv^(-1)]*G[{1}, yw]*G[{yv^(-1)}, yw]*G[{1, 1/(yu*yv)}, yw] + 
     4*G[{0}, yu^(-1)]*G[{yu}, yv^(-1)]*G[{yv^(-1)}, yw]*
      G[{1, 1/(yu*yv)}, yw] + 4*G[{0}, yv^(-1)]*G[{yu}, yv^(-1)]*
      G[{yv^(-1)}, yw]*G[{1, 1/(yu*yv)}, yw] - 4*G[{0}, yw]*G[{yu}, yv^(-1)]*
      G[{yv^(-1)}, yw]*G[{1, 1/(yu*yv)}, yw] - 4*G[{yu}, yv^(-1)]^2*
      G[{yv^(-1)}, yw]*G[{1, 1/(yu*yv)}, yw] + G[{1}, yu^(-1)]*
      G[{yv^(-1)}, yw]^2*G[{1, 1/(yu*yv)}, yw] + 
     G[{1}, yw]*G[{yv^(-1)}, yw]^2*G[{1, 1/(yu*yv)}, yw] - 
     G[{yu}, yv^(-1)]*G[{yv^(-1)}, yw]^2*G[{1, 1/(yu*yv)}, yw] + 
     (2*G[{yv^(-1)}, yw]^3*G[{1, 1/(yu*yv)}, yw])/3 + 
     2*G[{0}, yu^(-1)]^2*G[{1/(yu*yv)}, yw]*G[{1, 1/(yu*yv)}, yw] + 
     4*G[{0}, yu^(-1)]*G[{0}, yv^(-1)]*G[{1/(yu*yv)}, yw]*
      G[{1, 1/(yu*yv)}, yw] + 2*G[{0}, yv^(-1)]^2*G[{1/(yu*yv)}, yw]*
      G[{1, 1/(yu*yv)}, yw] - 4*G[{0}, yu^(-1)]*G[{0}, yw]*G[{1/(yu*yv)}, yw]*
      G[{1, 1/(yu*yv)}, yw] - 4*G[{0}, yv^(-1)]*G[{0}, yw]*G[{1/(yu*yv)}, yw]*
      G[{1, 1/(yu*yv)}, yw] + 2*G[{0}, yw]^2*G[{1/(yu*yv)}, yw]*
      G[{1, 1/(yu*yv)}, yw] - 2*G[{0}, yu^(-1)]*G[{1}, yu^(-1)]*
      G[{1/(yu*yv)}, yw]*G[{1, 1/(yu*yv)}, yw] - 2*G[{0}, yv^(-1)]*
      G[{1}, yu^(-1)]*G[{1/(yu*yv)}, yw]*G[{1, 1/(yu*yv)}, yw] + 
     2*G[{0}, yw]*G[{1}, yu^(-1)]*G[{1/(yu*yv)}, yw]*G[{1, 1/(yu*yv)}, yw] + 
     2*G[{0}, yu^(-1)]*G[{1}, yv^(-1)]*G[{1/(yu*yv)}, yw]*
      G[{1, 1/(yu*yv)}, yw] + 2*G[{0}, yv^(-1)]*G[{1}, yv^(-1)]*
      G[{1/(yu*yv)}, yw]*G[{1, 1/(yu*yv)}, yw] - 2*G[{0}, yw]*G[{1}, yv^(-1)]*
      G[{1/(yu*yv)}, yw]*G[{1, 1/(yu*yv)}, yw] - 4*G[{1}, yv^(-1)]^2*
      G[{1/(yu*yv)}, yw]*G[{1, 1/(yu*yv)}, yw] + 8*G[{0}, yu^(-1)]*G[{1}, yw]*
      G[{1/(yu*yv)}, yw]*G[{1, 1/(yu*yv)}, yw] + 8*G[{0}, yv^(-1)]*G[{1}, yw]*
      G[{1/(yu*yv)}, yw]*G[{1, 1/(yu*yv)}, yw] - 8*G[{0}, yw]*G[{1}, yw]*
      G[{1/(yu*yv)}, yw]*G[{1, 1/(yu*yv)}, yw] - 8*G[{1}, yu^(-1)]*G[{1}, yw]*
      G[{1/(yu*yv)}, yw]*G[{1, 1/(yu*yv)}, yw] - 8*G[{1}, yv^(-1)]*G[{1}, yw]*
      G[{1/(yu*yv)}, yw]*G[{1, 1/(yu*yv)}, yw] - 8*G[{0}, yu^(-1)]*
      G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{1, 1/(yu*yv)}, yw] - 
     8*G[{0}, yv^(-1)]*G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw]*
      G[{1, 1/(yu*yv)}, yw] + 8*G[{0}, yw]*G[{yu}, yv^(-1)]*
      G[{1/(yu*yv)}, yw]*G[{1, 1/(yu*yv)}, yw] + 4*G[{1}, yu^(-1)]*
      G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{1, 1/(yu*yv)}, yw] + 
     4*G[{1}, yv^(-1)]*G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw]*
      G[{1, 1/(yu*yv)}, yw] + 4*G[{yu}, yv^(-1)]^2*G[{1/(yu*yv)}, yw]*
      G[{1, 1/(yu*yv)}, yw] - 4*G[{0}, yu^(-1)]*G[{yv^(-1)}, yw]*
      G[{1/(yu*yv)}, yw]*G[{1, 1/(yu*yv)}, yw] - 4*G[{0}, yv^(-1)]*
      G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{1, 1/(yu*yv)}, yw] + 
     4*G[{0}, yw]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{1, 1/(yu*yv)}, yw] + 
     2*G[{1}, yu^(-1)]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*
      G[{1, 1/(yu*yv)}, yw] + 4*G[{1}, yv^(-1)]*G[{yv^(-1)}, yw]*
      G[{1/(yu*yv)}, yw]*G[{1, 1/(yu*yv)}, yw] - 
     2*G[{1}, yw]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{1, 1/(yu*yv)}, yw] + 
     2*G[{yu}, yv^(-1)]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*
      G[{1, 1/(yu*yv)}, yw] - 2*G[{yv^(-1)}, yw]^2*G[{1/(yu*yv)}, yw]*
      G[{1, 1/(yu*yv)}, yw] + 4*G[{0}, yu^(-1)]*G[{1/(yu*yv)}, yw]^2*
      G[{1, 1/(yu*yv)}, yw] + 4*G[{0}, yv^(-1)]*G[{1/(yu*yv)}, yw]^2*
      G[{1, 1/(yu*yv)}, yw] - 4*G[{0}, yw]*G[{1/(yu*yv)}, yw]^2*
      G[{1, 1/(yu*yv)}, yw] - 3*G[{1}, yu^(-1)]*G[{1/(yu*yv)}, yw]^2*
      G[{1, 1/(yu*yv)}, yw] + 5*G[{1}, yw]*G[{1/(yu*yv)}, yw]^2*
      G[{1, 1/(yu*yv)}, yw] - 5*G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw]^2*
      G[{1, 1/(yu*yv)}, yw] + G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2*
      G[{1, 1/(yu*yv)}, yw] + 2*G[{0}, yu^(-1)]*G[{0, 1}, yu^(-1)]*
      G[{1, 1/(yu*yv)}, yw] + 2*G[{0}, yv^(-1)]*G[{0, 1}, yu^(-1)]*
      G[{1, 1/(yu*yv)}, yw] - 2*G[{0}, yw]*G[{0, 1}, yu^(-1)]*
      G[{1, 1/(yu*yv)}, yw] - 2*G[{1}, yu^(-1)]*G[{0, 1}, yu^(-1)]*
      G[{1, 1/(yu*yv)}, yw] + 4*G[{1}, yv^(-1)]*G[{0, 1}, yu^(-1)]*
      G[{1, 1/(yu*yv)}, yw] - 6*G[{yu}, yv^(-1)]*G[{0, 1}, yu^(-1)]*
      G[{1, 1/(yu*yv)}, yw] - 4*G[{yv^(-1)}, yw]*G[{0, 1}, yu^(-1)]*
      G[{1, 1/(yu*yv)}, yw] + 4*G[{1/(yu*yv)}, yw]*G[{0, 1}, yu^(-1)]*
      G[{1, 1/(yu*yv)}, yw] - 2*G[{0}, yu^(-1)]*G[{0, 1}, yv^(-1)]*
      G[{1, 1/(yu*yv)}, yw] - 2*G[{0}, yv^(-1)]*G[{0, 1}, yv^(-1)]*
      G[{1, 1/(yu*yv)}, yw] + 2*G[{0}, yw]*G[{0, 1}, yv^(-1)]*
      G[{1, 1/(yu*yv)}, yw] + 2*G[{1}, yu^(-1)]*G[{0, 1}, yv^(-1)]*
      G[{1, 1/(yu*yv)}, yw] + 2*G[{1}, yv^(-1)]*G[{0, 1}, yv^(-1)]*
      G[{1, 1/(yu*yv)}, yw] - 4*G[{yv^(-1)}, yw]*G[{0, 1}, yv^(-1)]*
      G[{1, 1/(yu*yv)}, yw] + 4*G[{1/(yu*yv)}, yw]*G[{0, 1}, yv^(-1)]*
      G[{1, 1/(yu*yv)}, yw] - 2*G[{0}, yu^(-1)]*G[{0, 1}, yw]*
      G[{1, 1/(yu*yv)}, yw] - 2*G[{0}, yv^(-1)]*G[{0, 1}, yw]*
      G[{1, 1/(yu*yv)}, yw] + 2*G[{0}, yw]*G[{0, 1}, yw]*
      G[{1, 1/(yu*yv)}, yw] + 2*G[{1}, yu^(-1)]*G[{0, 1}, yw]*
      G[{1, 1/(yu*yv)}, yw] + 2*G[{1}, yv^(-1)]*G[{0, 1}, yw]*
      G[{1, 1/(yu*yv)}, yw] + 2*G[{0}, yu^(-1)]*G[{0, yu^(-1)}, yw]*
      G[{1, 1/(yu*yv)}, yw] + 2*G[{0}, yv^(-1)]*G[{0, yu^(-1)}, yw]*
      G[{1, 1/(yu*yv)}, yw] - 2*G[{0}, yw]*G[{0, yu^(-1)}, yw]*
      G[{1, 1/(yu*yv)}, yw] - 2*G[{1}, yu^(-1)]*G[{0, yu^(-1)}, yw]*
      G[{1, 1/(yu*yv)}, yw] - 2*G[{1}, yv^(-1)]*G[{0, yu^(-1)}, yw]*
      G[{1, 1/(yu*yv)}, yw] + 2*G[{0}, yu^(-1)]*G[{0, yu}, yv^(-1)]*
      G[{1, 1/(yu*yv)}, yw] + 2*G[{0}, yv^(-1)]*G[{0, yu}, yv^(-1)]*
      G[{1, 1/(yu*yv)}, yw] - 2*G[{0}, yw]*G[{0, yu}, yv^(-1)]*
      G[{1, 1/(yu*yv)}, yw] - 2*G[{1}, yu^(-1)]*G[{0, yu}, yv^(-1)]*
      G[{1, 1/(yu*yv)}, yw] - 2*G[{1}, yv^(-1)]*G[{0, yu}, yv^(-1)]*
      G[{1, 1/(yu*yv)}, yw] + 4*G[{yv^(-1)}, yw]*G[{0, yu}, yv^(-1)]*
      G[{1, 1/(yu*yv)}, yw] - 4*G[{1/(yu*yv)}, yw]*G[{0, yu}, yv^(-1)]*
      G[{1, 1/(yu*yv)}, yw] + 2*G[{0}, yu^(-1)]*G[{0, yv^(-1)}, yw]*
      G[{1, 1/(yu*yv)}, yw] + 2*G[{0}, yv^(-1)]*G[{0, yv^(-1)}, yw]*
      G[{1, 1/(yu*yv)}, yw] - 2*G[{0}, yw]*G[{0, yv^(-1)}, yw]*
      G[{1, 1/(yu*yv)}, yw] - 2*G[{1}, yu^(-1)]*G[{0, yv^(-1)}, yw]*
      G[{1, 1/(yu*yv)}, yw] - 2*G[{1}, yv^(-1)]*G[{0, yv^(-1)}, yw]*
      G[{1, 1/(yu*yv)}, yw] - 2*G[{0}, yu^(-1)]*G[{0, 1/(yu*yv)}, yw]*
      G[{1, 1/(yu*yv)}, yw] - 2*G[{0}, yv^(-1)]*G[{0, 1/(yu*yv)}, yw]*
      G[{1, 1/(yu*yv)}, yw] + 2*G[{0}, yw]*G[{0, 1/(yu*yv)}, yw]*
      G[{1, 1/(yu*yv)}, yw] + 2*G[{1}, yu^(-1)]*G[{0, 1/(yu*yv)}, yw]*
      G[{1, 1/(yu*yv)}, yw] + 2*G[{1}, yv^(-1)]*G[{0, 1/(yu*yv)}, yw]*
      G[{1, 1/(yu*yv)}, yw] - 4*G[{0}, yu^(-1)]*G[{1, yu^(-1)}, yw]*
      G[{1, 1/(yu*yv)}, yw] - 4*G[{0}, yv^(-1)]*G[{1, yu^(-1)}, yw]*
      G[{1, 1/(yu*yv)}, yw] + 4*G[{0}, yw]*G[{1, yu^(-1)}, yw]*
      G[{1, 1/(yu*yv)}, yw] + 4*G[{1}, yu^(-1)]*G[{1, yu^(-1)}, yw]*
      G[{1, 1/(yu*yv)}, yw] + 4*G[{1}, yv^(-1)]*G[{1, yu^(-1)}, yw]*
      G[{1, 1/(yu*yv)}, yw] - 4*G[{yv^(-1)}, yw]*G[{1, yu^(-1)}, yw]*
      G[{1, 1/(yu*yv)}, yw] + 4*G[{1/(yu*yv)}, yw]*G[{1, yu^(-1)}, yw]*
      G[{1, 1/(yu*yv)}, yw] - 4*G[{0}, yu^(-1)]*G[{1, yu}, yv^(-1)]*
      G[{1, 1/(yu*yv)}, yw] - 4*G[{0}, yv^(-1)]*G[{1, yu}, yv^(-1)]*
      G[{1, 1/(yu*yv)}, yw] + 4*G[{0}, yw]*G[{1, yu}, yv^(-1)]*
      G[{1, 1/(yu*yv)}, yw] + 4*G[{1}, yu^(-1)]*G[{1, yu}, yv^(-1)]*
      G[{1, 1/(yu*yv)}, yw] + 4*G[{1}, yv^(-1)]*G[{1, yu}, yv^(-1)]*
      G[{1, 1/(yu*yv)}, yw] + 6*G[{yu}, yv^(-1)]*G[{1, yu}, yv^(-1)]*
      G[{1, 1/(yu*yv)}, yw] - 4*G[{yv^(-1)}, yw]*G[{1, yv^(-1)}, yw]*
      G[{1, 1/(yu*yv)}, yw] + 4*G[{1/(yu*yv)}, yw]*G[{1, yv^(-1)}, yw]*
      G[{1, 1/(yu*yv)}, yw] + 4*G[{yv^(-1)}, yw]*G[{1, 1/(yu*yv)}, yw]^2 - 
     4*G[{1/(yu*yv)}, yw]*G[{1, 1/(yu*yv)}, yw]^2 + 
     (Pi^2*G[{yv^(-1)}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw])/3 - 
     2*G[{0}, yu^(-1)]*G[{1}, yv^(-1)]*G[{yv^(-1)}, yw]*
      G[{yu^(-1), 1/(yu*yv)}, yw] - 2*G[{0}, yv^(-1)]*G[{1}, yv^(-1)]*
      G[{yv^(-1)}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw] + 
     2*G[{0}, yw]*G[{1}, yv^(-1)]*G[{yv^(-1)}, yw]*G[{yu^(-1), 1/(yu*yv)}, 
       yw] + 2*G[{1}, yv^(-1)]^2*G[{yv^(-1)}, yw]*G[{yu^(-1), 1/(yu*yv)}, 
       yw] - 4*G[{0}, yu^(-1)]*G[{1}, yw]*G[{yv^(-1)}, yw]*
      G[{yu^(-1), 1/(yu*yv)}, yw] - 4*G[{0}, yv^(-1)]*G[{1}, yw]*
      G[{yv^(-1)}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw] + 
     4*G[{0}, yw]*G[{1}, yw]*G[{yv^(-1)}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw] + 
     4*G[{1}, yu^(-1)]*G[{1}, yw]*G[{yv^(-1)}, yw]*G[{yu^(-1), 1/(yu*yv)}, 
       yw] + 4*G[{1}, yv^(-1)]*G[{1}, yw]*G[{yv^(-1)}, yw]*
      G[{yu^(-1), 1/(yu*yv)}, yw] + 4*G[{0}, yu^(-1)]*G[{yu^(-1)}, yw]*
      G[{yv^(-1)}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw] + 
     4*G[{0}, yv^(-1)]*G[{yu^(-1)}, yw]*G[{yv^(-1)}, yw]*
      G[{yu^(-1), 1/(yu*yv)}, yw] - 4*G[{0}, yw]*G[{yu^(-1)}, yw]*
      G[{yv^(-1)}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw] - 
     4*G[{1}, yu^(-1)]*G[{yu^(-1)}, yw]*G[{yv^(-1)}, yw]*
      G[{yu^(-1), 1/(yu*yv)}, yw] - 8*G[{1}, yv^(-1)]*G[{yu^(-1)}, yw]*
      G[{yv^(-1)}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw] - 
     4*G[{1}, yw]*G[{yu^(-1)}, yw]*G[{yv^(-1)}, yw]*G[{yu^(-1), 1/(yu*yv)}, 
       yw] + 4*G[{yu^(-1)}, yw]^2*G[{yv^(-1)}, yw]*G[{yu^(-1), 1/(yu*yv)}, 
       yw] + 2*G[{0}, yu^(-1)]*G[{yu}, yv^(-1)]*G[{yv^(-1)}, yw]*
      G[{yu^(-1), 1/(yu*yv)}, yw] + 2*G[{0}, yv^(-1)]*G[{yu}, yv^(-1)]*
      G[{yv^(-1)}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw] - 
     2*G[{0}, yw]*G[{yu}, yv^(-1)]*G[{yv^(-1)}, yw]*G[{yu^(-1), 1/(yu*yv)}, 
       yw] - 4*G[{1}, yv^(-1)]*G[{yu}, yv^(-1)]*G[{yv^(-1)}, yw]*
      G[{yu^(-1), 1/(yu*yv)}, yw] + 4*G[{yu^(-1)}, yw]*G[{yu}, yv^(-1)]*
      G[{yv^(-1)}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw] + 
     2*G[{1}, yu^(-1)]*G[{yv^(-1)}, yw]^2*G[{yu^(-1), 1/(yu*yv)}, yw] + 
     2*G[{1}, yw]*G[{yv^(-1)}, yw]^2*G[{yu^(-1), 1/(yu*yv)}, yw] - 
     2*G[{yu}, yv^(-1)]*G[{yv^(-1)}, yw]^2*G[{yu^(-1), 1/(yu*yv)}, yw] - 
     (2*G[{yv^(-1)}, yw]^3*G[{yu^(-1), 1/(yu*yv)}, yw])/3 + 
     (Pi^2*G[{1/(yu*yv)}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw])/3 - 
     2*G[{0}, yu^(-1)]*G[{1}, yv^(-1)]*G[{1/(yu*yv)}, yw]*
      G[{yu^(-1), 1/(yu*yv)}, yw] - 2*G[{0}, yv^(-1)]*G[{1}, yv^(-1)]*
      G[{1/(yu*yv)}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw] + 
     2*G[{0}, yw]*G[{1}, yv^(-1)]*G[{1/(yu*yv)}, yw]*
      G[{yu^(-1), 1/(yu*yv)}, yw] + 2*G[{1}, yv^(-1)]^2*G[{1/(yu*yv)}, yw]*
      G[{yu^(-1), 1/(yu*yv)}, yw] - 4*G[{0}, yu^(-1)]*G[{1}, yw]*
      G[{1/(yu*yv)}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw] - 
     4*G[{0}, yv^(-1)]*G[{1}, yw]*G[{1/(yu*yv)}, yw]*
      G[{yu^(-1), 1/(yu*yv)}, yw] + 4*G[{0}, yw]*G[{1}, yw]*
      G[{1/(yu*yv)}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw] + 
     4*G[{1}, yu^(-1)]*G[{1}, yw]*G[{1/(yu*yv)}, yw]*
      G[{yu^(-1), 1/(yu*yv)}, yw] + 4*G[{1}, yv^(-1)]*G[{1}, yw]*
      G[{1/(yu*yv)}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw] + 
     4*G[{0}, yu^(-1)]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*
      G[{yu^(-1), 1/(yu*yv)}, yw] + 4*G[{0}, yv^(-1)]*G[{yu^(-1)}, yw]*
      G[{1/(yu*yv)}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw] - 
     4*G[{0}, yw]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*
      G[{yu^(-1), 1/(yu*yv)}, yw] - 4*G[{1}, yu^(-1)]*G[{yu^(-1)}, yw]*
      G[{1/(yu*yv)}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw] - 
     8*G[{1}, yv^(-1)]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*
      G[{yu^(-1), 1/(yu*yv)}, yw] - 4*G[{1}, yw]*G[{yu^(-1)}, yw]*
      G[{1/(yu*yv)}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw] + 
     4*G[{yu^(-1)}, yw]^2*G[{1/(yu*yv)}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw] + 
     2*G[{0}, yu^(-1)]*G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw]*
      G[{yu^(-1), 1/(yu*yv)}, yw] + 2*G[{0}, yv^(-1)]*G[{yu}, yv^(-1)]*
      G[{1/(yu*yv)}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw] - 
     2*G[{0}, yw]*G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw]*
      G[{yu^(-1), 1/(yu*yv)}, yw] - 4*G[{1}, yv^(-1)]*G[{yu}, yv^(-1)]*
      G[{1/(yu*yv)}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw] + 
     4*G[{yu^(-1)}, yw]*G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw]*
      G[{yu^(-1), 1/(yu*yv)}, yw] + 2*G[{yv^(-1)}, yw]^2*G[{1/(yu*yv)}, yw]*
      G[{yu^(-1), 1/(yu*yv)}, yw] - 2*G[{1}, yu^(-1)]*G[{1/(yu*yv)}, yw]^2*
      G[{yu^(-1), 1/(yu*yv)}, yw] - 2*G[{1}, yw]*G[{1/(yu*yv)}, yw]^2*
      G[{yu^(-1), 1/(yu*yv)}, yw] + 2*G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw]^2*
      G[{yu^(-1), 1/(yu*yv)}, yw] - 2*G[{yv^(-1)}, yw]*G[{0, 1}, yu^(-1)]*
      G[{yu^(-1), 1/(yu*yv)}, yw] - 2*G[{1/(yu*yv)}, yw]*G[{0, 1}, yu^(-1)]*
      G[{yu^(-1), 1/(yu*yv)}, yw] + 2*G[{yv^(-1)}, yw]*G[{0, 1}, yv^(-1)]*
      G[{yu^(-1), 1/(yu*yv)}, yw] + 2*G[{1/(yu*yv)}, yw]*G[{0, 1}, yv^(-1)]*
      G[{yu^(-1), 1/(yu*yv)}, yw] - 2*G[{yv^(-1)}, yw]*G[{0, 1}, yw]*
      G[{yu^(-1), 1/(yu*yv)}, yw] - 2*G[{1/(yu*yv)}, yw]*G[{0, 1}, yw]*
      G[{yu^(-1), 1/(yu*yv)}, yw] + 2*G[{yv^(-1)}, yw]*G[{0, yu^(-1)}, yw]*
      G[{yu^(-1), 1/(yu*yv)}, yw] + 2*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1)}, yw]*
      G[{yu^(-1), 1/(yu*yv)}, yw] - 2*G[{yv^(-1)}, yw]*G[{0, yu}, yv^(-1)]*
      G[{yu^(-1), 1/(yu*yv)}, yw] - 2*G[{1/(yu*yv)}, yw]*G[{0, yu}, yv^(-1)]*
      G[{yu^(-1), 1/(yu*yv)}, yw] + 2*G[{yv^(-1)}, yw]*G[{0, yv^(-1)}, yw]*
      G[{yu^(-1), 1/(yu*yv)}, yw] + 2*G[{1/(yu*yv)}, yw]*G[{0, yv^(-1)}, yw]*
      G[{yu^(-1), 1/(yu*yv)}, yw] - 2*G[{yv^(-1)}, yw]*G[{0, 1/(yu*yv)}, yw]*
      G[{yu^(-1), 1/(yu*yv)}, yw] - 2*G[{1/(yu*yv)}, yw]*
      G[{0, 1/(yu*yv)}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw] + 
     4*G[{yv^(-1)}, yw]*G[{1, yu}, yv^(-1)]*G[{yu^(-1), 1/(yu*yv)}, yw] + 
     4*G[{1/(yu*yv)}, yw]*G[{1, yu}, yv^(-1)]*G[{yu^(-1), 1/(yu*yv)}, yw] - 
     4*G[{yv^(-1)}, yw]*G[{1, yv^(-1)}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw] - 
     4*G[{1/(yu*yv)}, yw]*G[{1, yv^(-1)}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw] + 
     2*G[{yv^(-1)}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw]^2 + 
     2*G[{1/(yu*yv)}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw]^2 - 
     (Pi^2*G[{0}, yu^(-1)]*G[{yv^(-1), 1/(yu*yv)}, yw])/3 - 
     (Pi^2*G[{0}, yv^(-1)]*G[{yv^(-1), 1/(yu*yv)}, yw])/3 + 
     (Pi^2*G[{0}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw])/3 + 
     (Pi^2*G[{1}, yu^(-1)]*G[{yv^(-1), 1/(yu*yv)}, yw])/3 + 
     (Pi^2*G[{1}, yv^(-1)]*G[{yv^(-1), 1/(yu*yv)}, yw])/3 + 
     2*G[{0}, yu^(-1)]*G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*
      G[{yv^(-1), 1/(yu*yv)}, yw] + 2*G[{0}, yv^(-1)]*G[{1}, yu^(-1)]*
      G[{1}, yv^(-1)]*G[{yv^(-1), 1/(yu*yv)}, yw] - 
     2*G[{0}, yw]*G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*G[{yv^(-1), 1/(yu*yv)}, 
       yw] - 2*G[{1}, yu^(-1)]^2*G[{1}, yv^(-1)]*G[{yv^(-1), 1/(yu*yv)}, 
       yw] - G[{1}, yu^(-1)]*G[{1}, yv^(-1)]^2*G[{yv^(-1), 1/(yu*yv)}, yw] - 
     (Pi^2*G[{yu^(-1)}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw])/3 + 
     2*G[{0}, yu^(-1)]*G[{1}, yv^(-1)]*G[{yu^(-1)}, yw]*
      G[{yv^(-1), 1/(yu*yv)}, yw] + 2*G[{0}, yv^(-1)]*G[{1}, yv^(-1)]*
      G[{yu^(-1)}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw] - 
     2*G[{0}, yw]*G[{1}, yv^(-1)]*G[{yu^(-1)}, yw]*G[{yv^(-1), 1/(yu*yv)}, 
       yw] - 2*G[{1}, yv^(-1)]^2*G[{yu^(-1)}, yw]*G[{yv^(-1), 1/(yu*yv)}, 
       yw] + 4*G[{0}, yu^(-1)]*G[{1}, yw]*G[{yu^(-1)}, yw]*
      G[{yv^(-1), 1/(yu*yv)}, yw] + 4*G[{0}, yv^(-1)]*G[{1}, yw]*
      G[{yu^(-1)}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw] - 
     4*G[{0}, yw]*G[{1}, yw]*G[{yu^(-1)}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw] - 
     4*G[{1}, yu^(-1)]*G[{1}, yw]*G[{yu^(-1)}, yw]*G[{yv^(-1), 1/(yu*yv)}, 
       yw] - 4*G[{1}, yv^(-1)]*G[{1}, yw]*G[{yu^(-1)}, yw]*
      G[{yv^(-1), 1/(yu*yv)}, yw] - 2*G[{0}, yu^(-1)]*G[{yu^(-1)}, yw]^2*
      G[{yv^(-1), 1/(yu*yv)}, yw] - 2*G[{0}, yv^(-1)]*G[{yu^(-1)}, yw]^2*
      G[{yv^(-1), 1/(yu*yv)}, yw] + 2*G[{0}, yw]*G[{yu^(-1)}, yw]^2*
      G[{yv^(-1), 1/(yu*yv)}, yw] + 2*G[{1}, yu^(-1)]*G[{yu^(-1)}, yw]^2*
      G[{yv^(-1), 1/(yu*yv)}, yw] + 4*G[{1}, yv^(-1)]*G[{yu^(-1)}, yw]^2*
      G[{yv^(-1), 1/(yu*yv)}, yw] + 2*G[{1}, yw]*G[{yu^(-1)}, yw]^2*
      G[{yv^(-1), 1/(yu*yv)}, yw] - (4*G[{yu^(-1)}, yw]^3*
       G[{yv^(-1), 1/(yu*yv)}, yw])/3 - 2*G[{0}, yu^(-1)]*G[{1}, yu^(-1)]*
      G[{yu}, yv^(-1)]*G[{yv^(-1), 1/(yu*yv)}, yw] - 
     2*G[{0}, yv^(-1)]*G[{1}, yu^(-1)]*G[{yu}, yv^(-1)]*
      G[{yv^(-1), 1/(yu*yv)}, yw] + 2*G[{0}, yw]*G[{1}, yu^(-1)]*
      G[{yu}, yv^(-1)]*G[{yv^(-1), 1/(yu*yv)}, yw] + 
     2*G[{1}, yu^(-1)]^2*G[{yu}, yv^(-1)]*G[{yv^(-1), 1/(yu*yv)}, yw] + 
     2*G[{0}, yu^(-1)]*G[{1}, yv^(-1)]*G[{yu}, yv^(-1)]*
      G[{yv^(-1), 1/(yu*yv)}, yw] + 2*G[{0}, yv^(-1)]*G[{1}, yv^(-1)]*
      G[{yu}, yv^(-1)]*G[{yv^(-1), 1/(yu*yv)}, yw] - 
     2*G[{0}, yw]*G[{1}, yv^(-1)]*G[{yu}, yv^(-1)]*G[{yv^(-1), 1/(yu*yv)}, 
       yw] - 2*G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*G[{yu}, yv^(-1)]*
      G[{yv^(-1), 1/(yu*yv)}, yw] - 2*G[{1}, yv^(-1)]^2*G[{yu}, yv^(-1)]*
      G[{yv^(-1), 1/(yu*yv)}, yw] - 2*G[{0}, yu^(-1)]*G[{yu^(-1)}, yw]*
      G[{yu}, yv^(-1)]*G[{yv^(-1), 1/(yu*yv)}, yw] - 
     2*G[{0}, yv^(-1)]*G[{yu^(-1)}, yw]*G[{yu}, yv^(-1)]*
      G[{yv^(-1), 1/(yu*yv)}, yw] + 2*G[{0}, yw]*G[{yu^(-1)}, yw]*
      G[{yu}, yv^(-1)]*G[{yv^(-1), 1/(yu*yv)}, yw] + 
     4*G[{1}, yv^(-1)]*G[{yu^(-1)}, yw]*G[{yu}, yv^(-1)]*
      G[{yv^(-1), 1/(yu*yv)}, yw] - 2*G[{yu^(-1)}, yw]^2*G[{yu}, yv^(-1)]*
      G[{yv^(-1), 1/(yu*yv)}, yw] + G[{1}, yu^(-1)]*G[{yu}, yv^(-1)]^2*
      G[{yv^(-1), 1/(yu*yv)}, yw] - 
     (G[{yu}, yv^(-1)]^3*G[{yv^(-1), 1/(yu*yv)}, yw])/3 - 
     (Pi^2*G[{yv^(-1)}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw])/3 - 
     2*G[{0}, yu^(-1)]*G[{1}, yu^(-1)]*G[{yv^(-1)}, yw]*
      G[{yv^(-1), 1/(yu*yv)}, yw] - 2*G[{0}, yv^(-1)]*G[{1}, yu^(-1)]*
      G[{yv^(-1)}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw] + 
     2*G[{0}, yw]*G[{1}, yu^(-1)]*G[{yv^(-1)}, yw]*G[{yv^(-1), 1/(yu*yv)}, 
       yw] + 2*G[{1}, yu^(-1)]^2*G[{yv^(-1)}, yw]*G[{yv^(-1), 1/(yu*yv)}, 
       yw] + 2*G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*G[{yv^(-1)}, yw]*
      G[{yv^(-1), 1/(yu*yv)}, yw] - 2*G[{0}, yu^(-1)]*G[{yu^(-1)}, yw]*
      G[{yv^(-1)}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw] - 
     2*G[{0}, yv^(-1)]*G[{yu^(-1)}, yw]*G[{yv^(-1)}, yw]*
      G[{yv^(-1), 1/(yu*yv)}, yw] + 2*G[{0}, yw]*G[{yu^(-1)}, yw]*
      G[{yv^(-1)}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw] + 
     4*G[{1}, yv^(-1)]*G[{yu^(-1)}, yw]*G[{yv^(-1)}, yw]*
      G[{yv^(-1), 1/(yu*yv)}, yw] - 2*G[{yu^(-1)}, yw]^2*G[{yv^(-1)}, yw]*
      G[{yv^(-1), 1/(yu*yv)}, yw] + 2*G[{0}, yu^(-1)]*G[{yu}, yv^(-1)]*
      G[{yv^(-1)}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw] + 
     2*G[{0}, yv^(-1)]*G[{yu}, yv^(-1)]*G[{yv^(-1)}, yw]*
      G[{yv^(-1), 1/(yu*yv)}, yw] - 2*G[{0}, yw]*G[{yu}, yv^(-1)]*
      G[{yv^(-1)}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw] - 
     2*G[{1}, yu^(-1)]*G[{yu}, yv^(-1)]*G[{yv^(-1)}, yw]*
      G[{yv^(-1), 1/(yu*yv)}, yw] - G[{yu}, yv^(-1)]^2*G[{yv^(-1)}, yw]*
      G[{yv^(-1), 1/(yu*yv)}, yw] - G[{1}, yu^(-1)]*G[{yv^(-1)}, yw]^2*
      G[{yv^(-1), 1/(yu*yv)}, yw] - G[{1}, yw]*G[{yv^(-1)}, yw]^2*
      G[{yv^(-1), 1/(yu*yv)}, yw] + G[{yu}, yv^(-1)]*G[{yv^(-1)}, yw]^2*
      G[{yv^(-1), 1/(yu*yv)}, yw] + 
     (G[{yv^(-1)}, yw]^3*G[{yv^(-1), 1/(yu*yv)}, yw])/3 + 
     (Pi^2*G[{1/(yu*yv)}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw])/3 - 
     2*G[{0}, yu^(-1)]^2*G[{1/(yu*yv)}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw] - 
     4*G[{0}, yu^(-1)]*G[{0}, yv^(-1)]*G[{1/(yu*yv)}, yw]*
      G[{yv^(-1), 1/(yu*yv)}, yw] - 2*G[{0}, yv^(-1)]^2*G[{1/(yu*yv)}, yw]*
      G[{yv^(-1), 1/(yu*yv)}, yw] + 4*G[{0}, yu^(-1)]*G[{0}, yw]*
      G[{1/(yu*yv)}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw] + 
     4*G[{0}, yv^(-1)]*G[{0}, yw]*G[{1/(yu*yv)}, yw]*
      G[{yv^(-1), 1/(yu*yv)}, yw] - 2*G[{0}, yw]^2*G[{1/(yu*yv)}, yw]*
      G[{yv^(-1), 1/(yu*yv)}, yw] + 6*G[{0}, yu^(-1)]*G[{1}, yu^(-1)]*
      G[{1/(yu*yv)}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw] + 
     6*G[{0}, yv^(-1)]*G[{1}, yu^(-1)]*G[{1/(yu*yv)}, yw]*
      G[{yv^(-1), 1/(yu*yv)}, yw] - 6*G[{0}, yw]*G[{1}, yu^(-1)]*
      G[{1/(yu*yv)}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw] - 
     4*G[{1}, yu^(-1)]^2*G[{1/(yu*yv)}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw] + 
     2*G[{1}, yv^(-1)]^2*G[{1/(yu*yv)}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw] - 
     4*G[{0}, yu^(-1)]*G[{1}, yw]*G[{1/(yu*yv)}, yw]*
      G[{yv^(-1), 1/(yu*yv)}, yw] - 4*G[{0}, yv^(-1)]*G[{1}, yw]*
      G[{1/(yu*yv)}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw] + 
     4*G[{0}, yw]*G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw] + 
     4*G[{1}, yu^(-1)]*G[{1}, yw]*G[{1/(yu*yv)}, yw]*
      G[{yv^(-1), 1/(yu*yv)}, yw] + 4*G[{1}, yv^(-1)]*G[{1}, yw]*
      G[{1/(yu*yv)}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw] + 
     2*G[{0}, yu^(-1)]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*
      G[{yv^(-1), 1/(yu*yv)}, yw] + 2*G[{0}, yv^(-1)]*G[{yu^(-1)}, yw]*
      G[{1/(yu*yv)}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw] - 
     2*G[{0}, yw]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*
      G[{yv^(-1), 1/(yu*yv)}, yw] - 4*G[{1}, yv^(-1)]*G[{yu^(-1)}, yw]*
      G[{1/(yu*yv)}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw] + 
     2*G[{yu^(-1)}, yw]^2*G[{1/(yu*yv)}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw] + 
     2*G[{0}, yu^(-1)]*G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw]*
      G[{yv^(-1), 1/(yu*yv)}, yw] + 2*G[{0}, yv^(-1)]*G[{yu}, yv^(-1)]*
      G[{1/(yu*yv)}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw] - 
     2*G[{0}, yw]*G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw]*
      G[{yv^(-1), 1/(yu*yv)}, yw] - 4*G[{1}, yu^(-1)]*G[{yu}, yv^(-1)]*
      G[{1/(yu*yv)}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw] - 
     4*G[{0}, yu^(-1)]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*
      G[{yv^(-1), 1/(yu*yv)}, yw] - 4*G[{0}, yv^(-1)]*G[{yv^(-1)}, yw]*
      G[{1/(yu*yv)}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw] + 
     4*G[{0}, yw]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*
      G[{yv^(-1), 1/(yu*yv)}, yw] + 4*G[{1}, yu^(-1)]*G[{yv^(-1)}, yw]*
      G[{1/(yu*yv)}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw] - 
     4*G[{1}, yw]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*
      G[{yv^(-1), 1/(yu*yv)}, yw] + 4*G[{yu}, yv^(-1)]*G[{yv^(-1)}, yw]*
      G[{1/(yu*yv)}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw] - 
     2*G[{yv^(-1)}, yw]^2*G[{1/(yu*yv)}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw] - 
     2*G[{0}, yu^(-1)]*G[{1/(yu*yv)}, yw]^2*G[{yv^(-1), 1/(yu*yv)}, yw] - 
     2*G[{0}, yv^(-1)]*G[{1/(yu*yv)}, yw]^2*G[{yv^(-1), 1/(yu*yv)}, yw] + 
     2*G[{0}, yw]*G[{1/(yu*yv)}, yw]^2*G[{yv^(-1), 1/(yu*yv)}, yw] + 
     3*G[{1}, yu^(-1)]*G[{1/(yu*yv)}, yw]^2*G[{yv^(-1), 1/(yu*yv)}, yw] - 
     2*G[{1}, yv^(-1)]*G[{1/(yu*yv)}, yw]^2*G[{yv^(-1), 1/(yu*yv)}, yw] - 
     3*G[{1}, yw]*G[{1/(yu*yv)}, yw]^2*G[{yv^(-1), 1/(yu*yv)}, yw] + 
     2*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2*G[{yv^(-1), 1/(yu*yv)}, yw] + 
     3*G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw]^2*G[{yv^(-1), 1/(yu*yv)}, yw] - 
     3*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2*G[{yv^(-1), 1/(yu*yv)}, yw] + 
     2*G[{0}, yu^(-1)]*G[{0, 1}, yu^(-1)]*G[{yv^(-1), 1/(yu*yv)}, yw] + 
     2*G[{0}, yv^(-1)]*G[{0, 1}, yu^(-1)]*G[{yv^(-1), 1/(yu*yv)}, yw] - 
     2*G[{0}, yw]*G[{0, 1}, yu^(-1)]*G[{yv^(-1), 1/(yu*yv)}, yw] - 
     2*G[{1}, yu^(-1)]*G[{0, 1}, yu^(-1)]*G[{yv^(-1), 1/(yu*yv)}, yw] + 
     2*G[{yu^(-1)}, yw]*G[{0, 1}, yu^(-1)]*G[{yv^(-1), 1/(yu*yv)}, yw] - 
     2*G[{yu}, yv^(-1)]*G[{0, 1}, yu^(-1)]*G[{yv^(-1), 1/(yu*yv)}, yw] + 
     2*G[{1/(yu*yv)}, yw]*G[{0, 1}, yu^(-1)]*G[{yv^(-1), 1/(yu*yv)}, yw] - 
     2*G[{0}, yu^(-1)]*G[{0, 1}, yv^(-1)]*G[{yv^(-1), 1/(yu*yv)}, yw] - 
     2*G[{0}, yv^(-1)]*G[{0, 1}, yv^(-1)]*G[{yv^(-1), 1/(yu*yv)}, yw] + 
     2*G[{0}, yw]*G[{0, 1}, yv^(-1)]*G[{yv^(-1), 1/(yu*yv)}, yw] + 
     2*G[{1}, yu^(-1)]*G[{0, 1}, yv^(-1)]*G[{yv^(-1), 1/(yu*yv)}, yw] + 
     2*G[{1}, yv^(-1)]*G[{0, 1}, yv^(-1)]*G[{yv^(-1), 1/(yu*yv)}, yw] - 
     2*G[{yu^(-1)}, yw]*G[{0, 1}, yv^(-1)]*G[{yv^(-1), 1/(yu*yv)}, yw] - 
     2*G[{yv^(-1)}, yw]*G[{0, 1}, yv^(-1)]*G[{yv^(-1), 1/(yu*yv)}, yw] - 
     2*G[{1/(yu*yv)}, yw]*G[{0, 1}, yv^(-1)]*G[{yv^(-1), 1/(yu*yv)}, yw] - 
     2*G[{0}, yu^(-1)]*G[{0, 1}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw] - 
     2*G[{0}, yv^(-1)]*G[{0, 1}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw] + 
     2*G[{0}, yw]*G[{0, 1}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw] + 
     2*G[{1}, yu^(-1)]*G[{0, 1}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw] + 
     2*G[{1}, yv^(-1)]*G[{0, 1}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw] + 
     2*G[{yu^(-1)}, yw]*G[{0, 1}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw] + 
     2*G[{yv^(-1)}, yw]*G[{0, 1}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw] - 
     2*G[{1/(yu*yv)}, yw]*G[{0, 1}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw] + 
     2*G[{0}, yu^(-1)]*G[{0, yu^(-1)}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw] + 
     2*G[{0}, yv^(-1)]*G[{0, yu^(-1)}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw] - 
     2*G[{0}, yw]*G[{0, yu^(-1)}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw] - 
     2*G[{1}, yu^(-1)]*G[{0, yu^(-1)}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw] - 
     2*G[{1}, yv^(-1)]*G[{0, yu^(-1)}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw] - 
     2*G[{yu^(-1)}, yw]*G[{0, yu^(-1)}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw] - 
     2*G[{yv^(-1)}, yw]*G[{0, yu^(-1)}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw] + 
     2*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1)}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw] + 
     2*G[{0}, yu^(-1)]*G[{0, yu}, yv^(-1)]*G[{yv^(-1), 1/(yu*yv)}, yw] + 
     2*G[{0}, yv^(-1)]*G[{0, yu}, yv^(-1)]*G[{yv^(-1), 1/(yu*yv)}, yw] - 
     2*G[{0}, yw]*G[{0, yu}, yv^(-1)]*G[{yv^(-1), 1/(yu*yv)}, yw] - 
     2*G[{1}, yu^(-1)]*G[{0, yu}, yv^(-1)]*G[{yv^(-1), 1/(yu*yv)}, yw] - 
     2*G[{1}, yv^(-1)]*G[{0, yu}, yv^(-1)]*G[{yv^(-1), 1/(yu*yv)}, yw] + 
     2*G[{yu^(-1)}, yw]*G[{0, yu}, yv^(-1)]*G[{yv^(-1), 1/(yu*yv)}, yw] + 
     2*G[{yv^(-1)}, yw]*G[{0, yu}, yv^(-1)]*G[{yv^(-1), 1/(yu*yv)}, yw] + 
     2*G[{1/(yu*yv)}, yw]*G[{0, yu}, yv^(-1)]*G[{yv^(-1), 1/(yu*yv)}, yw] + 
     2*G[{0}, yu^(-1)]*G[{0, yv^(-1)}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw] + 
     2*G[{0}, yv^(-1)]*G[{0, yv^(-1)}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw] - 
     2*G[{0}, yw]*G[{0, yv^(-1)}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw] - 
     2*G[{1}, yu^(-1)]*G[{0, yv^(-1)}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw] - 
     2*G[{1}, yv^(-1)]*G[{0, yv^(-1)}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw] - 
     2*G[{yu^(-1)}, yw]*G[{0, yv^(-1)}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw] - 
     2*G[{yv^(-1)}, yw]*G[{0, yv^(-1)}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw] + 
     2*G[{1/(yu*yv)}, yw]*G[{0, yv^(-1)}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw] - 
     2*G[{0}, yu^(-1)]*G[{0, 1/(yu*yv)}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw] - 
     2*G[{0}, yv^(-1)]*G[{0, 1/(yu*yv)}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw] + 
     2*G[{0}, yw]*G[{0, 1/(yu*yv)}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw] + 
     2*G[{1}, yu^(-1)]*G[{0, 1/(yu*yv)}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw] + 
     2*G[{1}, yv^(-1)]*G[{0, 1/(yu*yv)}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw] + 
     2*G[{yu^(-1)}, yw]*G[{0, 1/(yu*yv)}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw] + 
     2*G[{yv^(-1)}, yw]*G[{0, 1/(yu*yv)}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw] - 
     2*G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv)}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw] - 
     4*G[{0}, yu^(-1)]*G[{1, yu^(-1)}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw] - 
     4*G[{0}, yv^(-1)]*G[{1, yu^(-1)}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw] + 
     4*G[{0}, yw]*G[{1, yu^(-1)}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw] + 
     4*G[{1}, yu^(-1)]*G[{1, yu^(-1)}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw] + 
     4*G[{1}, yv^(-1)]*G[{1, yu^(-1)}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw] - 
     4*G[{1/(yu*yv)}, yw]*G[{1, yu^(-1)}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw] - 
     4*G[{0}, yu^(-1)]*G[{1, yu}, yv^(-1)]*G[{yv^(-1), 1/(yu*yv)}, yw] - 
     4*G[{0}, yv^(-1)]*G[{1, yu}, yv^(-1)]*G[{yv^(-1), 1/(yu*yv)}, yw] + 
     4*G[{0}, yw]*G[{1, yu}, yv^(-1)]*G[{yv^(-1), 1/(yu*yv)}, yw] + 
     4*G[{1}, yu^(-1)]*G[{1, yu}, yv^(-1)]*G[{yv^(-1), 1/(yu*yv)}, yw] + 
     4*G[{1}, yv^(-1)]*G[{1, yu}, yv^(-1)]*G[{yv^(-1), 1/(yu*yv)}, yw] - 
     4*G[{yu^(-1)}, yw]*G[{1, yu}, yv^(-1)]*G[{yv^(-1), 1/(yu*yv)}, yw] + 
     2*G[{yu}, yv^(-1)]*G[{1, yu}, yv^(-1)]*G[{yv^(-1), 1/(yu*yv)}, yw] - 
     2*G[{yv^(-1)}, yw]*G[{1, yu}, yv^(-1)]*G[{yv^(-1), 1/(yu*yv)}, yw] - 
     4*G[{1/(yu*yv)}, yw]*G[{1, yu}, yv^(-1)]*G[{yv^(-1), 1/(yu*yv)}, yw] + 
     4*G[{yu^(-1)}, yw]*G[{1, yv^(-1)}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw] + 
     2*G[{yv^(-1)}, yw]*G[{1, yv^(-1)}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw] + 
     2*G[{yv^(-1)}, yw]*G[{1, 1/(yu*yv)}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw] - 
     4*G[{yv^(-1)}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw]*G[{yv^(-1), 1/(yu*yv)}, 
       yw] + 2*G[{0}, yu^(-1)]*G[{yv^(-1), 1/(yu*yv)}, yw]^2 + 
     2*G[{0}, yv^(-1)]*G[{yv^(-1), 1/(yu*yv)}, yw]^2 - 
     2*G[{0}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw]^2 - 
     2*G[{1}, yu^(-1)]*G[{yv^(-1), 1/(yu*yv)}, yw]^2 - 
     2*G[{1}, yv^(-1)]*G[{yv^(-1), 1/(yu*yv)}, yw]^2 + 
     2*G[{yu^(-1)}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw]^2 + 
     2*G[{yv^(-1)}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw]^2 + 
     2*G[{1/(yu*yv)}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw]^2 + 
     (2*Pi^2*G[{0, 0, 1}, yu^(-1)])/3 - 2*G[{0}, yu^(-1)]^2*
      G[{0, 0, 1}, yu^(-1)] - 4*G[{0}, yu^(-1)]*G[{0}, yv^(-1)]*
      G[{0, 0, 1}, yu^(-1)] - 2*G[{0}, yv^(-1)]^2*G[{0, 0, 1}, yu^(-1)] + 
     4*G[{0}, yu^(-1)]*G[{0}, yw]*G[{0, 0, 1}, yu^(-1)] + 
     4*G[{0}, yv^(-1)]*G[{0}, yw]*G[{0, 0, 1}, yu^(-1)] - 
     2*G[{0}, yw]^2*G[{0, 0, 1}, yu^(-1)] + 2*G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*
      G[{0, 0, 1}, yu^(-1)] + 4*G[{0}, yu^(-1)]*G[{yu}, yv^(-1)]*
      G[{0, 0, 1}, yu^(-1)] + 4*G[{0}, yv^(-1)]*G[{yu}, yv^(-1)]*
      G[{0, 0, 1}, yu^(-1)] - 4*G[{0}, yw]*G[{yu}, yv^(-1)]*
      G[{0, 0, 1}, yu^(-1)] - 2*G[{1}, yu^(-1)]*G[{yu}, yv^(-1)]*
      G[{0, 0, 1}, yu^(-1)] - 3*G[{yu}, yv^(-1)]^2*G[{0, 0, 1}, yu^(-1)] - 
     2*G[{1}, yu^(-1)]*G[{yv^(-1)}, yw]*G[{0, 0, 1}, yu^(-1)] - 
     2*G[{1}, yw]*G[{yv^(-1)}, yw]*G[{0, 0, 1}, yu^(-1)] + 
     2*G[{yu}, yv^(-1)]*G[{yv^(-1)}, yw]*G[{0, 0, 1}, yu^(-1)] + 
     G[{yv^(-1)}, yw]^2*G[{0, 0, 1}, yu^(-1)] - 4*G[{0}, yu^(-1)]*
      G[{1/(yu*yv)}, yw]*G[{0, 0, 1}, yu^(-1)] - 4*G[{0}, yv^(-1)]*
      G[{1/(yu*yv)}, yw]*G[{0, 0, 1}, yu^(-1)] + 
     4*G[{0}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 0, 1}, yu^(-1)] + 
     2*G[{1}, yu^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, 0, 1}, yu^(-1)] - 
     6*G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 0, 1}, yu^(-1)] + 
     6*G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, 0, 1}, yu^(-1)] - 
     2*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 0, 1}, yu^(-1)] + 
     2*G[{0, 1}, yu^(-1)]*G[{0, 0, 1}, yu^(-1)] + 
     4*G[{0, 1}, yw]*G[{0, 0, 1}, yu^(-1)] + 4*G[{0, yu}, yv^(-1)]*
      G[{0, 0, 1}, yu^(-1)] - 4*G[{0, 1/(yu*yv)}, yw]*G[{0, 0, 1}, yu^(-1)] - 
     2*G[{1, yu}, yv^(-1)]*G[{0, 0, 1}, yu^(-1)] + 2*G[{1, yv^(-1)}, yw]*
      G[{0, 0, 1}, yu^(-1)] + 6*G[{1, 1/(yu*yv)}, yw]*G[{0, 0, 1}, yu^(-1)] + 
     2*G[{yv^(-1), 1/(yu*yv)}, yw]*G[{0, 0, 1}, yu^(-1)] - 
     4*G[{1}, yw]*G[{yv^(-1)}, yw]*G[{0, 0, 1}, yw] + 
     4*G[{1}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, 0, 1}, yw] + 
     4*G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 0, 1}, yw] - 
     4*G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, 0, 1}, yw] + 
     4*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 0, 1}, yw] - 
     2*G[{1/(yu*yv)}, yw]^2*G[{0, 0, 1}, yw] - 4*G[{0, yv^(-1)}, yw]*
      G[{0, 0, 1}, yw] + 4*G[{0, 1/(yu*yv)}, yw]*G[{0, 0, 1}, yw] + 
     4*G[{1, yv^(-1)}, yw]*G[{0, 0, 1}, yw] - 4*G[{1, 1/(yu*yv)}, yw]*
      G[{0, 0, 1}, yw] - 4*G[{yv^(-1), 1/(yu*yv)}, yw]*G[{0, 0, 1}, yw] - 
     4*G[{1}, yv^(-1)]*G[{yv^(-1)}, yw]*G[{0, 0, yu^(-1)}, yw] + 
     4*G[{1}, yw]*G[{yv^(-1)}, yw]*G[{0, 0, yu^(-1)}, yw] + 
     4*G[{yu}, yv^(-1)]*G[{yv^(-1)}, yw]*G[{0, 0, yu^(-1)}, yw] - 
     4*G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 0, yu^(-1)}, yw] - 
     4*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 0, yu^(-1)}, yw] + 
     2*G[{1/(yu*yv)}, yw]^2*G[{0, 0, yu^(-1)}, yw] + 
     4*G[{0, yv^(-1)}, yw]*G[{0, 0, yu^(-1)}, yw] - 
     4*G[{0, 1/(yu*yv)}, yw]*G[{0, 0, yu^(-1)}, yw] - 
     4*G[{1, yv^(-1)}, yw]*G[{0, 0, yu^(-1)}, yw] + 
     4*G[{1, 1/(yu*yv)}, yw]*G[{0, 0, yu^(-1)}, yw] + 
     4*G[{yv^(-1), 1/(yu*yv)}, yw]*G[{0, 0, yu^(-1)}, yw] - 
     (2*Pi^2*G[{0, 0, yv^(-1)}, yw])/3 + 4*G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*
      G[{0, 0, yv^(-1)}, yw] - 4*G[{1}, yu^(-1)]*G[{yu}, yv^(-1)]*
      G[{0, 0, yv^(-1)}, yw] + 4*G[{1}, yv^(-1)]*G[{yu}, yv^(-1)]*
      G[{0, 0, yv^(-1)}, yw] - 4*G[{1}, yu^(-1)]*G[{yv^(-1)}, yw]*
      G[{0, 0, yv^(-1)}, yw] + 4*G[{1}, yw]*G[{yv^(-1)}, yw]*
      G[{0, 0, yv^(-1)}, yw] + 4*G[{yu}, yv^(-1)]*G[{yv^(-1)}, yw]*
      G[{0, 0, yv^(-1)}, yw] + 4*G[{1}, yu^(-1)]*G[{1/(yu*yv)}, yw]*
      G[{0, 0, yv^(-1)}, yw] - 4*G[{1}, yv^(-1)]*G[{1/(yu*yv)}, yw]*
      G[{0, 0, yv^(-1)}, yw] - 4*G[{1}, yw]*G[{1/(yu*yv)}, yw]*
      G[{0, 0, yv^(-1)}, yw] - 4*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*
      G[{0, 0, yv^(-1)}, yw] + 2*G[{1/(yu*yv)}, yw]^2*
      G[{0, 0, yv^(-1)}, yw] + 4*G[{0, 1}, yu^(-1)]*G[{0, 0, yv^(-1)}, yw] - 
     4*G[{0, 1}, yv^(-1)]*G[{0, 0, yv^(-1)}, yw] + 4*G[{0, yu}, yv^(-1)]*
      G[{0, 0, yv^(-1)}, yw] + 4*G[{0, yv^(-1)}, yw]*G[{0, 0, yv^(-1)}, yw] - 
     4*G[{0, 1/(yu*yv)}, yw]*G[{0, 0, yv^(-1)}, yw] - 
     8*G[{1, yu}, yv^(-1)]*G[{0, 0, yv^(-1)}, yw] - 
     4*G[{1, yv^(-1)}, yw]*G[{0, 0, yv^(-1)}, yw] + 
     4*G[{1, 1/(yu*yv)}, yw]*G[{0, 0, yv^(-1)}, yw] + 
     4*G[{yv^(-1), 1/(yu*yv)}, yw]*G[{0, 0, yv^(-1)}, yw] + 
     (2*Pi^2*G[{0, 0, 1/(yu*yv)}, yw])/3 - 4*G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*
      G[{0, 0, 1/(yu*yv)}, yw] + 4*G[{1}, yu^(-1)]*G[{yu}, yv^(-1)]*
      G[{0, 0, 1/(yu*yv)}, yw] - 4*G[{1}, yv^(-1)]*G[{yu}, yv^(-1)]*
      G[{0, 0, 1/(yu*yv)}, yw] + 4*G[{1}, yu^(-1)]*G[{yv^(-1)}, yw]*
      G[{0, 0, 1/(yu*yv)}, yw] + 4*G[{1}, yv^(-1)]*G[{yv^(-1)}, yw]*
      G[{0, 0, 1/(yu*yv)}, yw] - 4*G[{1}, yw]*G[{yv^(-1)}, yw]*
      G[{0, 0, 1/(yu*yv)}, yw] - 8*G[{yu}, yv^(-1)]*G[{yv^(-1)}, yw]*
      G[{0, 0, 1/(yu*yv)}, yw] - 4*G[{1}, yu^(-1)]*G[{1/(yu*yv)}, yw]*
      G[{0, 0, 1/(yu*yv)}, yw] + 4*G[{1}, yw]*G[{1/(yu*yv)}, yw]*
      G[{0, 0, 1/(yu*yv)}, yw] + 4*G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw]*
      G[{0, 0, 1/(yu*yv)}, yw] + 4*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*
      G[{0, 0, 1/(yu*yv)}, yw] - 2*G[{1/(yu*yv)}, yw]^2*
      G[{0, 0, 1/(yu*yv)}, yw] - 4*G[{0, 1}, yu^(-1)]*
      G[{0, 0, 1/(yu*yv)}, yw] + 4*G[{0, 1}, yv^(-1)]*
      G[{0, 0, 1/(yu*yv)}, yw] - 4*G[{0, yu}, yv^(-1)]*
      G[{0, 0, 1/(yu*yv)}, yw] - 4*G[{0, yv^(-1)}, yw]*
      G[{0, 0, 1/(yu*yv)}, yw] + 4*G[{0, 1/(yu*yv)}, yw]*
      G[{0, 0, 1/(yu*yv)}, yw] + 8*G[{1, yu}, yv^(-1)]*
      G[{0, 0, 1/(yu*yv)}, yw] + 4*G[{1, yv^(-1)}, yw]*
      G[{0, 0, 1/(yu*yv)}, yw] - 4*G[{1, 1/(yu*yv)}, yw]*
      G[{0, 0, 1/(yu*yv)}, yw] - 4*G[{yv^(-1), 1/(yu*yv)}, yw]*
      G[{0, 0, 1/(yu*yv)}, yw] + (Pi^2*G[{0, 1, 1}, yu^(-1)])/3 + 
     4*G[{0}, yu^(-1)]*G[{1}, yv^(-1)]*G[{0, 1, 1}, yu^(-1)] + 
     4*G[{0}, yv^(-1)]*G[{1}, yv^(-1)]*G[{0, 1, 1}, yu^(-1)] - 
     4*G[{0}, yw]*G[{1}, yv^(-1)]*G[{0, 1, 1}, yu^(-1)] - 
     2*G[{1}, yv^(-1)]^2*G[{0, 1, 1}, yu^(-1)] - 4*G[{0}, yu^(-1)]*
      G[{yu}, yv^(-1)]*G[{0, 1, 1}, yu^(-1)] - 4*G[{0}, yv^(-1)]*
      G[{yu}, yv^(-1)]*G[{0, 1, 1}, yu^(-1)] + 4*G[{0}, yw]*G[{yu}, yv^(-1)]*
      G[{0, 1, 1}, yu^(-1)] + 2*G[{yu}, yv^(-1)]^2*G[{0, 1, 1}, yu^(-1)] - 
     4*G[{0}, yu^(-1)]*G[{yv^(-1)}, yw]*G[{0, 1, 1}, yu^(-1)] - 
     4*G[{0}, yv^(-1)]*G[{yv^(-1)}, yw]*G[{0, 1, 1}, yu^(-1)] + 
     4*G[{0}, yw]*G[{yv^(-1)}, yw]*G[{0, 1, 1}, yu^(-1)] + 
     4*G[{1}, yv^(-1)]*G[{yv^(-1)}, yw]*G[{0, 1, 1}, yu^(-1)] - 
     2*G[{yv^(-1)}, yw]^2*G[{0, 1, 1}, yu^(-1)] + 
     4*G[{0}, yu^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, 1, 1}, yu^(-1)] + 
     4*G[{0}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, 1, 1}, yu^(-1)] - 
     4*G[{0}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1, 1}, yu^(-1)] - 
     4*G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, 1, 1}, yu^(-1)] + 
     2*G[{1/(yu*yv)}, yw]^2*G[{0, 1, 1}, yu^(-1)] - 
     2*G[{0, 1}, yu^(-1)]*G[{0, 1, 1}, yu^(-1)] - 
     (Pi^2*G[{0, 1, 1}, yv^(-1)])/3 + 4*G[{0}, yu^(-1)]*G[{1}, yv^(-1)]*
      G[{0, 1, 1}, yv^(-1)] + 4*G[{0}, yv^(-1)]*G[{1}, yv^(-1)]*
      G[{0, 1, 1}, yv^(-1)] - 4*G[{0}, yw]*G[{1}, yv^(-1)]*
      G[{0, 1, 1}, yv^(-1)] - 2*G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*
      G[{0, 1, 1}, yv^(-1)] - 2*G[{1}, yu^(-1)]*G[{yu}, yv^(-1)]*
      G[{0, 1, 1}, yv^(-1)] - 4*G[{1}, yv^(-1)]*G[{yu}, yv^(-1)]*
      G[{0, 1, 1}, yv^(-1)] - 4*G[{0}, yu^(-1)]*G[{yv^(-1)}, yw]*
      G[{0, 1, 1}, yv^(-1)] - 4*G[{0}, yv^(-1)]*G[{yv^(-1)}, yw]*
      G[{0, 1, 1}, yv^(-1)] + 4*G[{0}, yw]*G[{yv^(-1)}, yw]*
      G[{0, 1, 1}, yv^(-1)] + 2*G[{1}, yu^(-1)]*G[{yv^(-1)}, yw]*
      G[{0, 1, 1}, yv^(-1)] + 4*G[{yu}, yv^(-1)]*G[{yv^(-1)}, yw]*
      G[{0, 1, 1}, yv^(-1)] + 2*G[{1}, yu^(-1)]*G[{1/(yu*yv)}, yw]*
      G[{0, 1, 1}, yv^(-1)] + 4*G[{1}, yv^(-1)]*G[{1/(yu*yv)}, yw]*
      G[{0, 1, 1}, yv^(-1)] - 4*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*
      G[{0, 1, 1}, yv^(-1)] + 2*G[{0, 1}, yu^(-1)]*G[{0, 1, 1}, yv^(-1)] - 
     2*G[{0, 1}, yv^(-1)]*G[{0, 1, 1}, yv^(-1)] + 
     6*G[{0}, yu^(-1)]*G[{yv^(-1)}, yw]*G[{0, 1, 1}, yw] + 
     6*G[{0}, yv^(-1)]*G[{yv^(-1)}, yw]*G[{0, 1, 1}, yw] - 
     6*G[{0}, yw]*G[{yv^(-1)}, yw]*G[{0, 1, 1}, yw] - 
     6*G[{1}, yu^(-1)]*G[{yv^(-1)}, yw]*G[{0, 1, 1}, yw] - 
     6*G[{1}, yv^(-1)]*G[{yv^(-1)}, yw]*G[{0, 1, 1}, yw] - 
     2*G[{0}, yu^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, 1, 1}, yw] - 
     2*G[{0}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, 1, 1}, yw] + 
     2*G[{0}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1, 1}, yw] + 
     2*G[{1}, yu^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, 1, 1}, yw] + 
     2*G[{1}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, 1, 1}, yw] - 
     4*G[{0}, yu^(-1)]*G[{yv^(-1)}, yw]*G[{0, 1, yu^(-1)}, yw] - 
     4*G[{0}, yv^(-1)]*G[{yv^(-1)}, yw]*G[{0, 1, yu^(-1)}, yw] + 
     4*G[{0}, yw]*G[{yv^(-1)}, yw]*G[{0, 1, yu^(-1)}, yw] + 
     4*G[{1}, yu^(-1)]*G[{yv^(-1)}, yw]*G[{0, 1, yu^(-1)}, yw] + 
     8*G[{1}, yv^(-1)]*G[{yv^(-1)}, yw]*G[{0, 1, yu^(-1)}, yw] - 
     4*G[{1}, yw]*G[{yv^(-1)}, yw]*G[{0, 1, yu^(-1)}, yw] - 
     4*G[{yu}, yv^(-1)]*G[{yv^(-1)}, yw]*G[{0, 1, yu^(-1)}, yw] + 
     4*G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1, yu^(-1)}, yw] + 
     4*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1, yu^(-1)}, yw] - 
     2*G[{1/(yu*yv)}, yw]^2*G[{0, 1, yu^(-1)}, yw] - 
     4*G[{0, yv^(-1)}, yw]*G[{0, 1, yu^(-1)}, yw] + 
     4*G[{0, 1/(yu*yv)}, yw]*G[{0, 1, yu^(-1)}, yw] + 
     4*G[{1, yv^(-1)}, yw]*G[{0, 1, yu^(-1)}, yw] - 
     4*G[{1, 1/(yu*yv)}, yw]*G[{0, 1, yu^(-1)}, yw] - 
     4*G[{yv^(-1), 1/(yu*yv)}, yw]*G[{0, 1, yu^(-1)}, yw] + 
     (Pi^2*G[{0, 1, yu}, yv^(-1)])/3 - 2*G[{0}, yu^(-1)]*G[{1}, yv^(-1)]*
      G[{0, 1, yu}, yv^(-1)] - 2*G[{0}, yv^(-1)]*G[{1}, yv^(-1)]*
      G[{0, 1, yu}, yv^(-1)] + 2*G[{0}, yw]*G[{1}, yv^(-1)]*
      G[{0, 1, yu}, yv^(-1)] - 2*G[{0}, yu^(-1)]*G[{yu}, yv^(-1)]*
      G[{0, 1, yu}, yv^(-1)] - 2*G[{0}, yv^(-1)]*G[{yu}, yv^(-1)]*
      G[{0, 1, yu}, yv^(-1)] + 2*G[{0}, yw]*G[{yu}, yv^(-1)]*
      G[{0, 1, yu}, yv^(-1)] + 4*G[{1}, yu^(-1)]*G[{yu}, yv^(-1)]*
      G[{0, 1, yu}, yv^(-1)] + 4*G[{1}, yv^(-1)]*G[{yu}, yv^(-1)]*
      G[{0, 1, yu}, yv^(-1)] + 2*G[{0}, yu^(-1)]*G[{yv^(-1)}, yw]*
      G[{0, 1, yu}, yv^(-1)] + 2*G[{0}, yv^(-1)]*G[{yv^(-1)}, yw]*
      G[{0, 1, yu}, yv^(-1)] - 2*G[{0}, yw]*G[{yv^(-1)}, yw]*
      G[{0, 1, yu}, yv^(-1)] - 4*G[{yu}, yv^(-1)]*G[{yv^(-1)}, yw]*
      G[{0, 1, yu}, yv^(-1)] + 2*G[{0}, yu^(-1)]*G[{1/(yu*yv)}, yw]*
      G[{0, 1, yu}, yv^(-1)] + 2*G[{0}, yv^(-1)]*G[{1/(yu*yv)}, yw]*
      G[{0, 1, yu}, yv^(-1)] - 2*G[{0}, yw]*G[{1/(yu*yv)}, yw]*
      G[{0, 1, yu}, yv^(-1)] - 4*G[{1}, yu^(-1)]*G[{1/(yu*yv)}, yw]*
      G[{0, 1, yu}, yv^(-1)] - 4*G[{1}, yv^(-1)]*G[{1/(yu*yv)}, yw]*
      G[{0, 1, yu}, yv^(-1)] + 4*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*
      G[{0, 1, yu}, yv^(-1)] - 2*G[{0, 1}, yu^(-1)]*G[{0, 1, yu}, yv^(-1)] + 
     2*G[{0, 1}, yv^(-1)]*G[{0, 1, yu}, yv^(-1)] + 
     (2*Pi^2*G[{0, 1, yv^(-1)}, yw])/3 - 4*G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*
      G[{0, 1, yv^(-1)}, yw] + 4*G[{1}, yu^(-1)]*G[{yu}, yv^(-1)]*
      G[{0, 1, yv^(-1)}, yw] - 4*G[{1}, yv^(-1)]*G[{yu}, yv^(-1)]*
      G[{0, 1, yv^(-1)}, yw] - 4*G[{0}, yu^(-1)]*G[{yv^(-1)}, yw]*
      G[{0, 1, yv^(-1)}, yw] - 4*G[{0}, yv^(-1)]*G[{yv^(-1)}, yw]*
      G[{0, 1, yv^(-1)}, yw] + 4*G[{0}, yw]*G[{yv^(-1)}, yw]*
      G[{0, 1, yv^(-1)}, yw] + 8*G[{1}, yu^(-1)]*G[{yv^(-1)}, yw]*
      G[{0, 1, yv^(-1)}, yw] + 4*G[{1}, yv^(-1)]*G[{yv^(-1)}, yw]*
      G[{0, 1, yv^(-1)}, yw] - 4*G[{1}, yw]*G[{yv^(-1)}, yw]*
      G[{0, 1, yv^(-1)}, yw] - 4*G[{yu}, yv^(-1)]*G[{yv^(-1)}, yw]*
      G[{0, 1, yv^(-1)}, yw] - 4*G[{1}, yu^(-1)]*G[{1/(yu*yv)}, yw]*
      G[{0, 1, yv^(-1)}, yw] + 4*G[{1}, yv^(-1)]*G[{1/(yu*yv)}, yw]*
      G[{0, 1, yv^(-1)}, yw] + 4*G[{1}, yw]*G[{1/(yu*yv)}, yw]*
      G[{0, 1, yv^(-1)}, yw] + 4*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*
      G[{0, 1, yv^(-1)}, yw] - 2*G[{1/(yu*yv)}, yw]^2*
      G[{0, 1, yv^(-1)}, yw] - 4*G[{0, 1}, yu^(-1)]*G[{0, 1, yv^(-1)}, yw] + 
     4*G[{0, 1}, yv^(-1)]*G[{0, 1, yv^(-1)}, yw] - 
     4*G[{0, 1}, yw]*G[{0, 1, yv^(-1)}, yw] - 4*G[{0, yu}, yv^(-1)]*
      G[{0, 1, yv^(-1)}, yw] - 4*G[{0, yv^(-1)}, yw]*G[{0, 1, yv^(-1)}, yw] + 
     4*G[{0, 1/(yu*yv)}, yw]*G[{0, 1, yv^(-1)}, yw] + 
     8*G[{1, yu}, yv^(-1)]*G[{0, 1, yv^(-1)}, yw] + 
     4*G[{1, yv^(-1)}, yw]*G[{0, 1, yv^(-1)}, yw] - 
     4*G[{1, 1/(yu*yv)}, yw]*G[{0, 1, yv^(-1)}, yw] - 
     4*G[{yv^(-1), 1/(yu*yv)}, yw]*G[{0, 1, yv^(-1)}, yw] - 
     (Pi^2*G[{0, 1, 1/(yu*yv)}, yw])/3 - 2*G[{0}, yu^(-1)]*G[{1}, yv^(-1)]*
      G[{0, 1, 1/(yu*yv)}, yw] - 2*G[{0}, yv^(-1)]*G[{1}, yv^(-1)]*
      G[{0, 1, 1/(yu*yv)}, yw] + 2*G[{0}, yw]*G[{1}, yv^(-1)]*
      G[{0, 1, 1/(yu*yv)}, yw] + 4*G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*
      G[{0, 1, 1/(yu*yv)}, yw] + 2*G[{1}, yv^(-1)]^2*
      G[{0, 1, 1/(yu*yv)}, yw] + 2*G[{0}, yu^(-1)]*G[{yu}, yv^(-1)]*
      G[{0, 1, 1/(yu*yv)}, yw] + 2*G[{0}, yv^(-1)]*G[{yu}, yv^(-1)]*
      G[{0, 1, 1/(yu*yv)}, yw] - 2*G[{0}, yw]*G[{yu}, yv^(-1)]*
      G[{0, 1, 1/(yu*yv)}, yw] - 4*G[{1}, yu^(-1)]*G[{yu}, yv^(-1)]*
      G[{0, 1, 1/(yu*yv)}, yw] + 4*G[{0}, yu^(-1)]*G[{yv^(-1)}, yw]*
      G[{0, 1, 1/(yu*yv)}, yw] + 4*G[{0}, yv^(-1)]*G[{yv^(-1)}, yw]*
      G[{0, 1, 1/(yu*yv)}, yw] - 4*G[{0}, yw]*G[{yv^(-1)}, yw]*
      G[{0, 1, 1/(yu*yv)}, yw] - 6*G[{1}, yu^(-1)]*G[{yv^(-1)}, yw]*
      G[{0, 1, 1/(yu*yv)}, yw] - 6*G[{1}, yv^(-1)]*G[{yv^(-1)}, yw]*
      G[{0, 1, 1/(yu*yv)}, yw] + 4*G[{yu}, yv^(-1)]*G[{yv^(-1)}, yw]*
      G[{0, 1, 1/(yu*yv)}, yw] + 2*G[{1}, yu^(-1)]*G[{1/(yu*yv)}, yw]*
      G[{0, 1, 1/(yu*yv)}, yw] + 2*G[{1}, yv^(-1)]*G[{1/(yu*yv)}, yw]*
      G[{0, 1, 1/(yu*yv)}, yw] - 4*G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw]*
      G[{0, 1, 1/(yu*yv)}, yw] + 2*G[{0, 1}, yu^(-1)]*
      G[{0, 1, 1/(yu*yv)}, yw] - 2*G[{0, 1}, yv^(-1)]*
      G[{0, 1, 1/(yu*yv)}, yw] + 2*G[{0, 1}, yw]*G[{0, 1, 1/(yu*yv)}, yw] + 
     2*G[{0, yu}, yv^(-1)]*G[{0, 1, 1/(yu*yv)}, yw] - 
     4*G[{1, yu}, yv^(-1)]*G[{0, 1, 1/(yu*yv)}, yw] - 
     6*G[{0}, yu^(-1)]*G[{yv^(-1)}, yw]*G[{0, yu^(-1), 1}, yw] - 
     6*G[{0}, yv^(-1)]*G[{yv^(-1)}, yw]*G[{0, yu^(-1), 1}, yw] + 
     6*G[{0}, yw]*G[{yv^(-1)}, yw]*G[{0, yu^(-1), 1}, yw] + 
     6*G[{1}, yu^(-1)]*G[{yv^(-1)}, yw]*G[{0, yu^(-1), 1}, yw] + 
     6*G[{1}, yv^(-1)]*G[{yv^(-1)}, yw]*G[{0, yu^(-1), 1}, yw] + 
     2*G[{0}, yu^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1), 1}, yw] + 
     2*G[{0}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1), 1}, yw] - 
     2*G[{0}, yw]*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1), 1}, yw] - 
     2*G[{1}, yu^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1), 1}, yw] - 
     2*G[{1}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1), 1}, yw] + 
     4*G[{0}, yu^(-1)]*G[{yv^(-1)}, yw]*G[{0, yu^(-1), yu^(-1)}, yw] + 
     4*G[{0}, yv^(-1)]*G[{yv^(-1)}, yw]*G[{0, yu^(-1), yu^(-1)}, yw] - 
     4*G[{0}, yw]*G[{yv^(-1)}, yw]*G[{0, yu^(-1), yu^(-1)}, yw] - 
     4*G[{1}, yu^(-1)]*G[{yv^(-1)}, yw]*G[{0, yu^(-1), yu^(-1)}, yw] - 
     8*G[{1}, yv^(-1)]*G[{yv^(-1)}, yw]*G[{0, yu^(-1), yu^(-1)}, yw] + 
     4*G[{1}, yw]*G[{yv^(-1)}, yw]*G[{0, yu^(-1), yu^(-1)}, yw] + 
     4*G[{yu}, yv^(-1)]*G[{yv^(-1)}, yw]*G[{0, yu^(-1), yu^(-1)}, yw] - 
     4*G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1), yu^(-1)}, yw] - 
     4*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1), yu^(-1)}, yw] + 
     2*G[{1/(yu*yv)}, yw]^2*G[{0, yu^(-1), yu^(-1)}, yw] + 
     4*G[{0, yv^(-1)}, yw]*G[{0, yu^(-1), yu^(-1)}, yw] - 
     4*G[{0, 1/(yu*yv)}, yw]*G[{0, yu^(-1), yu^(-1)}, yw] - 
     4*G[{1, yv^(-1)}, yw]*G[{0, yu^(-1), yu^(-1)}, yw] + 
     4*G[{1, 1/(yu*yv)}, yw]*G[{0, yu^(-1), yu^(-1)}, yw] + 
     4*G[{yv^(-1), 1/(yu*yv)}, yw]*G[{0, yu^(-1), yu^(-1)}, yw] - 
     (Pi^2*G[{0, yu^(-1), yv^(-1)}, yw])/3 + 2*G[{0}, yu^(-1)]*
      G[{1}, yv^(-1)]*G[{0, yu^(-1), yv^(-1)}, yw] + 
     2*G[{0}, yv^(-1)]*G[{1}, yv^(-1)]*G[{0, yu^(-1), yv^(-1)}, yw] - 
     2*G[{0}, yw]*G[{1}, yv^(-1)]*G[{0, yu^(-1), yv^(-1)}, yw] - 
     2*G[{1}, yv^(-1)]^2*G[{0, yu^(-1), yv^(-1)}, yw] - 
     2*G[{0}, yu^(-1)]*G[{yu}, yv^(-1)]*G[{0, yu^(-1), yv^(-1)}, yw] - 
     2*G[{0}, yv^(-1)]*G[{yu}, yv^(-1)]*G[{0, yu^(-1), yv^(-1)}, yw] + 
     2*G[{0}, yw]*G[{yu}, yv^(-1)]*G[{0, yu^(-1), yv^(-1)}, yw] + 
     4*G[{1}, yv^(-1)]*G[{yu}, yv^(-1)]*G[{0, yu^(-1), yv^(-1)}, yw] + 
     2*G[{0}, yu^(-1)]*G[{yv^(-1)}, yw]*G[{0, yu^(-1), yv^(-1)}, yw] + 
     2*G[{0}, yv^(-1)]*G[{yv^(-1)}, yw]*G[{0, yu^(-1), yv^(-1)}, yw] - 
     2*G[{0}, yw]*G[{yv^(-1)}, yw]*G[{0, yu^(-1), yv^(-1)}, yw] - 
     4*G[{1}, yu^(-1)]*G[{yv^(-1)}, yw]*G[{0, yu^(-1), yv^(-1)}, yw] - 
     4*G[{1}, yv^(-1)]*G[{yv^(-1)}, yw]*G[{0, yu^(-1), yv^(-1)}, yw] + 
     4*G[{1}, yw]*G[{yv^(-1)}, yw]*G[{0, yu^(-1), yv^(-1)}, yw] + 
     4*G[{yu}, yv^(-1)]*G[{yv^(-1)}, yw]*G[{0, yu^(-1), yv^(-1)}, yw] + 
     2*G[{0}, yu^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1), yv^(-1)}, yw] + 
     2*G[{0}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1), yv^(-1)}, yw] - 
     2*G[{0}, yw]*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1), yv^(-1)}, yw] - 
     4*G[{1}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1), yv^(-1)}, yw] - 
     4*G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1), yv^(-1)}, yw] - 
     4*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1), yv^(-1)}, yw] + 
     2*G[{1/(yu*yv)}, yw]^2*G[{0, yu^(-1), yv^(-1)}, yw] + 
     2*G[{0, 1}, yu^(-1)]*G[{0, yu^(-1), yv^(-1)}, yw] - 
     2*G[{0, 1}, yv^(-1)]*G[{0, yu^(-1), yv^(-1)}, yw] + 
     2*G[{0, 1}, yw]*G[{0, yu^(-1), yv^(-1)}, yw] - 
     2*G[{0, yu^(-1)}, yw]*G[{0, yu^(-1), yv^(-1)}, yw] + 
     2*G[{0, yu}, yv^(-1)]*G[{0, yu^(-1), yv^(-1)}, yw] + 
     4*G[{0, yv^(-1)}, yw]*G[{0, yu^(-1), yv^(-1)}, yw] - 
     4*G[{0, 1/(yu*yv)}, yw]*G[{0, yu^(-1), yv^(-1)}, yw] - 
     4*G[{1, yu}, yv^(-1)]*G[{0, yu^(-1), yv^(-1)}, yw] - 
     4*G[{1, yv^(-1)}, yw]*G[{0, yu^(-1), yv^(-1)}, yw] + 
     4*G[{1, 1/(yu*yv)}, yw]*G[{0, yu^(-1), yv^(-1)}, yw] + 
     4*G[{yv^(-1), 1/(yu*yv)}, yw]*G[{0, yu^(-1), yv^(-1)}, yw] - 
     2*G[{0}, yu^(-1)]*G[{yv^(-1)}, yw]*G[{0, yu^(-1), 1/(yu*yv)}, yw] - 
     2*G[{0}, yv^(-1)]*G[{yv^(-1)}, yw]*G[{0, yu^(-1), 1/(yu*yv)}, yw] + 
     2*G[{0}, yw]*G[{yv^(-1)}, yw]*G[{0, yu^(-1), 1/(yu*yv)}, yw] + 
     2*G[{1}, yu^(-1)]*G[{yv^(-1)}, yw]*G[{0, yu^(-1), 1/(yu*yv)}, yw] + 
     2*G[{1}, yv^(-1)]*G[{yv^(-1)}, yw]*G[{0, yu^(-1), 1/(yu*yv)}, yw] - 
     2*G[{0}, yu^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1), 1/(yu*yv)}, yw] - 
     2*G[{0}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1), 1/(yu*yv)}, yw] + 
     2*G[{0}, yw]*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1), 1/(yu*yv)}, yw] + 
     2*G[{1}, yu^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1), 1/(yu*yv)}, yw] + 
     2*G[{1}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1), 1/(yu*yv)}, yw] + 
     6*G[{0, yv^(-1)}, yw]*G[{0, yu^(-1), 1/(yu*yv)}, yw] - 
     2*G[{0}, yu^(-1)]*G[{1}, yv^(-1)]*G[{0, yu, 1}, yv^(-1)] - 
     2*G[{0}, yv^(-1)]*G[{1}, yv^(-1)]*G[{0, yu, 1}, yv^(-1)] + 
     2*G[{0}, yw]*G[{1}, yv^(-1)]*G[{0, yu, 1}, yv^(-1)] + 
     2*G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*G[{0, yu, 1}, yv^(-1)] - 
     2*G[{0}, yu^(-1)]*G[{yu}, yv^(-1)]*G[{0, yu, 1}, yv^(-1)] - 
     2*G[{0}, yv^(-1)]*G[{yu}, yv^(-1)]*G[{0, yu, 1}, yv^(-1)] + 
     2*G[{0}, yw]*G[{yu}, yv^(-1)]*G[{0, yu, 1}, yv^(-1)] + 
     2*G[{1}, yu^(-1)]*G[{yu}, yv^(-1)]*G[{0, yu, 1}, yv^(-1)] + 
     4*G[{1}, yv^(-1)]*G[{yu}, yv^(-1)]*G[{0, yu, 1}, yv^(-1)] + 
     2*G[{0}, yu^(-1)]*G[{yv^(-1)}, yw]*G[{0, yu, 1}, yv^(-1)] + 
     2*G[{0}, yv^(-1)]*G[{yv^(-1)}, yw]*G[{0, yu, 1}, yv^(-1)] - 
     2*G[{0}, yw]*G[{yv^(-1)}, yw]*G[{0, yu, 1}, yv^(-1)] - 
     2*G[{1}, yu^(-1)]*G[{yv^(-1)}, yw]*G[{0, yu, 1}, yv^(-1)] - 
     4*G[{yu}, yv^(-1)]*G[{yv^(-1)}, yw]*G[{0, yu, 1}, yv^(-1)] + 
     2*G[{0}, yu^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, yu, 1}, yv^(-1)] + 
     2*G[{0}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, yu, 1}, yv^(-1)] - 
     2*G[{0}, yw]*G[{1/(yu*yv)}, yw]*G[{0, yu, 1}, yv^(-1)] - 
     2*G[{1}, yu^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, yu, 1}, yv^(-1)] - 
     4*G[{1}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, yu, 1}, yv^(-1)] + 
     4*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{0, yu, 1}, yv^(-1)] + 
     4*G[{0}, yu^(-1)]*G[{yu}, yv^(-1)]*G[{0, yu, yu}, yv^(-1)] + 
     4*G[{0}, yv^(-1)]*G[{yu}, yv^(-1)]*G[{0, yu, yu}, yv^(-1)] - 
     4*G[{0}, yw]*G[{yu}, yv^(-1)]*G[{0, yu, yu}, yv^(-1)] - 
     4*G[{1}, yu^(-1)]*G[{yu}, yv^(-1)]*G[{0, yu, yu}, yv^(-1)] - 
     4*G[{1}, yv^(-1)]*G[{yu}, yv^(-1)]*G[{0, yu, yu}, yv^(-1)] + 
     4*G[{yu}, yv^(-1)]*G[{yv^(-1)}, yw]*G[{0, yu, yu}, yv^(-1)] - 
     4*G[{0}, yu^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, yu, yu}, yv^(-1)] - 
     4*G[{0}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, yu, yu}, yv^(-1)] + 
     4*G[{0}, yw]*G[{1/(yu*yv)}, yw]*G[{0, yu, yu}, yv^(-1)] + 
     4*G[{1}, yu^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, yu, yu}, yv^(-1)] + 
     4*G[{1}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, yu, yu}, yv^(-1)] - 
     4*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{0, yu, yu}, yv^(-1)] - 
     6*G[{0}, yu^(-1)]*G[{yv^(-1)}, yw]*G[{0, yv^(-1), 1}, yw] - 
     6*G[{0}, yv^(-1)]*G[{yv^(-1)}, yw]*G[{0, yv^(-1), 1}, yw] + 
     6*G[{0}, yw]*G[{yv^(-1)}, yw]*G[{0, yv^(-1), 1}, yw] + 
     6*G[{1}, yu^(-1)]*G[{yv^(-1)}, yw]*G[{0, yv^(-1), 1}, yw] + 
     6*G[{1}, yv^(-1)]*G[{yv^(-1)}, yw]*G[{0, yv^(-1), 1}, yw] + 
     2*G[{0}, yu^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, yv^(-1), 1}, yw] + 
     2*G[{0}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, yv^(-1), 1}, yw] - 
     2*G[{0}, yw]*G[{1/(yu*yv)}, yw]*G[{0, yv^(-1), 1}, yw] - 
     2*G[{1}, yu^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, yv^(-1), 1}, yw] - 
     2*G[{1}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, yv^(-1), 1}, yw] - 
     (Pi^2*G[{0, yv^(-1), yu^(-1)}, yw])/3 + 2*G[{0}, yu^(-1)]*
      G[{1}, yv^(-1)]*G[{0, yv^(-1), yu^(-1)}, yw] + 
     2*G[{0}, yv^(-1)]*G[{1}, yv^(-1)]*G[{0, yv^(-1), yu^(-1)}, yw] - 
     2*G[{0}, yw]*G[{1}, yv^(-1)]*G[{0, yv^(-1), yu^(-1)}, yw] - 
     2*G[{1}, yv^(-1)]^2*G[{0, yv^(-1), yu^(-1)}, yw] - 
     2*G[{0}, yu^(-1)]*G[{yu}, yv^(-1)]*G[{0, yv^(-1), yu^(-1)}, yw] - 
     2*G[{0}, yv^(-1)]*G[{yu}, yv^(-1)]*G[{0, yv^(-1), yu^(-1)}, yw] + 
     2*G[{0}, yw]*G[{yu}, yv^(-1)]*G[{0, yv^(-1), yu^(-1)}, yw] + 
     4*G[{1}, yv^(-1)]*G[{yu}, yv^(-1)]*G[{0, yv^(-1), yu^(-1)}, yw] + 
     2*G[{0}, yu^(-1)]*G[{yv^(-1)}, yw]*G[{0, yv^(-1), yu^(-1)}, yw] + 
     2*G[{0}, yv^(-1)]*G[{yv^(-1)}, yw]*G[{0, yv^(-1), yu^(-1)}, yw] - 
     2*G[{0}, yw]*G[{yv^(-1)}, yw]*G[{0, yv^(-1), yu^(-1)}, yw] - 
     4*G[{1}, yu^(-1)]*G[{yv^(-1)}, yw]*G[{0, yv^(-1), yu^(-1)}, yw] - 
     4*G[{1}, yv^(-1)]*G[{yv^(-1)}, yw]*G[{0, yv^(-1), yu^(-1)}, yw] + 
     4*G[{1}, yw]*G[{yv^(-1)}, yw]*G[{0, yv^(-1), yu^(-1)}, yw] + 
     4*G[{yu}, yv^(-1)]*G[{yv^(-1)}, yw]*G[{0, yv^(-1), yu^(-1)}, yw] + 
     2*G[{0}, yu^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, yv^(-1), yu^(-1)}, yw] + 
     2*G[{0}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, yv^(-1), yu^(-1)}, yw] - 
     2*G[{0}, yw]*G[{1/(yu*yv)}, yw]*G[{0, yv^(-1), yu^(-1)}, yw] - 
     4*G[{1}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, yv^(-1), yu^(-1)}, yw] - 
     4*G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{0, yv^(-1), yu^(-1)}, yw] - 
     4*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{0, yv^(-1), yu^(-1)}, yw] + 
     2*G[{1/(yu*yv)}, yw]^2*G[{0, yv^(-1), yu^(-1)}, yw] + 
     2*G[{0, 1}, yu^(-1)]*G[{0, yv^(-1), yu^(-1)}, yw] - 
     2*G[{0, 1}, yv^(-1)]*G[{0, yv^(-1), yu^(-1)}, yw] + 
     2*G[{0, 1}, yw]*G[{0, yv^(-1), yu^(-1)}, yw] - 
     2*G[{0, yu^(-1)}, yw]*G[{0, yv^(-1), yu^(-1)}, yw] + 
     2*G[{0, yu}, yv^(-1)]*G[{0, yv^(-1), yu^(-1)}, yw] - 
     2*G[{0, yv^(-1)}, yw]*G[{0, yv^(-1), yu^(-1)}, yw] - 
     4*G[{0, 1/(yu*yv)}, yw]*G[{0, yv^(-1), yu^(-1)}, yw] - 
     4*G[{1, yu}, yv^(-1)]*G[{0, yv^(-1), yu^(-1)}, yw] - 
     4*G[{1, yv^(-1)}, yw]*G[{0, yv^(-1), yu^(-1)}, yw] + 
     4*G[{1, 1/(yu*yv)}, yw]*G[{0, yv^(-1), yu^(-1)}, yw] + 
     4*G[{yv^(-1), 1/(yu*yv)}, yw]*G[{0, yv^(-1), yu^(-1)}, yw] - 
     (2*Pi^2*G[{0, yv^(-1), yv^(-1)}, yw])/3 + 4*G[{1}, yu^(-1)]*
      G[{1}, yv^(-1)]*G[{0, yv^(-1), yv^(-1)}, yw] - 
     4*G[{1}, yu^(-1)]*G[{yu}, yv^(-1)]*G[{0, yv^(-1), yv^(-1)}, yw] + 
     4*G[{1}, yv^(-1)]*G[{yu}, yv^(-1)]*G[{0, yv^(-1), yv^(-1)}, yw] + 
     4*G[{0}, yu^(-1)]*G[{yv^(-1)}, yw]*G[{0, yv^(-1), yv^(-1)}, yw] + 
     4*G[{0}, yv^(-1)]*G[{yv^(-1)}, yw]*G[{0, yv^(-1), yv^(-1)}, yw] - 
     4*G[{0}, yw]*G[{yv^(-1)}, yw]*G[{0, yv^(-1), yv^(-1)}, yw] - 
     8*G[{1}, yu^(-1)]*G[{yv^(-1)}, yw]*G[{0, yv^(-1), yv^(-1)}, yw] - 
     4*G[{1}, yv^(-1)]*G[{yv^(-1)}, yw]*G[{0, yv^(-1), yv^(-1)}, yw] + 
     4*G[{1}, yw]*G[{yv^(-1)}, yw]*G[{0, yv^(-1), yv^(-1)}, yw] + 
     4*G[{yu}, yv^(-1)]*G[{yv^(-1)}, yw]*G[{0, yv^(-1), yv^(-1)}, yw] + 
     4*G[{1}, yu^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, yv^(-1), yv^(-1)}, yw] - 
     4*G[{1}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, yv^(-1), yv^(-1)}, yw] - 
     4*G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{0, yv^(-1), yv^(-1)}, yw] - 
     4*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{0, yv^(-1), yv^(-1)}, yw] + 
     2*G[{1/(yu*yv)}, yw]^2*G[{0, yv^(-1), yv^(-1)}, yw] + 
     4*G[{0, 1}, yu^(-1)]*G[{0, yv^(-1), yv^(-1)}, yw] - 
     4*G[{0, 1}, yv^(-1)]*G[{0, yv^(-1), yv^(-1)}, yw] + 
     4*G[{0, 1}, yw]*G[{0, yv^(-1), yv^(-1)}, yw] - 
     4*G[{0, yu^(-1)}, yw]*G[{0, yv^(-1), yv^(-1)}, yw] + 
     4*G[{0, yu}, yv^(-1)]*G[{0, yv^(-1), yv^(-1)}, yw] - 
     4*G[{0, yv^(-1)}, yw]*G[{0, yv^(-1), yv^(-1)}, yw] - 
     4*G[{0, 1/(yu*yv)}, yw]*G[{0, yv^(-1), yv^(-1)}, yw] - 
     8*G[{1, yu}, yv^(-1)]*G[{0, yv^(-1), yv^(-1)}, yw] - 
     4*G[{1, yv^(-1)}, yw]*G[{0, yv^(-1), yv^(-1)}, yw] + 
     4*G[{1, 1/(yu*yv)}, yw]*G[{0, yv^(-1), yv^(-1)}, yw] + 
     4*G[{yv^(-1), 1/(yu*yv)}, yw]*G[{0, yv^(-1), yv^(-1)}, yw] - 
     2*G[{0}, yu^(-1)]*G[{yv^(-1)}, yw]*G[{0, yv^(-1), 1/(yu*yv)}, yw] - 
     2*G[{0}, yv^(-1)]*G[{yv^(-1)}, yw]*G[{0, yv^(-1), 1/(yu*yv)}, yw] + 
     2*G[{0}, yw]*G[{yv^(-1)}, yw]*G[{0, yv^(-1), 1/(yu*yv)}, yw] + 
     2*G[{1}, yu^(-1)]*G[{yv^(-1)}, yw]*G[{0, yv^(-1), 1/(yu*yv)}, yw] + 
     2*G[{1}, yv^(-1)]*G[{yv^(-1)}, yw]*G[{0, yv^(-1), 1/(yu*yv)}, yw] - 
     2*G[{0}, yu^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, yv^(-1), 1/(yu*yv)}, yw] - 
     2*G[{0}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, yv^(-1), 1/(yu*yv)}, yw] + 
     2*G[{0}, yw]*G[{1/(yu*yv)}, yw]*G[{0, yv^(-1), 1/(yu*yv)}, yw] + 
     2*G[{1}, yu^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, yv^(-1), 1/(yu*yv)}, yw] + 
     2*G[{1}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, yv^(-1), 1/(yu*yv)}, yw] + 
     6*G[{0}, yu^(-1)]*G[{yv^(-1)}, yw]*G[{0, 1/(yu*yv), 1}, yw] + 
     6*G[{0}, yv^(-1)]*G[{yv^(-1)}, yw]*G[{0, 1/(yu*yv), 1}, yw] - 
     6*G[{0}, yw]*G[{yv^(-1)}, yw]*G[{0, 1/(yu*yv), 1}, yw] - 
     6*G[{1}, yu^(-1)]*G[{yv^(-1)}, yw]*G[{0, 1/(yu*yv), 1}, yw] - 
     6*G[{1}, yv^(-1)]*G[{yv^(-1)}, yw]*G[{0, 1/(yu*yv), 1}, yw] - 
     2*G[{0}, yu^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv), 1}, yw] - 
     2*G[{0}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv), 1}, yw] + 
     2*G[{0}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv), 1}, yw] + 
     2*G[{1}, yu^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv), 1}, yw] + 
     2*G[{1}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv), 1}, yw] + 
     (Pi^2*G[{0, 1/(yu*yv), yu^(-1)}, yw])/3 - 2*G[{0}, yu^(-1)]*
      G[{1}, yv^(-1)]*G[{0, 1/(yu*yv), yu^(-1)}, yw] - 
     2*G[{0}, yv^(-1)]*G[{1}, yv^(-1)]*G[{0, 1/(yu*yv), yu^(-1)}, yw] + 
     2*G[{0}, yw]*G[{1}, yv^(-1)]*G[{0, 1/(yu*yv), yu^(-1)}, yw] + 
     2*G[{1}, yv^(-1)]^2*G[{0, 1/(yu*yv), yu^(-1)}, yw] + 
     2*G[{0}, yu^(-1)]*G[{yu}, yv^(-1)]*G[{0, 1/(yu*yv), yu^(-1)}, yw] + 
     2*G[{0}, yv^(-1)]*G[{yu}, yv^(-1)]*G[{0, 1/(yu*yv), yu^(-1)}, yw] - 
     2*G[{0}, yw]*G[{yu}, yv^(-1)]*G[{0, 1/(yu*yv), yu^(-1)}, yw] - 
     4*G[{1}, yv^(-1)]*G[{yu}, yv^(-1)]*G[{0, 1/(yu*yv), yu^(-1)}, yw] - 
     2*G[{0}, yu^(-1)]*G[{yv^(-1)}, yw]*G[{0, 1/(yu*yv), yu^(-1)}, yw] - 
     2*G[{0}, yv^(-1)]*G[{yv^(-1)}, yw]*G[{0, 1/(yu*yv), yu^(-1)}, yw] + 
     2*G[{0}, yw]*G[{yv^(-1)}, yw]*G[{0, 1/(yu*yv), yu^(-1)}, yw] + 
     4*G[{1}, yu^(-1)]*G[{yv^(-1)}, yw]*G[{0, 1/(yu*yv), yu^(-1)}, yw] + 
     4*G[{1}, yv^(-1)]*G[{yv^(-1)}, yw]*G[{0, 1/(yu*yv), yu^(-1)}, yw] - 
     4*G[{1}, yw]*G[{yv^(-1)}, yw]*G[{0, 1/(yu*yv), yu^(-1)}, yw] - 
     4*G[{yu}, yv^(-1)]*G[{yv^(-1)}, yw]*G[{0, 1/(yu*yv), yu^(-1)}, yw] - 
     2*G[{0}, yu^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv), yu^(-1)}, yw] - 
     2*G[{0}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv), yu^(-1)}, yw] + 
     2*G[{0}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv), yu^(-1)}, yw] + 
     4*G[{1}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv), yu^(-1)}, yw] + 
     4*G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv), yu^(-1)}, yw] + 
     4*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv), yu^(-1)}, yw] - 
     2*G[{1/(yu*yv)}, yw]^2*G[{0, 1/(yu*yv), yu^(-1)}, yw] - 
     2*G[{0, 1}, yu^(-1)]*G[{0, 1/(yu*yv), yu^(-1)}, yw] + 
     2*G[{0, 1}, yv^(-1)]*G[{0, 1/(yu*yv), yu^(-1)}, yw] - 
     2*G[{0, 1}, yw]*G[{0, 1/(yu*yv), yu^(-1)}, yw] + 
     2*G[{0, yu^(-1)}, yw]*G[{0, 1/(yu*yv), yu^(-1)}, yw] - 
     2*G[{0, yu}, yv^(-1)]*G[{0, 1/(yu*yv), yu^(-1)}, yw] + 
     2*G[{0, yv^(-1)}, yw]*G[{0, 1/(yu*yv), yu^(-1)}, yw] - 
     2*G[{0, 1/(yu*yv)}, yw]*G[{0, 1/(yu*yv), yu^(-1)}, yw] + 
     4*G[{1, yu}, yv^(-1)]*G[{0, 1/(yu*yv), yu^(-1)}, yw] + 
     4*G[{1, yv^(-1)}, yw]*G[{0, 1/(yu*yv), yu^(-1)}, yw] - 
     4*G[{1, 1/(yu*yv)}, yw]*G[{0, 1/(yu*yv), yu^(-1)}, yw] - 
     4*G[{yv^(-1), 1/(yu*yv)}, yw]*G[{0, 1/(yu*yv), yu^(-1)}, yw] + 
     (Pi^2*G[{0, 1/(yu*yv), yv^(-1)}, yw])/3 - 2*G[{0}, yu^(-1)]*
      G[{1}, yv^(-1)]*G[{0, 1/(yu*yv), yv^(-1)}, yw] - 
     2*G[{0}, yv^(-1)]*G[{1}, yv^(-1)]*G[{0, 1/(yu*yv), yv^(-1)}, yw] + 
     2*G[{0}, yw]*G[{1}, yv^(-1)]*G[{0, 1/(yu*yv), yv^(-1)}, yw] + 
     2*G[{1}, yv^(-1)]^2*G[{0, 1/(yu*yv), yv^(-1)}, yw] + 
     2*G[{0}, yu^(-1)]*G[{yu}, yv^(-1)]*G[{0, 1/(yu*yv), yv^(-1)}, yw] + 
     2*G[{0}, yv^(-1)]*G[{yu}, yv^(-1)]*G[{0, 1/(yu*yv), yv^(-1)}, yw] - 
     2*G[{0}, yw]*G[{yu}, yv^(-1)]*G[{0, 1/(yu*yv), yv^(-1)}, yw] - 
     4*G[{1}, yv^(-1)]*G[{yu}, yv^(-1)]*G[{0, 1/(yu*yv), yv^(-1)}, yw] - 
     2*G[{0}, yu^(-1)]*G[{yv^(-1)}, yw]*G[{0, 1/(yu*yv), yv^(-1)}, yw] - 
     2*G[{0}, yv^(-1)]*G[{yv^(-1)}, yw]*G[{0, 1/(yu*yv), yv^(-1)}, yw] + 
     2*G[{0}, yw]*G[{yv^(-1)}, yw]*G[{0, 1/(yu*yv), yv^(-1)}, yw] + 
     4*G[{1}, yu^(-1)]*G[{yv^(-1)}, yw]*G[{0, 1/(yu*yv), yv^(-1)}, yw] + 
     4*G[{1}, yv^(-1)]*G[{yv^(-1)}, yw]*G[{0, 1/(yu*yv), yv^(-1)}, yw] - 
     4*G[{1}, yw]*G[{yv^(-1)}, yw]*G[{0, 1/(yu*yv), yv^(-1)}, yw] - 
     4*G[{yu}, yv^(-1)]*G[{yv^(-1)}, yw]*G[{0, 1/(yu*yv), yv^(-1)}, yw] - 
     2*G[{0}, yu^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv), yv^(-1)}, yw] - 
     2*G[{0}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv), yv^(-1)}, yw] + 
     2*G[{0}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv), yv^(-1)}, yw] + 
     4*G[{1}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv), yv^(-1)}, yw] + 
     4*G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv), yv^(-1)}, yw] + 
     4*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv), yv^(-1)}, yw] - 
     2*G[{1/(yu*yv)}, yw]^2*G[{0, 1/(yu*yv), yv^(-1)}, yw] - 
     2*G[{0, 1}, yu^(-1)]*G[{0, 1/(yu*yv), yv^(-1)}, yw] + 
     2*G[{0, 1}, yv^(-1)]*G[{0, 1/(yu*yv), yv^(-1)}, yw] - 
     2*G[{0, 1}, yw]*G[{0, 1/(yu*yv), yv^(-1)}, yw] + 
     2*G[{0, yu^(-1)}, yw]*G[{0, 1/(yu*yv), yv^(-1)}, yw] - 
     2*G[{0, yu}, yv^(-1)]*G[{0, 1/(yu*yv), yv^(-1)}, yw] + 
     2*G[{0, yv^(-1)}, yw]*G[{0, 1/(yu*yv), yv^(-1)}, yw] - 
     2*G[{0, 1/(yu*yv)}, yw]*G[{0, 1/(yu*yv), yv^(-1)}, yw] + 
     4*G[{1, yu}, yv^(-1)]*G[{0, 1/(yu*yv), yv^(-1)}, yw] + 
     4*G[{1, yv^(-1)}, yw]*G[{0, 1/(yu*yv), yv^(-1)}, yw] - 
     4*G[{1, 1/(yu*yv)}, yw]*G[{0, 1/(yu*yv), yv^(-1)}, yw] - 
     4*G[{yv^(-1), 1/(yu*yv)}, yw]*G[{0, 1/(yu*yv), yv^(-1)}, yw] + 
     (Pi^2*G[{0, 1/(yu*yv), 1/(yu*yv)}, yw])/3 + 2*G[{0}, yu^(-1)]*
      G[{1}, yv^(-1)]*G[{0, 1/(yu*yv), 1/(yu*yv)}, yw] + 
     2*G[{0}, yv^(-1)]*G[{1}, yv^(-1)]*G[{0, 1/(yu*yv), 1/(yu*yv)}, yw] - 
     2*G[{0}, yw]*G[{1}, yv^(-1)]*G[{0, 1/(yu*yv), 1/(yu*yv)}, yw] - 
     4*G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*G[{0, 1/(yu*yv), 1/(yu*yv)}, yw] - 
     2*G[{1}, yv^(-1)]^2*G[{0, 1/(yu*yv), 1/(yu*yv)}, yw] - 
     2*G[{0}, yu^(-1)]*G[{yu}, yv^(-1)]*G[{0, 1/(yu*yv), 1/(yu*yv)}, yw] - 
     2*G[{0}, yv^(-1)]*G[{yu}, yv^(-1)]*G[{0, 1/(yu*yv), 1/(yu*yv)}, yw] + 
     2*G[{0}, yw]*G[{yu}, yv^(-1)]*G[{0, 1/(yu*yv), 1/(yu*yv)}, yw] + 
     4*G[{1}, yu^(-1)]*G[{yu}, yv^(-1)]*G[{0, 1/(yu*yv), 1/(yu*yv)}, yw] + 
     2*G[{1}, yu^(-1)]*G[{yv^(-1)}, yw]*G[{0, 1/(yu*yv), 1/(yu*yv)}, yw] + 
     2*G[{1}, yv^(-1)]*G[{yv^(-1)}, yw]*G[{0, 1/(yu*yv), 1/(yu*yv)}, yw] - 
     4*G[{yu}, yv^(-1)]*G[{yv^(-1)}, yw]*G[{0, 1/(yu*yv), 1/(yu*yv)}, yw] + 
     4*G[{0}, yu^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv), 1/(yu*yv)}, yw] + 
     4*G[{0}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv), 1/(yu*yv)}, yw] - 
     4*G[{0}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv), 1/(yu*yv)}, yw] - 
     6*G[{1}, yu^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv), 1/(yu*yv)}, yw] - 
     6*G[{1}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv), 1/(yu*yv)}, yw] + 
     4*G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv), 1/(yu*yv)}, yw] - 
     2*G[{0, 1}, yu^(-1)]*G[{0, 1/(yu*yv), 1/(yu*yv)}, yw] + 
     2*G[{0, 1}, yv^(-1)]*G[{0, 1/(yu*yv), 1/(yu*yv)}, yw] - 
     2*G[{0, 1}, yw]*G[{0, 1/(yu*yv), 1/(yu*yv)}, yw] + 
     2*G[{0, yu^(-1)}, yw]*G[{0, 1/(yu*yv), 1/(yu*yv)}, yw] - 
     2*G[{0, yu}, yv^(-1)]*G[{0, 1/(yu*yv), 1/(yu*yv)}, yw] + 
     2*G[{0, yv^(-1)}, yw]*G[{0, 1/(yu*yv), 1/(yu*yv)}, yw] - 
     2*G[{0, 1/(yu*yv)}, yw]*G[{0, 1/(yu*yv), 1/(yu*yv)}, yw] + 
     4*G[{1, yu}, yv^(-1)]*G[{0, 1/(yu*yv), 1/(yu*yv)}, yw] - 
     8*G[{0}, yu^(-1)]*G[{yv^(-1)}, yw]*G[{1, 1, yu^(-1)}, yw] - 
     8*G[{0}, yv^(-1)]*G[{yv^(-1)}, yw]*G[{1, 1, yu^(-1)}, yw] + 
     8*G[{0}, yw]*G[{yv^(-1)}, yw]*G[{1, 1, yu^(-1)}, yw] + 
     8*G[{1}, yu^(-1)]*G[{yv^(-1)}, yw]*G[{1, 1, yu^(-1)}, yw] + 
     8*G[{1}, yv^(-1)]*G[{yv^(-1)}, yw]*G[{1, 1, yu^(-1)}, yw] + 
     8*G[{0}, yu^(-1)]*G[{1/(yu*yv)}, yw]*G[{1, 1, yu^(-1)}, yw] + 
     8*G[{0}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{1, 1, yu^(-1)}, yw] - 
     8*G[{0}, yw]*G[{1/(yu*yv)}, yw]*G[{1, 1, yu^(-1)}, yw] - 
     8*G[{1}, yu^(-1)]*G[{1/(yu*yv)}, yw]*G[{1, 1, yu^(-1)}, yw] - 
     8*G[{1}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{1, 1, yu^(-1)}, yw] + 
     4*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{1, 1, yu^(-1)}, yw] - 
     (Pi^2*G[{1, 1, yu}, yv^(-1)])/3 + 2*G[{0}, yu^(-1)]^2*
      G[{1, 1, yu}, yv^(-1)] + 4*G[{0}, yu^(-1)]*G[{0}, yv^(-1)]*
      G[{1, 1, yu}, yv^(-1)] + 2*G[{0}, yv^(-1)]^2*G[{1, 1, yu}, yv^(-1)] - 
     4*G[{0}, yu^(-1)]*G[{0}, yw]*G[{1, 1, yu}, yv^(-1)] - 
     4*G[{0}, yv^(-1)]*G[{0}, yw]*G[{1, 1, yu}, yv^(-1)] + 
     2*G[{0}, yw]^2*G[{1, 1, yu}, yv^(-1)] - 4*G[{0}, yu^(-1)]*
      G[{1}, yu^(-1)]*G[{1, 1, yu}, yv^(-1)] - 4*G[{0}, yv^(-1)]*
      G[{1}, yu^(-1)]*G[{1, 1, yu}, yv^(-1)] + 4*G[{0}, yw]*G[{1}, yu^(-1)]*
      G[{1, 1, yu}, yv^(-1)] + 2*G[{1}, yu^(-1)]^2*G[{1, 1, yu}, yv^(-1)] - 
     2*G[{0}, yu^(-1)]*G[{1}, yv^(-1)]*G[{1, 1, yu}, yv^(-1)] - 
     2*G[{0}, yv^(-1)]*G[{1}, yv^(-1)]*G[{1, 1, yu}, yv^(-1)] + 
     2*G[{0}, yw]*G[{1}, yv^(-1)]*G[{1, 1, yu}, yv^(-1)] + 
     2*G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*G[{1, 1, yu}, yv^(-1)] - 
     6*G[{0}, yu^(-1)]*G[{yu}, yv^(-1)]*G[{1, 1, yu}, yv^(-1)] - 
     6*G[{0}, yv^(-1)]*G[{yu}, yv^(-1)]*G[{1, 1, yu}, yv^(-1)] + 
     6*G[{0}, yw]*G[{yu}, yv^(-1)]*G[{1, 1, yu}, yv^(-1)] + 
     6*G[{1}, yu^(-1)]*G[{yu}, yv^(-1)]*G[{1, 1, yu}, yv^(-1)] + 
     3*G[{yu}, yv^(-1)]^2*G[{1, 1, yu}, yv^(-1)] + 
     2*G[{0}, yu^(-1)]*G[{yv^(-1)}, yw]*G[{1, 1, yu}, yv^(-1)] + 
     2*G[{0}, yv^(-1)]*G[{yv^(-1)}, yw]*G[{1, 1, yu}, yv^(-1)] - 
     2*G[{0}, yw]*G[{yv^(-1)}, yw]*G[{1, 1, yu}, yv^(-1)] - 
     2*G[{1}, yu^(-1)]*G[{yv^(-1)}, yw]*G[{1, 1, yu}, yv^(-1)] - 
     4*G[{1}, yv^(-1)]*G[{yv^(-1)}, yw]*G[{1, 1, yu}, yv^(-1)] + 
     2*G[{1}, yw]*G[{yv^(-1)}, yw]*G[{1, 1, yu}, yv^(-1)] - 
     6*G[{yu}, yv^(-1)]*G[{yv^(-1)}, yw]*G[{1, 1, yu}, yv^(-1)] - 
     G[{yv^(-1)}, yw]^2*G[{1, 1, yu}, yv^(-1)] + 6*G[{0}, yu^(-1)]*
      G[{1/(yu*yv)}, yw]*G[{1, 1, yu}, yv^(-1)] + 
     6*G[{0}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{1, 1, yu}, yv^(-1)] - 
     6*G[{0}, yw]*G[{1/(yu*yv)}, yw]*G[{1, 1, yu}, yv^(-1)] - 
     6*G[{1}, yu^(-1)]*G[{1/(yu*yv)}, yw]*G[{1, 1, yu}, yv^(-1)] + 
     6*G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{1, 1, yu}, yv^(-1)] - 
     6*G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{1, 1, yu}, yv^(-1)] + 
     6*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{1, 1, yu}, yv^(-1)] + 
     2*G[{0, 1}, yv^(-1)]*G[{1, 1, yu}, yv^(-1)] - 
     4*G[{0, 1}, yw]*G[{1, 1, yu}, yv^(-1)] - 2*G[{0, yu}, yv^(-1)]*
      G[{1, 1, yu}, yv^(-1)] + 4*G[{0, 1/(yu*yv)}, yw]*
      G[{1, 1, yu}, yv^(-1)] + 2*G[{1, yu}, yv^(-1)]*G[{1, 1, yu}, yv^(-1)] - 
     2*G[{1, yv^(-1)}, yw]*G[{1, 1, yu}, yv^(-1)] - 
     6*G[{1, 1/(yu*yv)}, yw]*G[{1, 1, yu}, yv^(-1)] - 
     2*G[{yv^(-1), 1/(yu*yv)}, yw]*G[{1, 1, yu}, yv^(-1)] - 
     8*G[{0}, yu^(-1)]*G[{yv^(-1)}, yw]*G[{1, 1, yv^(-1)}, yw] - 
     8*G[{0}, yv^(-1)]*G[{yv^(-1)}, yw]*G[{1, 1, yv^(-1)}, yw] + 
     8*G[{0}, yw]*G[{yv^(-1)}, yw]*G[{1, 1, yv^(-1)}, yw] + 
     8*G[{1}, yu^(-1)]*G[{yv^(-1)}, yw]*G[{1, 1, yv^(-1)}, yw] + 
     8*G[{1}, yv^(-1)]*G[{yv^(-1)}, yw]*G[{1, 1, yv^(-1)}, yw] + 
     2*G[{yv^(-1)}, yw]^2*G[{1, 1, yv^(-1)}, yw] + 
     4*G[{0}, yu^(-1)]*G[{1/(yu*yv)}, yw]*G[{1, 1, yv^(-1)}, yw] + 
     4*G[{0}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{1, 1, yv^(-1)}, yw] - 
     4*G[{0}, yw]*G[{1/(yu*yv)}, yw]*G[{1, 1, yv^(-1)}, yw] - 
     4*G[{1}, yu^(-1)]*G[{1/(yu*yv)}, yw]*G[{1, 1, yv^(-1)}, yw] - 
     4*G[{1}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{1, 1, yv^(-1)}, yw] - 
     2*G[{1/(yu*yv)}, yw]^2*G[{1, 1, yv^(-1)}, yw] + 
     4*G[{0}, yu^(-1)]*G[{yv^(-1)}, yw]*G[{1, 1, 1/(yu*yv)}, yw] + 
     4*G[{0}, yv^(-1)]*G[{yv^(-1)}, yw]*G[{1, 1, 1/(yu*yv)}, yw] - 
     4*G[{0}, yw]*G[{yv^(-1)}, yw]*G[{1, 1, 1/(yu*yv)}, yw] - 
     4*G[{1}, yu^(-1)]*G[{yv^(-1)}, yw]*G[{1, 1, 1/(yu*yv)}, yw] - 
     4*G[{1}, yv^(-1)]*G[{yv^(-1)}, yw]*G[{1, 1, 1/(yu*yv)}, yw] - 
     2*G[{yv^(-1)}, yw]^2*G[{1, 1, 1/(yu*yv)}, yw] - 
     8*G[{0}, yu^(-1)]*G[{1/(yu*yv)}, yw]*G[{1, 1, 1/(yu*yv)}, yw] - 
     8*G[{0}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{1, 1, 1/(yu*yv)}, yw] + 
     8*G[{0}, yw]*G[{1/(yu*yv)}, yw]*G[{1, 1, 1/(yu*yv)}, yw] + 
     8*G[{1}, yu^(-1)]*G[{1/(yu*yv)}, yw]*G[{1, 1, 1/(yu*yv)}, yw] + 
     8*G[{1}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{1, 1, 1/(yu*yv)}, yw] - 
     4*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{1, 1, 1/(yu*yv)}, yw] + 
     2*G[{1/(yu*yv)}, yw]^2*G[{1, 1, 1/(yu*yv)}, yw] - 
     4*G[{0}, yu^(-1)]*G[{yv^(-1)}, yw]*G[{1, yu^(-1), yu^(-1)}, yw] - 
     4*G[{0}, yv^(-1)]*G[{yv^(-1)}, yw]*G[{1, yu^(-1), yu^(-1)}, yw] + 
     4*G[{0}, yw]*G[{yv^(-1)}, yw]*G[{1, yu^(-1), yu^(-1)}, yw] + 
     4*G[{1}, yu^(-1)]*G[{yv^(-1)}, yw]*G[{1, yu^(-1), yu^(-1)}, yw] + 
     8*G[{1}, yv^(-1)]*G[{yv^(-1)}, yw]*G[{1, yu^(-1), yu^(-1)}, yw] + 
     4*G[{1}, yw]*G[{yv^(-1)}, yw]*G[{1, yu^(-1), yu^(-1)}, yw] - 
     4*G[{yu}, yv^(-1)]*G[{yv^(-1)}, yw]*G[{1, yu^(-1), yu^(-1)}, yw] + 
     4*G[{0}, yu^(-1)]*G[{1/(yu*yv)}, yw]*G[{1, yu^(-1), yu^(-1)}, yw] + 
     4*G[{0}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{1, yu^(-1), yu^(-1)}, yw] - 
     4*G[{0}, yw]*G[{1/(yu*yv)}, yw]*G[{1, yu^(-1), yu^(-1)}, yw] - 
     4*G[{1}, yu^(-1)]*G[{1/(yu*yv)}, yw]*G[{1, yu^(-1), yu^(-1)}, yw] - 
     8*G[{1}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{1, yu^(-1), yu^(-1)}, yw] - 
     4*G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{1, yu^(-1), yu^(-1)}, yw] + 
     4*G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{1, yu^(-1), yu^(-1)}, yw] + 
     8*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{1, yu^(-1), yu^(-1)}, yw] - 
     2*G[{1/(yu*yv)}, yw]^2*G[{1, yu^(-1), yu^(-1)}, yw] + 
     4*G[{1, yv^(-1)}, yw]*G[{1, yu^(-1), yu^(-1)}, yw] - 
     4*G[{1, 1/(yu*yv)}, yw]*G[{1, yu^(-1), yu^(-1)}, yw] - 
     4*G[{yv^(-1), 1/(yu*yv)}, yw]*G[{1, yu^(-1), yu^(-1)}, yw] + 
     (Pi^2*G[{1, yu^(-1), yv^(-1)}, yw])/3 - 2*G[{0}, yu^(-1)]*
      G[{1}, yv^(-1)]*G[{1, yu^(-1), yv^(-1)}, yw] - 
     2*G[{0}, yv^(-1)]*G[{1}, yv^(-1)]*G[{1, yu^(-1), yv^(-1)}, yw] + 
     2*G[{0}, yw]*G[{1}, yv^(-1)]*G[{1, yu^(-1), yv^(-1)}, yw] + 
     2*G[{1}, yv^(-1)]^2*G[{1, yu^(-1), yv^(-1)}, yw] - 
     4*G[{0}, yu^(-1)]*G[{1}, yw]*G[{1, yu^(-1), yv^(-1)}, yw] - 
     4*G[{0}, yv^(-1)]*G[{1}, yw]*G[{1, yu^(-1), yv^(-1)}, yw] + 
     4*G[{0}, yw]*G[{1}, yw]*G[{1, yu^(-1), yv^(-1)}, yw] + 
     4*G[{1}, yu^(-1)]*G[{1}, yw]*G[{1, yu^(-1), yv^(-1)}, yw] + 
     4*G[{1}, yv^(-1)]*G[{1}, yw]*G[{1, yu^(-1), yv^(-1)}, yw] + 
     2*G[{0}, yu^(-1)]*G[{yu}, yv^(-1)]*G[{1, yu^(-1), yv^(-1)}, yw] + 
     2*G[{0}, yv^(-1)]*G[{yu}, yv^(-1)]*G[{1, yu^(-1), yv^(-1)}, yw] - 
     2*G[{0}, yw]*G[{yu}, yv^(-1)]*G[{1, yu^(-1), yv^(-1)}, yw] - 
     4*G[{1}, yv^(-1)]*G[{yu}, yv^(-1)]*G[{1, yu^(-1), yv^(-1)}, yw] - 
     2*G[{0}, yu^(-1)]*G[{yv^(-1)}, yw]*G[{1, yu^(-1), yv^(-1)}, yw] - 
     2*G[{0}, yv^(-1)]*G[{yv^(-1)}, yw]*G[{1, yu^(-1), yv^(-1)}, yw] + 
     2*G[{0}, yw]*G[{yv^(-1)}, yw]*G[{1, yu^(-1), yv^(-1)}, yw] + 
     4*G[{1}, yu^(-1)]*G[{yv^(-1)}, yw]*G[{1, yu^(-1), yv^(-1)}, yw] + 
     4*G[{1}, yv^(-1)]*G[{yv^(-1)}, yw]*G[{1, yu^(-1), yv^(-1)}, yw] + 
     4*G[{1}, yw]*G[{yv^(-1)}, yw]*G[{1, yu^(-1), yv^(-1)}, yw] - 
     4*G[{yu}, yv^(-1)]*G[{yv^(-1)}, yw]*G[{1, yu^(-1), yv^(-1)}, yw] - 
     2*G[{0}, yu^(-1)]*G[{1/(yu*yv)}, yw]*G[{1, yu^(-1), yv^(-1)}, yw] - 
     2*G[{0}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{1, yu^(-1), yv^(-1)}, yw] + 
     2*G[{0}, yw]*G[{1/(yu*yv)}, yw]*G[{1, yu^(-1), yv^(-1)}, yw] + 
     4*G[{1}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{1, yu^(-1), yv^(-1)}, yw] + 
     4*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{1, yu^(-1), yv^(-1)}, yw] - 
     2*G[{1/(yu*yv)}, yw]^2*G[{1, yu^(-1), yv^(-1)}, yw] - 
     2*G[{0, 1}, yu^(-1)]*G[{1, yu^(-1), yv^(-1)}, yw] + 
     2*G[{0, 1}, yv^(-1)]*G[{1, yu^(-1), yv^(-1)}, yw] - 
     2*G[{0, 1}, yw]*G[{1, yu^(-1), yv^(-1)}, yw] + 
     2*G[{0, yu^(-1)}, yw]*G[{1, yu^(-1), yv^(-1)}, yw] - 
     2*G[{0, yu}, yv^(-1)]*G[{1, yu^(-1), yv^(-1)}, yw] + 
     2*G[{0, yv^(-1)}, yw]*G[{1, yu^(-1), yv^(-1)}, yw] - 
     2*G[{0, 1/(yu*yv)}, yw]*G[{1, yu^(-1), yv^(-1)}, yw] + 
     4*G[{1, yu}, yv^(-1)]*G[{1, yu^(-1), yv^(-1)}, yw] + 
     4*G[{1, yv^(-1)}, yw]*G[{1, yu^(-1), yv^(-1)}, yw] - 
     4*G[{1, 1/(yu*yv)}, yw]*G[{1, yu^(-1), yv^(-1)}, yw] - 
     4*G[{yv^(-1), 1/(yu*yv)}, yw]*G[{1, yu^(-1), yv^(-1)}, yw] - 
     (Pi^2*G[{1, yu^(-1), 1/(yu*yv)}, yw])/3 + 2*G[{0}, yu^(-1)]*
      G[{1}, yv^(-1)]*G[{1, yu^(-1), 1/(yu*yv)}, yw] + 
     2*G[{0}, yv^(-1)]*G[{1}, yv^(-1)]*G[{1, yu^(-1), 1/(yu*yv)}, yw] - 
     2*G[{0}, yw]*G[{1}, yv^(-1)]*G[{1, yu^(-1), 1/(yu*yv)}, yw] - 
     2*G[{1}, yv^(-1)]^2*G[{1, yu^(-1), 1/(yu*yv)}, yw] + 
     4*G[{0}, yu^(-1)]*G[{1}, yw]*G[{1, yu^(-1), 1/(yu*yv)}, yw] + 
     4*G[{0}, yv^(-1)]*G[{1}, yw]*G[{1, yu^(-1), 1/(yu*yv)}, yw] - 
     4*G[{0}, yw]*G[{1}, yw]*G[{1, yu^(-1), 1/(yu*yv)}, yw] - 
     4*G[{1}, yu^(-1)]*G[{1}, yw]*G[{1, yu^(-1), 1/(yu*yv)}, yw] - 
     4*G[{1}, yv^(-1)]*G[{1}, yw]*G[{1, yu^(-1), 1/(yu*yv)}, yw] - 
     2*G[{0}, yu^(-1)]*G[{yu}, yv^(-1)]*G[{1, yu^(-1), 1/(yu*yv)}, yw] - 
     2*G[{0}, yv^(-1)]*G[{yu}, yv^(-1)]*G[{1, yu^(-1), 1/(yu*yv)}, yw] + 
     2*G[{0}, yw]*G[{yu}, yv^(-1)]*G[{1, yu^(-1), 1/(yu*yv)}, yw] + 
     4*G[{1}, yv^(-1)]*G[{yu}, yv^(-1)]*G[{1, yu^(-1), 1/(yu*yv)}, yw] + 
     2*G[{0}, yu^(-1)]*G[{yv^(-1)}, yw]*G[{1, yu^(-1), 1/(yu*yv)}, yw] + 
     2*G[{0}, yv^(-1)]*G[{yv^(-1)}, yw]*G[{1, yu^(-1), 1/(yu*yv)}, yw] - 
     2*G[{0}, yw]*G[{yv^(-1)}, yw]*G[{1, yu^(-1), 1/(yu*yv)}, yw] - 
     4*G[{1}, yu^(-1)]*G[{yv^(-1)}, yw]*G[{1, yu^(-1), 1/(yu*yv)}, yw] + 
     2*G[{0}, yu^(-1)]*G[{1/(yu*yv)}, yw]*G[{1, yu^(-1), 1/(yu*yv)}, yw] + 
     2*G[{0}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{1, yu^(-1), 1/(yu*yv)}, yw] - 
     2*G[{0}, yw]*G[{1/(yu*yv)}, yw]*G[{1, yu^(-1), 1/(yu*yv)}, yw] + 
     4*G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{1, yu^(-1), 1/(yu*yv)}, yw] - 
     4*G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{1, yu^(-1), 1/(yu*yv)}, yw] + 
     2*G[{0, 1}, yu^(-1)]*G[{1, yu^(-1), 1/(yu*yv)}, yw] - 
     2*G[{0, 1}, yv^(-1)]*G[{1, yu^(-1), 1/(yu*yv)}, yw] + 
     2*G[{0, 1}, yw]*G[{1, yu^(-1), 1/(yu*yv)}, yw] - 
     2*G[{0, yu^(-1)}, yw]*G[{1, yu^(-1), 1/(yu*yv)}, yw] + 
     2*G[{0, yu}, yv^(-1)]*G[{1, yu^(-1), 1/(yu*yv)}, yw] - 
     2*G[{0, yv^(-1)}, yw]*G[{1, yu^(-1), 1/(yu*yv)}, yw] + 
     2*G[{0, 1/(yu*yv)}, yw]*G[{1, yu^(-1), 1/(yu*yv)}, yw] - 
     4*G[{1, yu}, yv^(-1)]*G[{1, yu^(-1), 1/(yu*yv)}, yw] + 
     4*G[{1, yv^(-1)}, yw]*G[{1, yu^(-1), 1/(yu*yv)}, yw] + 
     2*G[{0}, yu^(-1)]^2*G[{1, yu, yu}, yv^(-1)] + 
     4*G[{0}, yu^(-1)]*G[{0}, yv^(-1)]*G[{1, yu, yu}, yv^(-1)] + 
     2*G[{0}, yv^(-1)]^2*G[{1, yu, yu}, yv^(-1)] - 
     4*G[{0}, yu^(-1)]*G[{0}, yw]*G[{1, yu, yu}, yv^(-1)] - 
     4*G[{0}, yv^(-1)]*G[{0}, yw]*G[{1, yu, yu}, yv^(-1)] + 
     2*G[{0}, yw]^2*G[{1, yu, yu}, yv^(-1)] - 4*G[{0}, yu^(-1)]*
      G[{1}, yu^(-1)]*G[{1, yu, yu}, yv^(-1)] - 4*G[{0}, yv^(-1)]*
      G[{1}, yu^(-1)]*G[{1, yu, yu}, yv^(-1)] + 4*G[{0}, yw]*G[{1}, yu^(-1)]*
      G[{1, yu, yu}, yv^(-1)] + 2*G[{1}, yu^(-1)]^2*G[{1, yu, yu}, yv^(-1)] - 
     4*G[{0}, yu^(-1)]*G[{1}, yv^(-1)]*G[{1, yu, yu}, yv^(-1)] - 
     4*G[{0}, yv^(-1)]*G[{1}, yv^(-1)]*G[{1, yu, yu}, yv^(-1)] + 
     4*G[{0}, yw]*G[{1}, yv^(-1)]*G[{1, yu, yu}, yv^(-1)] + 
     2*G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*G[{1, yu, yu}, yv^(-1)] + 
     2*G[{1}, yv^(-1)]^2*G[{1, yu, yu}, yv^(-1)] - 
     8*G[{0}, yu^(-1)]*G[{yu}, yv^(-1)]*G[{1, yu, yu}, yv^(-1)] - 
     8*G[{0}, yv^(-1)]*G[{yu}, yv^(-1)]*G[{1, yu, yu}, yv^(-1)] + 
     8*G[{0}, yw]*G[{yu}, yv^(-1)]*G[{1, yu, yu}, yv^(-1)] + 
     10*G[{1}, yu^(-1)]*G[{yu}, yv^(-1)]*G[{1, yu, yu}, yv^(-1)] + 
     4*G[{1}, yv^(-1)]*G[{yu}, yv^(-1)]*G[{1, yu, yu}, yv^(-1)] + 
     5*G[{yu}, yv^(-1)]^2*G[{1, yu, yu}, yv^(-1)] + 
     2*G[{1}, yu^(-1)]*G[{yv^(-1)}, yw]*G[{1, yu, yu}, yv^(-1)] - 
     4*G[{1}, yv^(-1)]*G[{yv^(-1)}, yw]*G[{1, yu, yu}, yv^(-1)] + 
     2*G[{1}, yw]*G[{yv^(-1)}, yw]*G[{1, yu, yu}, yv^(-1)] - 
     6*G[{yu}, yv^(-1)]*G[{yv^(-1)}, yw]*G[{1, yu, yu}, yv^(-1)] - 
     3*G[{yv^(-1)}, yw]^2*G[{1, yu, yu}, yv^(-1)] + 
     8*G[{0}, yu^(-1)]*G[{1/(yu*yv)}, yw]*G[{1, yu, yu}, yv^(-1)] + 
     8*G[{0}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{1, yu, yu}, yv^(-1)] - 
     8*G[{0}, yw]*G[{1/(yu*yv)}, yw]*G[{1, yu, yu}, yv^(-1)] - 
     10*G[{1}, yu^(-1)]*G[{1/(yu*yv)}, yw]*G[{1, yu, yu}, yv^(-1)] - 
     4*G[{1}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{1, yu, yu}, yv^(-1)] + 
     6*G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{1, yu, yu}, yv^(-1)] - 
     10*G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{1, yu, yu}, yv^(-1)] + 
     6*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{1, yu, yu}, yv^(-1)] + 
     2*G[{1/(yu*yv)}, yw]^2*G[{1, yu, yu}, yv^(-1)] - 
     2*G[{0, 1}, yu^(-1)]*G[{1, yu, yu}, yv^(-1)] + 
     4*G[{0, 1}, yv^(-1)]*G[{1, yu, yu}, yv^(-1)] - 
     4*G[{0, 1}, yw]*G[{1, yu, yu}, yv^(-1)] - 4*G[{0, yu}, yv^(-1)]*
      G[{1, yu, yu}, yv^(-1)] + 4*G[{0, 1/(yu*yv)}, yw]*
      G[{1, yu, yu}, yv^(-1)] + 6*G[{1, yu}, yv^(-1)]*
      G[{1, yu, yu}, yv^(-1)] - 2*G[{1, yv^(-1)}, yw]*
      G[{1, yu, yu}, yv^(-1)] - 6*G[{1, 1/(yu*yv)}, yw]*
      G[{1, yu, yu}, yv^(-1)] - 2*G[{yv^(-1), 1/(yu*yv)}, yw]*
      G[{1, yu, yu}, yv^(-1)] + (Pi^2*G[{1, yv^(-1), yu^(-1)}, yw])/3 - 
     2*G[{0}, yu^(-1)]*G[{1}, yv^(-1)]*G[{1, yv^(-1), yu^(-1)}, yw] - 
     2*G[{0}, yv^(-1)]*G[{1}, yv^(-1)]*G[{1, yv^(-1), yu^(-1)}, yw] + 
     2*G[{0}, yw]*G[{1}, yv^(-1)]*G[{1, yv^(-1), yu^(-1)}, yw] + 
     2*G[{1}, yv^(-1)]^2*G[{1, yv^(-1), yu^(-1)}, yw] - 
     4*G[{0}, yu^(-1)]*G[{1}, yw]*G[{1, yv^(-1), yu^(-1)}, yw] - 
     4*G[{0}, yv^(-1)]*G[{1}, yw]*G[{1, yv^(-1), yu^(-1)}, yw] + 
     4*G[{0}, yw]*G[{1}, yw]*G[{1, yv^(-1), yu^(-1)}, yw] + 
     4*G[{1}, yu^(-1)]*G[{1}, yw]*G[{1, yv^(-1), yu^(-1)}, yw] + 
     4*G[{1}, yv^(-1)]*G[{1}, yw]*G[{1, yv^(-1), yu^(-1)}, yw] + 
     2*G[{0}, yu^(-1)]*G[{yu}, yv^(-1)]*G[{1, yv^(-1), yu^(-1)}, yw] + 
     2*G[{0}, yv^(-1)]*G[{yu}, yv^(-1)]*G[{1, yv^(-1), yu^(-1)}, yw] - 
     2*G[{0}, yw]*G[{yu}, yv^(-1)]*G[{1, yv^(-1), yu^(-1)}, yw] - 
     4*G[{1}, yv^(-1)]*G[{yu}, yv^(-1)]*G[{1, yv^(-1), yu^(-1)}, yw] - 
     2*G[{0}, yu^(-1)]*G[{yv^(-1)}, yw]*G[{1, yv^(-1), yu^(-1)}, yw] - 
     2*G[{0}, yv^(-1)]*G[{yv^(-1)}, yw]*G[{1, yv^(-1), yu^(-1)}, yw] + 
     2*G[{0}, yw]*G[{yv^(-1)}, yw]*G[{1, yv^(-1), yu^(-1)}, yw] + 
     4*G[{1}, yu^(-1)]*G[{yv^(-1)}, yw]*G[{1, yv^(-1), yu^(-1)}, yw] + 
     4*G[{1}, yv^(-1)]*G[{yv^(-1)}, yw]*G[{1, yv^(-1), yu^(-1)}, yw] + 
     4*G[{1}, yw]*G[{yv^(-1)}, yw]*G[{1, yv^(-1), yu^(-1)}, yw] - 
     4*G[{yu}, yv^(-1)]*G[{yv^(-1)}, yw]*G[{1, yv^(-1), yu^(-1)}, yw] - 
     2*G[{0}, yu^(-1)]*G[{1/(yu*yv)}, yw]*G[{1, yv^(-1), yu^(-1)}, yw] - 
     2*G[{0}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{1, yv^(-1), yu^(-1)}, yw] + 
     2*G[{0}, yw]*G[{1/(yu*yv)}, yw]*G[{1, yv^(-1), yu^(-1)}, yw] + 
     4*G[{1}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{1, yv^(-1), yu^(-1)}, yw] + 
     4*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{1, yv^(-1), yu^(-1)}, yw] - 
     2*G[{1/(yu*yv)}, yw]^2*G[{1, yv^(-1), yu^(-1)}, yw] - 
     2*G[{0, 1}, yu^(-1)]*G[{1, yv^(-1), yu^(-1)}, yw] + 
     2*G[{0, 1}, yv^(-1)]*G[{1, yv^(-1), yu^(-1)}, yw] - 
     2*G[{0, 1}, yw]*G[{1, yv^(-1), yu^(-1)}, yw] + 
     2*G[{0, yu^(-1)}, yw]*G[{1, yv^(-1), yu^(-1)}, yw] - 
     2*G[{0, yu}, yv^(-1)]*G[{1, yv^(-1), yu^(-1)}, yw] + 
     2*G[{0, yv^(-1)}, yw]*G[{1, yv^(-1), yu^(-1)}, yw] - 
     2*G[{0, 1/(yu*yv)}, yw]*G[{1, yv^(-1), yu^(-1)}, yw] + 
     4*G[{1, yu}, yv^(-1)]*G[{1, yv^(-1), yu^(-1)}, yw] - 
     4*G[{1, yv^(-1)}, yw]*G[{1, yv^(-1), yu^(-1)}, yw] - 
     4*G[{1, 1/(yu*yv)}, yw]*G[{1, yv^(-1), yu^(-1)}, yw] - 
     4*G[{yv^(-1), 1/(yu*yv)}, yw]*G[{1, yv^(-1), yu^(-1)}, yw] + 
     (4*Pi^2*G[{1, yv^(-1), yv^(-1)}, yw])/3 - 2*G[{0}, yu^(-1)]^2*
      G[{1, yv^(-1), yv^(-1)}, yw] - 4*G[{0}, yu^(-1)]*G[{0}, yv^(-1)]*
      G[{1, yv^(-1), yv^(-1)}, yw] - 2*G[{0}, yv^(-1)]^2*
      G[{1, yv^(-1), yv^(-1)}, yw] + 4*G[{0}, yu^(-1)]*G[{0}, yw]*
      G[{1, yv^(-1), yv^(-1)}, yw] + 4*G[{0}, yv^(-1)]*G[{0}, yw]*
      G[{1, yv^(-1), yv^(-1)}, yw] - 2*G[{0}, yw]^2*G[{1, yv^(-1), yv^(-1)}, 
       yw] + 4*G[{0}, yu^(-1)]*G[{1}, yu^(-1)]*G[{1, yv^(-1), yv^(-1)}, yw] + 
     4*G[{0}, yv^(-1)]*G[{1}, yu^(-1)]*G[{1, yv^(-1), yv^(-1)}, yw] - 
     4*G[{0}, yw]*G[{1}, yu^(-1)]*G[{1, yv^(-1), yv^(-1)}, yw] - 
     2*G[{1}, yu^(-1)]^2*G[{1, yv^(-1), yv^(-1)}, yw] + 
     4*G[{0}, yu^(-1)]*G[{1}, yv^(-1)]*G[{1, yv^(-1), yv^(-1)}, yw] + 
     4*G[{0}, yv^(-1)]*G[{1}, yv^(-1)]*G[{1, yv^(-1), yv^(-1)}, yw] - 
     4*G[{0}, yw]*G[{1}, yv^(-1)]*G[{1, yv^(-1), yv^(-1)}, yw] - 
     10*G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*G[{1, yv^(-1), yv^(-1)}, yw] - 
     2*G[{1}, yv^(-1)]^2*G[{1, yv^(-1), yv^(-1)}, yw] - 
     8*G[{0}, yu^(-1)]*G[{1}, yw]*G[{1, yv^(-1), yv^(-1)}, yw] - 
     8*G[{0}, yv^(-1)]*G[{1}, yw]*G[{1, yv^(-1), yv^(-1)}, yw] + 
     8*G[{0}, yw]*G[{1}, yw]*G[{1, yv^(-1), yv^(-1)}, yw] + 
     8*G[{1}, yu^(-1)]*G[{1}, yw]*G[{1, yv^(-1), yv^(-1)}, yw] + 
     8*G[{1}, yv^(-1)]*G[{1}, yw]*G[{1, yv^(-1), yv^(-1)}, yw] + 
     6*G[{1}, yu^(-1)]*G[{yu}, yv^(-1)]*G[{1, yv^(-1), yv^(-1)}, yw] - 
     4*G[{1}, yv^(-1)]*G[{yu}, yv^(-1)]*G[{1, yv^(-1), yv^(-1)}, yw] - 
     G[{yu}, yv^(-1)]^2*G[{1, yv^(-1), yv^(-1)}, yw] - 
     4*G[{0}, yu^(-1)]*G[{yv^(-1)}, yw]*G[{1, yv^(-1), yv^(-1)}, yw] - 
     4*G[{0}, yv^(-1)]*G[{yv^(-1)}, yw]*G[{1, yv^(-1), yv^(-1)}, yw] + 
     4*G[{0}, yw]*G[{yv^(-1)}, yw]*G[{1, yv^(-1), yv^(-1)}, yw] + 
     10*G[{1}, yu^(-1)]*G[{yv^(-1)}, yw]*G[{1, yv^(-1), yv^(-1)}, yw] + 
     4*G[{1}, yv^(-1)]*G[{yv^(-1)}, yw]*G[{1, yv^(-1), yv^(-1)}, yw] + 
     6*G[{1}, yw]*G[{yv^(-1)}, yw]*G[{1, yv^(-1), yv^(-1)}, yw] - 
     6*G[{yu}, yv^(-1)]*G[{yv^(-1)}, yw]*G[{1, yv^(-1), yv^(-1)}, yw] + 
     3*G[{yv^(-1)}, yw]^2*G[{1, yv^(-1), yv^(-1)}, yw] - 
     4*G[{0}, yu^(-1)]*G[{1/(yu*yv)}, yw]*G[{1, yv^(-1), yv^(-1)}, yw] - 
     4*G[{0}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{1, yv^(-1), yv^(-1)}, yw] + 
     4*G[{0}, yw]*G[{1/(yu*yv)}, yw]*G[{1, yv^(-1), yv^(-1)}, yw] - 
     2*G[{1}, yu^(-1)]*G[{1/(yu*yv)}, yw]*G[{1, yv^(-1), yv^(-1)}, yw] + 
     4*G[{1}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{1, yv^(-1), yv^(-1)}, yw] - 
     6*G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{1, yv^(-1), yv^(-1)}, yw] + 
     6*G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{1, yv^(-1), yv^(-1)}, yw] + 
     2*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{1, yv^(-1), yv^(-1)}, yw] - 
     4*G[{1/(yu*yv)}, yw]^2*G[{1, yv^(-1), yv^(-1)}, yw] - 
     6*G[{0, 1}, yu^(-1)]*G[{1, yv^(-1), yv^(-1)}, yw] + 
     4*G[{0, 1}, yv^(-1)]*G[{1, yv^(-1), yv^(-1)}, yw] - 
     8*G[{0, 1}, yw]*G[{1, yv^(-1), yv^(-1)}, yw] + 
     8*G[{0, yu^(-1)}, yw]*G[{1, yv^(-1), yv^(-1)}, yw] - 
     4*G[{0, yu}, yv^(-1)]*G[{1, yv^(-1), yv^(-1)}, yw] + 
     8*G[{0, yv^(-1)}, yw]*G[{1, yv^(-1), yv^(-1)}, yw] - 
     8*G[{0, 1/(yu*yv)}, yw]*G[{1, yv^(-1), yv^(-1)}, yw] - 
     4*G[{1, yu^(-1)}, yw]*G[{1, yv^(-1), yv^(-1)}, yw] + 
     10*G[{1, yu}, yv^(-1)]*G[{1, yv^(-1), yv^(-1)}, yw] - 
     14*G[{1, yv^(-1)}, yw]*G[{1, yv^(-1), yv^(-1)}, yw] + 
     2*G[{1, 1/(yu*yv)}, yw]*G[{1, yv^(-1), yv^(-1)}, yw] - 
     2*G[{yv^(-1), 1/(yu*yv)}, yw]*G[{1, yv^(-1), yv^(-1)}, yw] - 
     (Pi^2*G[{1, yv^(-1), 1/(yu*yv)}, yw])/3 + 2*G[{0}, yu^(-1)]^2*
      G[{1, yv^(-1), 1/(yu*yv)}, yw] + 4*G[{0}, yu^(-1)]*G[{0}, yv^(-1)]*
      G[{1, yv^(-1), 1/(yu*yv)}, yw] + 2*G[{0}, yv^(-1)]^2*
      G[{1, yv^(-1), 1/(yu*yv)}, yw] - 4*G[{0}, yu^(-1)]*G[{0}, yw]*
      G[{1, yv^(-1), 1/(yu*yv)}, yw] - 4*G[{0}, yv^(-1)]*G[{0}, yw]*
      G[{1, yv^(-1), 1/(yu*yv)}, yw] + 2*G[{0}, yw]^2*
      G[{1, yv^(-1), 1/(yu*yv)}, yw] - 4*G[{0}, yu^(-1)]*G[{1}, yu^(-1)]*
      G[{1, yv^(-1), 1/(yu*yv)}, yw] - 4*G[{0}, yv^(-1)]*G[{1}, yu^(-1)]*
      G[{1, yv^(-1), 1/(yu*yv)}, yw] + 4*G[{0}, yw]*G[{1}, yu^(-1)]*
      G[{1, yv^(-1), 1/(yu*yv)}, yw] + 2*G[{1}, yu^(-1)]^2*
      G[{1, yv^(-1), 1/(yu*yv)}, yw] - 2*G[{0}, yu^(-1)]*G[{1}, yv^(-1)]*
      G[{1, yv^(-1), 1/(yu*yv)}, yw] - 2*G[{0}, yv^(-1)]*G[{1}, yv^(-1)]*
      G[{1, yv^(-1), 1/(yu*yv)}, yw] + 2*G[{0}, yw]*G[{1}, yv^(-1)]*
      G[{1, yv^(-1), 1/(yu*yv)}, yw] + 2*G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*
      G[{1, yv^(-1), 1/(yu*yv)}, yw] + 4*G[{0}, yu^(-1)]*G[{1}, yw]*
      G[{1, yv^(-1), 1/(yu*yv)}, yw] + 4*G[{0}, yv^(-1)]*G[{1}, yw]*
      G[{1, yv^(-1), 1/(yu*yv)}, yw] - 4*G[{0}, yw]*G[{1}, yw]*
      G[{1, yv^(-1), 1/(yu*yv)}, yw] - 4*G[{1}, yu^(-1)]*G[{1}, yw]*
      G[{1, yv^(-1), 1/(yu*yv)}, yw] - 4*G[{1}, yv^(-1)]*G[{1}, yw]*
      G[{1, yv^(-1), 1/(yu*yv)}, yw] - 2*G[{0}, yu^(-1)]*G[{yu}, yv^(-1)]*
      G[{1, yv^(-1), 1/(yu*yv)}, yw] - 2*G[{0}, yv^(-1)]*G[{yu}, yv^(-1)]*
      G[{1, yv^(-1), 1/(yu*yv)}, yw] + 2*G[{0}, yw]*G[{yu}, yv^(-1)]*
      G[{1, yv^(-1), 1/(yu*yv)}, yw] + 2*G[{1}, yu^(-1)]*G[{yu}, yv^(-1)]*
      G[{1, yv^(-1), 1/(yu*yv)}, yw] + G[{yu}, yv^(-1)]^2*
      G[{1, yv^(-1), 1/(yu*yv)}, yw] + 2*G[{0}, yu^(-1)]*G[{yv^(-1)}, yw]*
      G[{1, yv^(-1), 1/(yu*yv)}, yw] + 2*G[{0}, yv^(-1)]*G[{yv^(-1)}, yw]*
      G[{1, yv^(-1), 1/(yu*yv)}, yw] - 2*G[{0}, yw]*G[{yv^(-1)}, yw]*
      G[{1, yv^(-1), 1/(yu*yv)}, yw] - 2*G[{1}, yu^(-1)]*G[{yv^(-1)}, yw]*
      G[{1, yv^(-1), 1/(yu*yv)}, yw] - 4*G[{1}, yv^(-1)]*G[{yv^(-1)}, yw]*
      G[{1, yv^(-1), 1/(yu*yv)}, yw] - 2*G[{1}, yw]*G[{yv^(-1)}, yw]*
      G[{1, yv^(-1), 1/(yu*yv)}, yw] + 2*G[{yu}, yv^(-1)]*G[{yv^(-1)}, yw]*
      G[{1, yv^(-1), 1/(yu*yv)}, yw] - G[{yv^(-1)}, yw]^2*
      G[{1, yv^(-1), 1/(yu*yv)}, yw] + 6*G[{0}, yu^(-1)]*G[{1/(yu*yv)}, yw]*
      G[{1, yv^(-1), 1/(yu*yv)}, yw] + 6*G[{0}, yv^(-1)]*G[{1/(yu*yv)}, yw]*
      G[{1, yv^(-1), 1/(yu*yv)}, yw] - 6*G[{0}, yw]*G[{1/(yu*yv)}, yw]*
      G[{1, yv^(-1), 1/(yu*yv)}, yw] - 6*G[{1}, yu^(-1)]*G[{1/(yu*yv)}, yw]*
      G[{1, yv^(-1), 1/(yu*yv)}, yw] + 6*G[{1}, yw]*G[{1/(yu*yv)}, yw]*
      G[{1, yv^(-1), 1/(yu*yv)}, yw] - 6*G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw]*
      G[{1, yv^(-1), 1/(yu*yv)}, yw] + 2*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*
      G[{1, yv^(-1), 1/(yu*yv)}, yw] + 2*G[{0, 1}, yv^(-1)]*
      G[{1, yv^(-1), 1/(yu*yv)}, yw] + 2*G[{0, 1}, yw]*
      G[{1, yv^(-1), 1/(yu*yv)}, yw] - 2*G[{0, yu^(-1)}, yw]*
      G[{1, yv^(-1), 1/(yu*yv)}, yw] - 2*G[{0, yu}, yv^(-1)]*
      G[{1, yv^(-1), 1/(yu*yv)}, yw] - 2*G[{0, yv^(-1)}, yw]*
      G[{1, yv^(-1), 1/(yu*yv)}, yw] + 2*G[{0, 1/(yu*yv)}, yw]*
      G[{1, yv^(-1), 1/(yu*yv)}, yw] + 4*G[{1, yu^(-1)}, yw]*
      G[{1, yv^(-1), 1/(yu*yv)}, yw] + 2*G[{1, yu}, yv^(-1)]*
      G[{1, yv^(-1), 1/(yu*yv)}, yw] + 2*G[{1, yv^(-1)}, yw]*
      G[{1, yv^(-1), 1/(yu*yv)}, yw] - 6*G[{1, 1/(yu*yv)}, yw]*
      G[{1, yv^(-1), 1/(yu*yv)}, yw] - 2*G[{yv^(-1), 1/(yu*yv)}, yw]*
      G[{1, yv^(-1), 1/(yu*yv)}, yw] - (Pi^2*G[{1, 1/(yu*yv), yu^(-1)}, yw])/
      3 + 2*G[{0}, yu^(-1)]*G[{1}, yv^(-1)]*G[{1, 1/(yu*yv), yu^(-1)}, yw] + 
     2*G[{0}, yv^(-1)]*G[{1}, yv^(-1)]*G[{1, 1/(yu*yv), yu^(-1)}, yw] - 
     2*G[{0}, yw]*G[{1}, yv^(-1)]*G[{1, 1/(yu*yv), yu^(-1)}, yw] - 
     2*G[{1}, yv^(-1)]^2*G[{1, 1/(yu*yv), yu^(-1)}, yw] + 
     4*G[{0}, yu^(-1)]*G[{1}, yw]*G[{1, 1/(yu*yv), yu^(-1)}, yw] + 
     4*G[{0}, yv^(-1)]*G[{1}, yw]*G[{1, 1/(yu*yv), yu^(-1)}, yw] - 
     4*G[{0}, yw]*G[{1}, yw]*G[{1, 1/(yu*yv), yu^(-1)}, yw] - 
     4*G[{1}, yu^(-1)]*G[{1}, yw]*G[{1, 1/(yu*yv), yu^(-1)}, yw] - 
     4*G[{1}, yv^(-1)]*G[{1}, yw]*G[{1, 1/(yu*yv), yu^(-1)}, yw] - 
     2*G[{0}, yu^(-1)]*G[{yu}, yv^(-1)]*G[{1, 1/(yu*yv), yu^(-1)}, yw] - 
     2*G[{0}, yv^(-1)]*G[{yu}, yv^(-1)]*G[{1, 1/(yu*yv), yu^(-1)}, yw] + 
     2*G[{0}, yw]*G[{yu}, yv^(-1)]*G[{1, 1/(yu*yv), yu^(-1)}, yw] + 
     4*G[{1}, yv^(-1)]*G[{yu}, yv^(-1)]*G[{1, 1/(yu*yv), yu^(-1)}, yw] - 
     2*G[{0}, yu^(-1)]*G[{yv^(-1)}, yw]*G[{1, 1/(yu*yv), yu^(-1)}, yw] - 
     2*G[{0}, yv^(-1)]*G[{yv^(-1)}, yw]*G[{1, 1/(yu*yv), yu^(-1)}, yw] + 
     2*G[{0}, yw]*G[{yv^(-1)}, yw]*G[{1, 1/(yu*yv), yu^(-1)}, yw] + 
     4*G[{1}, yv^(-1)]*G[{yv^(-1)}, yw]*G[{1, 1/(yu*yv), yu^(-1)}, yw] - 
     2*G[{0}, yu^(-1)]*G[{1/(yu*yv)}, yw]*G[{1, 1/(yu*yv), yu^(-1)}, yw] - 
     2*G[{0}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{1, 1/(yu*yv), yu^(-1)}, yw] + 
     2*G[{0}, yw]*G[{1/(yu*yv)}, yw]*G[{1, 1/(yu*yv), yu^(-1)}, yw] + 
     4*G[{1}, yu^(-1)]*G[{1/(yu*yv)}, yw]*G[{1, 1/(yu*yv), yu^(-1)}, yw] + 
     4*G[{1}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{1, 1/(yu*yv), yu^(-1)}, yw] + 
     4*G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{1, 1/(yu*yv), yu^(-1)}, yw] - 
     4*G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{1, 1/(yu*yv), yu^(-1)}, yw] - 
     4*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{1, 1/(yu*yv), yu^(-1)}, yw] + 
     2*G[{0, 1}, yu^(-1)]*G[{1, 1/(yu*yv), yu^(-1)}, yw] - 
     2*G[{0, 1}, yv^(-1)]*G[{1, 1/(yu*yv), yu^(-1)}, yw] + 
     2*G[{0, 1}, yw]*G[{1, 1/(yu*yv), yu^(-1)}, yw] - 
     2*G[{0, yu^(-1)}, yw]*G[{1, 1/(yu*yv), yu^(-1)}, yw] + 
     2*G[{0, yu}, yv^(-1)]*G[{1, 1/(yu*yv), yu^(-1)}, yw] - 
     2*G[{0, yv^(-1)}, yw]*G[{1, 1/(yu*yv), yu^(-1)}, yw] + 
     2*G[{0, 1/(yu*yv)}, yw]*G[{1, 1/(yu*yv), yu^(-1)}, yw] - 
     4*G[{1, yu}, yv^(-1)]*G[{1, 1/(yu*yv), yu^(-1)}, yw] + 
     4*G[{1, yv^(-1)}, yw]*G[{1, 1/(yu*yv), yu^(-1)}, yw] - 
     (Pi^2*G[{1, 1/(yu*yv), yv^(-1)}, yw])/3 + 2*G[{0}, yu^(-1)]^2*
      G[{1, 1/(yu*yv), yv^(-1)}, yw] + 4*G[{0}, yu^(-1)]*G[{0}, yv^(-1)]*
      G[{1, 1/(yu*yv), yv^(-1)}, yw] + 2*G[{0}, yv^(-1)]^2*
      G[{1, 1/(yu*yv), yv^(-1)}, yw] - 4*G[{0}, yu^(-1)]*G[{0}, yw]*
      G[{1, 1/(yu*yv), yv^(-1)}, yw] - 4*G[{0}, yv^(-1)]*G[{0}, yw]*
      G[{1, 1/(yu*yv), yv^(-1)}, yw] + 2*G[{0}, yw]^2*
      G[{1, 1/(yu*yv), yv^(-1)}, yw] - 4*G[{0}, yu^(-1)]*G[{1}, yu^(-1)]*
      G[{1, 1/(yu*yv), yv^(-1)}, yw] - 4*G[{0}, yv^(-1)]*G[{1}, yu^(-1)]*
      G[{1, 1/(yu*yv), yv^(-1)}, yw] + 4*G[{0}, yw]*G[{1}, yu^(-1)]*
      G[{1, 1/(yu*yv), yv^(-1)}, yw] + 2*G[{1}, yu^(-1)]^2*
      G[{1, 1/(yu*yv), yv^(-1)}, yw] - 2*G[{0}, yu^(-1)]*G[{1}, yv^(-1)]*
      G[{1, 1/(yu*yv), yv^(-1)}, yw] - 2*G[{0}, yv^(-1)]*G[{1}, yv^(-1)]*
      G[{1, 1/(yu*yv), yv^(-1)}, yw] + 2*G[{0}, yw]*G[{1}, yv^(-1)]*
      G[{1, 1/(yu*yv), yv^(-1)}, yw] + 2*G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*
      G[{1, 1/(yu*yv), yv^(-1)}, yw] + 4*G[{0}, yu^(-1)]*G[{1}, yw]*
      G[{1, 1/(yu*yv), yv^(-1)}, yw] + 4*G[{0}, yv^(-1)]*G[{1}, yw]*
      G[{1, 1/(yu*yv), yv^(-1)}, yw] - 4*G[{0}, yw]*G[{1}, yw]*
      G[{1, 1/(yu*yv), yv^(-1)}, yw] - 4*G[{1}, yu^(-1)]*G[{1}, yw]*
      G[{1, 1/(yu*yv), yv^(-1)}, yw] - 4*G[{1}, yv^(-1)]*G[{1}, yw]*
      G[{1, 1/(yu*yv), yv^(-1)}, yw] - 2*G[{0}, yu^(-1)]*G[{yu}, yv^(-1)]*
      G[{1, 1/(yu*yv), yv^(-1)}, yw] - 2*G[{0}, yv^(-1)]*G[{yu}, yv^(-1)]*
      G[{1, 1/(yu*yv), yv^(-1)}, yw] + 2*G[{0}, yw]*G[{yu}, yv^(-1)]*
      G[{1, 1/(yu*yv), yv^(-1)}, yw] + 2*G[{1}, yu^(-1)]*G[{yu}, yv^(-1)]*
      G[{1, 1/(yu*yv), yv^(-1)}, yw] + G[{yu}, yv^(-1)]^2*
      G[{1, 1/(yu*yv), yv^(-1)}, yw] - 2*G[{0}, yu^(-1)]*G[{yv^(-1)}, yw]*
      G[{1, 1/(yu*yv), yv^(-1)}, yw] - 2*G[{0}, yv^(-1)]*G[{yv^(-1)}, yw]*
      G[{1, 1/(yu*yv), yv^(-1)}, yw] + 2*G[{0}, yw]*G[{yv^(-1)}, yw]*
      G[{1, 1/(yu*yv), yv^(-1)}, yw] + 2*G[{1}, yu^(-1)]*G[{yv^(-1)}, yw]*
      G[{1, 1/(yu*yv), yv^(-1)}, yw] - 2*G[{1}, yw]*G[{yv^(-1)}, yw]*
      G[{1, 1/(yu*yv), yv^(-1)}, yw] + 2*G[{yu}, yv^(-1)]*G[{yv^(-1)}, yw]*
      G[{1, 1/(yu*yv), yv^(-1)}, yw] - 3*G[{yv^(-1)}, yw]^2*
      G[{1, 1/(yu*yv), yv^(-1)}, yw] + 6*G[{0}, yu^(-1)]*G[{1/(yu*yv)}, yw]*
      G[{1, 1/(yu*yv), yv^(-1)}, yw] + 6*G[{0}, yv^(-1)]*G[{1/(yu*yv)}, yw]*
      G[{1, 1/(yu*yv), yv^(-1)}, yw] - 6*G[{0}, yw]*G[{1/(yu*yv)}, yw]*
      G[{1, 1/(yu*yv), yv^(-1)}, yw] - 6*G[{1}, yu^(-1)]*G[{1/(yu*yv)}, yw]*
      G[{1, 1/(yu*yv), yv^(-1)}, yw] + 6*G[{1}, yw]*G[{1/(yu*yv)}, yw]*
      G[{1, 1/(yu*yv), yv^(-1)}, yw] - 6*G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw]*
      G[{1, 1/(yu*yv), yv^(-1)}, yw] + 2*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*
      G[{1, 1/(yu*yv), yv^(-1)}, yw] + 2*G[{1/(yu*yv)}, yw]^2*
      G[{1, 1/(yu*yv), yv^(-1)}, yw] + 2*G[{0, 1}, yv^(-1)]*
      G[{1, 1/(yu*yv), yv^(-1)}, yw] + 2*G[{0, 1}, yw]*
      G[{1, 1/(yu*yv), yv^(-1)}, yw] - 2*G[{0, yu^(-1)}, yw]*
      G[{1, 1/(yu*yv), yv^(-1)}, yw] - 2*G[{0, yu}, yv^(-1)]*
      G[{1, 1/(yu*yv), yv^(-1)}, yw] - 2*G[{0, yv^(-1)}, yw]*
      G[{1, 1/(yu*yv), yv^(-1)}, yw] + 2*G[{0, 1/(yu*yv)}, yw]*
      G[{1, 1/(yu*yv), yv^(-1)}, yw] + 4*G[{1, yu^(-1)}, yw]*
      G[{1, 1/(yu*yv), yv^(-1)}, yw] + 2*G[{1, yu}, yv^(-1)]*
      G[{1, 1/(yu*yv), yv^(-1)}, yw] + 2*G[{1, yv^(-1)}, yw]*
      G[{1, 1/(yu*yv), yv^(-1)}, yw] - 2*G[{1, 1/(yu*yv)}, yw]*
      G[{1, 1/(yu*yv), yv^(-1)}, yw] - 2*G[{yv^(-1), 1/(yu*yv)}, yw]*
      G[{1, 1/(yu*yv), yv^(-1)}, yw] - 2*G[{0}, yu^(-1)]^2*
      G[{1, 1/(yu*yv), 1/(yu*yv)}, yw] - 4*G[{0}, yu^(-1)]*G[{0}, yv^(-1)]*
      G[{1, 1/(yu*yv), 1/(yu*yv)}, yw] - 2*G[{0}, yv^(-1)]^2*
      G[{1, 1/(yu*yv), 1/(yu*yv)}, yw] + 4*G[{0}, yu^(-1)]*G[{0}, yw]*
      G[{1, 1/(yu*yv), 1/(yu*yv)}, yw] + 4*G[{0}, yv^(-1)]*G[{0}, yw]*
      G[{1, 1/(yu*yv), 1/(yu*yv)}, yw] - 2*G[{0}, yw]^2*
      G[{1, 1/(yu*yv), 1/(yu*yv)}, yw] + 4*G[{0}, yu^(-1)]*G[{1}, yu^(-1)]*
      G[{1, 1/(yu*yv), 1/(yu*yv)}, yw] + 4*G[{0}, yv^(-1)]*G[{1}, yu^(-1)]*
      G[{1, 1/(yu*yv), 1/(yu*yv)}, yw] - 4*G[{0}, yw]*G[{1}, yu^(-1)]*
      G[{1, 1/(yu*yv), 1/(yu*yv)}, yw] - 2*G[{1}, yu^(-1)]^2*
      G[{1, 1/(yu*yv), 1/(yu*yv)}, yw] - 4*G[{0}, yu^(-1)]*G[{1}, yv^(-1)]*
      G[{1, 1/(yu*yv), 1/(yu*yv)}, yw] - 4*G[{0}, yv^(-1)]*G[{1}, yv^(-1)]*
      G[{1, 1/(yu*yv), 1/(yu*yv)}, yw] + 4*G[{0}, yw]*G[{1}, yv^(-1)]*
      G[{1, 1/(yu*yv), 1/(yu*yv)}, yw] + 6*G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*
      G[{1, 1/(yu*yv), 1/(yu*yv)}, yw] + 6*G[{1}, yv^(-1)]^2*
      G[{1, 1/(yu*yv), 1/(yu*yv)}, yw] - 8*G[{0}, yu^(-1)]*G[{1}, yw]*
      G[{1, 1/(yu*yv), 1/(yu*yv)}, yw] - 8*G[{0}, yv^(-1)]*G[{1}, yw]*
      G[{1, 1/(yu*yv), 1/(yu*yv)}, yw] + 8*G[{0}, yw]*G[{1}, yw]*
      G[{1, 1/(yu*yv), 1/(yu*yv)}, yw] + 8*G[{1}, yu^(-1)]*G[{1}, yw]*
      G[{1, 1/(yu*yv), 1/(yu*yv)}, yw] + 8*G[{1}, yv^(-1)]*G[{1}, yw]*
      G[{1, 1/(yu*yv), 1/(yu*yv)}, yw] + 8*G[{0}, yu^(-1)]*G[{yu}, yv^(-1)]*
      G[{1, 1/(yu*yv), 1/(yu*yv)}, yw] + 8*G[{0}, yv^(-1)]*G[{yu}, yv^(-1)]*
      G[{1, 1/(yu*yv), 1/(yu*yv)}, yw] - 8*G[{0}, yw]*G[{yu}, yv^(-1)]*
      G[{1, 1/(yu*yv), 1/(yu*yv)}, yw] - 10*G[{1}, yu^(-1)]*G[{yu}, yv^(-1)]*
      G[{1, 1/(yu*yv), 1/(yu*yv)}, yw] - 4*G[{1}, yv^(-1)]*G[{yu}, yv^(-1)]*
      G[{1, 1/(yu*yv), 1/(yu*yv)}, yw] - G[{yu}, yv^(-1)]^2*
      G[{1, 1/(yu*yv), 1/(yu*yv)}, yw] + 4*G[{0}, yu^(-1)]*G[{yv^(-1)}, yw]*
      G[{1, 1/(yu*yv), 1/(yu*yv)}, yw] + 4*G[{0}, yv^(-1)]*G[{yv^(-1)}, yw]*
      G[{1, 1/(yu*yv), 1/(yu*yv)}, yw] - 4*G[{0}, yw]*G[{yv^(-1)}, yw]*
      G[{1, 1/(yu*yv), 1/(yu*yv)}, yw] - 6*G[{1}, yu^(-1)]*G[{yv^(-1)}, yw]*
      G[{1, 1/(yu*yv), 1/(yu*yv)}, yw] - 8*G[{1}, yv^(-1)]*G[{yv^(-1)}, yw]*
      G[{1, 1/(yu*yv), 1/(yu*yv)}, yw] - 6*G[{1}, yw]*G[{yv^(-1)}, yw]*
      G[{1, 1/(yu*yv), 1/(yu*yv)}, yw] + 6*G[{yu}, yv^(-1)]*G[{yv^(-1)}, yw]*
      G[{1, 1/(yu*yv), 1/(yu*yv)}, yw] + G[{yv^(-1)}, yw]^2*
      G[{1, 1/(yu*yv), 1/(yu*yv)}, yw] - 8*G[{0}, yu^(-1)]*G[{1/(yu*yv)}, yw]*
      G[{1, 1/(yu*yv), 1/(yu*yv)}, yw] - 8*G[{0}, yv^(-1)]*G[{1/(yu*yv)}, yw]*
      G[{1, 1/(yu*yv), 1/(yu*yv)}, yw] + 8*G[{0}, yw]*G[{1/(yu*yv)}, yw]*
      G[{1, 1/(yu*yv), 1/(yu*yv)}, yw] + 10*G[{1}, yu^(-1)]*
      G[{1/(yu*yv)}, yw]*G[{1, 1/(yu*yv), 1/(yu*yv)}, yw] + 
     4*G[{1}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{1, 1/(yu*yv), 1/(yu*yv)}, yw] - 
     2*G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{1, 1/(yu*yv), 1/(yu*yv)}, yw] + 
     2*G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{1, 1/(yu*yv), 1/(yu*yv)}, yw] - 
     2*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{1, 1/(yu*yv), 1/(yu*yv)}, yw] + 
     2*G[{0, 1}, yu^(-1)]*G[{1, 1/(yu*yv), 1/(yu*yv)}, yw] - 
     4*G[{0, 1}, yv^(-1)]*G[{1, 1/(yu*yv), 1/(yu*yv)}, yw] + 
     4*G[{0, yu}, yv^(-1)]*G[{1, 1/(yu*yv), 1/(yu*yv)}, yw] - 
     4*G[{1, yu^(-1)}, yw]*G[{1, 1/(yu*yv), 1/(yu*yv)}, yw] - 
     6*G[{1, yu}, yv^(-1)]*G[{1, 1/(yu*yv), 1/(yu*yv)}, yw] + 
     2*G[{1, yv^(-1)}, yw]*G[{1, 1/(yu*yv), 1/(yu*yv)}, yw] + 
     2*G[{1, 1/(yu*yv)}, yw]*G[{1, 1/(yu*yv), 1/(yu*yv)}, yw] + 
     2*G[{yv^(-1), 1/(yu*yv)}, yw]*G[{1, 1/(yu*yv), 1/(yu*yv)}, yw] - 
     4*G[{0}, yu^(-1)]*G[{yv^(-1)}, yw]*G[{yu^(-1), yu^(-1), 1/(yu*yv)}, 
       yw] - 4*G[{0}, yv^(-1)]*G[{yv^(-1)}, yw]*
      G[{yu^(-1), yu^(-1), 1/(yu*yv)}, yw] + 4*G[{0}, yw]*G[{yv^(-1)}, yw]*
      G[{yu^(-1), yu^(-1), 1/(yu*yv)}, yw] + 4*G[{1}, yu^(-1)]*
      G[{yv^(-1)}, yw]*G[{yu^(-1), yu^(-1), 1/(yu*yv)}, yw] + 
     8*G[{1}, yv^(-1)]*G[{yv^(-1)}, yw]*G[{yu^(-1), yu^(-1), 1/(yu*yv)}, 
       yw] + 4*G[{1}, yw]*G[{yv^(-1)}, yw]*G[{yu^(-1), yu^(-1), 1/(yu*yv)}, 
       yw] - 8*G[{yu^(-1)}, yw]*G[{yv^(-1)}, yw]*
      G[{yu^(-1), yu^(-1), 1/(yu*yv)}, yw] - 4*G[{yu}, yv^(-1)]*
      G[{yv^(-1)}, yw]*G[{yu^(-1), yu^(-1), 1/(yu*yv)}, yw] - 
     4*G[{0}, yu^(-1)]*G[{1/(yu*yv)}, yw]*G[{yu^(-1), yu^(-1), 1/(yu*yv)}, 
       yw] - 4*G[{0}, yv^(-1)]*G[{1/(yu*yv)}, yw]*
      G[{yu^(-1), yu^(-1), 1/(yu*yv)}, yw] + 4*G[{0}, yw]*G[{1/(yu*yv)}, yw]*
      G[{yu^(-1), yu^(-1), 1/(yu*yv)}, yw] + 4*G[{1}, yu^(-1)]*
      G[{1/(yu*yv)}, yw]*G[{yu^(-1), yu^(-1), 1/(yu*yv)}, yw] + 
     8*G[{1}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{yu^(-1), yu^(-1), 1/(yu*yv)}, 
       yw] + 4*G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{yu^(-1), yu^(-1), 1/(yu*yv)}, 
       yw] - 8*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*
      G[{yu^(-1), yu^(-1), 1/(yu*yv)}, yw] - 4*G[{yu}, yv^(-1)]*
      G[{1/(yu*yv)}, yw]*G[{yu^(-1), yu^(-1), 1/(yu*yv)}, yw] - 
     2*G[{1/(yu*yv)}, yw]^2*G[{yu^(-1), yu^(-1), 1/(yu*yv)}, yw] - 
     4*G[{yv^(-1), 1/(yu*yv)}, yw]*G[{yu^(-1), yu^(-1), 1/(yu*yv)}, yw] - 
     (Pi^2*G[{yu^(-1), 1/(yu*yv), yv^(-1)}, yw])/3 + 
     2*G[{0}, yu^(-1)]*G[{1}, yv^(-1)]*G[{yu^(-1), 1/(yu*yv), yv^(-1)}, yw] + 
     2*G[{0}, yv^(-1)]*G[{1}, yv^(-1)]*G[{yu^(-1), 1/(yu*yv), yv^(-1)}, yw] - 
     2*G[{0}, yw]*G[{1}, yv^(-1)]*G[{yu^(-1), 1/(yu*yv), yv^(-1)}, yw] - 
     2*G[{1}, yv^(-1)]^2*G[{yu^(-1), 1/(yu*yv), yv^(-1)}, yw] + 
     4*G[{0}, yu^(-1)]*G[{1}, yw]*G[{yu^(-1), 1/(yu*yv), yv^(-1)}, yw] + 
     4*G[{0}, yv^(-1)]*G[{1}, yw]*G[{yu^(-1), 1/(yu*yv), yv^(-1)}, yw] - 
     4*G[{0}, yw]*G[{1}, yw]*G[{yu^(-1), 1/(yu*yv), yv^(-1)}, yw] - 
     4*G[{1}, yu^(-1)]*G[{1}, yw]*G[{yu^(-1), 1/(yu*yv), yv^(-1)}, yw] - 
     4*G[{1}, yv^(-1)]*G[{1}, yw]*G[{yu^(-1), 1/(yu*yv), yv^(-1)}, yw] - 
     4*G[{0}, yu^(-1)]*G[{yu^(-1)}, yw]*G[{yu^(-1), 1/(yu*yv), yv^(-1)}, 
       yw] - 4*G[{0}, yv^(-1)]*G[{yu^(-1)}, yw]*
      G[{yu^(-1), 1/(yu*yv), yv^(-1)}, yw] + 4*G[{0}, yw]*G[{yu^(-1)}, yw]*
      G[{yu^(-1), 1/(yu*yv), yv^(-1)}, yw] + 4*G[{1}, yu^(-1)]*
      G[{yu^(-1)}, yw]*G[{yu^(-1), 1/(yu*yv), yv^(-1)}, yw] + 
     8*G[{1}, yv^(-1)]*G[{yu^(-1)}, yw]*G[{yu^(-1), 1/(yu*yv), yv^(-1)}, 
       yw] + 4*G[{1}, yw]*G[{yu^(-1)}, yw]*G[{yu^(-1), 1/(yu*yv), yv^(-1)}, 
       yw] - 4*G[{yu^(-1)}, yw]^2*G[{yu^(-1), 1/(yu*yv), yv^(-1)}, yw] - 
     2*G[{0}, yu^(-1)]*G[{yu}, yv^(-1)]*G[{yu^(-1), 1/(yu*yv), yv^(-1)}, 
       yw] - 2*G[{0}, yv^(-1)]*G[{yu}, yv^(-1)]*
      G[{yu^(-1), 1/(yu*yv), yv^(-1)}, yw] + 2*G[{0}, yw]*G[{yu}, yv^(-1)]*
      G[{yu^(-1), 1/(yu*yv), yv^(-1)}, yw] + 4*G[{1}, yv^(-1)]*
      G[{yu}, yv^(-1)]*G[{yu^(-1), 1/(yu*yv), yv^(-1)}, yw] - 
     4*G[{yu^(-1)}, yw]*G[{yu}, yv^(-1)]*G[{yu^(-1), 1/(yu*yv), yv^(-1)}, 
       yw] + 2*G[{0}, yu^(-1)]*G[{yv^(-1)}, yw]*
      G[{yu^(-1), 1/(yu*yv), yv^(-1)}, yw] + 2*G[{0}, yv^(-1)]*
      G[{yv^(-1)}, yw]*G[{yu^(-1), 1/(yu*yv), yv^(-1)}, yw] - 
     2*G[{0}, yw]*G[{yv^(-1)}, yw]*G[{yu^(-1), 1/(yu*yv), yv^(-1)}, yw] - 
     4*G[{1}, yu^(-1)]*G[{yv^(-1)}, yw]*G[{yu^(-1), 1/(yu*yv), yv^(-1)}, 
       yw] - 4*G[{1}, yv^(-1)]*G[{yv^(-1)}, yw]*
      G[{yu^(-1), 1/(yu*yv), yv^(-1)}, yw] - 4*G[{1}, yw]*G[{yv^(-1)}, yw]*
      G[{yu^(-1), 1/(yu*yv), yv^(-1)}, yw] + 4*G[{yu^(-1)}, yw]*
      G[{yv^(-1)}, yw]*G[{yu^(-1), 1/(yu*yv), yv^(-1)}, yw] + 
     4*G[{yu}, yv^(-1)]*G[{yv^(-1)}, yw]*G[{yu^(-1), 1/(yu*yv), yv^(-1)}, 
       yw] + 2*G[{0}, yu^(-1)]*G[{1/(yu*yv)}, yw]*
      G[{yu^(-1), 1/(yu*yv), yv^(-1)}, yw] + 2*G[{0}, yv^(-1)]*
      G[{1/(yu*yv)}, yw]*G[{yu^(-1), 1/(yu*yv), yv^(-1)}, yw] - 
     2*G[{0}, yw]*G[{1/(yu*yv)}, yw]*G[{yu^(-1), 1/(yu*yv), yv^(-1)}, yw] - 
     4*G[{1}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{yu^(-1), 1/(yu*yv), yv^(-1)}, 
       yw] + 4*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*
      G[{yu^(-1), 1/(yu*yv), yv^(-1)}, yw] - 4*G[{yv^(-1)}, yw]*
      G[{1/(yu*yv)}, yw]*G[{yu^(-1), 1/(yu*yv), yv^(-1)}, yw] + 
     2*G[{1/(yu*yv)}, yw]^2*G[{yu^(-1), 1/(yu*yv), yv^(-1)}, yw] + 
     2*G[{0, 1}, yu^(-1)]*G[{yu^(-1), 1/(yu*yv), yv^(-1)}, yw] - 
     2*G[{0, 1}, yv^(-1)]*G[{yu^(-1), 1/(yu*yv), yv^(-1)}, yw] + 
     2*G[{0, 1}, yw]*G[{yu^(-1), 1/(yu*yv), yv^(-1)}, yw] - 
     2*G[{0, yu^(-1)}, yw]*G[{yu^(-1), 1/(yu*yv), yv^(-1)}, yw] + 
     2*G[{0, yu}, yv^(-1)]*G[{yu^(-1), 1/(yu*yv), yv^(-1)}, yw] - 
     2*G[{0, yv^(-1)}, yw]*G[{yu^(-1), 1/(yu*yv), yv^(-1)}, yw] + 
     2*G[{0, 1/(yu*yv)}, yw]*G[{yu^(-1), 1/(yu*yv), yv^(-1)}, yw] - 
     4*G[{1, yu}, yv^(-1)]*G[{yu^(-1), 1/(yu*yv), yv^(-1)}, yw] + 
     4*G[{1, yv^(-1)}, yw]*G[{yu^(-1), 1/(yu*yv), yv^(-1)}, yw] - 
     4*G[{yu^(-1), 1/(yu*yv)}, yw]*G[{yu^(-1), 1/(yu*yv), yv^(-1)}, yw] + 
     4*G[{yv^(-1), 1/(yu*yv)}, yw]*G[{yu^(-1), 1/(yu*yv), yv^(-1)}, yw] - 
     (Pi^2*G[{yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/3 + 
     2*G[{0}, yu^(-1)]*G[{1}, yv^(-1)]*G[{yu^(-1), 1/(yu*yv), 1/(yu*yv)}, 
       yw] + 2*G[{0}, yv^(-1)]*G[{1}, yv^(-1)]*
      G[{yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] - 2*G[{0}, yw]*G[{1}, yv^(-1)]*
      G[{yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] - 2*G[{1}, yv^(-1)]^2*
      G[{yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] + 4*G[{0}, yu^(-1)]*G[{1}, yw]*
      G[{yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] + 4*G[{0}, yv^(-1)]*G[{1}, yw]*
      G[{yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] - 4*G[{0}, yw]*G[{1}, yw]*
      G[{yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] - 4*G[{1}, yu^(-1)]*G[{1}, yw]*
      G[{yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] - 4*G[{1}, yv^(-1)]*G[{1}, yw]*
      G[{yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] - 4*G[{0}, yu^(-1)]*
      G[{yu^(-1)}, yw]*G[{yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] - 
     4*G[{0}, yv^(-1)]*G[{yu^(-1)}, yw]*G[{yu^(-1), 1/(yu*yv), 1/(yu*yv)}, 
       yw] + 4*G[{0}, yw]*G[{yu^(-1)}, yw]*G[{yu^(-1), 1/(yu*yv), 1/(yu*yv)}, 
       yw] + 4*G[{1}, yu^(-1)]*G[{yu^(-1)}, yw]*
      G[{yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] + 8*G[{1}, yv^(-1)]*
      G[{yu^(-1)}, yw]*G[{yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] + 
     4*G[{1}, yw]*G[{yu^(-1)}, yw]*G[{yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] - 
     4*G[{yu^(-1)}, yw]^2*G[{yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] - 
     2*G[{0}, yu^(-1)]*G[{yu}, yv^(-1)]*G[{yu^(-1), 1/(yu*yv), 1/(yu*yv)}, 
       yw] - 2*G[{0}, yv^(-1)]*G[{yu}, yv^(-1)]*
      G[{yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] + 2*G[{0}, yw]*G[{yu}, yv^(-1)]*
      G[{yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] + 4*G[{1}, yv^(-1)]*
      G[{yu}, yv^(-1)]*G[{yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] - 
     4*G[{yu^(-1)}, yw]*G[{yu}, yv^(-1)]*G[{yu^(-1), 1/(yu*yv), 1/(yu*yv)}, 
       yw] - 2*G[{0}, yu^(-1)]*G[{yv^(-1)}, yw]*
      G[{yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] - 2*G[{0}, yv^(-1)]*
      G[{yv^(-1)}, yw]*G[{yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] + 
     2*G[{0}, yw]*G[{yv^(-1)}, yw]*G[{yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] + 
     4*G[{1}, yv^(-1)]*G[{yv^(-1)}, yw]*G[{yu^(-1), 1/(yu*yv), 1/(yu*yv)}, 
       yw] - 4*G[{yu^(-1)}, yw]*G[{yv^(-1)}, yw]*
      G[{yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] - 2*G[{0}, yu^(-1)]*
      G[{1/(yu*yv)}, yw]*G[{yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] - 
     2*G[{0}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{yu^(-1), 1/(yu*yv), 1/(yu*yv)}, 
       yw] + 2*G[{0}, yw]*G[{1/(yu*yv)}, yw]*
      G[{yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] + 4*G[{1}, yu^(-1)]*
      G[{1/(yu*yv)}, yw]*G[{yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] + 
     4*G[{1}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{yu^(-1), 1/(yu*yv), 1/(yu*yv)}, 
       yw] + 4*G[{1}, yw]*G[{1/(yu*yv)}, yw]*
      G[{yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] - 4*G[{yu^(-1)}, yw]*
      G[{1/(yu*yv)}, yw]*G[{yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] - 
     4*G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{yu^(-1), 1/(yu*yv), 1/(yu*yv)}, 
       yw] + 2*G[{0, 1}, yu^(-1)]*G[{yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] - 
     2*G[{0, 1}, yv^(-1)]*G[{yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] + 
     2*G[{0, 1}, yw]*G[{yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] - 
     2*G[{0, yu^(-1)}, yw]*G[{yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] + 
     2*G[{0, yu}, yv^(-1)]*G[{yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] - 
     2*G[{0, yv^(-1)}, yw]*G[{yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] + 
     2*G[{0, 1/(yu*yv)}, yw]*G[{yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] - 
     4*G[{1, yu}, yv^(-1)]*G[{yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] + 
     4*G[{1, yv^(-1)}, yw]*G[{yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] - 
     4*G[{yu^(-1), 1/(yu*yv)}, yw]*G[{yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] + 
     2*G[{0}, yu^(-1)]^2*G[{yv^(-1), yv^(-1), 1/(yu*yv)}, yw] + 
     4*G[{0}, yu^(-1)]*G[{0}, yv^(-1)]*G[{yv^(-1), yv^(-1), 1/(yu*yv)}, yw] + 
     2*G[{0}, yv^(-1)]^2*G[{yv^(-1), yv^(-1), 1/(yu*yv)}, yw] - 
     4*G[{0}, yu^(-1)]*G[{0}, yw]*G[{yv^(-1), yv^(-1), 1/(yu*yv)}, yw] - 
     4*G[{0}, yv^(-1)]*G[{0}, yw]*G[{yv^(-1), yv^(-1), 1/(yu*yv)}, yw] + 
     2*G[{0}, yw]^2*G[{yv^(-1), yv^(-1), 1/(yu*yv)}, yw] - 
     4*G[{0}, yu^(-1)]*G[{1}, yu^(-1)]*G[{yv^(-1), yv^(-1), 1/(yu*yv)}, yw] - 
     4*G[{0}, yv^(-1)]*G[{1}, yu^(-1)]*G[{yv^(-1), yv^(-1), 1/(yu*yv)}, yw] + 
     4*G[{0}, yw]*G[{1}, yu^(-1)]*G[{yv^(-1), yv^(-1), 1/(yu*yv)}, yw] + 
     2*G[{1}, yu^(-1)]^2*G[{yv^(-1), yv^(-1), 1/(yu*yv)}, yw] - 
     4*G[{0}, yu^(-1)]*G[{1}, yv^(-1)]*G[{yv^(-1), yv^(-1), 1/(yu*yv)}, yw] - 
     4*G[{0}, yv^(-1)]*G[{1}, yv^(-1)]*G[{yv^(-1), yv^(-1), 1/(yu*yv)}, yw] + 
     4*G[{0}, yw]*G[{1}, yv^(-1)]*G[{yv^(-1), yv^(-1), 1/(yu*yv)}, yw] + 
     2*G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*G[{yv^(-1), yv^(-1), 1/(yu*yv)}, yw] + 
     2*G[{1}, yv^(-1)]^2*G[{yv^(-1), yv^(-1), 1/(yu*yv)}, yw] + 
     4*G[{0}, yu^(-1)]*G[{yu^(-1)}, yw]*G[{yv^(-1), yv^(-1), 1/(yu*yv)}, 
       yw] + 4*G[{0}, yv^(-1)]*G[{yu^(-1)}, yw]*
      G[{yv^(-1), yv^(-1), 1/(yu*yv)}, yw] - 4*G[{0}, yw]*G[{yu^(-1)}, yw]*
      G[{yv^(-1), yv^(-1), 1/(yu*yv)}, yw] - 4*G[{1}, yu^(-1)]*
      G[{yu^(-1)}, yw]*G[{yv^(-1), yv^(-1), 1/(yu*yv)}, yw] - 
     8*G[{1}, yv^(-1)]*G[{yu^(-1)}, yw]*G[{yv^(-1), yv^(-1), 1/(yu*yv)}, 
       yw] - 4*G[{1}, yw]*G[{yu^(-1)}, yw]*G[{yv^(-1), yv^(-1), 1/(yu*yv)}, 
       yw] + 4*G[{yu^(-1)}, yw]^2*G[{yv^(-1), yv^(-1), 1/(yu*yv)}, yw] + 
     2*G[{1}, yu^(-1)]*G[{yu}, yv^(-1)]*G[{yv^(-1), yv^(-1), 1/(yu*yv)}, 
       yw] - 4*G[{1}, yv^(-1)]*G[{yu}, yv^(-1)]*
      G[{yv^(-1), yv^(-1), 1/(yu*yv)}, yw] + 4*G[{yu^(-1)}, yw]*
      G[{yu}, yv^(-1)]*G[{yv^(-1), yv^(-1), 1/(yu*yv)}, yw] + 
     G[{yu}, yv^(-1)]^2*G[{yv^(-1), yv^(-1), 1/(yu*yv)}, yw] + 
     4*G[{0}, yu^(-1)]*G[{yv^(-1)}, yw]*G[{yv^(-1), yv^(-1), 1/(yu*yv)}, 
       yw] + 4*G[{0}, yv^(-1)]*G[{yv^(-1)}, yw]*
      G[{yv^(-1), yv^(-1), 1/(yu*yv)}, yw] - 4*G[{0}, yw]*G[{yv^(-1)}, yw]*
      G[{yv^(-1), yv^(-1), 1/(yu*yv)}, yw] - 2*G[{1}, yu^(-1)]*
      G[{yv^(-1)}, yw]*G[{yv^(-1), yv^(-1), 1/(yu*yv)}, yw] - 
     4*G[{1}, yv^(-1)]*G[{yv^(-1)}, yw]*G[{yv^(-1), yv^(-1), 1/(yu*yv)}, 
       yw] + 2*G[{1}, yw]*G[{yv^(-1)}, yw]*G[{yv^(-1), yv^(-1), 1/(yu*yv)}, 
       yw] + 4*G[{yu^(-1)}, yw]*G[{yv^(-1)}, yw]*
      G[{yv^(-1), yv^(-1), 1/(yu*yv)}, yw] - 2*G[{yu}, yv^(-1)]*
      G[{yv^(-1)}, yw]*G[{yv^(-1), yv^(-1), 1/(yu*yv)}, yw] + 
     G[{yv^(-1)}, yw]^2*G[{yv^(-1), yv^(-1), 1/(yu*yv)}, yw] + 
     4*G[{0}, yu^(-1)]*G[{1/(yu*yv)}, yw]*G[{yv^(-1), yv^(-1), 1/(yu*yv)}, 
       yw] + 4*G[{0}, yv^(-1)]*G[{1/(yu*yv)}, yw]*
      G[{yv^(-1), yv^(-1), 1/(yu*yv)}, yw] - 4*G[{0}, yw]*G[{1/(yu*yv)}, yw]*
      G[{yv^(-1), yv^(-1), 1/(yu*yv)}, yw] - 6*G[{1}, yu^(-1)]*
      G[{1/(yu*yv)}, yw]*G[{yv^(-1), yv^(-1), 1/(yu*yv)}, yw] + 
     4*G[{1}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{yv^(-1), yv^(-1), 1/(yu*yv)}, 
       yw] + 6*G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{yv^(-1), yv^(-1), 1/(yu*yv)}, 
       yw] - 4*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*
      G[{yv^(-1), yv^(-1), 1/(yu*yv)}, yw] - 6*G[{yu}, yv^(-1)]*
      G[{1/(yu*yv)}, yw]*G[{yv^(-1), yv^(-1), 1/(yu*yv)}, yw] + 
     6*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{yv^(-1), yv^(-1), 1/(yu*yv)}, 
       yw] - 2*G[{0, 1}, yu^(-1)]*G[{yv^(-1), yv^(-1), 1/(yu*yv)}, yw] + 
     4*G[{0, 1}, yv^(-1)]*G[{yv^(-1), yv^(-1), 1/(yu*yv)}, yw] - 
     4*G[{0, yu}, yv^(-1)]*G[{yv^(-1), yv^(-1), 1/(yu*yv)}, yw] + 
     4*G[{1, yu^(-1)}, yw]*G[{yv^(-1), yv^(-1), 1/(yu*yv)}, yw] + 
     6*G[{1, yu}, yv^(-1)]*G[{yv^(-1), yv^(-1), 1/(yu*yv)}, yw] - 
     2*G[{1, yv^(-1)}, yw]*G[{yv^(-1), yv^(-1), 1/(yu*yv)}, yw] - 
     2*G[{1, 1/(yu*yv)}, yw]*G[{yv^(-1), yv^(-1), 1/(yu*yv)}, yw] + 
     4*G[{yu^(-1), 1/(yu*yv)}, yw]*G[{yv^(-1), yv^(-1), 1/(yu*yv)}, yw] - 
     6*G[{yv^(-1), 1/(yu*yv)}, yw]*G[{yv^(-1), yv^(-1), 1/(yu*yv)}, yw] - 
     (Pi^2*G[{yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/3 + 
     2*G[{0}, yu^(-1)]^2*G[{yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] + 
     4*G[{0}, yu^(-1)]*G[{0}, yv^(-1)]*G[{yv^(-1), 1/(yu*yv), 1/(yu*yv)}, 
       yw] + 2*G[{0}, yv^(-1)]^2*G[{yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] - 
     4*G[{0}, yu^(-1)]*G[{0}, yw]*G[{yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] - 
     4*G[{0}, yv^(-1)]*G[{0}, yw]*G[{yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] + 
     2*G[{0}, yw]^2*G[{yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] - 
     4*G[{0}, yu^(-1)]*G[{1}, yu^(-1)]*G[{yv^(-1), 1/(yu*yv), 1/(yu*yv)}, 
       yw] - 4*G[{0}, yv^(-1)]*G[{1}, yu^(-1)]*
      G[{yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] + 4*G[{0}, yw]*G[{1}, yu^(-1)]*
      G[{yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] + 2*G[{1}, yu^(-1)]^2*
      G[{yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] - 2*G[{0}, yu^(-1)]*
      G[{1}, yv^(-1)]*G[{yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] - 
     2*G[{0}, yv^(-1)]*G[{1}, yv^(-1)]*G[{yv^(-1), 1/(yu*yv), 1/(yu*yv)}, 
       yw] + 2*G[{0}, yw]*G[{1}, yv^(-1)]*G[{yv^(-1), 1/(yu*yv), 1/(yu*yv)}, 
       yw] + 2*G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*
      G[{yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] + 4*G[{0}, yu^(-1)]*G[{1}, yw]*
      G[{yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] + 4*G[{0}, yv^(-1)]*G[{1}, yw]*
      G[{yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] - 4*G[{0}, yw]*G[{1}, yw]*
      G[{yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] - 4*G[{1}, yu^(-1)]*G[{1}, yw]*
      G[{yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] - 4*G[{1}, yv^(-1)]*G[{1}, yw]*
      G[{yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] - 2*G[{0}, yu^(-1)]*
      G[{yu}, yv^(-1)]*G[{yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] - 
     2*G[{0}, yv^(-1)]*G[{yu}, yv^(-1)]*G[{yv^(-1), 1/(yu*yv), 1/(yu*yv)}, 
       yw] + 2*G[{0}, yw]*G[{yu}, yv^(-1)]*G[{yv^(-1), 1/(yu*yv), 1/(yu*yv)}, 
       yw] + 2*G[{1}, yu^(-1)]*G[{yu}, yv^(-1)]*
      G[{yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] + G[{yu}, yv^(-1)]^2*
      G[{yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] + 2*G[{0}, yu^(-1)]*
      G[{yv^(-1)}, yw]*G[{yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] + 
     2*G[{0}, yv^(-1)]*G[{yv^(-1)}, yw]*G[{yv^(-1), 1/(yu*yv), 1/(yu*yv)}, 
       yw] - 2*G[{0}, yw]*G[{yv^(-1)}, yw]*G[{yv^(-1), 1/(yu*yv), 1/(yu*yv)}, 
       yw] - 2*G[{1}, yu^(-1)]*G[{yv^(-1)}, yw]*
      G[{yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] + 2*G[{1}, yw]*G[{yv^(-1)}, yw]*
      G[{yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] - 2*G[{yu}, yv^(-1)]*
      G[{yv^(-1)}, yw]*G[{yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] + 
     G[{yv^(-1)}, yw]^2*G[{yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] + 
     2*G[{0}, yu^(-1)]*G[{1/(yu*yv)}, yw]*G[{yv^(-1), 1/(yu*yv), 1/(yu*yv)}, 
       yw] + 2*G[{0}, yv^(-1)]*G[{1/(yu*yv)}, yw]*
      G[{yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] - 
     2*G[{0}, yw]*G[{1/(yu*yv)}, yw]*G[{yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] - 
     2*G[{1}, yu^(-1)]*G[{1/(yu*yv)}, yw]*G[{yv^(-1), 1/(yu*yv), 1/(yu*yv)}, 
       yw] + 4*G[{1}, yv^(-1)]*G[{1/(yu*yv)}, yw]*
      G[{yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] + 
     6*G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] - 
     4*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{yv^(-1), 1/(yu*yv), 1/(yu*yv)}, 
       yw] - 6*G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw]*
      G[{yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] + 2*G[{yv^(-1)}, yw]*
      G[{1/(yu*yv)}, yw]*G[{yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] + 
     2*G[{0, 1}, yv^(-1)]*G[{yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] + 
     2*G[{0, 1}, yw]*G[{yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] - 
     2*G[{0, yu^(-1)}, yw]*G[{yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] - 
     2*G[{0, yu}, yv^(-1)]*G[{yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] - 
     2*G[{0, yv^(-1)}, yw]*G[{yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] + 
     2*G[{0, 1/(yu*yv)}, yw]*G[{yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] + 
     4*G[{1, yu^(-1)}, yw]*G[{yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] + 
     2*G[{1, yu}, yv^(-1)]*G[{yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] + 
     2*G[{1, yv^(-1)}, yw]*G[{yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] - 
     2*G[{1, 1/(yu*yv)}, yw]*G[{yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] - 
     2*G[{yv^(-1), 1/(yu*yv)}, yw]*G[{yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] + 
     4*G[{0}, yu^(-1)]*G[{0, 0, 1, 1}, yu^(-1)] + 
     4*G[{0}, yv^(-1)]*G[{0, 0, 1, 1}, yu^(-1)] - 
     4*G[{0}, yw]*G[{0, 0, 1, 1}, yu^(-1)] - 4*G[{1}, yv^(-1)]*
      G[{0, 0, 1, 1}, yu^(-1)] + 4*G[{yv^(-1)}, yw]*
      G[{0, 0, 1, 1}, yu^(-1)] - 4*G[{0}, yu^(-1)]*G[{0, 0, 1, 1}, yv^(-1)] - 
     4*G[{0}, yv^(-1)]*G[{0, 0, 1, 1}, yv^(-1)] + 
     4*G[{0}, yw]*G[{0, 0, 1, 1}, yv^(-1)] + 4*G[{1}, yu^(-1)]*
      G[{0, 0, 1, 1}, yv^(-1)] + 4*G[{yu}, yv^(-1)]*
      G[{0, 0, 1, 1}, yv^(-1)] - 4*G[{1/(yu*yv)}, yw]*
      G[{0, 0, 1, 1}, yv^(-1)] + 4*G[{yv^(-1)}, yw]*G[{0, 0, 1, 1}, yw] - 
     4*G[{yv^(-1)}, yw]*G[{0, 0, 1, yu^(-1)}, yw] + 
     4*G[{0}, yu^(-1)]*G[{0, 0, 1, yu}, yv^(-1)] + 
     4*G[{0}, yv^(-1)]*G[{0, 0, 1, yu}, yv^(-1)] - 
     4*G[{0}, yw]*G[{0, 0, 1, yu}, yv^(-1)] - 4*G[{1}, yu^(-1)]*
      G[{0, 0, 1, yu}, yv^(-1)] - 4*G[{1}, yv^(-1)]*
      G[{0, 0, 1, yu}, yv^(-1)] + 4*G[{yv^(-1)}, yw]*
      G[{0, 0, 1, yu}, yv^(-1)] + 4*G[{0}, yu^(-1)]*G[{0, 0, 1, yv^(-1)}, 
       yw] + 4*G[{0}, yv^(-1)]*G[{0, 0, 1, yv^(-1)}, yw] - 
     4*G[{0}, yw]*G[{0, 0, 1, yv^(-1)}, yw] - 4*G[{1}, yu^(-1)]*
      G[{0, 0, 1, yv^(-1)}, yw] - 4*G[{1}, yv^(-1)]*G[{0, 0, 1, yv^(-1)}, 
       yw] - 4*G[{yv^(-1)}, yw]*G[{0, 0, 1, yv^(-1)}, yw] - 
     4*G[{0}, yu^(-1)]*G[{0, 0, 1, 1/(yu*yv)}, yw] - 
     4*G[{0}, yv^(-1)]*G[{0, 0, 1, 1/(yu*yv)}, yw] + 
     4*G[{0}, yw]*G[{0, 0, 1, 1/(yu*yv)}, yw] + 4*G[{1}, yu^(-1)]*
      G[{0, 0, 1, 1/(yu*yv)}, yw] + 4*G[{yu}, yv^(-1)]*
      G[{0, 0, 1, 1/(yu*yv)}, yw] + 8*G[{yv^(-1)}, yw]*
      G[{0, 0, 1, 1/(yu*yv)}, yw] - 4*G[{1/(yu*yv)}, yw]*
      G[{0, 0, 1, 1/(yu*yv)}, yw] - 8*G[{yv^(-1)}, yw]*
      G[{0, 0, yu^(-1), 1}, yw] + 4*G[{1/(yu*yv)}, yw]*
      G[{0, 0, yu^(-1), 1}, yw] + 4*G[{yv^(-1)}, yw]*
      G[{0, 0, yu^(-1), yu^(-1)}, yw] - 4*G[{0}, yu^(-1)]*
      G[{0, 0, yu^(-1), yv^(-1)}, yw] - 4*G[{0}, yv^(-1)]*
      G[{0, 0, yu^(-1), yv^(-1)}, yw] + 4*G[{0}, yw]*
      G[{0, 0, yu^(-1), yv^(-1)}, yw] + 4*G[{1}, yu^(-1)]*
      G[{0, 0, yu^(-1), yv^(-1)}, yw] + 8*G[{1}, yv^(-1)]*
      G[{0, 0, yu^(-1), yv^(-1)}, yw] - 4*G[{yu}, yv^(-1)]*
      G[{0, 0, yu^(-1), yv^(-1)}, yw] + 4*G[{1/(yu*yv)}, yw]*
      G[{0, 0, yu^(-1), yv^(-1)}, yw] + 4*G[{0}, yu^(-1)]*
      G[{0, 0, yu^(-1), 1/(yu*yv)}, yw] + 4*G[{0}, yv^(-1)]*
      G[{0, 0, yu^(-1), 1/(yu*yv)}, yw] - 4*G[{0}, yw]*
      G[{0, 0, yu^(-1), 1/(yu*yv)}, yw] - 4*G[{1}, yu^(-1)]*
      G[{0, 0, yu^(-1), 1/(yu*yv)}, yw] - 4*G[{1}, yv^(-1)]*
      G[{0, 0, yu^(-1), 1/(yu*yv)}, yw] - 4*G[{yv^(-1)}, yw]*
      G[{0, 0, yu^(-1), 1/(yu*yv)}, yw] + 4*G[{0}, yu^(-1)]*
      G[{0, 0, yu, 1}, yv^(-1)] + 4*G[{0}, yv^(-1)]*
      G[{0, 0, yu, 1}, yv^(-1)] - 4*G[{0}, yw]*G[{0, 0, yu, 1}, yv^(-1)] - 
     4*G[{1}, yu^(-1)]*G[{0, 0, yu, 1}, yv^(-1)] - 
     4*G[{1}, yv^(-1)]*G[{0, 0, yu, 1}, yv^(-1)] + 
     4*G[{yv^(-1)}, yw]*G[{0, 0, yu, 1}, yv^(-1)] - 
     4*G[{0}, yu^(-1)]*G[{0, 0, yu, yu}, yv^(-1)] - 
     4*G[{0}, yv^(-1)]*G[{0, 0, yu, yu}, yv^(-1)] + 
     4*G[{0}, yw]*G[{0, 0, yu, yu}, yv^(-1)] + 4*G[{1}, yu^(-1)]*
      G[{0, 0, yu, yu}, yv^(-1)] + 4*G[{1}, yv^(-1)]*
      G[{0, 0, yu, yu}, yv^(-1)] - 4*G[{yv^(-1)}, yw]*
      G[{0, 0, yu, yu}, yv^(-1)] + 4*G[{0}, yu^(-1)]*
      G[{0, 0, yv^(-1), 1}, yw] + 4*G[{0}, yv^(-1)]*G[{0, 0, yv^(-1), 1}, 
       yw] - 4*G[{0}, yw]*G[{0, 0, yv^(-1), 1}, yw] - 
     4*G[{1}, yu^(-1)]*G[{0, 0, yv^(-1), 1}, yw] - 
     4*G[{1}, yv^(-1)]*G[{0, 0, yv^(-1), 1}, yw] - 
     8*G[{yv^(-1)}, yw]*G[{0, 0, yv^(-1), 1}, yw] + 
     4*G[{1/(yu*yv)}, yw]*G[{0, 0, yv^(-1), 1}, yw] - 
     4*G[{0}, yu^(-1)]*G[{0, 0, yv^(-1), yu^(-1)}, yw] - 
     4*G[{0}, yv^(-1)]*G[{0, 0, yv^(-1), yu^(-1)}, yw] + 
     4*G[{0}, yw]*G[{0, 0, yv^(-1), yu^(-1)}, yw] + 
     4*G[{1}, yu^(-1)]*G[{0, 0, yv^(-1), yu^(-1)}, yw] + 
     8*G[{1}, yv^(-1)]*G[{0, 0, yv^(-1), yu^(-1)}, yw] - 
     4*G[{yu}, yv^(-1)]*G[{0, 0, yv^(-1), yu^(-1)}, yw] + 
     4*G[{1/(yu*yv)}, yw]*G[{0, 0, yv^(-1), yu^(-1)}, yw] - 
     4*G[{0}, yu^(-1)]*G[{0, 0, yv^(-1), yv^(-1)}, yw] - 
     4*G[{0}, yv^(-1)]*G[{0, 0, yv^(-1), yv^(-1)}, yw] + 
     4*G[{0}, yw]*G[{0, 0, yv^(-1), yv^(-1)}, yw] + 
     4*G[{1}, yu^(-1)]*G[{0, 0, yv^(-1), yv^(-1)}, yw] + 
     4*G[{1}, yv^(-1)]*G[{0, 0, yv^(-1), yv^(-1)}, yw] + 
     4*G[{yv^(-1)}, yw]*G[{0, 0, yv^(-1), yv^(-1)}, yw] + 
     4*G[{0}, yu^(-1)]*G[{0, 0, yv^(-1), 1/(yu*yv)}, yw] + 
     4*G[{0}, yv^(-1)]*G[{0, 0, yv^(-1), 1/(yu*yv)}, yw] - 
     4*G[{0}, yw]*G[{0, 0, yv^(-1), 1/(yu*yv)}, yw] - 
     4*G[{1}, yu^(-1)]*G[{0, 0, yv^(-1), 1/(yu*yv)}, yw] - 
     4*G[{1}, yv^(-1)]*G[{0, 0, yv^(-1), 1/(yu*yv)}, yw] - 
     4*G[{yv^(-1)}, yw]*G[{0, 0, yv^(-1), 1/(yu*yv)}, yw] - 
     4*G[{0}, yu^(-1)]*G[{0, 0, 1/(yu*yv), 1}, yw] - 
     4*G[{0}, yv^(-1)]*G[{0, 0, 1/(yu*yv), 1}, yw] + 
     4*G[{0}, yw]*G[{0, 0, 1/(yu*yv), 1}, yw] + 4*G[{1}, yu^(-1)]*
      G[{0, 0, 1/(yu*yv), 1}, yw] + 4*G[{1}, yv^(-1)]*
      G[{0, 0, 1/(yu*yv), 1}, yw] + 12*G[{yv^(-1)}, yw]*
      G[{0, 0, 1/(yu*yv), 1}, yw] - 8*G[{1/(yu*yv)}, yw]*
      G[{0, 0, 1/(yu*yv), 1}, yw] + 4*G[{0}, yu^(-1)]*
      G[{0, 0, 1/(yu*yv), yu^(-1)}, yw] + 4*G[{0}, yv^(-1)]*
      G[{0, 0, 1/(yu*yv), yu^(-1)}, yw] - 4*G[{0}, yw]*
      G[{0, 0, 1/(yu*yv), yu^(-1)}, yw] - 4*G[{1}, yu^(-1)]*
      G[{0, 0, 1/(yu*yv), yu^(-1)}, yw] - 8*G[{1}, yv^(-1)]*
      G[{0, 0, 1/(yu*yv), yu^(-1)}, yw] + 4*G[{yu}, yv^(-1)]*
      G[{0, 0, 1/(yu*yv), yu^(-1)}, yw] - 4*G[{yv^(-1)}, yw]*
      G[{0, 0, 1/(yu*yv), yu^(-1)}, yw] + 4*G[{0}, yu^(-1)]*
      G[{0, 0, 1/(yu*yv), yv^(-1)}, yw] + 4*G[{0}, yv^(-1)]*
      G[{0, 0, 1/(yu*yv), yv^(-1)}, yw] - 4*G[{0}, yw]*
      G[{0, 0, 1/(yu*yv), yv^(-1)}, yw] - 4*G[{1}, yu^(-1)]*
      G[{0, 0, 1/(yu*yv), yv^(-1)}, yw] - 8*G[{1}, yv^(-1)]*
      G[{0, 0, 1/(yu*yv), yv^(-1)}, yw] + 4*G[{yu}, yv^(-1)]*
      G[{0, 0, 1/(yu*yv), yv^(-1)}, yw] - 4*G[{yv^(-1)}, yw]*
      G[{0, 0, 1/(yu*yv), yv^(-1)}, yw] - 4*G[{0}, yu^(-1)]*
      G[{0, 0, 1/(yu*yv), 1/(yu*yv)}, yw] - 4*G[{0}, yv^(-1)]*
      G[{0, 0, 1/(yu*yv), 1/(yu*yv)}, yw] + 4*G[{0}, yw]*
      G[{0, 0, 1/(yu*yv), 1/(yu*yv)}, yw] + 4*G[{1}, yu^(-1)]*
      G[{0, 0, 1/(yu*yv), 1/(yu*yv)}, yw] + 8*G[{1}, yv^(-1)]*
      G[{0, 0, 1/(yu*yv), 1/(yu*yv)}, yw] - 4*G[{yu}, yv^(-1)]*
      G[{0, 0, 1/(yu*yv), 1/(yu*yv)}, yw] + 4*G[{1/(yu*yv)}, yw]*
      G[{0, 0, 1/(yu*yv), 1/(yu*yv)}, yw] - 2*G[{yv^(-1)}, yw]*
      G[{0, 1, 0, yu^(-1)}, yw] + 2*G[{1/(yu*yv)}, yw]*
      G[{0, 1, 0, yu^(-1)}, yw] - 2*G[{1}, yv^(-1)]*
      G[{0, 1, 0, yu}, yv^(-1)] + 2*G[{yu}, yv^(-1)]*
      G[{0, 1, 0, yu}, yv^(-1)] + 2*G[{yv^(-1)}, yw]*
      G[{0, 1, 0, yu}, yv^(-1)] - 2*G[{1/(yu*yv)}, yw]*
      G[{0, 1, 0, yu}, yv^(-1)] + 2*G[{0}, yu^(-1)]*G[{0, 1, 0, yv^(-1)}, 
       yw] + 2*G[{0}, yv^(-1)]*G[{0, 1, 0, yv^(-1)}, yw] - 
     2*G[{0}, yw]*G[{0, 1, 0, yv^(-1)}, yw] - 2*G[{1}, yu^(-1)]*
      G[{0, 1, 0, yv^(-1)}, yw] - 2*G[{1}, yv^(-1)]*G[{0, 1, 0, yv^(-1)}, 
       yw] - 2*G[{yv^(-1)}, yw]*G[{0, 1, 0, yv^(-1)}, yw] + 
     2*G[{1/(yu*yv)}, yw]*G[{0, 1, 0, yv^(-1)}, yw] - 
     2*G[{0}, yu^(-1)]*G[{0, 1, 0, 1/(yu*yv)}, yw] - 
     2*G[{0}, yv^(-1)]*G[{0, 1, 0, 1/(yu*yv)}, yw] + 
     2*G[{0}, yw]*G[{0, 1, 0, 1/(yu*yv)}, yw] + 2*G[{1}, yu^(-1)]*
      G[{0, 1, 0, 1/(yu*yv)}, yw] + 2*G[{1}, yv^(-1)]*
      G[{0, 1, 0, 1/(yu*yv)}, yw] + 4*G[{yv^(-1)}, yw]*
      G[{0, 1, 0, 1/(yu*yv)}, yw] - 4*G[{1/(yu*yv)}, yw]*
      G[{0, 1, 0, 1/(yu*yv)}, yw] - 6*G[{1}, yv^(-1)]*
      G[{0, 1, 1, 1}, yu^(-1)] + 6*G[{yu}, yv^(-1)]*
      G[{0, 1, 1, 1}, yu^(-1)] + 6*G[{yv^(-1)}, yw]*
      G[{0, 1, 1, 1}, yu^(-1)] - 6*G[{1/(yu*yv)}, yw]*
      G[{0, 1, 1, 1}, yu^(-1)] - 6*G[{0}, yu^(-1)]*G[{0, 1, 1, 1}, yv^(-1)] - 
     6*G[{0}, yv^(-1)]*G[{0, 1, 1, 1}, yv^(-1)] + 
     6*G[{0}, yw]*G[{0, 1, 1, 1}, yv^(-1)] + 6*G[{1}, yu^(-1)]*
      G[{0, 1, 1, 1}, yv^(-1)] - 6*G[{1}, yv^(-1)]*G[{0, 1, 1, 1}, yv^(-1)] + 
     6*G[{yu}, yv^(-1)]*G[{0, 1, 1, 1}, yv^(-1)] + 
     6*G[{yv^(-1)}, yw]*G[{0, 1, 1, 1}, yv^(-1)] - 6*G[{1/(yu*yv)}, yw]*
      G[{0, 1, 1, 1}, yv^(-1)] + 6*G[{yv^(-1)}, yw]*G[{0, 1, 1, yu^(-1)}, 
       yw] - 2*G[{1/(yu*yv)}, yw]*G[{0, 1, 1, yu^(-1)}, yw] + 
     2*G[{0}, yu^(-1)]*G[{0, 1, 1, yu}, yv^(-1)] + 
     2*G[{0}, yv^(-1)]*G[{0, 1, 1, yu}, yv^(-1)] - 
     2*G[{0}, yw]*G[{0, 1, 1, yu}, yv^(-1)] - 2*G[{1}, yu^(-1)]*
      G[{0, 1, 1, yu}, yv^(-1)] + 4*G[{1}, yv^(-1)]*
      G[{0, 1, 1, yu}, yv^(-1)] - 4*G[{yv^(-1)}, yw]*
      G[{0, 1, 1, yu}, yv^(-1)] - 6*G[{0}, yu^(-1)]*G[{0, 1, 1, yv^(-1)}, 
       yw] - 6*G[{0}, yv^(-1)]*G[{0, 1, 1, yv^(-1)}, yw] + 
     6*G[{0}, yw]*G[{0, 1, 1, yv^(-1)}, yw] + 6*G[{1}, yu^(-1)]*
      G[{0, 1, 1, yv^(-1)}, yw] + 6*G[{1}, yv^(-1)]*G[{0, 1, 1, yv^(-1)}, 
       yw] + 6*G[{yv^(-1)}, yw]*G[{0, 1, 1, yv^(-1)}, yw] - 
     2*G[{1/(yu*yv)}, yw]*G[{0, 1, 1, yv^(-1)}, yw] + 
     2*G[{0}, yu^(-1)]*G[{0, 1, 1, 1/(yu*yv)}, yw] + 
     2*G[{0}, yv^(-1)]*G[{0, 1, 1, 1/(yu*yv)}, yw] - 
     2*G[{0}, yw]*G[{0, 1, 1, 1/(yu*yv)}, yw] - 2*G[{1}, yu^(-1)]*
      G[{0, 1, 1, 1/(yu*yv)}, yw] - 2*G[{1}, yv^(-1)]*
      G[{0, 1, 1, 1/(yu*yv)}, yw] + 8*G[{yv^(-1)}, yw]*
      G[{0, 1, yu^(-1), 1}, yw] - 4*G[{1/(yu*yv)}, yw]*
      G[{0, 1, yu^(-1), 1}, yw] - 8*G[{yv^(-1)}, yw]*
      G[{0, 1, yu^(-1), yu^(-1)}, yw] + 4*G[{0}, yu^(-1)]*
      G[{0, 1, yu^(-1), yv^(-1)}, yw] + 4*G[{0}, yv^(-1)]*
      G[{0, 1, yu^(-1), yv^(-1)}, yw] - 4*G[{0}, yw]*
      G[{0, 1, yu^(-1), yv^(-1)}, yw] - 4*G[{1}, yu^(-1)]*
      G[{0, 1, yu^(-1), yv^(-1)}, yw] - 8*G[{1}, yv^(-1)]*
      G[{0, 1, yu^(-1), yv^(-1)}, yw] + 4*G[{yu}, yv^(-1)]*
      G[{0, 1, yu^(-1), yv^(-1)}, yw] - 4*G[{yv^(-1)}, yw]*
      G[{0, 1, yu^(-1), yv^(-1)}, yw] - 4*G[{1/(yu*yv)}, yw]*
      G[{0, 1, yu^(-1), yv^(-1)}, yw] + 4*G[{1/(yu*yv)}, yw]*
      G[{0, 1, yu^(-1), 1/(yu*yv)}, yw] + 4*G[{1}, yv^(-1)]*
      G[{0, 1, yu, 1}, yv^(-1)] - 4*G[{yv^(-1)}, yw]*
      G[{0, 1, yu, 1}, yv^(-1)] + 4*G[{0}, yu^(-1)]*
      G[{0, 1, yu, yu}, yv^(-1)] + 4*G[{0}, yv^(-1)]*
      G[{0, 1, yu, yu}, yv^(-1)] - 4*G[{0}, yw]*G[{0, 1, yu, yu}, yv^(-1)] - 
     4*G[{1}, yu^(-1)]*G[{0, 1, yu, yu}, yv^(-1)] - 
     4*G[{1}, yv^(-1)]*G[{0, 1, yu, yu}, yv^(-1)] - 
     4*G[{yu}, yv^(-1)]*G[{0, 1, yu, yu}, yv^(-1)] + 
     4*G[{yv^(-1)}, yw]*G[{0, 1, yu, yu}, yv^(-1)] + 
     4*G[{1/(yu*yv)}, yw]*G[{0, 1, yu, yu}, yv^(-1)] - 
     4*G[{0}, yu^(-1)]*G[{0, 1, yv^(-1), 1}, yw] - 
     4*G[{0}, yv^(-1)]*G[{0, 1, yv^(-1), 1}, yw] + 
     4*G[{0}, yw]*G[{0, 1, yv^(-1), 1}, yw] + 4*G[{1}, yu^(-1)]*
      G[{0, 1, yv^(-1), 1}, yw] + 4*G[{1}, yv^(-1)]*G[{0, 1, yv^(-1), 1}, 
       yw] + 8*G[{yv^(-1)}, yw]*G[{0, 1, yv^(-1), 1}, yw] - 
     4*G[{1/(yu*yv)}, yw]*G[{0, 1, yv^(-1), 1}, yw] + 
     4*G[{0}, yu^(-1)]*G[{0, 1, yv^(-1), yu^(-1)}, yw] + 
     4*G[{0}, yv^(-1)]*G[{0, 1, yv^(-1), yu^(-1)}, yw] - 
     4*G[{0}, yw]*G[{0, 1, yv^(-1), yu^(-1)}, yw] - 
     4*G[{1}, yu^(-1)]*G[{0, 1, yv^(-1), yu^(-1)}, yw] - 
     8*G[{1}, yv^(-1)]*G[{0, 1, yv^(-1), yu^(-1)}, yw] + 
     4*G[{yu}, yv^(-1)]*G[{0, 1, yv^(-1), yu^(-1)}, yw] - 
     4*G[{yv^(-1)}, yw]*G[{0, 1, yv^(-1), yu^(-1)}, yw] - 
     4*G[{1/(yu*yv)}, yw]*G[{0, 1, yv^(-1), yu^(-1)}, yw] + 
     8*G[{0}, yu^(-1)]*G[{0, 1, yv^(-1), yv^(-1)}, yw] + 
     8*G[{0}, yv^(-1)]*G[{0, 1, yv^(-1), yv^(-1)}, yw] - 
     8*G[{0}, yw]*G[{0, 1, yv^(-1), yv^(-1)}, yw] - 
     8*G[{1}, yu^(-1)]*G[{0, 1, yv^(-1), yv^(-1)}, yw] - 
     8*G[{1}, yv^(-1)]*G[{0, 1, yv^(-1), yv^(-1)}, yw] - 
     8*G[{yv^(-1)}, yw]*G[{0, 1, yv^(-1), yv^(-1)}, yw] - 
     4*G[{0}, yu^(-1)]*G[{0, 1, yv^(-1), 1/(yu*yv)}, yw] - 
     4*G[{0}, yv^(-1)]*G[{0, 1, yv^(-1), 1/(yu*yv)}, yw] + 
     4*G[{0}, yw]*G[{0, 1, yv^(-1), 1/(yu*yv)}, yw] + 
     4*G[{1}, yu^(-1)]*G[{0, 1, yv^(-1), 1/(yu*yv)}, yw] + 
     4*G[{1}, yv^(-1)]*G[{0, 1, yv^(-1), 1/(yu*yv)}, yw] + 
     4*G[{1/(yu*yv)}, yw]*G[{0, 1, yv^(-1), 1/(yu*yv)}, yw] - 
     4*G[{yv^(-1)}, yw]*G[{0, 1, 1/(yu*yv), 1}, yw] + 
     4*G[{1/(yu*yv)}, yw]*G[{0, 1, 1/(yu*yv), 1}, yw] + 
     6*G[{yv^(-1)}, yw]*G[{0, 1, 1/(yu*yv), yu^(-1)}, yw] - 
     2*G[{1/(yu*yv)}, yw]*G[{0, 1, 1/(yu*yv), yu^(-1)}, yw] - 
     6*G[{0}, yu^(-1)]*G[{0, 1, 1/(yu*yv), yv^(-1)}, yw] - 
     6*G[{0}, yv^(-1)]*G[{0, 1, 1/(yu*yv), yv^(-1)}, yw] + 
     6*G[{0}, yw]*G[{0, 1, 1/(yu*yv), yv^(-1)}, yw] + 
     6*G[{1}, yu^(-1)]*G[{0, 1, 1/(yu*yv), yv^(-1)}, yw] + 
     6*G[{1}, yv^(-1)]*G[{0, 1, 1/(yu*yv), yv^(-1)}, yw] + 
     6*G[{yv^(-1)}, yw]*G[{0, 1, 1/(yu*yv), yv^(-1)}, yw] - 
     2*G[{1/(yu*yv)}, yw]*G[{0, 1, 1/(yu*yv), yv^(-1)}, yw] + 
     2*G[{0}, yu^(-1)]*G[{0, 1, 1/(yu*yv), 1/(yu*yv)}, yw] + 
     2*G[{0}, yv^(-1)]*G[{0, 1, 1/(yu*yv), 1/(yu*yv)}, yw] - 
     2*G[{0}, yw]*G[{0, 1, 1/(yu*yv), 1/(yu*yv)}, yw] - 
     2*G[{1}, yu^(-1)]*G[{0, 1, 1/(yu*yv), 1/(yu*yv)}, yw] - 
     6*G[{1}, yv^(-1)]*G[{0, 1, 1/(yu*yv), 1/(yu*yv)}, yw] + 
     4*G[{yu}, yv^(-1)]*G[{0, 1, 1/(yu*yv), 1/(yu*yv)}, yw] - 
     2*G[{0}, yu^(-1)]*G[{0, yu^(-1), 0, yv^(-1)}, yw] - 
     2*G[{0}, yv^(-1)]*G[{0, yu^(-1), 0, yv^(-1)}, yw] + 
     2*G[{0}, yw]*G[{0, yu^(-1), 0, yv^(-1)}, yw] + 
     2*G[{1}, yu^(-1)]*G[{0, yu^(-1), 0, yv^(-1)}, yw] + 
     2*G[{1}, yv^(-1)]*G[{0, yu^(-1), 0, yv^(-1)}, yw] + 
     2*G[{0}, yu^(-1)]*G[{0, yu^(-1), 0, 1/(yu*yv)}, yw] + 
     2*G[{0}, yv^(-1)]*G[{0, yu^(-1), 0, 1/(yu*yv)}, yw] - 
     2*G[{0}, yw]*G[{0, yu^(-1), 0, 1/(yu*yv)}, yw] - 
     2*G[{1}, yu^(-1)]*G[{0, yu^(-1), 0, 1/(yu*yv)}, yw] - 
     2*G[{1}, yv^(-1)]*G[{0, yu^(-1), 0, 1/(yu*yv)}, yw] - 
     2*G[{yv^(-1)}, yw]*G[{0, yu^(-1), 0, 1/(yu*yv)}, yw] + 
     2*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1), 0, 1/(yu*yv)}, yw] - 
     6*G[{yv^(-1)}, yw]*G[{0, yu^(-1), 1, yu^(-1)}, yw] + 
     2*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1), 1, yu^(-1)}, yw] + 
     6*G[{0}, yu^(-1)]*G[{0, yu^(-1), 1, yv^(-1)}, yw] + 
     6*G[{0}, yv^(-1)]*G[{0, yu^(-1), 1, yv^(-1)}, yw] - 
     6*G[{0}, yw]*G[{0, yu^(-1), 1, yv^(-1)}, yw] - 
     6*G[{1}, yu^(-1)]*G[{0, yu^(-1), 1, yv^(-1)}, yw] - 
     6*G[{1}, yv^(-1)]*G[{0, yu^(-1), 1, yv^(-1)}, yw] - 
     6*G[{yv^(-1)}, yw]*G[{0, yu^(-1), 1, yv^(-1)}, yw] + 
     2*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1), 1, yv^(-1)}, yw] - 
     2*G[{0}, yu^(-1)]*G[{0, yu^(-1), 1, 1/(yu*yv)}, yw] - 
     2*G[{0}, yv^(-1)]*G[{0, yu^(-1), 1, 1/(yu*yv)}, yw] + 
     2*G[{0}, yw]*G[{0, yu^(-1), 1, 1/(yu*yv)}, yw] + 
     2*G[{1}, yu^(-1)]*G[{0, yu^(-1), 1, 1/(yu*yv)}, yw] + 
     2*G[{1}, yv^(-1)]*G[{0, yu^(-1), 1, 1/(yu*yv)}, yw] - 
     8*G[{yv^(-1)}, yw]*G[{0, yu^(-1), yu^(-1), 1}, yw] + 
     4*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1), yu^(-1), 1}, yw] + 
     8*G[{yv^(-1)}, yw]*G[{0, yu^(-1), yu^(-1), yu^(-1)}, yw] - 
     4*G[{0}, yu^(-1)]*G[{0, yu^(-1), yu^(-1), yv^(-1)}, yw] - 
     4*G[{0}, yv^(-1)]*G[{0, yu^(-1), yu^(-1), yv^(-1)}, yw] + 
     4*G[{0}, yw]*G[{0, yu^(-1), yu^(-1), yv^(-1)}, yw] + 
     4*G[{1}, yu^(-1)]*G[{0, yu^(-1), yu^(-1), yv^(-1)}, yw] + 
     8*G[{1}, yv^(-1)]*G[{0, yu^(-1), yu^(-1), yv^(-1)}, yw] - 
     4*G[{yu}, yv^(-1)]*G[{0, yu^(-1), yu^(-1), yv^(-1)}, yw] + 
     4*G[{yv^(-1)}, yw]*G[{0, yu^(-1), yu^(-1), yv^(-1)}, yw] + 
     4*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1), yu^(-1), yv^(-1)}, yw] - 
     4*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1), yu^(-1), 1/(yu*yv)}, yw] + 
     4*G[{0}, yu^(-1)]*G[{0, yu^(-1), yv^(-1), 1}, yw] + 
     4*G[{0}, yv^(-1)]*G[{0, yu^(-1), yv^(-1), 1}, yw] - 
     4*G[{0}, yw]*G[{0, yu^(-1), yv^(-1), 1}, yw] - 
     4*G[{1}, yu^(-1)]*G[{0, yu^(-1), yv^(-1), 1}, yw] - 
     4*G[{1}, yv^(-1)]*G[{0, yu^(-1), yv^(-1), 1}, yw] - 
     8*G[{yv^(-1)}, yw]*G[{0, yu^(-1), yv^(-1), 1}, yw] + 
     4*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1), yv^(-1), 1}, yw] - 
     4*G[{0}, yu^(-1)]*G[{0, yu^(-1), yv^(-1), yu^(-1)}, yw] - 
     4*G[{0}, yv^(-1)]*G[{0, yu^(-1), yv^(-1), yu^(-1)}, yw] + 
     4*G[{0}, yw]*G[{0, yu^(-1), yv^(-1), yu^(-1)}, yw] + 
     4*G[{1}, yu^(-1)]*G[{0, yu^(-1), yv^(-1), yu^(-1)}, yw] + 
     8*G[{1}, yv^(-1)]*G[{0, yu^(-1), yv^(-1), yu^(-1)}, yw] - 
     4*G[{yu}, yv^(-1)]*G[{0, yu^(-1), yv^(-1), yu^(-1)}, yw] + 
     4*G[{yv^(-1)}, yw]*G[{0, yu^(-1), yv^(-1), yu^(-1)}, yw] + 
     4*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1), yv^(-1), yu^(-1)}, yw] - 
     4*G[{0}, yu^(-1)]*G[{0, yu^(-1), yv^(-1), yv^(-1)}, yw] - 
     4*G[{0}, yv^(-1)]*G[{0, yu^(-1), yv^(-1), yv^(-1)}, yw] + 
     4*G[{0}, yw]*G[{0, yu^(-1), yv^(-1), yv^(-1)}, yw] + 
     4*G[{1}, yu^(-1)]*G[{0, yu^(-1), yv^(-1), yv^(-1)}, yw] + 
     8*G[{1}, yv^(-1)]*G[{0, yu^(-1), yv^(-1), yv^(-1)}, yw] - 
     4*G[{yu}, yv^(-1)]*G[{0, yu^(-1), yv^(-1), yv^(-1)}, yw] + 
     4*G[{yv^(-1)}, yw]*G[{0, yu^(-1), yv^(-1), yv^(-1)}, yw] + 
     4*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1), yv^(-1), yv^(-1)}, yw] - 
     4*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1), yv^(-1), 1/(yu*yv)}, yw] - 
     2*G[{yv^(-1)}, yw]*G[{0, yu^(-1), 1/(yu*yv), yu^(-1)}, yw] - 
     2*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1), 1/(yu*yv), yu^(-1)}, yw] + 
     2*G[{0}, yu^(-1)]*G[{0, yu^(-1), 1/(yu*yv), yv^(-1)}, yw] + 
     2*G[{0}, yv^(-1)]*G[{0, yu^(-1), 1/(yu*yv), yv^(-1)}, yw] - 
     2*G[{0}, yw]*G[{0, yu^(-1), 1/(yu*yv), yv^(-1)}, yw] - 
     2*G[{1}, yu^(-1)]*G[{0, yu^(-1), 1/(yu*yv), yv^(-1)}, yw] - 
     2*G[{1}, yv^(-1)]*G[{0, yu^(-1), 1/(yu*yv), yv^(-1)}, yw] - 
     2*G[{yv^(-1)}, yw]*G[{0, yu^(-1), 1/(yu*yv), yv^(-1)}, yw] - 
     2*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1), 1/(yu*yv), yv^(-1)}, yw] + 
     2*G[{0}, yu^(-1)]*G[{0, yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] + 
     2*G[{0}, yv^(-1)]*G[{0, yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] - 
     2*G[{0}, yw]*G[{0, yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] - 
     2*G[{1}, yu^(-1)]*G[{0, yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] - 
     2*G[{1}, yv^(-1)]*G[{0, yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] + 
     2*G[{0}, yu^(-1)]*G[{0, yu, 1, 1}, yv^(-1)] + 
     2*G[{0}, yv^(-1)]*G[{0, yu, 1, 1}, yv^(-1)] - 
     2*G[{0}, yw]*G[{0, yu, 1, 1}, yv^(-1)] - 2*G[{1}, yu^(-1)]*
      G[{0, yu, 1, 1}, yv^(-1)] + 2*G[{1}, yv^(-1)]*
      G[{0, yu, 1, 1}, yv^(-1)] - 2*G[{yu}, yv^(-1)]*
      G[{0, yu, 1, 1}, yv^(-1)] - 2*G[{yv^(-1)}, yw]*
      G[{0, yu, 1, 1}, yv^(-1)] + 2*G[{1/(yu*yv)}, yw]*
      G[{0, yu, 1, 1}, yv^(-1)] + 2*G[{0}, yu^(-1)]*
      G[{0, yu, 1, yu}, yv^(-1)] + 2*G[{0}, yv^(-1)]*
      G[{0, yu, 1, yu}, yv^(-1)] - 2*G[{0}, yw]*G[{0, yu, 1, yu}, yv^(-1)] - 
     2*G[{1}, yu^(-1)]*G[{0, yu, 1, yu}, yv^(-1)] - 
     4*G[{1}, yv^(-1)]*G[{0, yu, 1, yu}, yv^(-1)] + 
     4*G[{yv^(-1)}, yw]*G[{0, yu, 1, yu}, yv^(-1)] + 
     4*G[{0}, yu^(-1)]*G[{0, yu, yu, 1}, yv^(-1)] + 
     4*G[{0}, yv^(-1)]*G[{0, yu, yu, 1}, yv^(-1)] - 
     4*G[{0}, yw]*G[{0, yu, yu, 1}, yv^(-1)] - 4*G[{1}, yu^(-1)]*
      G[{0, yu, yu, 1}, yv^(-1)] - 4*G[{1}, yv^(-1)]*
      G[{0, yu, yu, 1}, yv^(-1)] + 4*G[{yv^(-1)}, yw]*
      G[{0, yu, yu, 1}, yv^(-1)] - 8*G[{0}, yu^(-1)]*
      G[{0, yu, yu, yu}, yv^(-1)] - 8*G[{0}, yv^(-1)]*
      G[{0, yu, yu, yu}, yv^(-1)] + 8*G[{0}, yw]*G[{0, yu, yu, yu}, 
       yv^(-1)] + 8*G[{1}, yu^(-1)]*G[{0, yu, yu, yu}, yv^(-1)] + 
     8*G[{1}, yv^(-1)]*G[{0, yu, yu, yu}, yv^(-1)] - 
     8*G[{yv^(-1)}, yw]*G[{0, yu, yu, yu}, yv^(-1)] - 
     2*G[{yv^(-1)}, yw]*G[{0, yv^(-1), 0, 1/(yu*yv)}, yw] + 
     2*G[{1/(yu*yv)}, yw]*G[{0, yv^(-1), 0, 1/(yu*yv)}, yw] - 
     6*G[{yv^(-1)}, yw]*G[{0, yv^(-1), 1, yu^(-1)}, yw] + 
     2*G[{1/(yu*yv)}, yw]*G[{0, yv^(-1), 1, yu^(-1)}, yw] + 
     6*G[{0}, yu^(-1)]*G[{0, yv^(-1), 1, yv^(-1)}, yw] + 
     6*G[{0}, yv^(-1)]*G[{0, yv^(-1), 1, yv^(-1)}, yw] - 
     6*G[{0}, yw]*G[{0, yv^(-1), 1, yv^(-1)}, yw] - 
     6*G[{1}, yu^(-1)]*G[{0, yv^(-1), 1, yv^(-1)}, yw] - 
     6*G[{1}, yv^(-1)]*G[{0, yv^(-1), 1, yv^(-1)}, yw] - 
     6*G[{yv^(-1)}, yw]*G[{0, yv^(-1), 1, yv^(-1)}, yw] + 
     2*G[{1/(yu*yv)}, yw]*G[{0, yv^(-1), 1, yv^(-1)}, yw] - 
     2*G[{0}, yu^(-1)]*G[{0, yv^(-1), 1, 1/(yu*yv)}, yw] - 
     2*G[{0}, yv^(-1)]*G[{0, yv^(-1), 1, 1/(yu*yv)}, yw] + 
     2*G[{0}, yw]*G[{0, yv^(-1), 1, 1/(yu*yv)}, yw] + 
     2*G[{1}, yu^(-1)]*G[{0, yv^(-1), 1, 1/(yu*yv)}, yw] + 
     2*G[{1}, yv^(-1)]*G[{0, yv^(-1), 1, 1/(yu*yv)}, yw] + 
     4*G[{0}, yu^(-1)]*G[{0, yv^(-1), yu^(-1), 1}, yw] + 
     4*G[{0}, yv^(-1)]*G[{0, yv^(-1), yu^(-1), 1}, yw] - 
     4*G[{0}, yw]*G[{0, yv^(-1), yu^(-1), 1}, yw] - 
     4*G[{1}, yu^(-1)]*G[{0, yv^(-1), yu^(-1), 1}, yw] - 
     4*G[{1}, yv^(-1)]*G[{0, yv^(-1), yu^(-1), 1}, yw] - 
     8*G[{yv^(-1)}, yw]*G[{0, yv^(-1), yu^(-1), 1}, yw] + 
     4*G[{1/(yu*yv)}, yw]*G[{0, yv^(-1), yu^(-1), 1}, yw] - 
     4*G[{0}, yu^(-1)]*G[{0, yv^(-1), yu^(-1), yu^(-1)}, yw] - 
     4*G[{0}, yv^(-1)]*G[{0, yv^(-1), yu^(-1), yu^(-1)}, yw] + 
     4*G[{0}, yw]*G[{0, yv^(-1), yu^(-1), yu^(-1)}, yw] + 
     4*G[{1}, yu^(-1)]*G[{0, yv^(-1), yu^(-1), yu^(-1)}, yw] + 
     8*G[{1}, yv^(-1)]*G[{0, yv^(-1), yu^(-1), yu^(-1)}, yw] - 
     4*G[{yu}, yv^(-1)]*G[{0, yv^(-1), yu^(-1), yu^(-1)}, yw] + 
     4*G[{yv^(-1)}, yw]*G[{0, yv^(-1), yu^(-1), yu^(-1)}, yw] + 
     4*G[{1/(yu*yv)}, yw]*G[{0, yv^(-1), yu^(-1), yu^(-1)}, yw] - 
     4*G[{0}, yu^(-1)]*G[{0, yv^(-1), yu^(-1), yv^(-1)}, yw] - 
     4*G[{0}, yv^(-1)]*G[{0, yv^(-1), yu^(-1), yv^(-1)}, yw] + 
     4*G[{0}, yw]*G[{0, yv^(-1), yu^(-1), yv^(-1)}, yw] + 
     4*G[{1}, yu^(-1)]*G[{0, yv^(-1), yu^(-1), yv^(-1)}, yw] + 
     8*G[{1}, yv^(-1)]*G[{0, yv^(-1), yu^(-1), yv^(-1)}, yw] - 
     4*G[{yu}, yv^(-1)]*G[{0, yv^(-1), yu^(-1), yv^(-1)}, yw] + 
     4*G[{yv^(-1)}, yw]*G[{0, yv^(-1), yu^(-1), yv^(-1)}, yw] + 
     4*G[{1/(yu*yv)}, yw]*G[{0, yv^(-1), yu^(-1), yv^(-1)}, yw] - 
     4*G[{1/(yu*yv)}, yw]*G[{0, yv^(-1), yu^(-1), 1/(yu*yv)}, yw] + 
     4*G[{0}, yu^(-1)]*G[{0, yv^(-1), yv^(-1), 1}, yw] + 
     4*G[{0}, yv^(-1)]*G[{0, yv^(-1), yv^(-1), 1}, yw] - 
     4*G[{0}, yw]*G[{0, yv^(-1), yv^(-1), 1}, yw] - 
     4*G[{1}, yu^(-1)]*G[{0, yv^(-1), yv^(-1), 1}, yw] - 
     4*G[{1}, yv^(-1)]*G[{0, yv^(-1), yv^(-1), 1}, yw] - 
     8*G[{yv^(-1)}, yw]*G[{0, yv^(-1), yv^(-1), 1}, yw] + 
     4*G[{1/(yu*yv)}, yw]*G[{0, yv^(-1), yv^(-1), 1}, yw] - 
     4*G[{0}, yu^(-1)]*G[{0, yv^(-1), yv^(-1), yu^(-1)}, yw] - 
     4*G[{0}, yv^(-1)]*G[{0, yv^(-1), yv^(-1), yu^(-1)}, yw] + 
     4*G[{0}, yw]*G[{0, yv^(-1), yv^(-1), yu^(-1)}, yw] + 
     4*G[{1}, yu^(-1)]*G[{0, yv^(-1), yv^(-1), yu^(-1)}, yw] + 
     8*G[{1}, yv^(-1)]*G[{0, yv^(-1), yv^(-1), yu^(-1)}, yw] - 
     4*G[{yu}, yv^(-1)]*G[{0, yv^(-1), yv^(-1), yu^(-1)}, yw] + 
     4*G[{yv^(-1)}, yw]*G[{0, yv^(-1), yv^(-1), yu^(-1)}, yw] + 
     4*G[{1/(yu*yv)}, yw]*G[{0, yv^(-1), yv^(-1), yu^(-1)}, yw] - 
     8*G[{0}, yu^(-1)]*G[{0, yv^(-1), yv^(-1), yv^(-1)}, yw] - 
     8*G[{0}, yv^(-1)]*G[{0, yv^(-1), yv^(-1), yv^(-1)}, yw] + 
     8*G[{0}, yw]*G[{0, yv^(-1), yv^(-1), yv^(-1)}, yw] + 
     8*G[{1}, yu^(-1)]*G[{0, yv^(-1), yv^(-1), yv^(-1)}, yw] + 
     8*G[{1}, yv^(-1)]*G[{0, yv^(-1), yv^(-1), yv^(-1)}, yw] + 
     8*G[{yv^(-1)}, yw]*G[{0, yv^(-1), yv^(-1), yv^(-1)}, yw] + 
     4*G[{0}, yu^(-1)]*G[{0, yv^(-1), yv^(-1), 1/(yu*yv)}, yw] + 
     4*G[{0}, yv^(-1)]*G[{0, yv^(-1), yv^(-1), 1/(yu*yv)}, yw] - 
     4*G[{0}, yw]*G[{0, yv^(-1), yv^(-1), 1/(yu*yv)}, yw] - 
     4*G[{1}, yu^(-1)]*G[{0, yv^(-1), yv^(-1), 1/(yu*yv)}, yw] - 
     4*G[{1}, yv^(-1)]*G[{0, yv^(-1), yv^(-1), 1/(yu*yv)}, yw] - 
     4*G[{1/(yu*yv)}, yw]*G[{0, yv^(-1), yv^(-1), 1/(yu*yv)}, yw] - 
     2*G[{yv^(-1)}, yw]*G[{0, yv^(-1), 1/(yu*yv), yu^(-1)}, yw] - 
     2*G[{1/(yu*yv)}, yw]*G[{0, yv^(-1), 1/(yu*yv), yu^(-1)}, yw] + 
     2*G[{0}, yu^(-1)]*G[{0, yv^(-1), 1/(yu*yv), yv^(-1)}, yw] + 
     2*G[{0}, yv^(-1)]*G[{0, yv^(-1), 1/(yu*yv), yv^(-1)}, yw] - 
     2*G[{0}, yw]*G[{0, yv^(-1), 1/(yu*yv), yv^(-1)}, yw] - 
     2*G[{1}, yu^(-1)]*G[{0, yv^(-1), 1/(yu*yv), yv^(-1)}, yw] - 
     2*G[{1}, yv^(-1)]*G[{0, yv^(-1), 1/(yu*yv), yv^(-1)}, yw] - 
     2*G[{yv^(-1)}, yw]*G[{0, yv^(-1), 1/(yu*yv), yv^(-1)}, yw] - 
     2*G[{1/(yu*yv)}, yw]*G[{0, yv^(-1), 1/(yu*yv), yv^(-1)}, yw] + 
     2*G[{0}, yu^(-1)]*G[{0, yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] + 
     2*G[{0}, yv^(-1)]*G[{0, yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] - 
     2*G[{0}, yw]*G[{0, yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] - 
     2*G[{1}, yu^(-1)]*G[{0, yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] - 
     2*G[{1}, yv^(-1)]*G[{0, yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] + 
     6*G[{yv^(-1)}, yw]*G[{0, 1/(yu*yv), 1, yu^(-1)}, yw] - 
     2*G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv), 1, yu^(-1)}, yw] - 
     6*G[{0}, yu^(-1)]*G[{0, 1/(yu*yv), 1, yv^(-1)}, yw] - 
     6*G[{0}, yv^(-1)]*G[{0, 1/(yu*yv), 1, yv^(-1)}, yw] + 
     6*G[{0}, yw]*G[{0, 1/(yu*yv), 1, yv^(-1)}, yw] + 
     6*G[{1}, yu^(-1)]*G[{0, 1/(yu*yv), 1, yv^(-1)}, yw] + 
     6*G[{1}, yv^(-1)]*G[{0, 1/(yu*yv), 1, yv^(-1)}, yw] + 
     6*G[{yv^(-1)}, yw]*G[{0, 1/(yu*yv), 1, yv^(-1)}, yw] - 
     2*G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv), 1, yv^(-1)}, yw] + 
     2*G[{0}, yu^(-1)]*G[{0, 1/(yu*yv), 1, 1/(yu*yv)}, yw] + 
     2*G[{0}, yv^(-1)]*G[{0, 1/(yu*yv), 1, 1/(yu*yv)}, yw] - 
     2*G[{0}, yw]*G[{0, 1/(yu*yv), 1, 1/(yu*yv)}, yw] - 
     2*G[{1}, yu^(-1)]*G[{0, 1/(yu*yv), 1, 1/(yu*yv)}, yw] - 
     2*G[{1}, yv^(-1)]*G[{0, 1/(yu*yv), 1, 1/(yu*yv)}, yw] - 
     4*G[{0}, yu^(-1)]*G[{0, 1/(yu*yv), yu^(-1), 1}, yw] - 
     4*G[{0}, yv^(-1)]*G[{0, 1/(yu*yv), yu^(-1), 1}, yw] + 
     4*G[{0}, yw]*G[{0, 1/(yu*yv), yu^(-1), 1}, yw] + 
     4*G[{1}, yu^(-1)]*G[{0, 1/(yu*yv), yu^(-1), 1}, yw] + 
     4*G[{1}, yv^(-1)]*G[{0, 1/(yu*yv), yu^(-1), 1}, yw] + 
     8*G[{yv^(-1)}, yw]*G[{0, 1/(yu*yv), yu^(-1), 1}, yw] - 
     4*G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv), yu^(-1), 1}, yw] + 
     4*G[{0}, yu^(-1)]*G[{0, 1/(yu*yv), yu^(-1), yu^(-1)}, yw] + 
     4*G[{0}, yv^(-1)]*G[{0, 1/(yu*yv), yu^(-1), yu^(-1)}, yw] - 
     4*G[{0}, yw]*G[{0, 1/(yu*yv), yu^(-1), yu^(-1)}, yw] - 
     4*G[{1}, yu^(-1)]*G[{0, 1/(yu*yv), yu^(-1), yu^(-1)}, yw] - 
     8*G[{1}, yv^(-1)]*G[{0, 1/(yu*yv), yu^(-1), yu^(-1)}, yw] + 
     4*G[{yu}, yv^(-1)]*G[{0, 1/(yu*yv), yu^(-1), yu^(-1)}, yw] - 
     4*G[{yv^(-1)}, yw]*G[{0, 1/(yu*yv), yu^(-1), yu^(-1)}, yw] - 
     4*G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv), yu^(-1), yu^(-1)}, yw] + 
     4*G[{0}, yu^(-1)]*G[{0, 1/(yu*yv), yu^(-1), yv^(-1)}, yw] + 
     4*G[{0}, yv^(-1)]*G[{0, 1/(yu*yv), yu^(-1), yv^(-1)}, yw] - 
     4*G[{0}, yw]*G[{0, 1/(yu*yv), yu^(-1), yv^(-1)}, yw] - 
     4*G[{1}, yu^(-1)]*G[{0, 1/(yu*yv), yu^(-1), yv^(-1)}, yw] - 
     8*G[{1}, yv^(-1)]*G[{0, 1/(yu*yv), yu^(-1), yv^(-1)}, yw] + 
     4*G[{yu}, yv^(-1)]*G[{0, 1/(yu*yv), yu^(-1), yv^(-1)}, yw] - 
     4*G[{yv^(-1)}, yw]*G[{0, 1/(yu*yv), yu^(-1), yv^(-1)}, yw] - 
     4*G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv), yu^(-1), yv^(-1)}, yw] + 
     4*G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv), yu^(-1), 1/(yu*yv)}, yw] - 
     4*G[{0}, yu^(-1)]*G[{0, 1/(yu*yv), yv^(-1), 1}, yw] - 
     4*G[{0}, yv^(-1)]*G[{0, 1/(yu*yv), yv^(-1), 1}, yw] + 
     4*G[{0}, yw]*G[{0, 1/(yu*yv), yv^(-1), 1}, yw] + 
     4*G[{1}, yu^(-1)]*G[{0, 1/(yu*yv), yv^(-1), 1}, yw] + 
     4*G[{1}, yv^(-1)]*G[{0, 1/(yu*yv), yv^(-1), 1}, yw] + 
     8*G[{yv^(-1)}, yw]*G[{0, 1/(yu*yv), yv^(-1), 1}, yw] - 
     4*G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv), yv^(-1), 1}, yw] + 
     4*G[{0}, yu^(-1)]*G[{0, 1/(yu*yv), yv^(-1), yu^(-1)}, yw] + 
     4*G[{0}, yv^(-1)]*G[{0, 1/(yu*yv), yv^(-1), yu^(-1)}, yw] - 
     4*G[{0}, yw]*G[{0, 1/(yu*yv), yv^(-1), yu^(-1)}, yw] - 
     4*G[{1}, yu^(-1)]*G[{0, 1/(yu*yv), yv^(-1), yu^(-1)}, yw] - 
     8*G[{1}, yv^(-1)]*G[{0, 1/(yu*yv), yv^(-1), yu^(-1)}, yw] + 
     4*G[{yu}, yv^(-1)]*G[{0, 1/(yu*yv), yv^(-1), yu^(-1)}, yw] - 
     4*G[{yv^(-1)}, yw]*G[{0, 1/(yu*yv), yv^(-1), yu^(-1)}, yw] - 
     4*G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv), yv^(-1), yu^(-1)}, yw] + 
     4*G[{0}, yu^(-1)]*G[{0, 1/(yu*yv), yv^(-1), yv^(-1)}, yw] + 
     4*G[{0}, yv^(-1)]*G[{0, 1/(yu*yv), yv^(-1), yv^(-1)}, yw] - 
     4*G[{0}, yw]*G[{0, 1/(yu*yv), yv^(-1), yv^(-1)}, yw] - 
     4*G[{1}, yu^(-1)]*G[{0, 1/(yu*yv), yv^(-1), yv^(-1)}, yw] - 
     8*G[{1}, yv^(-1)]*G[{0, 1/(yu*yv), yv^(-1), yv^(-1)}, yw] + 
     4*G[{yu}, yv^(-1)]*G[{0, 1/(yu*yv), yv^(-1), yv^(-1)}, yw] - 
     4*G[{yv^(-1)}, yw]*G[{0, 1/(yu*yv), yv^(-1), yv^(-1)}, yw] - 
     4*G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv), yv^(-1), yv^(-1)}, yw] + 
     4*G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv), yv^(-1), 1/(yu*yv)}, yw] + 
     4*G[{yv^(-1)}, yw]*G[{0, 1/(yu*yv), 1/(yu*yv), 1}, yw] - 
     4*G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv), 1/(yu*yv), 1}, yw] - 
     2*G[{yv^(-1)}, yw]*G[{0, 1/(yu*yv), 1/(yu*yv), yu^(-1)}, yw] + 
     6*G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv), 1/(yu*yv), yu^(-1)}, yw] + 
     2*G[{0}, yu^(-1)]*G[{0, 1/(yu*yv), 1/(yu*yv), yv^(-1)}, yw] + 
     2*G[{0}, yv^(-1)]*G[{0, 1/(yu*yv), 1/(yu*yv), yv^(-1)}, yw] - 
     2*G[{0}, yw]*G[{0, 1/(yu*yv), 1/(yu*yv), yv^(-1)}, yw] - 
     2*G[{1}, yu^(-1)]*G[{0, 1/(yu*yv), 1/(yu*yv), yv^(-1)}, yw] - 
     2*G[{1}, yv^(-1)]*G[{0, 1/(yu*yv), 1/(yu*yv), yv^(-1)}, yw] - 
     2*G[{yv^(-1)}, yw]*G[{0, 1/(yu*yv), 1/(yu*yv), yv^(-1)}, yw] + 
     6*G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv), 1/(yu*yv), yv^(-1)}, yw] - 
     6*G[{0}, yu^(-1)]*G[{0, 1/(yu*yv), 1/(yu*yv), 1/(yu*yv)}, yw] - 
     6*G[{0}, yv^(-1)]*G[{0, 1/(yu*yv), 1/(yu*yv), 1/(yu*yv)}, yw] + 
     6*G[{0}, yw]*G[{0, 1/(yu*yv), 1/(yu*yv), 1/(yu*yv)}, yw] + 
     6*G[{1}, yu^(-1)]*G[{0, 1/(yu*yv), 1/(yu*yv), 1/(yu*yv)}, yw] + 
     10*G[{1}, yv^(-1)]*G[{0, 1/(yu*yv), 1/(yu*yv), 1/(yu*yv)}, yw] - 
     4*G[{yu}, yv^(-1)]*G[{0, 1/(yu*yv), 1/(yu*yv), 1/(yu*yv)}, yw] + 
     4*G[{1}, yv^(-1)]*G[{1, 1, 1, yu}, yv^(-1)] + 
     4*G[{yu}, yv^(-1)]*G[{1, 1, 1, yu}, yv^(-1)] + 
     4*G[{yv^(-1)}, yw]*G[{1, 1, 1, yu}, yv^(-1)] - 
     4*G[{1/(yu*yv)}, yw]*G[{1, 1, 1, yu}, yv^(-1)] - 
     8*G[{yv^(-1)}, yw]*G[{1, 1, yu^(-1), yu^(-1)}, yw] + 
     8*G[{1/(yu*yv)}, yw]*G[{1, 1, yu^(-1), yu^(-1)}, yw] - 
     8*G[{yv^(-1)}, yw]*G[{1, 1, yu^(-1), yv^(-1)}, yw] + 
     4*G[{1/(yu*yv)}, yw]*G[{1, 1, yu^(-1), yv^(-1)}, yw] + 
     4*G[{yv^(-1)}, yw]*G[{1, 1, yu^(-1), 1/(yu*yv)}, yw] - 
     8*G[{1/(yu*yv)}, yw]*G[{1, 1, yu^(-1), 1/(yu*yv)}, yw] + 
     4*G[{0}, yu^(-1)]*G[{1, 1, yu, yu}, yv^(-1)] + 
     4*G[{0}, yv^(-1)]*G[{1, 1, yu, yu}, yv^(-1)] - 
     4*G[{0}, yw]*G[{1, 1, yu, yu}, yv^(-1)] - 4*G[{1}, yu^(-1)]*
      G[{1, 1, yu, yu}, yv^(-1)] + 8*G[{yv^(-1)}, yw]*
      G[{1, 1, yu, yu}, yv^(-1)] - 8*G[{yv^(-1)}, yw]*
      G[{1, 1, yv^(-1), yu^(-1)}, yw] + 4*G[{1/(yu*yv)}, yw]*
      G[{1, 1, yv^(-1), yu^(-1)}, yw] + 8*G[{0}, yu^(-1)]*
      G[{1, 1, yv^(-1), yv^(-1)}, yw] + 8*G[{0}, yv^(-1)]*
      G[{1, 1, yv^(-1), yv^(-1)}, yw] - 8*G[{0}, yw]*
      G[{1, 1, yv^(-1), yv^(-1)}, yw] - 8*G[{1}, yu^(-1)]*
      G[{1, 1, yv^(-1), yv^(-1)}, yw] - 8*G[{1}, yv^(-1)]*
      G[{1, 1, yv^(-1), yv^(-1)}, yw] - 12*G[{yv^(-1)}, yw]*
      G[{1, 1, yv^(-1), yv^(-1)}, yw] + 4*G[{1/(yu*yv)}, yw]*
      G[{1, 1, yv^(-1), yv^(-1)}, yw] - 4*G[{0}, yu^(-1)]*
      G[{1, 1, yv^(-1), 1/(yu*yv)}, yw] - 4*G[{0}, yv^(-1)]*
      G[{1, 1, yv^(-1), 1/(yu*yv)}, yw] + 4*G[{0}, yw]*
      G[{1, 1, yv^(-1), 1/(yu*yv)}, yw] + 4*G[{1}, yu^(-1)]*
      G[{1, 1, yv^(-1), 1/(yu*yv)}, yw] + 4*G[{1}, yv^(-1)]*
      G[{1, 1, yv^(-1), 1/(yu*yv)}, yw] + 8*G[{yv^(-1)}, yw]*
      G[{1, 1, yv^(-1), 1/(yu*yv)}, yw] - 4*G[{1/(yu*yv)}, yw]*
      G[{1, 1, yv^(-1), 1/(yu*yv)}, yw] + 4*G[{yv^(-1)}, yw]*
      G[{1, 1, 1/(yu*yv), yu^(-1)}, yw] - 8*G[{1/(yu*yv)}, yw]*
      G[{1, 1, 1/(yu*yv), yu^(-1)}, yw] - 4*G[{0}, yu^(-1)]*
      G[{1, 1, 1/(yu*yv), yv^(-1)}, yw] - 4*G[{0}, yv^(-1)]*
      G[{1, 1, 1/(yu*yv), yv^(-1)}, yw] + 4*G[{0}, yw]*
      G[{1, 1, 1/(yu*yv), yv^(-1)}, yw] + 4*G[{1}, yu^(-1)]*
      G[{1, 1, 1/(yu*yv), yv^(-1)}, yw] + 4*G[{1}, yv^(-1)]*
      G[{1, 1, 1/(yu*yv), yv^(-1)}, yw] + 8*G[{yv^(-1)}, yw]*
      G[{1, 1, 1/(yu*yv), yv^(-1)}, yw] - 4*G[{1/(yu*yv)}, yw]*
      G[{1, 1, 1/(yu*yv), yv^(-1)}, yw] + 8*G[{0}, yu^(-1)]*
      G[{1, 1, 1/(yu*yv), 1/(yu*yv)}, yw] + 8*G[{0}, yv^(-1)]*
      G[{1, 1, 1/(yu*yv), 1/(yu*yv)}, yw] - 8*G[{0}, yw]*
      G[{1, 1, 1/(yu*yv), 1/(yu*yv)}, yw] - 8*G[{1}, yu^(-1)]*
      G[{1, 1, 1/(yu*yv), 1/(yu*yv)}, yw] - 8*G[{1}, yv^(-1)]*
      G[{1, 1, 1/(yu*yv), 1/(yu*yv)}, yw] + 4*G[{yv^(-1)}, yw]*
      G[{1, 1, 1/(yu*yv), 1/(yu*yv)}, yw] - 4*G[{1/(yu*yv)}, yw]*
      G[{1, 1, 1/(yu*yv), 1/(yu*yv)}, yw] - 4*G[{0}, yu^(-1)]*
      G[{1, yu^(-1), 1, yv^(-1)}, yw] - 4*G[{0}, yv^(-1)]*
      G[{1, yu^(-1), 1, yv^(-1)}, yw] + 4*G[{0}, yw]*
      G[{1, yu^(-1), 1, yv^(-1)}, yw] + 4*G[{1}, yu^(-1)]*
      G[{1, yu^(-1), 1, yv^(-1)}, yw] + 4*G[{1}, yv^(-1)]*
      G[{1, yu^(-1), 1, yv^(-1)}, yw] + 4*G[{0}, yu^(-1)]*
      G[{1, yu^(-1), 1, 1/(yu*yv)}, yw] + 4*G[{0}, yv^(-1)]*
      G[{1, yu^(-1), 1, 1/(yu*yv)}, yw] - 4*G[{0}, yw]*
      G[{1, yu^(-1), 1, 1/(yu*yv)}, yw] - 4*G[{1}, yu^(-1)]*
      G[{1, yu^(-1), 1, 1/(yu*yv)}, yw] - 4*G[{1}, yv^(-1)]*
      G[{1, yu^(-1), 1, 1/(yu*yv)}, yw] + 4*G[{yv^(-1)}, yw]*
      G[{1, yu^(-1), 1, 1/(yu*yv)}, yw] - 4*G[{1/(yu*yv)}, yw]*
      G[{1, yu^(-1), 1, 1/(yu*yv)}, yw] - 8*G[{yv^(-1)}, yw]*
      G[{1, yu^(-1), yu^(-1), yu^(-1)}, yw] + 8*G[{1/(yu*yv)}, yw]*
      G[{1, yu^(-1), yu^(-1), yu^(-1)}, yw] + 4*G[{0}, yu^(-1)]*
      G[{1, yu^(-1), yu^(-1), yv^(-1)}, yw] + 4*G[{0}, yv^(-1)]*
      G[{1, yu^(-1), yu^(-1), yv^(-1)}, yw] - 
     4*G[{0}, yw]*G[{1, yu^(-1), yu^(-1), yv^(-1)}, yw] - 
     4*G[{1}, yu^(-1)]*G[{1, yu^(-1), yu^(-1), yv^(-1)}, yw] - 
     8*G[{1}, yv^(-1)]*G[{1, yu^(-1), yu^(-1), yv^(-1)}, yw] - 
     4*G[{1}, yw]*G[{1, yu^(-1), yu^(-1), yv^(-1)}, yw] + 
     4*G[{yu}, yv^(-1)]*G[{1, yu^(-1), yu^(-1), yv^(-1)}, yw] - 
     4*G[{yv^(-1)}, yw]*G[{1, yu^(-1), yu^(-1), yv^(-1)}, yw] - 
     4*G[{1/(yu*yv)}, yw]*G[{1, yu^(-1), yu^(-1), yv^(-1)}, yw] - 
     4*G[{0}, yu^(-1)]*G[{1, yu^(-1), yu^(-1), 1/(yu*yv)}, yw] - 
     4*G[{0}, yv^(-1)]*G[{1, yu^(-1), yu^(-1), 1/(yu*yv)}, yw] + 
     4*G[{0}, yw]*G[{1, yu^(-1), yu^(-1), 1/(yu*yv)}, yw] + 
     4*G[{1}, yu^(-1)]*G[{1, yu^(-1), yu^(-1), 1/(yu*yv)}, yw] + 
     8*G[{1}, yv^(-1)]*G[{1, yu^(-1), yu^(-1), 1/(yu*yv)}, yw] + 
     4*G[{1}, yw]*G[{1, yu^(-1), yu^(-1), 1/(yu*yv)}, yw] - 
     4*G[{yu}, yv^(-1)]*G[{1, yu^(-1), yu^(-1), 1/(yu*yv)}, yw] - 
     4*G[{yv^(-1)}, yw]*G[{1, yu^(-1), yu^(-1), 1/(yu*yv)}, yw] + 
     4*G[{1/(yu*yv)}, yw]*G[{1, yu^(-1), yu^(-1), 1/(yu*yv)}, yw] + 
     4*G[{0}, yu^(-1)]*G[{1, yu^(-1), yv^(-1), yu^(-1)}, yw] + 
     4*G[{0}, yv^(-1)]*G[{1, yu^(-1), yv^(-1), yu^(-1)}, yw] - 
     4*G[{0}, yw]*G[{1, yu^(-1), yv^(-1), yu^(-1)}, yw] - 
     4*G[{1}, yu^(-1)]*G[{1, yu^(-1), yv^(-1), yu^(-1)}, yw] - 
     8*G[{1}, yv^(-1)]*G[{1, yu^(-1), yv^(-1), yu^(-1)}, yw] - 
     4*G[{1}, yw]*G[{1, yu^(-1), yv^(-1), yu^(-1)}, yw] + 
     4*G[{yu}, yv^(-1)]*G[{1, yu^(-1), yv^(-1), yu^(-1)}, yw] - 
     4*G[{yv^(-1)}, yw]*G[{1, yu^(-1), yv^(-1), yu^(-1)}, yw] - 
     4*G[{1/(yu*yv)}, yw]*G[{1, yu^(-1), yv^(-1), yu^(-1)}, yw] + 
     4*G[{0}, yu^(-1)]*G[{1, yu^(-1), yv^(-1), yv^(-1)}, yw] + 
     4*G[{0}, yv^(-1)]*G[{1, yu^(-1), yv^(-1), yv^(-1)}, yw] - 
     4*G[{0}, yw]*G[{1, yu^(-1), yv^(-1), yv^(-1)}, yw] - 
     4*G[{1}, yu^(-1)]*G[{1, yu^(-1), yv^(-1), yv^(-1)}, yw] - 
     8*G[{1}, yv^(-1)]*G[{1, yu^(-1), yv^(-1), yv^(-1)}, yw] - 
     4*G[{1}, yw]*G[{1, yu^(-1), yv^(-1), yv^(-1)}, yw] + 
     4*G[{yu}, yv^(-1)]*G[{1, yu^(-1), yv^(-1), yv^(-1)}, yw] - 
     4*G[{yv^(-1)}, yw]*G[{1, yu^(-1), yv^(-1), yv^(-1)}, yw] - 
     4*G[{1/(yu*yv)}, yw]*G[{1, yu^(-1), yv^(-1), yv^(-1)}, yw] + 
     4*G[{1/(yu*yv)}, yw]*G[{1, yu^(-1), yv^(-1), 1/(yu*yv)}, yw] - 
     4*G[{0}, yu^(-1)]*G[{1, yu^(-1), 1/(yu*yv), yu^(-1)}, yw] - 
     4*G[{0}, yv^(-1)]*G[{1, yu^(-1), 1/(yu*yv), yu^(-1)}, yw] + 
     4*G[{0}, yw]*G[{1, yu^(-1), 1/(yu*yv), yu^(-1)}, yw] + 
     4*G[{1}, yu^(-1)]*G[{1, yu^(-1), 1/(yu*yv), yu^(-1)}, yw] + 
     8*G[{1}, yv^(-1)]*G[{1, yu^(-1), 1/(yu*yv), yu^(-1)}, yw] + 
     4*G[{1}, yw]*G[{1, yu^(-1), 1/(yu*yv), yu^(-1)}, yw] - 
     4*G[{yu}, yv^(-1)]*G[{1, yu^(-1), 1/(yu*yv), yu^(-1)}, yw] - 
     4*G[{0}, yu^(-1)]*G[{1, yu^(-1), 1/(yu*yv), yv^(-1)}, yw] - 
     4*G[{0}, yv^(-1)]*G[{1, yu^(-1), 1/(yu*yv), yv^(-1)}, yw] + 
     4*G[{0}, yw]*G[{1, yu^(-1), 1/(yu*yv), yv^(-1)}, yw] + 
     4*G[{1}, yu^(-1)]*G[{1, yu^(-1), 1/(yu*yv), yv^(-1)}, yw] + 
     4*G[{1}, yv^(-1)]*G[{1, yu^(-1), 1/(yu*yv), yv^(-1)}, yw] + 
     4*G[{yv^(-1)}, yw]*G[{1, yu^(-1), 1/(yu*yv), yv^(-1)}, yw] - 
     4*G[{1}, yv^(-1)]*G[{1, yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] - 
     4*G[{1}, yw]*G[{1, yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] + 
     4*G[{yu}, yv^(-1)]*G[{1, yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] + 
     8*G[{0}, yu^(-1)]*G[{1, yu, yu, yu}, yv^(-1)] + 
     8*G[{0}, yv^(-1)]*G[{1, yu, yu, yu}, yv^(-1)] - 
     8*G[{0}, yw]*G[{1, yu, yu, yu}, yv^(-1)] - 8*G[{1}, yu^(-1)]*
      G[{1, yu, yu, yu}, yv^(-1)] - 8*G[{1}, yv^(-1)]*
      G[{1, yu, yu, yu}, yv^(-1)] - 8*G[{yu}, yv^(-1)]*
      G[{1, yu, yu, yu}, yv^(-1)] + 8*G[{yv^(-1)}, yw]*
      G[{1, yu, yu, yu}, yv^(-1)] + 8*G[{1/(yu*yv)}, yw]*
      G[{1, yu, yu, yu}, yv^(-1)] + 4*G[{yv^(-1)}, yw]*
      G[{1, yv^(-1), 1, 1/(yu*yv)}, yw] - 4*G[{1/(yu*yv)}, yw]*
      G[{1, yv^(-1), 1, 1/(yu*yv)}, yw] + 4*G[{0}, yu^(-1)]*
      G[{1, yv^(-1), yu^(-1), yu^(-1)}, yw] + 4*G[{0}, yv^(-1)]*
      G[{1, yv^(-1), yu^(-1), yu^(-1)}, yw] - 
     4*G[{0}, yw]*G[{1, yv^(-1), yu^(-1), yu^(-1)}, yw] - 
     4*G[{1}, yu^(-1)]*G[{1, yv^(-1), yu^(-1), yu^(-1)}, yw] - 
     8*G[{1}, yv^(-1)]*G[{1, yv^(-1), yu^(-1), yu^(-1)}, yw] - 
     4*G[{1}, yw]*G[{1, yv^(-1), yu^(-1), yu^(-1)}, yw] + 
     4*G[{yu}, yv^(-1)]*G[{1, yv^(-1), yu^(-1), yu^(-1)}, yw] - 
     4*G[{yv^(-1)}, yw]*G[{1, yv^(-1), yu^(-1), yu^(-1)}, yw] - 
     4*G[{1/(yu*yv)}, yw]*G[{1, yv^(-1), yu^(-1), yu^(-1)}, yw] + 
     4*G[{0}, yu^(-1)]*G[{1, yv^(-1), yu^(-1), yv^(-1)}, yw] + 
     4*G[{0}, yv^(-1)]*G[{1, yv^(-1), yu^(-1), yv^(-1)}, yw] - 
     4*G[{0}, yw]*G[{1, yv^(-1), yu^(-1), yv^(-1)}, yw] - 
     4*G[{1}, yu^(-1)]*G[{1, yv^(-1), yu^(-1), yv^(-1)}, yw] - 
     8*G[{1}, yv^(-1)]*G[{1, yv^(-1), yu^(-1), yv^(-1)}, yw] - 
     4*G[{1}, yw]*G[{1, yv^(-1), yu^(-1), yv^(-1)}, yw] + 
     4*G[{yu}, yv^(-1)]*G[{1, yv^(-1), yu^(-1), yv^(-1)}, yw] - 
     4*G[{yv^(-1)}, yw]*G[{1, yv^(-1), yu^(-1), yv^(-1)}, yw] - 
     4*G[{1/(yu*yv)}, yw]*G[{1, yv^(-1), yu^(-1), yv^(-1)}, yw] + 
     4*G[{1/(yu*yv)}, yw]*G[{1, yv^(-1), yu^(-1), 1/(yu*yv)}, yw] + 
     4*G[{0}, yu^(-1)]*G[{1, yv^(-1), yv^(-1), yu^(-1)}, yw] + 
     4*G[{0}, yv^(-1)]*G[{1, yv^(-1), yv^(-1), yu^(-1)}, yw] - 
     4*G[{0}, yw]*G[{1, yv^(-1), yv^(-1), yu^(-1)}, yw] - 
     4*G[{1}, yu^(-1)]*G[{1, yv^(-1), yv^(-1), yu^(-1)}, yw] - 
     8*G[{1}, yv^(-1)]*G[{1, yv^(-1), yv^(-1), yu^(-1)}, yw] - 
     4*G[{1}, yw]*G[{1, yv^(-1), yv^(-1), yu^(-1)}, yw] + 
     4*G[{yu}, yv^(-1)]*G[{1, yv^(-1), yv^(-1), yu^(-1)}, yw] - 
     4*G[{yv^(-1)}, yw]*G[{1, yv^(-1), yv^(-1), yu^(-1)}, yw] - 
     4*G[{1/(yu*yv)}, yw]*G[{1, yv^(-1), yv^(-1), yu^(-1)}, yw] + 
     8*G[{0}, yu^(-1)]*G[{1, yv^(-1), yv^(-1), yv^(-1)}, yw] + 
     8*G[{0}, yv^(-1)]*G[{1, yv^(-1), yv^(-1), yv^(-1)}, yw] - 
     8*G[{0}, yw]*G[{1, yv^(-1), yv^(-1), yv^(-1)}, yw] - 
     8*G[{1}, yu^(-1)]*G[{1, yv^(-1), yv^(-1), yv^(-1)}, yw] - 
     8*G[{1}, yv^(-1)]*G[{1, yv^(-1), yv^(-1), yv^(-1)}, yw] - 
     16*G[{yv^(-1)}, yw]*G[{1, yv^(-1), yv^(-1), yv^(-1)}, yw] - 
     4*G[{0}, yu^(-1)]*G[{1, yv^(-1), yv^(-1), 1/(yu*yv)}, yw] - 
     4*G[{0}, yv^(-1)]*G[{1, yv^(-1), yv^(-1), 1/(yu*yv)}, yw] + 
     4*G[{0}, yw]*G[{1, yv^(-1), yv^(-1), 1/(yu*yv)}, yw] + 
     4*G[{1}, yu^(-1)]*G[{1, yv^(-1), yv^(-1), 1/(yu*yv)}, yw] + 
     8*G[{1}, yv^(-1)]*G[{1, yv^(-1), yv^(-1), 1/(yu*yv)}, yw] + 
     4*G[{1}, yw]*G[{1, yv^(-1), yv^(-1), 1/(yu*yv)}, yw] - 
     4*G[{yu}, yv^(-1)]*G[{1, yv^(-1), yv^(-1), 1/(yu*yv)}, yw] + 
     8*G[{1/(yu*yv)}, yw]*G[{1, yv^(-1), yv^(-1), 1/(yu*yv)}, yw] + 
     4*G[{yv^(-1)}, yw]*G[{1, yv^(-1), 1/(yu*yv), yu^(-1)}, yw] + 
     4*G[{1}, yv^(-1)]*G[{1, yv^(-1), 1/(yu*yv), yv^(-1)}, yw] + 
     4*G[{1}, yw]*G[{1, yv^(-1), 1/(yu*yv), yv^(-1)}, yw] - 
     4*G[{yu}, yv^(-1)]*G[{1, yv^(-1), 1/(yu*yv), yv^(-1)}, yw] + 
     4*G[{yv^(-1)}, yw]*G[{1, yv^(-1), 1/(yu*yv), yv^(-1)}, yw] + 
     4*G[{1/(yu*yv)}, yw]*G[{1, yv^(-1), 1/(yu*yv), yv^(-1)}, yw] - 
     4*G[{0}, yu^(-1)]*G[{1, yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] - 
     4*G[{0}, yv^(-1)]*G[{1, yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] + 
     4*G[{0}, yw]*G[{1, yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] + 
     4*G[{1}, yu^(-1)]*G[{1, yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] - 
     4*G[{1}, yw]*G[{1, yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] + 
     4*G[{yu}, yv^(-1)]*G[{1, yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] - 
     4*G[{0}, yu^(-1)]*G[{1, 1/(yu*yv), yu^(-1), yu^(-1)}, yw] - 
     4*G[{0}, yv^(-1)]*G[{1, 1/(yu*yv), yu^(-1), yu^(-1)}, yw] + 
     4*G[{0}, yw]*G[{1, 1/(yu*yv), yu^(-1), yu^(-1)}, yw] + 
     4*G[{1}, yu^(-1)]*G[{1, 1/(yu*yv), yu^(-1), yu^(-1)}, yw] + 
     8*G[{1}, yv^(-1)]*G[{1, 1/(yu*yv), yu^(-1), yu^(-1)}, yw] + 
     4*G[{1}, yw]*G[{1, 1/(yu*yv), yu^(-1), yu^(-1)}, yw] - 
     4*G[{yu}, yv^(-1)]*G[{1, 1/(yu*yv), yu^(-1), yu^(-1)}, yw] - 
     4*G[{yv^(-1)}, yw]*G[{1, 1/(yu*yv), yu^(-1), yu^(-1)}, yw] - 
     4*G[{1/(yu*yv)}, yw]*G[{1, 1/(yu*yv), yu^(-1), yu^(-1)}, yw] + 
     4*G[{0}, yu^(-1)]*G[{1, 1/(yu*yv), yu^(-1), 1/(yu*yv)}, yw] + 
     4*G[{0}, yv^(-1)]*G[{1, 1/(yu*yv), yu^(-1), 1/(yu*yv)}, yw] - 
     4*G[{0}, yw]*G[{1, 1/(yu*yv), yu^(-1), 1/(yu*yv)}, yw] - 
     4*G[{1}, yu^(-1)]*G[{1, 1/(yu*yv), yu^(-1), 1/(yu*yv)}, yw] - 
     8*G[{1}, yv^(-1)]*G[{1, 1/(yu*yv), yu^(-1), 1/(yu*yv)}, yw] - 
     4*G[{1}, yw]*G[{1, 1/(yu*yv), yu^(-1), 1/(yu*yv)}, yw] + 
     4*G[{yu}, yv^(-1)]*G[{1, 1/(yu*yv), yu^(-1), 1/(yu*yv)}, yw] + 
     4*G[{yv^(-1)}, yw]*G[{1, 1/(yu*yv), yu^(-1), 1/(yu*yv)}, yw] + 
     4*G[{0}, yu^(-1)]*G[{1, 1/(yu*yv), yv^(-1), yv^(-1)}, yw] + 
     4*G[{0}, yv^(-1)]*G[{1, 1/(yu*yv), yv^(-1), yv^(-1)}, yw] - 
     4*G[{0}, yw]*G[{1, 1/(yu*yv), yv^(-1), yv^(-1)}, yw] - 
     4*G[{1}, yu^(-1)]*G[{1, 1/(yu*yv), yv^(-1), yv^(-1)}, yw] + 
     4*G[{1}, yw]*G[{1, 1/(yu*yv), yv^(-1), yv^(-1)}, yw] - 
     4*G[{yu}, yv^(-1)]*G[{1, 1/(yu*yv), yv^(-1), yv^(-1)}, yw] + 
     4*G[{yv^(-1)}, yw]*G[{1, 1/(yu*yv), yv^(-1), yv^(-1)}, yw] + 
     4*G[{1/(yu*yv)}, yw]*G[{1, 1/(yu*yv), yv^(-1), yv^(-1)}, yw] - 
     4*G[{0}, yu^(-1)]*G[{1, 1/(yu*yv), yv^(-1), 1/(yu*yv)}, yw] - 
     4*G[{0}, yv^(-1)]*G[{1, 1/(yu*yv), yv^(-1), 1/(yu*yv)}, yw] + 
     4*G[{0}, yw]*G[{1, 1/(yu*yv), yv^(-1), 1/(yu*yv)}, yw] + 
     4*G[{1}, yu^(-1)]*G[{1, 1/(yu*yv), yv^(-1), 1/(yu*yv)}, yw] - 
     4*G[{1}, yw]*G[{1, 1/(yu*yv), yv^(-1), 1/(yu*yv)}, yw] + 
     4*G[{yu}, yv^(-1)]*G[{1, 1/(yu*yv), yv^(-1), 1/(yu*yv)}, yw] - 
     4*G[{1/(yu*yv)}, yw]*G[{1, 1/(yu*yv), yv^(-1), 1/(yu*yv)}, yw] + 
     4*G[{0}, yu^(-1)]*G[{1, 1/(yu*yv), 1/(yu*yv), yu^(-1)}, yw] + 
     4*G[{0}, yv^(-1)]*G[{1, 1/(yu*yv), 1/(yu*yv), yu^(-1)}, yw] - 
     4*G[{0}, yw]*G[{1, 1/(yu*yv), 1/(yu*yv), yu^(-1)}, yw] - 
     4*G[{1}, yu^(-1)]*G[{1, 1/(yu*yv), 1/(yu*yv), yu^(-1)}, yw] - 
     8*G[{1}, yv^(-1)]*G[{1, 1/(yu*yv), 1/(yu*yv), yu^(-1)}, yw] - 
     4*G[{1}, yw]*G[{1, 1/(yu*yv), 1/(yu*yv), yu^(-1)}, yw] + 
     4*G[{yu}, yv^(-1)]*G[{1, 1/(yu*yv), 1/(yu*yv), yu^(-1)}, yw] + 
     8*G[{yv^(-1)}, yw]*G[{1, 1/(yu*yv), 1/(yu*yv), yu^(-1)}, yw] - 
     4*G[{1/(yu*yv)}, yw]*G[{1, 1/(yu*yv), 1/(yu*yv), yu^(-1)}, yw] - 
     8*G[{0}, yu^(-1)]*G[{1, 1/(yu*yv), 1/(yu*yv), yv^(-1)}, yw] - 
     8*G[{0}, yv^(-1)]*G[{1, 1/(yu*yv), 1/(yu*yv), yv^(-1)}, yw] + 
     8*G[{0}, yw]*G[{1, 1/(yu*yv), 1/(yu*yv), yv^(-1)}, yw] + 
     8*G[{1}, yu^(-1)]*G[{1, 1/(yu*yv), 1/(yu*yv), yv^(-1)}, yw] + 
     4*G[{1}, yv^(-1)]*G[{1, 1/(yu*yv), 1/(yu*yv), yv^(-1)}, yw] - 
     4*G[{1}, yw]*G[{1, 1/(yu*yv), 1/(yu*yv), yv^(-1)}, yw] + 
     4*G[{yu}, yv^(-1)]*G[{1, 1/(yu*yv), 1/(yu*yv), yv^(-1)}, yw] + 
     4*G[{yv^(-1)}, yw]*G[{1, 1/(yu*yv), 1/(yu*yv), yv^(-1)}, yw] - 
     8*G[{1/(yu*yv)}, yw]*G[{1, 1/(yu*yv), 1/(yu*yv), yv^(-1)}, yw] + 
     8*G[{0}, yu^(-1)]*G[{1, 1/(yu*yv), 1/(yu*yv), 1/(yu*yv)}, yw] + 
     8*G[{0}, yv^(-1)]*G[{1, 1/(yu*yv), 1/(yu*yv), 1/(yu*yv)}, yw] - 
     8*G[{0}, yw]*G[{1, 1/(yu*yv), 1/(yu*yv), 1/(yu*yv)}, yw] - 
     8*G[{1}, yu^(-1)]*G[{1, 1/(yu*yv), 1/(yu*yv), 1/(yu*yv)}, yw] - 
     8*G[{1}, yv^(-1)]*G[{1, 1/(yu*yv), 1/(yu*yv), 1/(yu*yv)}, yw] + 
     8*G[{yv^(-1)}, yw]*G[{yu^(-1), yu^(-1), yu^(-1), 1/(yu*yv)}, yw] + 
     8*G[{1/(yu*yv)}, yw]*G[{yu^(-1), yu^(-1), yu^(-1), 1/(yu*yv)}, yw] + 
     4*G[{0}, yu^(-1)]*G[{yu^(-1), yu^(-1), 1/(yu*yv), yv^(-1)}, yw] + 
     4*G[{0}, yv^(-1)]*G[{yu^(-1), yu^(-1), 1/(yu*yv), yv^(-1)}, yw] - 
     4*G[{0}, yw]*G[{yu^(-1), yu^(-1), 1/(yu*yv), yv^(-1)}, yw] - 
     4*G[{1}, yu^(-1)]*G[{yu^(-1), yu^(-1), 1/(yu*yv), yv^(-1)}, yw] - 
     8*G[{1}, yv^(-1)]*G[{yu^(-1), yu^(-1), 1/(yu*yv), yv^(-1)}, yw] - 
     4*G[{1}, yw]*G[{yu^(-1), yu^(-1), 1/(yu*yv), yv^(-1)}, yw] + 
     8*G[{yu^(-1)}, yw]*G[{yu^(-1), yu^(-1), 1/(yu*yv), yv^(-1)}, yw] + 
     4*G[{yu}, yv^(-1)]*G[{yu^(-1), yu^(-1), 1/(yu*yv), yv^(-1)}, yw] - 
     4*G[{yv^(-1)}, yw]*G[{yu^(-1), yu^(-1), 1/(yu*yv), yv^(-1)}, yw] - 
     4*G[{1/(yu*yv)}, yw]*G[{yu^(-1), yu^(-1), 1/(yu*yv), yv^(-1)}, yw] + 
     4*G[{0}, yu^(-1)]*G[{yu^(-1), yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] + 
     4*G[{0}, yv^(-1)]*G[{yu^(-1), yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] - 
     4*G[{0}, yw]*G[{yu^(-1), yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] - 
     4*G[{1}, yu^(-1)]*G[{yu^(-1), yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] - 
     8*G[{1}, yv^(-1)]*G[{yu^(-1), yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] - 
     4*G[{1}, yw]*G[{yu^(-1), yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] + 
     8*G[{yu^(-1)}, yw]*G[{yu^(-1), yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] + 
     4*G[{yu}, yv^(-1)]*G[{yu^(-1), yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] + 
     4*G[{yv^(-1)}, yw]*G[{yu^(-1), yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] + 
     4*G[{1/(yu*yv)}, yw]*G[{yu^(-1), yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] - 
     4*G[{0}, yu^(-1)]*G[{yu^(-1), 1/(yu*yv), yv^(-1), yv^(-1)}, yw] - 
     4*G[{0}, yv^(-1)]*G[{yu^(-1), 1/(yu*yv), yv^(-1), yv^(-1)}, yw] + 
     4*G[{0}, yw]*G[{yu^(-1), 1/(yu*yv), yv^(-1), yv^(-1)}, yw] + 
     4*G[{1}, yu^(-1)]*G[{yu^(-1), 1/(yu*yv), yv^(-1), yv^(-1)}, yw] + 
     8*G[{1}, yv^(-1)]*G[{yu^(-1), 1/(yu*yv), yv^(-1), yv^(-1)}, yw] + 
     4*G[{1}, yw]*G[{yu^(-1), 1/(yu*yv), yv^(-1), yv^(-1)}, yw] - 
     8*G[{yu^(-1)}, yw]*G[{yu^(-1), 1/(yu*yv), yv^(-1), yv^(-1)}, yw] - 
     4*G[{yu}, yv^(-1)]*G[{yu^(-1), 1/(yu*yv), yv^(-1), yv^(-1)}, yw] + 
     4*G[{yv^(-1)}, yw]*G[{yu^(-1), 1/(yu*yv), yv^(-1), yv^(-1)}, yw] + 
     4*G[{1/(yu*yv)}, yw]*G[{yu^(-1), 1/(yu*yv), yv^(-1), yv^(-1)}, yw] - 
     4*G[{1/(yu*yv)}, yw]*G[{yu^(-1), 1/(yu*yv), yv^(-1), 1/(yu*yv)}, yw] - 
     4*G[{1/(yu*yv)}, yw]*G[{yu^(-1), 1/(yu*yv), 1/(yu*yv), yv^(-1)}, yw] + 
     4*G[{0}, yu^(-1)]*G[{yu^(-1), 1/(yu*yv), 1/(yu*yv), 1/(yu*yv)}, yw] + 
     4*G[{0}, yv^(-1)]*G[{yu^(-1), 1/(yu*yv), 1/(yu*yv), 1/(yu*yv)}, yw] - 
     4*G[{0}, yw]*G[{yu^(-1), 1/(yu*yv), 1/(yu*yv), 1/(yu*yv)}, yw] - 
     4*G[{1}, yu^(-1)]*G[{yu^(-1), 1/(yu*yv), 1/(yu*yv), 1/(yu*yv)}, yw] - 
     8*G[{1}, yv^(-1)]*G[{yu^(-1), 1/(yu*yv), 1/(yu*yv), 1/(yu*yv)}, yw] - 
     4*G[{1}, yw]*G[{yu^(-1), 1/(yu*yv), 1/(yu*yv), 1/(yu*yv)}, yw] + 
     8*G[{yu^(-1)}, yw]*G[{yu^(-1), 1/(yu*yv), 1/(yu*yv), 1/(yu*yv)}, yw] + 
     4*G[{yu}, yv^(-1)]*G[{yu^(-1), 1/(yu*yv), 1/(yu*yv), 1/(yu*yv)}, yw] - 
     8*G[{0}, yu^(-1)]*G[{yv^(-1), yv^(-1), yv^(-1), 1/(yu*yv)}, yw] - 
     8*G[{0}, yv^(-1)]*G[{yv^(-1), yv^(-1), yv^(-1), 1/(yu*yv)}, yw] + 
     8*G[{0}, yw]*G[{yv^(-1), yv^(-1), yv^(-1), 1/(yu*yv)}, yw] + 
     8*G[{1}, yu^(-1)]*G[{yv^(-1), yv^(-1), yv^(-1), 1/(yu*yv)}, yw] + 
     8*G[{1}, yv^(-1)]*G[{yv^(-1), yv^(-1), yv^(-1), 1/(yu*yv)}, yw] - 
     8*G[{yu^(-1)}, yw]*G[{yv^(-1), yv^(-1), yv^(-1), 1/(yu*yv)}, yw] - 
     8*G[{yv^(-1)}, yw]*G[{yv^(-1), yv^(-1), yv^(-1), 1/(yu*yv)}, yw] - 
     4*G[{0}, yu^(-1)]*G[{yv^(-1), yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] - 
     4*G[{0}, yv^(-1)]*G[{yv^(-1), yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] + 
     4*G[{0}, yw]*G[{yv^(-1), yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] + 
     4*G[{1}, yu^(-1)]*G[{yv^(-1), yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] - 
     4*G[{1}, yw]*G[{yv^(-1), yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] + 
     4*G[{yu}, yv^(-1)]*G[{yv^(-1), yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] - 
     4*G[{yv^(-1)}, yw]*G[{yv^(-1), yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] - 
     4*G[{1}, yv^(-1)]*G[{yv^(-1), 1/(yu*yv), 1/(yu*yv), 1/(yu*yv)}, yw] - 
     4*G[{1}, yw]*G[{yv^(-1), 1/(yu*yv), 1/(yu*yv), 1/(yu*yv)}, yw] + 
     4*G[{yu^(-1)}, yw]*G[{yv^(-1), 1/(yu*yv), 1/(yu*yv), 1/(yu*yv)}, yw] + 
     4*G[{yu}, yv^(-1)]*G[{yv^(-1), 1/(yu*yv), 1/(yu*yv), 1/(yu*yv)}, yw] - 
     12*G[{0, 0, 0, 1, 1}, yu^(-1)] + 12*G[{0, 0, 0, 1, yv^(-1)}, yw] - 
     12*G[{0, 0, 0, 1, 1/(yu*yv)}, yw] - 12*G[{0, 0, 0, yu^(-1), yv^(-1)}, 
       yw] + 12*G[{0, 0, 0, yu^(-1), 1/(yu*yv)}, yw] + 
     12*G[{0, 0, 0, yv^(-1), 1}, yw] - 12*G[{0, 0, 0, yv^(-1), yu^(-1)}, 
       yw] - 24*G[{0, 0, 0, yv^(-1), yv^(-1)}, yw] + 
     24*G[{0, 0, 0, yv^(-1), 1/(yu*yv)}, yw] - 
     12*G[{0, 0, 0, 1/(yu*yv), 1}, yw] + 12*G[{0, 0, 0, 1/(yu*yv), yu^(-1)}, 
       yw] + 24*G[{0, 0, 0, 1/(yu*yv), yv^(-1)}, yw] - 
     24*G[{0, 0, 0, 1/(yu*yv), 1/(yu*yv)}, yw] - 
     4*G[{0, 0, 1, 0, 1}, yu^(-1)] + 4*G[{0, 0, 1, 0, yv^(-1)}, yw] - 
     4*G[{0, 0, 1, 0, 1/(yu*yv)}, yw] + 12*G[{0, 0, 1, 1, 1}, yv^(-1)] - 
     8*G[{0, 0, 1, 1, yu}, yv^(-1)] + 4*G[{0, 0, 1, 1, yv^(-1)}, yw] - 
     4*G[{0, 0, 1, 1, 1/(yu*yv)}, yw] + 12*G[{0, 0, 1, yu^(-1), yv^(-1)}, 
       yw] - 8*G[{0, 0, 1, yu^(-1), 1/(yu*yv)}, yw] - 
     4*G[{0, 0, 1, yu, 1}, yv^(-1)] + 12*G[{0, 0, 1, yv^(-1), yu^(-1)}, yw] + 
     24*G[{0, 0, 1, yv^(-1), yv^(-1)}, yw] - 
     16*G[{0, 0, 1, yv^(-1), 1/(yu*yv)}, yw] - 
     4*G[{0, 0, 1, 1/(yu*yv), 1}, yw] - 4*G[{0, 0, 1, 1/(yu*yv), yu^(-1)}, 
       yw] - 16*G[{0, 0, 1, 1/(yu*yv), yv^(-1)}, yw] + 
     8*G[{0, 0, 1, 1/(yu*yv), 1/(yu*yv)}, yw] - 
     4*G[{0, 0, yu^(-1), 0, yv^(-1)}, yw] + 
     4*G[{0, 0, yu^(-1), 0, 1/(yu*yv)}, yw] + 
     8*G[{0, 0, yu^(-1), 1, yv^(-1)}, yw] - 
     4*G[{0, 0, yu^(-1), 1, 1/(yu*yv)}, yw] - 
     8*G[{0, 0, yu^(-1), yu^(-1), yv^(-1)}, yw] + 
     8*G[{0, 0, yu^(-1), yu^(-1), 1/(yu*yv)}, yw] + 
     4*G[{0, 0, yu^(-1), yv^(-1), 1}, yw] - 
     8*G[{0, 0, yu^(-1), yv^(-1), yu^(-1)}, yw] - 
     16*G[{0, 0, yu^(-1), yv^(-1), yv^(-1)}, yw] - 
     4*G[{0, 0, yu^(-1), yv^(-1), 1/(yu*yv)}, yw] + 
     4*G[{0, 0, yu^(-1), 1/(yu*yv), yu^(-1)}, yw] - 
     4*G[{0, 0, yu^(-1), 1/(yu*yv), yv^(-1)}, yw] + 
     4*G[{0, 0, yv^(-1), 0, 1}, yw] - 4*G[{0, 0, yv^(-1), 0, yu^(-1)}, yw] - 
     8*G[{0, 0, yv^(-1), 0, yv^(-1)}, yw] + 
     8*G[{0, 0, yv^(-1), 0, 1/(yu*yv)}, yw] + 
     4*G[{0, 0, yv^(-1), 1, yu^(-1)}, yw] + 
     12*G[{0, 0, yv^(-1), 1, yv^(-1)}, yw] - 
     4*G[{0, 0, yv^(-1), 1, 1/(yu*yv)}, yw] + 
     4*G[{0, 0, yv^(-1), yu^(-1), 1}, yw] - 
     8*G[{0, 0, yv^(-1), yu^(-1), yu^(-1)}, yw] - 
     4*G[{0, 0, yv^(-1), yu^(-1), yv^(-1)}, yw] - 
     4*G[{0, 0, yv^(-1), yu^(-1), 1/(yu*yv)}, yw] + 
     8*G[{0, 0, yv^(-1), yv^(-1), yu^(-1)}, yw] + 
     8*G[{0, 0, yv^(-1), yv^(-1), yv^(-1)}, yw] + 
     16*G[{0, 0, yv^(-1), yv^(-1), 1/(yu*yv)}, yw] + 
     4*G[{0, 0, yv^(-1), 1/(yu*yv), yu^(-1)}, yw] + 
     8*G[{0, 0, yv^(-1), 1/(yu*yv), yv^(-1)}, yw] - 
     4*G[{0, 0, 1/(yu*yv), 0, 1}, yw] + 4*G[{0, 0, 1/(yu*yv), 0, yu^(-1)}, 
       yw] + 8*G[{0, 0, 1/(yu*yv), 0, yv^(-1)}, yw] - 
     8*G[{0, 0, 1/(yu*yv), 0, 1/(yu*yv)}, yw] - 
     4*G[{0, 0, 1/(yu*yv), 1, yu^(-1)}, yw] - 
     16*G[{0, 0, 1/(yu*yv), 1, yv^(-1)}, yw] + 
     8*G[{0, 0, 1/(yu*yv), 1, 1/(yu*yv)}, yw] - 
     4*G[{0, 0, 1/(yu*yv), yu^(-1), 1}, yw] + 
     8*G[{0, 0, 1/(yu*yv), yu^(-1), yu^(-1)}, yw] + 
     8*G[{0, 0, 1/(yu*yv), yu^(-1), yv^(-1)}, yw] - 
     4*G[{0, 0, 1/(yu*yv), yv^(-1), 1}, yw] + 
     8*G[{0, 0, 1/(yu*yv), yv^(-1), yu^(-1)}, yw] + 
     8*G[{0, 0, 1/(yu*yv), yv^(-1), yv^(-1)}, yw] + 
     4*G[{0, 0, 1/(yu*yv), 1/(yu*yv), 1}, yw] + 
     4*G[{0, 0, 1/(yu*yv), 1/(yu*yv), yu^(-1)}, yw] + 
     8*G[{0, 0, 1/(yu*yv), 1/(yu*yv), yv^(-1)}, yw] + 
     2*G[{0, 1, 0, 1, 1}, yu^(-1)] + 2*G[{0, 1, 0, 1, 1}, yv^(-1)] + 
     4*G[{0, 1, 0, 1, yv^(-1)}, yw] - 2*G[{0, 1, 0, 1, 1/(yu*yv)}, yw] + 
     6*G[{0, 1, 0, yu^(-1), yv^(-1)}, yw] - 
     6*G[{0, 1, 0, yu^(-1), 1/(yu*yv)}, yw] + 
     2*G[{0, 1, 0, yu, 1}, yv^(-1)] - 4*G[{0, 1, 0, yu, yu}, yv^(-1)] + 
     6*G[{0, 1, 0, yv^(-1), yu^(-1)}, yw] + 
     12*G[{0, 1, 0, yv^(-1), yv^(-1)}, yw] - 
     10*G[{0, 1, 0, yv^(-1), 1/(yu*yv)}, yw] - 
     4*G[{0, 1, 0, 1/(yu*yv), yu^(-1)}, yw] - 
     8*G[{0, 1, 0, 1/(yu*yv), yv^(-1)}, yw] + 
     6*G[{0, 1, 0, 1/(yu*yv), 1/(yu*yv)}, yw] + 
     2*G[{0, 1, 1, 0, yu}, yv^(-1)] + 16*G[{0, 1, 1, 1, 1}, yv^(-1)] - 
     10*G[{0, 1, 1, 1, yu}, yv^(-1)] - 6*G[{0, 1, 1, yu^(-1), yv^(-1)}, yw] + 
     2*G[{0, 1, 1, yu^(-1), 1/(yu*yv)}, yw] - 
     6*G[{0, 1, 1, yu, 1}, yv^(-1)] - 6*G[{0, 1, 1, yv^(-1), yu^(-1)}, yw] - 
     12*G[{0, 1, 1, yv^(-1), yv^(-1)}, yw] + 
     2*G[{0, 1, 1, yv^(-1), 1/(yu*yv)}, yw] + 
     2*G[{0, 1, 1, 1/(yu*yv), yu^(-1)}, yw] + 
     2*G[{0, 1, 1, 1/(yu*yv), yv^(-1)}, yw] + 
     4*G[{0, 1, yu^(-1), 0, yv^(-1)}, yw] - 
     4*G[{0, 1, yu^(-1), 0, 1/(yu*yv)}, yw] - 
     8*G[{0, 1, yu^(-1), 1, yv^(-1)}, yw] + 
     4*G[{0, 1, yu^(-1), 1, 1/(yu*yv)}, yw] + 
     8*G[{0, 1, yu^(-1), yu^(-1), yv^(-1)}, yw] - 
     4*G[{0, 1, yu^(-1), yv^(-1), 1}, yw] + 
     8*G[{0, 1, yu^(-1), yv^(-1), yu^(-1)}, yw] + 
     8*G[{0, 1, yu^(-1), yv^(-1), yv^(-1)}, yw] + 
     4*G[{0, 1, yu^(-1), yv^(-1), 1/(yu*yv)}, yw] - 
     4*G[{0, 1, yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] - 
     2*G[{0, 1, yu, 0, yu}, yv^(-1)] - 4*G[{0, 1, yu, 1, 1}, yv^(-1)] - 
     4*G[{0, 1, yu, yu, 1}, yv^(-1)] + 8*G[{0, 1, yu, yu, yu}, yv^(-1)] + 
     4*G[{0, 1, yv^(-1), 0, yu^(-1)}, yw] + 
     8*G[{0, 1, yv^(-1), 0, yv^(-1)}, yw] - 
     8*G[{0, 1, yv^(-1), 0, 1/(yu*yv)}, yw] - 
     4*G[{0, 1, yv^(-1), 1, yu^(-1)}, yw] - 
     12*G[{0, 1, yv^(-1), 1, yv^(-1)}, yw] + 
     4*G[{0, 1, yv^(-1), 1, 1/(yu*yv)}, yw] - 
     4*G[{0, 1, yv^(-1), yu^(-1), 1}, yw] + 
     8*G[{0, 1, yv^(-1), yu^(-1), yu^(-1)}, yw] + 
     8*G[{0, 1, yv^(-1), yu^(-1), yv^(-1)}, yw] + 
     4*G[{0, 1, yv^(-1), yu^(-1), 1/(yu*yv)}, yw] + 
     8*G[{0, 1, yv^(-1), yv^(-1), yu^(-1)}, yw] + 
     16*G[{0, 1, yv^(-1), yv^(-1), yv^(-1)}, yw] - 
     4*G[{0, 1, yv^(-1), 1/(yu*yv), yu^(-1)}, yw] - 
     4*G[{0, 1, yv^(-1), 1/(yu*yv), yv^(-1)}, yw] - 
     4*G[{0, 1, yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] - 
     2*G[{0, 1, 1/(yu*yv), 0, yu^(-1)}, yw] - 
     2*G[{0, 1, 1/(yu*yv), 0, yv^(-1)}, yw] + 
     2*G[{0, 1, 1/(yu*yv), 0, 1/(yu*yv)}, yw] + 
     4*G[{0, 1, 1/(yu*yv), 1, yv^(-1)}, yw] - 
     4*G[{0, 1, 1/(yu*yv), 1, 1/(yu*yv)}, yw] - 
     6*G[{0, 1, 1/(yu*yv), yu^(-1), yv^(-1)}, yw] + 
     2*G[{0, 1, 1/(yu*yv), yu^(-1), 1/(yu*yv)}, yw] - 
     6*G[{0, 1, 1/(yu*yv), yv^(-1), yu^(-1)}, yw] - 
     12*G[{0, 1, 1/(yu*yv), yv^(-1), yv^(-1)}, yw] + 
     2*G[{0, 1, 1/(yu*yv), yv^(-1), 1/(yu*yv)}, yw] - 
     4*G[{0, 1, 1/(yu*yv), 1/(yu*yv), 1}, yw] + 
     6*G[{0, 1, 1/(yu*yv), 1/(yu*yv), yu^(-1)}, yw] + 
     2*G[{0, 1, 1/(yu*yv), 1/(yu*yv), yv^(-1)}, yw] - 
     2*G[{0, yu^(-1), 0, yu^(-1), yv^(-1)}, yw] + 
     4*G[{0, yu^(-1), 0, yu^(-1), 1/(yu*yv)}, yw] - 
     2*G[{0, yu^(-1), 0, yv^(-1), yu^(-1)}, yw] - 
     8*G[{0, yu^(-1), 0, yv^(-1), yv^(-1)}, yw] + 
     2*G[{0, yu^(-1), 0, 1/(yu*yv), yu^(-1)}, yw] - 
     2*G[{0, yu^(-1), 0, 1/(yu*yv), yv^(-1)}, yw] - 
     2*G[{0, yu^(-1), 0, 1/(yu*yv), 1/(yu*yv)}, yw] + 
     6*G[{0, yu^(-1), 1, yu^(-1), yv^(-1)}, yw] - 
     2*G[{0, yu^(-1), 1, yu^(-1), 1/(yu*yv)}, yw] + 
     6*G[{0, yu^(-1), 1, yv^(-1), yu^(-1)}, yw] + 
     12*G[{0, yu^(-1), 1, yv^(-1), yv^(-1)}, yw] - 
     2*G[{0, yu^(-1), 1, yv^(-1), 1/(yu*yv)}, yw] - 
     2*G[{0, yu^(-1), 1, 1/(yu*yv), yu^(-1)}, yw] - 
     2*G[{0, yu^(-1), 1, 1/(yu*yv), yv^(-1)}, yw] - 
     4*G[{0, yu^(-1), yu^(-1), 0, yv^(-1)}, yw] + 
     4*G[{0, yu^(-1), yu^(-1), 0, 1/(yu*yv)}, yw] + 
     8*G[{0, yu^(-1), yu^(-1), 1, yv^(-1)}, yw] - 
     4*G[{0, yu^(-1), yu^(-1), 1, 1/(yu*yv)}, yw] - 
     8*G[{0, yu^(-1), yu^(-1), yu^(-1), yv^(-1)}, yw] + 
     4*G[{0, yu^(-1), yu^(-1), yv^(-1), 1}, yw] - 
     8*G[{0, yu^(-1), yu^(-1), yv^(-1), yu^(-1)}, yw] - 
     8*G[{0, yu^(-1), yu^(-1), yv^(-1), yv^(-1)}, yw] - 
     4*G[{0, yu^(-1), yu^(-1), yv^(-1), 1/(yu*yv)}, yw] + 
     4*G[{0, yu^(-1), yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] - 
     6*G[{0, yu^(-1), yv^(-1), 0, yv^(-1)}, yw] + 
     6*G[{0, yu^(-1), yv^(-1), 0, 1/(yu*yv)}, yw] + 
     4*G[{0, yu^(-1), yv^(-1), 1, yu^(-1)}, yw] + 
     12*G[{0, yu^(-1), yv^(-1), 1, yv^(-1)}, yw] - 
     4*G[{0, yu^(-1), yv^(-1), 1, 1/(yu*yv)}, yw] + 
     4*G[{0, yu^(-1), yv^(-1), yu^(-1), 1}, yw] - 
     8*G[{0, yu^(-1), yv^(-1), yu^(-1), yu^(-1)}, yw] - 
     8*G[{0, yu^(-1), yv^(-1), yu^(-1), yv^(-1)}, yw] - 
     4*G[{0, yu^(-1), yv^(-1), yu^(-1), 1/(yu*yv)}, yw] + 
     4*G[{0, yu^(-1), yv^(-1), yv^(-1), 1}, yw] - 
     8*G[{0, yu^(-1), yv^(-1), yv^(-1), yu^(-1)}, yw] - 
     8*G[{0, yu^(-1), yv^(-1), yv^(-1), yv^(-1)}, yw] - 
     4*G[{0, yu^(-1), yv^(-1), yv^(-1), 1/(yu*yv)}, yw] + 
     4*G[{0, yu^(-1), yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] - 
     6*G[{0, yu^(-1), 1/(yu*yv), 0, yv^(-1)}, yw] + 
     2*G[{0, yu^(-1), 1/(yu*yv), yu^(-1), yv^(-1)}, yw] + 
     2*G[{0, yu^(-1), 1/(yu*yv), yu^(-1), 1/(yu*yv)}, yw] + 
     2*G[{0, yu^(-1), 1/(yu*yv), yv^(-1), yu^(-1)}, yw] + 
     4*G[{0, yu^(-1), 1/(yu*yv), yv^(-1), yv^(-1)}, yw] + 
     2*G[{0, yu^(-1), 1/(yu*yv), yv^(-1), 1/(yu*yv)}, yw] + 
     2*G[{0, yu^(-1), 1/(yu*yv), 1/(yu*yv), yu^(-1)}, yw] + 
     2*G[{0, yu^(-1), 1/(yu*yv), 1/(yu*yv), yv^(-1)}, yw] - 
     4*G[{0, yu, 1, 1, 1}, yv^(-1)] + 2*G[{0, yu, 1, 1, yu}, yv^(-1)] + 
     2*G[{0, yu, 1, yu, 1}, yv^(-1)] + 6*G[{0, yv^(-1), 0, yv^(-1), yu^(-1)}, 
       yw] + 8*G[{0, yv^(-1), 0, yv^(-1), yv^(-1)}, yw] + 
     8*G[{0, yv^(-1), 0, yv^(-1), 1/(yu*yv)}, yw] + 
     2*G[{0, yv^(-1), 0, 1/(yu*yv), yv^(-1)}, yw] - 
     2*G[{0, yv^(-1), 0, 1/(yu*yv), 1/(yu*yv)}, yw] + 
     6*G[{0, yv^(-1), 1, yu^(-1), yv^(-1)}, yw] - 
     2*G[{0, yv^(-1), 1, yu^(-1), 1/(yu*yv)}, yw] + 
     6*G[{0, yv^(-1), 1, yv^(-1), yu^(-1)}, yw] + 
     12*G[{0, yv^(-1), 1, yv^(-1), yv^(-1)}, yw] - 
     2*G[{0, yv^(-1), 1, yv^(-1), 1/(yu*yv)}, yw] - 
     2*G[{0, yv^(-1), 1, 1/(yu*yv), yu^(-1)}, yw] - 
     2*G[{0, yv^(-1), 1, 1/(yu*yv), yv^(-1)}, yw] + 
     6*G[{0, yv^(-1), yu^(-1), 0, 1/(yu*yv)}, yw] + 
     4*G[{0, yv^(-1), yu^(-1), 1, yu^(-1)}, yw] + 
     12*G[{0, yv^(-1), yu^(-1), 1, yv^(-1)}, yw] - 
     4*G[{0, yv^(-1), yu^(-1), 1, 1/(yu*yv)}, yw] + 
     4*G[{0, yv^(-1), yu^(-1), yu^(-1), 1}, yw] - 
     8*G[{0, yv^(-1), yu^(-1), yu^(-1), yu^(-1)}, yw] - 
     8*G[{0, yv^(-1), yu^(-1), yu^(-1), yv^(-1)}, yw] - 
     4*G[{0, yv^(-1), yu^(-1), yu^(-1), 1/(yu*yv)}, yw] + 
     4*G[{0, yv^(-1), yu^(-1), yv^(-1), 1}, yw] - 
     8*G[{0, yv^(-1), yu^(-1), yv^(-1), yu^(-1)}, yw] - 
     8*G[{0, yv^(-1), yu^(-1), yv^(-1), yv^(-1)}, yw] - 
     4*G[{0, yv^(-1), yu^(-1), yv^(-1), 1/(yu*yv)}, yw] + 
     4*G[{0, yv^(-1), yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] + 
     8*G[{0, yv^(-1), yv^(-1), 0, 1/(yu*yv)}, yw] + 
     4*G[{0, yv^(-1), yv^(-1), 1, yu^(-1)}, yw] + 
     12*G[{0, yv^(-1), yv^(-1), 1, yv^(-1)}, yw] - 
     4*G[{0, yv^(-1), yv^(-1), 1, 1/(yu*yv)}, yw] + 
     4*G[{0, yv^(-1), yv^(-1), yu^(-1), 1}, yw] - 
     8*G[{0, yv^(-1), yv^(-1), yu^(-1), yu^(-1)}, yw] - 
     8*G[{0, yv^(-1), yv^(-1), yu^(-1), yv^(-1)}, yw] - 
     4*G[{0, yv^(-1), yv^(-1), yu^(-1), 1/(yu*yv)}, yw] - 
     8*G[{0, yv^(-1), yv^(-1), yv^(-1), yu^(-1)}, yw] - 
     16*G[{0, yv^(-1), yv^(-1), yv^(-1), yv^(-1)}, yw] + 
     4*G[{0, yv^(-1), yv^(-1), 1/(yu*yv), yu^(-1)}, yw] + 
     4*G[{0, yv^(-1), yv^(-1), 1/(yu*yv), yv^(-1)}, yw] + 
     4*G[{0, yv^(-1), yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] + 
     2*G[{0, yv^(-1), 1/(yu*yv), yu^(-1), yv^(-1)}, yw] + 
     2*G[{0, yv^(-1), 1/(yu*yv), yu^(-1), 1/(yu*yv)}, yw] + 
     2*G[{0, yv^(-1), 1/(yu*yv), yv^(-1), yu^(-1)}, yw] + 
     4*G[{0, yv^(-1), 1/(yu*yv), yv^(-1), yv^(-1)}, yw] + 
     2*G[{0, yv^(-1), 1/(yu*yv), yv^(-1), 1/(yu*yv)}, yw] + 
     2*G[{0, yv^(-1), 1/(yu*yv), 1/(yu*yv), yu^(-1)}, yw] + 
     2*G[{0, yv^(-1), 1/(yu*yv), 1/(yu*yv), yv^(-1)}, yw] + 
     6*G[{0, 1/(yu*yv), 0, 1/(yu*yv), yu^(-1)}, yw] + 
     6*G[{0, 1/(yu*yv), 0, 1/(yu*yv), yv^(-1)}, yw] + 
     2*G[{0, 1/(yu*yv), 0, 1/(yu*yv), 1/(yu*yv)}, yw] - 
     6*G[{0, 1/(yu*yv), 1, yu^(-1), yv^(-1)}, yw] + 
     2*G[{0, 1/(yu*yv), 1, yu^(-1), 1/(yu*yv)}, yw] - 
     6*G[{0, 1/(yu*yv), 1, yv^(-1), yu^(-1)}, yw] - 
     12*G[{0, 1/(yu*yv), 1, yv^(-1), yv^(-1)}, yw] + 
     2*G[{0, 1/(yu*yv), 1, yv^(-1), 1/(yu*yv)}, yw] + 
     2*G[{0, 1/(yu*yv), 1, 1/(yu*yv), yu^(-1)}, yw] + 
     2*G[{0, 1/(yu*yv), 1, 1/(yu*yv), yv^(-1)}, yw] - 
     4*G[{0, 1/(yu*yv), yu^(-1), 1, yu^(-1)}, yw] - 
     12*G[{0, 1/(yu*yv), yu^(-1), 1, yv^(-1)}, yw] + 
     4*G[{0, 1/(yu*yv), yu^(-1), 1, 1/(yu*yv)}, yw] - 
     4*G[{0, 1/(yu*yv), yu^(-1), yu^(-1), 1}, yw] + 
     8*G[{0, 1/(yu*yv), yu^(-1), yu^(-1), yu^(-1)}, yw] + 
     8*G[{0, 1/(yu*yv), yu^(-1), yu^(-1), yv^(-1)}, yw] + 
     4*G[{0, 1/(yu*yv), yu^(-1), yu^(-1), 1/(yu*yv)}, yw] - 
     4*G[{0, 1/(yu*yv), yu^(-1), yv^(-1), 1}, yw] + 
     8*G[{0, 1/(yu*yv), yu^(-1), yv^(-1), yu^(-1)}, yw] + 
     8*G[{0, 1/(yu*yv), yu^(-1), yv^(-1), yv^(-1)}, yw] + 
     4*G[{0, 1/(yu*yv), yu^(-1), yv^(-1), 1/(yu*yv)}, yw] - 
     4*G[{0, 1/(yu*yv), yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] - 
     4*G[{0, 1/(yu*yv), yv^(-1), 1, yu^(-1)}, yw] - 
     12*G[{0, 1/(yu*yv), yv^(-1), 1, yv^(-1)}, yw] + 
     4*G[{0, 1/(yu*yv), yv^(-1), 1, 1/(yu*yv)}, yw] - 
     4*G[{0, 1/(yu*yv), yv^(-1), yu^(-1), 1}, yw] + 
     8*G[{0, 1/(yu*yv), yv^(-1), yu^(-1), yu^(-1)}, yw] + 
     8*G[{0, 1/(yu*yv), yv^(-1), yu^(-1), yv^(-1)}, yw] + 
     4*G[{0, 1/(yu*yv), yv^(-1), yu^(-1), 1/(yu*yv)}, yw] - 
     4*G[{0, 1/(yu*yv), yv^(-1), yv^(-1), 1}, yw] + 
     8*G[{0, 1/(yu*yv), yv^(-1), yv^(-1), yu^(-1)}, yw] + 
     8*G[{0, 1/(yu*yv), yv^(-1), yv^(-1), yv^(-1)}, yw] + 
     4*G[{0, 1/(yu*yv), yv^(-1), yv^(-1), 1/(yu*yv)}, yw] - 
     4*G[{0, 1/(yu*yv), yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] - 
     4*G[{0, 1/(yu*yv), 1/(yu*yv), 1, yv^(-1)}, yw] + 
     4*G[{0, 1/(yu*yv), 1/(yu*yv), 1, 1/(yu*yv)}, yw] + 
     2*G[{0, 1/(yu*yv), 1/(yu*yv), yu^(-1), yv^(-1)}, yw] - 
     6*G[{0, 1/(yu*yv), 1/(yu*yv), yu^(-1), 1/(yu*yv)}, yw] + 
     2*G[{0, 1/(yu*yv), 1/(yu*yv), yv^(-1), yu^(-1)}, yw] + 
     4*G[{0, 1/(yu*yv), 1/(yu*yv), yv^(-1), yv^(-1)}, yw] - 
     6*G[{0, 1/(yu*yv), 1/(yu*yv), yv^(-1), 1/(yu*yv)}, yw] + 
     4*G[{0, 1/(yu*yv), 1/(yu*yv), 1/(yu*yv), 1}, yw] - 
     10*G[{0, 1/(yu*yv), 1/(yu*yv), 1/(yu*yv), yu^(-1)}, yw] - 
     6*G[{0, 1/(yu*yv), 1/(yu*yv), 1/(yu*yv), yv^(-1)}, yw] - 
     8*G[{1, 1, 1, 1, yu}, yv^(-1)] - 8*G[{1, 1, 1, yu, yu}, yv^(-1)] - 
     8*G[{1, 1, yu^(-1), yv^(-1), yv^(-1)}, yw] - 
     4*G[{1, 1, yu^(-1), yv^(-1), 1/(yu*yv)}, yw] - 
     4*G[{1, 1, yu^(-1), 1/(yu*yv), yv^(-1)}, yw] + 
     8*G[{1, 1, yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] - 
     12*G[{1, 1, yu, yu, yu}, yv^(-1)] + 
     8*G[{1, 1, yv^(-1), yu^(-1), yv^(-1)}, yw] - 
     4*G[{1, 1, yv^(-1), yu^(-1), 1/(yu*yv)}, yw] + 
     24*G[{1, 1, yv^(-1), yv^(-1), yu^(-1)}, yw] + 
     60*G[{1, 1, yv^(-1), yv^(-1), yv^(-1)}, yw] - 
     12*G[{1, 1, yv^(-1), yv^(-1), 1/(yu*yv)}, yw] - 
     4*G[{1, 1, yv^(-1), 1/(yu*yv), yu^(-1)}, yw] - 
     12*G[{1, 1, yv^(-1), 1/(yu*yv), yv^(-1)}, yw] + 
     12*G[{1, 1, yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] - 
     4*G[{1, 1, 1/(yu*yv), yu^(-1), yv^(-1)}, yw] + 
     8*G[{1, 1, 1/(yu*yv), yu^(-1), 1/(yu*yv)}, yw] - 
     4*G[{1, 1, 1/(yu*yv), yv^(-1), yu^(-1)}, yw] - 
     12*G[{1, 1, 1/(yu*yv), yv^(-1), yv^(-1)}, yw] + 
     4*G[{1, 1, 1/(yu*yv), yv^(-1), 1/(yu*yv)}, yw] + 
     8*G[{1, 1, 1/(yu*yv), 1/(yu*yv), yu^(-1)}, yw] - 
     4*G[{1, 1, 1/(yu*yv), 1/(yu*yv), yv^(-1)}, yw] + 
     12*G[{1, 1, 1/(yu*yv), 1/(yu*yv), 1/(yu*yv)}, yw] - 
     4*G[{1, yu^(-1), 1, yu^(-1), yv^(-1)}, yw] + 
     4*G[{1, yu^(-1), 1, yu^(-1), 1/(yu*yv)}, yw] - 
     4*G[{1, yu^(-1), 1, yv^(-1), yu^(-1)}, yw] - 
     12*G[{1, yu^(-1), 1, yv^(-1), yv^(-1)}, yw] + 
     4*G[{1, yu^(-1), 1, 1/(yu*yv), yu^(-1)}, yw] + 
     4*G[{1, yu^(-1), 1, 1/(yu*yv), 1/(yu*yv)}, yw] - 
     4*G[{1, yu^(-1), yu^(-1), 1, yv^(-1)}, yw] + 
     4*G[{1, yu^(-1), yu^(-1), 1, 1/(yu*yv)}, yw] + 
     8*G[{1, yu^(-1), yu^(-1), yu^(-1), yv^(-1)}, yw] - 
     8*G[{1, yu^(-1), yu^(-1), yu^(-1), 1/(yu*yv)}, yw] + 
     8*G[{1, yu^(-1), yu^(-1), yv^(-1), yu^(-1)}, yw] + 
     8*G[{1, yu^(-1), yu^(-1), yv^(-1), yv^(-1)}, yw] + 
     4*G[{1, yu^(-1), yu^(-1), yv^(-1), 1/(yu*yv)}, yw] - 
     8*G[{1, yu^(-1), yu^(-1), 1/(yu*yv), yu^(-1)}, yw] - 
     4*G[{1, yu^(-1), yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] - 
     8*G[{1, yu^(-1), yv^(-1), 1, yv^(-1)}, yw] + 
     4*G[{1, yu^(-1), yv^(-1), 1, 1/(yu*yv)}, yw] + 
     8*G[{1, yu^(-1), yv^(-1), yu^(-1), yu^(-1)}, yw] + 
     8*G[{1, yu^(-1), yv^(-1), yu^(-1), yv^(-1)}, yw] + 
     4*G[{1, yu^(-1), yv^(-1), yu^(-1), 1/(yu*yv)}, yw] + 
     8*G[{1, yu^(-1), yv^(-1), yv^(-1), yu^(-1)}, yw] + 
     8*G[{1, yu^(-1), yv^(-1), yv^(-1), yv^(-1)}, yw] + 
     4*G[{1, yu^(-1), yv^(-1), yv^(-1), 1/(yu*yv)}, yw] - 
     4*G[{1, yu^(-1), yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] - 
     8*G[{1, yu^(-1), 1/(yu*yv), yu^(-1), yu^(-1)}, yw] - 
     4*G[{1, yu^(-1), 1/(yu*yv), yu^(-1), yv^(-1)}, yw] - 
     4*G[{1, yu^(-1), 1/(yu*yv), yv^(-1), yu^(-1)}, yw] - 
     8*G[{1, yu^(-1), 1/(yu*yv), yv^(-1), yv^(-1)}, yw] + 
     4*G[{1, yu^(-1), 1/(yu*yv), 1/(yu*yv), yu^(-1)}, yw] - 
     4*G[{1, yu, 1, yu, yu}, yv^(-1)] + 8*G[{1, yu, yu, yu, yu}, yv^(-1)] + 
     8*G[{1, yv^(-1), 1, yv^(-1), yu^(-1)}, yw] + 
     20*G[{1, yv^(-1), 1, yv^(-1), yv^(-1)}, yw] - 
     4*G[{1, yv^(-1), 1, yv^(-1), 1/(yu*yv)}, yw] - 
     4*G[{1, yv^(-1), 1, 1/(yu*yv), yv^(-1)}, yw] + 
     8*G[{1, yv^(-1), 1, 1/(yu*yv), 1/(yu*yv)}, yw] + 
     4*G[{1, yv^(-1), yu^(-1), 1, 1/(yu*yv)}, yw] + 
     8*G[{1, yv^(-1), yu^(-1), yu^(-1), yu^(-1)}, yw] + 
     8*G[{1, yv^(-1), yu^(-1), yu^(-1), yv^(-1)}, yw] + 
     4*G[{1, yv^(-1), yu^(-1), yu^(-1), 1/(yu*yv)}, yw] + 
     8*G[{1, yv^(-1), yu^(-1), yv^(-1), yu^(-1)}, yw] + 
     8*G[{1, yv^(-1), yu^(-1), yv^(-1), yv^(-1)}, yw] + 
     4*G[{1, yv^(-1), yu^(-1), yv^(-1), 1/(yu*yv)}, yw] - 
     4*G[{1, yv^(-1), yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] + 
     8*G[{1, yv^(-1), yv^(-1), yu^(-1), yu^(-1)}, yw] + 
     8*G[{1, yv^(-1), yv^(-1), yu^(-1), yv^(-1)}, yw] + 
     4*G[{1, yv^(-1), yv^(-1), yu^(-1), 1/(yu*yv)}, yw] + 
     8*G[{1, yv^(-1), yv^(-1), yv^(-1), yu^(-1)}, yw] + 
     24*G[{1, yv^(-1), yv^(-1), yv^(-1), yv^(-1)}, yw] - 
     8*G[{1, yv^(-1), yv^(-1), 1/(yu*yv), yu^(-1)}, yw] - 
     4*G[{1, yv^(-1), yv^(-1), 1/(yu*yv), yv^(-1)}, yw] - 
     8*G[{1, yv^(-1), yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] + 
     4*G[{1, yv^(-1), 1/(yu*yv), 1, 1/(yu*yv)}, yw] - 
     4*G[{1, yv^(-1), 1/(yu*yv), yu^(-1), yv^(-1)}, yw] - 
     4*G[{1, yv^(-1), 1/(yu*yv), yv^(-1), yu^(-1)}, yw] - 
     4*G[{1, yv^(-1), 1/(yu*yv), yv^(-1), yv^(-1)}, yw] - 
     4*G[{1, yv^(-1), 1/(yu*yv), yv^(-1), 1/(yu*yv)}, yw] - 
     4*G[{1, yv^(-1), 1/(yu*yv), 1/(yu*yv), yv^(-1)}, yw] - 
     4*G[{1, 1/(yu*yv), 1, 1/(yu*yv), yv^(-1)}, yw] + 
     4*G[{1, 1/(yu*yv), 1, 1/(yu*yv), 1/(yu*yv)}, yw] - 
     8*G[{1, 1/(yu*yv), yu^(-1), yu^(-1), yu^(-1)}, yw] + 
     4*G[{1, 1/(yu*yv), yu^(-1), yu^(-1), 1/(yu*yv)}, yw] + 
     8*G[{1, 1/(yu*yv), yu^(-1), 1/(yu*yv), yu^(-1)}, yw] - 
     4*G[{1, 1/(yu*yv), yv^(-1), yv^(-1), 1/(yu*yv)}, yw] - 
     4*G[{1, 1/(yu*yv), yv^(-1), 1/(yu*yv), yv^(-1)}, yw] + 
     4*G[{1, 1/(yu*yv), yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] + 
     8*G[{1, 1/(yu*yv), 1/(yu*yv), yu^(-1), yu^(-1)}, yw] - 
     4*G[{1, 1/(yu*yv), 1/(yu*yv), yu^(-1), yv^(-1)}, yw] + 
     4*G[{1, 1/(yu*yv), 1/(yu*yv), yu^(-1), 1/(yu*yv)}, yw] - 
     4*G[{1, 1/(yu*yv), 1/(yu*yv), yv^(-1), yu^(-1)}, yw] - 
     12*G[{1, 1/(yu*yv), 1/(yu*yv), yv^(-1), yv^(-1)}, yw] + 
     8*G[{1, 1/(yu*yv), 1/(yu*yv), yv^(-1), 1/(yu*yv)}, yw] + 
     8*G[{1, 1/(yu*yv), 1/(yu*yv), 1/(yu*yv), yu^(-1)}, yw] + 
     8*G[{1, 1/(yu*yv), 1/(yu*yv), 1/(yu*yv), yv^(-1)}, yw] - 
     8*G[{yu^(-1), yu^(-1), yu^(-1), 1/(yu*yv), yv^(-1)}, yw] - 
     8*G[{yu^(-1), yu^(-1), yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] + 
     8*G[{yu^(-1), yu^(-1), 1/(yu*yv), yv^(-1), yv^(-1)}, yw] + 
     4*G[{yu^(-1), yu^(-1), 1/(yu*yv), yv^(-1), 1/(yu*yv)}, yw] + 
     8*G[{yu^(-1), yu^(-1), 1/(yu*yv), 1/(yu*yv), yv^(-1)}, yw] + 
     4*G[{yu^(-1), yu^(-1), 1/(yu*yv), 1/(yu*yv), 1/(yu*yv)}, yw] + 
     4*G[{yu^(-1), 1/(yu*yv), yu^(-1), 1/(yu*yv), yv^(-1)}, yw] + 
     4*G[{yu^(-1), 1/(yu*yv), yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] - 
     8*G[{yu^(-1), 1/(yu*yv), yv^(-1), yv^(-1), yv^(-1)}, yw] - 
     4*G[{yu^(-1), 1/(yu*yv), yv^(-1), yv^(-1), 1/(yu*yv)}, yw] + 
     4*G[{yu^(-1), 1/(yu*yv), yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] + 
     4*G[{yu^(-1), 1/(yu*yv), 1/(yu*yv), yv^(-1), 1/(yu*yv)}, yw] + 
     4*G[{yu^(-1), 1/(yu*yv), 1/(yu*yv), 1/(yu*yv), yv^(-1)}, yw] + 
     8*G[{yv^(-1), yv^(-1), yv^(-1), yv^(-1), 1/(yu*yv)}, yw] + 
     12*G[{yv^(-1), yv^(-1), yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] + 
     4*G[{yv^(-1), yv^(-1), 1/(yu*yv), yv^(-1), 1/(yu*yv)}, yw] + 
     (Pi^2*Zeta[3])/3 - 2*G[{0}, yu^(-1)]^2*Zeta[3] - 
     4*G[{0}, yu^(-1)]*G[{0}, yv^(-1)]*Zeta[3] - 2*G[{0}, yv^(-1)]^2*
      Zeta[3] + 4*G[{0}, yu^(-1)]*G[{0}, yw]*Zeta[3] + 
     4*G[{0}, yv^(-1)]*G[{0}, yw]*Zeta[3] - 2*G[{0}, yw]^2*Zeta[3] - 
     2*G[{1}, yv^(-1)]^2*Zeta[3] + 4*G[{0}, yu^(-1)]*G[{yu}, yv^(-1)]*
      Zeta[3] + 4*G[{0}, yv^(-1)]*G[{yu}, yv^(-1)]*Zeta[3] - 
     4*G[{0}, yw]*G[{yu}, yv^(-1)]*Zeta[3] - 2*G[{yu}, yv^(-1)]^2*Zeta[3] + 
     4*G[{1}, yv^(-1)]*G[{yv^(-1)}, yw]*Zeta[3] - 
     8*G[{1}, yw]*G[{yv^(-1)}, yw]*Zeta[3] + 2*G[{yv^(-1)}, yw]^2*Zeta[3] - 
     4*G[{0}, yu^(-1)]*G[{1/(yu*yv)}, yw]*Zeta[3] - 
     4*G[{0}, yv^(-1)]*G[{1/(yu*yv)}, yw]*Zeta[3] + 
     4*G[{0}, yw]*G[{1/(yu*yv)}, yw]*Zeta[3] + 4*G[{yu}, yv^(-1)]*
      G[{1/(yu*yv)}, yw]*Zeta[3] - 2*G[{1/(yu*yv)}, yw]^2*Zeta[3] + 
     4*G[{0, 1}, yv^(-1)]*Zeta[3] + 4*G[{0, 1}, yw]*Zeta[3] - 
     4*G[{0, yv^(-1)}, yw]*Zeta[3] + 8*G[{1, yv^(-1)}, yw]*Zeta[3] - 7*Zeta[5]
 
M1wuvRegII = (-5*Pi^4*G[{1}, yw])/36 + (Pi^2*G[{1}, yu^(-1)]^2*G[{1}, yw])/
      2 - Pi^2*G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*G[{1}, yw] - 
     (Pi^2*G[{0}, yu^(-1)]*G[{1}, yw]^2)/2 - 
     (Pi^2*G[{0}, yv^(-1)]*G[{1}, yw]^2)/2 + (Pi^2*G[{0}, yw]*G[{1}, yw]^2)/
      2 + Pi^2*G[{1}, yu^(-1)]*G[{1}, yw]^2 + G[{0}, yu^(-1)]*
      G[{1}, yu^(-1)]^2*G[{1}, yw]^2 + G[{0}, yv^(-1)]*G[{1}, yu^(-1)]^2*
      G[{1}, yw]^2 - G[{0}, yw]*G[{1}, yu^(-1)]^2*G[{1}, yw]^2 - 
     G[{1}, yu^(-1)]^3*G[{1}, yw]^2 + (Pi^2*G[{1}, yv^(-1)]*G[{1}, yw]^2)/2 - 
     2*G[{0}, yu^(-1)]*G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*G[{1}, yw]^2 - 
     2*G[{0}, yv^(-1)]*G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*G[{1}, yw]^2 + 
     2*G[{0}, yw]*G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*G[{1}, yw]^2 + 
     G[{1}, yu^(-1)]^2*G[{1}, yv^(-1)]*G[{1}, yw]^2 + 
     2*G[{1}, yu^(-1)]*G[{1}, yv^(-1)]^2*G[{1}, yw]^2 + 
     (Pi^2*G[{1}, yw]^3)/6 + G[{0}, yu^(-1)]*G[{1}, yu^(-1)]*G[{1}, yw]^3 + 
     G[{0}, yv^(-1)]*G[{1}, yu^(-1)]*G[{1}, yw]^3 - 
     G[{0}, yw]*G[{1}, yu^(-1)]*G[{1}, yw]^3 - G[{1}, yu^(-1)]^2*
      G[{1}, yw]^3 - (2*G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*G[{1}, yw]^3)/3 + 
     (G[{0}, yu^(-1)]*G[{1}, yw]^4)/3 + (G[{0}, yv^(-1)]*G[{1}, yw]^4)/3 - 
     (G[{0}, yw]*G[{1}, yw]^4)/3 - (G[{1}, yu^(-1)]*G[{1}, yw]^4)/3 - 
     (G[{1}, yv^(-1)]*G[{1}, yw]^4)/3 - (Pi^4*G[{yu^(-1)}, yw])/90 - 
     (Pi^2*G[{1}, yu^(-1)]^2*G[{yu^(-1)}, yw])/2 + Pi^2*G[{1}, yu^(-1)]*
      G[{1}, yv^(-1)]*G[{yu^(-1)}, yw] + (2*Pi^2*G[{0}, yu^(-1)]*G[{1}, yw]*
       G[{yu^(-1)}, yw])/3 + (2*Pi^2*G[{0}, yv^(-1)]*G[{1}, yw]*
       G[{yu^(-1)}, yw])/3 - (2*Pi^2*G[{0}, yw]*G[{1}, yw]*G[{yu^(-1)}, yw])/
      3 - 2*G[{0}, yu^(-1)]*G[{1}, yu^(-1)]^2*G[{1}, yw]*G[{yu^(-1)}, yw] - 
     2*G[{0}, yv^(-1)]*G[{1}, yu^(-1)]^2*G[{1}, yw]*G[{yu^(-1)}, yw] + 
     2*G[{0}, yw]*G[{1}, yu^(-1)]^2*G[{1}, yw]*G[{yu^(-1)}, yw] + 
     2*G[{1}, yu^(-1)]^3*G[{1}, yw]*G[{yu^(-1)}, yw] - 
     (Pi^2*G[{1}, yv^(-1)]*G[{1}, yw]*G[{yu^(-1)}, yw])/3 + 
     4*G[{0}, yu^(-1)]*G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*G[{1}, yw]*
      G[{yu^(-1)}, yw] + 4*G[{0}, yv^(-1)]*G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*
      G[{1}, yw]*G[{yu^(-1)}, yw] - 4*G[{0}, yw]*G[{1}, yu^(-1)]*
      G[{1}, yv^(-1)]*G[{1}, yw]*G[{yu^(-1)}, yw] - 
     2*G[{1}, yu^(-1)]^2*G[{1}, yv^(-1)]*G[{1}, yw]*G[{yu^(-1)}, yw] - 
     2*G[{1}, yu^(-1)]*G[{1}, yv^(-1)]^2*G[{1}, yw]*G[{yu^(-1)}, yw] + 
     (Pi^2*G[{1}, yw]^2*G[{yu^(-1)}, yw])/2 + G[{0}, yu^(-1)]*G[{1}, yu^(-1)]*
      G[{1}, yw]^2*G[{yu^(-1)}, yw] + G[{0}, yv^(-1)]*G[{1}, yu^(-1)]*
      G[{1}, yw]^2*G[{yu^(-1)}, yw] - G[{0}, yw]*G[{1}, yu^(-1)]*G[{1}, yw]^2*
      G[{yu^(-1)}, yw] - G[{1}, yu^(-1)]^2*G[{1}, yw]^2*G[{yu^(-1)}, yw] + 
     (2*G[{0}, yu^(-1)]*G[{1}, yw]^3*G[{yu^(-1)}, yw])/3 + 
     (2*G[{0}, yv^(-1)]*G[{1}, yw]^3*G[{yu^(-1)}, yw])/3 - 
     (2*G[{0}, yw]*G[{1}, yw]^3*G[{yu^(-1)}, yw])/3 - 
     (2*G[{1}, yu^(-1)]*G[{1}, yw]^3*G[{yu^(-1)}, yw])/3 - 
     (2*G[{1}, yv^(-1)]*G[{1}, yw]^3*G[{yu^(-1)}, yw])/3 - 
     (Pi^2*G[{0}, yu^(-1)]*G[{yu^(-1)}, yw]^2)/6 - 
     (Pi^2*G[{0}, yv^(-1)]*G[{yu^(-1)}, yw]^2)/6 + 
     (Pi^2*G[{0}, yw]*G[{yu^(-1)}, yw]^2)/6 - 
     (Pi^2*G[{1}, yu^(-1)]*G[{yu^(-1)}, yw]^2)/2 + 
     G[{0}, yu^(-1)]*G[{1}, yu^(-1)]^2*G[{yu^(-1)}, yw]^2 + 
     G[{0}, yv^(-1)]*G[{1}, yu^(-1)]^2*G[{yu^(-1)}, yw]^2 - 
     G[{0}, yw]*G[{1}, yu^(-1)]^2*G[{yu^(-1)}, yw]^2 - 
     G[{1}, yu^(-1)]^3*G[{yu^(-1)}, yw]^2 + 
     (5*Pi^2*G[{1}, yv^(-1)]*G[{yu^(-1)}, yw]^2)/6 - 
     2*G[{0}, yu^(-1)]*G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*G[{yu^(-1)}, yw]^2 - 
     2*G[{0}, yv^(-1)]*G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*G[{yu^(-1)}, yw]^2 + 
     2*G[{0}, yw]*G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*G[{yu^(-1)}, yw]^2 + 
     G[{1}, yu^(-1)]^2*G[{1}, yv^(-1)]*G[{yu^(-1)}, yw]^2 + 
     2*G[{1}, yu^(-1)]*G[{1}, yv^(-1)]^2*G[{yu^(-1)}, yw]^2 + 
     (Pi^2*G[{1}, yw]*G[{yu^(-1)}, yw]^2)/2 - 4*G[{0}, yu^(-1)]*
      G[{1}, yu^(-1)]*G[{1}, yw]*G[{yu^(-1)}, yw]^2 - 
     4*G[{0}, yv^(-1)]*G[{1}, yu^(-1)]*G[{1}, yw]*G[{yu^(-1)}, yw]^2 + 
     4*G[{0}, yw]*G[{1}, yu^(-1)]*G[{1}, yw]*G[{yu^(-1)}, yw]^2 + 
     4*G[{1}, yu^(-1)]^2*G[{1}, yw]*G[{yu^(-1)}, yw]^2 + 
     2*G[{0}, yu^(-1)]*G[{1}, yv^(-1)]*G[{1}, yw]*G[{yu^(-1)}, yw]^2 + 
     2*G[{0}, yv^(-1)]*G[{1}, yv^(-1)]*G[{1}, yw]*G[{yu^(-1)}, yw]^2 - 
     2*G[{0}, yw]*G[{1}, yv^(-1)]*G[{1}, yw]*G[{yu^(-1)}, yw]^2 + 
     2*G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*G[{1}, yw]*G[{yu^(-1)}, yw]^2 - 
     2*G[{1}, yv^(-1)]^2*G[{1}, yw]*G[{yu^(-1)}, yw]^2 + 
     (G[{0}, yu^(-1)]*G[{1}, yw]^2*G[{yu^(-1)}, yw]^2)/2 + 
     (G[{0}, yv^(-1)]*G[{1}, yw]^2*G[{yu^(-1)}, yw]^2)/2 - 
     (G[{0}, yw]*G[{1}, yw]^2*G[{yu^(-1)}, yw]^2)/2 - 
     (G[{1}, yu^(-1)]*G[{1}, yw]^2*G[{yu^(-1)}, yw]^2)/2 - 
     (G[{1}, yv^(-1)]*G[{1}, yw]^2*G[{yu^(-1)}, yw]^2)/2 - 
     (4*Pi^2*G[{yu^(-1)}, yw]^3)/9 + 2*G[{0}, yu^(-1)]*G[{1}, yu^(-1)]*
      G[{yu^(-1)}, yw]^3 + 2*G[{0}, yv^(-1)]*G[{1}, yu^(-1)]*
      G[{yu^(-1)}, yw]^3 - 2*G[{0}, yw]*G[{1}, yu^(-1)]*G[{yu^(-1)}, yw]^3 - 
     (5*G[{1}, yu^(-1)]^2*G[{yu^(-1)}, yw]^3)/3 - 
     2*G[{0}, yu^(-1)]*G[{1}, yv^(-1)]*G[{yu^(-1)}, yw]^3 - 
     2*G[{0}, yv^(-1)]*G[{1}, yv^(-1)]*G[{yu^(-1)}, yw]^3 + 
     2*G[{0}, yw]*G[{1}, yv^(-1)]*G[{yu^(-1)}, yw]^3 - 
     (2*G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*G[{yu^(-1)}, yw]^3)/3 + 
     2*G[{1}, yv^(-1)]^2*G[{yu^(-1)}, yw]^3 - 
     (8*G[{0}, yu^(-1)]*G[{1}, yw]*G[{yu^(-1)}, yw]^3)/3 - 
     (8*G[{0}, yv^(-1)]*G[{1}, yw]*G[{yu^(-1)}, yw]^3)/3 + 
     (8*G[{0}, yw]*G[{1}, yw]*G[{yu^(-1)}, yw]^3)/3 + 
     (8*G[{1}, yu^(-1)]*G[{1}, yw]*G[{yu^(-1)}, yw]^3)/3 + 
     2*G[{1}, yv^(-1)]*G[{1}, yw]*G[{yu^(-1)}, yw]^3 - 
     (G[{1}, yw]^2*G[{yu^(-1)}, yw]^3)/3 + 
     (7*G[{0}, yu^(-1)]*G[{yu^(-1)}, yw]^4)/6 + 
     (7*G[{0}, yv^(-1)]*G[{yu^(-1)}, yw]^4)/6 - 
     (7*G[{0}, yw]*G[{yu^(-1)}, yw]^4)/6 - 
     (G[{1}, yu^(-1)]*G[{yu^(-1)}, yw]^4)/2 - 
     (11*G[{1}, yv^(-1)]*G[{yu^(-1)}, yw]^4)/6 + (11*G[{yu^(-1)}, yw]^5)/30 - 
     (Pi^2*G[{1}, yw]^2*G[{yu}, yv^(-1)])/2 - 2*G[{1}, yu^(-1)]*
      G[{1}, yv^(-1)]*G[{1}, yw]^2*G[{yu}, yv^(-1)] - 
     G[{0}, yu^(-1)]*G[{1}, yw]^3*G[{yu}, yv^(-1)] - 
     G[{0}, yv^(-1)]*G[{1}, yw]^3*G[{yu}, yv^(-1)] + 
     G[{0}, yw]*G[{1}, yw]^3*G[{yu}, yv^(-1)] + 
     (2*G[{1}, yu^(-1)]*G[{1}, yw]^3*G[{yu}, yv^(-1)])/3 + 
     (2*G[{1}, yv^(-1)]*G[{1}, yw]^3*G[{yu}, yv^(-1)])/3 - 
     Pi^2*G[{1}, yw]*G[{yu^(-1)}, yw]*G[{yu}, yv^(-1)] - 
     4*G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*G[{1}, yw]*G[{yu^(-1)}, yw]*
      G[{yu}, yv^(-1)] - G[{0}, yu^(-1)]*G[{1}, yw]^2*G[{yu^(-1)}, yw]*
      G[{yu}, yv^(-1)] - G[{0}, yv^(-1)]*G[{1}, yw]^2*G[{yu^(-1)}, yw]*
      G[{yu}, yv^(-1)] + G[{0}, yw]*G[{1}, yw]^2*G[{yu^(-1)}, yw]*
      G[{yu}, yv^(-1)] + 2*G[{0}, yu^(-1)]*G[{1}, yw]*G[{yu^(-1)}, yw]^2*
      G[{yu}, yv^(-1)] + 2*G[{0}, yv^(-1)]*G[{1}, yw]*G[{yu^(-1)}, yw]^2*
      G[{yu}, yv^(-1)] - 2*G[{0}, yw]*G[{1}, yw]*G[{yu^(-1)}, yw]^2*
      G[{yu}, yv^(-1)] - 2*G[{1}, yu^(-1)]*G[{1}, yw]*G[{yu^(-1)}, yw]^2*
      G[{yu}, yv^(-1)] - 2*G[{1}, yv^(-1)]*G[{1}, yw]*G[{yu^(-1)}, yw]^2*
      G[{yu}, yv^(-1)] + (2*G[{1}, yw]*G[{yu^(-1)}, yw]^3*G[{yu}, yv^(-1)])/
      3 + G[{1}, yu^(-1)]*G[{1}, yw]^2*G[{yu}, yv^(-1)]^2 + 
     G[{1}, yv^(-1)]*G[{1}, yw]^2*G[{yu}, yv^(-1)]^2 + 
     (G[{1}, yw]^3*G[{yu}, yv^(-1)]^2)/3 + 2*G[{1}, yu^(-1)]*G[{1}, yw]*
      G[{yu^(-1)}, yw]*G[{yu}, yv^(-1)]^2 + 2*G[{1}, yv^(-1)]*G[{1}, yw]*
      G[{yu^(-1)}, yw]*G[{yu}, yv^(-1)]^2 + G[{1}, yw]^2*G[{yu^(-1)}, yw]*
      G[{yu}, yv^(-1)]^2 - (2*G[{1}, yw]^2*G[{yu}, yv^(-1)]^3)/3 - 
     (4*G[{1}, yw]*G[{yu^(-1)}, yw]*G[{yu}, yv^(-1)]^3)/3 + 
     (5*Pi^4*G[{yv^(-1)}, yw])/36 - (Pi^2*G[{1}, yu^(-1)]^2*G[{yv^(-1)}, yw])/
      2 + Pi^2*G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*G[{yv^(-1)}, yw] + 
     Pi^2*G[{0}, yu^(-1)]*G[{1}, yw]*G[{yv^(-1)}, yw] + 
     Pi^2*G[{0}, yv^(-1)]*G[{1}, yw]*G[{yv^(-1)}, yw] - 
     Pi^2*G[{0}, yw]*G[{1}, yw]*G[{yv^(-1)}, yw] - 2*Pi^2*G[{1}, yu^(-1)]*
      G[{1}, yw]*G[{yv^(-1)}, yw] - 2*G[{0}, yu^(-1)]*G[{1}, yu^(-1)]^2*
      G[{1}, yw]*G[{yv^(-1)}, yw] - 2*G[{0}, yv^(-1)]*G[{1}, yu^(-1)]^2*
      G[{1}, yw]*G[{yv^(-1)}, yw] + 2*G[{0}, yw]*G[{1}, yu^(-1)]^2*G[{1}, yw]*
      G[{yv^(-1)}, yw] + 2*G[{1}, yu^(-1)]^3*G[{1}, yw]*G[{yv^(-1)}, yw] - 
     Pi^2*G[{1}, yv^(-1)]*G[{1}, yw]*G[{yv^(-1)}, yw] + 
     4*G[{0}, yu^(-1)]*G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*G[{1}, yw]*
      G[{yv^(-1)}, yw] + 4*G[{0}, yv^(-1)]*G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*
      G[{1}, yw]*G[{yv^(-1)}, yw] - 4*G[{0}, yw]*G[{1}, yu^(-1)]*
      G[{1}, yv^(-1)]*G[{1}, yw]*G[{yv^(-1)}, yw] - 
     2*G[{1}, yu^(-1)]^2*G[{1}, yv^(-1)]*G[{1}, yw]*G[{yv^(-1)}, yw] - 
     4*G[{1}, yu^(-1)]*G[{1}, yv^(-1)]^2*G[{1}, yw]*G[{yv^(-1)}, yw] - 
     (Pi^2*G[{1}, yw]^2*G[{yv^(-1)}, yw])/2 - 3*G[{0}, yu^(-1)]*
      G[{1}, yu^(-1)]*G[{1}, yw]^2*G[{yv^(-1)}, yw] - 
     3*G[{0}, yv^(-1)]*G[{1}, yu^(-1)]*G[{1}, yw]^2*G[{yv^(-1)}, yw] + 
     3*G[{0}, yw]*G[{1}, yu^(-1)]*G[{1}, yw]^2*G[{yv^(-1)}, yw] + 
     3*G[{1}, yu^(-1)]^2*G[{1}, yw]^2*G[{yv^(-1)}, yw] + 
     2*G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*G[{1}, yw]^2*G[{yv^(-1)}, yw] - 
     (4*G[{0}, yu^(-1)]*G[{1}, yw]^3*G[{yv^(-1)}, yw])/3 - 
     (4*G[{0}, yv^(-1)]*G[{1}, yw]^3*G[{yv^(-1)}, yw])/3 + 
     (4*G[{0}, yw]*G[{1}, yw]^3*G[{yv^(-1)}, yw])/3 + 
     (4*G[{1}, yu^(-1)]*G[{1}, yw]^3*G[{yv^(-1)}, yw])/3 + 
     (4*G[{1}, yv^(-1)]*G[{1}, yw]^3*G[{yv^(-1)}, yw])/3 - 
     (2*Pi^2*G[{0}, yu^(-1)]*G[{yu^(-1)}, yw]*G[{yv^(-1)}, yw])/3 - 
     (2*Pi^2*G[{0}, yv^(-1)]*G[{yu^(-1)}, yw]*G[{yv^(-1)}, yw])/3 + 
     (2*Pi^2*G[{0}, yw]*G[{yu^(-1)}, yw]*G[{yv^(-1)}, yw])/3 + 
     Pi^2*G[{1}, yu^(-1)]*G[{yu^(-1)}, yw]*G[{yv^(-1)}, yw] + 
     2*G[{0}, yu^(-1)]*G[{1}, yu^(-1)]^2*G[{yu^(-1)}, yw]*G[{yv^(-1)}, yw] + 
     2*G[{0}, yv^(-1)]*G[{1}, yu^(-1)]^2*G[{yu^(-1)}, yw]*G[{yv^(-1)}, yw] - 
     2*G[{0}, yw]*G[{1}, yu^(-1)]^2*G[{yu^(-1)}, yw]*G[{yv^(-1)}, yw] - 
     2*G[{1}, yu^(-1)]^3*G[{yu^(-1)}, yw]*G[{yv^(-1)}, yw] + 
     (Pi^2*G[{1}, yv^(-1)]*G[{yu^(-1)}, yw]*G[{yv^(-1)}, yw])/3 - 
     4*G[{0}, yu^(-1)]*G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*G[{yu^(-1)}, yw]*
      G[{yv^(-1)}, yw] - 4*G[{0}, yv^(-1)]*G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*
      G[{yu^(-1)}, yw]*G[{yv^(-1)}, yw] + 4*G[{0}, yw]*G[{1}, yu^(-1)]*
      G[{1}, yv^(-1)]*G[{yu^(-1)}, yw]*G[{yv^(-1)}, yw] + 
     2*G[{1}, yu^(-1)]^2*G[{1}, yv^(-1)]*G[{yu^(-1)}, yw]*G[{yv^(-1)}, yw] + 
     2*G[{1}, yu^(-1)]*G[{1}, yv^(-1)]^2*G[{yu^(-1)}, yw]*G[{yv^(-1)}, yw] - 
     (Pi^2*G[{1}, yw]*G[{yu^(-1)}, yw]*G[{yv^(-1)}, yw])/3 - 
     G[{0}, yu^(-1)]*G[{1}, yw]^2*G[{yu^(-1)}, yw]*G[{yv^(-1)}, yw] - 
     G[{0}, yv^(-1)]*G[{1}, yw]^2*G[{yu^(-1)}, yw]*G[{yv^(-1)}, yw] + 
     G[{0}, yw]*G[{1}, yw]^2*G[{yu^(-1)}, yw]*G[{yv^(-1)}, yw] + 
     G[{1}, yu^(-1)]*G[{1}, yw]^2*G[{yu^(-1)}, yw]*G[{yv^(-1)}, yw] + 
     G[{1}, yv^(-1)]*G[{1}, yw]^2*G[{yu^(-1)}, yw]*G[{yv^(-1)}, yw] + 
     2*G[{0}, yu^(-1)]*G[{1}, yu^(-1)]*G[{yu^(-1)}, yw]^2*G[{yv^(-1)}, yw] + 
     2*G[{0}, yv^(-1)]*G[{1}, yu^(-1)]*G[{yu^(-1)}, yw]^2*G[{yv^(-1)}, yw] - 
     2*G[{0}, yw]*G[{1}, yu^(-1)]*G[{yu^(-1)}, yw]^2*G[{yv^(-1)}, yw] - 
     G[{1}, yu^(-1)]^2*G[{yu^(-1)}, yw]^2*G[{yv^(-1)}, yw] - 
     2*G[{0}, yu^(-1)]*G[{1}, yv^(-1)]*G[{yu^(-1)}, yw]^2*G[{yv^(-1)}, yw] - 
     2*G[{0}, yv^(-1)]*G[{1}, yv^(-1)]*G[{yu^(-1)}, yw]^2*G[{yv^(-1)}, yw] + 
     2*G[{0}, yw]*G[{1}, yv^(-1)]*G[{yu^(-1)}, yw]^2*G[{yv^(-1)}, yw] - 
     2*G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*G[{yu^(-1)}, yw]^2*G[{yv^(-1)}, yw] + 
     2*G[{1}, yv^(-1)]^2*G[{yu^(-1)}, yw]^2*G[{yv^(-1)}, yw] - 
     2*G[{1}, yv^(-1)]*G[{1}, yw]*G[{yu^(-1)}, yw]^2*G[{yv^(-1)}, yw] - 
     G[{1}, yw]^2*G[{yu^(-1)}, yw]^2*G[{yv^(-1)}, yw] + 
     (2*G[{0}, yu^(-1)]*G[{yu^(-1)}, yw]^3*G[{yv^(-1)}, yw])/3 + 
     (2*G[{0}, yv^(-1)]*G[{yu^(-1)}, yw]^3*G[{yv^(-1)}, yw])/3 - 
     (2*G[{0}, yw]*G[{yu^(-1)}, yw]^3*G[{yv^(-1)}, yw])/3 + 
     (2*G[{1}, yu^(-1)]*G[{yu^(-1)}, yw]^3*G[{yv^(-1)}, yw])/3 - 
     2*G[{1}, yv^(-1)]*G[{yu^(-1)}, yw]^3*G[{yv^(-1)}, yw] + 
     (G[{yu^(-1)}, yw]^4*G[{yv^(-1)}, yw])/2 + Pi^2*G[{1}, yw]*
      G[{yu}, yv^(-1)]*G[{yv^(-1)}, yw] + 4*G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*
      G[{1}, yw]*G[{yu}, yv^(-1)]*G[{yv^(-1)}, yw] + 
     3*G[{0}, yu^(-1)]*G[{1}, yw]^2*G[{yu}, yv^(-1)]*G[{yv^(-1)}, yw] + 
     3*G[{0}, yv^(-1)]*G[{1}, yw]^2*G[{yu}, yv^(-1)]*G[{yv^(-1)}, yw] - 
     3*G[{0}, yw]*G[{1}, yw]^2*G[{yu}, yv^(-1)]*G[{yv^(-1)}, yw] - 
     2*G[{1}, yu^(-1)]*G[{1}, yw]^2*G[{yu}, yv^(-1)]*G[{yv^(-1)}, yw] - 
     2*G[{1}, yv^(-1)]*G[{1}, yw]^2*G[{yu}, yv^(-1)]*G[{yv^(-1)}, yw] + 
     2*G[{1}, yw]*G[{yu^(-1)}, yw]^2*G[{yu}, yv^(-1)]*G[{yv^(-1)}, yw] - 
     2*G[{1}, yu^(-1)]*G[{1}, yw]*G[{yu}, yv^(-1)]^2*G[{yv^(-1)}, yw] - 
     2*G[{1}, yv^(-1)]*G[{1}, yw]*G[{yu}, yv^(-1)]^2*G[{yv^(-1)}, yw] - 
     G[{1}, yw]^2*G[{yu}, yv^(-1)]^2*G[{yv^(-1)}, yw] + 
     (4*G[{1}, yw]*G[{yu}, yv^(-1)]^3*G[{yv^(-1)}, yw])/3 - 
     (Pi^2*G[{0}, yu^(-1)]*G[{yv^(-1)}, yw]^2)/2 - 
     (Pi^2*G[{0}, yv^(-1)]*G[{yv^(-1)}, yw]^2)/2 + 
     (Pi^2*G[{0}, yw]*G[{yv^(-1)}, yw]^2)/2 + 
     (Pi^2*G[{1}, yu^(-1)]*G[{yv^(-1)}, yw]^2)/2 + 
     G[{0}, yu^(-1)]*G[{1}, yu^(-1)]^2*G[{yv^(-1)}, yw]^2 + 
     G[{0}, yv^(-1)]*G[{1}, yu^(-1)]^2*G[{yv^(-1)}, yw]^2 - 
     G[{0}, yw]*G[{1}, yu^(-1)]^2*G[{yv^(-1)}, yw]^2 - 
     G[{1}, yu^(-1)]^3*G[{yv^(-1)}, yw]^2 + 
     (Pi^2*G[{1}, yv^(-1)]*G[{yv^(-1)}, yw]^2)/2 - 
     2*G[{0}, yu^(-1)]*G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*G[{yv^(-1)}, yw]^2 - 
     2*G[{0}, yv^(-1)]*G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*G[{yv^(-1)}, yw]^2 + 
     2*G[{0}, yw]*G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*G[{yv^(-1)}, yw]^2 + 
     G[{1}, yu^(-1)]^2*G[{1}, yv^(-1)]*G[{yv^(-1)}, yw]^2 + 
     2*G[{1}, yu^(-1)]*G[{1}, yv^(-1)]^2*G[{yv^(-1)}, yw]^2 - 
     (Pi^2*G[{1}, yw]*G[{yv^(-1)}, yw]^2)/6 + 2*G[{0}, yu^(-1)]*
      G[{1}, yu^(-1)]*G[{1}, yw]*G[{yv^(-1)}, yw]^2 + 
     2*G[{0}, yv^(-1)]*G[{1}, yu^(-1)]*G[{1}, yw]*G[{yv^(-1)}, yw]^2 - 
     2*G[{0}, yw]*G[{1}, yu^(-1)]*G[{1}, yw]*G[{yv^(-1)}, yw]^2 - 
     2*G[{1}, yu^(-1)]^2*G[{1}, yw]*G[{yv^(-1)}, yw]^2 - 
     2*G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*G[{1}, yw]*G[{yv^(-1)}, yw]^2 + 
     (G[{0}, yu^(-1)]*G[{1}, yw]^2*G[{yv^(-1)}, yw]^2)/2 + 
     (G[{0}, yv^(-1)]*G[{1}, yw]^2*G[{yv^(-1)}, yw]^2)/2 - 
     (G[{0}, yw]*G[{1}, yw]^2*G[{yv^(-1)}, yw]^2)/2 - 
     (G[{1}, yu^(-1)]*G[{1}, yw]^2*G[{yv^(-1)}, yw]^2)/2 - 
     (G[{1}, yv^(-1)]*G[{1}, yw]^2*G[{yv^(-1)}, yw]^2)/2 - 
     (Pi^2*G[{yu^(-1)}, yw]*G[{yv^(-1)}, yw]^2)/3 + 
     G[{1}, yu^(-1)]^2*G[{yu^(-1)}, yw]*G[{yv^(-1)}, yw]^2 - 
     2*G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*G[{yu^(-1)}, yw]*G[{yv^(-1)}, yw]^2 + 
     2*G[{0}, yu^(-1)]*G[{1}, yw]*G[{yu^(-1)}, yw]*G[{yv^(-1)}, yw]^2 + 
     2*G[{0}, yv^(-1)]*G[{1}, yw]*G[{yu^(-1)}, yw]*G[{yv^(-1)}, yw]^2 - 
     2*G[{0}, yw]*G[{1}, yw]*G[{yu^(-1)}, yw]*G[{yv^(-1)}, yw]^2 - 
     2*G[{1}, yv^(-1)]*G[{1}, yw]*G[{yu^(-1)}, yw]*G[{yv^(-1)}, yw]^2 + 
     G[{1}, yw]^2*G[{yu^(-1)}, yw]*G[{yv^(-1)}, yw]^2 - 
     G[{0}, yu^(-1)]*G[{yu^(-1)}, yw]^2*G[{yv^(-1)}, yw]^2 - 
     G[{0}, yv^(-1)]*G[{yu^(-1)}, yw]^2*G[{yv^(-1)}, yw]^2 + 
     G[{0}, yw]*G[{yu^(-1)}, yw]^2*G[{yv^(-1)}, yw]^2 + 
     G[{1}, yu^(-1)]*G[{yu^(-1)}, yw]^2*G[{yv^(-1)}, yw]^2 + 
     G[{1}, yv^(-1)]*G[{yu^(-1)}, yw]^2*G[{yv^(-1)}, yw]^2 - 
     (G[{yu^(-1)}, yw]^3*G[{yv^(-1)}, yw]^2)/3 - 2*G[{0}, yu^(-1)]*G[{1}, yw]*
      G[{yu}, yv^(-1)]*G[{yv^(-1)}, yw]^2 - 2*G[{0}, yv^(-1)]*G[{1}, yw]*
      G[{yu}, yv^(-1)]*G[{yv^(-1)}, yw]^2 + 2*G[{0}, yw]*G[{1}, yw]*
      G[{yu}, yv^(-1)]*G[{yv^(-1)}, yw]^2 + 2*G[{1}, yu^(-1)]*G[{1}, yw]*
      G[{yu}, yv^(-1)]*G[{yv^(-1)}, yw]^2 + 2*G[{1}, yv^(-1)]*G[{1}, yw]*
      G[{yu}, yv^(-1)]*G[{yv^(-1)}, yw]^2 - 2*G[{1}, yw]*G[{yu^(-1)}, yw]*
      G[{yu}, yv^(-1)]*G[{yv^(-1)}, yw]^2 - (Pi^2*G[{yv^(-1)}, yw]^3)/9 + 
     (G[{1}, yu^(-1)]^2*G[{yv^(-1)}, yw]^3)/3 - 
     (2*G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*G[{yv^(-1)}, yw]^3)/3 + 
     (2*G[{0}, yu^(-1)]*G[{1}, yw]*G[{yv^(-1)}, yw]^3)/3 + 
     (2*G[{0}, yv^(-1)]*G[{1}, yw]*G[{yv^(-1)}, yw]^3)/3 - 
     (2*G[{0}, yw]*G[{1}, yw]*G[{yv^(-1)}, yw]^3)/3 - 
     (2*G[{1}, yv^(-1)]*G[{1}, yw]*G[{yv^(-1)}, yw]^3)/3 + 
     (G[{1}, yw]^2*G[{yv^(-1)}, yw]^3)/3 - 
     (2*G[{0}, yu^(-1)]*G[{yu^(-1)}, yw]*G[{yv^(-1)}, yw]^3)/3 - 
     (2*G[{0}, yv^(-1)]*G[{yu^(-1)}, yw]*G[{yv^(-1)}, yw]^3)/3 + 
     (2*G[{0}, yw]*G[{yu^(-1)}, yw]*G[{yv^(-1)}, yw]^3)/3 + 
     (2*G[{1}, yu^(-1)]*G[{yu^(-1)}, yw]*G[{yv^(-1)}, yw]^3)/3 + 
     (2*G[{1}, yv^(-1)]*G[{yu^(-1)}, yw]*G[{yv^(-1)}, yw]^3)/3 - 
     (G[{yu^(-1)}, yw]^2*G[{yv^(-1)}, yw]^3)/3 - 
     (2*G[{1}, yw]*G[{yu}, yv^(-1)]*G[{yv^(-1)}, yw]^3)/3 - 
     (G[{0}, yu^(-1)]*G[{yv^(-1)}, yw]^4)/6 - 
     (G[{0}, yv^(-1)]*G[{yv^(-1)}, yw]^4)/6 + (G[{0}, yw]*G[{yv^(-1)}, yw]^4)/
      6 + (G[{1}, yu^(-1)]*G[{yv^(-1)}, yw]^4)/6 + 
     (G[{1}, yv^(-1)]*G[{yv^(-1)}, yw]^4)/6 - 
     (G[{yu^(-1)}, yw]*G[{yv^(-1)}, yw]^4)/6 - G[{yv^(-1)}, yw]^5/30 + 
     (Pi^4*G[{1/(yu*yv)}, yw])/90 + (Pi^2*G[{1}, yu^(-1)]^2*
       G[{1/(yu*yv)}, yw])/2 - Pi^2*G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*
      G[{1/(yu*yv)}, yw] - (2*Pi^2*G[{0}, yu^(-1)]*G[{1}, yw]*
       G[{1/(yu*yv)}, yw])/3 - (2*Pi^2*G[{0}, yv^(-1)]*G[{1}, yw]*
       G[{1/(yu*yv)}, yw])/3 + (2*Pi^2*G[{0}, yw]*G[{1}, yw]*
       G[{1/(yu*yv)}, yw])/3 + 2*G[{0}, yu^(-1)]*G[{1}, yu^(-1)]^2*G[{1}, yw]*
      G[{1/(yu*yv)}, yw] + 2*G[{0}, yv^(-1)]*G[{1}, yu^(-1)]^2*G[{1}, yw]*
      G[{1/(yu*yv)}, yw] - 2*G[{0}, yw]*G[{1}, yu^(-1)]^2*G[{1}, yw]*
      G[{1/(yu*yv)}, yw] - 2*G[{1}, yu^(-1)]^3*G[{1}, yw]*
      G[{1/(yu*yv)}, yw] + (Pi^2*G[{1}, yv^(-1)]*G[{1}, yw]*
       G[{1/(yu*yv)}, yw])/3 - 4*G[{0}, yu^(-1)]*G[{1}, yu^(-1)]*
      G[{1}, yv^(-1)]*G[{1}, yw]*G[{1/(yu*yv)}, yw] - 
     4*G[{0}, yv^(-1)]*G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*G[{1}, yw]*
      G[{1/(yu*yv)}, yw] + 4*G[{0}, yw]*G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*
      G[{1}, yw]*G[{1/(yu*yv)}, yw] + 2*G[{1}, yu^(-1)]^2*G[{1}, yv^(-1)]*
      G[{1}, yw]*G[{1/(yu*yv)}, yw] + 2*G[{1}, yu^(-1)]*G[{1}, yv^(-1)]^2*
      G[{1}, yw]*G[{1/(yu*yv)}, yw] - (Pi^2*G[{1}, yw]^2*G[{1/(yu*yv)}, yw])/
      2 - G[{0}, yu^(-1)]*G[{1}, yu^(-1)]*G[{1}, yw]^2*G[{1/(yu*yv)}, yw] - 
     G[{0}, yv^(-1)]*G[{1}, yu^(-1)]*G[{1}, yw]^2*G[{1/(yu*yv)}, yw] + 
     G[{0}, yw]*G[{1}, yu^(-1)]*G[{1}, yw]^2*G[{1/(yu*yv)}, yw] + 
     G[{1}, yu^(-1)]^2*G[{1}, yw]^2*G[{1/(yu*yv)}, yw] - 
     (2*G[{0}, yu^(-1)]*G[{1}, yw]^3*G[{1/(yu*yv)}, yw])/3 - 
     (2*G[{0}, yv^(-1)]*G[{1}, yw]^3*G[{1/(yu*yv)}, yw])/3 + 
     (2*G[{0}, yw]*G[{1}, yw]^3*G[{1/(yu*yv)}, yw])/3 + 
     (2*G[{1}, yu^(-1)]*G[{1}, yw]^3*G[{1/(yu*yv)}, yw])/3 + 
     (2*G[{1}, yv^(-1)]*G[{1}, yw]^3*G[{1/(yu*yv)}, yw])/3 + 
     (Pi^2*G[{0}, yu^(-1)]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw])/3 + 
     (Pi^2*G[{0}, yv^(-1)]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw])/3 - 
     (Pi^2*G[{0}, yw]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw])/3 + 
     Pi^2*G[{1}, yu^(-1)]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw] - 
     2*G[{0}, yu^(-1)]*G[{1}, yu^(-1)]^2*G[{yu^(-1)}, yw]*
      G[{1/(yu*yv)}, yw] - 2*G[{0}, yv^(-1)]*G[{1}, yu^(-1)]^2*
      G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw] + 2*G[{0}, yw]*G[{1}, yu^(-1)]^2*
      G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw] + 2*G[{1}, yu^(-1)]^3*
      G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw] - 
     (5*Pi^2*G[{1}, yv^(-1)]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw])/3 + 
     4*G[{0}, yu^(-1)]*G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*G[{yu^(-1)}, yw]*
      G[{1/(yu*yv)}, yw] + 4*G[{0}, yv^(-1)]*G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*
      G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw] - 4*G[{0}, yw]*G[{1}, yu^(-1)]*
      G[{1}, yv^(-1)]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw] - 
     2*G[{1}, yu^(-1)]^2*G[{1}, yv^(-1)]*G[{yu^(-1)}, yw]*
      G[{1/(yu*yv)}, yw] - 4*G[{1}, yu^(-1)]*G[{1}, yv^(-1)]^2*
      G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw] - Pi^2*G[{1}, yw]*G[{yu^(-1)}, yw]*
      G[{1/(yu*yv)}, yw] + 8*G[{0}, yu^(-1)]*G[{1}, yu^(-1)]*G[{1}, yw]*
      G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw] + 8*G[{0}, yv^(-1)]*G[{1}, yu^(-1)]*
      G[{1}, yw]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw] - 
     8*G[{0}, yw]*G[{1}, yu^(-1)]*G[{1}, yw]*G[{yu^(-1)}, yw]*
      G[{1/(yu*yv)}, yw] - 8*G[{1}, yu^(-1)]^2*G[{1}, yw]*G[{yu^(-1)}, yw]*
      G[{1/(yu*yv)}, yw] - 4*G[{0}, yu^(-1)]*G[{1}, yv^(-1)]*G[{1}, yw]*
      G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw] - 4*G[{0}, yv^(-1)]*G[{1}, yv^(-1)]*
      G[{1}, yw]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw] + 
     4*G[{0}, yw]*G[{1}, yv^(-1)]*G[{1}, yw]*G[{yu^(-1)}, yw]*
      G[{1/(yu*yv)}, yw] - 4*G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*G[{1}, yw]*
      G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw] + 4*G[{1}, yv^(-1)]^2*G[{1}, yw]*
      G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw] - G[{0}, yu^(-1)]*G[{1}, yw]^2*
      G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw] - G[{0}, yv^(-1)]*G[{1}, yw]^2*
      G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw] + G[{0}, yw]*G[{1}, yw]^2*
      G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw] + G[{1}, yu^(-1)]*G[{1}, yw]^2*
      G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw] + G[{1}, yv^(-1)]*G[{1}, yw]^2*
      G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw] + 
     (4*Pi^2*G[{yu^(-1)}, yw]^2*G[{1/(yu*yv)}, yw])/3 - 
     6*G[{0}, yu^(-1)]*G[{1}, yu^(-1)]*G[{yu^(-1)}, yw]^2*
      G[{1/(yu*yv)}, yw] - 6*G[{0}, yv^(-1)]*G[{1}, yu^(-1)]*
      G[{yu^(-1)}, yw]^2*G[{1/(yu*yv)}, yw] + 6*G[{0}, yw]*G[{1}, yu^(-1)]*
      G[{yu^(-1)}, yw]^2*G[{1/(yu*yv)}, yw] + 5*G[{1}, yu^(-1)]^2*
      G[{yu^(-1)}, yw]^2*G[{1/(yu*yv)}, yw] + 6*G[{0}, yu^(-1)]*
      G[{1}, yv^(-1)]*G[{yu^(-1)}, yw]^2*G[{1/(yu*yv)}, yw] + 
     6*G[{0}, yv^(-1)]*G[{1}, yv^(-1)]*G[{yu^(-1)}, yw]^2*
      G[{1/(yu*yv)}, yw] - 6*G[{0}, yw]*G[{1}, yv^(-1)]*G[{yu^(-1)}, yw]^2*
      G[{1/(yu*yv)}, yw] + 2*G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*
      G[{yu^(-1)}, yw]^2*G[{1/(yu*yv)}, yw] - 6*G[{1}, yv^(-1)]^2*
      G[{yu^(-1)}, yw]^2*G[{1/(yu*yv)}, yw] + 8*G[{0}, yu^(-1)]*G[{1}, yw]*
      G[{yu^(-1)}, yw]^2*G[{1/(yu*yv)}, yw] + 8*G[{0}, yv^(-1)]*G[{1}, yw]*
      G[{yu^(-1)}, yw]^2*G[{1/(yu*yv)}, yw] - 8*G[{0}, yw]*G[{1}, yw]*
      G[{yu^(-1)}, yw]^2*G[{1/(yu*yv)}, yw] - 8*G[{1}, yu^(-1)]*G[{1}, yw]*
      G[{yu^(-1)}, yw]^2*G[{1/(yu*yv)}, yw] - 6*G[{1}, yv^(-1)]*G[{1}, yw]*
      G[{yu^(-1)}, yw]^2*G[{1/(yu*yv)}, yw] + G[{1}, yw]^2*G[{yu^(-1)}, yw]^2*
      G[{1/(yu*yv)}, yw] - (14*G[{0}, yu^(-1)]*G[{yu^(-1)}, yw]^3*
       G[{1/(yu*yv)}, yw])/3 - (14*G[{0}, yv^(-1)]*G[{yu^(-1)}, yw]^3*
       G[{1/(yu*yv)}, yw])/3 + (14*G[{0}, yw]*G[{yu^(-1)}, yw]^3*
       G[{1/(yu*yv)}, yw])/3 + 2*G[{1}, yu^(-1)]*G[{yu^(-1)}, yw]^3*
      G[{1/(yu*yv)}, yw] + (22*G[{1}, yv^(-1)]*G[{yu^(-1)}, yw]^3*
       G[{1/(yu*yv)}, yw])/3 - (11*G[{yu^(-1)}, yw]^4*G[{1/(yu*yv)}, yw])/6 + 
     Pi^2*G[{1}, yw]*G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw] + 
     4*G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*G[{1}, yw]*G[{yu}, yv^(-1)]*
      G[{1/(yu*yv)}, yw] + G[{0}, yu^(-1)]*G[{1}, yw]^2*G[{yu}, yv^(-1)]*
      G[{1/(yu*yv)}, yw] + G[{0}, yv^(-1)]*G[{1}, yw]^2*G[{yu}, yv^(-1)]*
      G[{1/(yu*yv)}, yw] - G[{0}, yw]*G[{1}, yw]^2*G[{yu}, yv^(-1)]*
      G[{1/(yu*yv)}, yw] - 4*G[{0}, yu^(-1)]*G[{1}, yw]*G[{yu^(-1)}, yw]*
      G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw] - 4*G[{0}, yv^(-1)]*G[{1}, yw]*
      G[{yu^(-1)}, yw]*G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw] + 
     4*G[{0}, yw]*G[{1}, yw]*G[{yu^(-1)}, yw]*G[{yu}, yv^(-1)]*
      G[{1/(yu*yv)}, yw] + 4*G[{1}, yu^(-1)]*G[{1}, yw]*G[{yu^(-1)}, yw]*
      G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw] + 4*G[{1}, yv^(-1)]*G[{1}, yw]*
      G[{yu^(-1)}, yw]*G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw] - 
     2*G[{1}, yw]*G[{yu^(-1)}, yw]^2*G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw] - 
     2*G[{1}, yu^(-1)]*G[{1}, yw]*G[{yu}, yv^(-1)]^2*G[{1/(yu*yv)}, yw] - 
     2*G[{1}, yv^(-1)]*G[{1}, yw]*G[{yu}, yv^(-1)]^2*G[{1/(yu*yv)}, yw] - 
     G[{1}, yw]^2*G[{yu}, yv^(-1)]^2*G[{1/(yu*yv)}, yw] + 
     (4*G[{1}, yw]*G[{yu}, yv^(-1)]^3*G[{1/(yu*yv)}, yw])/3 + 
     (2*Pi^2*G[{0}, yu^(-1)]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw])/3 + 
     (2*Pi^2*G[{0}, yv^(-1)]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw])/3 - 
     (2*Pi^2*G[{0}, yw]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw])/3 - 
     Pi^2*G[{1}, yu^(-1)]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw] - 
     2*G[{0}, yu^(-1)]*G[{1}, yu^(-1)]^2*G[{yv^(-1)}, yw]*
      G[{1/(yu*yv)}, yw] - 2*G[{0}, yv^(-1)]*G[{1}, yu^(-1)]^2*
      G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw] + 2*G[{0}, yw]*G[{1}, yu^(-1)]^2*
      G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw] + 2*G[{1}, yu^(-1)]^3*
      G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw] - 
     (Pi^2*G[{1}, yv^(-1)]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw])/3 + 
     4*G[{0}, yu^(-1)]*G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*G[{yv^(-1)}, yw]*
      G[{1/(yu*yv)}, yw] + 4*G[{0}, yv^(-1)]*G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*
      G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw] - 4*G[{0}, yw]*G[{1}, yu^(-1)]*
      G[{1}, yv^(-1)]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw] - 
     2*G[{1}, yu^(-1)]^2*G[{1}, yv^(-1)]*G[{yv^(-1)}, yw]*
      G[{1/(yu*yv)}, yw] - 2*G[{1}, yu^(-1)]*G[{1}, yv^(-1)]^2*
      G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw] + 
     (Pi^2*G[{1}, yw]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw])/3 + 
     G[{0}, yu^(-1)]*G[{1}, yw]^2*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw] + 
     G[{0}, yv^(-1)]*G[{1}, yw]^2*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw] - 
     G[{0}, yw]*G[{1}, yw]^2*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw] - 
     G[{1}, yu^(-1)]*G[{1}, yw]^2*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw] - 
     G[{1}, yv^(-1)]*G[{1}, yw]^2*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw] - 
     4*G[{0}, yu^(-1)]*G[{1}, yu^(-1)]*G[{yu^(-1)}, yw]*G[{yv^(-1)}, yw]*
      G[{1/(yu*yv)}, yw] - 4*G[{0}, yv^(-1)]*G[{1}, yu^(-1)]*G[{yu^(-1)}, yw]*
      G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw] + 4*G[{0}, yw]*G[{1}, yu^(-1)]*
      G[{yu^(-1)}, yw]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw] + 
     2*G[{1}, yu^(-1)]^2*G[{yu^(-1)}, yw]*G[{yv^(-1)}, yw]*
      G[{1/(yu*yv)}, yw] + 4*G[{0}, yu^(-1)]*G[{1}, yv^(-1)]*G[{yu^(-1)}, yw]*
      G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw] + 4*G[{0}, yv^(-1)]*G[{1}, yv^(-1)]*
      G[{yu^(-1)}, yw]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw] - 
     4*G[{0}, yw]*G[{1}, yv^(-1)]*G[{yu^(-1)}, yw]*G[{yv^(-1)}, yw]*
      G[{1/(yu*yv)}, yw] + 4*G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*G[{yu^(-1)}, yw]*
      G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw] - 4*G[{1}, yv^(-1)]^2*
      G[{yu^(-1)}, yw]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw] + 
     4*G[{1}, yv^(-1)]*G[{1}, yw]*G[{yu^(-1)}, yw]*G[{yv^(-1)}, yw]*
      G[{1/(yu*yv)}, yw] + 2*G[{1}, yw]^2*G[{yu^(-1)}, yw]*G[{yv^(-1)}, yw]*
      G[{1/(yu*yv)}, yw] - 2*G[{0}, yu^(-1)]*G[{yu^(-1)}, yw]^2*
      G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw] - 2*G[{0}, yv^(-1)]*
      G[{yu^(-1)}, yw]^2*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw] + 
     2*G[{0}, yw]*G[{yu^(-1)}, yw]^2*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw] - 
     2*G[{1}, yu^(-1)]*G[{yu^(-1)}, yw]^2*G[{yv^(-1)}, yw]*
      G[{1/(yu*yv)}, yw] + 6*G[{1}, yv^(-1)]*G[{yu^(-1)}, yw]^2*
      G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw] - 2*G[{yu^(-1)}, yw]^3*
      G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw] - 4*G[{1}, yw]*G[{yu^(-1)}, yw]*
      G[{yu}, yv^(-1)]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw] + 
     (Pi^2*G[{yv^(-1)}, yw]^2*G[{1/(yu*yv)}, yw])/3 - 
     G[{1}, yu^(-1)]^2*G[{yv^(-1)}, yw]^2*G[{1/(yu*yv)}, yw] + 
     2*G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*G[{yv^(-1)}, yw]^2*
      G[{1/(yu*yv)}, yw] - 2*G[{0}, yu^(-1)]*G[{1}, yw]*G[{yv^(-1)}, yw]^2*
      G[{1/(yu*yv)}, yw] - 2*G[{0}, yv^(-1)]*G[{1}, yw]*G[{yv^(-1)}, yw]^2*
      G[{1/(yu*yv)}, yw] + 2*G[{0}, yw]*G[{1}, yw]*G[{yv^(-1)}, yw]^2*
      G[{1/(yu*yv)}, yw] + 2*G[{1}, yv^(-1)]*G[{1}, yw]*G[{yv^(-1)}, yw]^2*
      G[{1/(yu*yv)}, yw] - G[{1}, yw]^2*G[{yv^(-1)}, yw]^2*
      G[{1/(yu*yv)}, yw] + 2*G[{0}, yu^(-1)]*G[{yu^(-1)}, yw]*
      G[{yv^(-1)}, yw]^2*G[{1/(yu*yv)}, yw] + 2*G[{0}, yv^(-1)]*
      G[{yu^(-1)}, yw]*G[{yv^(-1)}, yw]^2*G[{1/(yu*yv)}, yw] - 
     2*G[{0}, yw]*G[{yu^(-1)}, yw]*G[{yv^(-1)}, yw]^2*G[{1/(yu*yv)}, yw] - 
     2*G[{1}, yu^(-1)]*G[{yu^(-1)}, yw]*G[{yv^(-1)}, yw]^2*
      G[{1/(yu*yv)}, yw] - 2*G[{1}, yv^(-1)]*G[{yu^(-1)}, yw]*
      G[{yv^(-1)}, yw]^2*G[{1/(yu*yv)}, yw] + G[{yu^(-1)}, yw]^2*
      G[{yv^(-1)}, yw]^2*G[{1/(yu*yv)}, yw] + 2*G[{1}, yw]*G[{yu}, yv^(-1)]*
      G[{yv^(-1)}, yw]^2*G[{1/(yu*yv)}, yw] + 
     (2*G[{0}, yu^(-1)]*G[{yv^(-1)}, yw]^3*G[{1/(yu*yv)}, yw])/3 + 
     (2*G[{0}, yv^(-1)]*G[{yv^(-1)}, yw]^3*G[{1/(yu*yv)}, yw])/3 - 
     (2*G[{0}, yw]*G[{yv^(-1)}, yw]^3*G[{1/(yu*yv)}, yw])/3 - 
     (2*G[{1}, yu^(-1)]*G[{yv^(-1)}, yw]^3*G[{1/(yu*yv)}, yw])/3 - 
     (2*G[{1}, yv^(-1)]*G[{yv^(-1)}, yw]^3*G[{1/(yu*yv)}, yw])/3 + 
     (2*G[{yu^(-1)}, yw]*G[{yv^(-1)}, yw]^3*G[{1/(yu*yv)}, yw])/3 + 
     (G[{yv^(-1)}, yw]^4*G[{1/(yu*yv)}, yw])/6 - 
     (Pi^2*G[{0}, yu^(-1)]*G[{1/(yu*yv)}, yw]^2)/6 - 
     (Pi^2*G[{0}, yv^(-1)]*G[{1/(yu*yv)}, yw]^2)/6 + 
     (Pi^2*G[{0}, yw]*G[{1/(yu*yv)}, yw]^2)/6 + G[{0}, yu^(-1)]*
      G[{1}, yu^(-1)]^2*G[{1/(yu*yv)}, yw]^2 + G[{0}, yv^(-1)]*
      G[{1}, yu^(-1)]^2*G[{1/(yu*yv)}, yw]^2 - G[{0}, yw]*G[{1}, yu^(-1)]^2*
      G[{1/(yu*yv)}, yw]^2 - G[{1}, yu^(-1)]^3*G[{1/(yu*yv)}, yw]^2 + 
     (5*Pi^2*G[{1}, yv^(-1)]*G[{1/(yu*yv)}, yw]^2)/6 - 
     2*G[{0}, yu^(-1)]*G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*G[{1/(yu*yv)}, yw]^2 - 
     2*G[{0}, yv^(-1)]*G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*G[{1/(yu*yv)}, yw]^2 + 
     2*G[{0}, yw]*G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*G[{1/(yu*yv)}, yw]^2 + 
     G[{1}, yu^(-1)]^2*G[{1}, yv^(-1)]*G[{1/(yu*yv)}, yw]^2 + 
     2*G[{1}, yu^(-1)]*G[{1}, yv^(-1)]^2*G[{1/(yu*yv)}, yw]^2 + 
     (Pi^2*G[{1}, yw]*G[{1/(yu*yv)}, yw]^2)/2 - 3*G[{0}, yu^(-1)]*
      G[{1}, yu^(-1)]*G[{1}, yw]*G[{1/(yu*yv)}, yw]^2 - 
     3*G[{0}, yv^(-1)]*G[{1}, yu^(-1)]*G[{1}, yw]*G[{1/(yu*yv)}, yw]^2 + 
     3*G[{0}, yw]*G[{1}, yu^(-1)]*G[{1}, yw]*G[{1/(yu*yv)}, yw]^2 + 
     3*G[{1}, yu^(-1)]^2*G[{1}, yw]*G[{1/(yu*yv)}, yw]^2 + 
     2*G[{0}, yu^(-1)]*G[{1}, yv^(-1)]*G[{1}, yw]*G[{1/(yu*yv)}, yw]^2 + 
     2*G[{0}, yv^(-1)]*G[{1}, yv^(-1)]*G[{1}, yw]*G[{1/(yu*yv)}, yw]^2 - 
     2*G[{0}, yw]*G[{1}, yv^(-1)]*G[{1}, yw]*G[{1/(yu*yv)}, yw]^2 + 
     2*G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*G[{1}, yw]*G[{1/(yu*yv)}, yw]^2 - 
     2*G[{1}, yv^(-1)]^2*G[{1}, yw]*G[{1/(yu*yv)}, yw]^2 - 
     (5*Pi^2*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2)/6 + 
     5*G[{0}, yu^(-1)]*G[{1}, yu^(-1)]*G[{yu^(-1)}, yw]*
      G[{1/(yu*yv)}, yw]^2 + 5*G[{0}, yv^(-1)]*G[{1}, yu^(-1)]*
      G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2 - 5*G[{0}, yw]*G[{1}, yu^(-1)]*
      G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2 - 4*G[{1}, yu^(-1)]^2*
      G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2 - 6*G[{0}, yu^(-1)]*
      G[{1}, yv^(-1)]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2 - 
     6*G[{0}, yv^(-1)]*G[{1}, yv^(-1)]*G[{yu^(-1)}, yw]*
      G[{1/(yu*yv)}, yw]^2 + 6*G[{0}, yw]*G[{1}, yv^(-1)]*G[{yu^(-1)}, yw]*
      G[{1/(yu*yv)}, yw]^2 - 2*G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*
      G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2 + 6*G[{1}, yv^(-1)]^2*
      G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2 - 6*G[{0}, yu^(-1)]*G[{1}, yw]*
      G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2 - 6*G[{0}, yv^(-1)]*G[{1}, yw]*
      G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2 + 6*G[{0}, yw]*G[{1}, yw]*
      G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2 + 5*G[{1}, yu^(-1)]*G[{1}, yw]*
      G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2 + 3*G[{1}, yv^(-1)]*G[{1}, yw]*
      G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2 - 2*G[{1}, yw]^2*G[{yu^(-1)}, yw]*
      G[{1/(yu*yv)}, yw]^2 + (11*G[{0}, yu^(-1)]*G[{yu^(-1)}, yw]^2*
       G[{1/(yu*yv)}, yw]^2)/2 + (11*G[{0}, yv^(-1)]*G[{yu^(-1)}, yw]^2*
       G[{1/(yu*yv)}, yw]^2)/2 - (11*G[{0}, yw]*G[{yu^(-1)}, yw]^2*
       G[{1/(yu*yv)}, yw]^2)/2 - (3*G[{1}, yu^(-1)]*G[{yu^(-1)}, yw]^2*
       G[{1/(yu*yv)}, yw]^2)/2 - (19*G[{1}, yv^(-1)]*G[{yu^(-1)}, yw]^2*
       G[{1/(yu*yv)}, yw]^2)/2 + (19*G[{yu^(-1)}, yw]^3*G[{1/(yu*yv)}, yw]^2)/
      6 - (Pi^2*G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw]^2)/2 - 
     2*G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*G[{yu}, yv^(-1)]*
      G[{1/(yu*yv)}, yw]^2 + G[{0}, yu^(-1)]*G[{1}, yw]*G[{yu}, yv^(-1)]*
      G[{1/(yu*yv)}, yw]^2 + G[{0}, yv^(-1)]*G[{1}, yw]*G[{yu}, yv^(-1)]*
      G[{1/(yu*yv)}, yw]^2 - G[{0}, yw]*G[{1}, yw]*G[{yu}, yv^(-1)]*
      G[{1/(yu*yv)}, yw]^2 - 2*G[{1}, yu^(-1)]*G[{1}, yw]*G[{yu}, yv^(-1)]*
      G[{1/(yu*yv)}, yw]^2 - 2*G[{1}, yv^(-1)]*G[{1}, yw]*G[{yu}, yv^(-1)]*
      G[{1/(yu*yv)}, yw]^2 + G[{0}, yu^(-1)]*G[{yu^(-1)}, yw]*
      G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw]^2 + G[{0}, yv^(-1)]*
      G[{yu^(-1)}, yw]*G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw]^2 - 
     G[{0}, yw]*G[{yu^(-1)}, yw]*G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw]^2 + 
     4*G[{1}, yw]*G[{yu^(-1)}, yw]*G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw]^2 + 
     G[{1}, yu^(-1)]*G[{yu}, yv^(-1)]^2*G[{1/(yu*yv)}, yw]^2 + 
     G[{1}, yv^(-1)]*G[{yu}, yv^(-1)]^2*G[{1/(yu*yv)}, yw]^2 + 
     G[{1}, yw]*G[{yu}, yv^(-1)]^2*G[{1/(yu*yv)}, yw]^2 - 
     G[{yu^(-1)}, yw]*G[{yu}, yv^(-1)]^2*G[{1/(yu*yv)}, yw]^2 - 
     (2*G[{yu}, yv^(-1)]^3*G[{1/(yu*yv)}, yw]^2)/3 + 
     G[{0}, yu^(-1)]*G[{1}, yu^(-1)]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2 + 
     G[{0}, yv^(-1)]*G[{1}, yu^(-1)]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2 - 
     G[{0}, yw]*G[{1}, yu^(-1)]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2 - 
     2*G[{0}, yu^(-1)]*G[{1}, yv^(-1)]*G[{yv^(-1)}, yw]*
      G[{1/(yu*yv)}, yw]^2 - 2*G[{0}, yv^(-1)]*G[{1}, yv^(-1)]*
      G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2 + 2*G[{0}, yw]*G[{1}, yv^(-1)]*
      G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2 - 2*G[{1}, yu^(-1)]*
      G[{1}, yv^(-1)]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2 + 
     2*G[{1}, yv^(-1)]^2*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2 + 
     G[{0}, yu^(-1)]*G[{1}, yw]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2 + 
     G[{0}, yv^(-1)]*G[{1}, yw]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2 - 
     G[{0}, yw]*G[{1}, yw]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2 - 
     G[{1}, yu^(-1)]*G[{1}, yw]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2 - 
     3*G[{1}, yv^(-1)]*G[{1}, yw]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2 - 
     G[{1}, yw]^2*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2 + 
     3*G[{1}, yu^(-1)]*G[{yu^(-1)}, yw]*G[{yv^(-1)}, yw]*
      G[{1/(yu*yv)}, yw]^2 - 3*G[{1}, yv^(-1)]*G[{yu^(-1)}, yw]*
      G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2 + 
     (3*G[{yu^(-1)}, yw]^2*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2)/2 + 
     G[{0}, yu^(-1)]*G[{yu}, yv^(-1)]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2 + 
     G[{0}, yv^(-1)]*G[{yu}, yv^(-1)]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2 - 
     G[{0}, yw]*G[{yu}, yv^(-1)]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2 + 
     2*G[{1}, yw]*G[{yu}, yv^(-1)]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2 - 
     G[{yu}, yv^(-1)]^2*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2 - 
     (3*G[{0}, yu^(-1)]*G[{yv^(-1)}, yw]^2*G[{1/(yu*yv)}, yw]^2)/2 - 
     (3*G[{0}, yv^(-1)]*G[{yv^(-1)}, yw]^2*G[{1/(yu*yv)}, yw]^2)/2 + 
     (3*G[{0}, yw]*G[{yv^(-1)}, yw]^2*G[{1/(yu*yv)}, yw]^2)/2 + 
     (3*G[{1}, yu^(-1)]*G[{yv^(-1)}, yw]^2*G[{1/(yu*yv)}, yw]^2)/2 + 
     (3*G[{1}, yv^(-1)]*G[{yv^(-1)}, yw]^2*G[{1/(yu*yv)}, yw]^2)/2 - 
     (3*G[{yu^(-1)}, yw]*G[{yv^(-1)}, yw]^2*G[{1/(yu*yv)}, yw]^2)/2 - 
     (G[{yv^(-1)}, yw]^3*G[{1/(yu*yv)}, yw]^2)/2 - 
     G[{0}, yu^(-1)]*G[{1}, yu^(-1)]*G[{1/(yu*yv)}, yw]^3 - 
     G[{0}, yv^(-1)]*G[{1}, yu^(-1)]*G[{1/(yu*yv)}, yw]^3 + 
     G[{0}, yw]*G[{1}, yu^(-1)]*G[{1/(yu*yv)}, yw]^3 + 
     G[{1}, yu^(-1)]^2*G[{1/(yu*yv)}, yw]^3 + 2*G[{0}, yu^(-1)]*
      G[{1}, yv^(-1)]*G[{1/(yu*yv)}, yw]^3 + 2*G[{0}, yv^(-1)]*
      G[{1}, yv^(-1)]*G[{1/(yu*yv)}, yw]^3 - 2*G[{0}, yw]*G[{1}, yv^(-1)]*
      G[{1/(yu*yv)}, yw]^3 - (2*G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*
       G[{1/(yu*yv)}, yw]^3)/3 - 2*G[{1}, yv^(-1)]^2*G[{1/(yu*yv)}, yw]^3 + 
     G[{0}, yu^(-1)]*G[{1}, yw]*G[{1/(yu*yv)}, yw]^3 + 
     G[{0}, yv^(-1)]*G[{1}, yw]*G[{1/(yu*yv)}, yw]^3 - 
     G[{0}, yw]*G[{1}, yw]*G[{1/(yu*yv)}, yw]^3 - 
     (2*G[{1}, yu^(-1)]*G[{1}, yw]*G[{1/(yu*yv)}, yw]^3)/3 - 
     (2*G[{1}, yv^(-1)]*G[{1}, yw]*G[{1/(yu*yv)}, yw]^3)/3 + 
     (G[{1}, yw]^2*G[{1/(yu*yv)}, yw]^3)/3 - 2*G[{0}, yu^(-1)]*
      G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]^3 - 2*G[{0}, yv^(-1)]*
      G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]^3 + 2*G[{0}, yw]*G[{yu^(-1)}, yw]*
      G[{1/(yu*yv)}, yw]^3 + (2*G[{1}, yu^(-1)]*G[{yu^(-1)}, yw]*
       G[{1/(yu*yv)}, yw]^3)/3 + 4*G[{1}, yv^(-1)]*G[{yu^(-1)}, yw]*
      G[{1/(yu*yv)}, yw]^3 + (2*G[{1}, yw]*G[{yu^(-1)}, yw]*
       G[{1/(yu*yv)}, yw]^3)/3 - 2*G[{yu^(-1)}, yw]^2*G[{1/(yu*yv)}, yw]^3 - 
     G[{0}, yu^(-1)]*G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw]^3 - 
     G[{0}, yv^(-1)]*G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw]^3 + 
     G[{0}, yw]*G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw]^3 + 
     (2*G[{1}, yu^(-1)]*G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw]^3)/3 + 
     (2*G[{1}, yv^(-1)]*G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw]^3)/3 - 
     (2*G[{1}, yw]*G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw]^3)/3 - 
     (2*G[{yu^(-1)}, yw]*G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw]^3)/3 + 
     (G[{yu}, yv^(-1)]^2*G[{1/(yu*yv)}, yw]^3)/3 + 
     G[{0}, yu^(-1)]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]^3 + 
     G[{0}, yv^(-1)]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]^3 - 
     G[{0}, yw]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]^3 - 
     2*G[{1}, yu^(-1)]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]^3 + 
     (2*G[{1}, yv^(-1)]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]^3)/3 + 
     (2*G[{1}, yw]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]^3)/3 - 
     (2*G[{yu^(-1)}, yw]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]^3)/3 - 
     (2*G[{yu}, yv^(-1)]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]^3)/3 + 
     G[{yv^(-1)}, yw]^2*G[{1/(yu*yv)}, yw]^3 - Pi^2*G[{1}, yw]*
      G[{0, 1}, yu^(-1)] + G[{1}, yu^(-1)]^2*G[{1}, yw]*G[{0, 1}, yu^(-1)] - 
     2*G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*G[{1}, yw]*G[{0, 1}, yu^(-1)] - 
     2*G[{0}, yu^(-1)]*G[{1}, yw]^2*G[{0, 1}, yu^(-1)] - 
     2*G[{0}, yv^(-1)]*G[{1}, yw]^2*G[{0, 1}, yu^(-1)] + 
     2*G[{0}, yw]*G[{1}, yw]^2*G[{0, 1}, yu^(-1)] + 
     3*G[{1}, yu^(-1)]*G[{1}, yw]^2*G[{0, 1}, yu^(-1)] + 
     2*G[{1}, yv^(-1)]*G[{1}, yw]^2*G[{0, 1}, yu^(-1)] + 
     (G[{1}, yw]^3*G[{0, 1}, yu^(-1)])/3 - G[{1}, yu^(-1)]^2*G[{yu^(-1)}, yw]*
      G[{0, 1}, yu^(-1)] + 2*G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*G[{yu^(-1)}, yw]*
      G[{0, 1}, yu^(-1)] + 2*G[{0}, yu^(-1)]*G[{1}, yw]*G[{yu^(-1)}, yw]*
      G[{0, 1}, yu^(-1)] + 2*G[{0}, yv^(-1)]*G[{1}, yw]*G[{yu^(-1)}, yw]*
      G[{0, 1}, yu^(-1)] - 2*G[{0}, yw]*G[{1}, yw]*G[{yu^(-1)}, yw]*
      G[{0, 1}, yu^(-1)] - 2*G[{1}, yu^(-1)]*G[{1}, yw]*G[{yu^(-1)}, yw]*
      G[{0, 1}, yu^(-1)] + G[{1}, yw]^2*G[{yu^(-1)}, yw]*G[{0, 1}, yu^(-1)] - 
     G[{1}, yw]^2*G[{yu}, yv^(-1)]*G[{0, 1}, yu^(-1)] - 
     2*G[{1}, yw]*G[{yu^(-1)}, yw]*G[{yu}, yv^(-1)]*G[{0, 1}, yu^(-1)] + 
     Pi^2*G[{yv^(-1)}, yw]*G[{0, 1}, yu^(-1)] - G[{1}, yu^(-1)]^2*
      G[{yv^(-1)}, yw]*G[{0, 1}, yu^(-1)] + 2*G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*
      G[{yv^(-1)}, yw]*G[{0, 1}, yu^(-1)] + 4*G[{0}, yu^(-1)]*G[{1}, yw]*
      G[{yv^(-1)}, yw]*G[{0, 1}, yu^(-1)] + 4*G[{0}, yv^(-1)]*G[{1}, yw]*
      G[{yv^(-1)}, yw]*G[{0, 1}, yu^(-1)] - 4*G[{0}, yw]*G[{1}, yw]*
      G[{yv^(-1)}, yw]*G[{0, 1}, yu^(-1)] - 6*G[{1}, yu^(-1)]*G[{1}, yw]*
      G[{yv^(-1)}, yw]*G[{0, 1}, yu^(-1)] - 4*G[{1}, yv^(-1)]*G[{1}, yw]*
      G[{yv^(-1)}, yw]*G[{0, 1}, yu^(-1)] - G[{1}, yw]^2*G[{yv^(-1)}, yw]*
      G[{0, 1}, yu^(-1)] - 2*G[{0}, yu^(-1)]*G[{yu^(-1)}, yw]*
      G[{yv^(-1)}, yw]*G[{0, 1}, yu^(-1)] - 2*G[{0}, yv^(-1)]*
      G[{yu^(-1)}, yw]*G[{yv^(-1)}, yw]*G[{0, 1}, yu^(-1)] + 
     2*G[{0}, yw]*G[{yu^(-1)}, yw]*G[{yv^(-1)}, yw]*G[{0, 1}, yu^(-1)] + 
     4*G[{1}, yu^(-1)]*G[{yu^(-1)}, yw]*G[{yv^(-1)}, yw]*G[{0, 1}, yu^(-1)] + 
     2*G[{1}, yw]*G[{yu}, yv^(-1)]*G[{yv^(-1)}, yw]*G[{0, 1}, yu^(-1)] - 
     2*G[{0}, yu^(-1)]*G[{yv^(-1)}, yw]^2*G[{0, 1}, yu^(-1)] - 
     2*G[{0}, yv^(-1)]*G[{yv^(-1)}, yw]^2*G[{0, 1}, yu^(-1)] + 
     2*G[{0}, yw]*G[{yv^(-1)}, yw]^2*G[{0, 1}, yu^(-1)] + 
     2*G[{1}, yu^(-1)]*G[{yv^(-1)}, yw]^2*G[{0, 1}, yu^(-1)] + 
     2*G[{1}, yv^(-1)]*G[{yv^(-1)}, yw]^2*G[{0, 1}, yu^(-1)] - 
     2*G[{yu^(-1)}, yw]*G[{yv^(-1)}, yw]^2*G[{0, 1}, yu^(-1)] - 
     (2*G[{yv^(-1)}, yw]^3*G[{0, 1}, yu^(-1)])/3 + 
     G[{1}, yu^(-1)]^2*G[{1/(yu*yv)}, yw]*G[{0, 1}, yu^(-1)] - 
     2*G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*G[{1/(yu*yv)}, yw]*
      G[{0, 1}, yu^(-1)] - 2*G[{0}, yu^(-1)]*G[{1}, yw]*G[{1/(yu*yv)}, yw]*
      G[{0, 1}, yu^(-1)] - 2*G[{0}, yv^(-1)]*G[{1}, yw]*G[{1/(yu*yv)}, yw]*
      G[{0, 1}, yu^(-1)] + 2*G[{0}, yw]*G[{1}, yw]*G[{1/(yu*yv)}, yw]*
      G[{0, 1}, yu^(-1)] + 2*G[{1}, yu^(-1)]*G[{1}, yw]*G[{1/(yu*yv)}, yw]*
      G[{0, 1}, yu^(-1)] - G[{1}, yw]^2*G[{1/(yu*yv)}, yw]*
      G[{0, 1}, yu^(-1)] + 2*G[{1}, yw]*G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw]*
      G[{0, 1}, yu^(-1)] + 2*G[{0}, yu^(-1)]*G[{yv^(-1)}, yw]*
      G[{1/(yu*yv)}, yw]*G[{0, 1}, yu^(-1)] + 2*G[{0}, yv^(-1)]*
      G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1}, yu^(-1)] - 
     2*G[{0}, yw]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1}, yu^(-1)] - 
     4*G[{1}, yu^(-1)]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*
      G[{0, 1}, yu^(-1)] + 2*G[{yv^(-1)}, yw]^2*G[{1/(yu*yv)}, yw]*
      G[{0, 1}, yu^(-1)] + G[{1}, yu^(-1)]*G[{1/(yu*yv)}, yw]^2*
      G[{0, 1}, yu^(-1)] + G[{1}, yw]*G[{1/(yu*yv)}, yw]^2*
      G[{0, 1}, yu^(-1)] - G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw]^2*
      G[{0, 1}, yu^(-1)] - G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2*
      G[{0, 1}, yu^(-1)] - G[{1}, yw]*G[{0, 1}, yu^(-1)]^2 + 
     G[{yv^(-1)}, yw]*G[{0, 1}, yu^(-1)]^2 - 
     (Pi^2*G[{1}, yw]*G[{0, 1}, yv^(-1)])/3 - 2*G[{1}, yu^(-1)]*
      G[{1}, yv^(-1)]*G[{1}, yw]*G[{0, 1}, yv^(-1)] + 
     G[{1}, yu^(-1)]*G[{1}, yw]^2*G[{0, 1}, yv^(-1)] + 
     (G[{1}, yw]^3*G[{0, 1}, yv^(-1)])/3 - 
     (2*Pi^2*G[{yu^(-1)}, yw]*G[{0, 1}, yv^(-1)])/3 + 
     2*G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*G[{yu^(-1)}, yw]*G[{0, 1}, yv^(-1)] - 
     2*G[{0}, yu^(-1)]*G[{1}, yw]*G[{yu^(-1)}, yw]*G[{0, 1}, yv^(-1)] - 
     2*G[{0}, yv^(-1)]*G[{1}, yw]*G[{yu^(-1)}, yw]*G[{0, 1}, yv^(-1)] + 
     2*G[{0}, yw]*G[{1}, yw]*G[{yu^(-1)}, yw]*G[{0, 1}, yv^(-1)] + 
     2*G[{1}, yu^(-1)]*G[{1}, yw]*G[{yu^(-1)}, yw]*G[{0, 1}, yv^(-1)] + 
     4*G[{1}, yv^(-1)]*G[{1}, yw]*G[{yu^(-1)}, yw]*G[{0, 1}, yv^(-1)] + 
     G[{1}, yw]^2*G[{yu^(-1)}, yw]*G[{0, 1}, yv^(-1)] + 
     2*G[{0}, yu^(-1)]*G[{yu^(-1)}, yw]^2*G[{0, 1}, yv^(-1)] + 
     2*G[{0}, yv^(-1)]*G[{yu^(-1)}, yw]^2*G[{0, 1}, yv^(-1)] - 
     2*G[{0}, yw]*G[{yu^(-1)}, yw]^2*G[{0, 1}, yv^(-1)] - 
     2*G[{1}, yu^(-1)]*G[{yu^(-1)}, yw]^2*G[{0, 1}, yv^(-1)] - 
     2*G[{1}, yv^(-1)]*G[{yu^(-1)}, yw]^2*G[{0, 1}, yv^(-1)] + 
     (2*G[{yu^(-1)}, yw]^3*G[{0, 1}, yv^(-1)])/3 - 
     G[{1}, yw]^2*G[{yu}, yv^(-1)]*G[{0, 1}, yv^(-1)] - 
     2*G[{1}, yw]*G[{yu^(-1)}, yw]*G[{yu}, yv^(-1)]*G[{0, 1}, yv^(-1)] + 
     (Pi^2*G[{yv^(-1)}, yw]*G[{0, 1}, yv^(-1)])/3 + 
     2*G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*G[{yv^(-1)}, yw]*G[{0, 1}, yv^(-1)] - 
     2*G[{1}, yu^(-1)]*G[{1}, yw]*G[{yv^(-1)}, yw]*G[{0, 1}, yv^(-1)] - 
     G[{1}, yw]^2*G[{yv^(-1)}, yw]*G[{0, 1}, yv^(-1)] + 
     2*G[{0}, yu^(-1)]*G[{yu^(-1)}, yw]*G[{yv^(-1)}, yw]*G[{0, 1}, yv^(-1)] + 
     2*G[{0}, yv^(-1)]*G[{yu^(-1)}, yw]*G[{yv^(-1)}, yw]*G[{0, 1}, yv^(-1)] - 
     2*G[{0}, yw]*G[{yu^(-1)}, yw]*G[{yv^(-1)}, yw]*G[{0, 1}, yv^(-1)] - 
     4*G[{1}, yv^(-1)]*G[{yu^(-1)}, yw]*G[{yv^(-1)}, yw]*G[{0, 1}, yv^(-1)] + 
     2*G[{yu^(-1)}, yw]^2*G[{yv^(-1)}, yw]*G[{0, 1}, yv^(-1)] + 
     2*G[{1}, yw]*G[{yu}, yv^(-1)]*G[{yv^(-1)}, yw]*G[{0, 1}, yv^(-1)] + 
     (2*Pi^2*G[{1/(yu*yv)}, yw]*G[{0, 1}, yv^(-1)])/3 - 
     2*G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*G[{1/(yu*yv)}, yw]*
      G[{0, 1}, yv^(-1)] + 2*G[{0}, yu^(-1)]*G[{1}, yw]*G[{1/(yu*yv)}, yw]*
      G[{0, 1}, yv^(-1)] + 2*G[{0}, yv^(-1)]*G[{1}, yw]*G[{1/(yu*yv)}, yw]*
      G[{0, 1}, yv^(-1)] - 2*G[{0}, yw]*G[{1}, yw]*G[{1/(yu*yv)}, yw]*
      G[{0, 1}, yv^(-1)] - 2*G[{1}, yu^(-1)]*G[{1}, yw]*G[{1/(yu*yv)}, yw]*
      G[{0, 1}, yv^(-1)] - 4*G[{1}, yv^(-1)]*G[{1}, yw]*G[{1/(yu*yv)}, yw]*
      G[{0, 1}, yv^(-1)] - G[{1}, yw]^2*G[{1/(yu*yv)}, yw]*
      G[{0, 1}, yv^(-1)] - 4*G[{0}, yu^(-1)]*G[{yu^(-1)}, yw]*
      G[{1/(yu*yv)}, yw]*G[{0, 1}, yv^(-1)] - 4*G[{0}, yv^(-1)]*
      G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1}, yv^(-1)] + 
     4*G[{0}, yw]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1}, yv^(-1)] + 
     4*G[{1}, yu^(-1)]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*
      G[{0, 1}, yv^(-1)] + 4*G[{1}, yv^(-1)]*G[{yu^(-1)}, yw]*
      G[{1/(yu*yv)}, yw]*G[{0, 1}, yv^(-1)] - 2*G[{yu^(-1)}, yw]^2*
      G[{1/(yu*yv)}, yw]*G[{0, 1}, yv^(-1)] + 2*G[{1}, yw]*G[{yu}, yv^(-1)]*
      G[{1/(yu*yv)}, yw]*G[{0, 1}, yv^(-1)] - 2*G[{0}, yu^(-1)]*
      G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1}, yv^(-1)] - 
     2*G[{0}, yv^(-1)]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*
      G[{0, 1}, yv^(-1)] + 2*G[{0}, yw]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*
      G[{0, 1}, yv^(-1)] + 4*G[{1}, yv^(-1)]*G[{yv^(-1)}, yw]*
      G[{1/(yu*yv)}, yw]*G[{0, 1}, yv^(-1)] - 4*G[{yu^(-1)}, yw]*
      G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1}, yv^(-1)] + 
     2*G[{0}, yu^(-1)]*G[{1/(yu*yv)}, yw]^2*G[{0, 1}, yv^(-1)] + 
     2*G[{0}, yv^(-1)]*G[{1/(yu*yv)}, yw]^2*G[{0, 1}, yv^(-1)] - 
     2*G[{0}, yw]*G[{1/(yu*yv)}, yw]^2*G[{0, 1}, yv^(-1)] - 
     G[{1}, yu^(-1)]*G[{1/(yu*yv)}, yw]^2*G[{0, 1}, yv^(-1)] - 
     2*G[{1}, yv^(-1)]*G[{1/(yu*yv)}, yw]^2*G[{0, 1}, yv^(-1)] + 
     G[{1}, yw]*G[{1/(yu*yv)}, yw]^2*G[{0, 1}, yv^(-1)] + 
     2*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2*G[{0, 1}, yv^(-1)] - 
     G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw]^2*G[{0, 1}, yv^(-1)] + 
     G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2*G[{0, 1}, yv^(-1)] - 
     2*G[{1}, yw]*G[{0, 1}, yu^(-1)]*G[{0, 1}, yv^(-1)] + 
     2*G[{yv^(-1)}, yw]*G[{0, 1}, yu^(-1)]*G[{0, 1}, yv^(-1)] - 
     G[{1}, yw]*G[{0, 1}, yv^(-1)]^2 + G[{yv^(-1)}, yw]*
      G[{0, 1}, yv^(-1)]^2 - (4*Pi^2*G[{1}, yw]*G[{0, 1}, yw])/3 + 
     2*G[{1}, yu^(-1)]^2*G[{1}, yw]*G[{0, 1}, yw] - 
     4*G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*G[{1}, yw]*G[{0, 1}, yw] - 
     G[{0}, yu^(-1)]*G[{1}, yw]^2*G[{0, 1}, yw] - 
     G[{0}, yv^(-1)]*G[{1}, yw]^2*G[{0, 1}, yw] + G[{0}, yw]*G[{1}, yw]^2*
      G[{0, 1}, yw] + 2*G[{1}, yu^(-1)]*G[{1}, yw]^2*G[{0, 1}, yw] + 
     G[{1}, yv^(-1)]*G[{1}, yw]^2*G[{0, 1}, yw] + 
     (G[{1}, yw]^3*G[{0, 1}, yw])/3 + (Pi^2*G[{yu^(-1)}, yw]*G[{0, 1}, yw])/
      3 - 2*G[{1}, yu^(-1)]^2*G[{yu^(-1)}, yw]*G[{0, 1}, yw] + 
     4*G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*G[{yu^(-1)}, yw]*G[{0, 1}, yw] + 
     4*G[{1}, yu^(-1)]*G[{1}, yw]*G[{yu^(-1)}, yw]*G[{0, 1}, yw] - 
     2*G[{1}, yv^(-1)]*G[{1}, yw]*G[{yu^(-1)}, yw]*G[{0, 1}, yw] + 
     G[{1}, yw]^2*G[{yu^(-1)}, yw]*G[{0, 1}, yw] + 
     G[{0}, yu^(-1)]*G[{yu^(-1)}, yw]^2*G[{0, 1}, yw] + 
     G[{0}, yv^(-1)]*G[{yu^(-1)}, yw]^2*G[{0, 1}, yw] - 
     G[{0}, yw]*G[{yu^(-1)}, yw]^2*G[{0, 1}, yw] - 
     5*G[{1}, yu^(-1)]*G[{yu^(-1)}, yw]^2*G[{0, 1}, yw] + 
     3*G[{1}, yv^(-1)]*G[{yu^(-1)}, yw]^2*G[{0, 1}, yw] + 
     3*G[{1}, yw]*G[{yu^(-1)}, yw]^2*G[{0, 1}, yw] - 
     (8*G[{yu^(-1)}, yw]^3*G[{0, 1}, yw])/3 - G[{1}, yw]^2*G[{yu}, yv^(-1)]*
      G[{0, 1}, yw] - 2*G[{1}, yw]*G[{yu^(-1)}, yw]*G[{yu}, yv^(-1)]*
      G[{0, 1}, yw] + (4*Pi^2*G[{yv^(-1)}, yw]*G[{0, 1}, yw])/3 - 
     2*G[{1}, yu^(-1)]^2*G[{yv^(-1)}, yw]*G[{0, 1}, yw] + 
     4*G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*G[{yv^(-1)}, yw]*G[{0, 1}, yw] + 
     2*G[{0}, yu^(-1)]*G[{1}, yw]*G[{yv^(-1)}, yw]*G[{0, 1}, yw] + 
     2*G[{0}, yv^(-1)]*G[{1}, yw]*G[{yv^(-1)}, yw]*G[{0, 1}, yw] - 
     2*G[{0}, yw]*G[{1}, yw]*G[{yv^(-1)}, yw]*G[{0, 1}, yw] - 
     4*G[{1}, yu^(-1)]*G[{1}, yw]*G[{yv^(-1)}, yw]*G[{0, 1}, yw] - 
     2*G[{1}, yv^(-1)]*G[{1}, yw]*G[{yv^(-1)}, yw]*G[{0, 1}, yw] - 
     G[{1}, yw]^2*G[{yv^(-1)}, yw]*G[{0, 1}, yw] - 
     2*G[{1}, yu^(-1)]*G[{yu^(-1)}, yw]*G[{yv^(-1)}, yw]*G[{0, 1}, yw] + 
     2*G[{1}, yv^(-1)]*G[{yu^(-1)}, yw]*G[{yv^(-1)}, yw]*G[{0, 1}, yw] - 
     2*G[{1}, yw]*G[{yu^(-1)}, yw]*G[{yv^(-1)}, yw]*G[{0, 1}, yw] + 
     2*G[{1}, yw]*G[{yu}, yv^(-1)]*G[{yv^(-1)}, yw]*G[{0, 1}, yw] - 
     G[{0}, yu^(-1)]*G[{yv^(-1)}, yw]^2*G[{0, 1}, yw] - 
     G[{0}, yv^(-1)]*G[{yv^(-1)}, yw]^2*G[{0, 1}, yw] + 
     G[{0}, yw]*G[{yv^(-1)}, yw]^2*G[{0, 1}, yw] + 
     G[{1}, yu^(-1)]*G[{yv^(-1)}, yw]^2*G[{0, 1}, yw] + 
     G[{1}, yv^(-1)]*G[{yv^(-1)}, yw]^2*G[{0, 1}, yw] - 
     G[{1}, yw]*G[{yv^(-1)}, yw]^2*G[{0, 1}, yw] + 
     2*G[{yu^(-1)}, yw]*G[{yv^(-1)}, yw]^2*G[{0, 1}, yw] + 
     (2*G[{yv^(-1)}, yw]^3*G[{0, 1}, yw])/3 - 
     (Pi^2*G[{1/(yu*yv)}, yw]*G[{0, 1}, yw])/3 + 2*G[{1}, yu^(-1)]^2*
      G[{1/(yu*yv)}, yw]*G[{0, 1}, yw] - 4*G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*
      G[{1/(yu*yv)}, yw]*G[{0, 1}, yw] - 4*G[{1}, yu^(-1)]*G[{1}, yw]*
      G[{1/(yu*yv)}, yw]*G[{0, 1}, yw] + 2*G[{1}, yv^(-1)]*G[{1}, yw]*
      G[{1/(yu*yv)}, yw]*G[{0, 1}, yw] - G[{1}, yw]^2*G[{1/(yu*yv)}, yw]*
      G[{0, 1}, yw] - 2*G[{0}, yu^(-1)]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*
      G[{0, 1}, yw] - 2*G[{0}, yv^(-1)]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*
      G[{0, 1}, yw] + 2*G[{0}, yw]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*
      G[{0, 1}, yw] + 10*G[{1}, yu^(-1)]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*
      G[{0, 1}, yw] - 6*G[{1}, yv^(-1)]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*
      G[{0, 1}, yw] - 6*G[{1}, yw]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*
      G[{0, 1}, yw] + 8*G[{yu^(-1)}, yw]^2*G[{1/(yu*yv)}, yw]*G[{0, 1}, yw] + 
     2*G[{1}, yw]*G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, 1}, yw] + 
     2*G[{1}, yu^(-1)]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1}, yw] - 
     2*G[{1}, yv^(-1)]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1}, yw] + 
     2*G[{1}, yw]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1}, yw] - 
     2*G[{yv^(-1)}, yw]^2*G[{1/(yu*yv)}, yw]*G[{0, 1}, yw] + 
     G[{0}, yu^(-1)]*G[{1/(yu*yv)}, yw]^2*G[{0, 1}, yw] + 
     G[{0}, yv^(-1)]*G[{1/(yu*yv)}, yw]^2*G[{0, 1}, yw] - 
     G[{0}, yw]*G[{1/(yu*yv)}, yw]^2*G[{0, 1}, yw] - 
     4*G[{1}, yu^(-1)]*G[{1/(yu*yv)}, yw]^2*G[{0, 1}, yw] + 
     3*G[{1}, yv^(-1)]*G[{1/(yu*yv)}, yw]^2*G[{0, 1}, yw] + 
     G[{1}, yw]*G[{1/(yu*yv)}, yw]^2*G[{0, 1}, yw] - 
     5*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2*G[{0, 1}, yw] - 
     G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw]^2*G[{0, 1}, yw] + 
     2*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2*G[{0, 1}, yw] - 
     4*G[{1}, yw]*G[{0, 1}, yu^(-1)]*G[{0, 1}, yw] + 
     2*G[{yu^(-1)}, yw]*G[{0, 1}, yu^(-1)]*G[{0, 1}, yw] + 
     4*G[{yv^(-1)}, yw]*G[{0, 1}, yu^(-1)]*G[{0, 1}, yw] - 
     2*G[{1/(yu*yv)}, yw]*G[{0, 1}, yu^(-1)]*G[{0, 1}, yw] - 
     2*G[{yu^(-1)}, yw]*G[{0, 1}, yv^(-1)]*G[{0, 1}, yw] + 
     2*G[{1/(yu*yv)}, yw]*G[{0, 1}, yv^(-1)]*G[{0, 1}, yw] - 
     G[{yu^(-1)}, yw]*G[{0, 1}, yw]^2 + G[{1/(yu*yv)}, yw]*G[{0, 1}, yw]^2 + 
     Pi^2*G[{1}, yw]*G[{0, yu^(-1)}, yw] - 2*G[{1}, yu^(-1)]^2*G[{1}, yw]*
      G[{0, yu^(-1)}, yw] + 4*G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*G[{1}, yw]*
      G[{0, yu^(-1)}, yw] + G[{0}, yu^(-1)]*G[{1}, yw]^2*
      G[{0, yu^(-1)}, yw] + G[{0}, yv^(-1)]*G[{1}, yw]^2*
      G[{0, yu^(-1)}, yw] - G[{0}, yw]*G[{1}, yw]^2*G[{0, yu^(-1)}, yw] - 
     2*G[{1}, yu^(-1)]*G[{1}, yw]^2*G[{0, yu^(-1)}, yw] - 
     G[{1}, yv^(-1)]*G[{1}, yw]^2*G[{0, yu^(-1)}, yw] - 
     (G[{1}, yw]^3*G[{0, yu^(-1)}, yw])/3 + 2*G[{1}, yu^(-1)]^2*
      G[{yu^(-1)}, yw]*G[{0, yu^(-1)}, yw] - 4*G[{1}, yu^(-1)]*
      G[{1}, yv^(-1)]*G[{yu^(-1)}, yw]*G[{0, yu^(-1)}, yw] - 
     4*G[{1}, yu^(-1)]*G[{1}, yw]*G[{yu^(-1)}, yw]*G[{0, yu^(-1)}, yw] + 
     2*G[{1}, yv^(-1)]*G[{1}, yw]*G[{yu^(-1)}, yw]*G[{0, yu^(-1)}, yw] - 
     G[{1}, yw]^2*G[{yu^(-1)}, yw]*G[{0, yu^(-1)}, yw] - 
     G[{0}, yu^(-1)]*G[{yu^(-1)}, yw]^2*G[{0, yu^(-1)}, yw] - 
     G[{0}, yv^(-1)]*G[{yu^(-1)}, yw]^2*G[{0, yu^(-1)}, yw] + 
     G[{0}, yw]*G[{yu^(-1)}, yw]^2*G[{0, yu^(-1)}, yw] + 
     5*G[{1}, yu^(-1)]*G[{yu^(-1)}, yw]^2*G[{0, yu^(-1)}, yw] - 
     3*G[{1}, yv^(-1)]*G[{yu^(-1)}, yw]^2*G[{0, yu^(-1)}, yw] - 
     3*G[{1}, yw]*G[{yu^(-1)}, yw]^2*G[{0, yu^(-1)}, yw] + 
     (8*G[{yu^(-1)}, yw]^3*G[{0, yu^(-1)}, yw])/3 + 
     G[{1}, yw]^2*G[{yu}, yv^(-1)]*G[{0, yu^(-1)}, yw] + 
     2*G[{1}, yw]*G[{yu^(-1)}, yw]*G[{yu}, yv^(-1)]*G[{0, yu^(-1)}, yw] - 
     Pi^2*G[{yv^(-1)}, yw]*G[{0, yu^(-1)}, yw] + 2*G[{1}, yu^(-1)]^2*
      G[{yv^(-1)}, yw]*G[{0, yu^(-1)}, yw] - 4*G[{1}, yu^(-1)]*
      G[{1}, yv^(-1)]*G[{yv^(-1)}, yw]*G[{0, yu^(-1)}, yw] - 
     2*G[{0}, yu^(-1)]*G[{1}, yw]*G[{yv^(-1)}, yw]*G[{0, yu^(-1)}, yw] - 
     2*G[{0}, yv^(-1)]*G[{1}, yw]*G[{yv^(-1)}, yw]*G[{0, yu^(-1)}, yw] + 
     2*G[{0}, yw]*G[{1}, yw]*G[{yv^(-1)}, yw]*G[{0, yu^(-1)}, yw] + 
     4*G[{1}, yu^(-1)]*G[{1}, yw]*G[{yv^(-1)}, yw]*G[{0, yu^(-1)}, yw] + 
     2*G[{1}, yv^(-1)]*G[{1}, yw]*G[{yv^(-1)}, yw]*G[{0, yu^(-1)}, yw] + 
     G[{1}, yw]^2*G[{yv^(-1)}, yw]*G[{0, yu^(-1)}, yw] + 
     2*G[{1}, yu^(-1)]*G[{yu^(-1)}, yw]*G[{yv^(-1)}, yw]*
      G[{0, yu^(-1)}, yw] - 2*G[{1}, yv^(-1)]*G[{yu^(-1)}, yw]*
      G[{yv^(-1)}, yw]*G[{0, yu^(-1)}, yw] + 2*G[{1}, yw]*G[{yu^(-1)}, yw]*
      G[{yv^(-1)}, yw]*G[{0, yu^(-1)}, yw] - 2*G[{1}, yw]*G[{yu}, yv^(-1)]*
      G[{yv^(-1)}, yw]*G[{0, yu^(-1)}, yw] + G[{0}, yu^(-1)]*
      G[{yv^(-1)}, yw]^2*G[{0, yu^(-1)}, yw] + G[{0}, yv^(-1)]*
      G[{yv^(-1)}, yw]^2*G[{0, yu^(-1)}, yw] - G[{0}, yw]*G[{yv^(-1)}, yw]^2*
      G[{0, yu^(-1)}, yw] - G[{1}, yu^(-1)]*G[{yv^(-1)}, yw]^2*
      G[{0, yu^(-1)}, yw] - G[{1}, yv^(-1)]*G[{yv^(-1)}, yw]^2*
      G[{0, yu^(-1)}, yw] + G[{1}, yw]*G[{yv^(-1)}, yw]^2*
      G[{0, yu^(-1)}, yw] - 2*G[{yu^(-1)}, yw]*G[{yv^(-1)}, yw]^2*
      G[{0, yu^(-1)}, yw] - (2*G[{yv^(-1)}, yw]^3*G[{0, yu^(-1)}, yw])/3 - 
     2*G[{1}, yu^(-1)]^2*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1)}, yw] + 
     4*G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*G[{1/(yu*yv)}, yw]*
      G[{0, yu^(-1)}, yw] + 4*G[{1}, yu^(-1)]*G[{1}, yw]*G[{1/(yu*yv)}, yw]*
      G[{0, yu^(-1)}, yw] - 2*G[{1}, yv^(-1)]*G[{1}, yw]*G[{1/(yu*yv)}, yw]*
      G[{0, yu^(-1)}, yw] + G[{1}, yw]^2*G[{1/(yu*yv)}, yw]*
      G[{0, yu^(-1)}, yw] + 2*G[{0}, yu^(-1)]*G[{yu^(-1)}, yw]*
      G[{1/(yu*yv)}, yw]*G[{0, yu^(-1)}, yw] + 2*G[{0}, yv^(-1)]*
      G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1)}, yw] - 
     2*G[{0}, yw]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1)}, yw] - 
     10*G[{1}, yu^(-1)]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*
      G[{0, yu^(-1)}, yw] + 6*G[{1}, yv^(-1)]*G[{yu^(-1)}, yw]*
      G[{1/(yu*yv)}, yw]*G[{0, yu^(-1)}, yw] + 6*G[{1}, yw]*G[{yu^(-1)}, yw]*
      G[{1/(yu*yv)}, yw]*G[{0, yu^(-1)}, yw] - 8*G[{yu^(-1)}, yw]^2*
      G[{1/(yu*yv)}, yw]*G[{0, yu^(-1)}, yw] - 2*G[{1}, yw]*G[{yu}, yv^(-1)]*
      G[{1/(yu*yv)}, yw]*G[{0, yu^(-1)}, yw] - 2*G[{1}, yu^(-1)]*
      G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1)}, yw] + 
     2*G[{1}, yv^(-1)]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*
      G[{0, yu^(-1)}, yw] - 2*G[{1}, yw]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*
      G[{0, yu^(-1)}, yw] + 2*G[{yv^(-1)}, yw]^2*G[{1/(yu*yv)}, yw]*
      G[{0, yu^(-1)}, yw] - G[{0}, yu^(-1)]*G[{1/(yu*yv)}, yw]^2*
      G[{0, yu^(-1)}, yw] - G[{0}, yv^(-1)]*G[{1/(yu*yv)}, yw]^2*
      G[{0, yu^(-1)}, yw] + G[{0}, yw]*G[{1/(yu*yv)}, yw]^2*
      G[{0, yu^(-1)}, yw] + 4*G[{1}, yu^(-1)]*G[{1/(yu*yv)}, yw]^2*
      G[{0, yu^(-1)}, yw] - 3*G[{1}, yv^(-1)]*G[{1/(yu*yv)}, yw]^2*
      G[{0, yu^(-1)}, yw] - G[{1}, yw]*G[{1/(yu*yv)}, yw]^2*
      G[{0, yu^(-1)}, yw] + 5*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2*
      G[{0, yu^(-1)}, yw] + G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw]^2*
      G[{0, yu^(-1)}, yw] - 2*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2*
      G[{0, yu^(-1)}, yw] + 2*G[{1}, yw]*G[{0, 1}, yu^(-1)]*
      G[{0, yu^(-1)}, yw] - 2*G[{yv^(-1)}, yw]*G[{0, 1}, yu^(-1)]*
      G[{0, yu^(-1)}, yw] - 2*G[{1}, yw]*G[{0, 1}, yv^(-1)]*
      G[{0, yu^(-1)}, yw] + 4*G[{yu^(-1)}, yw]*G[{0, 1}, yv^(-1)]*
      G[{0, yu^(-1)}, yw] + 2*G[{yv^(-1)}, yw]*G[{0, 1}, yv^(-1)]*
      G[{0, yu^(-1)}, yw] - 4*G[{1/(yu*yv)}, yw]*G[{0, 1}, yv^(-1)]*
      G[{0, yu^(-1)}, yw] + 2*G[{1}, yw]*G[{0, 1}, yw]*G[{0, yu^(-1)}, yw] - 
     2*G[{yv^(-1)}, yw]*G[{0, 1}, yw]*G[{0, yu^(-1)}, yw] - 
     G[{1}, yw]*G[{0, yu^(-1)}, yw]^2 + G[{yv^(-1)}, yw]*
      G[{0, yu^(-1)}, yw]^2 + 2*G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*G[{1}, yw]*
      G[{0, yu}, yv^(-1)] - G[{1}, yu^(-1)]*G[{1}, yw]^2*
      G[{0, yu}, yv^(-1)] - (G[{1}, yw]^3*G[{0, yu}, yv^(-1)])/3 + 
     Pi^2*G[{yu^(-1)}, yw]*G[{0, yu}, yv^(-1)] - 2*G[{1}, yu^(-1)]*
      G[{1}, yv^(-1)]*G[{yu^(-1)}, yw]*G[{0, yu}, yv^(-1)] + 
     2*G[{0}, yu^(-1)]*G[{1}, yw]*G[{yu^(-1)}, yw]*G[{0, yu}, yv^(-1)] + 
     2*G[{0}, yv^(-1)]*G[{1}, yw]*G[{yu^(-1)}, yw]*G[{0, yu}, yv^(-1)] - 
     2*G[{0}, yw]*G[{1}, yw]*G[{yu^(-1)}, yw]*G[{0, yu}, yv^(-1)] - 
     2*G[{1}, yu^(-1)]*G[{1}, yw]*G[{yu^(-1)}, yw]*G[{0, yu}, yv^(-1)] - 
     4*G[{1}, yv^(-1)]*G[{1}, yw]*G[{yu^(-1)}, yw]*G[{0, yu}, yv^(-1)] - 
     G[{1}, yw]^2*G[{yu^(-1)}, yw]*G[{0, yu}, yv^(-1)] - 
     2*G[{0}, yu^(-1)]*G[{yu^(-1)}, yw]^2*G[{0, yu}, yv^(-1)] - 
     2*G[{0}, yv^(-1)]*G[{yu^(-1)}, yw]^2*G[{0, yu}, yv^(-1)] + 
     2*G[{0}, yw]*G[{yu^(-1)}, yw]^2*G[{0, yu}, yv^(-1)] + 
     2*G[{1}, yu^(-1)]*G[{yu^(-1)}, yw]^2*G[{0, yu}, yv^(-1)] + 
     2*G[{1}, yv^(-1)]*G[{yu^(-1)}, yw]^2*G[{0, yu}, yv^(-1)] - 
     (2*G[{yu^(-1)}, yw]^3*G[{0, yu}, yv^(-1)])/3 + 
     G[{1}, yw]^2*G[{yu}, yv^(-1)]*G[{0, yu}, yv^(-1)] + 
     2*G[{1}, yw]*G[{yu^(-1)}, yw]*G[{yu}, yv^(-1)]*G[{0, yu}, yv^(-1)] - 
     2*G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*G[{yv^(-1)}, yw]*G[{0, yu}, yv^(-1)] + 
     2*G[{1}, yu^(-1)]*G[{1}, yw]*G[{yv^(-1)}, yw]*G[{0, yu}, yv^(-1)] + 
     G[{1}, yw]^2*G[{yv^(-1)}, yw]*G[{0, yu}, yv^(-1)] - 
     2*G[{0}, yu^(-1)]*G[{yu^(-1)}, yw]*G[{yv^(-1)}, yw]*
      G[{0, yu}, yv^(-1)] - 2*G[{0}, yv^(-1)]*G[{yu^(-1)}, yw]*
      G[{yv^(-1)}, yw]*G[{0, yu}, yv^(-1)] + 2*G[{0}, yw]*G[{yu^(-1)}, yw]*
      G[{yv^(-1)}, yw]*G[{0, yu}, yv^(-1)] + 4*G[{1}, yv^(-1)]*
      G[{yu^(-1)}, yw]*G[{yv^(-1)}, yw]*G[{0, yu}, yv^(-1)] - 
     2*G[{yu^(-1)}, yw]^2*G[{yv^(-1)}, yw]*G[{0, yu}, yv^(-1)] - 
     2*G[{1}, yw]*G[{yu}, yv^(-1)]*G[{yv^(-1)}, yw]*G[{0, yu}, yv^(-1)] - 
     Pi^2*G[{1/(yu*yv)}, yw]*G[{0, yu}, yv^(-1)] + 
     2*G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*G[{1/(yu*yv)}, yw]*
      G[{0, yu}, yv^(-1)] - 2*G[{0}, yu^(-1)]*G[{1}, yw]*G[{1/(yu*yv)}, yw]*
      G[{0, yu}, yv^(-1)] - 2*G[{0}, yv^(-1)]*G[{1}, yw]*G[{1/(yu*yv)}, yw]*
      G[{0, yu}, yv^(-1)] + 2*G[{0}, yw]*G[{1}, yw]*G[{1/(yu*yv)}, yw]*
      G[{0, yu}, yv^(-1)] + 2*G[{1}, yu^(-1)]*G[{1}, yw]*G[{1/(yu*yv)}, yw]*
      G[{0, yu}, yv^(-1)] + 4*G[{1}, yv^(-1)]*G[{1}, yw]*G[{1/(yu*yv)}, yw]*
      G[{0, yu}, yv^(-1)] + G[{1}, yw]^2*G[{1/(yu*yv)}, yw]*
      G[{0, yu}, yv^(-1)] + 4*G[{0}, yu^(-1)]*G[{yu^(-1)}, yw]*
      G[{1/(yu*yv)}, yw]*G[{0, yu}, yv^(-1)] + 4*G[{0}, yv^(-1)]*
      G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{0, yu}, yv^(-1)] - 
     4*G[{0}, yw]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{0, yu}, yv^(-1)] - 
     4*G[{1}, yu^(-1)]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*
      G[{0, yu}, yv^(-1)] - 4*G[{1}, yv^(-1)]*G[{yu^(-1)}, yw]*
      G[{1/(yu*yv)}, yw]*G[{0, yu}, yv^(-1)] + 2*G[{yu^(-1)}, yw]^2*
      G[{1/(yu*yv)}, yw]*G[{0, yu}, yv^(-1)] - 2*G[{1}, yw]*G[{yu}, yv^(-1)]*
      G[{1/(yu*yv)}, yw]*G[{0, yu}, yv^(-1)] + 2*G[{0}, yu^(-1)]*
      G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{0, yu}, yv^(-1)] + 
     2*G[{0}, yv^(-1)]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*
      G[{0, yu}, yv^(-1)] - 2*G[{0}, yw]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*
      G[{0, yu}, yv^(-1)] - 4*G[{1}, yv^(-1)]*G[{yv^(-1)}, yw]*
      G[{1/(yu*yv)}, yw]*G[{0, yu}, yv^(-1)] + 4*G[{yu^(-1)}, yw]*
      G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{0, yu}, yv^(-1)] - 
     2*G[{0}, yu^(-1)]*G[{1/(yu*yv)}, yw]^2*G[{0, yu}, yv^(-1)] - 
     2*G[{0}, yv^(-1)]*G[{1/(yu*yv)}, yw]^2*G[{0, yu}, yv^(-1)] + 
     2*G[{0}, yw]*G[{1/(yu*yv)}, yw]^2*G[{0, yu}, yv^(-1)] + 
     G[{1}, yu^(-1)]*G[{1/(yu*yv)}, yw]^2*G[{0, yu}, yv^(-1)] + 
     2*G[{1}, yv^(-1)]*G[{1/(yu*yv)}, yw]^2*G[{0, yu}, yv^(-1)] - 
     G[{1}, yw]*G[{1/(yu*yv)}, yw]^2*G[{0, yu}, yv^(-1)] - 
     2*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2*G[{0, yu}, yv^(-1)] + 
     G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw]^2*G[{0, yu}, yv^(-1)] - 
     G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2*G[{0, yu}, yv^(-1)] + 
     2*G[{yu^(-1)}, yw]*G[{0, 1}, yu^(-1)]*G[{0, yu}, yv^(-1)] - 
     2*G[{1/(yu*yv)}, yw]*G[{0, 1}, yu^(-1)]*G[{0, yu}, yv^(-1)] + 
     2*G[{yu^(-1)}, yw]*G[{0, 1}, yv^(-1)]*G[{0, yu}, yv^(-1)] - 
     2*G[{1/(yu*yv)}, yw]*G[{0, 1}, yv^(-1)]*G[{0, yu}, yv^(-1)] + 
     2*G[{yu^(-1)}, yw]*G[{0, 1}, yw]*G[{0, yu}, yv^(-1)] - 
     2*G[{1/(yu*yv)}, yw]*G[{0, 1}, yw]*G[{0, yu}, yv^(-1)] + 
     2*G[{1}, yw]*G[{0, yu^(-1)}, yw]*G[{0, yu}, yv^(-1)] - 
     4*G[{yu^(-1)}, yw]*G[{0, yu^(-1)}, yw]*G[{0, yu}, yv^(-1)] - 
     2*G[{yv^(-1)}, yw]*G[{0, yu^(-1)}, yw]*G[{0, yu}, yv^(-1)] + 
     4*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1)}, yw]*G[{0, yu}, yv^(-1)] - 
     G[{yu^(-1)}, yw]*G[{0, yu}, yv^(-1)]^2 + G[{1/(yu*yv)}, yw]*
      G[{0, yu}, yv^(-1)]^2 + (4*Pi^2*G[{1}, yw]*G[{0, yv^(-1)}, yw])/3 - 
     2*G[{1}, yu^(-1)]^2*G[{1}, yw]*G[{0, yv^(-1)}, yw] + 
     4*G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*G[{1}, yw]*G[{0, yv^(-1)}, yw] + 
     G[{0}, yu^(-1)]*G[{1}, yw]^2*G[{0, yv^(-1)}, yw] + 
     G[{0}, yv^(-1)]*G[{1}, yw]^2*G[{0, yv^(-1)}, yw] - 
     G[{0}, yw]*G[{1}, yw]^2*G[{0, yv^(-1)}, yw] - 
     2*G[{1}, yu^(-1)]*G[{1}, yw]^2*G[{0, yv^(-1)}, yw] - 
     G[{1}, yv^(-1)]*G[{1}, yw]^2*G[{0, yv^(-1)}, yw] - 
     (G[{1}, yw]^3*G[{0, yv^(-1)}, yw])/3 - 
     (Pi^2*G[{yu^(-1)}, yw]*G[{0, yv^(-1)}, yw])/3 + 
     2*G[{1}, yu^(-1)]^2*G[{yu^(-1)}, yw]*G[{0, yv^(-1)}, yw] - 
     4*G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*G[{yu^(-1)}, yw]*G[{0, yv^(-1)}, yw] - 
     4*G[{1}, yu^(-1)]*G[{1}, yw]*G[{yu^(-1)}, yw]*G[{0, yv^(-1)}, yw] + 
     2*G[{1}, yv^(-1)]*G[{1}, yw]*G[{yu^(-1)}, yw]*G[{0, yv^(-1)}, yw] - 
     G[{1}, yw]^2*G[{yu^(-1)}, yw]*G[{0, yv^(-1)}, yw] - 
     G[{0}, yu^(-1)]*G[{yu^(-1)}, yw]^2*G[{0, yv^(-1)}, yw] - 
     G[{0}, yv^(-1)]*G[{yu^(-1)}, yw]^2*G[{0, yv^(-1)}, yw] + 
     G[{0}, yw]*G[{yu^(-1)}, yw]^2*G[{0, yv^(-1)}, yw] + 
     5*G[{1}, yu^(-1)]*G[{yu^(-1)}, yw]^2*G[{0, yv^(-1)}, yw] - 
     3*G[{1}, yv^(-1)]*G[{yu^(-1)}, yw]^2*G[{0, yv^(-1)}, yw] - 
     3*G[{1}, yw]*G[{yu^(-1)}, yw]^2*G[{0, yv^(-1)}, yw] + 
     (8*G[{yu^(-1)}, yw]^3*G[{0, yv^(-1)}, yw])/3 + 
     G[{1}, yw]^2*G[{yu}, yv^(-1)]*G[{0, yv^(-1)}, yw] + 
     2*G[{1}, yw]*G[{yu^(-1)}, yw]*G[{yu}, yv^(-1)]*G[{0, yv^(-1)}, yw] - 
     (4*Pi^2*G[{yv^(-1)}, yw]*G[{0, yv^(-1)}, yw])/3 + 
     2*G[{1}, yu^(-1)]^2*G[{yv^(-1)}, yw]*G[{0, yv^(-1)}, yw] - 
     4*G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*G[{yv^(-1)}, yw]*G[{0, yv^(-1)}, yw] - 
     2*G[{0}, yu^(-1)]*G[{1}, yw]*G[{yv^(-1)}, yw]*G[{0, yv^(-1)}, yw] - 
     2*G[{0}, yv^(-1)]*G[{1}, yw]*G[{yv^(-1)}, yw]*G[{0, yv^(-1)}, yw] + 
     2*G[{0}, yw]*G[{1}, yw]*G[{yv^(-1)}, yw]*G[{0, yv^(-1)}, yw] + 
     4*G[{1}, yu^(-1)]*G[{1}, yw]*G[{yv^(-1)}, yw]*G[{0, yv^(-1)}, yw] + 
     2*G[{1}, yv^(-1)]*G[{1}, yw]*G[{yv^(-1)}, yw]*G[{0, yv^(-1)}, yw] + 
     G[{1}, yw]^2*G[{yv^(-1)}, yw]*G[{0, yv^(-1)}, yw] + 
     2*G[{1}, yu^(-1)]*G[{yu^(-1)}, yw]*G[{yv^(-1)}, yw]*
      G[{0, yv^(-1)}, yw] - 2*G[{1}, yv^(-1)]*G[{yu^(-1)}, yw]*
      G[{yv^(-1)}, yw]*G[{0, yv^(-1)}, yw] + 2*G[{1}, yw]*G[{yu^(-1)}, yw]*
      G[{yv^(-1)}, yw]*G[{0, yv^(-1)}, yw] - 2*G[{1}, yw]*G[{yu}, yv^(-1)]*
      G[{yv^(-1)}, yw]*G[{0, yv^(-1)}, yw] + G[{0}, yu^(-1)]*
      G[{yv^(-1)}, yw]^2*G[{0, yv^(-1)}, yw] + G[{0}, yv^(-1)]*
      G[{yv^(-1)}, yw]^2*G[{0, yv^(-1)}, yw] - G[{0}, yw]*G[{yv^(-1)}, yw]^2*
      G[{0, yv^(-1)}, yw] - G[{1}, yu^(-1)]*G[{yv^(-1)}, yw]^2*
      G[{0, yv^(-1)}, yw] - G[{1}, yv^(-1)]*G[{yv^(-1)}, yw]^2*
      G[{0, yv^(-1)}, yw] + G[{1}, yw]*G[{yv^(-1)}, yw]^2*
      G[{0, yv^(-1)}, yw] - 2*G[{yu^(-1)}, yw]*G[{yv^(-1)}, yw]^2*
      G[{0, yv^(-1)}, yw] - (2*G[{yv^(-1)}, yw]^3*G[{0, yv^(-1)}, yw])/3 + 
     (Pi^2*G[{1/(yu*yv)}, yw]*G[{0, yv^(-1)}, yw])/3 - 
     2*G[{1}, yu^(-1)]^2*G[{1/(yu*yv)}, yw]*G[{0, yv^(-1)}, yw] + 
     4*G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*G[{1/(yu*yv)}, yw]*
      G[{0, yv^(-1)}, yw] + 4*G[{1}, yu^(-1)]*G[{1}, yw]*G[{1/(yu*yv)}, yw]*
      G[{0, yv^(-1)}, yw] - 2*G[{1}, yv^(-1)]*G[{1}, yw]*G[{1/(yu*yv)}, yw]*
      G[{0, yv^(-1)}, yw] + G[{1}, yw]^2*G[{1/(yu*yv)}, yw]*
      G[{0, yv^(-1)}, yw] + 2*G[{0}, yu^(-1)]*G[{yu^(-1)}, yw]*
      G[{1/(yu*yv)}, yw]*G[{0, yv^(-1)}, yw] + 2*G[{0}, yv^(-1)]*
      G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{0, yv^(-1)}, yw] - 
     2*G[{0}, yw]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{0, yv^(-1)}, yw] - 
     10*G[{1}, yu^(-1)]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*
      G[{0, yv^(-1)}, yw] + 6*G[{1}, yv^(-1)]*G[{yu^(-1)}, yw]*
      G[{1/(yu*yv)}, yw]*G[{0, yv^(-1)}, yw] + 6*G[{1}, yw]*G[{yu^(-1)}, yw]*
      G[{1/(yu*yv)}, yw]*G[{0, yv^(-1)}, yw] - 8*G[{yu^(-1)}, yw]^2*
      G[{1/(yu*yv)}, yw]*G[{0, yv^(-1)}, yw] - 2*G[{1}, yw]*G[{yu}, yv^(-1)]*
      G[{1/(yu*yv)}, yw]*G[{0, yv^(-1)}, yw] - 2*G[{1}, yu^(-1)]*
      G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{0, yv^(-1)}, yw] + 
     2*G[{1}, yv^(-1)]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*
      G[{0, yv^(-1)}, yw] - 2*G[{1}, yw]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*
      G[{0, yv^(-1)}, yw] + 2*G[{yv^(-1)}, yw]^2*G[{1/(yu*yv)}, yw]*
      G[{0, yv^(-1)}, yw] - G[{0}, yu^(-1)]*G[{1/(yu*yv)}, yw]^2*
      G[{0, yv^(-1)}, yw] - G[{0}, yv^(-1)]*G[{1/(yu*yv)}, yw]^2*
      G[{0, yv^(-1)}, yw] + G[{0}, yw]*G[{1/(yu*yv)}, yw]^2*
      G[{0, yv^(-1)}, yw] + 4*G[{1}, yu^(-1)]*G[{1/(yu*yv)}, yw]^2*
      G[{0, yv^(-1)}, yw] - 3*G[{1}, yv^(-1)]*G[{1/(yu*yv)}, yw]^2*
      G[{0, yv^(-1)}, yw] - G[{1}, yw]*G[{1/(yu*yv)}, yw]^2*
      G[{0, yv^(-1)}, yw] + 5*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2*
      G[{0, yv^(-1)}, yw] + G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw]^2*
      G[{0, yv^(-1)}, yw] - 2*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2*
      G[{0, yv^(-1)}, yw] + 4*G[{1}, yw]*G[{0, 1}, yu^(-1)]*
      G[{0, yv^(-1)}, yw] - 2*G[{yu^(-1)}, yw]*G[{0, 1}, yu^(-1)]*
      G[{0, yv^(-1)}, yw] - 4*G[{yv^(-1)}, yw]*G[{0, 1}, yu^(-1)]*
      G[{0, yv^(-1)}, yw] + 2*G[{1/(yu*yv)}, yw]*G[{0, 1}, yu^(-1)]*
      G[{0, yv^(-1)}, yw] + 2*G[{yu^(-1)}, yw]*G[{0, 1}, yv^(-1)]*
      G[{0, yv^(-1)}, yw] - 2*G[{1/(yu*yv)}, yw]*G[{0, 1}, yv^(-1)]*
      G[{0, yv^(-1)}, yw] + 2*G[{yu^(-1)}, yw]*G[{0, 1}, yw]*
      G[{0, yv^(-1)}, yw] - 2*G[{1/(yu*yv)}, yw]*G[{0, 1}, yw]*
      G[{0, yv^(-1)}, yw] - 2*G[{yu^(-1)}, yw]*G[{0, yu^(-1)}, yw]*
      G[{0, yv^(-1)}, yw] + 2*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1)}, yw]*
      G[{0, yv^(-1)}, yw] - 2*G[{yu^(-1)}, yw]*G[{0, yu}, yv^(-1)]*
      G[{0, yv^(-1)}, yw] + 2*G[{1/(yu*yv)}, yw]*G[{0, yu}, yv^(-1)]*
      G[{0, yv^(-1)}, yw] - G[{yu^(-1)}, yw]*G[{0, yv^(-1)}, yw]^2 + 
     G[{1/(yu*yv)}, yw]*G[{0, yv^(-1)}, yw]^2 - Pi^2*G[{1}, yw]*
      G[{0, 1/(yu*yv)}, yw] + 2*G[{1}, yu^(-1)]^2*G[{1}, yw]*
      G[{0, 1/(yu*yv)}, yw] - 4*G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*G[{1}, yw]*
      G[{0, 1/(yu*yv)}, yw] - G[{0}, yu^(-1)]*G[{1}, yw]^2*
      G[{0, 1/(yu*yv)}, yw] - G[{0}, yv^(-1)]*G[{1}, yw]^2*
      G[{0, 1/(yu*yv)}, yw] + G[{0}, yw]*G[{1}, yw]^2*G[{0, 1/(yu*yv)}, yw] + 
     2*G[{1}, yu^(-1)]*G[{1}, yw]^2*G[{0, 1/(yu*yv)}, yw] + 
     G[{1}, yv^(-1)]*G[{1}, yw]^2*G[{0, 1/(yu*yv)}, yw] + 
     (G[{1}, yw]^3*G[{0, 1/(yu*yv)}, yw])/3 - 2*G[{1}, yu^(-1)]^2*
      G[{yu^(-1)}, yw]*G[{0, 1/(yu*yv)}, yw] + 4*G[{1}, yu^(-1)]*
      G[{1}, yv^(-1)]*G[{yu^(-1)}, yw]*G[{0, 1/(yu*yv)}, yw] + 
     4*G[{1}, yu^(-1)]*G[{1}, yw]*G[{yu^(-1)}, yw]*G[{0, 1/(yu*yv)}, yw] - 
     2*G[{1}, yv^(-1)]*G[{1}, yw]*G[{yu^(-1)}, yw]*G[{0, 1/(yu*yv)}, yw] + 
     G[{1}, yw]^2*G[{yu^(-1)}, yw]*G[{0, 1/(yu*yv)}, yw] + 
     G[{0}, yu^(-1)]*G[{yu^(-1)}, yw]^2*G[{0, 1/(yu*yv)}, yw] + 
     G[{0}, yv^(-1)]*G[{yu^(-1)}, yw]^2*G[{0, 1/(yu*yv)}, yw] - 
     G[{0}, yw]*G[{yu^(-1)}, yw]^2*G[{0, 1/(yu*yv)}, yw] - 
     5*G[{1}, yu^(-1)]*G[{yu^(-1)}, yw]^2*G[{0, 1/(yu*yv)}, yw] + 
     3*G[{1}, yv^(-1)]*G[{yu^(-1)}, yw]^2*G[{0, 1/(yu*yv)}, yw] + 
     3*G[{1}, yw]*G[{yu^(-1)}, yw]^2*G[{0, 1/(yu*yv)}, yw] - 
     (8*G[{yu^(-1)}, yw]^3*G[{0, 1/(yu*yv)}, yw])/3 - 
     G[{1}, yw]^2*G[{yu}, yv^(-1)]*G[{0, 1/(yu*yv)}, yw] - 
     2*G[{1}, yw]*G[{yu^(-1)}, yw]*G[{yu}, yv^(-1)]*G[{0, 1/(yu*yv)}, yw] + 
     Pi^2*G[{yv^(-1)}, yw]*G[{0, 1/(yu*yv)}, yw] - 
     2*G[{1}, yu^(-1)]^2*G[{yv^(-1)}, yw]*G[{0, 1/(yu*yv)}, yw] + 
     4*G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*G[{yv^(-1)}, yw]*
      G[{0, 1/(yu*yv)}, yw] + 2*G[{0}, yu^(-1)]*G[{1}, yw]*G[{yv^(-1)}, yw]*
      G[{0, 1/(yu*yv)}, yw] + 2*G[{0}, yv^(-1)]*G[{1}, yw]*G[{yv^(-1)}, yw]*
      G[{0, 1/(yu*yv)}, yw] - 2*G[{0}, yw]*G[{1}, yw]*G[{yv^(-1)}, yw]*
      G[{0, 1/(yu*yv)}, yw] - 4*G[{1}, yu^(-1)]*G[{1}, yw]*G[{yv^(-1)}, yw]*
      G[{0, 1/(yu*yv)}, yw] - 2*G[{1}, yv^(-1)]*G[{1}, yw]*G[{yv^(-1)}, yw]*
      G[{0, 1/(yu*yv)}, yw] - G[{1}, yw]^2*G[{yv^(-1)}, yw]*
      G[{0, 1/(yu*yv)}, yw] - 2*G[{1}, yu^(-1)]*G[{yu^(-1)}, yw]*
      G[{yv^(-1)}, yw]*G[{0, 1/(yu*yv)}, yw] + 2*G[{1}, yv^(-1)]*
      G[{yu^(-1)}, yw]*G[{yv^(-1)}, yw]*G[{0, 1/(yu*yv)}, yw] - 
     2*G[{1}, yw]*G[{yu^(-1)}, yw]*G[{yv^(-1)}, yw]*G[{0, 1/(yu*yv)}, yw] + 
     2*G[{1}, yw]*G[{yu}, yv^(-1)]*G[{yv^(-1)}, yw]*G[{0, 1/(yu*yv)}, yw] - 
     G[{0}, yu^(-1)]*G[{yv^(-1)}, yw]^2*G[{0, 1/(yu*yv)}, yw] - 
     G[{0}, yv^(-1)]*G[{yv^(-1)}, yw]^2*G[{0, 1/(yu*yv)}, yw] + 
     G[{0}, yw]*G[{yv^(-1)}, yw]^2*G[{0, 1/(yu*yv)}, yw] + 
     G[{1}, yu^(-1)]*G[{yv^(-1)}, yw]^2*G[{0, 1/(yu*yv)}, yw] + 
     G[{1}, yv^(-1)]*G[{yv^(-1)}, yw]^2*G[{0, 1/(yu*yv)}, yw] - 
     G[{1}, yw]*G[{yv^(-1)}, yw]^2*G[{0, 1/(yu*yv)}, yw] + 
     2*G[{yu^(-1)}, yw]*G[{yv^(-1)}, yw]^2*G[{0, 1/(yu*yv)}, yw] + 
     (2*G[{yv^(-1)}, yw]^3*G[{0, 1/(yu*yv)}, yw])/3 + 
     2*G[{1}, yu^(-1)]^2*G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv)}, yw] - 
     4*G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*G[{1/(yu*yv)}, yw]*
      G[{0, 1/(yu*yv)}, yw] - 4*G[{1}, yu^(-1)]*G[{1}, yw]*G[{1/(yu*yv)}, yw]*
      G[{0, 1/(yu*yv)}, yw] + 2*G[{1}, yv^(-1)]*G[{1}, yw]*G[{1/(yu*yv)}, yw]*
      G[{0, 1/(yu*yv)}, yw] - G[{1}, yw]^2*G[{1/(yu*yv)}, yw]*
      G[{0, 1/(yu*yv)}, yw] - 2*G[{0}, yu^(-1)]*G[{yu^(-1)}, yw]*
      G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv)}, yw] - 2*G[{0}, yv^(-1)]*
      G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv)}, yw] + 
     2*G[{0}, yw]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv)}, yw] + 
     10*G[{1}, yu^(-1)]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*
      G[{0, 1/(yu*yv)}, yw] - 6*G[{1}, yv^(-1)]*G[{yu^(-1)}, yw]*
      G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv)}, yw] - 
     6*G[{1}, yw]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv)}, yw] + 
     8*G[{yu^(-1)}, yw]^2*G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv)}, yw] + 
     2*G[{1}, yw]*G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv)}, yw] + 
     2*G[{1}, yu^(-1)]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*
      G[{0, 1/(yu*yv)}, yw] - 2*G[{1}, yv^(-1)]*G[{yv^(-1)}, yw]*
      G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv)}, yw] + 
     2*G[{1}, yw]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv)}, yw] - 
     2*G[{yv^(-1)}, yw]^2*G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv)}, yw] + 
     G[{0}, yu^(-1)]*G[{1/(yu*yv)}, yw]^2*G[{0, 1/(yu*yv)}, yw] + 
     G[{0}, yv^(-1)]*G[{1/(yu*yv)}, yw]^2*G[{0, 1/(yu*yv)}, yw] - 
     G[{0}, yw]*G[{1/(yu*yv)}, yw]^2*G[{0, 1/(yu*yv)}, yw] - 
     4*G[{1}, yu^(-1)]*G[{1/(yu*yv)}, yw]^2*G[{0, 1/(yu*yv)}, yw] + 
     3*G[{1}, yv^(-1)]*G[{1/(yu*yv)}, yw]^2*G[{0, 1/(yu*yv)}, yw] + 
     G[{1}, yw]*G[{1/(yu*yv)}, yw]^2*G[{0, 1/(yu*yv)}, yw] - 
     5*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2*G[{0, 1/(yu*yv)}, yw] - 
     G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw]^2*G[{0, 1/(yu*yv)}, yw] + 
     2*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2*G[{0, 1/(yu*yv)}, yw] - 
     2*G[{1}, yw]*G[{0, 1}, yu^(-1)]*G[{0, 1/(yu*yv)}, yw] + 
     2*G[{yv^(-1)}, yw]*G[{0, 1}, yu^(-1)]*G[{0, 1/(yu*yv)}, yw] + 
     2*G[{1}, yw]*G[{0, 1}, yv^(-1)]*G[{0, 1/(yu*yv)}, yw] - 
     4*G[{yu^(-1)}, yw]*G[{0, 1}, yv^(-1)]*G[{0, 1/(yu*yv)}, yw] - 
     2*G[{yv^(-1)}, yw]*G[{0, 1}, yv^(-1)]*G[{0, 1/(yu*yv)}, yw] + 
     4*G[{1/(yu*yv)}, yw]*G[{0, 1}, yv^(-1)]*G[{0, 1/(yu*yv)}, yw] - 
     2*G[{1}, yw]*G[{0, 1}, yw]*G[{0, 1/(yu*yv)}, yw] + 
     2*G[{yv^(-1)}, yw]*G[{0, 1}, yw]*G[{0, 1/(yu*yv)}, yw] + 
     2*G[{1}, yw]*G[{0, yu^(-1)}, yw]*G[{0, 1/(yu*yv)}, yw] - 
     2*G[{yv^(-1)}, yw]*G[{0, yu^(-1)}, yw]*G[{0, 1/(yu*yv)}, yw] - 
     2*G[{1}, yw]*G[{0, yu}, yv^(-1)]*G[{0, 1/(yu*yv)}, yw] + 
     4*G[{yu^(-1)}, yw]*G[{0, yu}, yv^(-1)]*G[{0, 1/(yu*yv)}, yw] + 
     2*G[{yv^(-1)}, yw]*G[{0, yu}, yv^(-1)]*G[{0, 1/(yu*yv)}, yw] - 
     4*G[{1/(yu*yv)}, yw]*G[{0, yu}, yv^(-1)]*G[{0, 1/(yu*yv)}, yw] + 
     2*G[{1}, yw]*G[{0, yv^(-1)}, yw]*G[{0, 1/(yu*yv)}, yw] - 
     2*G[{yv^(-1)}, yw]*G[{0, yv^(-1)}, yw]*G[{0, 1/(yu*yv)}, yw] - 
     G[{1}, yw]*G[{0, 1/(yu*yv)}, yw]^2 + G[{yv^(-1)}, yw]*
      G[{0, 1/(yu*yv)}, yw]^2 - Pi^2*G[{1}, yu^(-1)]*G[{1, yu^(-1)}, yw] - 
     (2*Pi^2*G[{1}, yw]*G[{1, yu^(-1)}, yw])/3 - 2*G[{0}, yu^(-1)]*
      G[{1}, yu^(-1)]*G[{1}, yw]*G[{1, yu^(-1)}, yw] - 
     2*G[{0}, yv^(-1)]*G[{1}, yu^(-1)]*G[{1}, yw]*G[{1, yu^(-1)}, yw] + 
     2*G[{0}, yw]*G[{1}, yu^(-1)]*G[{1}, yw]*G[{1, yu^(-1)}, yw] + 
     2*G[{1}, yu^(-1)]^2*G[{1}, yw]*G[{1, yu^(-1)}, yw] - 
     G[{0}, yu^(-1)]*G[{1}, yw]^2*G[{1, yu^(-1)}, yw] - 
     G[{0}, yv^(-1)]*G[{1}, yw]^2*G[{1, yu^(-1)}, yw] + 
     G[{0}, yw]*G[{1}, yw]^2*G[{1, yu^(-1)}, yw] + 
     G[{1}, yu^(-1)]*G[{1}, yw]^2*G[{1, yu^(-1)}, yw] + 
     G[{1}, yv^(-1)]*G[{1}, yw]^2*G[{1, yu^(-1)}, yw] - 
     (2*Pi^2*G[{yu^(-1)}, yw]*G[{1, yu^(-1)}, yw])/3 + 
     2*G[{0}, yu^(-1)]*G[{1}, yu^(-1)]*G[{yu^(-1)}, yw]*G[{1, yu^(-1)}, yw] + 
     2*G[{0}, yv^(-1)]*G[{1}, yu^(-1)]*G[{yu^(-1)}, yw]*G[{1, yu^(-1)}, yw] - 
     2*G[{0}, yw]*G[{1}, yu^(-1)]*G[{yu^(-1)}, yw]*G[{1, yu^(-1)}, yw] - 
     4*G[{1}, yu^(-1)]^2*G[{yu^(-1)}, yw]*G[{1, yu^(-1)}, yw] - 
     2*G[{0}, yu^(-1)]*G[{1}, yw]*G[{yu^(-1)}, yw]*G[{1, yu^(-1)}, yw] - 
     2*G[{0}, yv^(-1)]*G[{1}, yw]*G[{yu^(-1)}, yw]*G[{1, yu^(-1)}, yw] + 
     2*G[{0}, yw]*G[{1}, yw]*G[{yu^(-1)}, yw]*G[{1, yu^(-1)}, yw] + 
     4*G[{1}, yv^(-1)]*G[{1}, yw]*G[{yu^(-1)}, yw]*G[{1, yu^(-1)}, yw] + 
     3*G[{0}, yu^(-1)]*G[{yu^(-1)}, yw]^2*G[{1, yu^(-1)}, yw] + 
     3*G[{0}, yv^(-1)]*G[{yu^(-1)}, yw]^2*G[{1, yu^(-1)}, yw] - 
     3*G[{0}, yw]*G[{yu^(-1)}, yw]^2*G[{1, yu^(-1)}, yw] - 
     7*G[{1}, yu^(-1)]*G[{yu^(-1)}, yw]^2*G[{1, yu^(-1)}, yw] + 
     G[{1}, yv^(-1)]*G[{yu^(-1)}, yw]^2*G[{1, yu^(-1)}, yw] - 
     2*G[{yu^(-1)}, yw]^3*G[{1, yu^(-1)}, yw] + Pi^2*G[{yu}, yv^(-1)]*
      G[{1, yu^(-1)}, yw] + 4*G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*
      G[{yu}, yv^(-1)]*G[{1, yu^(-1)}, yw] + 2*G[{0}, yu^(-1)]*G[{1}, yw]*
      G[{yu}, yv^(-1)]*G[{1, yu^(-1)}, yw] + 2*G[{0}, yv^(-1)]*G[{1}, yw]*
      G[{yu}, yv^(-1)]*G[{1, yu^(-1)}, yw] - 2*G[{0}, yw]*G[{1}, yw]*
      G[{yu}, yv^(-1)]*G[{1, yu^(-1)}, yw] - 2*G[{0}, yu^(-1)]*
      G[{yu^(-1)}, yw]*G[{yu}, yv^(-1)]*G[{1, yu^(-1)}, yw] - 
     2*G[{0}, yv^(-1)]*G[{yu^(-1)}, yw]*G[{yu}, yv^(-1)]*
      G[{1, yu^(-1)}, yw] + 2*G[{0}, yw]*G[{yu^(-1)}, yw]*G[{yu}, yv^(-1)]*
      G[{1, yu^(-1)}, yw] + 4*G[{1}, yu^(-1)]*G[{yu^(-1)}, yw]*
      G[{yu}, yv^(-1)]*G[{1, yu^(-1)}, yw] + 4*G[{1}, yv^(-1)]*
      G[{yu^(-1)}, yw]*G[{yu}, yv^(-1)]*G[{1, yu^(-1)}, yw] - 
     2*G[{1}, yu^(-1)]*G[{yu}, yv^(-1)]^2*G[{1, yu^(-1)}, yw] - 
     2*G[{1}, yv^(-1)]*G[{yu}, yv^(-1)]^2*G[{1, yu^(-1)}, yw] - 
     2*G[{1}, yw]*G[{yu}, yv^(-1)]^2*G[{1, yu^(-1)}, yw] - 
     2*G[{yu^(-1)}, yw]*G[{yu}, yv^(-1)]^2*G[{1, yu^(-1)}, yw] + 
     (4*G[{yu}, yv^(-1)]^3*G[{1, yu^(-1)}, yw])/3 + 
     (4*Pi^2*G[{yv^(-1)}, yw]*G[{1, yu^(-1)}, yw])/3 + 
     2*G[{0}, yu^(-1)]*G[{1}, yu^(-1)]*G[{yv^(-1)}, yw]*G[{1, yu^(-1)}, yw] + 
     2*G[{0}, yv^(-1)]*G[{1}, yu^(-1)]*G[{yv^(-1)}, yw]*G[{1, yu^(-1)}, yw] - 
     2*G[{0}, yw]*G[{1}, yu^(-1)]*G[{yv^(-1)}, yw]*G[{1, yu^(-1)}, yw] - 
     4*G[{1}, yu^(-1)]^2*G[{yv^(-1)}, yw]*G[{1, yu^(-1)}, yw] + 
     4*G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*G[{yv^(-1)}, yw]*G[{1, yu^(-1)}, yw] + 
     2*G[{0}, yu^(-1)]*G[{1}, yw]*G[{yv^(-1)}, yw]*G[{1, yu^(-1)}, yw] + 
     2*G[{0}, yv^(-1)]*G[{1}, yw]*G[{yv^(-1)}, yw]*G[{1, yu^(-1)}, yw] - 
     2*G[{0}, yw]*G[{1}, yw]*G[{yv^(-1)}, yw]*G[{1, yu^(-1)}, yw] - 
     4*G[{1}, yu^(-1)]*G[{1}, yw]*G[{yv^(-1)}, yw]*G[{1, yu^(-1)}, yw] + 
     2*G[{0}, yu^(-1)]*G[{yu^(-1)}, yw]*G[{yv^(-1)}, yw]*
      G[{1, yu^(-1)}, yw] + 2*G[{0}, yv^(-1)]*G[{yu^(-1)}, yw]*
      G[{yv^(-1)}, yw]*G[{1, yu^(-1)}, yw] - 2*G[{0}, yw]*G[{yu^(-1)}, yw]*
      G[{yv^(-1)}, yw]*G[{1, yu^(-1)}, yw] - 2*G[{1}, yu^(-1)]*
      G[{yu^(-1)}, yw]*G[{yv^(-1)}, yw]*G[{1, yu^(-1)}, yw] + 
     2*G[{1}, yv^(-1)]*G[{yu^(-1)}, yw]*G[{yv^(-1)}, yw]*
      G[{1, yu^(-1)}, yw] + 4*G[{1}, yw]*G[{yu^(-1)}, yw]*G[{yv^(-1)}, yw]*
      G[{1, yu^(-1)}, yw] + 2*G[{yu^(-1)}, yw]^2*G[{yv^(-1)}, yw]*
      G[{1, yu^(-1)}, yw] - 2*G[{0}, yu^(-1)]*G[{yu}, yv^(-1)]*
      G[{yv^(-1)}, yw]*G[{1, yu^(-1)}, yw] - 2*G[{0}, yv^(-1)]*
      G[{yu}, yv^(-1)]*G[{yv^(-1)}, yw]*G[{1, yu^(-1)}, yw] + 
     2*G[{0}, yw]*G[{yu}, yv^(-1)]*G[{yv^(-1)}, yw]*G[{1, yu^(-1)}, yw] - 
     4*G[{yu^(-1)}, yw]*G[{yu}, yv^(-1)]*G[{yv^(-1)}, yw]*
      G[{1, yu^(-1)}, yw] + 2*G[{yu}, yv^(-1)]^2*G[{yv^(-1)}, yw]*
      G[{1, yu^(-1)}, yw] - G[{0}, yu^(-1)]*G[{yv^(-1)}, yw]^2*
      G[{1, yu^(-1)}, yw] - G[{0}, yv^(-1)]*G[{yv^(-1)}, yw]^2*
      G[{1, yu^(-1)}, yw] + G[{0}, yw]*G[{yv^(-1)}, yw]^2*
      G[{1, yu^(-1)}, yw] + G[{1}, yu^(-1)]*G[{yv^(-1)}, yw]^2*
      G[{1, yu^(-1)}, yw] + G[{1}, yv^(-1)]*G[{yv^(-1)}, yw]^2*
      G[{1, yu^(-1)}, yw] + 2*G[{yu^(-1)}, yw]*G[{yv^(-1)}, yw]^2*
      G[{1, yu^(-1)}, yw] + (2*G[{yv^(-1)}, yw]^3*G[{1, yu^(-1)}, yw])/3 + 
     (2*Pi^2*G[{1/(yu*yv)}, yw]*G[{1, yu^(-1)}, yw])/3 - 
     2*G[{0}, yu^(-1)]*G[{1}, yu^(-1)]*G[{1/(yu*yv)}, yw]*
      G[{1, yu^(-1)}, yw] - 2*G[{0}, yv^(-1)]*G[{1}, yu^(-1)]*
      G[{1/(yu*yv)}, yw]*G[{1, yu^(-1)}, yw] + 2*G[{0}, yw]*G[{1}, yu^(-1)]*
      G[{1/(yu*yv)}, yw]*G[{1, yu^(-1)}, yw] + 4*G[{1}, yu^(-1)]^2*
      G[{1/(yu*yv)}, yw]*G[{1, yu^(-1)}, yw] + 2*G[{0}, yu^(-1)]*G[{1}, yw]*
      G[{1/(yu*yv)}, yw]*G[{1, yu^(-1)}, yw] + 2*G[{0}, yv^(-1)]*G[{1}, yw]*
      G[{1/(yu*yv)}, yw]*G[{1, yu^(-1)}, yw] - 2*G[{0}, yw]*G[{1}, yw]*
      G[{1/(yu*yv)}, yw]*G[{1, yu^(-1)}, yw] - 4*G[{1}, yv^(-1)]*G[{1}, yw]*
      G[{1/(yu*yv)}, yw]*G[{1, yu^(-1)}, yw] - 6*G[{0}, yu^(-1)]*
      G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{1, yu^(-1)}, yw] - 
     6*G[{0}, yv^(-1)]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*
      G[{1, yu^(-1)}, yw] + 6*G[{0}, yw]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*
      G[{1, yu^(-1)}, yw] + 14*G[{1}, yu^(-1)]*G[{yu^(-1)}, yw]*
      G[{1/(yu*yv)}, yw]*G[{1, yu^(-1)}, yw] - 2*G[{1}, yv^(-1)]*
      G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{1, yu^(-1)}, yw] + 
     6*G[{yu^(-1)}, yw]^2*G[{1/(yu*yv)}, yw]*G[{1, yu^(-1)}, yw] + 
     2*G[{0}, yu^(-1)]*G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw]*
      G[{1, yu^(-1)}, yw] + 2*G[{0}, yv^(-1)]*G[{yu}, yv^(-1)]*
      G[{1/(yu*yv)}, yw]*G[{1, yu^(-1)}, yw] - 2*G[{0}, yw]*G[{yu}, yv^(-1)]*
      G[{1/(yu*yv)}, yw]*G[{1, yu^(-1)}, yw] - 4*G[{1}, yu^(-1)]*
      G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{1, yu^(-1)}, yw] - 
     4*G[{1}, yv^(-1)]*G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw]*
      G[{1, yu^(-1)}, yw] + 2*G[{yu}, yv^(-1)]^2*G[{1/(yu*yv)}, yw]*
      G[{1, yu^(-1)}, yw] - 2*G[{0}, yu^(-1)]*G[{yv^(-1)}, yw]*
      G[{1/(yu*yv)}, yw]*G[{1, yu^(-1)}, yw] - 2*G[{0}, yv^(-1)]*
      G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{1, yu^(-1)}, yw] + 
     2*G[{0}, yw]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{1, yu^(-1)}, yw] + 
     2*G[{1}, yu^(-1)]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*
      G[{1, yu^(-1)}, yw] - 2*G[{1}, yv^(-1)]*G[{yv^(-1)}, yw]*
      G[{1/(yu*yv)}, yw]*G[{1, yu^(-1)}, yw] - 4*G[{1}, yw]*G[{yv^(-1)}, yw]*
      G[{1/(yu*yv)}, yw]*G[{1, yu^(-1)}, yw] - 4*G[{yu^(-1)}, yw]*
      G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{1, yu^(-1)}, yw] + 
     4*G[{yu}, yv^(-1)]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*
      G[{1, yu^(-1)}, yw] - 2*G[{yv^(-1)}, yw]^2*G[{1/(yu*yv)}, yw]*
      G[{1, yu^(-1)}, yw] + 3*G[{0}, yu^(-1)]*G[{1/(yu*yv)}, yw]^2*
      G[{1, yu^(-1)}, yw] + 3*G[{0}, yv^(-1)]*G[{1/(yu*yv)}, yw]^2*
      G[{1, yu^(-1)}, yw] - 3*G[{0}, yw]*G[{1/(yu*yv)}, yw]^2*
      G[{1, yu^(-1)}, yw] - 5*G[{1}, yu^(-1)]*G[{1/(yu*yv)}, yw]^2*
      G[{1, yu^(-1)}, yw] + G[{1}, yv^(-1)]*G[{1/(yu*yv)}, yw]^2*
      G[{1, yu^(-1)}, yw] + 2*G[{1}, yw]*G[{1/(yu*yv)}, yw]^2*
      G[{1, yu^(-1)}, yw] - 3*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2*
      G[{1, yu^(-1)}, yw] - 2*G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw]^2*
      G[{1, yu^(-1)}, yw] + 3*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2*
      G[{1, yu^(-1)}, yw] - 2*G[{1}, yu^(-1)]*G[{0, 1}, yu^(-1)]*
      G[{1, yu^(-1)}, yw] - 2*G[{1}, yw]*G[{0, 1}, yu^(-1)]*
      G[{1, yu^(-1)}, yw] + 2*G[{yu}, yv^(-1)]*G[{0, 1}, yu^(-1)]*
      G[{1, yu^(-1)}, yw] + 4*G[{yv^(-1)}, yw]*G[{0, 1}, yu^(-1)]*
      G[{1, yu^(-1)}, yw] - 2*G[{1}, yu^(-1)]*G[{0, 1}, yv^(-1)]*
      G[{1, yu^(-1)}, yw] - 2*G[{1}, yw]*G[{0, 1}, yv^(-1)]*
      G[{1, yu^(-1)}, yw] - 4*G[{yu^(-1)}, yw]*G[{0, 1}, yv^(-1)]*
      G[{1, yu^(-1)}, yw] + 2*G[{yu}, yv^(-1)]*G[{0, 1}, yv^(-1)]*
      G[{1, yu^(-1)}, yw] + 4*G[{1/(yu*yv)}, yw]*G[{0, 1}, yv^(-1)]*
      G[{1, yu^(-1)}, yw] - 2*G[{1}, yu^(-1)]*G[{0, 1}, yw]*
      G[{1, yu^(-1)}, yw] - 4*G[{yu^(-1)}, yw]*G[{0, 1}, yw]*
      G[{1, yu^(-1)}, yw] + 2*G[{yu}, yv^(-1)]*G[{0, 1}, yw]*
      G[{1, yu^(-1)}, yw] + 4*G[{1/(yu*yv)}, yw]*G[{0, 1}, yw]*
      G[{1, yu^(-1)}, yw] + 2*G[{1}, yu^(-1)]*G[{0, yu^(-1)}, yw]*
      G[{1, yu^(-1)}, yw] + 4*G[{yu^(-1)}, yw]*G[{0, yu^(-1)}, yw]*
      G[{1, yu^(-1)}, yw] - 2*G[{yu}, yv^(-1)]*G[{0, yu^(-1)}, yw]*
      G[{1, yu^(-1)}, yw] - 4*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1)}, yw]*
      G[{1, yu^(-1)}, yw] + 2*G[{1}, yu^(-1)]*G[{0, yu}, yv^(-1)]*
      G[{1, yu^(-1)}, yw] + 2*G[{1}, yw]*G[{0, yu}, yv^(-1)]*
      G[{1, yu^(-1)}, yw] + 4*G[{yu^(-1)}, yw]*G[{0, yu}, yv^(-1)]*
      G[{1, yu^(-1)}, yw] - 2*G[{yu}, yv^(-1)]*G[{0, yu}, yv^(-1)]*
      G[{1, yu^(-1)}, yw] - 4*G[{1/(yu*yv)}, yw]*G[{0, yu}, yv^(-1)]*
      G[{1, yu^(-1)}, yw] + 2*G[{1}, yu^(-1)]*G[{0, yv^(-1)}, yw]*
      G[{1, yu^(-1)}, yw] + 4*G[{yu^(-1)}, yw]*G[{0, yv^(-1)}, yw]*
      G[{1, yu^(-1)}, yw] - 2*G[{yu}, yv^(-1)]*G[{0, yv^(-1)}, yw]*
      G[{1, yu^(-1)}, yw] - 4*G[{1/(yu*yv)}, yw]*G[{0, yv^(-1)}, yw]*
      G[{1, yu^(-1)}, yw] - 2*G[{1}, yu^(-1)]*G[{0, 1/(yu*yv)}, yw]*
      G[{1, yu^(-1)}, yw] - 4*G[{yu^(-1)}, yw]*G[{0, 1/(yu*yv)}, yw]*
      G[{1, yu^(-1)}, yw] + 2*G[{yu}, yv^(-1)]*G[{0, 1/(yu*yv)}, yw]*
      G[{1, yu^(-1)}, yw] + 4*G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv)}, yw]*
      G[{1, yu^(-1)}, yw] - 2*G[{1}, yu^(-1)]*G[{1, yu^(-1)}, yw]^2 - 
     2*G[{1}, yw]*G[{1, yu^(-1)}, yw]^2 - 4*G[{yu^(-1)}, yw]*
      G[{1, yu^(-1)}, yw]^2 + 2*G[{yu}, yv^(-1)]*G[{1, yu^(-1)}, yw]^2 + 
     4*G[{1/(yu*yv)}, yw]*G[{1, yu^(-1)}, yw]^2 + 
     Pi^2*G[{1}, yw]*G[{1, yu}, yv^(-1)] + 4*G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*
      G[{1}, yw]*G[{1, yu}, yv^(-1)] + 2*G[{0}, yu^(-1)]*G[{1}, yw]^2*
      G[{1, yu}, yv^(-1)] + 2*G[{0}, yv^(-1)]*G[{1}, yw]^2*
      G[{1, yu}, yv^(-1)] - 2*G[{0}, yw]*G[{1}, yw]^2*G[{1, yu}, yv^(-1)] - 
     2*G[{1}, yv^(-1)]*G[{1}, yw]^2*G[{1, yu}, yv^(-1)] - 
     Pi^2*G[{yu^(-1)}, yw]*G[{1, yu}, yv^(-1)] - 4*G[{1}, yu^(-1)]*
      G[{1}, yv^(-1)]*G[{yu^(-1)}, yw]*G[{1, yu}, yv^(-1)] - 
     4*G[{0}, yu^(-1)]*G[{1}, yw]*G[{yu^(-1)}, yw]*G[{1, yu}, yv^(-1)] - 
     4*G[{0}, yv^(-1)]*G[{1}, yw]*G[{yu^(-1)}, yw]*G[{1, yu}, yv^(-1)] + 
     4*G[{0}, yw]*G[{1}, yw]*G[{yu^(-1)}, yw]*G[{1, yu}, yv^(-1)] + 
     4*G[{1}, yu^(-1)]*G[{1}, yw]*G[{yu^(-1)}, yw]*G[{1, yu}, yv^(-1)] + 
     2*G[{0}, yu^(-1)]*G[{yu^(-1)}, yw]^2*G[{1, yu}, yv^(-1)] + 
     2*G[{0}, yv^(-1)]*G[{yu^(-1)}, yw]^2*G[{1, yu}, yv^(-1)] - 
     2*G[{0}, yw]*G[{yu^(-1)}, yw]^2*G[{1, yu}, yv^(-1)] - 
     2*G[{1}, yu^(-1)]*G[{yu^(-1)}, yw]^2*G[{1, yu}, yv^(-1)] - 
     2*G[{1}, yv^(-1)]*G[{yu^(-1)}, yw]^2*G[{1, yu}, yv^(-1)] + 
     (2*G[{yu^(-1)}, yw]^3*G[{1, yu}, yv^(-1)])/3 - 
     Pi^2*G[{yv^(-1)}, yw]*G[{1, yu}, yv^(-1)] - 4*G[{1}, yu^(-1)]*
      G[{1}, yv^(-1)]*G[{yv^(-1)}, yw]*G[{1, yu}, yv^(-1)] - 
     4*G[{0}, yu^(-1)]*G[{1}, yw]*G[{yv^(-1)}, yw]*G[{1, yu}, yv^(-1)] - 
     4*G[{0}, yv^(-1)]*G[{1}, yw]*G[{yv^(-1)}, yw]*G[{1, yu}, yv^(-1)] + 
     4*G[{0}, yw]*G[{1}, yw]*G[{yv^(-1)}, yw]*G[{1, yu}, yv^(-1)] + 
     4*G[{1}, yv^(-1)]*G[{1}, yw]*G[{yv^(-1)}, yw]*G[{1, yu}, yv^(-1)] + 
     4*G[{0}, yu^(-1)]*G[{yu^(-1)}, yw]*G[{yv^(-1)}, yw]*
      G[{1, yu}, yv^(-1)] + 4*G[{0}, yv^(-1)]*G[{yu^(-1)}, yw]*
      G[{yv^(-1)}, yw]*G[{1, yu}, yv^(-1)] - 4*G[{0}, yw]*G[{yu^(-1)}, yw]*
      G[{yv^(-1)}, yw]*G[{1, yu}, yv^(-1)] + 2*G[{yu^(-1)}, yw]^2*
      G[{yv^(-1)}, yw]*G[{1, yu}, yv^(-1)] + 2*G[{0}, yu^(-1)]*
      G[{yv^(-1)}, yw]^2*G[{1, yu}, yv^(-1)] + 2*G[{0}, yv^(-1)]*
      G[{yv^(-1)}, yw]^2*G[{1, yu}, yv^(-1)] - 
     2*G[{0}, yw]*G[{yv^(-1)}, yw]^2*G[{1, yu}, yv^(-1)] - 
     2*G[{1}, yu^(-1)]*G[{yv^(-1)}, yw]^2*G[{1, yu}, yv^(-1)] - 
     2*G[{1}, yv^(-1)]*G[{yv^(-1)}, yw]^2*G[{1, yu}, yv^(-1)] + 
     2*G[{yu^(-1)}, yw]*G[{yv^(-1)}, yw]^2*G[{1, yu}, yv^(-1)] + 
     (2*G[{yv^(-1)}, yw]^3*G[{1, yu}, yv^(-1)])/3 + 
     Pi^2*G[{1/(yu*yv)}, yw]*G[{1, yu}, yv^(-1)] + 
     4*G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*G[{1/(yu*yv)}, yw]*
      G[{1, yu}, yv^(-1)] + 4*G[{0}, yu^(-1)]*G[{1}, yw]*G[{1/(yu*yv)}, yw]*
      G[{1, yu}, yv^(-1)] + 4*G[{0}, yv^(-1)]*G[{1}, yw]*G[{1/(yu*yv)}, yw]*
      G[{1, yu}, yv^(-1)] - 4*G[{0}, yw]*G[{1}, yw]*G[{1/(yu*yv)}, yw]*
      G[{1, yu}, yv^(-1)] - 4*G[{1}, yu^(-1)]*G[{1}, yw]*G[{1/(yu*yv)}, yw]*
      G[{1, yu}, yv^(-1)] - 4*G[{0}, yu^(-1)]*G[{yu^(-1)}, yw]*
      G[{1/(yu*yv)}, yw]*G[{1, yu}, yv^(-1)] - 4*G[{0}, yv^(-1)]*
      G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{1, yu}, yv^(-1)] + 
     4*G[{0}, yw]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{1, yu}, yv^(-1)] + 
     4*G[{1}, yu^(-1)]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*
      G[{1, yu}, yv^(-1)] + 4*G[{1}, yv^(-1)]*G[{yu^(-1)}, yw]*
      G[{1/(yu*yv)}, yw]*G[{1, yu}, yv^(-1)] - 2*G[{yu^(-1)}, yw]^2*
      G[{1/(yu*yv)}, yw]*G[{1, yu}, yv^(-1)] - 4*G[{0}, yu^(-1)]*
      G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{1, yu}, yv^(-1)] - 
     4*G[{0}, yv^(-1)]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*
      G[{1, yu}, yv^(-1)] + 4*G[{0}, yw]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*
      G[{1, yu}, yv^(-1)] - 4*G[{yu^(-1)}, yw]*G[{yv^(-1)}, yw]*
      G[{1/(yu*yv)}, yw]*G[{1, yu}, yv^(-1)] - 2*G[{yv^(-1)}, yw]^2*
      G[{1/(yu*yv)}, yw]*G[{1, yu}, yv^(-1)] + 2*G[{0}, yu^(-1)]*
      G[{1/(yu*yv)}, yw]^2*G[{1, yu}, yv^(-1)] + 2*G[{0}, yv^(-1)]*
      G[{1/(yu*yv)}, yw]^2*G[{1, yu}, yv^(-1)] - 
     2*G[{0}, yw]*G[{1/(yu*yv)}, yw]^2*G[{1, yu}, yv^(-1)] - 
     2*G[{1}, yv^(-1)]*G[{1/(yu*yv)}, yw]^2*G[{1, yu}, yv^(-1)] + 
     2*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2*G[{1, yu}, yv^(-1)] + 
     2*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2*G[{1, yu}, yv^(-1)] + 
     2*G[{1}, yw]*G[{0, 1}, yu^(-1)]*G[{1, yu}, yv^(-1)] - 
     2*G[{yu^(-1)}, yw]*G[{0, 1}, yu^(-1)]*G[{1, yu}, yv^(-1)] - 
     2*G[{yv^(-1)}, yw]*G[{0, 1}, yu^(-1)]*G[{1, yu}, yv^(-1)] + 
     2*G[{1/(yu*yv)}, yw]*G[{0, 1}, yu^(-1)]*G[{1, yu}, yv^(-1)] + 
     2*G[{1}, yw]*G[{0, 1}, yv^(-1)]*G[{1, yu}, yv^(-1)] - 
     2*G[{yu^(-1)}, yw]*G[{0, 1}, yv^(-1)]*G[{1, yu}, yv^(-1)] - 
     2*G[{yv^(-1)}, yw]*G[{0, 1}, yv^(-1)]*G[{1, yu}, yv^(-1)] + 
     2*G[{1/(yu*yv)}, yw]*G[{0, 1}, yv^(-1)]*G[{1, yu}, yv^(-1)] + 
     4*G[{1}, yw]*G[{0, 1}, yw]*G[{1, yu}, yv^(-1)] - 
     4*G[{yu^(-1)}, yw]*G[{0, 1}, yw]*G[{1, yu}, yv^(-1)] - 
     4*G[{yv^(-1)}, yw]*G[{0, 1}, yw]*G[{1, yu}, yv^(-1)] + 
     4*G[{1/(yu*yv)}, yw]*G[{0, 1}, yw]*G[{1, yu}, yv^(-1)] - 
     4*G[{1}, yw]*G[{0, yu^(-1)}, yw]*G[{1, yu}, yv^(-1)] + 
     4*G[{yu^(-1)}, yw]*G[{0, yu^(-1)}, yw]*G[{1, yu}, yv^(-1)] + 
     4*G[{yv^(-1)}, yw]*G[{0, yu^(-1)}, yw]*G[{1, yu}, yv^(-1)] - 
     4*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1)}, yw]*G[{1, yu}, yv^(-1)] - 
     2*G[{1}, yw]*G[{0, yu}, yv^(-1)]*G[{1, yu}, yv^(-1)] + 
     2*G[{yu^(-1)}, yw]*G[{0, yu}, yv^(-1)]*G[{1, yu}, yv^(-1)] + 
     2*G[{yv^(-1)}, yw]*G[{0, yu}, yv^(-1)]*G[{1, yu}, yv^(-1)] - 
     2*G[{1/(yu*yv)}, yw]*G[{0, yu}, yv^(-1)]*G[{1, yu}, yv^(-1)] - 
     4*G[{1}, yw]*G[{0, yv^(-1)}, yw]*G[{1, yu}, yv^(-1)] + 
     4*G[{yu^(-1)}, yw]*G[{0, yv^(-1)}, yw]*G[{1, yu}, yv^(-1)] + 
     4*G[{yv^(-1)}, yw]*G[{0, yv^(-1)}, yw]*G[{1, yu}, yv^(-1)] - 
     4*G[{1/(yu*yv)}, yw]*G[{0, yv^(-1)}, yw]*G[{1, yu}, yv^(-1)] + 
     4*G[{1}, yw]*G[{0, 1/(yu*yv)}, yw]*G[{1, yu}, yv^(-1)] - 
     4*G[{yu^(-1)}, yw]*G[{0, 1/(yu*yv)}, yw]*G[{1, yu}, yv^(-1)] - 
     4*G[{yv^(-1)}, yw]*G[{0, 1/(yu*yv)}, yw]*G[{1, yu}, yv^(-1)] + 
     4*G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv)}, yw]*G[{1, yu}, yv^(-1)] - 
     4*G[{1}, yu^(-1)]*G[{1, yu^(-1)}, yw]*G[{1, yu}, yv^(-1)] - 
     4*G[{yu^(-1)}, yw]*G[{1, yu^(-1)}, yw]*G[{1, yu}, yv^(-1)] - 
     4*G[{yv^(-1)}, yw]*G[{1, yu^(-1)}, yw]*G[{1, yu}, yv^(-1)] + 
     4*G[{1/(yu*yv)}, yw]*G[{1, yu^(-1)}, yw]*G[{1, yu}, yv^(-1)] + 
     Pi^2*G[{1}, yu^(-1)]*G[{1, yv^(-1)}, yw] + 
     (4*Pi^2*G[{1}, yw]*G[{1, yv^(-1)}, yw])/3 + 2*G[{0}, yu^(-1)]*
      G[{1}, yu^(-1)]*G[{1}, yw]*G[{1, yv^(-1)}, yw] + 
     2*G[{0}, yv^(-1)]*G[{1}, yu^(-1)]*G[{1}, yw]*G[{1, yv^(-1)}, yw] - 
     2*G[{0}, yw]*G[{1}, yu^(-1)]*G[{1}, yw]*G[{1, yv^(-1)}, yw] - 
     2*G[{1}, yu^(-1)]^2*G[{1}, yw]*G[{1, yv^(-1)}, yw] + 
     3*G[{0}, yu^(-1)]*G[{1}, yw]^2*G[{1, yv^(-1)}, yw] + 
     3*G[{0}, yv^(-1)]*G[{1}, yw]^2*G[{1, yv^(-1)}, yw] - 
     3*G[{0}, yw]*G[{1}, yw]^2*G[{1, yv^(-1)}, yw] - 
     3*G[{1}, yu^(-1)]*G[{1}, yw]^2*G[{1, yv^(-1)}, yw] - 
     3*G[{1}, yv^(-1)]*G[{1}, yw]^2*G[{1, yv^(-1)}, yw] + 
     (Pi^2*G[{yu^(-1)}, yw]*G[{1, yv^(-1)}, yw])/3 - 
     2*G[{0}, yu^(-1)]*G[{1}, yu^(-1)]*G[{yu^(-1)}, yw]*G[{1, yv^(-1)}, yw] - 
     2*G[{0}, yv^(-1)]*G[{1}, yu^(-1)]*G[{yu^(-1)}, yw]*G[{1, yv^(-1)}, yw] + 
     2*G[{0}, yw]*G[{1}, yu^(-1)]*G[{yu^(-1)}, yw]*G[{1, yv^(-1)}, yw] + 
     4*G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*G[{yu^(-1)}, yw]*G[{1, yv^(-1)}, yw] - 
     4*G[{0}, yu^(-1)]*G[{1}, yw]*G[{yu^(-1)}, yw]*G[{1, yv^(-1)}, yw] - 
     4*G[{0}, yv^(-1)]*G[{1}, yw]*G[{yu^(-1)}, yw]*G[{1, yv^(-1)}, yw] + 
     4*G[{0}, yw]*G[{1}, yw]*G[{yu^(-1)}, yw]*G[{1, yv^(-1)}, yw] + 
     4*G[{1}, yv^(-1)]*G[{1}, yw]*G[{yu^(-1)}, yw]*G[{1, yv^(-1)}, yw] - 
     2*G[{1}, yw]^2*G[{yu^(-1)}, yw]*G[{1, yv^(-1)}, yw] + 
     G[{0}, yu^(-1)]*G[{yu^(-1)}, yw]^2*G[{1, yv^(-1)}, yw] + 
     G[{0}, yv^(-1)]*G[{yu^(-1)}, yw]^2*G[{1, yv^(-1)}, yw] - 
     G[{0}, yw]*G[{yu^(-1)}, yw]^2*G[{1, yv^(-1)}, yw] - 
     5*G[{1}, yu^(-1)]*G[{yu^(-1)}, yw]^2*G[{1, yv^(-1)}, yw] + 
     3*G[{1}, yv^(-1)]*G[{yu^(-1)}, yw]^2*G[{1, yv^(-1)}, yw] - 
     (8*G[{yu^(-1)}, yw]^3*G[{1, yv^(-1)}, yw])/3 - 
     Pi^2*G[{yu}, yv^(-1)]*G[{1, yv^(-1)}, yw] - 4*G[{1}, yu^(-1)]*
      G[{1}, yv^(-1)]*G[{yu}, yv^(-1)]*G[{1, yv^(-1)}, yw] - 
     2*G[{0}, yu^(-1)]*G[{1}, yw]*G[{yu}, yv^(-1)]*G[{1, yv^(-1)}, yw] - 
     2*G[{0}, yv^(-1)]*G[{1}, yw]*G[{yu}, yv^(-1)]*G[{1, yv^(-1)}, yw] + 
     2*G[{0}, yw]*G[{1}, yw]*G[{yu}, yv^(-1)]*G[{1, yv^(-1)}, yw] + 
     2*G[{0}, yu^(-1)]*G[{yu^(-1)}, yw]*G[{yu}, yv^(-1)]*
      G[{1, yv^(-1)}, yw] + 2*G[{0}, yv^(-1)]*G[{yu^(-1)}, yw]*
      G[{yu}, yv^(-1)]*G[{1, yv^(-1)}, yw] - 2*G[{0}, yw]*G[{yu^(-1)}, yw]*
      G[{yu}, yv^(-1)]*G[{1, yv^(-1)}, yw] + 4*G[{1}, yw]*G[{yu^(-1)}, yw]*
      G[{yu}, yv^(-1)]*G[{1, yv^(-1)}, yw] + 2*G[{1}, yu^(-1)]*
      G[{yu}, yv^(-1)]^2*G[{1, yv^(-1)}, yw] + 2*G[{1}, yv^(-1)]*
      G[{yu}, yv^(-1)]^2*G[{1, yv^(-1)}, yw] + 
     2*G[{1}, yw]*G[{yu}, yv^(-1)]^2*G[{1, yv^(-1)}, yw] - 
     2*G[{yu^(-1)}, yw]*G[{yu}, yv^(-1)]^2*G[{1, yv^(-1)}, yw] - 
     (4*G[{yu}, yv^(-1)]^3*G[{1, yv^(-1)}, yw])/3 + 
     (7*Pi^2*G[{yv^(-1)}, yw]*G[{1, yv^(-1)}, yw])/3 - 
     2*G[{0}, yu^(-1)]*G[{1}, yu^(-1)]*G[{yv^(-1)}, yw]*G[{1, yv^(-1)}, yw] - 
     2*G[{0}, yv^(-1)]*G[{1}, yu^(-1)]*G[{yv^(-1)}, yw]*G[{1, yv^(-1)}, yw] + 
     2*G[{0}, yw]*G[{1}, yu^(-1)]*G[{yv^(-1)}, yw]*G[{1, yv^(-1)}, yw] + 
     8*G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*G[{yv^(-1)}, yw]*G[{1, yv^(-1)}, yw] - 
     4*G[{1}, yu^(-1)]*G[{1}, yw]*G[{yv^(-1)}, yw]*G[{1, yv^(-1)}, yw] - 
     2*G[{1}, yw]^2*G[{yv^(-1)}, yw]*G[{1, yv^(-1)}, yw] - 
     2*G[{0}, yu^(-1)]*G[{yu^(-1)}, yw]*G[{yv^(-1)}, yw]*
      G[{1, yv^(-1)}, yw] - 2*G[{0}, yv^(-1)]*G[{yu^(-1)}, yw]*
      G[{yv^(-1)}, yw]*G[{1, yv^(-1)}, yw] + 2*G[{0}, yw]*G[{yu^(-1)}, yw]*
      G[{yv^(-1)}, yw]*G[{1, yv^(-1)}, yw] - 2*G[{1}, yu^(-1)]*
      G[{yu^(-1)}, yw]*G[{yv^(-1)}, yw]*G[{1, yv^(-1)}, yw] + 
     2*G[{1}, yv^(-1)]*G[{yu^(-1)}, yw]*G[{yv^(-1)}, yw]*
      G[{1, yv^(-1)}, yw] - 4*G[{1}, yw]*G[{yu^(-1)}, yw]*G[{yv^(-1)}, yw]*
      G[{1, yv^(-1)}, yw] + 2*G[{0}, yu^(-1)]*G[{yu}, yv^(-1)]*
      G[{yv^(-1)}, yw]*G[{1, yv^(-1)}, yw] + 2*G[{0}, yv^(-1)]*
      G[{yu}, yv^(-1)]*G[{yv^(-1)}, yw]*G[{1, yv^(-1)}, yw] - 
     2*G[{0}, yw]*G[{yu}, yv^(-1)]*G[{yv^(-1)}, yw]*G[{1, yv^(-1)}, yw] - 
     4*G[{1}, yu^(-1)]*G[{yu}, yv^(-1)]*G[{yv^(-1)}, yw]*
      G[{1, yv^(-1)}, yw] - 4*G[{1}, yv^(-1)]*G[{yu}, yv^(-1)]*
      G[{yv^(-1)}, yw]*G[{1, yv^(-1)}, yw] + 4*G[{1}, yw]*G[{yu}, yv^(-1)]*
      G[{yv^(-1)}, yw]*G[{1, yv^(-1)}, yw] + 4*G[{yu^(-1)}, yw]*
      G[{yu}, yv^(-1)]*G[{yv^(-1)}, yw]*G[{1, yv^(-1)}, yw] + 
     2*G[{yu}, yv^(-1)]^2*G[{yv^(-1)}, yw]*G[{1, yv^(-1)}, yw] - 
     3*G[{0}, yu^(-1)]*G[{yv^(-1)}, yw]^2*G[{1, yv^(-1)}, yw] - 
     3*G[{0}, yv^(-1)]*G[{yv^(-1)}, yw]^2*G[{1, yv^(-1)}, yw] + 
     3*G[{0}, yw]*G[{yv^(-1)}, yw]^2*G[{1, yv^(-1)}, yw] + 
     3*G[{1}, yu^(-1)]*G[{yv^(-1)}, yw]^2*G[{1, yv^(-1)}, yw] + 
     3*G[{1}, yv^(-1)]*G[{yv^(-1)}, yw]^2*G[{1, yv^(-1)}, yw] - 
     (Pi^2*G[{1/(yu*yv)}, yw]*G[{1, yv^(-1)}, yw])/3 + 
     2*G[{0}, yu^(-1)]*G[{1}, yu^(-1)]*G[{1/(yu*yv)}, yw]*
      G[{1, yv^(-1)}, yw] + 2*G[{0}, yv^(-1)]*G[{1}, yu^(-1)]*
      G[{1/(yu*yv)}, yw]*G[{1, yv^(-1)}, yw] - 2*G[{0}, yw]*G[{1}, yu^(-1)]*
      G[{1/(yu*yv)}, yw]*G[{1, yv^(-1)}, yw] - 4*G[{1}, yu^(-1)]*
      G[{1}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{1, yv^(-1)}, yw] + 
     4*G[{0}, yu^(-1)]*G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{1, yv^(-1)}, yw] + 
     4*G[{0}, yv^(-1)]*G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{1, yv^(-1)}, yw] - 
     4*G[{0}, yw]*G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{1, yv^(-1)}, yw] - 
     4*G[{1}, yv^(-1)]*G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{1, yv^(-1)}, yw] + 
     2*G[{1}, yw]^2*G[{1/(yu*yv)}, yw]*G[{1, yv^(-1)}, yw] - 
     2*G[{0}, yu^(-1)]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*
      G[{1, yv^(-1)}, yw] - 2*G[{0}, yv^(-1)]*G[{yu^(-1)}, yw]*
      G[{1/(yu*yv)}, yw]*G[{1, yv^(-1)}, yw] + 2*G[{0}, yw]*G[{yu^(-1)}, yw]*
      G[{1/(yu*yv)}, yw]*G[{1, yv^(-1)}, yw] + 10*G[{1}, yu^(-1)]*
      G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{1, yv^(-1)}, yw] - 
     6*G[{1}, yv^(-1)]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*
      G[{1, yv^(-1)}, yw] + 8*G[{yu^(-1)}, yw]^2*G[{1/(yu*yv)}, yw]*
      G[{1, yv^(-1)}, yw] - 2*G[{0}, yu^(-1)]*G[{yu}, yv^(-1)]*
      G[{1/(yu*yv)}, yw]*G[{1, yv^(-1)}, yw] - 2*G[{0}, yv^(-1)]*
      G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{1, yv^(-1)}, yw] + 
     2*G[{0}, yw]*G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{1, yv^(-1)}, yw] - 
     4*G[{1}, yw]*G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{1, yv^(-1)}, yw] + 
     2*G[{yu}, yv^(-1)]^2*G[{1/(yu*yv)}, yw]*G[{1, yv^(-1)}, yw] + 
     2*G[{0}, yu^(-1)]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*
      G[{1, yv^(-1)}, yw] + 2*G[{0}, yv^(-1)]*G[{yv^(-1)}, yw]*
      G[{1/(yu*yv)}, yw]*G[{1, yv^(-1)}, yw] - 2*G[{0}, yw]*G[{yv^(-1)}, yw]*
      G[{1/(yu*yv)}, yw]*G[{1, yv^(-1)}, yw] + 2*G[{1}, yu^(-1)]*
      G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{1, yv^(-1)}, yw] - 
     2*G[{1}, yv^(-1)]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*
      G[{1, yv^(-1)}, yw] + 4*G[{1}, yw]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*
      G[{1, yv^(-1)}, yw] - 4*G[{yu}, yv^(-1)]*G[{yv^(-1)}, yw]*
      G[{1/(yu*yv)}, yw]*G[{1, yv^(-1)}, yw] + G[{0}, yu^(-1)]*
      G[{1/(yu*yv)}, yw]^2*G[{1, yv^(-1)}, yw] + 
     G[{0}, yv^(-1)]*G[{1/(yu*yv)}, yw]^2*G[{1, yv^(-1)}, yw] - 
     G[{0}, yw]*G[{1/(yu*yv)}, yw]^2*G[{1, yv^(-1)}, yw] - 
     5*G[{1}, yu^(-1)]*G[{1/(yu*yv)}, yw]^2*G[{1, yv^(-1)}, yw] + 
     3*G[{1}, yv^(-1)]*G[{1/(yu*yv)}, yw]^2*G[{1, yv^(-1)}, yw] - 
     5*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2*G[{1, yv^(-1)}, yw] + 
     G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2*G[{1, yv^(-1)}, yw] + 
     2*G[{1}, yu^(-1)]*G[{0, 1}, yu^(-1)]*G[{1, yv^(-1)}, yw] + 
     2*G[{1}, yw]*G[{0, 1}, yu^(-1)]*G[{1, yv^(-1)}, yw] + 
     2*G[{yu^(-1)}, yw]*G[{0, 1}, yu^(-1)]*G[{1, yv^(-1)}, yw] - 
     2*G[{yu}, yv^(-1)]*G[{0, 1}, yu^(-1)]*G[{1, yv^(-1)}, yw] + 
     6*G[{yv^(-1)}, yw]*G[{0, 1}, yu^(-1)]*G[{1, yv^(-1)}, yw] - 
     2*G[{1/(yu*yv)}, yw]*G[{0, 1}, yu^(-1)]*G[{1, yv^(-1)}, yw] + 
     2*G[{1}, yu^(-1)]*G[{0, 1}, yv^(-1)]*G[{1, yv^(-1)}, yw] + 
     2*G[{1}, yw]*G[{0, 1}, yv^(-1)]*G[{1, yv^(-1)}, yw] - 
     2*G[{yu^(-1)}, yw]*G[{0, 1}, yv^(-1)]*G[{1, yv^(-1)}, yw] - 
     2*G[{yu}, yv^(-1)]*G[{0, 1}, yv^(-1)]*G[{1, yv^(-1)}, yw] + 
     2*G[{yv^(-1)}, yw]*G[{0, 1}, yv^(-1)]*G[{1, yv^(-1)}, yw] + 
     2*G[{1/(yu*yv)}, yw]*G[{0, 1}, yv^(-1)]*G[{1, yv^(-1)}, yw] + 
     2*G[{1}, yu^(-1)]*G[{0, 1}, yw]*G[{1, yv^(-1)}, yw] + 
     4*G[{1}, yw]*G[{0, 1}, yw]*G[{1, yv^(-1)}, yw] - 
     2*G[{yu^(-1)}, yw]*G[{0, 1}, yw]*G[{1, yv^(-1)}, yw] - 
     2*G[{yu}, yv^(-1)]*G[{0, 1}, yw]*G[{1, yv^(-1)}, yw] + 
     2*G[{yv^(-1)}, yw]*G[{0, 1}, yw]*G[{1, yv^(-1)}, yw] + 
     2*G[{1/(yu*yv)}, yw]*G[{0, 1}, yw]*G[{1, yv^(-1)}, yw] - 
     2*G[{1}, yu^(-1)]*G[{0, yu^(-1)}, yw]*G[{1, yv^(-1)}, yw] - 
     4*G[{1}, yw]*G[{0, yu^(-1)}, yw]*G[{1, yv^(-1)}, yw] + 
     2*G[{yu^(-1)}, yw]*G[{0, yu^(-1)}, yw]*G[{1, yv^(-1)}, yw] + 
     2*G[{yu}, yv^(-1)]*G[{0, yu^(-1)}, yw]*G[{1, yv^(-1)}, yw] - 
     2*G[{yv^(-1)}, yw]*G[{0, yu^(-1)}, yw]*G[{1, yv^(-1)}, yw] - 
     2*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1)}, yw]*G[{1, yv^(-1)}, yw] - 
     2*G[{1}, yu^(-1)]*G[{0, yu}, yv^(-1)]*G[{1, yv^(-1)}, yw] - 
     2*G[{1}, yw]*G[{0, yu}, yv^(-1)]*G[{1, yv^(-1)}, yw] + 
     2*G[{yu^(-1)}, yw]*G[{0, yu}, yv^(-1)]*G[{1, yv^(-1)}, yw] + 
     2*G[{yu}, yv^(-1)]*G[{0, yu}, yv^(-1)]*G[{1, yv^(-1)}, yw] - 
     2*G[{yv^(-1)}, yw]*G[{0, yu}, yv^(-1)]*G[{1, yv^(-1)}, yw] - 
     2*G[{1/(yu*yv)}, yw]*G[{0, yu}, yv^(-1)]*G[{1, yv^(-1)}, yw] - 
     2*G[{1}, yu^(-1)]*G[{0, yv^(-1)}, yw]*G[{1, yv^(-1)}, yw] - 
     4*G[{1}, yw]*G[{0, yv^(-1)}, yw]*G[{1, yv^(-1)}, yw] + 
     2*G[{yu^(-1)}, yw]*G[{0, yv^(-1)}, yw]*G[{1, yv^(-1)}, yw] + 
     2*G[{yu}, yv^(-1)]*G[{0, yv^(-1)}, yw]*G[{1, yv^(-1)}, yw] - 
     2*G[{yv^(-1)}, yw]*G[{0, yv^(-1)}, yw]*G[{1, yv^(-1)}, yw] - 
     2*G[{1/(yu*yv)}, yw]*G[{0, yv^(-1)}, yw]*G[{1, yv^(-1)}, yw] + 
     2*G[{1}, yu^(-1)]*G[{0, 1/(yu*yv)}, yw]*G[{1, yv^(-1)}, yw] + 
     4*G[{1}, yw]*G[{0, 1/(yu*yv)}, yw]*G[{1, yv^(-1)}, yw] - 
     2*G[{yu^(-1)}, yw]*G[{0, 1/(yu*yv)}, yw]*G[{1, yv^(-1)}, yw] - 
     2*G[{yu}, yv^(-1)]*G[{0, 1/(yu*yv)}, yw]*G[{1, yv^(-1)}, yw] + 
     2*G[{yv^(-1)}, yw]*G[{0, 1/(yu*yv)}, yw]*G[{1, yv^(-1)}, yw] + 
     2*G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv)}, yw]*G[{1, yv^(-1)}, yw] + 
     4*G[{1}, yu^(-1)]*G[{1, yu^(-1)}, yw]*G[{1, yv^(-1)}, yw] + 
     4*G[{1}, yw]*G[{1, yu^(-1)}, yw]*G[{1, yv^(-1)}, yw] - 
     4*G[{yu^(-1)}, yw]*G[{1, yu^(-1)}, yw]*G[{1, yv^(-1)}, yw] - 
     4*G[{yu}, yv^(-1)]*G[{1, yu^(-1)}, yw]*G[{1, yv^(-1)}, yw] + 
     4*G[{yv^(-1)}, yw]*G[{1, yu^(-1)}, yw]*G[{1, yv^(-1)}, yw] + 
     4*G[{1/(yu*yv)}, yw]*G[{1, yu^(-1)}, yw]*G[{1, yv^(-1)}, yw] + 
     4*G[{1}, yu^(-1)]*G[{1, yu}, yv^(-1)]*G[{1, yv^(-1)}, yw] - 
     4*G[{yu^(-1)}, yw]*G[{1, yu}, yv^(-1)]*G[{1, yv^(-1)}, yw] - 
     4*G[{yv^(-1)}, yw]*G[{1, yu}, yv^(-1)]*G[{1, yv^(-1)}, yw] + 
     4*G[{1/(yu*yv)}, yw]*G[{1, yu}, yv^(-1)]*G[{1, yv^(-1)}, yw] + 
     4*G[{yv^(-1)}, yw]*G[{1, yv^(-1)}, yw]^2 + Pi^2*G[{yu^(-1)}, yw]*
      G[{1, 1/(yu*yv)}, yw] + 4*G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*
      G[{yu^(-1)}, yw]*G[{1, 1/(yu*yv)}, yw] + 2*G[{0}, yu^(-1)]*G[{1}, yw]*
      G[{yu^(-1)}, yw]*G[{1, 1/(yu*yv)}, yw] + 2*G[{0}, yv^(-1)]*G[{1}, yw]*
      G[{yu^(-1)}, yw]*G[{1, 1/(yu*yv)}, yw] - 2*G[{0}, yw]*G[{1}, yw]*
      G[{yu^(-1)}, yw]*G[{1, 1/(yu*yv)}, yw] + 2*G[{1}, yw]^2*
      G[{yu^(-1)}, yw]*G[{1, 1/(yu*yv)}, yw] - 2*G[{0}, yu^(-1)]*
      G[{yu^(-1)}, yw]^2*G[{1, 1/(yu*yv)}, yw] - 2*G[{0}, yv^(-1)]*
      G[{yu^(-1)}, yw]^2*G[{1, 1/(yu*yv)}, yw] + 
     2*G[{0}, yw]*G[{yu^(-1)}, yw]^2*G[{1, 1/(yu*yv)}, yw] + 
     2*G[{1}, yu^(-1)]*G[{yu^(-1)}, yw]^2*G[{1, 1/(yu*yv)}, yw] + 
     2*G[{1}, yv^(-1)]*G[{yu^(-1)}, yw]^2*G[{1, 1/(yu*yv)}, yw] - 
     (2*G[{yu^(-1)}, yw]^3*G[{1, 1/(yu*yv)}, yw])/3 - 
     4*G[{1}, yu^(-1)]*G[{yu^(-1)}, yw]*G[{yu}, yv^(-1)]*
      G[{1, 1/(yu*yv)}, yw] - 4*G[{1}, yv^(-1)]*G[{yu^(-1)}, yw]*
      G[{yu}, yv^(-1)]*G[{1, 1/(yu*yv)}, yw] - 4*G[{1}, yw]*G[{yu^(-1)}, yw]*
      G[{yu}, yv^(-1)]*G[{1, 1/(yu*yv)}, yw] + 4*G[{yu^(-1)}, yw]*
      G[{yu}, yv^(-1)]^2*G[{1, 1/(yu*yv)}, yw] - Pi^2*G[{yv^(-1)}, yw]*
      G[{1, 1/(yu*yv)}, yw] - 4*G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*
      G[{yv^(-1)}, yw]*G[{1, 1/(yu*yv)}, yw] - 2*G[{0}, yu^(-1)]*G[{1}, yw]*
      G[{yv^(-1)}, yw]*G[{1, 1/(yu*yv)}, yw] - 2*G[{0}, yv^(-1)]*G[{1}, yw]*
      G[{yv^(-1)}, yw]*G[{1, 1/(yu*yv)}, yw] + 2*G[{0}, yw]*G[{1}, yw]*
      G[{yv^(-1)}, yw]*G[{1, 1/(yu*yv)}, yw] - 2*G[{1}, yw]^2*
      G[{yv^(-1)}, yw]*G[{1, 1/(yu*yv)}, yw] - 2*G[{yu^(-1)}, yw]^2*
      G[{yv^(-1)}, yw]*G[{1, 1/(yu*yv)}, yw] + 4*G[{1}, yu^(-1)]*
      G[{yu}, yv^(-1)]*G[{yv^(-1)}, yw]*G[{1, 1/(yu*yv)}, yw] + 
     4*G[{1}, yv^(-1)]*G[{yu}, yv^(-1)]*G[{yv^(-1)}, yw]*
      G[{1, 1/(yu*yv)}, yw] + 4*G[{1}, yw]*G[{yu}, yv^(-1)]*G[{yv^(-1)}, yw]*
      G[{1, 1/(yu*yv)}, yw] - 4*G[{yu}, yv^(-1)]^2*G[{yv^(-1)}, yw]*
      G[{1, 1/(yu*yv)}, yw] + 2*G[{0}, yu^(-1)]*G[{yv^(-1)}, yw]^2*
      G[{1, 1/(yu*yv)}, yw] + 2*G[{0}, yv^(-1)]*G[{yv^(-1)}, yw]^2*
      G[{1, 1/(yu*yv)}, yw] - 2*G[{0}, yw]*G[{yv^(-1)}, yw]^2*
      G[{1, 1/(yu*yv)}, yw] - 2*G[{1}, yu^(-1)]*G[{yv^(-1)}, yw]^2*
      G[{1, 1/(yu*yv)}, yw] - 2*G[{1}, yv^(-1)]*G[{yv^(-1)}, yw]^2*
      G[{1, 1/(yu*yv)}, yw] + 2*G[{yu^(-1)}, yw]*G[{yv^(-1)}, yw]^2*
      G[{1, 1/(yu*yv)}, yw] + (2*G[{yv^(-1)}, yw]^3*G[{1, 1/(yu*yv)}, yw])/
      3 - Pi^2*G[{1/(yu*yv)}, yw]*G[{1, 1/(yu*yv)}, yw] - 
     4*G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*G[{1/(yu*yv)}, yw]*
      G[{1, 1/(yu*yv)}, yw] - 2*G[{0}, yu^(-1)]*G[{1}, yw]*G[{1/(yu*yv)}, yw]*
      G[{1, 1/(yu*yv)}, yw] - 2*G[{0}, yv^(-1)]*G[{1}, yw]*G[{1/(yu*yv)}, yw]*
      G[{1, 1/(yu*yv)}, yw] + 2*G[{0}, yw]*G[{1}, yw]*G[{1/(yu*yv)}, yw]*
      G[{1, 1/(yu*yv)}, yw] - 2*G[{1}, yw]^2*G[{1/(yu*yv)}, yw]*
      G[{1, 1/(yu*yv)}, yw] + 4*G[{0}, yu^(-1)]*G[{yu^(-1)}, yw]*
      G[{1/(yu*yv)}, yw]*G[{1, 1/(yu*yv)}, yw] + 4*G[{0}, yv^(-1)]*
      G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{1, 1/(yu*yv)}, yw] - 
     4*G[{0}, yw]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{1, 1/(yu*yv)}, yw] - 
     4*G[{1}, yu^(-1)]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*
      G[{1, 1/(yu*yv)}, yw] - 4*G[{1}, yv^(-1)]*G[{yu^(-1)}, yw]*
      G[{1/(yu*yv)}, yw]*G[{1, 1/(yu*yv)}, yw] + 2*G[{yu^(-1)}, yw]^2*
      G[{1/(yu*yv)}, yw]*G[{1, 1/(yu*yv)}, yw] + 4*G[{1}, yu^(-1)]*
      G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{1, 1/(yu*yv)}, yw] + 
     4*G[{1}, yv^(-1)]*G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw]*
      G[{1, 1/(yu*yv)}, yw] + 4*G[{1}, yw]*G[{yu}, yv^(-1)]*
      G[{1/(yu*yv)}, yw]*G[{1, 1/(yu*yv)}, yw] - 4*G[{yu}, yv^(-1)]^2*
      G[{1/(yu*yv)}, yw]*G[{1, 1/(yu*yv)}, yw] + 4*G[{yu^(-1)}, yw]*
      G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{1, 1/(yu*yv)}, yw] - 
     2*G[{yv^(-1)}, yw]^2*G[{1/(yu*yv)}, yw]*G[{1, 1/(yu*yv)}, yw] - 
     2*G[{0}, yu^(-1)]*G[{1/(yu*yv)}, yw]^2*G[{1, 1/(yu*yv)}, yw] - 
     2*G[{0}, yv^(-1)]*G[{1/(yu*yv)}, yw]^2*G[{1, 1/(yu*yv)}, yw] + 
     2*G[{0}, yw]*G[{1/(yu*yv)}, yw]^2*G[{1, 1/(yu*yv)}, yw] + 
     2*G[{1}, yu^(-1)]*G[{1/(yu*yv)}, yw]^2*G[{1, 1/(yu*yv)}, yw] + 
     2*G[{1}, yv^(-1)]*G[{1/(yu*yv)}, yw]^2*G[{1, 1/(yu*yv)}, yw] - 
     2*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2*G[{1, 1/(yu*yv)}, yw] + 
     2*G[{yu^(-1)}, yw]*G[{0, 1}, yu^(-1)]*G[{1, 1/(yu*yv)}, yw] - 
     2*G[{yv^(-1)}, yw]*G[{0, 1}, yu^(-1)]*G[{1, 1/(yu*yv)}, yw] - 
     2*G[{1/(yu*yv)}, yw]*G[{0, 1}, yu^(-1)]*G[{1, 1/(yu*yv)}, yw] + 
     2*G[{yu^(-1)}, yw]*G[{0, 1}, yv^(-1)]*G[{1, 1/(yu*yv)}, yw] - 
     2*G[{yv^(-1)}, yw]*G[{0, 1}, yv^(-1)]*G[{1, 1/(yu*yv)}, yw] - 
     2*G[{1/(yu*yv)}, yw]*G[{0, 1}, yv^(-1)]*G[{1, 1/(yu*yv)}, yw] + 
     2*G[{yu^(-1)}, yw]*G[{0, 1}, yw]*G[{1, 1/(yu*yv)}, yw] - 
     2*G[{yv^(-1)}, yw]*G[{0, 1}, yw]*G[{1, 1/(yu*yv)}, yw] - 
     2*G[{1/(yu*yv)}, yw]*G[{0, 1}, yw]*G[{1, 1/(yu*yv)}, yw] - 
     2*G[{yu^(-1)}, yw]*G[{0, yu^(-1)}, yw]*G[{1, 1/(yu*yv)}, yw] + 
     2*G[{yv^(-1)}, yw]*G[{0, yu^(-1)}, yw]*G[{1, 1/(yu*yv)}, yw] + 
     2*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1)}, yw]*G[{1, 1/(yu*yv)}, yw] - 
     2*G[{yu^(-1)}, yw]*G[{0, yu}, yv^(-1)]*G[{1, 1/(yu*yv)}, yw] + 
     2*G[{yv^(-1)}, yw]*G[{0, yu}, yv^(-1)]*G[{1, 1/(yu*yv)}, yw] + 
     2*G[{1/(yu*yv)}, yw]*G[{0, yu}, yv^(-1)]*G[{1, 1/(yu*yv)}, yw] - 
     2*G[{yu^(-1)}, yw]*G[{0, yv^(-1)}, yw]*G[{1, 1/(yu*yv)}, yw] + 
     2*G[{yv^(-1)}, yw]*G[{0, yv^(-1)}, yw]*G[{1, 1/(yu*yv)}, yw] + 
     2*G[{1/(yu*yv)}, yw]*G[{0, yv^(-1)}, yw]*G[{1, 1/(yu*yv)}, yw] + 
     2*G[{yu^(-1)}, yw]*G[{0, 1/(yu*yv)}, yw]*G[{1, 1/(yu*yv)}, yw] - 
     2*G[{yv^(-1)}, yw]*G[{0, 1/(yu*yv)}, yw]*G[{1, 1/(yu*yv)}, yw] - 
     2*G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv)}, yw]*G[{1, 1/(yu*yv)}, yw] + 
     4*G[{yu^(-1)}, yw]*G[{1, yu^(-1)}, yw]*G[{1, 1/(yu*yv)}, yw] - 
     4*G[{yv^(-1)}, yw]*G[{1, yu^(-1)}, yw]*G[{1, 1/(yu*yv)}, yw] - 
     4*G[{1/(yu*yv)}, yw]*G[{1, yu^(-1)}, yw]*G[{1, 1/(yu*yv)}, yw] + 
     4*G[{yu^(-1)}, yw]*G[{1, yv^(-1)}, yw]*G[{1, 1/(yu*yv)}, yw] - 
     4*G[{yv^(-1)}, yw]*G[{1, yv^(-1)}, yw]*G[{1, 1/(yu*yv)}, yw] - 
     4*G[{1/(yu*yv)}, yw]*G[{1, yv^(-1)}, yw]*G[{1, 1/(yu*yv)}, yw] - 
     2*G[{yu^(-1)}, yw]*G[{1, 1/(yu*yv)}, yw]^2 + 2*G[{yv^(-1)}, yw]*
      G[{1, 1/(yu*yv)}, yw]^2 + 2*G[{1/(yu*yv)}, yw]*
      G[{1, 1/(yu*yv)}, yw]^2 - Pi^2*G[{1}, yu^(-1)]*
      G[{yu^(-1), 1/(yu*yv)}, yw] - 2*G[{0}, yu^(-1)]*G[{1}, yu^(-1)]*
      G[{1}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw] - 2*G[{0}, yv^(-1)]*
      G[{1}, yu^(-1)]*G[{1}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw] + 
     2*G[{0}, yw]*G[{1}, yu^(-1)]*G[{1}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw] + 
     2*G[{1}, yu^(-1)]^2*G[{1}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw] + 
     G[{0}, yu^(-1)]*G[{1}, yw]^2*G[{yu^(-1), 1/(yu*yv)}, yw] + 
     G[{0}, yv^(-1)]*G[{1}, yw]^2*G[{yu^(-1), 1/(yu*yv)}, yw] - 
     G[{0}, yw]*G[{1}, yw]^2*G[{yu^(-1), 1/(yu*yv)}, yw] - 
     G[{1}, yu^(-1)]*G[{1}, yw]^2*G[{yu^(-1), 1/(yu*yv)}, yw] - 
     G[{1}, yv^(-1)]*G[{1}, yw]^2*G[{yu^(-1), 1/(yu*yv)}, yw] - 
     Pi^2*G[{yu^(-1)}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw] + 
     2*G[{0}, yu^(-1)]*G[{1}, yu^(-1)]*G[{yu^(-1)}, yw]*
      G[{yu^(-1), 1/(yu*yv)}, yw] + 2*G[{0}, yv^(-1)]*G[{1}, yu^(-1)]*
      G[{yu^(-1)}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw] - 
     2*G[{0}, yw]*G[{1}, yu^(-1)]*G[{yu^(-1)}, yw]*G[{yu^(-1), 1/(yu*yv)}, 
       yw] - 2*G[{1}, yu^(-1)]^2*G[{yu^(-1)}, yw]*G[{yu^(-1), 1/(yu*yv)}, 
       yw] - 4*G[{0}, yu^(-1)]*G[{1}, yw]*G[{yu^(-1)}, yw]*
      G[{yu^(-1), 1/(yu*yv)}, yw] - 4*G[{0}, yv^(-1)]*G[{1}, yw]*
      G[{yu^(-1)}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw] + 
     4*G[{0}, yw]*G[{1}, yw]*G[{yu^(-1)}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw] + 
     6*G[{1}, yu^(-1)]*G[{1}, yw]*G[{yu^(-1)}, yw]*G[{yu^(-1), 1/(yu*yv)}, 
       yw] + 6*G[{1}, yv^(-1)]*G[{1}, yw]*G[{yu^(-1)}, yw]*
      G[{yu^(-1), 1/(yu*yv)}, yw] + 2*G[{1}, yw]^2*G[{yu^(-1)}, yw]*
      G[{yu^(-1), 1/(yu*yv)}, yw] + 3*G[{0}, yu^(-1)]*G[{yu^(-1)}, yw]^2*
      G[{yu^(-1), 1/(yu*yv)}, yw] + 3*G[{0}, yv^(-1)]*G[{yu^(-1)}, yw]^2*
      G[{yu^(-1), 1/(yu*yv)}, yw] - 3*G[{0}, yw]*G[{yu^(-1)}, yw]^2*
      G[{yu^(-1), 1/(yu*yv)}, yw] - 3*G[{1}, yu^(-1)]*G[{yu^(-1)}, yw]^2*
      G[{yu^(-1), 1/(yu*yv)}, yw] - 3*G[{1}, yv^(-1)]*G[{yu^(-1)}, yw]^2*
      G[{yu^(-1), 1/(yu*yv)}, yw] + G[{yu^(-1)}, yw]^3*
      G[{yu^(-1), 1/(yu*yv)}, yw] + Pi^2*G[{yu}, yv^(-1)]*
      G[{yu^(-1), 1/(yu*yv)}, yw] + 4*G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*
      G[{yu}, yv^(-1)]*G[{yu^(-1), 1/(yu*yv)}, yw] + 
     2*G[{0}, yu^(-1)]*G[{1}, yw]*G[{yu}, yv^(-1)]*G[{yu^(-1), 1/(yu*yv)}, 
       yw] + 2*G[{0}, yv^(-1)]*G[{1}, yw]*G[{yu}, yv^(-1)]*
      G[{yu^(-1), 1/(yu*yv)}, yw] - 2*G[{0}, yw]*G[{1}, yw]*G[{yu}, yv^(-1)]*
      G[{yu^(-1), 1/(yu*yv)}, yw] - 2*G[{0}, yu^(-1)]*G[{yu^(-1)}, yw]*
      G[{yu}, yv^(-1)]*G[{yu^(-1), 1/(yu*yv)}, yw] - 
     2*G[{0}, yv^(-1)]*G[{yu^(-1)}, yw]*G[{yu}, yv^(-1)]*
      G[{yu^(-1), 1/(yu*yv)}, yw] + 2*G[{0}, yw]*G[{yu^(-1)}, yw]*
      G[{yu}, yv^(-1)]*G[{yu^(-1), 1/(yu*yv)}, yw] - 
     4*G[{1}, yw]*G[{yu^(-1)}, yw]*G[{yu}, yv^(-1)]*G[{yu^(-1), 1/(yu*yv)}, 
       yw] - 2*G[{1}, yu^(-1)]*G[{yu}, yv^(-1)]^2*G[{yu^(-1), 1/(yu*yv)}, 
       yw] - 2*G[{1}, yv^(-1)]*G[{yu}, yv^(-1)]^2*G[{yu^(-1), 1/(yu*yv)}, 
       yw] - 2*G[{1}, yw]*G[{yu}, yv^(-1)]^2*G[{yu^(-1), 1/(yu*yv)}, yw] + 
     2*G[{yu^(-1)}, yw]*G[{yu}, yv^(-1)]^2*G[{yu^(-1), 1/(yu*yv)}, yw] + 
     (4*G[{yu}, yv^(-1)]^3*G[{yu^(-1), 1/(yu*yv)}, yw])/3 - 
     (2*Pi^2*G[{yv^(-1)}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw])/3 + 
     2*G[{0}, yu^(-1)]*G[{1}, yu^(-1)]*G[{yv^(-1)}, yw]*
      G[{yu^(-1), 1/(yu*yv)}, yw] + 2*G[{0}, yv^(-1)]*G[{1}, yu^(-1)]*
      G[{yv^(-1)}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw] - 
     2*G[{0}, yw]*G[{1}, yu^(-1)]*G[{yv^(-1)}, yw]*G[{yu^(-1), 1/(yu*yv)}, 
       yw] - 4*G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*G[{yv^(-1)}, yw]*
      G[{yu^(-1), 1/(yu*yv)}, yw] - 2*G[{0}, yu^(-1)]*G[{1}, yw]*
      G[{yv^(-1)}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw] - 
     2*G[{0}, yv^(-1)]*G[{1}, yw]*G[{yv^(-1)}, yw]*G[{yu^(-1), 1/(yu*yv)}, 
       yw] + 2*G[{0}, yw]*G[{1}, yw]*G[{yv^(-1)}, yw]*
      G[{yu^(-1), 1/(yu*yv)}, yw] + 4*G[{1}, yu^(-1)]*G[{1}, yw]*
      G[{yv^(-1)}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw] + 
     4*G[{0}, yu^(-1)]*G[{yu^(-1)}, yw]*G[{yv^(-1)}, yw]*
      G[{yu^(-1), 1/(yu*yv)}, yw] + 4*G[{0}, yv^(-1)]*G[{yu^(-1)}, yw]*
      G[{yv^(-1)}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw] - 
     4*G[{0}, yw]*G[{yu^(-1)}, yw]*G[{yv^(-1)}, yw]*G[{yu^(-1), 1/(yu*yv)}, 
       yw] - 8*G[{1}, yv^(-1)]*G[{yu^(-1)}, yw]*G[{yv^(-1)}, yw]*
      G[{yu^(-1), 1/(yu*yv)}, yw] + 4*G[{yu^(-1)}, yw]^2*G[{yv^(-1)}, yw]*
      G[{yu^(-1), 1/(yu*yv)}, yw] - 2*G[{0}, yu^(-1)]*G[{yu}, yv^(-1)]*
      G[{yv^(-1)}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw] - 
     2*G[{0}, yv^(-1)]*G[{yu}, yv^(-1)]*G[{yv^(-1)}, yw]*
      G[{yu^(-1), 1/(yu*yv)}, yw] + 2*G[{0}, yw]*G[{yu}, yv^(-1)]*
      G[{yv^(-1)}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw] + 
     2*G[{yu}, yv^(-1)]^2*G[{yv^(-1)}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw] + 
     G[{0}, yu^(-1)]*G[{yv^(-1)}, yw]^2*G[{yu^(-1), 1/(yu*yv)}, yw] + 
     G[{0}, yv^(-1)]*G[{yv^(-1)}, yw]^2*G[{yu^(-1), 1/(yu*yv)}, yw] - 
     G[{0}, yw]*G[{yv^(-1)}, yw]^2*G[{yu^(-1), 1/(yu*yv)}, yw] - 
     G[{1}, yu^(-1)]*G[{yv^(-1)}, yw]^2*G[{yu^(-1), 1/(yu*yv)}, yw] - 
     G[{1}, yv^(-1)]*G[{yv^(-1)}, yw]^2*G[{yu^(-1), 1/(yu*yv)}, yw] + 
     G[{yu^(-1)}, yw]*G[{yv^(-1)}, yw]^2*G[{yu^(-1), 1/(yu*yv)}, yw] - 
     (2*G[{yv^(-1)}, yw]^3*G[{yu^(-1), 1/(yu*yv)}, yw])/3 + 
     (2*Pi^2*G[{1/(yu*yv)}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw])/3 - 
     2*G[{0}, yu^(-1)]*G[{1}, yu^(-1)]*G[{1/(yu*yv)}, yw]*
      G[{yu^(-1), 1/(yu*yv)}, yw] - 2*G[{0}, yv^(-1)]*G[{1}, yu^(-1)]*
      G[{1/(yu*yv)}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw] + 
     2*G[{0}, yw]*G[{1}, yu^(-1)]*G[{1/(yu*yv)}, yw]*
      G[{yu^(-1), 1/(yu*yv)}, yw] + 8*G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*
      G[{1/(yu*yv)}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw] + 
     2*G[{0}, yu^(-1)]*G[{1}, yw]*G[{1/(yu*yv)}, yw]*
      G[{yu^(-1), 1/(yu*yv)}, yw] + 2*G[{0}, yv^(-1)]*G[{1}, yw]*
      G[{1/(yu*yv)}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw] - 
     2*G[{0}, yw]*G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw] + 
     4*G[{1}, yv^(-1)]*G[{1}, yw]*G[{1/(yu*yv)}, yw]*
      G[{yu^(-1), 1/(yu*yv)}, yw] + 4*G[{1}, yw]^2*G[{1/(yu*yv)}, yw]*
      G[{yu^(-1), 1/(yu*yv)}, yw] - 4*G[{0}, yu^(-1)]*G[{yu^(-1)}, yw]*
      G[{1/(yu*yv)}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw] - 
     4*G[{0}, yv^(-1)]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*
      G[{yu^(-1), 1/(yu*yv)}, yw] + 4*G[{0}, yw]*G[{yu^(-1)}, yw]*
      G[{1/(yu*yv)}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw] - 
     4*G[{1}, yu^(-1)]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*
      G[{yu^(-1), 1/(yu*yv)}, yw] + 8*G[{1}, yv^(-1)]*G[{yu^(-1)}, yw]*
      G[{1/(yu*yv)}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw] - 
     4*G[{1}, yw]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*
      G[{yu^(-1), 1/(yu*yv)}, yw] - 4*G[{yu^(-1)}, yw]^2*G[{1/(yu*yv)}, yw]*
      G[{yu^(-1), 1/(yu*yv)}, yw] + 2*G[{0}, yu^(-1)]*G[{yu}, yv^(-1)]*
      G[{1/(yu*yv)}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw] + 
     2*G[{0}, yv^(-1)]*G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw]*
      G[{yu^(-1), 1/(yu*yv)}, yw] - 2*G[{0}, yw]*G[{yu}, yv^(-1)]*
      G[{1/(yu*yv)}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw] - 
     4*G[{1}, yu^(-1)]*G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw]*
      G[{yu^(-1), 1/(yu*yv)}, yw] - 4*G[{1}, yv^(-1)]*G[{yu}, yv^(-1)]*
      G[{1/(yu*yv)}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw] - 
     8*G[{1}, yw]*G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw]*
      G[{yu^(-1), 1/(yu*yv)}, yw] + 4*G[{yu^(-1)}, yw]*G[{yu}, yv^(-1)]*
      G[{1/(yu*yv)}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw] + 
     2*G[{yu}, yv^(-1)]^2*G[{1/(yu*yv)}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw] - 
     2*G[{0}, yu^(-1)]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*
      G[{yu^(-1), 1/(yu*yv)}, yw] - 2*G[{0}, yv^(-1)]*G[{yv^(-1)}, yw]*
      G[{1/(yu*yv)}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw] + 
     2*G[{0}, yw]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*
      G[{yu^(-1), 1/(yu*yv)}, yw] - 2*G[{1}, yu^(-1)]*G[{yv^(-1)}, yw]*
      G[{1/(yu*yv)}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw] + 
     2*G[{1}, yv^(-1)]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*
      G[{yu^(-1), 1/(yu*yv)}, yw] - 4*G[{1}, yw]*G[{yv^(-1)}, yw]*
      G[{1/(yu*yv)}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw] - 
     2*G[{yu^(-1)}, yw]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*
      G[{yu^(-1), 1/(yu*yv)}, yw] + 4*G[{yu}, yv^(-1)]*G[{yv^(-1)}, yw]*
      G[{1/(yu*yv)}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw] + 
     2*G[{yv^(-1)}, yw]^2*G[{1/(yu*yv)}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw] + 
     G[{0}, yu^(-1)]*G[{1/(yu*yv)}, yw]^2*G[{yu^(-1), 1/(yu*yv)}, yw] + 
     G[{0}, yv^(-1)]*G[{1/(yu*yv)}, yw]^2*G[{yu^(-1), 1/(yu*yv)}, yw] - 
     G[{0}, yw]*G[{1/(yu*yv)}, yw]^2*G[{yu^(-1), 1/(yu*yv)}, yw] + 
     3*G[{1}, yu^(-1)]*G[{1/(yu*yv)}, yw]^2*G[{yu^(-1), 1/(yu*yv)}, yw] - 
     5*G[{1}, yv^(-1)]*G[{1/(yu*yv)}, yw]^2*G[{yu^(-1), 1/(yu*yv)}, yw] + 
     5*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2*G[{yu^(-1), 1/(yu*yv)}, yw] - 
     G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2*G[{yu^(-1), 1/(yu*yv)}, yw] - 
     2*G[{1}, yu^(-1)]*G[{0, 1}, yu^(-1)]*G[{yu^(-1), 1/(yu*yv)}, yw] - 
     2*G[{1}, yw]*G[{0, 1}, yu^(-1)]*G[{yu^(-1), 1/(yu*yv)}, yw] + 
     2*G[{yu}, yv^(-1)]*G[{0, 1}, yu^(-1)]*G[{yu^(-1), 1/(yu*yv)}, yw] - 
     2*G[{1}, yu^(-1)]*G[{0, 1}, yv^(-1)]*G[{yu^(-1), 1/(yu*yv)}, yw] - 
     2*G[{1}, yw]*G[{0, 1}, yv^(-1)]*G[{yu^(-1), 1/(yu*yv)}, yw] + 
     2*G[{yu}, yv^(-1)]*G[{0, 1}, yv^(-1)]*G[{yu^(-1), 1/(yu*yv)}, yw] + 
     4*G[{yv^(-1)}, yw]*G[{0, 1}, yv^(-1)]*G[{yu^(-1), 1/(yu*yv)}, yw] - 
     4*G[{1/(yu*yv)}, yw]*G[{0, 1}, yv^(-1)]*G[{yu^(-1), 1/(yu*yv)}, yw] - 
     2*G[{1}, yu^(-1)]*G[{0, 1}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw] + 
     4*G[{1}, yw]*G[{0, 1}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw] - 
     6*G[{yu^(-1)}, yw]*G[{0, 1}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw] + 
     2*G[{yu}, yv^(-1)]*G[{0, 1}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw] - 
     4*G[{yv^(-1)}, yw]*G[{0, 1}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw] + 
     4*G[{1/(yu*yv)}, yw]*G[{0, 1}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw] + 
     2*G[{1}, yu^(-1)]*G[{0, yu^(-1)}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw] - 
     4*G[{1}, yw]*G[{0, yu^(-1)}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw] + 
     6*G[{yu^(-1)}, yw]*G[{0, yu^(-1)}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw] - 
     2*G[{yu}, yv^(-1)]*G[{0, yu^(-1)}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw] + 
     4*G[{yv^(-1)}, yw]*G[{0, yu^(-1)}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw] - 
     4*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1)}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw] + 
     2*G[{1}, yu^(-1)]*G[{0, yu}, yv^(-1)]*G[{yu^(-1), 1/(yu*yv)}, yw] + 
     2*G[{1}, yw]*G[{0, yu}, yv^(-1)]*G[{yu^(-1), 1/(yu*yv)}, yw] - 
     2*G[{yu}, yv^(-1)]*G[{0, yu}, yv^(-1)]*G[{yu^(-1), 1/(yu*yv)}, yw] - 
     4*G[{yv^(-1)}, yw]*G[{0, yu}, yv^(-1)]*G[{yu^(-1), 1/(yu*yv)}, yw] + 
     4*G[{1/(yu*yv)}, yw]*G[{0, yu}, yv^(-1)]*G[{yu^(-1), 1/(yu*yv)}, yw] + 
     2*G[{1}, yu^(-1)]*G[{0, yv^(-1)}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw] - 
     4*G[{1}, yw]*G[{0, yv^(-1)}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw] + 
     6*G[{yu^(-1)}, yw]*G[{0, yv^(-1)}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw] - 
     2*G[{yu}, yv^(-1)]*G[{0, yv^(-1)}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw] + 
     4*G[{yv^(-1)}, yw]*G[{0, yv^(-1)}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw] - 
     4*G[{1/(yu*yv)}, yw]*G[{0, yv^(-1)}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw] - 
     2*G[{1}, yu^(-1)]*G[{0, 1/(yu*yv)}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw] + 
     4*G[{1}, yw]*G[{0, 1/(yu*yv)}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw] - 
     6*G[{yu^(-1)}, yw]*G[{0, 1/(yu*yv)}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw] + 
     2*G[{yu}, yv^(-1)]*G[{0, 1/(yu*yv)}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw] - 
     4*G[{yv^(-1)}, yw]*G[{0, 1/(yu*yv)}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw] + 
     4*G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv)}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw] - 
     4*G[{1}, yu^(-1)]*G[{1, yu^(-1)}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw] - 
     4*G[{1}, yw]*G[{1, yu^(-1)}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw] - 
     6*G[{yu^(-1)}, yw]*G[{1, yu^(-1)}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw] + 
     4*G[{yu}, yv^(-1)]*G[{1, yu^(-1)}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw] - 
     4*G[{1}, yu^(-1)]*G[{1, yu}, yv^(-1)]*G[{yu^(-1), 1/(yu*yv)}, yw] + 
     4*G[{yv^(-1)}, yw]*G[{1, yu}, yv^(-1)]*G[{yu^(-1), 1/(yu*yv)}, yw] - 
     4*G[{1/(yu*yv)}, yw]*G[{1, yu}, yv^(-1)]*G[{yu^(-1), 1/(yu*yv)}, yw] - 
     6*G[{yu^(-1)}, yw]*G[{1, yv^(-1)}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw] - 
     4*G[{yv^(-1)}, yw]*G[{1, yv^(-1)}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw] + 
     4*G[{1/(yu*yv)}, yw]*G[{1, yv^(-1)}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw] - 
     4*G[{yv^(-1)}, yw]*G[{1, 1/(yu*yv)}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw] + 
     4*G[{1/(yu*yv)}, yw]*G[{1, 1/(yu*yv)}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw] + 
     4*G[{yv^(-1)}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw]^2 - 
     4*G[{1/(yu*yv)}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw]^2 + 
     Pi^2*G[{1}, yu^(-1)]*G[{yv^(-1), 1/(yu*yv)}, yw] + 
     (2*Pi^2*G[{1}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw])/3 + 
     2*G[{0}, yu^(-1)]*G[{1}, yu^(-1)]*G[{1}, yw]*G[{yv^(-1), 1/(yu*yv)}, 
       yw] + 2*G[{0}, yv^(-1)]*G[{1}, yu^(-1)]*G[{1}, yw]*
      G[{yv^(-1), 1/(yu*yv)}, yw] - 2*G[{0}, yw]*G[{1}, yu^(-1)]*G[{1}, yw]*
      G[{yv^(-1), 1/(yu*yv)}, yw] - 2*G[{1}, yu^(-1)]^2*G[{1}, yw]*
      G[{yv^(-1), 1/(yu*yv)}, yw] + G[{0}, yu^(-1)]*G[{1}, yw]^2*
      G[{yv^(-1), 1/(yu*yv)}, yw] + G[{0}, yv^(-1)]*G[{1}, yw]^2*
      G[{yv^(-1), 1/(yu*yv)}, yw] - G[{0}, yw]*G[{1}, yw]^2*
      G[{yv^(-1), 1/(yu*yv)}, yw] - G[{1}, yu^(-1)]*G[{1}, yw]^2*
      G[{yv^(-1), 1/(yu*yv)}, yw] - G[{1}, yv^(-1)]*G[{1}, yw]^2*
      G[{yv^(-1), 1/(yu*yv)}, yw] + (Pi^2*G[{yu^(-1)}, yw]*
       G[{yv^(-1), 1/(yu*yv)}, yw])/3 - 2*G[{0}, yu^(-1)]*G[{1}, yu^(-1)]*
      G[{yu^(-1)}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw] - 
     2*G[{0}, yv^(-1)]*G[{1}, yu^(-1)]*G[{yu^(-1)}, yw]*
      G[{yv^(-1), 1/(yu*yv)}, yw] + 2*G[{0}, yw]*G[{1}, yu^(-1)]*
      G[{yu^(-1)}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw] + 
     2*G[{1}, yu^(-1)]^2*G[{yu^(-1)}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw] - 
     2*G[{1}, yu^(-1)]*G[{1}, yw]*G[{yu^(-1)}, yw]*G[{yv^(-1), 1/(yu*yv)}, 
       yw] - 2*G[{1}, yv^(-1)]*G[{1}, yw]*G[{yu^(-1)}, yw]*
      G[{yv^(-1), 1/(yu*yv)}, yw] - 2*G[{1}, yw]^2*G[{yu^(-1)}, yw]*
      G[{yv^(-1), 1/(yu*yv)}, yw] - G[{0}, yu^(-1)]*G[{yu^(-1)}, yw]^2*
      G[{yv^(-1), 1/(yu*yv)}, yw] - G[{0}, yv^(-1)]*G[{yu^(-1)}, yw]^2*
      G[{yv^(-1), 1/(yu*yv)}, yw] + G[{0}, yw]*G[{yu^(-1)}, yw]^2*
      G[{yv^(-1), 1/(yu*yv)}, yw] + G[{1}, yu^(-1)]*G[{yu^(-1)}, yw]^2*
      G[{yv^(-1), 1/(yu*yv)}, yw] + G[{1}, yv^(-1)]*G[{yu^(-1)}, yw]^2*
      G[{yv^(-1), 1/(yu*yv)}, yw] - 
     (G[{yu^(-1)}, yw]^3*G[{yv^(-1), 1/(yu*yv)}, yw])/3 - 
     Pi^2*G[{yu}, yv^(-1)]*G[{yv^(-1), 1/(yu*yv)}, yw] - 
     4*G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*G[{yu}, yv^(-1)]*
      G[{yv^(-1), 1/(yu*yv)}, yw] - 2*G[{0}, yu^(-1)]*G[{1}, yw]*
      G[{yu}, yv^(-1)]*G[{yv^(-1), 1/(yu*yv)}, yw] - 
     2*G[{0}, yv^(-1)]*G[{1}, yw]*G[{yu}, yv^(-1)]*G[{yv^(-1), 1/(yu*yv)}, 
       yw] + 2*G[{0}, yw]*G[{1}, yw]*G[{yu}, yv^(-1)]*
      G[{yv^(-1), 1/(yu*yv)}, yw] + 2*G[{0}, yu^(-1)]*G[{yu^(-1)}, yw]*
      G[{yu}, yv^(-1)]*G[{yv^(-1), 1/(yu*yv)}, yw] + 
     2*G[{0}, yv^(-1)]*G[{yu^(-1)}, yw]*G[{yu}, yv^(-1)]*
      G[{yv^(-1), 1/(yu*yv)}, yw] - 2*G[{0}, yw]*G[{yu^(-1)}, yw]*
      G[{yu}, yv^(-1)]*G[{yv^(-1), 1/(yu*yv)}, yw] + 
     4*G[{1}, yw]*G[{yu^(-1)}, yw]*G[{yu}, yv^(-1)]*G[{yv^(-1), 1/(yu*yv)}, 
       yw] + 2*G[{1}, yu^(-1)]*G[{yu}, yv^(-1)]^2*G[{yv^(-1), 1/(yu*yv)}, 
       yw] + 2*G[{1}, yv^(-1)]*G[{yu}, yv^(-1)]^2*G[{yv^(-1), 1/(yu*yv)}, 
       yw] + 2*G[{1}, yw]*G[{yu}, yv^(-1)]^2*G[{yv^(-1), 1/(yu*yv)}, yw] - 
     2*G[{yu^(-1)}, yw]*G[{yu}, yv^(-1)]^2*G[{yv^(-1), 1/(yu*yv)}, yw] - 
     (4*G[{yu}, yv^(-1)]^3*G[{yv^(-1), 1/(yu*yv)}, yw])/3 - 
     (2*Pi^2*G[{yv^(-1)}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw])/3 - 
     2*G[{0}, yu^(-1)]*G[{1}, yu^(-1)]*G[{yv^(-1)}, yw]*
      G[{yv^(-1), 1/(yu*yv)}, yw] - 2*G[{0}, yv^(-1)]*G[{1}, yu^(-1)]*
      G[{yv^(-1)}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw] + 
     2*G[{0}, yw]*G[{1}, yu^(-1)]*G[{yv^(-1)}, yw]*G[{yv^(-1), 1/(yu*yv)}, 
       yw] + 2*G[{1}, yu^(-1)]^2*G[{yv^(-1)}, yw]*G[{yv^(-1), 1/(yu*yv)}, 
       yw] - 2*G[{0}, yu^(-1)]*G[{1}, yw]*G[{yv^(-1)}, yw]*
      G[{yv^(-1), 1/(yu*yv)}, yw] - 2*G[{0}, yv^(-1)]*G[{1}, yw]*
      G[{yv^(-1)}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw] + 
     2*G[{0}, yw]*G[{1}, yw]*G[{yv^(-1)}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw] + 
     2*G[{1}, yu^(-1)]*G[{1}, yw]*G[{yv^(-1)}, yw]*G[{yv^(-1), 1/(yu*yv)}, 
       yw] + 2*G[{1}, yv^(-1)]*G[{1}, yw]*G[{yv^(-1)}, yw]*
      G[{yv^(-1), 1/(yu*yv)}, yw] - 2*G[{1}, yu^(-1)]*G[{yu^(-1)}, yw]*
      G[{yv^(-1)}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw] + 
     2*G[{1}, yv^(-1)]*G[{yu^(-1)}, yw]*G[{yv^(-1)}, yw]*
      G[{yv^(-1), 1/(yu*yv)}, yw] - G[{yu^(-1)}, yw]^2*G[{yv^(-1)}, yw]*
      G[{yv^(-1), 1/(yu*yv)}, yw] + 2*G[{0}, yu^(-1)]*G[{yu}, yv^(-1)]*
      G[{yv^(-1)}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw] + 
     2*G[{0}, yv^(-1)]*G[{yu}, yv^(-1)]*G[{yv^(-1)}, yw]*
      G[{yv^(-1), 1/(yu*yv)}, yw] - 2*G[{0}, yw]*G[{yu}, yv^(-1)]*
      G[{yv^(-1)}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw] - 
     2*G[{yu}, yv^(-1)]^2*G[{yv^(-1)}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw] + 
     G[{0}, yu^(-1)]*G[{yv^(-1)}, yw]^2*G[{yv^(-1), 1/(yu*yv)}, yw] + 
     G[{0}, yv^(-1)]*G[{yv^(-1)}, yw]^2*G[{yv^(-1), 1/(yu*yv)}, yw] - 
     G[{0}, yw]*G[{yv^(-1)}, yw]^2*G[{yv^(-1), 1/(yu*yv)}, yw] - 
     G[{1}, yu^(-1)]*G[{yv^(-1)}, yw]^2*G[{yv^(-1), 1/(yu*yv)}, yw] - 
     G[{1}, yv^(-1)]*G[{yv^(-1)}, yw]^2*G[{yv^(-1), 1/(yu*yv)}, yw] + 
     G[{yu^(-1)}, yw]*G[{yv^(-1)}, yw]^2*G[{yv^(-1), 1/(yu*yv)}, yw] + 
     (G[{yv^(-1)}, yw]^3*G[{yv^(-1), 1/(yu*yv)}, yw])/3 + 
     (Pi^2*G[{1/(yu*yv)}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw])/3 + 
     2*G[{0}, yu^(-1)]*G[{1}, yu^(-1)]*G[{1/(yu*yv)}, yw]*
      G[{yv^(-1), 1/(yu*yv)}, yw] + 2*G[{0}, yv^(-1)]*G[{1}, yu^(-1)]*
      G[{1/(yu*yv)}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw] - 
     2*G[{0}, yw]*G[{1}, yu^(-1)]*G[{1/(yu*yv)}, yw]*
      G[{yv^(-1), 1/(yu*yv)}, yw] - 4*G[{1}, yu^(-1)]^2*G[{1/(yu*yv)}, yw]*
      G[{yv^(-1), 1/(yu*yv)}, yw] + 4*G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*
      G[{1/(yu*yv)}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw] + 
     4*G[{1}, yv^(-1)]*G[{1}, yw]*G[{1/(yu*yv)}, yw]*
      G[{yv^(-1), 1/(yu*yv)}, yw] + 2*G[{1}, yw]^2*G[{1/(yu*yv)}, yw]*
      G[{yv^(-1), 1/(yu*yv)}, yw] + 2*G[{0}, yu^(-1)]*G[{yu^(-1)}, yw]*
      G[{1/(yu*yv)}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw] + 
     2*G[{0}, yv^(-1)]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*
      G[{yv^(-1), 1/(yu*yv)}, yw] - 2*G[{0}, yw]*G[{yu^(-1)}, yw]*
      G[{1/(yu*yv)}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw] - 
     4*G[{1}, yu^(-1)]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*
      G[{yv^(-1), 1/(yu*yv)}, yw] - 2*G[{0}, yu^(-1)]*G[{yu}, yv^(-1)]*
      G[{1/(yu*yv)}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw] - 
     2*G[{0}, yv^(-1)]*G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw]*
      G[{yv^(-1), 1/(yu*yv)}, yw] + 2*G[{0}, yw]*G[{yu}, yv^(-1)]*
      G[{1/(yu*yv)}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw] - 
     4*G[{1}, yw]*G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw]*
      G[{yv^(-1), 1/(yu*yv)}, yw] + 2*G[{yu}, yv^(-1)]^2*G[{1/(yu*yv)}, yw]*
      G[{yv^(-1), 1/(yu*yv)}, yw] + 4*G[{1}, yu^(-1)]*G[{yv^(-1)}, yw]*
      G[{1/(yu*yv)}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw] - 
     4*G[{1}, yv^(-1)]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*
      G[{yv^(-1), 1/(yu*yv)}, yw] + 4*G[{yu^(-1)}, yw]*G[{yv^(-1)}, yw]*
      G[{1/(yu*yv)}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw] - 
     2*G[{yv^(-1)}, yw]^2*G[{1/(yu*yv)}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw] - 
     G[{0}, yu^(-1)]*G[{1/(yu*yv)}, yw]^2*G[{yv^(-1), 1/(yu*yv)}, yw] - 
     G[{0}, yv^(-1)]*G[{1/(yu*yv)}, yw]^2*G[{yv^(-1), 1/(yu*yv)}, yw] + 
     G[{0}, yw]*G[{1/(yu*yv)}, yw]^2*G[{yv^(-1), 1/(yu*yv)}, yw] + 
     3*G[{1}, yu^(-1)]*G[{1/(yu*yv)}, yw]^2*G[{yv^(-1), 1/(yu*yv)}, yw] - 
     3*G[{1}, yv^(-1)]*G[{1/(yu*yv)}, yw]^2*G[{yv^(-1), 1/(yu*yv)}, yw] - 
     2*G[{1}, yw]*G[{1/(yu*yv)}, yw]^2*G[{yv^(-1), 1/(yu*yv)}, yw] + 
     3*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2*G[{yv^(-1), 1/(yu*yv)}, yw] + 
     2*G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw]^2*G[{yv^(-1), 1/(yu*yv)}, yw] - 
     3*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2*G[{yv^(-1), 1/(yu*yv)}, yw] + 
     2*G[{1}, yu^(-1)]*G[{0, 1}, yu^(-1)]*G[{yv^(-1), 1/(yu*yv)}, yw] + 
     2*G[{1}, yw]*G[{0, 1}, yu^(-1)]*G[{yv^(-1), 1/(yu*yv)}, yw] - 
     2*G[{yu}, yv^(-1)]*G[{0, 1}, yu^(-1)]*G[{yv^(-1), 1/(yu*yv)}, yw] - 
     2*G[{yv^(-1)}, yw]*G[{0, 1}, yu^(-1)]*G[{yv^(-1), 1/(yu*yv)}, yw] + 
     2*G[{1/(yu*yv)}, yw]*G[{0, 1}, yu^(-1)]*G[{yv^(-1), 1/(yu*yv)}, yw] + 
     2*G[{1}, yu^(-1)]*G[{0, 1}, yv^(-1)]*G[{yv^(-1), 1/(yu*yv)}, yw] + 
     2*G[{1}, yw]*G[{0, 1}, yv^(-1)]*G[{yv^(-1), 1/(yu*yv)}, yw] - 
     2*G[{yu}, yv^(-1)]*G[{0, 1}, yv^(-1)]*G[{yv^(-1), 1/(yu*yv)}, yw] - 
     2*G[{yv^(-1)}, yw]*G[{0, 1}, yv^(-1)]*G[{yv^(-1), 1/(yu*yv)}, yw] - 
     2*G[{1/(yu*yv)}, yw]*G[{0, 1}, yv^(-1)]*G[{yv^(-1), 1/(yu*yv)}, yw] + 
     2*G[{1}, yu^(-1)]*G[{0, 1}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw] + 
     2*G[{yu^(-1)}, yw]*G[{0, 1}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw] - 
     2*G[{yu}, yv^(-1)]*G[{0, 1}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw] - 
     2*G[{1/(yu*yv)}, yw]*G[{0, 1}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw] - 
     2*G[{1}, yu^(-1)]*G[{0, yu^(-1)}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw] - 
     2*G[{yu^(-1)}, yw]*G[{0, yu^(-1)}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw] + 
     2*G[{yu}, yv^(-1)]*G[{0, yu^(-1)}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw] + 
     2*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1)}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw] - 
     2*G[{1}, yu^(-1)]*G[{0, yu}, yv^(-1)]*G[{yv^(-1), 1/(yu*yv)}, yw] - 
     2*G[{1}, yw]*G[{0, yu}, yv^(-1)]*G[{yv^(-1), 1/(yu*yv)}, yw] + 
     2*G[{yu}, yv^(-1)]*G[{0, yu}, yv^(-1)]*G[{yv^(-1), 1/(yu*yv)}, yw] + 
     2*G[{yv^(-1)}, yw]*G[{0, yu}, yv^(-1)]*G[{yv^(-1), 1/(yu*yv)}, yw] + 
     2*G[{1/(yu*yv)}, yw]*G[{0, yu}, yv^(-1)]*G[{yv^(-1), 1/(yu*yv)}, yw] - 
     2*G[{1}, yu^(-1)]*G[{0, yv^(-1)}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw] - 
     2*G[{yu^(-1)}, yw]*G[{0, yv^(-1)}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw] + 
     2*G[{yu}, yv^(-1)]*G[{0, yv^(-1)}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw] + 
     2*G[{1/(yu*yv)}, yw]*G[{0, yv^(-1)}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw] + 
     2*G[{1}, yu^(-1)]*G[{0, 1/(yu*yv)}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw] + 
     2*G[{yu^(-1)}, yw]*G[{0, 1/(yu*yv)}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw] - 
     2*G[{yu}, yv^(-1)]*G[{0, 1/(yu*yv)}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw] - 
     2*G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv)}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw] + 
     4*G[{1}, yu^(-1)]*G[{1, yu^(-1)}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw] + 
     4*G[{1}, yw]*G[{1, yu^(-1)}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw] + 
     2*G[{yu^(-1)}, yw]*G[{1, yu^(-1)}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw] - 
     4*G[{yu}, yv^(-1)]*G[{1, yu^(-1)}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw] - 
     2*G[{yv^(-1)}, yw]*G[{1, yu^(-1)}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw] - 
     4*G[{1/(yu*yv)}, yw]*G[{1, yu^(-1)}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw] + 
     4*G[{1}, yu^(-1)]*G[{1, yu}, yv^(-1)]*G[{yv^(-1), 1/(yu*yv)}, yw] - 
     4*G[{1/(yu*yv)}, yw]*G[{1, yu}, yv^(-1)]*G[{yv^(-1), 1/(yu*yv)}, yw] + 
     2*G[{yu^(-1)}, yw]*G[{1, yv^(-1)}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw] - 
     2*G[{yv^(-1)}, yw]*G[{1, yv^(-1)}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw] + 
     4*G[{yv^(-1)}, yw]*G[{1, 1/(yu*yv)}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw] - 
     2*G[{yv^(-1)}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw]*G[{yv^(-1), 1/(yu*yv)}, 
       yw] - 2*G[{1}, yu^(-1)]*G[{yv^(-1), 1/(yu*yv)}, yw]^2 - 
     2*G[{1}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw]^2 + 2*G[{yu}, yv^(-1)]*
      G[{yv^(-1), 1/(yu*yv)}, yw]^2 + 2*G[{yv^(-1)}, yw]*
      G[{yv^(-1), 1/(yu*yv)}, yw]^2 + 2*G[{1/(yu*yv)}, yw]*
      G[{yv^(-1), 1/(yu*yv)}, yw]^2 - 2*G[{1}, yw]^2*G[{0, 0, 1}, yw] + 
     2*G[{yu^(-1)}, yw]^2*G[{0, 0, 1}, yw] + 4*G[{1}, yw]*G[{yv^(-1)}, yw]*
      G[{0, 0, 1}, yw] - 2*G[{yv^(-1)}, yw]^2*G[{0, 0, 1}, yw] - 
     4*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 0, 1}, yw] + 
     2*G[{1/(yu*yv)}, yw]^2*G[{0, 0, 1}, yw] + 2*G[{1}, yw]^2*
      G[{0, 0, yu^(-1)}, yw] - 2*G[{yu^(-1)}, yw]^2*G[{0, 0, yu^(-1)}, yw] - 
     4*G[{1}, yw]*G[{yv^(-1)}, yw]*G[{0, 0, yu^(-1)}, yw] + 
     2*G[{yv^(-1)}, yw]^2*G[{0, 0, yu^(-1)}, yw] + 
     4*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 0, yu^(-1)}, yw] - 
     2*G[{1/(yu*yv)}, yw]^2*G[{0, 0, yu^(-1)}, yw] + 
     2*G[{1}, yw]^2*G[{0, 0, yv^(-1)}, yw] - 2*G[{yu^(-1)}, yw]^2*
      G[{0, 0, yv^(-1)}, yw] - 4*G[{1}, yw]*G[{yv^(-1)}, yw]*
      G[{0, 0, yv^(-1)}, yw] + 2*G[{yv^(-1)}, yw]^2*G[{0, 0, yv^(-1)}, yw] + 
     4*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 0, yv^(-1)}, yw] - 
     2*G[{1/(yu*yv)}, yw]^2*G[{0, 0, yv^(-1)}, yw] - 
     2*G[{1}, yw]^2*G[{0, 0, 1/(yu*yv)}, yw] + 2*G[{yu^(-1)}, yw]^2*
      G[{0, 0, 1/(yu*yv)}, yw] + 4*G[{1}, yw]*G[{yv^(-1)}, yw]*
      G[{0, 0, 1/(yu*yv)}, yw] - 2*G[{yv^(-1)}, yw]^2*
      G[{0, 0, 1/(yu*yv)}, yw] - 4*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*
      G[{0, 0, 1/(yu*yv)}, yw] + 2*G[{1/(yu*yv)}, yw]^2*
      G[{0, 0, 1/(yu*yv)}, yw] - 4*G[{1}, yu^(-1)]*G[{1}, yw]*
      G[{0, 1, 1}, yu^(-1)] + 4*G[{1}, yv^(-1)]*G[{1}, yw]*
      G[{0, 1, 1}, yu^(-1)] - 2*G[{1}, yw]^2*G[{0, 1, 1}, yu^(-1)] + 
     4*G[{1}, yu^(-1)]*G[{yu^(-1)}, yw]*G[{0, 1, 1}, yu^(-1)] - 
     4*G[{1}, yv^(-1)]*G[{yu^(-1)}, yw]*G[{0, 1, 1}, yu^(-1)] + 
     4*G[{1}, yu^(-1)]*G[{yv^(-1)}, yw]*G[{0, 1, 1}, yu^(-1)] - 
     4*G[{1}, yv^(-1)]*G[{yv^(-1)}, yw]*G[{0, 1, 1}, yu^(-1)] + 
     4*G[{1}, yw]*G[{yv^(-1)}, yw]*G[{0, 1, 1}, yu^(-1)] - 
     4*G[{yu^(-1)}, yw]*G[{yv^(-1)}, yw]*G[{0, 1, 1}, yu^(-1)] - 
     4*G[{1}, yu^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, 1, 1}, yu^(-1)] + 
     4*G[{1}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, 1, 1}, yu^(-1)] + 
     4*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1, 1}, yu^(-1)] - 
     2*G[{1/(yu*yv)}, yw]^2*G[{0, 1, 1}, yu^(-1)] + 
     4*G[{1, yu^(-1)}, yw]*G[{0, 1, 1}, yu^(-1)] - 4*G[{1, yv^(-1)}, yw]*
      G[{0, 1, 1}, yu^(-1)] + 4*G[{yu^(-1), 1/(yu*yv)}, yw]*
      G[{0, 1, 1}, yu^(-1)] - 4*G[{yv^(-1), 1/(yu*yv)}, yw]*
      G[{0, 1, 1}, yu^(-1)] + 2*G[{1}, yu^(-1)]*G[{1}, yw]*
      G[{0, 1, 1}, yv^(-1)] - 6*G[{1}, yu^(-1)]*G[{yu^(-1)}, yw]*
      G[{0, 1, 1}, yv^(-1)] - 4*G[{1}, yw]*G[{yu^(-1)}, yw]*
      G[{0, 1, 1}, yv^(-1)] - 2*G[{1}, yu^(-1)]*G[{yv^(-1)}, yw]*
      G[{0, 1, 1}, yv^(-1)] + 4*G[{yu^(-1)}, yw]*G[{yv^(-1)}, yw]*
      G[{0, 1, 1}, yv^(-1)] + 6*G[{1}, yu^(-1)]*G[{1/(yu*yv)}, yw]*
      G[{0, 1, 1}, yv^(-1)] + 4*G[{1}, yw]*G[{1/(yu*yv)}, yw]*
      G[{0, 1, 1}, yv^(-1)] - 4*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*
      G[{0, 1, 1}, yv^(-1)] + (5*Pi^2*G[{0, 1, 1}, yw])/3 - 
     2*G[{1}, yu^(-1)]^2*G[{0, 1, 1}, yw] + 4*G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*
      G[{0, 1, 1}, yw] + 2*G[{0}, yu^(-1)]*G[{1}, yw]*G[{0, 1, 1}, yw] + 
     2*G[{0}, yv^(-1)]*G[{1}, yw]*G[{0, 1, 1}, yw] - 
     2*G[{0}, yw]*G[{1}, yw]*G[{0, 1, 1}, yw] - 2*G[{1}, yv^(-1)]*G[{1}, yw]*
      G[{0, 1, 1}, yw] - 2*G[{0}, yu^(-1)]*G[{yu^(-1)}, yw]*
      G[{0, 1, 1}, yw] - 2*G[{0}, yv^(-1)]*G[{yu^(-1)}, yw]*
      G[{0, 1, 1}, yw] + 2*G[{0}, yw]*G[{yu^(-1)}, yw]*G[{0, 1, 1}, yw] - 
     4*G[{1}, yu^(-1)]*G[{yu^(-1)}, yw]*G[{0, 1, 1}, yw] + 
     6*G[{1}, yv^(-1)]*G[{yu^(-1)}, yw]*G[{0, 1, 1}, yw] - 
     3*G[{yu^(-1)}, yw]^2*G[{0, 1, 1}, yw] - 2*G[{1}, yw]*G[{yu}, yv^(-1)]*
      G[{0, 1, 1}, yw] + 2*G[{yu^(-1)}, yw]*G[{yu}, yv^(-1)]*
      G[{0, 1, 1}, yw] - 2*G[{0}, yu^(-1)]*G[{yv^(-1)}, yw]*
      G[{0, 1, 1}, yw] - 2*G[{0}, yv^(-1)]*G[{yv^(-1)}, yw]*
      G[{0, 1, 1}, yw] + 2*G[{0}, yw]*G[{yv^(-1)}, yw]*G[{0, 1, 1}, yw] + 
     2*G[{1}, yv^(-1)]*G[{yv^(-1)}, yw]*G[{0, 1, 1}, yw] + 
     2*G[{yu^(-1)}, yw]*G[{yv^(-1)}, yw]*G[{0, 1, 1}, yw] + 
     2*G[{yu}, yv^(-1)]*G[{yv^(-1)}, yw]*G[{0, 1, 1}, yw] + 
     G[{yv^(-1)}, yw]^2*G[{0, 1, 1}, yw] + 2*G[{0}, yu^(-1)]*
      G[{1/(yu*yv)}, yw]*G[{0, 1, 1}, yw] + 2*G[{0}, yv^(-1)]*
      G[{1/(yu*yv)}, yw]*G[{0, 1, 1}, yw] - 2*G[{0}, yw]*G[{1/(yu*yv)}, yw]*
      G[{0, 1, 1}, yw] + 4*G[{1}, yu^(-1)]*G[{1/(yu*yv)}, yw]*
      G[{0, 1, 1}, yw] - 6*G[{1}, yv^(-1)]*G[{1/(yu*yv)}, yw]*
      G[{0, 1, 1}, yw] + 6*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*
      G[{0, 1, 1}, yw] - 2*G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw]*
      G[{0, 1, 1}, yw] - 2*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*
      G[{0, 1, 1}, yw] + 4*G[{0, 1}, yu^(-1)]*G[{0, 1, 1}, yw] + 
     2*G[{0, 1}, yw]*G[{0, 1, 1}, yw] - 2*G[{0, yu^(-1)}, yw]*
      G[{0, 1, 1}, yw] + 2*G[{0, yv^(-1)}, yw]*G[{0, 1, 1}, yw] + 
     2*G[{0, 1/(yu*yv)}, yw]*G[{0, 1, 1}, yw] - 2*G[{1, yu^(-1)}, yw]*
      G[{0, 1, 1}, yw] - 4*G[{1, yu}, yv^(-1)]*G[{0, 1, 1}, yw] - 
     2*G[{1, yv^(-1)}, yw]*G[{0, 1, 1}, yw] - 6*G[{yu^(-1), 1/(yu*yv)}, yw]*
      G[{0, 1, 1}, yw] + 2*G[{yv^(-1), 1/(yu*yv)}, yw]*G[{0, 1, 1}, yw] - 
     (2*Pi^2*G[{0, 1, yu^(-1)}, yw])/3 + 2*G[{1}, yu^(-1)]^2*
      G[{0, 1, yu^(-1)}, yw] - 4*G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*
      G[{0, 1, yu^(-1)}, yw] - 2*G[{1}, yu^(-1)]*G[{1}, yw]*
      G[{0, 1, yu^(-1)}, yw] + 2*G[{1}, yv^(-1)]*G[{1}, yw]*
      G[{0, 1, yu^(-1)}, yw] - 2*G[{1}, yw]^2*G[{0, 1, yu^(-1)}, yw] + 
     6*G[{1}, yu^(-1)]*G[{yu^(-1)}, yw]*G[{0, 1, yu^(-1)}, yw] - 
     6*G[{1}, yv^(-1)]*G[{yu^(-1)}, yw]*G[{0, 1, yu^(-1)}, yw] + 
     5*G[{yu^(-1)}, yw]^2*G[{0, 1, yu^(-1)}, yw] + 
     2*G[{1}, yu^(-1)]*G[{yv^(-1)}, yw]*G[{0, 1, yu^(-1)}, yw] - 
     2*G[{1}, yv^(-1)]*G[{yv^(-1)}, yw]*G[{0, 1, yu^(-1)}, yw] + 
     4*G[{1}, yw]*G[{yv^(-1)}, yw]*G[{0, 1, yu^(-1)}, yw] - 
     2*G[{yu^(-1)}, yw]*G[{yv^(-1)}, yw]*G[{0, 1, yu^(-1)}, yw] - 
     3*G[{yv^(-1)}, yw]^2*G[{0, 1, yu^(-1)}, yw] - 
     6*G[{1}, yu^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, 1, yu^(-1)}, yw] + 
     6*G[{1}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, 1, yu^(-1)}, yw] - 
     10*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1, yu^(-1)}, yw] + 
     2*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1, yu^(-1)}, yw] + 
     2*G[{1/(yu*yv)}, yw]^2*G[{0, 1, yu^(-1)}, yw] - 
     2*G[{0, 1}, yu^(-1)]*G[{0, 1, yu^(-1)}, yw] + 2*G[{0, 1}, yv^(-1)]*
      G[{0, 1, yu^(-1)}, yw] + 2*G[{0, yu^(-1)}, yw]*G[{0, 1, yu^(-1)}, yw] - 
     2*G[{0, yu}, yv^(-1)]*G[{0, 1, yu^(-1)}, yw] - 
     2*G[{0, yv^(-1)}, yw]*G[{0, 1, yu^(-1)}, yw] - 
     2*G[{0, 1/(yu*yv)}, yw]*G[{0, 1, yu^(-1)}, yw] + 
     2*G[{1, yu^(-1)}, yw]*G[{0, 1, yu^(-1)}, yw] + 
     4*G[{1, yu}, yv^(-1)]*G[{0, 1, yu^(-1)}, yw] + 
     2*G[{1, yv^(-1)}, yw]*G[{0, 1, yu^(-1)}, yw] + 
     6*G[{yu^(-1), 1/(yu*yv)}, yw]*G[{0, 1, yu^(-1)}, yw] - 
     2*G[{yv^(-1), 1/(yu*yv)}, yw]*G[{0, 1, yu^(-1)}, yw] + 
     4*G[{1}, yu^(-1)]*G[{yu^(-1)}, yw]*G[{0, 1, yu}, yv^(-1)] + 
     4*G[{1}, yw]*G[{yu^(-1)}, yw]*G[{0, 1, yu}, yv^(-1)] - 
     4*G[{yu^(-1)}, yw]*G[{yv^(-1)}, yw]*G[{0, 1, yu}, yv^(-1)] - 
     4*G[{1}, yu^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, 1, yu}, yv^(-1)] - 
     4*G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1, yu}, yv^(-1)] + 
     4*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1, yu}, yv^(-1)] - 
     (5*Pi^2*G[{0, 1, yv^(-1)}, yw])/3 + 2*G[{1}, yu^(-1)]^2*
      G[{0, 1, yv^(-1)}, yw] - 4*G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*
      G[{0, 1, yv^(-1)}, yw] - 2*G[{0}, yu^(-1)]*G[{1}, yw]*
      G[{0, 1, yv^(-1)}, yw] - 2*G[{0}, yv^(-1)]*G[{1}, yw]*
      G[{0, 1, yv^(-1)}, yw] + 2*G[{0}, yw]*G[{1}, yw]*
      G[{0, 1, yv^(-1)}, yw] + 2*G[{1}, yu^(-1)]*G[{1}, yw]*
      G[{0, 1, yv^(-1)}, yw] + 2*G[{1}, yv^(-1)]*G[{1}, yw]*
      G[{0, 1, yv^(-1)}, yw] - 2*G[{1}, yw]^2*G[{0, 1, yv^(-1)}, yw] + 
     2*G[{0}, yu^(-1)]*G[{yu^(-1)}, yw]*G[{0, 1, yv^(-1)}, yw] + 
     2*G[{0}, yv^(-1)]*G[{yu^(-1)}, yw]*G[{0, 1, yv^(-1)}, yw] - 
     2*G[{0}, yw]*G[{yu^(-1)}, yw]*G[{0, 1, yv^(-1)}, yw] + 
     2*G[{1}, yu^(-1)]*G[{yu^(-1)}, yw]*G[{0, 1, yv^(-1)}, yw] - 
     6*G[{1}, yv^(-1)]*G[{yu^(-1)}, yw]*G[{0, 1, yv^(-1)}, yw] + 
     5*G[{yu^(-1)}, yw]^2*G[{0, 1, yv^(-1)}, yw] + 
     2*G[{0}, yu^(-1)]*G[{yv^(-1)}, yw]*G[{0, 1, yv^(-1)}, yw] + 
     2*G[{0}, yv^(-1)]*G[{yv^(-1)}, yw]*G[{0, 1, yv^(-1)}, yw] - 
     2*G[{0}, yw]*G[{yv^(-1)}, yw]*G[{0, 1, yv^(-1)}, yw] - 
     2*G[{1}, yu^(-1)]*G[{yv^(-1)}, yw]*G[{0, 1, yv^(-1)}, yw] - 
     2*G[{1}, yv^(-1)]*G[{yv^(-1)}, yw]*G[{0, 1, yv^(-1)}, yw] + 
     4*G[{1}, yw]*G[{yv^(-1)}, yw]*G[{0, 1, yv^(-1)}, yw] - 
     2*G[{yu^(-1)}, yw]*G[{yv^(-1)}, yw]*G[{0, 1, yv^(-1)}, yw] - 
     3*G[{yv^(-1)}, yw]^2*G[{0, 1, yv^(-1)}, yw] - 
     2*G[{0}, yu^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, 1, yv^(-1)}, yw] - 
     2*G[{0}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, 1, yv^(-1)}, yw] + 
     2*G[{0}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1, yv^(-1)}, yw] - 
     2*G[{1}, yu^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, 1, yv^(-1)}, yw] + 
     6*G[{1}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, 1, yv^(-1)}, yw] - 
     10*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1, yv^(-1)}, yw] + 
     2*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1, yv^(-1)}, yw] + 
     2*G[{1/(yu*yv)}, yw]^2*G[{0, 1, yv^(-1)}, yw] - 
     4*G[{0, 1}, yu^(-1)]*G[{0, 1, yv^(-1)}, yw] - 
     2*G[{0, 1}, yw]*G[{0, 1, yv^(-1)}, yw] + 4*G[{0, yu^(-1)}, yw]*
      G[{0, 1, yv^(-1)}, yw] - 2*G[{0, yv^(-1)}, yw]*G[{0, 1, yv^(-1)}, yw] - 
     2*G[{0, 1/(yu*yv)}, yw]*G[{0, 1, yv^(-1)}, yw] + 
     2*G[{1, yu^(-1)}, yw]*G[{0, 1, yv^(-1)}, yw] + 
     4*G[{1, yu}, yv^(-1)]*G[{0, 1, yv^(-1)}, yw] + 
     2*G[{1, yv^(-1)}, yw]*G[{0, 1, yv^(-1)}, yw] + 
     6*G[{yu^(-1), 1/(yu*yv)}, yw]*G[{0, 1, yv^(-1)}, yw] - 
     2*G[{yv^(-1), 1/(yu*yv)}, yw]*G[{0, 1, yv^(-1)}, yw] + 
     (2*Pi^2*G[{0, 1, 1/(yu*yv)}, yw])/3 - 2*G[{1}, yu^(-1)]^2*
      G[{0, 1, 1/(yu*yv)}, yw] + 4*G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*
      G[{0, 1, 1/(yu*yv)}, yw] - 2*G[{1}, yv^(-1)]*G[{1}, yw]*
      G[{0, 1, 1/(yu*yv)}, yw] - 4*G[{1}, yu^(-1)]*G[{yu^(-1)}, yw]*
      G[{0, 1, 1/(yu*yv)}, yw] + 6*G[{1}, yv^(-1)]*G[{yu^(-1)}, yw]*
      G[{0, 1, 1/(yu*yv)}, yw] - 3*G[{yu^(-1)}, yw]^2*
      G[{0, 1, 1/(yu*yv)}, yw] + 2*G[{1}, yw]*G[{yu}, yv^(-1)]*
      G[{0, 1, 1/(yu*yv)}, yw] - 2*G[{yu^(-1)}, yw]*G[{yu}, yv^(-1)]*
      G[{0, 1, 1/(yu*yv)}, yw] + 2*G[{1}, yv^(-1)]*G[{yv^(-1)}, yw]*
      G[{0, 1, 1/(yu*yv)}, yw] + 2*G[{yu^(-1)}, yw]*G[{yv^(-1)}, yw]*
      G[{0, 1, 1/(yu*yv)}, yw] - 2*G[{yu}, yv^(-1)]*G[{yv^(-1)}, yw]*
      G[{0, 1, 1/(yu*yv)}, yw] + G[{yv^(-1)}, yw]^2*G[{0, 1, 1/(yu*yv)}, 
       yw] + 4*G[{1}, yu^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, 1, 1/(yu*yv)}, yw] - 
     6*G[{1}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, 1, 1/(yu*yv)}, yw] + 
     6*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1, 1/(yu*yv)}, yw] + 
     2*G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, 1, 1/(yu*yv)}, yw] - 
     2*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1, 1/(yu*yv)}, yw] + 
     2*G[{0, 1}, yu^(-1)]*G[{0, 1, 1/(yu*yv)}, yw] - 
     2*G[{0, 1}, yv^(-1)]*G[{0, 1, 1/(yu*yv)}, yw] + 
     2*G[{0, yu}, yv^(-1)]*G[{0, 1, 1/(yu*yv)}, yw] + 
     2*G[{0, yv^(-1)}, yw]*G[{0, 1, 1/(yu*yv)}, yw] + 
     2*G[{0, 1/(yu*yv)}, yw]*G[{0, 1, 1/(yu*yv)}, yw] - 
     2*G[{1, yu^(-1)}, yw]*G[{0, 1, 1/(yu*yv)}, yw] - 
     4*G[{1, yu}, yv^(-1)]*G[{0, 1, 1/(yu*yv)}, yw] - 
     2*G[{1, yv^(-1)}, yw]*G[{0, 1, 1/(yu*yv)}, yw] - 
     6*G[{yu^(-1), 1/(yu*yv)}, yw]*G[{0, 1, 1/(yu*yv)}, yw] + 
     2*G[{yv^(-1), 1/(yu*yv)}, yw]*G[{0, 1, 1/(yu*yv)}, yw] - 
     (2*Pi^2*G[{0, yu^(-1), 1}, yw])/3 + 2*G[{1}, yu^(-1)]^2*
      G[{0, yu^(-1), 1}, yw] - 4*G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*
      G[{0, yu^(-1), 1}, yw] + 2*G[{1}, yv^(-1)]*G[{1}, yw]*
      G[{0, yu^(-1), 1}, yw] + 4*G[{1}, yu^(-1)]*G[{yu^(-1)}, yw]*
      G[{0, yu^(-1), 1}, yw] - 6*G[{1}, yv^(-1)]*G[{yu^(-1)}, yw]*
      G[{0, yu^(-1), 1}, yw] + 3*G[{yu^(-1)}, yw]^2*G[{0, yu^(-1), 1}, yw] - 
     2*G[{1}, yw]*G[{yu}, yv^(-1)]*G[{0, yu^(-1), 1}, yw] + 
     2*G[{yu^(-1)}, yw]*G[{yu}, yv^(-1)]*G[{0, yu^(-1), 1}, yw] - 
     2*G[{1}, yv^(-1)]*G[{yv^(-1)}, yw]*G[{0, yu^(-1), 1}, yw] - 
     2*G[{yu^(-1)}, yw]*G[{yv^(-1)}, yw]*G[{0, yu^(-1), 1}, yw] + 
     2*G[{yu}, yv^(-1)]*G[{yv^(-1)}, yw]*G[{0, yu^(-1), 1}, yw] - 
     G[{yv^(-1)}, yw]^2*G[{0, yu^(-1), 1}, yw] - 4*G[{1}, yu^(-1)]*
      G[{1/(yu*yv)}, yw]*G[{0, yu^(-1), 1}, yw] + 
     6*G[{1}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1), 1}, yw] - 
     6*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1), 1}, yw] - 
     2*G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1), 1}, yw] + 
     2*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1), 1}, yw] - 
     2*G[{0, 1}, yu^(-1)]*G[{0, yu^(-1), 1}, yw] + 2*G[{0, 1}, yv^(-1)]*
      G[{0, yu^(-1), 1}, yw] - 2*G[{0, yu}, yv^(-1)]*G[{0, yu^(-1), 1}, yw] - 
     2*G[{0, yv^(-1)}, yw]*G[{0, yu^(-1), 1}, yw] - 
     2*G[{0, 1/(yu*yv)}, yw]*G[{0, yu^(-1), 1}, yw] + 
     2*G[{1, yu^(-1)}, yw]*G[{0, yu^(-1), 1}, yw] + 
     4*G[{1, yu}, yv^(-1)]*G[{0, yu^(-1), 1}, yw] + 
     2*G[{1, yv^(-1)}, yw]*G[{0, yu^(-1), 1}, yw] + 
     6*G[{yu^(-1), 1/(yu*yv)}, yw]*G[{0, yu^(-1), 1}, yw] - 
     2*G[{yv^(-1), 1/(yu*yv)}, yw]*G[{0, yu^(-1), 1}, yw] - 
     (Pi^2*G[{0, yu^(-1), yu^(-1)}, yw])/3 - 2*G[{1}, yu^(-1)]^2*
      G[{0, yu^(-1), yu^(-1)}, yw] + 4*G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*
      G[{0, yu^(-1), yu^(-1)}, yw] - 2*G[{0}, yu^(-1)]*G[{1}, yw]*
      G[{0, yu^(-1), yu^(-1)}, yw] - 2*G[{0}, yv^(-1)]*G[{1}, yw]*
      G[{0, yu^(-1), yu^(-1)}, yw] + 2*G[{0}, yw]*G[{1}, yw]*
      G[{0, yu^(-1), yu^(-1)}, yw] + 2*G[{1}, yu^(-1)]*G[{1}, yw]*
      G[{0, yu^(-1), yu^(-1)}, yw] + 2*G[{1}, yv^(-1)]*G[{1}, yw]*
      G[{0, yu^(-1), yu^(-1)}, yw] + 2*G[{1}, yw]^2*G[{0, yu^(-1), yu^(-1)}, 
       yw] + 2*G[{0}, yu^(-1)]*G[{yu^(-1)}, yw]*G[{0, yu^(-1), yu^(-1)}, 
       yw] + 2*G[{0}, yv^(-1)]*G[{yu^(-1)}, yw]*G[{0, yu^(-1), yu^(-1)}, 
       yw] - 2*G[{0}, yw]*G[{yu^(-1)}, yw]*G[{0, yu^(-1), yu^(-1)}, yw] - 
     6*G[{1}, yu^(-1)]*G[{yu^(-1)}, yw]*G[{0, yu^(-1), yu^(-1)}, yw] + 
     2*G[{1}, yv^(-1)]*G[{yu^(-1)}, yw]*G[{0, yu^(-1), yu^(-1)}, yw] - 
     5*G[{yu^(-1)}, yw]^2*G[{0, yu^(-1), yu^(-1)}, yw] + 
     2*G[{0}, yu^(-1)]*G[{yv^(-1)}, yw]*G[{0, yu^(-1), yu^(-1)}, yw] + 
     2*G[{0}, yv^(-1)]*G[{yv^(-1)}, yw]*G[{0, yu^(-1), yu^(-1)}, yw] - 
     2*G[{0}, yw]*G[{yv^(-1)}, yw]*G[{0, yu^(-1), yu^(-1)}, yw] - 
     2*G[{1}, yu^(-1)]*G[{yv^(-1)}, yw]*G[{0, yu^(-1), yu^(-1)}, yw] - 
     2*G[{1}, yv^(-1)]*G[{yv^(-1)}, yw]*G[{0, yu^(-1), yu^(-1)}, yw] - 
     4*G[{1}, yw]*G[{yv^(-1)}, yw]*G[{0, yu^(-1), yu^(-1)}, yw] + 
     2*G[{yu^(-1)}, yw]*G[{yv^(-1)}, yw]*G[{0, yu^(-1), yu^(-1)}, yw] + 
     3*G[{yv^(-1)}, yw]^2*G[{0, yu^(-1), yu^(-1)}, yw] - 
     2*G[{0}, yu^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1), yu^(-1)}, yw] - 
     2*G[{0}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1), yu^(-1)}, yw] + 
     2*G[{0}, yw]*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1), yu^(-1)}, yw] + 
     6*G[{1}, yu^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1), yu^(-1)}, yw] - 
     2*G[{1}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1), yu^(-1)}, yw] + 
     10*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1), yu^(-1)}, yw] - 
     2*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1), yu^(-1)}, yw] - 
     2*G[{1/(yu*yv)}, yw]^2*G[{0, yu^(-1), yu^(-1)}, yw] - 
     4*G[{0, 1}, yv^(-1)]*G[{0, yu^(-1), yu^(-1)}, yw] - 
     2*G[{0, 1}, yw]*G[{0, yu^(-1), yu^(-1)}, yw] + 
     2*G[{0, yu^(-1)}, yw]*G[{0, yu^(-1), yu^(-1)}, yw] + 
     4*G[{0, yu}, yv^(-1)]*G[{0, yu^(-1), yu^(-1)}, yw] + 
     2*G[{0, yv^(-1)}, yw]*G[{0, yu^(-1), yu^(-1)}, yw] + 
     2*G[{0, 1/(yu*yv)}, yw]*G[{0, yu^(-1), yu^(-1)}, yw] - 
     2*G[{1, yu^(-1)}, yw]*G[{0, yu^(-1), yu^(-1)}, yw] - 
     4*G[{1, yu}, yv^(-1)]*G[{0, yu^(-1), yu^(-1)}, yw] - 
     2*G[{1, yv^(-1)}, yw]*G[{0, yu^(-1), yu^(-1)}, yw] - 
     6*G[{yu^(-1), 1/(yu*yv)}, yw]*G[{0, yu^(-1), yu^(-1)}, yw] + 
     2*G[{yv^(-1), 1/(yu*yv)}, yw]*G[{0, yu^(-1), yu^(-1)}, yw] + 
     (2*Pi^2*G[{0, yu^(-1), yv^(-1)}, yw])/3 - 2*G[{1}, yu^(-1)]^2*
      G[{0, yu^(-1), yv^(-1)}, yw] + 4*G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*
      G[{0, yu^(-1), yv^(-1)}, yw] + 2*G[{1}, yu^(-1)]*G[{1}, yw]*
      G[{0, yu^(-1), yv^(-1)}, yw] - 2*G[{1}, yv^(-1)]*G[{1}, yw]*
      G[{0, yu^(-1), yv^(-1)}, yw] + 2*G[{1}, yw]^2*G[{0, yu^(-1), yv^(-1)}, 
       yw] - 6*G[{1}, yu^(-1)]*G[{yu^(-1)}, yw]*G[{0, yu^(-1), yv^(-1)}, 
       yw] + 6*G[{1}, yv^(-1)]*G[{yu^(-1)}, yw]*G[{0, yu^(-1), yv^(-1)}, 
       yw] - 5*G[{yu^(-1)}, yw]^2*G[{0, yu^(-1), yv^(-1)}, yw] - 
     2*G[{1}, yu^(-1)]*G[{yv^(-1)}, yw]*G[{0, yu^(-1), yv^(-1)}, yw] + 
     2*G[{1}, yv^(-1)]*G[{yv^(-1)}, yw]*G[{0, yu^(-1), yv^(-1)}, yw] - 
     4*G[{1}, yw]*G[{yv^(-1)}, yw]*G[{0, yu^(-1), yv^(-1)}, yw] + 
     2*G[{yu^(-1)}, yw]*G[{yv^(-1)}, yw]*G[{0, yu^(-1), yv^(-1)}, yw] + 
     3*G[{yv^(-1)}, yw]^2*G[{0, yu^(-1), yv^(-1)}, yw] + 
     6*G[{1}, yu^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1), yv^(-1)}, yw] - 
     6*G[{1}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1), yv^(-1)}, yw] + 
     10*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1), yv^(-1)}, yw] - 
     2*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1), yv^(-1)}, yw] - 
     2*G[{1/(yu*yv)}, yw]^2*G[{0, yu^(-1), yv^(-1)}, yw] + 
     2*G[{0, 1}, yu^(-1)]*G[{0, yu^(-1), yv^(-1)}, yw] - 
     2*G[{0, 1}, yv^(-1)]*G[{0, yu^(-1), yv^(-1)}, yw] + 
     2*G[{0, yu}, yv^(-1)]*G[{0, yu^(-1), yv^(-1)}, yw] + 
     2*G[{0, yv^(-1)}, yw]*G[{0, yu^(-1), yv^(-1)}, yw] + 
     2*G[{0, 1/(yu*yv)}, yw]*G[{0, yu^(-1), yv^(-1)}, yw] - 
     2*G[{1, yu^(-1)}, yw]*G[{0, yu^(-1), yv^(-1)}, yw] - 
     4*G[{1, yu}, yv^(-1)]*G[{0, yu^(-1), yv^(-1)}, yw] - 
     2*G[{1, yv^(-1)}, yw]*G[{0, yu^(-1), yv^(-1)}, yw] - 
     6*G[{yu^(-1), 1/(yu*yv)}, yw]*G[{0, yu^(-1), yv^(-1)}, yw] + 
     2*G[{yv^(-1), 1/(yu*yv)}, yw]*G[{0, yu^(-1), yv^(-1)}, yw] + 
     (Pi^2*G[{0, yu^(-1), 1/(yu*yv)}, yw])/3 + 2*G[{1}, yu^(-1)]^2*
      G[{0, yu^(-1), 1/(yu*yv)}, yw] - 4*G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*
      G[{0, yu^(-1), 1/(yu*yv)}, yw] + 2*G[{0}, yu^(-1)]*G[{1}, yw]*
      G[{0, yu^(-1), 1/(yu*yv)}, yw] + 2*G[{0}, yv^(-1)]*G[{1}, yw]*
      G[{0, yu^(-1), 1/(yu*yv)}, yw] - 2*G[{0}, yw]*G[{1}, yw]*
      G[{0, yu^(-1), 1/(yu*yv)}, yw] - 4*G[{1}, yu^(-1)]*G[{1}, yw]*
      G[{0, yu^(-1), 1/(yu*yv)}, yw] - 2*G[{1}, yv^(-1)]*G[{1}, yw]*
      G[{0, yu^(-1), 1/(yu*yv)}, yw] - 2*G[{0}, yu^(-1)]*G[{yu^(-1)}, yw]*
      G[{0, yu^(-1), 1/(yu*yv)}, yw] - 2*G[{0}, yv^(-1)]*G[{yu^(-1)}, yw]*
      G[{0, yu^(-1), 1/(yu*yv)}, yw] + 2*G[{0}, yw]*G[{yu^(-1)}, yw]*
      G[{0, yu^(-1), 1/(yu*yv)}, yw] + 8*G[{1}, yu^(-1)]*G[{yu^(-1)}, yw]*
      G[{0, yu^(-1), 1/(yu*yv)}, yw] - 2*G[{1}, yv^(-1)]*G[{yu^(-1)}, yw]*
      G[{0, yu^(-1), 1/(yu*yv)}, yw] + 3*G[{yu^(-1)}, yw]^2*
      G[{0, yu^(-1), 1/(yu*yv)}, yw] + 2*G[{1}, yw]*G[{yu}, yv^(-1)]*
      G[{0, yu^(-1), 1/(yu*yv)}, yw] - 2*G[{yu^(-1)}, yw]*G[{yu}, yv^(-1)]*
      G[{0, yu^(-1), 1/(yu*yv)}, yw] - 2*G[{0}, yu^(-1)]*G[{yv^(-1)}, yw]*
      G[{0, yu^(-1), 1/(yu*yv)}, yw] - 2*G[{0}, yv^(-1)]*G[{yv^(-1)}, yw]*
      G[{0, yu^(-1), 1/(yu*yv)}, yw] + 2*G[{0}, yw]*G[{yv^(-1)}, yw]*
      G[{0, yu^(-1), 1/(yu*yv)}, yw] + 4*G[{1}, yu^(-1)]*G[{yv^(-1)}, yw]*
      G[{0, yu^(-1), 1/(yu*yv)}, yw] + 2*G[{1}, yv^(-1)]*G[{yv^(-1)}, yw]*
      G[{0, yu^(-1), 1/(yu*yv)}, yw] - 2*G[{yu^(-1)}, yw]*G[{yv^(-1)}, yw]*
      G[{0, yu^(-1), 1/(yu*yv)}, yw] - 2*G[{yu}, yv^(-1)]*G[{yv^(-1)}, yw]*
      G[{0, yu^(-1), 1/(yu*yv)}, yw] - G[{yv^(-1)}, yw]^2*
      G[{0, yu^(-1), 1/(yu*yv)}, yw] + 2*G[{0}, yu^(-1)]*G[{1/(yu*yv)}, yw]*
      G[{0, yu^(-1), 1/(yu*yv)}, yw] + 2*G[{0}, yv^(-1)]*G[{1/(yu*yv)}, yw]*
      G[{0, yu^(-1), 1/(yu*yv)}, yw] - 2*G[{0}, yw]*G[{1/(yu*yv)}, yw]*
      G[{0, yu^(-1), 1/(yu*yv)}, yw] - 8*G[{1}, yu^(-1)]*G[{1/(yu*yv)}, yw]*
      G[{0, yu^(-1), 1/(yu*yv)}, yw] + 2*G[{1}, yv^(-1)]*G[{1/(yu*yv)}, yw]*
      G[{0, yu^(-1), 1/(yu*yv)}, yw] - 6*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*
      G[{0, yu^(-1), 1/(yu*yv)}, yw] + 2*G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw]*
      G[{0, yu^(-1), 1/(yu*yv)}, yw] + 2*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*
      G[{0, yu^(-1), 1/(yu*yv)}, yw] + 4*G[{0, 1}, yv^(-1)]*
      G[{0, yu^(-1), 1/(yu*yv)}, yw] + 2*G[{0, 1}, yw]*
      G[{0, yu^(-1), 1/(yu*yv)}, yw] - 2*G[{0, yu^(-1)}, yw]*
      G[{0, yu^(-1), 1/(yu*yv)}, yw] - 4*G[{0, yu}, yv^(-1)]*
      G[{0, yu^(-1), 1/(yu*yv)}, yw] - 4*G[{0, yv^(-1)}, yw]*
      G[{0, yu^(-1), 1/(yu*yv)}, yw] - 2*G[{0, 1/(yu*yv)}, yw]*
      G[{0, yu^(-1), 1/(yu*yv)}, yw] + 2*G[{1, yu^(-1)}, yw]*
      G[{0, yu^(-1), 1/(yu*yv)}, yw] + 4*G[{1, yu}, yv^(-1)]*
      G[{0, yu^(-1), 1/(yu*yv)}, yw] + 2*G[{1, yv^(-1)}, yw]*
      G[{0, yu^(-1), 1/(yu*yv)}, yw] + 6*G[{yu^(-1), 1/(yu*yv)}, yw]*
      G[{0, yu^(-1), 1/(yu*yv)}, yw] - 2*G[{yv^(-1), 1/(yu*yv)}, yw]*
      G[{0, yu^(-1), 1/(yu*yv)}, yw] - 2*G[{1}, yu^(-1)]*G[{1}, yw]*
      G[{0, yu, 1}, yv^(-1)] + 6*G[{1}, yu^(-1)]*G[{yu^(-1)}, yw]*
      G[{0, yu, 1}, yv^(-1)] + 4*G[{1}, yw]*G[{yu^(-1)}, yw]*
      G[{0, yu, 1}, yv^(-1)] + 2*G[{1}, yu^(-1)]*G[{yv^(-1)}, yw]*
      G[{0, yu, 1}, yv^(-1)] - 4*G[{yu^(-1)}, yw]*G[{yv^(-1)}, yw]*
      G[{0, yu, 1}, yv^(-1)] - 6*G[{1}, yu^(-1)]*G[{1/(yu*yv)}, yw]*
      G[{0, yu, 1}, yv^(-1)] - 4*G[{1}, yw]*G[{1/(yu*yv)}, yw]*
      G[{0, yu, 1}, yv^(-1)] + 4*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*
      G[{0, yu, 1}, yv^(-1)] - 4*G[{1}, yu^(-1)]*G[{yu^(-1)}, yw]*
      G[{0, yu, yu}, yv^(-1)] - 4*G[{1}, yw]*G[{yu^(-1)}, yw]*
      G[{0, yu, yu}, yv^(-1)] + 4*G[{yu^(-1)}, yw]*G[{yv^(-1)}, yw]*
      G[{0, yu, yu}, yv^(-1)] + 4*G[{1}, yu^(-1)]*G[{1/(yu*yv)}, yw]*
      G[{0, yu, yu}, yv^(-1)] + 4*G[{1}, yw]*G[{1/(yu*yv)}, yw]*
      G[{0, yu, yu}, yv^(-1)] - 4*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*
      G[{0, yu, yu}, yv^(-1)] - (5*Pi^2*G[{0, yv^(-1), 1}, yw])/3 + 
     2*G[{1}, yu^(-1)]^2*G[{0, yv^(-1), 1}, yw] - 
     4*G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*G[{0, yv^(-1), 1}, yw] - 
     2*G[{0}, yu^(-1)]*G[{1}, yw]*G[{0, yv^(-1), 1}, yw] - 
     2*G[{0}, yv^(-1)]*G[{1}, yw]*G[{0, yv^(-1), 1}, yw] + 
     2*G[{0}, yw]*G[{1}, yw]*G[{0, yv^(-1), 1}, yw] + 
     2*G[{1}, yv^(-1)]*G[{1}, yw]*G[{0, yv^(-1), 1}, yw] + 
     2*G[{0}, yu^(-1)]*G[{yu^(-1)}, yw]*G[{0, yv^(-1), 1}, yw] + 
     2*G[{0}, yv^(-1)]*G[{yu^(-1)}, yw]*G[{0, yv^(-1), 1}, yw] - 
     2*G[{0}, yw]*G[{yu^(-1)}, yw]*G[{0, yv^(-1), 1}, yw] + 
     4*G[{1}, yu^(-1)]*G[{yu^(-1)}, yw]*G[{0, yv^(-1), 1}, yw] - 
     6*G[{1}, yv^(-1)]*G[{yu^(-1)}, yw]*G[{0, yv^(-1), 1}, yw] + 
     3*G[{yu^(-1)}, yw]^2*G[{0, yv^(-1), 1}, yw] + 
     2*G[{1}, yw]*G[{yu}, yv^(-1)]*G[{0, yv^(-1), 1}, yw] - 
     2*G[{yu^(-1)}, yw]*G[{yu}, yv^(-1)]*G[{0, yv^(-1), 1}, yw] + 
     2*G[{0}, yu^(-1)]*G[{yv^(-1)}, yw]*G[{0, yv^(-1), 1}, yw] + 
     2*G[{0}, yv^(-1)]*G[{yv^(-1)}, yw]*G[{0, yv^(-1), 1}, yw] - 
     2*G[{0}, yw]*G[{yv^(-1)}, yw]*G[{0, yv^(-1), 1}, yw] - 
     2*G[{1}, yv^(-1)]*G[{yv^(-1)}, yw]*G[{0, yv^(-1), 1}, yw] - 
     2*G[{yu^(-1)}, yw]*G[{yv^(-1)}, yw]*G[{0, yv^(-1), 1}, yw] - 
     2*G[{yu}, yv^(-1)]*G[{yv^(-1)}, yw]*G[{0, yv^(-1), 1}, yw] - 
     G[{yv^(-1)}, yw]^2*G[{0, yv^(-1), 1}, yw] - 2*G[{0}, yu^(-1)]*
      G[{1/(yu*yv)}, yw]*G[{0, yv^(-1), 1}, yw] - 
     2*G[{0}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, yv^(-1), 1}, yw] + 
     2*G[{0}, yw]*G[{1/(yu*yv)}, yw]*G[{0, yv^(-1), 1}, yw] - 
     4*G[{1}, yu^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, yv^(-1), 1}, yw] + 
     6*G[{1}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, yv^(-1), 1}, yw] - 
     6*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{0, yv^(-1), 1}, yw] + 
     2*G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, yv^(-1), 1}, yw] + 
     2*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{0, yv^(-1), 1}, yw] - 
     4*G[{0, 1}, yu^(-1)]*G[{0, yv^(-1), 1}, yw] - 
     2*G[{0, 1}, yw]*G[{0, yv^(-1), 1}, yw] + 2*G[{0, yu^(-1)}, yw]*
      G[{0, yv^(-1), 1}, yw] + 2*G[{0, yv^(-1)}, yw]*G[{0, yv^(-1), 1}, yw] - 
     2*G[{0, 1/(yu*yv)}, yw]*G[{0, yv^(-1), 1}, yw] + 
     2*G[{1, yu^(-1)}, yw]*G[{0, yv^(-1), 1}, yw] + 
     4*G[{1, yu}, yv^(-1)]*G[{0, yv^(-1), 1}, yw] + 
     2*G[{1, yv^(-1)}, yw]*G[{0, yv^(-1), 1}, yw] + 
     6*G[{yu^(-1), 1/(yu*yv)}, yw]*G[{0, yv^(-1), 1}, yw] - 
     2*G[{yv^(-1), 1/(yu*yv)}, yw]*G[{0, yv^(-1), 1}, yw] + 
     (2*Pi^2*G[{0, yv^(-1), yu^(-1)}, yw])/3 - 2*G[{1}, yu^(-1)]^2*
      G[{0, yv^(-1), yu^(-1)}, yw] + 4*G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*
      G[{0, yv^(-1), yu^(-1)}, yw] + 2*G[{1}, yu^(-1)]*G[{1}, yw]*
      G[{0, yv^(-1), yu^(-1)}, yw] - 2*G[{1}, yv^(-1)]*G[{1}, yw]*
      G[{0, yv^(-1), yu^(-1)}, yw] + 2*G[{1}, yw]^2*G[{0, yv^(-1), yu^(-1)}, 
       yw] - 6*G[{1}, yu^(-1)]*G[{yu^(-1)}, yw]*G[{0, yv^(-1), yu^(-1)}, 
       yw] + 6*G[{1}, yv^(-1)]*G[{yu^(-1)}, yw]*G[{0, yv^(-1), yu^(-1)}, 
       yw] - 5*G[{yu^(-1)}, yw]^2*G[{0, yv^(-1), yu^(-1)}, yw] - 
     2*G[{1}, yu^(-1)]*G[{yv^(-1)}, yw]*G[{0, yv^(-1), yu^(-1)}, yw] + 
     2*G[{1}, yv^(-1)]*G[{yv^(-1)}, yw]*G[{0, yv^(-1), yu^(-1)}, yw] - 
     4*G[{1}, yw]*G[{yv^(-1)}, yw]*G[{0, yv^(-1), yu^(-1)}, yw] + 
     2*G[{yu^(-1)}, yw]*G[{yv^(-1)}, yw]*G[{0, yv^(-1), yu^(-1)}, yw] + 
     3*G[{yv^(-1)}, yw]^2*G[{0, yv^(-1), yu^(-1)}, yw] + 
     6*G[{1}, yu^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, yv^(-1), yu^(-1)}, yw] - 
     6*G[{1}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, yv^(-1), yu^(-1)}, yw] + 
     10*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{0, yv^(-1), yu^(-1)}, yw] - 
     2*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{0, yv^(-1), yu^(-1)}, yw] - 
     2*G[{1/(yu*yv)}, yw]^2*G[{0, yv^(-1), yu^(-1)}, yw] + 
     2*G[{0, 1}, yu^(-1)]*G[{0, yv^(-1), yu^(-1)}, yw] - 
     2*G[{0, 1}, yv^(-1)]*G[{0, yv^(-1), yu^(-1)}, yw] + 
     2*G[{0, yu}, yv^(-1)]*G[{0, yv^(-1), yu^(-1)}, yw] + 
     2*G[{0, 1/(yu*yv)}, yw]*G[{0, yv^(-1), yu^(-1)}, yw] - 
     2*G[{1, yu^(-1)}, yw]*G[{0, yv^(-1), yu^(-1)}, yw] - 
     4*G[{1, yu}, yv^(-1)]*G[{0, yv^(-1), yu^(-1)}, yw] - 
     2*G[{1, yv^(-1)}, yw]*G[{0, yv^(-1), yu^(-1)}, yw] - 
     6*G[{yu^(-1), 1/(yu*yv)}, yw]*G[{0, yv^(-1), yu^(-1)}, yw] + 
     2*G[{yv^(-1), 1/(yu*yv)}, yw]*G[{0, yv^(-1), yu^(-1)}, yw] + 
     (5*Pi^2*G[{0, yv^(-1), yv^(-1)}, yw])/3 - 2*G[{1}, yu^(-1)]^2*
      G[{0, yv^(-1), yv^(-1)}, yw] + 4*G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*
      G[{0, yv^(-1), yv^(-1)}, yw] + 2*G[{0}, yu^(-1)]*G[{1}, yw]*
      G[{0, yv^(-1), yv^(-1)}, yw] + 2*G[{0}, yv^(-1)]*G[{1}, yw]*
      G[{0, yv^(-1), yv^(-1)}, yw] - 2*G[{0}, yw]*G[{1}, yw]*
      G[{0, yv^(-1), yv^(-1)}, yw] - 2*G[{1}, yu^(-1)]*G[{1}, yw]*
      G[{0, yv^(-1), yv^(-1)}, yw] - 2*G[{1}, yv^(-1)]*G[{1}, yw]*
      G[{0, yv^(-1), yv^(-1)}, yw] + 2*G[{1}, yw]^2*G[{0, yv^(-1), yv^(-1)}, 
       yw] - 2*G[{0}, yu^(-1)]*G[{yu^(-1)}, yw]*G[{0, yv^(-1), yv^(-1)}, 
       yw] - 2*G[{0}, yv^(-1)]*G[{yu^(-1)}, yw]*G[{0, yv^(-1), yv^(-1)}, 
       yw] + 2*G[{0}, yw]*G[{yu^(-1)}, yw]*G[{0, yv^(-1), yv^(-1)}, yw] - 
     2*G[{1}, yu^(-1)]*G[{yu^(-1)}, yw]*G[{0, yv^(-1), yv^(-1)}, yw] + 
     6*G[{1}, yv^(-1)]*G[{yu^(-1)}, yw]*G[{0, yv^(-1), yv^(-1)}, yw] - 
     5*G[{yu^(-1)}, yw]^2*G[{0, yv^(-1), yv^(-1)}, yw] - 
     2*G[{0}, yu^(-1)]*G[{yv^(-1)}, yw]*G[{0, yv^(-1), yv^(-1)}, yw] - 
     2*G[{0}, yv^(-1)]*G[{yv^(-1)}, yw]*G[{0, yv^(-1), yv^(-1)}, yw] + 
     2*G[{0}, yw]*G[{yv^(-1)}, yw]*G[{0, yv^(-1), yv^(-1)}, yw] + 
     2*G[{1}, yu^(-1)]*G[{yv^(-1)}, yw]*G[{0, yv^(-1), yv^(-1)}, yw] + 
     2*G[{1}, yv^(-1)]*G[{yv^(-1)}, yw]*G[{0, yv^(-1), yv^(-1)}, yw] - 
     4*G[{1}, yw]*G[{yv^(-1)}, yw]*G[{0, yv^(-1), yv^(-1)}, yw] + 
     2*G[{yu^(-1)}, yw]*G[{yv^(-1)}, yw]*G[{0, yv^(-1), yv^(-1)}, yw] + 
     3*G[{yv^(-1)}, yw]^2*G[{0, yv^(-1), yv^(-1)}, yw] + 
     2*G[{0}, yu^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, yv^(-1), yv^(-1)}, yw] + 
     2*G[{0}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, yv^(-1), yv^(-1)}, yw] - 
     2*G[{0}, yw]*G[{1/(yu*yv)}, yw]*G[{0, yv^(-1), yv^(-1)}, yw] + 
     2*G[{1}, yu^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, yv^(-1), yv^(-1)}, yw] - 
     6*G[{1}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, yv^(-1), yv^(-1)}, yw] + 
     10*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{0, yv^(-1), yv^(-1)}, yw] - 
     2*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{0, yv^(-1), yv^(-1)}, yw] - 
     2*G[{1/(yu*yv)}, yw]^2*G[{0, yv^(-1), yv^(-1)}, yw] + 
     4*G[{0, 1}, yu^(-1)]*G[{0, yv^(-1), yv^(-1)}, yw] + 
     2*G[{0, 1}, yw]*G[{0, yv^(-1), yv^(-1)}, yw] - 
     2*G[{0, yu^(-1)}, yw]*G[{0, yv^(-1), yv^(-1)}, yw] - 
     2*G[{0, yv^(-1)}, yw]*G[{0, yv^(-1), yv^(-1)}, yw] + 
     2*G[{0, 1/(yu*yv)}, yw]*G[{0, yv^(-1), yv^(-1)}, yw] - 
     2*G[{1, yu^(-1)}, yw]*G[{0, yv^(-1), yv^(-1)}, yw] - 
     4*G[{1, yu}, yv^(-1)]*G[{0, yv^(-1), yv^(-1)}, yw] - 
     2*G[{1, yv^(-1)}, yw]*G[{0, yv^(-1), yv^(-1)}, yw] - 
     6*G[{yu^(-1), 1/(yu*yv)}, yw]*G[{0, yv^(-1), yv^(-1)}, yw] + 
     2*G[{yv^(-1), 1/(yu*yv)}, yw]*G[{0, yv^(-1), yv^(-1)}, yw] - 
     (2*Pi^2*G[{0, yv^(-1), 1/(yu*yv)}, yw])/3 + 2*G[{1}, yu^(-1)]^2*
      G[{0, yv^(-1), 1/(yu*yv)}, yw] - 4*G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*
      G[{0, yv^(-1), 1/(yu*yv)}, yw] + 2*G[{1}, yv^(-1)]*G[{1}, yw]*
      G[{0, yv^(-1), 1/(yu*yv)}, yw] + 4*G[{1}, yu^(-1)]*G[{yu^(-1)}, yw]*
      G[{0, yv^(-1), 1/(yu*yv)}, yw] - 6*G[{1}, yv^(-1)]*G[{yu^(-1)}, yw]*
      G[{0, yv^(-1), 1/(yu*yv)}, yw] + 3*G[{yu^(-1)}, yw]^2*
      G[{0, yv^(-1), 1/(yu*yv)}, yw] - 2*G[{1}, yw]*G[{yu}, yv^(-1)]*
      G[{0, yv^(-1), 1/(yu*yv)}, yw] + 2*G[{yu^(-1)}, yw]*G[{yu}, yv^(-1)]*
      G[{0, yv^(-1), 1/(yu*yv)}, yw] - 2*G[{1}, yv^(-1)]*G[{yv^(-1)}, yw]*
      G[{0, yv^(-1), 1/(yu*yv)}, yw] - 2*G[{yu^(-1)}, yw]*G[{yv^(-1)}, yw]*
      G[{0, yv^(-1), 1/(yu*yv)}, yw] + 2*G[{yu}, yv^(-1)]*G[{yv^(-1)}, yw]*
      G[{0, yv^(-1), 1/(yu*yv)}, yw] - G[{yv^(-1)}, yw]^2*
      G[{0, yv^(-1), 1/(yu*yv)}, yw] - 4*G[{1}, yu^(-1)]*G[{1/(yu*yv)}, yw]*
      G[{0, yv^(-1), 1/(yu*yv)}, yw] + 6*G[{1}, yv^(-1)]*G[{1/(yu*yv)}, yw]*
      G[{0, yv^(-1), 1/(yu*yv)}, yw] - 6*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*
      G[{0, yv^(-1), 1/(yu*yv)}, yw] - 2*G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw]*
      G[{0, yv^(-1), 1/(yu*yv)}, yw] + 2*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*
      G[{0, yv^(-1), 1/(yu*yv)}, yw] - 2*G[{0, 1}, yu^(-1)]*
      G[{0, yv^(-1), 1/(yu*yv)}, yw] + 2*G[{0, 1}, yv^(-1)]*
      G[{0, yv^(-1), 1/(yu*yv)}, yw] - 2*G[{0, yu}, yv^(-1)]*
      G[{0, yv^(-1), 1/(yu*yv)}, yw] - 2*G[{0, 1/(yu*yv)}, yw]*
      G[{0, yv^(-1), 1/(yu*yv)}, yw] + 2*G[{1, yu^(-1)}, yw]*
      G[{0, yv^(-1), 1/(yu*yv)}, yw] + 4*G[{1, yu}, yv^(-1)]*
      G[{0, yv^(-1), 1/(yu*yv)}, yw] + 2*G[{1, yv^(-1)}, yw]*
      G[{0, yv^(-1), 1/(yu*yv)}, yw] + 6*G[{yu^(-1), 1/(yu*yv)}, yw]*
      G[{0, yv^(-1), 1/(yu*yv)}, yw] - 2*G[{yv^(-1), 1/(yu*yv)}, yw]*
      G[{0, yv^(-1), 1/(yu*yv)}, yw] + (2*Pi^2*G[{0, 1/(yu*yv), 1}, yw])/3 - 
     2*G[{1}, yu^(-1)]^2*G[{0, 1/(yu*yv), 1}, yw] + 
     4*G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*G[{0, 1/(yu*yv), 1}, yw] - 
     2*G[{1}, yv^(-1)]*G[{1}, yw]*G[{0, 1/(yu*yv), 1}, yw] - 
     4*G[{1}, yu^(-1)]*G[{yu^(-1)}, yw]*G[{0, 1/(yu*yv), 1}, yw] + 
     6*G[{1}, yv^(-1)]*G[{yu^(-1)}, yw]*G[{0, 1/(yu*yv), 1}, yw] - 
     3*G[{yu^(-1)}, yw]^2*G[{0, 1/(yu*yv), 1}, yw] + 
     2*G[{1}, yw]*G[{yu}, yv^(-1)]*G[{0, 1/(yu*yv), 1}, yw] - 
     2*G[{yu^(-1)}, yw]*G[{yu}, yv^(-1)]*G[{0, 1/(yu*yv), 1}, yw] + 
     2*G[{1}, yv^(-1)]*G[{yv^(-1)}, yw]*G[{0, 1/(yu*yv), 1}, yw] + 
     2*G[{yu^(-1)}, yw]*G[{yv^(-1)}, yw]*G[{0, 1/(yu*yv), 1}, yw] - 
     2*G[{yu}, yv^(-1)]*G[{yv^(-1)}, yw]*G[{0, 1/(yu*yv), 1}, yw] + 
     G[{yv^(-1)}, yw]^2*G[{0, 1/(yu*yv), 1}, yw] + 
     4*G[{1}, yu^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv), 1}, yw] - 
     6*G[{1}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv), 1}, yw] + 
     6*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv), 1}, yw] + 
     2*G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv), 1}, yw] - 
     2*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv), 1}, yw] + 
     2*G[{0, 1}, yu^(-1)]*G[{0, 1/(yu*yv), 1}, yw] - 
     2*G[{0, 1}, yv^(-1)]*G[{0, 1/(yu*yv), 1}, yw] + 
     2*G[{0, yu}, yv^(-1)]*G[{0, 1/(yu*yv), 1}, yw] - 
     2*G[{1, yu^(-1)}, yw]*G[{0, 1/(yu*yv), 1}, yw] - 
     4*G[{1, yu}, yv^(-1)]*G[{0, 1/(yu*yv), 1}, yw] - 
     2*G[{1, yv^(-1)}, yw]*G[{0, 1/(yu*yv), 1}, yw] - 
     6*G[{yu^(-1), 1/(yu*yv)}, yw]*G[{0, 1/(yu*yv), 1}, yw] + 
     2*G[{yv^(-1), 1/(yu*yv)}, yw]*G[{0, 1/(yu*yv), 1}, yw] + 
     (Pi^2*G[{0, 1/(yu*yv), yu^(-1)}, yw])/3 + 2*G[{1}, yu^(-1)]^2*
      G[{0, 1/(yu*yv), yu^(-1)}, yw] - 4*G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*
      G[{0, 1/(yu*yv), yu^(-1)}, yw] + 2*G[{0}, yu^(-1)]*G[{1}, yw]*
      G[{0, 1/(yu*yv), yu^(-1)}, yw] + 2*G[{0}, yv^(-1)]*G[{1}, yw]*
      G[{0, 1/(yu*yv), yu^(-1)}, yw] - 2*G[{0}, yw]*G[{1}, yw]*
      G[{0, 1/(yu*yv), yu^(-1)}, yw] - 2*G[{1}, yu^(-1)]*G[{1}, yw]*
      G[{0, 1/(yu*yv), yu^(-1)}, yw] - 2*G[{1}, yv^(-1)]*G[{1}, yw]*
      G[{0, 1/(yu*yv), yu^(-1)}, yw] - 2*G[{1}, yw]^2*
      G[{0, 1/(yu*yv), yu^(-1)}, yw] - 2*G[{0}, yu^(-1)]*G[{yu^(-1)}, yw]*
      G[{0, 1/(yu*yv), yu^(-1)}, yw] - 2*G[{0}, yv^(-1)]*G[{yu^(-1)}, yw]*
      G[{0, 1/(yu*yv), yu^(-1)}, yw] + 2*G[{0}, yw]*G[{yu^(-1)}, yw]*
      G[{0, 1/(yu*yv), yu^(-1)}, yw] + 6*G[{1}, yu^(-1)]*G[{yu^(-1)}, yw]*
      G[{0, 1/(yu*yv), yu^(-1)}, yw] - 2*G[{1}, yv^(-1)]*G[{yu^(-1)}, yw]*
      G[{0, 1/(yu*yv), yu^(-1)}, yw] + 5*G[{yu^(-1)}, yw]^2*
      G[{0, 1/(yu*yv), yu^(-1)}, yw] - 2*G[{0}, yu^(-1)]*G[{yv^(-1)}, yw]*
      G[{0, 1/(yu*yv), yu^(-1)}, yw] - 2*G[{0}, yv^(-1)]*G[{yv^(-1)}, yw]*
      G[{0, 1/(yu*yv), yu^(-1)}, yw] + 2*G[{0}, yw]*G[{yv^(-1)}, yw]*
      G[{0, 1/(yu*yv), yu^(-1)}, yw] + 2*G[{1}, yu^(-1)]*G[{yv^(-1)}, yw]*
      G[{0, 1/(yu*yv), yu^(-1)}, yw] + 2*G[{1}, yv^(-1)]*G[{yv^(-1)}, yw]*
      G[{0, 1/(yu*yv), yu^(-1)}, yw] + 4*G[{1}, yw]*G[{yv^(-1)}, yw]*
      G[{0, 1/(yu*yv), yu^(-1)}, yw] - 2*G[{yu^(-1)}, yw]*G[{yv^(-1)}, yw]*
      G[{0, 1/(yu*yv), yu^(-1)}, yw] - 3*G[{yv^(-1)}, yw]^2*
      G[{0, 1/(yu*yv), yu^(-1)}, yw] + 2*G[{0}, yu^(-1)]*G[{1/(yu*yv)}, yw]*
      G[{0, 1/(yu*yv), yu^(-1)}, yw] + 2*G[{0}, yv^(-1)]*G[{1/(yu*yv)}, yw]*
      G[{0, 1/(yu*yv), yu^(-1)}, yw] - 2*G[{0}, yw]*G[{1/(yu*yv)}, yw]*
      G[{0, 1/(yu*yv), yu^(-1)}, yw] - 6*G[{1}, yu^(-1)]*G[{1/(yu*yv)}, yw]*
      G[{0, 1/(yu*yv), yu^(-1)}, yw] + 2*G[{1}, yv^(-1)]*G[{1/(yu*yv)}, yw]*
      G[{0, 1/(yu*yv), yu^(-1)}, yw] - 10*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*
      G[{0, 1/(yu*yv), yu^(-1)}, yw] + 2*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*
      G[{0, 1/(yu*yv), yu^(-1)}, yw] + 2*G[{1/(yu*yv)}, yw]^2*
      G[{0, 1/(yu*yv), yu^(-1)}, yw] + 4*G[{0, 1}, yv^(-1)]*
      G[{0, 1/(yu*yv), yu^(-1)}, yw] + 2*G[{0, 1}, yw]*
      G[{0, 1/(yu*yv), yu^(-1)}, yw] - 2*G[{0, yu^(-1)}, yw]*
      G[{0, 1/(yu*yv), yu^(-1)}, yw] - 4*G[{0, yu}, yv^(-1)]*
      G[{0, 1/(yu*yv), yu^(-1)}, yw] - 2*G[{0, yv^(-1)}, yw]*
      G[{0, 1/(yu*yv), yu^(-1)}, yw] + 2*G[{0, 1/(yu*yv)}, yw]*
      G[{0, 1/(yu*yv), yu^(-1)}, yw] + 2*G[{1, yu^(-1)}, yw]*
      G[{0, 1/(yu*yv), yu^(-1)}, yw] + 4*G[{1, yu}, yv^(-1)]*
      G[{0, 1/(yu*yv), yu^(-1)}, yw] + 2*G[{1, yv^(-1)}, yw]*
      G[{0, 1/(yu*yv), yu^(-1)}, yw] + 6*G[{yu^(-1), 1/(yu*yv)}, yw]*
      G[{0, 1/(yu*yv), yu^(-1)}, yw] - 2*G[{yv^(-1), 1/(yu*yv)}, yw]*
      G[{0, 1/(yu*yv), yu^(-1)}, yw] - 
     (2*Pi^2*G[{0, 1/(yu*yv), yv^(-1)}, yw])/3 + 2*G[{1}, yu^(-1)]^2*
      G[{0, 1/(yu*yv), yv^(-1)}, yw] - 4*G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*
      G[{0, 1/(yu*yv), yv^(-1)}, yw] - 2*G[{1}, yu^(-1)]*G[{1}, yw]*
      G[{0, 1/(yu*yv), yv^(-1)}, yw] + 2*G[{1}, yv^(-1)]*G[{1}, yw]*
      G[{0, 1/(yu*yv), yv^(-1)}, yw] - 2*G[{1}, yw]^2*
      G[{0, 1/(yu*yv), yv^(-1)}, yw] + 6*G[{1}, yu^(-1)]*G[{yu^(-1)}, yw]*
      G[{0, 1/(yu*yv), yv^(-1)}, yw] - 6*G[{1}, yv^(-1)]*G[{yu^(-1)}, yw]*
      G[{0, 1/(yu*yv), yv^(-1)}, yw] + 5*G[{yu^(-1)}, yw]^2*
      G[{0, 1/(yu*yv), yv^(-1)}, yw] + 2*G[{1}, yu^(-1)]*G[{yv^(-1)}, yw]*
      G[{0, 1/(yu*yv), yv^(-1)}, yw] - 2*G[{1}, yv^(-1)]*G[{yv^(-1)}, yw]*
      G[{0, 1/(yu*yv), yv^(-1)}, yw] + 4*G[{1}, yw]*G[{yv^(-1)}, yw]*
      G[{0, 1/(yu*yv), yv^(-1)}, yw] - 2*G[{yu^(-1)}, yw]*G[{yv^(-1)}, yw]*
      G[{0, 1/(yu*yv), yv^(-1)}, yw] - 3*G[{yv^(-1)}, yw]^2*
      G[{0, 1/(yu*yv), yv^(-1)}, yw] - 6*G[{1}, yu^(-1)]*G[{1/(yu*yv)}, yw]*
      G[{0, 1/(yu*yv), yv^(-1)}, yw] + 6*G[{1}, yv^(-1)]*G[{1/(yu*yv)}, yw]*
      G[{0, 1/(yu*yv), yv^(-1)}, yw] - 10*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*
      G[{0, 1/(yu*yv), yv^(-1)}, yw] + 2*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*
      G[{0, 1/(yu*yv), yv^(-1)}, yw] + 2*G[{1/(yu*yv)}, yw]^2*
      G[{0, 1/(yu*yv), yv^(-1)}, yw] - 2*G[{0, 1}, yu^(-1)]*
      G[{0, 1/(yu*yv), yv^(-1)}, yw] + 2*G[{0, 1}, yv^(-1)]*
      G[{0, 1/(yu*yv), yv^(-1)}, yw] - 2*G[{0, yu}, yv^(-1)]*
      G[{0, 1/(yu*yv), yv^(-1)}, yw] + 2*G[{1, yu^(-1)}, yw]*
      G[{0, 1/(yu*yv), yv^(-1)}, yw] + 4*G[{1, yu}, yv^(-1)]*
      G[{0, 1/(yu*yv), yv^(-1)}, yw] + 2*G[{1, yv^(-1)}, yw]*
      G[{0, 1/(yu*yv), yv^(-1)}, yw] + 6*G[{yu^(-1), 1/(yu*yv)}, yw]*
      G[{0, 1/(yu*yv), yv^(-1)}, yw] - 2*G[{yv^(-1), 1/(yu*yv)}, yw]*
      G[{0, 1/(yu*yv), yv^(-1)}, yw] - 
     (Pi^2*G[{0, 1/(yu*yv), 1/(yu*yv)}, yw])/3 - 2*G[{1}, yu^(-1)]^2*
      G[{0, 1/(yu*yv), 1/(yu*yv)}, yw] + 4*G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*
      G[{0, 1/(yu*yv), 1/(yu*yv)}, yw] - 2*G[{0}, yu^(-1)]*G[{1}, yw]*
      G[{0, 1/(yu*yv), 1/(yu*yv)}, yw] - 2*G[{0}, yv^(-1)]*G[{1}, yw]*
      G[{0, 1/(yu*yv), 1/(yu*yv)}, yw] + 2*G[{0}, yw]*G[{1}, yw]*
      G[{0, 1/(yu*yv), 1/(yu*yv)}, yw] + 4*G[{1}, yu^(-1)]*G[{1}, yw]*
      G[{0, 1/(yu*yv), 1/(yu*yv)}, yw] + 2*G[{1}, yv^(-1)]*G[{1}, yw]*
      G[{0, 1/(yu*yv), 1/(yu*yv)}, yw] + 2*G[{0}, yu^(-1)]*G[{yu^(-1)}, yw]*
      G[{0, 1/(yu*yv), 1/(yu*yv)}, yw] + 2*G[{0}, yv^(-1)]*G[{yu^(-1)}, yw]*
      G[{0, 1/(yu*yv), 1/(yu*yv)}, yw] - 2*G[{0}, yw]*G[{yu^(-1)}, yw]*
      G[{0, 1/(yu*yv), 1/(yu*yv)}, yw] - 8*G[{1}, yu^(-1)]*G[{yu^(-1)}, yw]*
      G[{0, 1/(yu*yv), 1/(yu*yv)}, yw] + 2*G[{1}, yv^(-1)]*G[{yu^(-1)}, yw]*
      G[{0, 1/(yu*yv), 1/(yu*yv)}, yw] - 3*G[{yu^(-1)}, yw]^2*
      G[{0, 1/(yu*yv), 1/(yu*yv)}, yw] - 2*G[{1}, yw]*G[{yu}, yv^(-1)]*
      G[{0, 1/(yu*yv), 1/(yu*yv)}, yw] + 2*G[{yu^(-1)}, yw]*G[{yu}, yv^(-1)]*
      G[{0, 1/(yu*yv), 1/(yu*yv)}, yw] + 2*G[{0}, yu^(-1)]*G[{yv^(-1)}, yw]*
      G[{0, 1/(yu*yv), 1/(yu*yv)}, yw] + 2*G[{0}, yv^(-1)]*G[{yv^(-1)}, yw]*
      G[{0, 1/(yu*yv), 1/(yu*yv)}, yw] - 2*G[{0}, yw]*G[{yv^(-1)}, yw]*
      G[{0, 1/(yu*yv), 1/(yu*yv)}, yw] - 4*G[{1}, yu^(-1)]*G[{yv^(-1)}, yw]*
      G[{0, 1/(yu*yv), 1/(yu*yv)}, yw] - 2*G[{1}, yv^(-1)]*G[{yv^(-1)}, yw]*
      G[{0, 1/(yu*yv), 1/(yu*yv)}, yw] + 2*G[{yu^(-1)}, yw]*G[{yv^(-1)}, yw]*
      G[{0, 1/(yu*yv), 1/(yu*yv)}, yw] + 2*G[{yu}, yv^(-1)]*G[{yv^(-1)}, yw]*
      G[{0, 1/(yu*yv), 1/(yu*yv)}, yw] + G[{yv^(-1)}, yw]^2*
      G[{0, 1/(yu*yv), 1/(yu*yv)}, yw] - 2*G[{0}, yu^(-1)]*G[{1/(yu*yv)}, yw]*
      G[{0, 1/(yu*yv), 1/(yu*yv)}, yw] - 2*G[{0}, yv^(-1)]*G[{1/(yu*yv)}, yw]*
      G[{0, 1/(yu*yv), 1/(yu*yv)}, yw] + 2*G[{0}, yw]*G[{1/(yu*yv)}, yw]*
      G[{0, 1/(yu*yv), 1/(yu*yv)}, yw] + 8*G[{1}, yu^(-1)]*G[{1/(yu*yv)}, yw]*
      G[{0, 1/(yu*yv), 1/(yu*yv)}, yw] - 2*G[{1}, yv^(-1)]*G[{1/(yu*yv)}, yw]*
      G[{0, 1/(yu*yv), 1/(yu*yv)}, yw] + 6*G[{yu^(-1)}, yw]*
      G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv), 1/(yu*yv)}, yw] - 
     2*G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv), 1/(yu*yv)}, yw] - 
     2*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv), 1/(yu*yv)}, yw] - 
     4*G[{0, 1}, yv^(-1)]*G[{0, 1/(yu*yv), 1/(yu*yv)}, yw] - 
     2*G[{0, 1}, yw]*G[{0, 1/(yu*yv), 1/(yu*yv)}, yw] + 
     2*G[{0, yu^(-1)}, yw]*G[{0, 1/(yu*yv), 1/(yu*yv)}, yw] + 
     4*G[{0, yu}, yv^(-1)]*G[{0, 1/(yu*yv), 1/(yu*yv)}, yw] + 
     2*G[{0, yv^(-1)}, yw]*G[{0, 1/(yu*yv), 1/(yu*yv)}, yw] - 
     2*G[{0, 1/(yu*yv)}, yw]*G[{0, 1/(yu*yv), 1/(yu*yv)}, yw] - 
     2*G[{1, yu^(-1)}, yw]*G[{0, 1/(yu*yv), 1/(yu*yv)}, yw] - 
     4*G[{1, yu}, yv^(-1)]*G[{0, 1/(yu*yv), 1/(yu*yv)}, yw] - 
     2*G[{1, yv^(-1)}, yw]*G[{0, 1/(yu*yv), 1/(yu*yv)}, yw] - 
     6*G[{yu^(-1), 1/(yu*yv)}, yw]*G[{0, 1/(yu*yv), 1/(yu*yv)}, yw] + 
     2*G[{yv^(-1), 1/(yu*yv)}, yw]*G[{0, 1/(yu*yv), 1/(yu*yv)}, yw] - 
     (2*Pi^2*G[{1, 1, yu^(-1)}, yw])/3 + 2*G[{1}, yu^(-1)]^2*
      G[{1, 1, yu^(-1)}, yw] - 4*G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*
      G[{1, 1, yu^(-1)}, yw] + 2*G[{1}, yu^(-1)]*G[{1}, yw]*
      G[{1, 1, yu^(-1)}, yw] - 2*G[{1}, yv^(-1)]*G[{1}, yw]*
      G[{1, 1, yu^(-1)}, yw] + 6*G[{1}, yu^(-1)]*G[{yu^(-1)}, yw]*
      G[{1, 1, yu^(-1)}, yw] - 6*G[{1}, yv^(-1)]*G[{yu^(-1)}, yw]*
      G[{1, 1, yu^(-1)}, yw] + 3*G[{yu^(-1)}, yw]^2*G[{1, 1, yu^(-1)}, yw] - 
     2*G[{1}, yu^(-1)]*G[{yv^(-1)}, yw]*G[{1, 1, yu^(-1)}, yw] - 
     2*G[{1}, yv^(-1)]*G[{yv^(-1)}, yw]*G[{1, 1, yu^(-1)}, yw] - 
     4*G[{1}, yw]*G[{yv^(-1)}, yw]*G[{1, 1, yu^(-1)}, yw] - 
     6*G[{yu^(-1)}, yw]*G[{yv^(-1)}, yw]*G[{1, 1, yu^(-1)}, yw] + 
     4*G[{yu}, yv^(-1)]*G[{yv^(-1)}, yw]*G[{1, 1, yu^(-1)}, yw] - 
     G[{yv^(-1)}, yw]^2*G[{1, 1, yu^(-1)}, yw] - 6*G[{1}, yu^(-1)]*
      G[{1/(yu*yv)}, yw]*G[{1, 1, yu^(-1)}, yw] + 
     6*G[{1}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{1, 1, yu^(-1)}, yw] - 
     6*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{1, 1, yu^(-1)}, yw] + 
     6*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{1, 1, yu^(-1)}, yw] - 
     2*G[{0, 1}, yu^(-1)]*G[{1, 1, yu^(-1)}, yw] + 2*G[{0, 1}, yv^(-1)]*
      G[{1, 1, yu^(-1)}, yw] - 2*G[{0, yu}, yv^(-1)]*G[{1, 1, yu^(-1)}, yw] + 
     2*G[{1, yu^(-1)}, yw]*G[{1, 1, yu^(-1)}, yw] + 
     4*G[{1, yu}, yv^(-1)]*G[{1, 1, yu^(-1)}, yw] + 
     2*G[{1, yv^(-1)}, yw]*G[{1, 1, yu^(-1)}, yw] + 
     6*G[{yu^(-1), 1/(yu*yv)}, yw]*G[{1, 1, yu^(-1)}, yw] - 
     2*G[{yv^(-1), 1/(yu*yv)}, yw]*G[{1, 1, yu^(-1)}, yw] - 
     8*G[{1}, yu^(-1)]*G[{1}, yw]*G[{1, 1, yu}, yv^(-1)] + 
     8*G[{1}, yu^(-1)]*G[{yu^(-1)}, yw]*G[{1, 1, yu}, yv^(-1)] + 
     4*G[{1}, yw]*G[{yu^(-1)}, yw]*G[{1, 1, yu}, yv^(-1)] + 
     8*G[{1}, yu^(-1)]*G[{yv^(-1)}, yw]*G[{1, 1, yu}, yv^(-1)] - 
     4*G[{yu^(-1)}, yw]*G[{yv^(-1)}, yw]*G[{1, 1, yu}, yv^(-1)] - 
     8*G[{1}, yu^(-1)]*G[{1/(yu*yv)}, yw]*G[{1, 1, yu}, yv^(-1)] - 
     4*G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{1, 1, yu}, yv^(-1)] + 
     4*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{1, 1, yu}, yv^(-1)] - 
     (11*Pi^2*G[{1, 1, yv^(-1)}, yw])/3 + 2*G[{1}, yu^(-1)]^2*
      G[{1, 1, yv^(-1)}, yw] - 8*G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*
      G[{1, 1, yv^(-1)}, yw] - 6*G[{0}, yu^(-1)]*G[{1}, yw]*
      G[{1, 1, yv^(-1)}, yw] - 6*G[{0}, yv^(-1)]*G[{1}, yw]*
      G[{1, 1, yv^(-1)}, yw] + 6*G[{0}, yw]*G[{1}, yw]*
      G[{1, 1, yv^(-1)}, yw] + 10*G[{1}, yu^(-1)]*G[{1}, yw]*
      G[{1, 1, yv^(-1)}, yw] + 6*G[{1}, yv^(-1)]*G[{1}, yw]*
      G[{1, 1, yv^(-1)}, yw] + 2*G[{1}, yw]^2*G[{1, 1, yv^(-1)}, yw] + 
     6*G[{0}, yu^(-1)]*G[{yu^(-1)}, yw]*G[{1, 1, yv^(-1)}, yw] + 
     6*G[{0}, yv^(-1)]*G[{yu^(-1)}, yw]*G[{1, 1, yv^(-1)}, yw] - 
     6*G[{0}, yw]*G[{yu^(-1)}, yw]*G[{1, 1, yv^(-1)}, yw] + 
     2*G[{1}, yu^(-1)]*G[{yu^(-1)}, yw]*G[{1, 1, yv^(-1)}, yw] - 
     6*G[{1}, yv^(-1)]*G[{yu^(-1)}, yw]*G[{1, 1, yv^(-1)}, yw] + 
     8*G[{1}, yw]*G[{yu^(-1)}, yw]*G[{1, 1, yv^(-1)}, yw] + 
     3*G[{yu^(-1)}, yw]^2*G[{1, 1, yv^(-1)}, yw] + 
     4*G[{1}, yu^(-1)]*G[{yu}, yv^(-1)]*G[{1, 1, yv^(-1)}, yw] + 
     4*G[{1}, yv^(-1)]*G[{yu}, yv^(-1)]*G[{1, 1, yv^(-1)}, yw] - 
     4*G[{1}, yw]*G[{yu}, yv^(-1)]*G[{1, 1, yv^(-1)}, yw] - 
     8*G[{yu^(-1)}, yw]*G[{yu}, yv^(-1)]*G[{1, 1, yv^(-1)}, yw] - 
     4*G[{yu}, yv^(-1)]^2*G[{1, 1, yv^(-1)}, yw] + 
     6*G[{0}, yu^(-1)]*G[{yv^(-1)}, yw]*G[{1, 1, yv^(-1)}, yw] + 
     6*G[{0}, yv^(-1)]*G[{yv^(-1)}, yw]*G[{1, 1, yv^(-1)}, yw] - 
     6*G[{0}, yw]*G[{yv^(-1)}, yw]*G[{1, 1, yv^(-1)}, yw] - 
     2*G[{1}, yu^(-1)]*G[{yv^(-1)}, yw]*G[{1, 1, yv^(-1)}, yw] - 
     6*G[{1}, yv^(-1)]*G[{yv^(-1)}, yw]*G[{1, 1, yv^(-1)}, yw] + 
     4*G[{1}, yw]*G[{yv^(-1)}, yw]*G[{1, 1, yv^(-1)}, yw] + 
     2*G[{yu^(-1)}, yw]*G[{yv^(-1)}, yw]*G[{1, 1, yv^(-1)}, yw] - 
     4*G[{yu}, yv^(-1)]*G[{yv^(-1)}, yw]*G[{1, 1, yv^(-1)}, yw] - 
     G[{yv^(-1)}, yw]^2*G[{1, 1, yv^(-1)}, yw] - 6*G[{0}, yu^(-1)]*
      G[{1/(yu*yv)}, yw]*G[{1, 1, yv^(-1)}, yw] - 
     6*G[{0}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{1, 1, yv^(-1)}, yw] + 
     6*G[{0}, yw]*G[{1/(yu*yv)}, yw]*G[{1, 1, yv^(-1)}, yw] - 
     2*G[{1}, yu^(-1)]*G[{1/(yu*yv)}, yw]*G[{1, 1, yv^(-1)}, yw] + 
     6*G[{1}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{1, 1, yv^(-1)}, yw] - 
     8*G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{1, 1, yv^(-1)}, yw] - 
     6*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{1, 1, yv^(-1)}, yw] + 
     8*G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{1, 1, yv^(-1)}, yw] - 
     2*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{1, 1, yv^(-1)}, yw] + 
     2*G[{1/(yu*yv)}, yw]^2*G[{1, 1, yv^(-1)}, yw] - 
     8*G[{0, 1}, yu^(-1)]*G[{1, 1, yv^(-1)}, yw] - 4*G[{0, 1}, yv^(-1)]*
      G[{1, 1, yv^(-1)}, yw] - 6*G[{0, 1}, yw]*G[{1, 1, yv^(-1)}, yw] + 
     6*G[{0, yu^(-1)}, yw]*G[{1, 1, yv^(-1)}, yw] + 
     4*G[{0, yu}, yv^(-1)]*G[{1, 1, yv^(-1)}, yw] + 
     6*G[{0, yv^(-1)}, yw]*G[{1, 1, yv^(-1)}, yw] - 
     6*G[{0, 1/(yu*yv)}, yw]*G[{1, 1, yv^(-1)}, yw] - 
     2*G[{1, yu^(-1)}, yw]*G[{1, 1, yv^(-1)}, yw] + 
     4*G[{1, yu}, yv^(-1)]*G[{1, 1, yv^(-1)}, yw] + 
     6*G[{1, yv^(-1)}, yw]*G[{1, 1, yv^(-1)}, yw] + 
     2*G[{yu^(-1), 1/(yu*yv)}, yw]*G[{1, 1, yv^(-1)}, yw] + 
     2*G[{yv^(-1), 1/(yu*yv)}, yw]*G[{1, 1, yv^(-1)}, yw] + 
     Pi^2*G[{1, 1, 1/(yu*yv)}, yw] + 4*G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*
      G[{1, 1, 1/(yu*yv)}, yw] + 2*G[{0}, yu^(-1)]*G[{1}, yw]*
      G[{1, 1, 1/(yu*yv)}, yw] + 2*G[{0}, yv^(-1)]*G[{1}, yw]*
      G[{1, 1, 1/(yu*yv)}, yw] - 2*G[{0}, yw]*G[{1}, yw]*
      G[{1, 1, 1/(yu*yv)}, yw] + 2*G[{1}, yw]^2*G[{1, 1, 1/(yu*yv)}, yw] - 
     2*G[{0}, yu^(-1)]*G[{yu^(-1)}, yw]*G[{1, 1, 1/(yu*yv)}, yw] - 
     2*G[{0}, yv^(-1)]*G[{yu^(-1)}, yw]*G[{1, 1, 1/(yu*yv)}, yw] + 
     2*G[{0}, yw]*G[{yu^(-1)}, yw]*G[{1, 1, 1/(yu*yv)}, yw] - 
     4*G[{1}, yw]*G[{yu^(-1)}, yw]*G[{1, 1, 1/(yu*yv)}, yw] - 
     4*G[{1}, yu^(-1)]*G[{yu}, yv^(-1)]*G[{1, 1, 1/(yu*yv)}, yw] - 
     4*G[{1}, yv^(-1)]*G[{yu}, yv^(-1)]*G[{1, 1, 1/(yu*yv)}, yw] - 
     4*G[{1}, yw]*G[{yu}, yv^(-1)]*G[{1, 1, 1/(yu*yv)}, yw] + 
     4*G[{yu^(-1)}, yw]*G[{yu}, yv^(-1)]*G[{1, 1, 1/(yu*yv)}, yw] + 
     4*G[{yu}, yv^(-1)]^2*G[{1, 1, 1/(yu*yv)}, yw] - 
     2*G[{0}, yu^(-1)]*G[{yv^(-1)}, yw]*G[{1, 1, 1/(yu*yv)}, yw] - 
     2*G[{0}, yv^(-1)]*G[{yv^(-1)}, yw]*G[{1, 1, 1/(yu*yv)}, yw] + 
     2*G[{0}, yw]*G[{yv^(-1)}, yw]*G[{1, 1, 1/(yu*yv)}, yw] + 
     4*G[{1}, yu^(-1)]*G[{yv^(-1)}, yw]*G[{1, 1, 1/(yu*yv)}, yw] + 
     4*G[{1}, yv^(-1)]*G[{yv^(-1)}, yw]*G[{1, 1, 1/(yu*yv)}, yw] + 
     4*G[{1}, yw]*G[{yv^(-1)}, yw]*G[{1, 1, 1/(yu*yv)}, yw] - 
     4*G[{yu}, yv^(-1)]*G[{yv^(-1)}, yw]*G[{1, 1, 1/(yu*yv)}, yw] + 
     2*G[{0}, yu^(-1)]*G[{1/(yu*yv)}, yw]*G[{1, 1, 1/(yu*yv)}, yw] + 
     2*G[{0}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{1, 1, 1/(yu*yv)}, yw] - 
     2*G[{0}, yw]*G[{1/(yu*yv)}, yw]*G[{1, 1, 1/(yu*yv)}, yw] + 
     4*G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{1, 1, 1/(yu*yv)}, yw] - 
     4*G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{1, 1, 1/(yu*yv)}, yw] - 
     2*G[{1/(yu*yv)}, yw]^2*G[{1, 1, 1/(yu*yv)}, yw] + 
     2*G[{0, 1}, yu^(-1)]*G[{1, 1, 1/(yu*yv)}, yw] + 
     2*G[{0, 1}, yv^(-1)]*G[{1, 1, 1/(yu*yv)}, yw] + 
     2*G[{0, 1}, yw]*G[{1, 1, 1/(yu*yv)}, yw] - 2*G[{0, yu^(-1)}, yw]*
      G[{1, 1, 1/(yu*yv)}, yw] - 2*G[{0, yu}, yv^(-1)]*
      G[{1, 1, 1/(yu*yv)}, yw] - 2*G[{0, yv^(-1)}, yw]*
      G[{1, 1, 1/(yu*yv)}, yw] + 2*G[{0, 1/(yu*yv)}, yw]*
      G[{1, 1, 1/(yu*yv)}, yw] + 4*G[{1, yu^(-1)}, yw]*
      G[{1, 1, 1/(yu*yv)}, yw] - 4*G[{1, yv^(-1)}, yw]*
      G[{1, 1, 1/(yu*yv)}, yw] + 4*G[{yu^(-1), 1/(yu*yv)}, yw]*
      G[{1, 1, 1/(yu*yv)}, yw] - 4*G[{yv^(-1), 1/(yu*yv)}, yw]*
      G[{1, 1, 1/(yu*yv)}, yw] + (Pi^2*G[{1, yu^(-1), yu^(-1)}, yw])/3 + 
     2*G[{1}, yu^(-1)]^2*G[{1, yu^(-1), yu^(-1)}, yw] + 
     2*G[{0}, yu^(-1)]*G[{1}, yw]*G[{1, yu^(-1), yu^(-1)}, yw] + 
     2*G[{0}, yv^(-1)]*G[{1}, yw]*G[{1, yu^(-1), yu^(-1)}, yw] - 
     2*G[{0}, yw]*G[{1}, yw]*G[{1, yu^(-1), yu^(-1)}, yw] + 
     2*G[{1}, yu^(-1)]*G[{1}, yw]*G[{1, yu^(-1), yu^(-1)}, yw] - 
     2*G[{1}, yv^(-1)]*G[{1}, yw]*G[{1, yu^(-1), yu^(-1)}, yw] + 
     2*G[{1}, yw]^2*G[{1, yu^(-1), yu^(-1)}, yw] - 
     2*G[{0}, yu^(-1)]*G[{yu^(-1)}, yw]*G[{1, yu^(-1), yu^(-1)}, yw] - 
     2*G[{0}, yv^(-1)]*G[{yu^(-1)}, yw]*G[{1, yu^(-1), yu^(-1)}, yw] + 
     2*G[{0}, yw]*G[{yu^(-1)}, yw]*G[{1, yu^(-1), yu^(-1)}, yw] + 
     10*G[{1}, yu^(-1)]*G[{yu^(-1)}, yw]*G[{1, yu^(-1), yu^(-1)}, yw] - 
     2*G[{1}, yv^(-1)]*G[{yu^(-1)}, yw]*G[{1, yu^(-1), yu^(-1)}, yw] + 
     4*G[{1}, yw]*G[{yu^(-1)}, yw]*G[{1, yu^(-1), yu^(-1)}, yw] + 
     5*G[{yu^(-1)}, yw]^2*G[{1, yu^(-1), yu^(-1)}, yw] - 
     4*G[{1}, yu^(-1)]*G[{yu}, yv^(-1)]*G[{1, yu^(-1), yu^(-1)}, yw] - 
     4*G[{1}, yv^(-1)]*G[{yu}, yv^(-1)]*G[{1, yu^(-1), yu^(-1)}, yw] - 
     4*G[{1}, yw]*G[{yu}, yv^(-1)]*G[{1, yu^(-1), yu^(-1)}, yw] - 
     4*G[{yu^(-1)}, yw]*G[{yu}, yv^(-1)]*G[{1, yu^(-1), yu^(-1)}, yw] + 
     4*G[{yu}, yv^(-1)]^2*G[{1, yu^(-1), yu^(-1)}, yw] - 
     2*G[{0}, yu^(-1)]*G[{yv^(-1)}, yw]*G[{1, yu^(-1), yu^(-1)}, yw] - 
     2*G[{0}, yv^(-1)]*G[{yv^(-1)}, yw]*G[{1, yu^(-1), yu^(-1)}, yw] + 
     2*G[{0}, yw]*G[{yv^(-1)}, yw]*G[{1, yu^(-1), yu^(-1)}, yw] + 
     2*G[{1}, yu^(-1)]*G[{yv^(-1)}, yw]*G[{1, yu^(-1), yu^(-1)}, yw] - 
     2*G[{1}, yv^(-1)]*G[{yv^(-1)}, yw]*G[{1, yu^(-1), yu^(-1)}, yw] - 
     4*G[{1}, yw]*G[{yv^(-1)}, yw]*G[{1, yu^(-1), yu^(-1)}, yw] - 
     6*G[{yu^(-1)}, yw]*G[{yv^(-1)}, yw]*G[{1, yu^(-1), yu^(-1)}, yw] + 
     4*G[{yu}, yv^(-1)]*G[{yv^(-1)}, yw]*G[{1, yu^(-1), yu^(-1)}, yw] - 
     3*G[{yv^(-1)}, yw]^2*G[{1, yu^(-1), yu^(-1)}, yw] + 
     2*G[{0}, yu^(-1)]*G[{1/(yu*yv)}, yw]*G[{1, yu^(-1), yu^(-1)}, yw] + 
     2*G[{0}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{1, yu^(-1), yu^(-1)}, yw] - 
     2*G[{0}, yw]*G[{1/(yu*yv)}, yw]*G[{1, yu^(-1), yu^(-1)}, yw] - 
     10*G[{1}, yu^(-1)]*G[{1/(yu*yv)}, yw]*G[{1, yu^(-1), yu^(-1)}, yw] + 
     2*G[{1}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{1, yu^(-1), yu^(-1)}, yw] - 
     4*G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{1, yu^(-1), yu^(-1)}, yw] - 
     10*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{1, yu^(-1), yu^(-1)}, yw] + 
     4*G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{1, yu^(-1), yu^(-1)}, yw] + 
     6*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{1, yu^(-1), yu^(-1)}, yw] + 
     2*G[{1/(yu*yv)}, yw]^2*G[{1, yu^(-1), yu^(-1)}, yw] + 
     4*G[{0, 1}, yv^(-1)]*G[{1, yu^(-1), yu^(-1)}, yw] + 
     2*G[{0, 1}, yw]*G[{1, yu^(-1), yu^(-1)}, yw] - 
     2*G[{0, yu^(-1)}, yw]*G[{1, yu^(-1), yu^(-1)}, yw] - 
     4*G[{0, yu}, yv^(-1)]*G[{1, yu^(-1), yu^(-1)}, yw] - 
     2*G[{0, yv^(-1)}, yw]*G[{1, yu^(-1), yu^(-1)}, yw] + 
     2*G[{0, 1/(yu*yv)}, yw]*G[{1, yu^(-1), yu^(-1)}, yw] + 
     6*G[{1, yu^(-1)}, yw]*G[{1, yu^(-1), yu^(-1)}, yw] + 
     4*G[{1, yu}, yv^(-1)]*G[{1, yu^(-1), yu^(-1)}, yw] + 
     2*G[{1, yv^(-1)}, yw]*G[{1, yu^(-1), yu^(-1)}, yw] + 
     6*G[{yu^(-1), 1/(yu*yv)}, yw]*G[{1, yu^(-1), yu^(-1)}, yw] - 
     2*G[{yv^(-1), 1/(yu*yv)}, yw]*G[{1, yu^(-1), yu^(-1)}, yw] - 
     (2*Pi^2*G[{1, yu^(-1), yv^(-1)}, yw])/3 + 2*G[{1}, yu^(-1)]^2*
      G[{1, yu^(-1), yv^(-1)}, yw] - 4*G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*
      G[{1, yu^(-1), yv^(-1)}, yw] + 2*G[{1}, yu^(-1)]*G[{1}, yw]*
      G[{1, yu^(-1), yv^(-1)}, yw] - 2*G[{1}, yv^(-1)]*G[{1}, yw]*
      G[{1, yu^(-1), yv^(-1)}, yw] + 6*G[{1}, yu^(-1)]*G[{yu^(-1)}, yw]*
      G[{1, yu^(-1), yv^(-1)}, yw] - 6*G[{1}, yv^(-1)]*G[{yu^(-1)}, yw]*
      G[{1, yu^(-1), yv^(-1)}, yw] + 5*G[{yu^(-1)}, yw]^2*
      G[{1, yu^(-1), yv^(-1)}, yw] + 2*G[{1}, yu^(-1)]*G[{yv^(-1)}, yw]*
      G[{1, yu^(-1), yv^(-1)}, yw] - 2*G[{1}, yv^(-1)]*G[{yv^(-1)}, yw]*
      G[{1, yu^(-1), yv^(-1)}, yw] - 2*G[{yu^(-1)}, yw]*G[{yv^(-1)}, yw]*
      G[{1, yu^(-1), yv^(-1)}, yw] - 3*G[{yv^(-1)}, yw]^2*
      G[{1, yu^(-1), yv^(-1)}, yw] - 6*G[{1}, yu^(-1)]*G[{1/(yu*yv)}, yw]*
      G[{1, yu^(-1), yv^(-1)}, yw] + 6*G[{1}, yv^(-1)]*G[{1/(yu*yv)}, yw]*
      G[{1, yu^(-1), yv^(-1)}, yw] - 10*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*
      G[{1, yu^(-1), yv^(-1)}, yw] + 2*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*
      G[{1, yu^(-1), yv^(-1)}, yw] + 2*G[{1/(yu*yv)}, yw]^2*
      G[{1, yu^(-1), yv^(-1)}, yw] - 2*G[{0, 1}, yu^(-1)]*
      G[{1, yu^(-1), yv^(-1)}, yw] + 2*G[{0, 1}, yv^(-1)]*
      G[{1, yu^(-1), yv^(-1)}, yw] - 2*G[{0, yu}, yv^(-1)]*
      G[{1, yu^(-1), yv^(-1)}, yw] + 2*G[{1, yu^(-1)}, yw]*
      G[{1, yu^(-1), yv^(-1)}, yw] + 4*G[{1, yu}, yv^(-1)]*
      G[{1, yu^(-1), yv^(-1)}, yw] + 2*G[{1, yv^(-1)}, yw]*
      G[{1, yu^(-1), yv^(-1)}, yw] + 6*G[{yu^(-1), 1/(yu*yv)}, yw]*
      G[{1, yu^(-1), yv^(-1)}, yw] - 2*G[{yv^(-1), 1/(yu*yv)}, yw]*
      G[{1, yu^(-1), yv^(-1)}, yw] - (Pi^2*G[{1, yu^(-1), 1/(yu*yv)}, yw])/
      3 - 2*G[{1}, yu^(-1)]^2*G[{1, yu^(-1), 1/(yu*yv)}, yw] - 
     2*G[{0}, yu^(-1)]*G[{1}, yw]*G[{1, yu^(-1), 1/(yu*yv)}, yw] - 
     2*G[{0}, yv^(-1)]*G[{1}, yw]*G[{1, yu^(-1), 1/(yu*yv)}, yw] + 
     2*G[{0}, yw]*G[{1}, yw]*G[{1, yu^(-1), 1/(yu*yv)}, yw] - 
     2*G[{1}, yu^(-1)]*G[{1}, yw]*G[{1, yu^(-1), 1/(yu*yv)}, yw] + 
     2*G[{1}, yv^(-1)]*G[{1}, yw]*G[{1, yu^(-1), 1/(yu*yv)}, yw] - 
     2*G[{1}, yw]^2*G[{1, yu^(-1), 1/(yu*yv)}, yw] + 
     2*G[{0}, yu^(-1)]*G[{yu^(-1)}, yw]*G[{1, yu^(-1), 1/(yu*yv)}, yw] + 
     2*G[{0}, yv^(-1)]*G[{yu^(-1)}, yw]*G[{1, yu^(-1), 1/(yu*yv)}, yw] - 
     2*G[{0}, yw]*G[{yu^(-1)}, yw]*G[{1, yu^(-1), 1/(yu*yv)}, yw] - 
     6*G[{1}, yu^(-1)]*G[{yu^(-1)}, yw]*G[{1, yu^(-1), 1/(yu*yv)}, yw] + 
     2*G[{1}, yv^(-1)]*G[{yu^(-1)}, yw]*G[{1, yu^(-1), 1/(yu*yv)}, yw] - 
     3*G[{yu^(-1)}, yw]^2*G[{1, yu^(-1), 1/(yu*yv)}, yw] + 
     4*G[{1}, yu^(-1)]*G[{yu}, yv^(-1)]*G[{1, yu^(-1), 1/(yu*yv)}, yw] + 
     4*G[{1}, yv^(-1)]*G[{yu}, yv^(-1)]*G[{1, yu^(-1), 1/(yu*yv)}, yw] + 
     4*G[{1}, yw]*G[{yu}, yv^(-1)]*G[{1, yu^(-1), 1/(yu*yv)}, yw] - 
     4*G[{yu}, yv^(-1)]^2*G[{1, yu^(-1), 1/(yu*yv)}, yw] + 
     2*G[{0}, yu^(-1)]*G[{yv^(-1)}, yw]*G[{1, yu^(-1), 1/(yu*yv)}, yw] + 
     2*G[{0}, yv^(-1)]*G[{yv^(-1)}, yw]*G[{1, yu^(-1), 1/(yu*yv)}, yw] - 
     2*G[{0}, yw]*G[{yv^(-1)}, yw]*G[{1, yu^(-1), 1/(yu*yv)}, yw] - 
     2*G[{1}, yu^(-1)]*G[{yv^(-1)}, yw]*G[{1, yu^(-1), 1/(yu*yv)}, yw] + 
     2*G[{1}, yv^(-1)]*G[{yv^(-1)}, yw]*G[{1, yu^(-1), 1/(yu*yv)}, yw] + 
     4*G[{1}, yw]*G[{yv^(-1)}, yw]*G[{1, yu^(-1), 1/(yu*yv)}, yw] + 
     2*G[{yu^(-1)}, yw]*G[{yv^(-1)}, yw]*G[{1, yu^(-1), 1/(yu*yv)}, yw] - 
     4*G[{yu}, yv^(-1)]*G[{yv^(-1)}, yw]*G[{1, yu^(-1), 1/(yu*yv)}, yw] + 
     G[{yv^(-1)}, yw]^2*G[{1, yu^(-1), 1/(yu*yv)}, yw] - 
     2*G[{0}, yu^(-1)]*G[{1/(yu*yv)}, yw]*G[{1, yu^(-1), 1/(yu*yv)}, yw] - 
     2*G[{0}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{1, yu^(-1), 1/(yu*yv)}, yw] + 
     2*G[{0}, yw]*G[{1/(yu*yv)}, yw]*G[{1, yu^(-1), 1/(yu*yv)}, yw] + 
     6*G[{1}, yu^(-1)]*G[{1/(yu*yv)}, yw]*G[{1, yu^(-1), 1/(yu*yv)}, yw] - 
     2*G[{1}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{1, yu^(-1), 1/(yu*yv)}, yw] + 
     6*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{1, yu^(-1), 1/(yu*yv)}, yw] - 
     2*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{1, yu^(-1), 1/(yu*yv)}, yw] - 
     4*G[{0, 1}, yv^(-1)]*G[{1, yu^(-1), 1/(yu*yv)}, yw] - 
     2*G[{0, 1}, yw]*G[{1, yu^(-1), 1/(yu*yv)}, yw] + 
     2*G[{0, yu^(-1)}, yw]*G[{1, yu^(-1), 1/(yu*yv)}, yw] + 
     4*G[{0, yu}, yv^(-1)]*G[{1, yu^(-1), 1/(yu*yv)}, yw] + 
     2*G[{0, yv^(-1)}, yw]*G[{1, yu^(-1), 1/(yu*yv)}, yw] - 
     2*G[{0, 1/(yu*yv)}, yw]*G[{1, yu^(-1), 1/(yu*yv)}, yw] - 
     6*G[{1, yu^(-1)}, yw]*G[{1, yu^(-1), 1/(yu*yv)}, yw] - 
     4*G[{1, yu}, yv^(-1)]*G[{1, yu^(-1), 1/(yu*yv)}, yw] - 
     2*G[{1, yv^(-1)}, yw]*G[{1, yu^(-1), 1/(yu*yv)}, yw] - 
     6*G[{yu^(-1), 1/(yu*yv)}, yw]*G[{1, yu^(-1), 1/(yu*yv)}, yw] + 
     2*G[{yv^(-1), 1/(yu*yv)}, yw]*G[{1, yu^(-1), 1/(yu*yv)}, yw] - 
     4*G[{1}, yu^(-1)]*G[{1}, yw]*G[{1, yu, yu}, yv^(-1)] - 
     4*G[{1}, yv^(-1)]*G[{1}, yw]*G[{1, yu, yu}, yv^(-1)] - 
     2*G[{1}, yw]^2*G[{1, yu, yu}, yv^(-1)] + 4*G[{1}, yu^(-1)]*
      G[{yu^(-1)}, yw]*G[{1, yu, yu}, yv^(-1)] + 4*G[{1}, yv^(-1)]*
      G[{yu^(-1)}, yw]*G[{1, yu, yu}, yv^(-1)] + 
     4*G[{1}, yw]*G[{yu^(-1)}, yw]*G[{1, yu, yu}, yv^(-1)] + 
     4*G[{1}, yu^(-1)]*G[{yv^(-1)}, yw]*G[{1, yu, yu}, yv^(-1)] + 
     4*G[{1}, yv^(-1)]*G[{yv^(-1)}, yw]*G[{1, yu, yu}, yv^(-1)] + 
     4*G[{1}, yw]*G[{yv^(-1)}, yw]*G[{1, yu, yu}, yv^(-1)] - 
     8*G[{yu^(-1)}, yw]*G[{yv^(-1)}, yw]*G[{1, yu, yu}, yv^(-1)] - 
     4*G[{1}, yu^(-1)]*G[{1/(yu*yv)}, yw]*G[{1, yu, yu}, yv^(-1)] - 
     4*G[{1}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{1, yu, yu}, yv^(-1)] - 
     4*G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{1, yu, yu}, yv^(-1)] + 
     8*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{1, yu, yu}, yv^(-1)] - 
     2*G[{1/(yu*yv)}, yw]^2*G[{1, yu, yu}, yv^(-1)] + 
     4*G[{1, yu^(-1)}, yw]*G[{1, yu, yu}, yv^(-1)] - 
     4*G[{1, yv^(-1)}, yw]*G[{1, yu, yu}, yv^(-1)] + 
     4*G[{yu^(-1), 1/(yu*yv)}, yw]*G[{1, yu, yu}, yv^(-1)] - 
     4*G[{yv^(-1), 1/(yu*yv)}, yw]*G[{1, yu, yu}, yv^(-1)] - 
     (2*Pi^2*G[{1, yv^(-1), yu^(-1)}, yw])/3 + 2*G[{1}, yu^(-1)]^2*
      G[{1, yv^(-1), yu^(-1)}, yw] - 4*G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*
      G[{1, yv^(-1), yu^(-1)}, yw] + 2*G[{1}, yu^(-1)]*G[{1}, yw]*
      G[{1, yv^(-1), yu^(-1)}, yw] - 2*G[{1}, yv^(-1)]*G[{1}, yw]*
      G[{1, yv^(-1), yu^(-1)}, yw] + 6*G[{1}, yu^(-1)]*G[{yu^(-1)}, yw]*
      G[{1, yv^(-1), yu^(-1)}, yw] - 6*G[{1}, yv^(-1)]*G[{yu^(-1)}, yw]*
      G[{1, yv^(-1), yu^(-1)}, yw] + 5*G[{yu^(-1)}, yw]^2*
      G[{1, yv^(-1), yu^(-1)}, yw] + 2*G[{1}, yu^(-1)]*G[{yv^(-1)}, yw]*
      G[{1, yv^(-1), yu^(-1)}, yw] - 2*G[{1}, yv^(-1)]*G[{yv^(-1)}, yw]*
      G[{1, yv^(-1), yu^(-1)}, yw] - 2*G[{yu^(-1)}, yw]*G[{yv^(-1)}, yw]*
      G[{1, yv^(-1), yu^(-1)}, yw] - 3*G[{yv^(-1)}, yw]^2*
      G[{1, yv^(-1), yu^(-1)}, yw] - 6*G[{1}, yu^(-1)]*G[{1/(yu*yv)}, yw]*
      G[{1, yv^(-1), yu^(-1)}, yw] + 6*G[{1}, yv^(-1)]*G[{1/(yu*yv)}, yw]*
      G[{1, yv^(-1), yu^(-1)}, yw] - 10*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*
      G[{1, yv^(-1), yu^(-1)}, yw] + 2*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*
      G[{1, yv^(-1), yu^(-1)}, yw] + 2*G[{1/(yu*yv)}, yw]^2*
      G[{1, yv^(-1), yu^(-1)}, yw] - 2*G[{0, 1}, yu^(-1)]*
      G[{1, yv^(-1), yu^(-1)}, yw] + 2*G[{0, 1}, yv^(-1)]*
      G[{1, yv^(-1), yu^(-1)}, yw] - 2*G[{0, yu}, yv^(-1)]*
      G[{1, yv^(-1), yu^(-1)}, yw] + 2*G[{1, yu^(-1)}, yw]*
      G[{1, yv^(-1), yu^(-1)}, yw] + 4*G[{1, yu}, yv^(-1)]*
      G[{1, yv^(-1), yu^(-1)}, yw] - 2*G[{1, yv^(-1)}, yw]*
      G[{1, yv^(-1), yu^(-1)}, yw] + 6*G[{yu^(-1), 1/(yu*yv)}, yw]*
      G[{1, yv^(-1), yu^(-1)}, yw] - 2*G[{yv^(-1), 1/(yu*yv)}, yw]*
      G[{1, yv^(-1), yu^(-1)}, yw] - (11*Pi^2*G[{1, yv^(-1), yv^(-1)}, yw])/
      3 + 2*G[{1}, yu^(-1)]^2*G[{1, yv^(-1), yv^(-1)}, yw] - 
     8*G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*G[{1, yv^(-1), yv^(-1)}, yw] - 
     6*G[{0}, yu^(-1)]*G[{1}, yw]*G[{1, yv^(-1), yv^(-1)}, yw] - 
     6*G[{0}, yv^(-1)]*G[{1}, yw]*G[{1, yv^(-1), yv^(-1)}, yw] + 
     6*G[{0}, yw]*G[{1}, yw]*G[{1, yv^(-1), yv^(-1)}, yw] + 
     10*G[{1}, yu^(-1)]*G[{1}, yw]*G[{1, yv^(-1), yv^(-1)}, yw] + 
     6*G[{1}, yv^(-1)]*G[{1}, yw]*G[{1, yv^(-1), yv^(-1)}, yw] + 
     2*G[{1}, yw]^2*G[{1, yv^(-1), yv^(-1)}, yw] + 
     6*G[{0}, yu^(-1)]*G[{yu^(-1)}, yw]*G[{1, yv^(-1), yv^(-1)}, yw] + 
     6*G[{0}, yv^(-1)]*G[{yu^(-1)}, yw]*G[{1, yv^(-1), yv^(-1)}, yw] - 
     6*G[{0}, yw]*G[{yu^(-1)}, yw]*G[{1, yv^(-1), yv^(-1)}, yw] - 
     2*G[{1}, yu^(-1)]*G[{yu^(-1)}, yw]*G[{1, yv^(-1), yv^(-1)}, yw] - 
     6*G[{1}, yv^(-1)]*G[{yu^(-1)}, yw]*G[{1, yv^(-1), yv^(-1)}, yw] + 
     4*G[{1}, yw]*G[{yu^(-1)}, yw]*G[{1, yv^(-1), yv^(-1)}, yw] + 
     5*G[{yu^(-1)}, yw]^2*G[{1, yv^(-1), yv^(-1)}, yw] + 
     4*G[{1}, yu^(-1)]*G[{yu}, yv^(-1)]*G[{1, yv^(-1), yv^(-1)}, yw] + 
     4*G[{1}, yv^(-1)]*G[{yu}, yv^(-1)]*G[{1, yv^(-1), yv^(-1)}, yw] - 
     4*G[{1}, yw]*G[{yu}, yv^(-1)]*G[{1, yv^(-1), yv^(-1)}, yw] - 
     4*G[{yu^(-1)}, yw]*G[{yu}, yv^(-1)]*G[{1, yv^(-1), yv^(-1)}, yw] - 
     4*G[{yu}, yv^(-1)]^2*G[{1, yv^(-1), yv^(-1)}, yw] + 
     6*G[{0}, yu^(-1)]*G[{yv^(-1)}, yw]*G[{1, yv^(-1), yv^(-1)}, yw] + 
     6*G[{0}, yv^(-1)]*G[{yv^(-1)}, yw]*G[{1, yv^(-1), yv^(-1)}, yw] - 
     6*G[{0}, yw]*G[{yv^(-1)}, yw]*G[{1, yv^(-1), yv^(-1)}, yw] - 
     10*G[{1}, yu^(-1)]*G[{yv^(-1)}, yw]*G[{1, yv^(-1), yv^(-1)}, yw] - 
     6*G[{1}, yv^(-1)]*G[{yv^(-1)}, yw]*G[{1, yv^(-1), yv^(-1)}, yw] - 
     4*G[{1}, yw]*G[{yv^(-1)}, yw]*G[{1, yv^(-1), yv^(-1)}, yw] + 
     2*G[{yu^(-1)}, yw]*G[{yv^(-1)}, yw]*G[{1, yv^(-1), yv^(-1)}, yw] + 
     4*G[{yu}, yv^(-1)]*G[{yv^(-1)}, yw]*G[{1, yv^(-1), yv^(-1)}, yw] - 
     3*G[{yv^(-1)}, yw]^2*G[{1, yv^(-1), yv^(-1)}, yw] - 
     6*G[{0}, yu^(-1)]*G[{1/(yu*yv)}, yw]*G[{1, yv^(-1), yv^(-1)}, yw] - 
     6*G[{0}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{1, yv^(-1), yv^(-1)}, yw] + 
     6*G[{0}, yw]*G[{1/(yu*yv)}, yw]*G[{1, yv^(-1), yv^(-1)}, yw] + 
     2*G[{1}, yu^(-1)]*G[{1/(yu*yv)}, yw]*G[{1, yv^(-1), yv^(-1)}, yw] + 
     6*G[{1}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{1, yv^(-1), yv^(-1)}, yw] - 
     4*G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{1, yv^(-1), yv^(-1)}, yw] - 
     10*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{1, yv^(-1), yv^(-1)}, yw] + 
     4*G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{1, yv^(-1), yv^(-1)}, yw] - 
     2*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{1, yv^(-1), yv^(-1)}, yw] + 
     4*G[{1/(yu*yv)}, yw]^2*G[{1, yv^(-1), yv^(-1)}, yw] - 
     8*G[{0, 1}, yu^(-1)]*G[{1, yv^(-1), yv^(-1)}, yw] - 
     4*G[{0, 1}, yv^(-1)]*G[{1, yv^(-1), yv^(-1)}, yw] - 
     6*G[{0, 1}, yw]*G[{1, yv^(-1), yv^(-1)}, yw] + 
     6*G[{0, yu^(-1)}, yw]*G[{1, yv^(-1), yv^(-1)}, yw] + 
     4*G[{0, yu}, yv^(-1)]*G[{1, yv^(-1), yv^(-1)}, yw] + 
     6*G[{0, yv^(-1)}, yw]*G[{1, yv^(-1), yv^(-1)}, yw] - 
     6*G[{0, 1/(yu*yv)}, yw]*G[{1, yv^(-1), yv^(-1)}, yw] - 
     10*G[{1, yu^(-1)}, yw]*G[{1, yv^(-1), yv^(-1)}, yw] + 
     4*G[{1, yu}, yv^(-1)]*G[{1, yv^(-1), yv^(-1)}, yw] - 
     14*G[{1, yv^(-1)}, yw]*G[{1, yv^(-1), yv^(-1)}, yw] + 
     2*G[{yu^(-1), 1/(yu*yv)}, yw]*G[{1, yv^(-1), yv^(-1)}, yw] + 
     2*G[{yv^(-1), 1/(yu*yv)}, yw]*G[{1, yv^(-1), yv^(-1)}, yw] + 
     (2*Pi^2*G[{1, yv^(-1), 1/(yu*yv)}, yw])/3 - 2*G[{1}, yu^(-1)]^2*
      G[{1, yv^(-1), 1/(yu*yv)}, yw] + 4*G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*
      G[{1, yv^(-1), 1/(yu*yv)}, yw] - 2*G[{1}, yu^(-1)]*G[{1}, yw]*
      G[{1, yv^(-1), 1/(yu*yv)}, yw] + 2*G[{1}, yv^(-1)]*G[{1}, yw]*
      G[{1, yv^(-1), 1/(yu*yv)}, yw] - 6*G[{1}, yu^(-1)]*G[{yu^(-1)}, yw]*
      G[{1, yv^(-1), 1/(yu*yv)}, yw] + 6*G[{1}, yv^(-1)]*G[{yu^(-1)}, yw]*
      G[{1, yv^(-1), 1/(yu*yv)}, yw] - 3*G[{yu^(-1)}, yw]^2*
      G[{1, yv^(-1), 1/(yu*yv)}, yw] + 2*G[{1}, yu^(-1)]*G[{yv^(-1)}, yw]*
      G[{1, yv^(-1), 1/(yu*yv)}, yw] + 2*G[{1}, yv^(-1)]*G[{yv^(-1)}, yw]*
      G[{1, yv^(-1), 1/(yu*yv)}, yw] + 4*G[{1}, yw]*G[{yv^(-1)}, yw]*
      G[{1, yv^(-1), 1/(yu*yv)}, yw] + 2*G[{yu^(-1)}, yw]*G[{yv^(-1)}, yw]*
      G[{1, yv^(-1), 1/(yu*yv)}, yw] - 4*G[{yu}, yv^(-1)]*G[{yv^(-1)}, yw]*
      G[{1, yv^(-1), 1/(yu*yv)}, yw] + G[{yv^(-1)}, yw]^2*
      G[{1, yv^(-1), 1/(yu*yv)}, yw] + 6*G[{1}, yu^(-1)]*G[{1/(yu*yv)}, yw]*
      G[{1, yv^(-1), 1/(yu*yv)}, yw] - 6*G[{1}, yv^(-1)]*G[{1/(yu*yv)}, yw]*
      G[{1, yv^(-1), 1/(yu*yv)}, yw] + 6*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*
      G[{1, yv^(-1), 1/(yu*yv)}, yw] - 2*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*
      G[{1, yv^(-1), 1/(yu*yv)}, yw] + 2*G[{0, 1}, yu^(-1)]*
      G[{1, yv^(-1), 1/(yu*yv)}, yw] - 2*G[{0, 1}, yv^(-1)]*
      G[{1, yv^(-1), 1/(yu*yv)}, yw] + 2*G[{0, yu}, yv^(-1)]*
      G[{1, yv^(-1), 1/(yu*yv)}, yw] - 2*G[{1, yu^(-1)}, yw]*
      G[{1, yv^(-1), 1/(yu*yv)}, yw] - 4*G[{1, yu}, yv^(-1)]*
      G[{1, yv^(-1), 1/(yu*yv)}, yw] + 2*G[{1, yv^(-1)}, yw]*
      G[{1, yv^(-1), 1/(yu*yv)}, yw] - 6*G[{yu^(-1), 1/(yu*yv)}, yw]*
      G[{1, yv^(-1), 1/(yu*yv)}, yw] + 2*G[{yv^(-1), 1/(yu*yv)}, yw]*
      G[{1, yv^(-1), 1/(yu*yv)}, yw] - Pi^2*G[{1, 1/(yu*yv), yu^(-1)}, yw] - 
     4*G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*G[{1, 1/(yu*yv), yu^(-1)}, yw] - 
     2*G[{0}, yu^(-1)]*G[{1}, yw]*G[{1, 1/(yu*yv), yu^(-1)}, yw] - 
     2*G[{0}, yv^(-1)]*G[{1}, yw]*G[{1, 1/(yu*yv), yu^(-1)}, yw] + 
     2*G[{0}, yw]*G[{1}, yw]*G[{1, 1/(yu*yv), yu^(-1)}, yw] - 
     2*G[{1}, yw]^2*G[{1, 1/(yu*yv), yu^(-1)}, yw] + 
     2*G[{0}, yu^(-1)]*G[{yu^(-1)}, yw]*G[{1, 1/(yu*yv), yu^(-1)}, yw] + 
     2*G[{0}, yv^(-1)]*G[{yu^(-1)}, yw]*G[{1, 1/(yu*yv), yu^(-1)}, yw] - 
     2*G[{0}, yw]*G[{yu^(-1)}, yw]*G[{1, 1/(yu*yv), yu^(-1)}, yw] - 
     4*G[{1}, yu^(-1)]*G[{yu^(-1)}, yw]*G[{1, 1/(yu*yv), yu^(-1)}, yw] - 
     4*G[{1}, yv^(-1)]*G[{yu^(-1)}, yw]*G[{1, 1/(yu*yv), yu^(-1)}, yw] - 
     4*G[{1}, yw]*G[{yu^(-1)}, yw]*G[{1, 1/(yu*yv), yu^(-1)}, yw] + 
     4*G[{1}, yu^(-1)]*G[{yu}, yv^(-1)]*G[{1, 1/(yu*yv), yu^(-1)}, yw] + 
     4*G[{1}, yv^(-1)]*G[{yu}, yv^(-1)]*G[{1, 1/(yu*yv), yu^(-1)}, yw] + 
     4*G[{1}, yw]*G[{yu}, yv^(-1)]*G[{1, 1/(yu*yv), yu^(-1)}, yw] + 
     4*G[{yu^(-1)}, yw]*G[{yu}, yv^(-1)]*G[{1, 1/(yu*yv), yu^(-1)}, yw] - 
     4*G[{yu}, yv^(-1)]^2*G[{1, 1/(yu*yv), yu^(-1)}, yw] + 
     2*G[{0}, yu^(-1)]*G[{yv^(-1)}, yw]*G[{1, 1/(yu*yv), yu^(-1)}, yw] + 
     2*G[{0}, yv^(-1)]*G[{yv^(-1)}, yw]*G[{1, 1/(yu*yv), yu^(-1)}, yw] - 
     2*G[{0}, yw]*G[{yv^(-1)}, yw]*G[{1, 1/(yu*yv), yu^(-1)}, yw] + 
     4*G[{1}, yw]*G[{yv^(-1)}, yw]*G[{1, 1/(yu*yv), yu^(-1)}, yw] + 
     4*G[{yu^(-1)}, yw]*G[{yv^(-1)}, yw]*G[{1, 1/(yu*yv), yu^(-1)}, yw] - 
     4*G[{yu}, yv^(-1)]*G[{yv^(-1)}, yw]*G[{1, 1/(yu*yv), yu^(-1)}, yw] - 
     2*G[{0}, yu^(-1)]*G[{1/(yu*yv)}, yw]*G[{1, 1/(yu*yv), yu^(-1)}, yw] - 
     2*G[{0}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{1, 1/(yu*yv), yu^(-1)}, yw] + 
     2*G[{0}, yw]*G[{1/(yu*yv)}, yw]*G[{1, 1/(yu*yv), yu^(-1)}, yw] + 
     4*G[{1}, yu^(-1)]*G[{1/(yu*yv)}, yw]*G[{1, 1/(yu*yv), yu^(-1)}, yw] + 
     4*G[{1}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{1, 1/(yu*yv), yu^(-1)}, yw] + 
     4*G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{1, 1/(yu*yv), yu^(-1)}, yw] - 
     4*G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{1, 1/(yu*yv), yu^(-1)}, yw] - 
     4*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{1, 1/(yu*yv), yu^(-1)}, yw] - 
     2*G[{0, 1}, yu^(-1)]*G[{1, 1/(yu*yv), yu^(-1)}, yw] - 
     2*G[{0, 1}, yv^(-1)]*G[{1, 1/(yu*yv), yu^(-1)}, yw] - 
     2*G[{0, 1}, yw]*G[{1, 1/(yu*yv), yu^(-1)}, yw] + 
     2*G[{0, yu^(-1)}, yw]*G[{1, 1/(yu*yv), yu^(-1)}, yw] + 
     2*G[{0, yu}, yv^(-1)]*G[{1, 1/(yu*yv), yu^(-1)}, yw] + 
     2*G[{0, yv^(-1)}, yw]*G[{1, 1/(yu*yv), yu^(-1)}, yw] - 
     2*G[{0, 1/(yu*yv)}, yw]*G[{1, 1/(yu*yv), yu^(-1)}, yw] - 
     4*G[{1, yu^(-1)}, yw]*G[{1, 1/(yu*yv), yu^(-1)}, yw] - 
     4*G[{1, yv^(-1)}, yw]*G[{1, 1/(yu*yv), yu^(-1)}, yw] + 
     4*G[{1, 1/(yu*yv)}, yw]*G[{1, 1/(yu*yv), yu^(-1)}, yw] + 
     Pi^2*G[{1, 1/(yu*yv), yv^(-1)}, yw] + 4*G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*
      G[{1, 1/(yu*yv), yv^(-1)}, yw] + 2*G[{0}, yu^(-1)]*G[{1}, yw]*
      G[{1, 1/(yu*yv), yv^(-1)}, yw] + 2*G[{0}, yv^(-1)]*G[{1}, yw]*
      G[{1, 1/(yu*yv), yv^(-1)}, yw] - 2*G[{0}, yw]*G[{1}, yw]*
      G[{1, 1/(yu*yv), yv^(-1)}, yw] + 2*G[{1}, yw]^2*
      G[{1, 1/(yu*yv), yv^(-1)}, yw] - 2*G[{0}, yu^(-1)]*G[{yu^(-1)}, yw]*
      G[{1, 1/(yu*yv), yv^(-1)}, yw] - 2*G[{0}, yv^(-1)]*G[{yu^(-1)}, yw]*
      G[{1, 1/(yu*yv), yv^(-1)}, yw] + 2*G[{0}, yw]*G[{yu^(-1)}, yw]*
      G[{1, 1/(yu*yv), yv^(-1)}, yw] - 4*G[{1}, yw]*G[{yu^(-1)}, yw]*
      G[{1, 1/(yu*yv), yv^(-1)}, yw] - 4*G[{1}, yu^(-1)]*G[{yu}, yv^(-1)]*
      G[{1, 1/(yu*yv), yv^(-1)}, yw] - 4*G[{1}, yv^(-1)]*G[{yu}, yv^(-1)]*
      G[{1, 1/(yu*yv), yv^(-1)}, yw] - 4*G[{1}, yw]*G[{yu}, yv^(-1)]*
      G[{1, 1/(yu*yv), yv^(-1)}, yw] + 4*G[{yu^(-1)}, yw]*G[{yu}, yv^(-1)]*
      G[{1, 1/(yu*yv), yv^(-1)}, yw] + 4*G[{yu}, yv^(-1)]^2*
      G[{1, 1/(yu*yv), yv^(-1)}, yw] - 2*G[{0}, yu^(-1)]*G[{yv^(-1)}, yw]*
      G[{1, 1/(yu*yv), yv^(-1)}, yw] - 2*G[{0}, yv^(-1)]*G[{yv^(-1)}, yw]*
      G[{1, 1/(yu*yv), yv^(-1)}, yw] + 2*G[{0}, yw]*G[{yv^(-1)}, yw]*
      G[{1, 1/(yu*yv), yv^(-1)}, yw] + 4*G[{1}, yu^(-1)]*G[{yv^(-1)}, yw]*
      G[{1, 1/(yu*yv), yv^(-1)}, yw] + 4*G[{1}, yv^(-1)]*G[{yv^(-1)}, yw]*
      G[{1, 1/(yu*yv), yv^(-1)}, yw] + 4*G[{1}, yw]*G[{yv^(-1)}, yw]*
      G[{1, 1/(yu*yv), yv^(-1)}, yw] - 4*G[{yu^(-1)}, yw]*G[{yv^(-1)}, yw]*
      G[{1, 1/(yu*yv), yv^(-1)}, yw] - 4*G[{yu}, yv^(-1)]*G[{yv^(-1)}, yw]*
      G[{1, 1/(yu*yv), yv^(-1)}, yw] + 2*G[{0}, yu^(-1)]*G[{1/(yu*yv)}, yw]*
      G[{1, 1/(yu*yv), yv^(-1)}, yw] + 2*G[{0}, yv^(-1)]*G[{1/(yu*yv)}, yw]*
      G[{1, 1/(yu*yv), yv^(-1)}, yw] - 2*G[{0}, yw]*G[{1/(yu*yv)}, yw]*
      G[{1, 1/(yu*yv), yv^(-1)}, yw] + 4*G[{1}, yw]*G[{1/(yu*yv)}, yw]*
      G[{1, 1/(yu*yv), yv^(-1)}, yw] - 4*G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw]*
      G[{1, 1/(yu*yv), yv^(-1)}, yw] + 4*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*
      G[{1, 1/(yu*yv), yv^(-1)}, yw] - 2*G[{1/(yu*yv)}, yw]^2*
      G[{1, 1/(yu*yv), yv^(-1)}, yw] + 2*G[{0, 1}, yu^(-1)]*
      G[{1, 1/(yu*yv), yv^(-1)}, yw] + 2*G[{0, 1}, yv^(-1)]*
      G[{1, 1/(yu*yv), yv^(-1)}, yw] + 2*G[{0, 1}, yw]*
      G[{1, 1/(yu*yv), yv^(-1)}, yw] - 2*G[{0, yu^(-1)}, yw]*
      G[{1, 1/(yu*yv), yv^(-1)}, yw] - 2*G[{0, yu}, yv^(-1)]*
      G[{1, 1/(yu*yv), yv^(-1)}, yw] - 2*G[{0, yv^(-1)}, yw]*
      G[{1, 1/(yu*yv), yv^(-1)}, yw] + 2*G[{0, 1/(yu*yv)}, yw]*
      G[{1, 1/(yu*yv), yv^(-1)}, yw] + 4*G[{1, yu^(-1)}, yw]*
      G[{1, 1/(yu*yv), yv^(-1)}, yw] + 4*G[{1, yv^(-1)}, yw]*
      G[{1, 1/(yu*yv), yv^(-1)}, yw] - 4*G[{1, 1/(yu*yv)}, yw]*
      G[{1, 1/(yu*yv), yv^(-1)}, yw] + 4*G[{yu^(-1), 1/(yu*yv)}, yw]*
      G[{1, 1/(yu*yv), yv^(-1)}, yw] - 4*G[{yv^(-1), 1/(yu*yv)}, yw]*
      G[{1, 1/(yu*yv), yv^(-1)}, yw] + Pi^2*G[{1, 1/(yu*yv), 1/(yu*yv)}, 
       yw] + 4*G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*G[{1, 1/(yu*yv), 1/(yu*yv)}, 
       yw] + 2*G[{0}, yu^(-1)]*G[{1}, yw]*G[{1, 1/(yu*yv), 1/(yu*yv)}, yw] + 
     2*G[{0}, yv^(-1)]*G[{1}, yw]*G[{1, 1/(yu*yv), 1/(yu*yv)}, yw] - 
     2*G[{0}, yw]*G[{1}, yw]*G[{1, 1/(yu*yv), 1/(yu*yv)}, yw] + 
     2*G[{1}, yw]^2*G[{1, 1/(yu*yv), 1/(yu*yv)}, yw] - 
     2*G[{0}, yu^(-1)]*G[{yu^(-1)}, yw]*G[{1, 1/(yu*yv), 1/(yu*yv)}, yw] - 
     2*G[{0}, yv^(-1)]*G[{yu^(-1)}, yw]*G[{1, 1/(yu*yv), 1/(yu*yv)}, yw] + 
     2*G[{0}, yw]*G[{yu^(-1)}, yw]*G[{1, 1/(yu*yv), 1/(yu*yv)}, yw] + 
     4*G[{1}, yu^(-1)]*G[{yu^(-1)}, yw]*G[{1, 1/(yu*yv), 1/(yu*yv)}, yw] + 
     4*G[{1}, yv^(-1)]*G[{yu^(-1)}, yw]*G[{1, 1/(yu*yv), 1/(yu*yv)}, yw] + 
     4*G[{1}, yw]*G[{yu^(-1)}, yw]*G[{1, 1/(yu*yv), 1/(yu*yv)}, yw] - 
     4*G[{1}, yu^(-1)]*G[{yu}, yv^(-1)]*G[{1, 1/(yu*yv), 1/(yu*yv)}, yw] - 
     4*G[{1}, yv^(-1)]*G[{yu}, yv^(-1)]*G[{1, 1/(yu*yv), 1/(yu*yv)}, yw] - 
     4*G[{1}, yw]*G[{yu}, yv^(-1)]*G[{1, 1/(yu*yv), 1/(yu*yv)}, yw] - 
     4*G[{yu^(-1)}, yw]*G[{yu}, yv^(-1)]*G[{1, 1/(yu*yv), 1/(yu*yv)}, yw] + 
     4*G[{yu}, yv^(-1)]^2*G[{1, 1/(yu*yv), 1/(yu*yv)}, yw] - 
     2*G[{0}, yu^(-1)]*G[{yv^(-1)}, yw]*G[{1, 1/(yu*yv), 1/(yu*yv)}, yw] - 
     2*G[{0}, yv^(-1)]*G[{yv^(-1)}, yw]*G[{1, 1/(yu*yv), 1/(yu*yv)}, yw] + 
     2*G[{0}, yw]*G[{yv^(-1)}, yw]*G[{1, 1/(yu*yv), 1/(yu*yv)}, yw] - 
     4*G[{1}, yw]*G[{yv^(-1)}, yw]*G[{1, 1/(yu*yv), 1/(yu*yv)}, yw] + 
     4*G[{yu}, yv^(-1)]*G[{yv^(-1)}, yw]*G[{1, 1/(yu*yv), 1/(yu*yv)}, yw] + 
     2*G[{0}, yu^(-1)]*G[{1/(yu*yv)}, yw]*G[{1, 1/(yu*yv), 1/(yu*yv)}, yw] + 
     2*G[{0}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{1, 1/(yu*yv), 1/(yu*yv)}, yw] - 
     2*G[{0}, yw]*G[{1/(yu*yv)}, yw]*G[{1, 1/(yu*yv), 1/(yu*yv)}, yw] - 
     4*G[{1}, yu^(-1)]*G[{1/(yu*yv)}, yw]*G[{1, 1/(yu*yv), 1/(yu*yv)}, yw] - 
     4*G[{1}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{1, 1/(yu*yv), 1/(yu*yv)}, yw] - 
     4*G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{1, 1/(yu*yv), 1/(yu*yv)}, yw] + 
     4*G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{1, 1/(yu*yv), 1/(yu*yv)}, yw] + 
     2*G[{0, 1}, yu^(-1)]*G[{1, 1/(yu*yv), 1/(yu*yv)}, yw] + 
     2*G[{0, 1}, yv^(-1)]*G[{1, 1/(yu*yv), 1/(yu*yv)}, yw] + 
     2*G[{0, 1}, yw]*G[{1, 1/(yu*yv), 1/(yu*yv)}, yw] - 
     2*G[{0, yu^(-1)}, yw]*G[{1, 1/(yu*yv), 1/(yu*yv)}, yw] - 
     2*G[{0, yu}, yv^(-1)]*G[{1, 1/(yu*yv), 1/(yu*yv)}, yw] - 
     2*G[{0, yv^(-1)}, yw]*G[{1, 1/(yu*yv), 1/(yu*yv)}, yw] + 
     2*G[{0, 1/(yu*yv)}, yw]*G[{1, 1/(yu*yv), 1/(yu*yv)}, yw] + 
     4*G[{1, yu^(-1)}, yw]*G[{1, 1/(yu*yv), 1/(yu*yv)}, yw] + 
     4*G[{1, yv^(-1)}, yw]*G[{1, 1/(yu*yv), 1/(yu*yv)}, yw] - 
     4*G[{1, 1/(yu*yv)}, yw]*G[{1, 1/(yu*yv), 1/(yu*yv)}, yw] + 
     (Pi^2*G[{yu^(-1), yu^(-1), 1/(yu*yv)}, yw])/3 + 
     2*G[{1}, yu^(-1)]^2*G[{yu^(-1), yu^(-1), 1/(yu*yv)}, yw] - 
     8*G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*G[{yu^(-1), yu^(-1), 1/(yu*yv)}, yw] + 
     2*G[{0}, yu^(-1)]*G[{1}, yw]*G[{yu^(-1), yu^(-1), 1/(yu*yv)}, yw] + 
     2*G[{0}, yv^(-1)]*G[{1}, yw]*G[{yu^(-1), yu^(-1), 1/(yu*yv)}, yw] - 
     2*G[{0}, yw]*G[{1}, yw]*G[{yu^(-1), yu^(-1), 1/(yu*yv)}, yw] - 
     6*G[{1}, yu^(-1)]*G[{1}, yw]*G[{yu^(-1), yu^(-1), 1/(yu*yv)}, yw] - 
     10*G[{1}, yv^(-1)]*G[{1}, yw]*G[{yu^(-1), yu^(-1), 1/(yu*yv)}, yw] - 
     6*G[{1}, yw]^2*G[{yu^(-1), yu^(-1), 1/(yu*yv)}, yw] - 
     2*G[{0}, yu^(-1)]*G[{yu^(-1)}, yw]*G[{yu^(-1), yu^(-1), 1/(yu*yv)}, 
       yw] - 2*G[{0}, yv^(-1)]*G[{yu^(-1)}, yw]*
      G[{yu^(-1), yu^(-1), 1/(yu*yv)}, yw] + 2*G[{0}, yw]*G[{yu^(-1)}, yw]*
      G[{yu^(-1), yu^(-1), 1/(yu*yv)}, yw] + 10*G[{1}, yu^(-1)]*
      G[{yu^(-1)}, yw]*G[{yu^(-1), yu^(-1), 1/(yu*yv)}, yw] - 
     2*G[{1}, yv^(-1)]*G[{yu^(-1)}, yw]*G[{yu^(-1), yu^(-1), 1/(yu*yv)}, 
       yw] + 4*G[{1}, yw]*G[{yu^(-1)}, yw]*G[{yu^(-1), yu^(-1), 1/(yu*yv)}, 
       yw] + G[{yu^(-1)}, yw]^2*G[{yu^(-1), yu^(-1), 1/(yu*yv)}, yw] + 
     4*G[{1}, yu^(-1)]*G[{yu}, yv^(-1)]*G[{yu^(-1), yu^(-1), 1/(yu*yv)}, 
       yw] + 4*G[{1}, yv^(-1)]*G[{yu}, yv^(-1)]*
      G[{yu^(-1), yu^(-1), 1/(yu*yv)}, yw] + 12*G[{1}, yw]*G[{yu}, yv^(-1)]*
      G[{yu^(-1), yu^(-1), 1/(yu*yv)}, yw] - 4*G[{yu^(-1)}, yw]*
      G[{yu}, yv^(-1)]*G[{yu^(-1), yu^(-1), 1/(yu*yv)}, yw] - 
     4*G[{yu}, yv^(-1)]^2*G[{yu^(-1), yu^(-1), 1/(yu*yv)}, yw] - 
     2*G[{0}, yu^(-1)]*G[{yv^(-1)}, yw]*G[{yu^(-1), yu^(-1), 1/(yu*yv)}, 
       yw] - 2*G[{0}, yv^(-1)]*G[{yv^(-1)}, yw]*
      G[{yu^(-1), yu^(-1), 1/(yu*yv)}, yw] + 2*G[{0}, yw]*G[{yv^(-1)}, yw]*
      G[{yu^(-1), yu^(-1), 1/(yu*yv)}, yw] + 2*G[{1}, yu^(-1)]*
      G[{yv^(-1)}, yw]*G[{yu^(-1), yu^(-1), 1/(yu*yv)}, yw] + 
     6*G[{1}, yv^(-1)]*G[{yv^(-1)}, yw]*G[{yu^(-1), yu^(-1), 1/(yu*yv)}, 
       yw] + 4*G[{1}, yw]*G[{yv^(-1)}, yw]*G[{yu^(-1), yu^(-1), 1/(yu*yv)}, 
       yw] - 6*G[{yu^(-1)}, yw]*G[{yv^(-1)}, yw]*
      G[{yu^(-1), yu^(-1), 1/(yu*yv)}, yw] - 4*G[{yu}, yv^(-1)]*
      G[{yv^(-1)}, yw]*G[{yu^(-1), yu^(-1), 1/(yu*yv)}, yw] - 
     3*G[{yv^(-1)}, yw]^2*G[{yu^(-1), yu^(-1), 1/(yu*yv)}, yw] + 
     2*G[{0}, yu^(-1)]*G[{1/(yu*yv)}, yw]*G[{yu^(-1), yu^(-1), 1/(yu*yv)}, 
       yw] + 2*G[{0}, yv^(-1)]*G[{1/(yu*yv)}, yw]*
      G[{yu^(-1), yu^(-1), 1/(yu*yv)}, yw] - 2*G[{0}, yw]*G[{1/(yu*yv)}, yw]*
      G[{yu^(-1), yu^(-1), 1/(yu*yv)}, yw] - 2*G[{1}, yu^(-1)]*
      G[{1/(yu*yv)}, yw]*G[{yu^(-1), yu^(-1), 1/(yu*yv)}, yw] + 
     2*G[{1}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{yu^(-1), yu^(-1), 1/(yu*yv)}, 
       yw] + 4*G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{yu^(-1), yu^(-1), 1/(yu*yv)}, 
       yw] - 2*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*
      G[{yu^(-1), yu^(-1), 1/(yu*yv)}, yw] - 4*G[{yu}, yv^(-1)]*
      G[{1/(yu*yv)}, yw]*G[{yu^(-1), yu^(-1), 1/(yu*yv)}, yw] - 
     2*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{yu^(-1), yu^(-1), 1/(yu*yv)}, 
       yw] + 2*G[{1/(yu*yv)}, yw]^2*G[{yu^(-1), yu^(-1), 1/(yu*yv)}, yw] + 
     4*G[{0, 1}, yv^(-1)]*G[{yu^(-1), yu^(-1), 1/(yu*yv)}, yw] + 
     2*G[{0, 1}, yw]*G[{yu^(-1), yu^(-1), 1/(yu*yv)}, yw] - 
     2*G[{0, yu^(-1)}, yw]*G[{yu^(-1), yu^(-1), 1/(yu*yv)}, yw] - 
     4*G[{0, yu}, yv^(-1)]*G[{yu^(-1), yu^(-1), 1/(yu*yv)}, yw] - 
     2*G[{0, yv^(-1)}, yw]*G[{yu^(-1), yu^(-1), 1/(yu*yv)}, yw] + 
     2*G[{0, 1/(yu*yv)}, yw]*G[{yu^(-1), yu^(-1), 1/(yu*yv)}, yw] + 
     6*G[{1, yu^(-1)}, yw]*G[{yu^(-1), yu^(-1), 1/(yu*yv)}, yw] + 
     4*G[{1, yu}, yv^(-1)]*G[{yu^(-1), yu^(-1), 1/(yu*yv)}, yw] + 
     2*G[{1, yv^(-1)}, yw]*G[{yu^(-1), yu^(-1), 1/(yu*yv)}, yw] - 
     4*G[{1, 1/(yu*yv)}, yw]*G[{yu^(-1), yu^(-1), 1/(yu*yv)}, yw] + 
     6*G[{yu^(-1), 1/(yu*yv)}, yw]*G[{yu^(-1), yu^(-1), 1/(yu*yv)}, yw] - 
     2*G[{yv^(-1), 1/(yu*yv)}, yw]*G[{yu^(-1), yu^(-1), 1/(yu*yv)}, yw] + 
     (2*Pi^2*G[{yu^(-1), 1/(yu*yv), yv^(-1)}, yw])/3 - 
     2*G[{1}, yu^(-1)]^2*G[{yu^(-1), 1/(yu*yv), yv^(-1)}, yw] + 
     4*G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*G[{yu^(-1), 1/(yu*yv), yv^(-1)}, yw] - 
     2*G[{1}, yu^(-1)]*G[{1}, yw]*G[{yu^(-1), 1/(yu*yv), yv^(-1)}, yw] + 
     2*G[{1}, yv^(-1)]*G[{1}, yw]*G[{yu^(-1), 1/(yu*yv), yv^(-1)}, yw] - 
     2*G[{1}, yu^(-1)]*G[{yu^(-1)}, yw]*G[{yu^(-1), 1/(yu*yv), yv^(-1)}, 
       yw] + 2*G[{1}, yv^(-1)]*G[{yu^(-1)}, yw]*
      G[{yu^(-1), 1/(yu*yv), yv^(-1)}, yw] - G[{yu^(-1)}, yw]^2*
      G[{yu^(-1), 1/(yu*yv), yv^(-1)}, yw] - 2*G[{1}, yu^(-1)]*
      G[{yv^(-1)}, yw]*G[{yu^(-1), 1/(yu*yv), yv^(-1)}, yw] + 
     2*G[{1}, yv^(-1)]*G[{yv^(-1)}, yw]*G[{yu^(-1), 1/(yu*yv), yv^(-1)}, 
       yw] - 2*G[{yu^(-1)}, yw]*G[{yv^(-1)}, yw]*
      G[{yu^(-1), 1/(yu*yv), yv^(-1)}, yw] + 3*G[{yv^(-1)}, yw]^2*
      G[{yu^(-1), 1/(yu*yv), yv^(-1)}, yw] + 6*G[{1}, yu^(-1)]*
      G[{1/(yu*yv)}, yw]*G[{yu^(-1), 1/(yu*yv), yv^(-1)}, yw] - 
     6*G[{1}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{yu^(-1), 1/(yu*yv), yv^(-1)}, 
       yw] + 6*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*
      G[{yu^(-1), 1/(yu*yv), yv^(-1)}, yw] - 2*G[{yv^(-1)}, yw]*
      G[{1/(yu*yv)}, yw]*G[{yu^(-1), 1/(yu*yv), yv^(-1)}, yw] - 
     2*G[{1/(yu*yv)}, yw]^2*G[{yu^(-1), 1/(yu*yv), yv^(-1)}, yw] + 
     2*G[{0, 1}, yu^(-1)]*G[{yu^(-1), 1/(yu*yv), yv^(-1)}, yw] - 
     2*G[{0, 1}, yv^(-1)]*G[{yu^(-1), 1/(yu*yv), yv^(-1)}, yw] + 
     2*G[{0, yu}, yv^(-1)]*G[{yu^(-1), 1/(yu*yv), yv^(-1)}, yw] - 
     2*G[{1, yu^(-1)}, yw]*G[{yu^(-1), 1/(yu*yv), yv^(-1)}, yw] - 
     4*G[{1, yu}, yv^(-1)]*G[{yu^(-1), 1/(yu*yv), yv^(-1)}, yw] + 
     2*G[{1, yv^(-1)}, yw]*G[{yu^(-1), 1/(yu*yv), yv^(-1)}, yw] - 
     2*G[{yu^(-1), 1/(yu*yv)}, yw]*G[{yu^(-1), 1/(yu*yv), yv^(-1)}, yw] + 
     2*G[{yv^(-1), 1/(yu*yv)}, yw]*G[{yu^(-1), 1/(yu*yv), yv^(-1)}, yw] + 
     (Pi^2*G[{yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/3 + 
     2*G[{1}, yu^(-1)]^2*G[{yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] - 
     8*G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*G[{yu^(-1), 1/(yu*yv), 1/(yu*yv)}, 
       yw] + 2*G[{0}, yu^(-1)]*G[{1}, yw]*G[{yu^(-1), 1/(yu*yv), 1/(yu*yv)}, 
       yw] + 2*G[{0}, yv^(-1)]*G[{1}, yw]*G[{yu^(-1), 1/(yu*yv), 1/(yu*yv)}, 
       yw] - 2*G[{0}, yw]*G[{1}, yw]*G[{yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] - 
     6*G[{1}, yu^(-1)]*G[{1}, yw]*G[{yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] - 
     10*G[{1}, yv^(-1)]*G[{1}, yw]*G[{yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] - 
     6*G[{1}, yw]^2*G[{yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] - 
     2*G[{0}, yu^(-1)]*G[{yu^(-1)}, yw]*G[{yu^(-1), 1/(yu*yv), 1/(yu*yv)}, 
       yw] - 2*G[{0}, yv^(-1)]*G[{yu^(-1)}, yw]*
      G[{yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] + 2*G[{0}, yw]*G[{yu^(-1)}, yw]*
      G[{yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] + 10*G[{1}, yu^(-1)]*
      G[{yu^(-1)}, yw]*G[{yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] - 
     2*G[{1}, yv^(-1)]*G[{yu^(-1)}, yw]*G[{yu^(-1), 1/(yu*yv), 1/(yu*yv)}, 
       yw] + 4*G[{1}, yw]*G[{yu^(-1)}, yw]*G[{yu^(-1), 1/(yu*yv), 1/(yu*yv)}, 
       yw] + G[{yu^(-1)}, yw]^2*G[{yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] + 
     4*G[{1}, yu^(-1)]*G[{yu}, yv^(-1)]*G[{yu^(-1), 1/(yu*yv), 1/(yu*yv)}, 
       yw] + 4*G[{1}, yv^(-1)]*G[{yu}, yv^(-1)]*
      G[{yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] + 12*G[{1}, yw]*G[{yu}, yv^(-1)]*
      G[{yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] - 4*G[{yu^(-1)}, yw]*
      G[{yu}, yv^(-1)]*G[{yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] - 
     4*G[{yu}, yv^(-1)]^2*G[{yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] - 
     2*G[{0}, yu^(-1)]*G[{yv^(-1)}, yw]*G[{yu^(-1), 1/(yu*yv), 1/(yu*yv)}, 
       yw] - 2*G[{0}, yv^(-1)]*G[{yv^(-1)}, yw]*
      G[{yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] + 2*G[{0}, yw]*G[{yv^(-1)}, yw]*
      G[{yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] + 6*G[{1}, yu^(-1)]*
      G[{yv^(-1)}, yw]*G[{yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] + 
     6*G[{1}, yv^(-1)]*G[{yv^(-1)}, yw]*G[{yu^(-1), 1/(yu*yv), 1/(yu*yv)}, 
       yw] + 8*G[{1}, yw]*G[{yv^(-1)}, yw]*G[{yu^(-1), 1/(yu*yv), 1/(yu*yv)}, 
       yw] - 6*G[{yu^(-1)}, yw]*G[{yv^(-1)}, yw]*
      G[{yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] - 8*G[{yu}, yv^(-1)]*
      G[{yv^(-1)}, yw]*G[{yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] - 
     G[{yv^(-1)}, yw]^2*G[{yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] + 
     2*G[{0}, yu^(-1)]*G[{1/(yu*yv)}, yw]*G[{yu^(-1), 1/(yu*yv), 1/(yu*yv)}, 
       yw] + 2*G[{0}, yv^(-1)]*G[{1/(yu*yv)}, yw]*
      G[{yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] - 
     2*G[{0}, yw]*G[{1/(yu*yv)}, yw]*G[{yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] - 
     10*G[{1}, yu^(-1)]*G[{1/(yu*yv)}, yw]*G[{yu^(-1), 1/(yu*yv), 1/(yu*yv)}, 
       yw] + 2*G[{1}, yv^(-1)]*G[{1/(yu*yv)}, yw]*
      G[{yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] - 
     4*G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] - 
     2*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{yu^(-1), 1/(yu*yv), 1/(yu*yv)}, 
       yw] + 4*G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw]*
      G[{yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] + 2*G[{yv^(-1)}, yw]*
      G[{1/(yu*yv)}, yw]*G[{yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] + 
     4*G[{0, 1}, yv^(-1)]*G[{yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] + 
     2*G[{0, 1}, yw]*G[{yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] - 
     2*G[{0, yu^(-1)}, yw]*G[{yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] - 
     4*G[{0, yu}, yv^(-1)]*G[{yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] - 
     2*G[{0, yv^(-1)}, yw]*G[{yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] + 
     2*G[{0, 1/(yu*yv)}, yw]*G[{yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] + 
     6*G[{1, yu^(-1)}, yw]*G[{yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] + 
     4*G[{1, yu}, yv^(-1)]*G[{yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] + 
     2*G[{1, yv^(-1)}, yw]*G[{yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] - 
     4*G[{1, 1/(yu*yv)}, yw]*G[{yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] + 
     2*G[{yu^(-1), 1/(yu*yv)}, yw]*G[{yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] - 
     2*G[{yv^(-1), 1/(yu*yv)}, yw]*G[{yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] + 
     (Pi^2*G[{yv^(-1), yv^(-1), 1/(yu*yv)}, yw])/3 + 
     2*G[{1}, yu^(-1)]^2*G[{yv^(-1), yv^(-1), 1/(yu*yv)}, yw] + 
     2*G[{0}, yu^(-1)]*G[{1}, yw]*G[{yv^(-1), yv^(-1), 1/(yu*yv)}, yw] + 
     2*G[{0}, yv^(-1)]*G[{1}, yw]*G[{yv^(-1), yv^(-1), 1/(yu*yv)}, yw] - 
     2*G[{0}, yw]*G[{1}, yw]*G[{yv^(-1), yv^(-1), 1/(yu*yv)}, yw] + 
     2*G[{1}, yu^(-1)]*G[{1}, yw]*G[{yv^(-1), yv^(-1), 1/(yu*yv)}, yw] - 
     2*G[{1}, yv^(-1)]*G[{1}, yw]*G[{yv^(-1), yv^(-1), 1/(yu*yv)}, yw] + 
     2*G[{1}, yw]^2*G[{yv^(-1), yv^(-1), 1/(yu*yv)}, yw] - 
     2*G[{0}, yu^(-1)]*G[{yu^(-1)}, yw]*G[{yv^(-1), yv^(-1), 1/(yu*yv)}, 
       yw] - 2*G[{0}, yv^(-1)]*G[{yu^(-1)}, yw]*
      G[{yv^(-1), yv^(-1), 1/(yu*yv)}, yw] + 2*G[{0}, yw]*G[{yu^(-1)}, yw]*
      G[{yv^(-1), yv^(-1), 1/(yu*yv)}, yw] + 2*G[{1}, yu^(-1)]*
      G[{yu^(-1)}, yw]*G[{yv^(-1), yv^(-1), 1/(yu*yv)}, yw] - 
     2*G[{1}, yv^(-1)]*G[{yu^(-1)}, yw]*G[{yv^(-1), yv^(-1), 1/(yu*yv)}, 
       yw] - 4*G[{1}, yw]*G[{yu^(-1)}, yw]*G[{yv^(-1), yv^(-1), 1/(yu*yv)}, 
       yw] + G[{yu^(-1)}, yw]^2*G[{yv^(-1), yv^(-1), 1/(yu*yv)}, yw] - 
     4*G[{1}, yu^(-1)]*G[{yu}, yv^(-1)]*G[{yv^(-1), yv^(-1), 1/(yu*yv)}, 
       yw] - 4*G[{1}, yv^(-1)]*G[{yu}, yv^(-1)]*
      G[{yv^(-1), yv^(-1), 1/(yu*yv)}, yw] - 4*G[{1}, yw]*G[{yu}, yv^(-1)]*
      G[{yv^(-1), yv^(-1), 1/(yu*yv)}, yw] + 4*G[{yu^(-1)}, yw]*
      G[{yu}, yv^(-1)]*G[{yv^(-1), yv^(-1), 1/(yu*yv)}, yw] + 
     4*G[{yu}, yv^(-1)]^2*G[{yv^(-1), yv^(-1), 1/(yu*yv)}, yw] - 
     2*G[{0}, yu^(-1)]*G[{yv^(-1)}, yw]*G[{yv^(-1), yv^(-1), 1/(yu*yv)}, 
       yw] - 2*G[{0}, yv^(-1)]*G[{yv^(-1)}, yw]*
      G[{yv^(-1), yv^(-1), 1/(yu*yv)}, yw] + 2*G[{0}, yw]*G[{yv^(-1)}, yw]*
      G[{yv^(-1), yv^(-1), 1/(yu*yv)}, yw] - 2*G[{1}, yu^(-1)]*
      G[{yv^(-1)}, yw]*G[{yv^(-1), yv^(-1), 1/(yu*yv)}, yw] + 
     2*G[{1}, yv^(-1)]*G[{yv^(-1)}, yw]*G[{yv^(-1), yv^(-1), 1/(yu*yv)}, 
       yw] - 4*G[{1}, yw]*G[{yv^(-1)}, yw]*G[{yv^(-1), yv^(-1), 1/(yu*yv)}, 
       yw] - 2*G[{yu^(-1)}, yw]*G[{yv^(-1)}, yw]*
      G[{yv^(-1), yv^(-1), 1/(yu*yv)}, yw] + 4*G[{yu}, yv^(-1)]*
      G[{yv^(-1)}, yw]*G[{yv^(-1), yv^(-1), 1/(yu*yv)}, yw] + 
     G[{yv^(-1)}, yw]^2*G[{yv^(-1), yv^(-1), 1/(yu*yv)}, yw] + 
     2*G[{0}, yu^(-1)]*G[{1/(yu*yv)}, yw]*G[{yv^(-1), yv^(-1), 1/(yu*yv)}, 
       yw] + 2*G[{0}, yv^(-1)]*G[{1/(yu*yv)}, yw]*
      G[{yv^(-1), yv^(-1), 1/(yu*yv)}, yw] - 2*G[{0}, yw]*G[{1/(yu*yv)}, yw]*
      G[{yv^(-1), yv^(-1), 1/(yu*yv)}, yw] - 6*G[{1}, yu^(-1)]*
      G[{1/(yu*yv)}, yw]*G[{yv^(-1), yv^(-1), 1/(yu*yv)}, yw] + 
     6*G[{1}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{yv^(-1), yv^(-1), 1/(yu*yv)}, 
       yw] + 4*G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{yv^(-1), yv^(-1), 1/(yu*yv)}, 
       yw] - 6*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*
      G[{yv^(-1), yv^(-1), 1/(yu*yv)}, yw] - 4*G[{yu}, yv^(-1)]*
      G[{1/(yu*yv)}, yw]*G[{yv^(-1), yv^(-1), 1/(yu*yv)}, yw] + 
     6*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{yv^(-1), yv^(-1), 1/(yu*yv)}, 
       yw] + 4*G[{0, 1}, yv^(-1)]*G[{yv^(-1), yv^(-1), 1/(yu*yv)}, yw] + 
     2*G[{0, 1}, yw]*G[{yv^(-1), yv^(-1), 1/(yu*yv)}, yw] - 
     2*G[{0, yu^(-1)}, yw]*G[{yv^(-1), yv^(-1), 1/(yu*yv)}, yw] - 
     4*G[{0, yu}, yv^(-1)]*G[{yv^(-1), yv^(-1), 1/(yu*yv)}, yw] - 
     2*G[{0, yv^(-1)}, yw]*G[{yv^(-1), yv^(-1), 1/(yu*yv)}, yw] + 
     2*G[{0, 1/(yu*yv)}, yw]*G[{yv^(-1), yv^(-1), 1/(yu*yv)}, yw] + 
     6*G[{1, yu^(-1)}, yw]*G[{yv^(-1), yv^(-1), 1/(yu*yv)}, yw] + 
     4*G[{1, yu}, yv^(-1)]*G[{yv^(-1), yv^(-1), 1/(yu*yv)}, yw] + 
     2*G[{1, yv^(-1)}, yw]*G[{yv^(-1), yv^(-1), 1/(yu*yv)}, yw] - 
     4*G[{1, 1/(yu*yv)}, yw]*G[{yv^(-1), yv^(-1), 1/(yu*yv)}, yw] + 
     2*G[{yu^(-1), 1/(yu*yv)}, yw]*G[{yv^(-1), yv^(-1), 1/(yu*yv)}, yw] - 
     6*G[{yv^(-1), 1/(yu*yv)}, yw]*G[{yv^(-1), yv^(-1), 1/(yu*yv)}, yw] - 
     (2*Pi^2*G[{yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/3 + 
     2*G[{1}, yu^(-1)]^2*G[{yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] - 
     4*G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*G[{yv^(-1), 1/(yu*yv), 1/(yu*yv)}, 
       yw] + 2*G[{1}, yu^(-1)]*G[{1}, yw]*G[{yv^(-1), 1/(yu*yv), 1/(yu*yv)}, 
       yw] - 2*G[{1}, yv^(-1)]*G[{1}, yw]*G[{yv^(-1), 1/(yu*yv), 1/(yu*yv)}, 
       yw] + 2*G[{1}, yu^(-1)]*G[{yu^(-1)}, yw]*
      G[{yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] - 2*G[{1}, yv^(-1)]*
      G[{yu^(-1)}, yw]*G[{yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] + 
     G[{yu^(-1)}, yw]^2*G[{yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] - 
     2*G[{1}, yu^(-1)]*G[{yv^(-1)}, yw]*G[{yv^(-1), 1/(yu*yv), 1/(yu*yv)}, 
       yw] + 2*G[{1}, yv^(-1)]*G[{yv^(-1)}, yw]*
      G[{yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] - 2*G[{yu^(-1)}, yw]*
      G[{yv^(-1)}, yw]*G[{yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] + 
     G[{yv^(-1)}, yw]^2*G[{yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] - 
     2*G[{1}, yu^(-1)]*G[{1/(yu*yv)}, yw]*G[{yv^(-1), 1/(yu*yv), 1/(yu*yv)}, 
       yw] + 6*G[{1}, yv^(-1)]*G[{1/(yu*yv)}, yw]*
      G[{yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] + 
     4*G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] - 
     6*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{yv^(-1), 1/(yu*yv), 1/(yu*yv)}, 
       yw] - 4*G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw]*
      G[{yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] + 2*G[{yv^(-1)}, yw]*
      G[{1/(yu*yv)}, yw]*G[{yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] - 
     2*G[{0, 1}, yu^(-1)]*G[{yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] + 
     2*G[{0, 1}, yv^(-1)]*G[{yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] - 
     2*G[{0, yu}, yv^(-1)]*G[{yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] + 
     2*G[{1, yu^(-1)}, yw]*G[{yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] + 
     4*G[{1, yu}, yv^(-1)]*G[{yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] - 
     2*G[{1, yv^(-1)}, yw]*G[{yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] + 
     2*G[{yu^(-1), 1/(yu*yv)}, yw]*G[{yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] - 
     2*G[{yv^(-1), 1/(yu*yv)}, yw]*G[{yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] + 
     4*G[{1}, yw]*G[{0, 0, 1, 1}, yu^(-1)] - 4*G[{yv^(-1)}, yw]*
      G[{0, 0, 1, 1}, yu^(-1)] + 4*G[{1}, yw]*G[{0, 0, 1, 1}, yv^(-1)] - 
     4*G[{yv^(-1)}, yw]*G[{0, 0, 1, 1}, yv^(-1)] + 
     4*G[{1}, yw]*G[{0, 0, 1, 1}, yw] - 4*G[{yv^(-1)}, yw]*
      G[{0, 0, 1, 1}, yw] - 4*G[{1}, yw]*G[{0, 0, 1, yu^(-1)}, yw] + 
     4*G[{yv^(-1)}, yw]*G[{0, 0, 1, yu^(-1)}, yw] - 
     4*G[{yu^(-1)}, yw]*G[{0, 0, 1, yu}, yv^(-1)] + 
     4*G[{1/(yu*yv)}, yw]*G[{0, 0, 1, yu}, yv^(-1)] - 
     4*G[{1}, yw]*G[{0, 0, 1, yv^(-1)}, yw] + 4*G[{yv^(-1)}, yw]*
      G[{0, 0, 1, yv^(-1)}, yw] + 4*G[{1}, yw]*G[{0, 0, 1, 1/(yu*yv)}, yw] - 
     4*G[{yv^(-1)}, yw]*G[{0, 0, 1, 1/(yu*yv)}, yw] - 
     4*G[{1}, yw]*G[{0, 0, yu^(-1), 1}, yw] + 4*G[{yv^(-1)}, yw]*
      G[{0, 0, yu^(-1), 1}, yw] + 4*G[{yu^(-1)}, yw]*
      G[{0, 0, yu^(-1), yu^(-1)}, yw] - 4*G[{1/(yu*yv)}, yw]*
      G[{0, 0, yu^(-1), yu^(-1)}, yw] + 4*G[{yu^(-1)}, yw]*
      G[{0, 0, yu^(-1), yv^(-1)}, yw] - 4*G[{1/(yu*yv)}, yw]*
      G[{0, 0, yu^(-1), yv^(-1)}, yw] - 4*G[{yu^(-1)}, yw]*
      G[{0, 0, yu^(-1), 1/(yu*yv)}, yw] + 4*G[{1/(yu*yv)}, yw]*
      G[{0, 0, yu^(-1), 1/(yu*yv)}, yw] - 4*G[{yu^(-1)}, yw]*
      G[{0, 0, yu, 1}, yv^(-1)] + 4*G[{1/(yu*yv)}, yw]*
      G[{0, 0, yu, 1}, yv^(-1)] + 4*G[{yu^(-1)}, yw]*
      G[{0, 0, yu, yu}, yv^(-1)] - 4*G[{1/(yu*yv)}, yw]*
      G[{0, 0, yu, yu}, yv^(-1)] - 4*G[{1}, yw]*G[{0, 0, yv^(-1), 1}, yw] + 
     4*G[{yv^(-1)}, yw]*G[{0, 0, yv^(-1), 1}, yw] + 
     4*G[{yu^(-1)}, yw]*G[{0, 0, yv^(-1), yu^(-1)}, yw] - 
     4*G[{1/(yu*yv)}, yw]*G[{0, 0, yv^(-1), yu^(-1)}, yw] + 
     4*G[{1}, yw]*G[{0, 0, yv^(-1), yv^(-1)}, yw] - 
     4*G[{yv^(-1)}, yw]*G[{0, 0, yv^(-1), yv^(-1)}, yw] - 
     4*G[{1}, yw]*G[{0, 0, yv^(-1), 1/(yu*yv)}, yw] + 
     4*G[{yv^(-1)}, yw]*G[{0, 0, yv^(-1), 1/(yu*yv)}, yw] + 
     4*G[{1}, yw]*G[{0, 0, 1/(yu*yv), 1}, yw] - 4*G[{yv^(-1)}, yw]*
      G[{0, 0, 1/(yu*yv), 1}, yw] - 4*G[{yu^(-1)}, yw]*
      G[{0, 0, 1/(yu*yv), yu^(-1)}, yw] + 4*G[{1/(yu*yv)}, yw]*
      G[{0, 0, 1/(yu*yv), yu^(-1)}, yw] - 4*G[{1}, yw]*
      G[{0, 0, 1/(yu*yv), yv^(-1)}, yw] + 4*G[{yv^(-1)}, yw]*
      G[{0, 0, 1/(yu*yv), yv^(-1)}, yw] + 4*G[{yu^(-1)}, yw]*
      G[{0, 0, 1/(yu*yv), 1/(yu*yv)}, yw] - 4*G[{1/(yu*yv)}, yw]*
      G[{0, 0, 1/(yu*yv), 1/(yu*yv)}, yw] - 2*G[{1}, yw]*
      G[{0, 1, 0, yu^(-1)}, yw] + 2*G[{yu^(-1)}, yw]*
      G[{0, 1, 0, yu^(-1)}, yw] + 2*G[{yv^(-1)}, yw]*
      G[{0, 1, 0, yu^(-1)}, yw] - 2*G[{1/(yu*yv)}, yw]*
      G[{0, 1, 0, yu^(-1)}, yw] + 2*G[{1}, yw]*G[{0, 1, 0, yu}, yv^(-1)] - 
     2*G[{yu^(-1)}, yw]*G[{0, 1, 0, yu}, yv^(-1)] - 
     2*G[{yv^(-1)}, yw]*G[{0, 1, 0, yu}, yv^(-1)] + 
     2*G[{1/(yu*yv)}, yw]*G[{0, 1, 0, yu}, yv^(-1)] + 
     2*G[{1}, yw]*G[{0, 1, 0, 1/(yu*yv)}, yw] - 2*G[{yu^(-1)}, yw]*
      G[{0, 1, 0, 1/(yu*yv)}, yw] - 2*G[{yv^(-1)}, yw]*
      G[{0, 1, 0, 1/(yu*yv)}, yw] + 2*G[{1/(yu*yv)}, yw]*
      G[{0, 1, 0, 1/(yu*yv)}, yw] + 6*G[{1}, yw]*G[{0, 1, 1, 1}, yu^(-1)] - 
     6*G[{yu^(-1)}, yw]*G[{0, 1, 1, 1}, yu^(-1)] - 
     6*G[{yv^(-1)}, yw]*G[{0, 1, 1, 1}, yu^(-1)] + 6*G[{1/(yu*yv)}, yw]*
      G[{0, 1, 1, 1}, yu^(-1)] - 6*G[{1}, yu^(-1)]*G[{0, 1, 1, 1}, yw] + 
     2*G[{1}, yw]*G[{0, 1, 1, 1}, yw] - 2*G[{yu^(-1)}, yw]*
      G[{0, 1, 1, 1}, yw] + 6*G[{yu}, yv^(-1)]*G[{0, 1, 1, 1}, yw] - 
     2*G[{yv^(-1)}, yw]*G[{0, 1, 1, 1}, yw] + 2*G[{1/(yu*yv)}, yw]*
      G[{0, 1, 1, 1}, yw] + 6*G[{1}, yu^(-1)]*G[{0, 1, 1, yu^(-1)}, yw] - 
     4*G[{1}, yv^(-1)]*G[{0, 1, 1, yu^(-1)}, yw] + 
     4*G[{1}, yw]*G[{0, 1, 1, yu^(-1)}, yw] - 2*G[{yu}, yv^(-1)]*
      G[{0, 1, 1, yu^(-1)}, yw] - 4*G[{yv^(-1)}, yw]*
      G[{0, 1, 1, yu^(-1)}, yw] - 2*G[{1}, yw]*G[{0, 1, 1, yu}, yv^(-1)] + 
     6*G[{yu^(-1)}, yw]*G[{0, 1, 1, yu}, yv^(-1)] + 
     2*G[{yv^(-1)}, yw]*G[{0, 1, 1, yu}, yv^(-1)] - 
     6*G[{1/(yu*yv)}, yw]*G[{0, 1, 1, yu}, yv^(-1)] + 
     2*G[{1}, yu^(-1)]*G[{0, 1, 1, yv^(-1)}, yw] + 
     2*G[{1}, yw]*G[{0, 1, 1, yv^(-1)}, yw] + 2*G[{yu^(-1)}, yw]*
      G[{0, 1, 1, yv^(-1)}, yw] - 2*G[{yu}, yv^(-1)]*
      G[{0, 1, 1, yv^(-1)}, yw] - 2*G[{yv^(-1)}, yw]*
      G[{0, 1, 1, yv^(-1)}, yw] - 2*G[{1/(yu*yv)}, yw]*
      G[{0, 1, 1, yv^(-1)}, yw] - 2*G[{1}, yu^(-1)]*G[{0, 1, 1, 1/(yu*yv)}, 
       yw] + 4*G[{1}, yv^(-1)]*G[{0, 1, 1, 1/(yu*yv)}, yw] - 
     2*G[{yu}, yv^(-1)]*G[{0, 1, 1, 1/(yu*yv)}, yw] + 
     4*G[{1}, yu^(-1)]*G[{0, 1, yu^(-1), 1}, yw] - 
     4*G[{1}, yv^(-1)]*G[{0, 1, yu^(-1), 1}, yw] + 
     4*G[{1}, yw]*G[{0, 1, yu^(-1), 1}, yw] - 4*G[{yv^(-1)}, yw]*
      G[{0, 1, yu^(-1), 1}, yw] - 4*G[{1}, yu^(-1)]*
      G[{0, 1, yu^(-1), yu^(-1)}, yw] + 4*G[{1}, yv^(-1)]*
      G[{0, 1, yu^(-1), yu^(-1)}, yw] - 4*G[{1}, yw]*
      G[{0, 1, yu^(-1), yu^(-1)}, yw] - 4*G[{yu^(-1)}, yw]*
      G[{0, 1, yu^(-1), yu^(-1)}, yw] + 4*G[{yv^(-1)}, yw]*
      G[{0, 1, yu^(-1), yu^(-1)}, yw] + 4*G[{1/(yu*yv)}, yw]*
      G[{0, 1, yu^(-1), yu^(-1)}, yw] - 4*G[{1}, yu^(-1)]*
      G[{0, 1, yu^(-1), yv^(-1)}, yw] + 4*G[{1}, yv^(-1)]*
      G[{0, 1, yu^(-1), yv^(-1)}, yw] - 4*G[{1}, yw]*
      G[{0, 1, yu^(-1), yv^(-1)}, yw] - 4*G[{yu^(-1)}, yw]*
      G[{0, 1, yu^(-1), yv^(-1)}, yw] + 4*G[{yv^(-1)}, yw]*
      G[{0, 1, yu^(-1), yv^(-1)}, yw] + 4*G[{1/(yu*yv)}, yw]*
      G[{0, 1, yu^(-1), yv^(-1)}, yw] + 4*G[{1}, yu^(-1)]*
      G[{0, 1, yu^(-1), 1/(yu*yv)}, yw] - 4*G[{1}, yv^(-1)]*
      G[{0, 1, yu^(-1), 1/(yu*yv)}, yw] + 4*G[{yu^(-1)}, yw]*
      G[{0, 1, yu^(-1), 1/(yu*yv)}, yw] - 4*G[{1/(yu*yv)}, yw]*
      G[{0, 1, yu^(-1), 1/(yu*yv)}, yw] + 4*G[{yu^(-1)}, yw]*
      G[{0, 1, yu, 1}, yv^(-1)] - 4*G[{1/(yu*yv)}, yw]*
      G[{0, 1, yu, 1}, yv^(-1)] - 8*G[{yu^(-1)}, yw]*
      G[{0, 1, yu, yu}, yv^(-1)] + 8*G[{1/(yu*yv)}, yw]*
      G[{0, 1, yu, yu}, yv^(-1)] + 4*G[{1}, yu^(-1)]*
      G[{0, 1, yv^(-1), 1}, yw] + 4*G[{1}, yw]*G[{0, 1, yv^(-1), 1}, yw] - 
     4*G[{yu}, yv^(-1)]*G[{0, 1, yv^(-1), 1}, yw] - 
     4*G[{yv^(-1)}, yw]*G[{0, 1, yv^(-1), 1}, yw] - 
     4*G[{1}, yu^(-1)]*G[{0, 1, yv^(-1), yu^(-1)}, yw] + 
     4*G[{1}, yv^(-1)]*G[{0, 1, yv^(-1), yu^(-1)}, yw] - 
     4*G[{1}, yw]*G[{0, 1, yv^(-1), yu^(-1)}, yw] - 
     4*G[{yu^(-1)}, yw]*G[{0, 1, yv^(-1), yu^(-1)}, yw] + 
     4*G[{yv^(-1)}, yw]*G[{0, 1, yv^(-1), yu^(-1)}, yw] + 
     4*G[{1/(yu*yv)}, yw]*G[{0, 1, yv^(-1), yu^(-1)}, yw] - 
     8*G[{1}, yw]*G[{0, 1, yv^(-1), yv^(-1)}, yw] + 
     8*G[{yv^(-1)}, yw]*G[{0, 1, yv^(-1), yv^(-1)}, yw] - 
     4*G[{1}, yv^(-1)]*G[{0, 1, yv^(-1), 1/(yu*yv)}, yw] + 
     4*G[{yu^(-1)}, yw]*G[{0, 1, yv^(-1), 1/(yu*yv)}, yw] + 
     4*G[{yu}, yv^(-1)]*G[{0, 1, yv^(-1), 1/(yu*yv)}, yw] - 
     4*G[{1/(yu*yv)}, yw]*G[{0, 1, yv^(-1), 1/(yu*yv)}, yw] - 
     2*G[{1}, yu^(-1)]*G[{0, 1, 1/(yu*yv), 1}, yw] + 
     4*G[{1}, yv^(-1)]*G[{0, 1, 1/(yu*yv), 1}, yw] - 
     2*G[{1}, yw]*G[{0, 1, 1/(yu*yv), 1}, yw] + 2*G[{yu^(-1)}, yw]*
      G[{0, 1, 1/(yu*yv), 1}, yw] - 2*G[{yu}, yv^(-1)]*
      G[{0, 1, 1/(yu*yv), 1}, yw] + 2*G[{yv^(-1)}, yw]*
      G[{0, 1, 1/(yu*yv), 1}, yw] - 2*G[{1/(yu*yv)}, yw]*
      G[{0, 1, 1/(yu*yv), 1}, yw] + 2*G[{1}, yu^(-1)]*
      G[{0, 1, 1/(yu*yv), yu^(-1)}, yw] - 4*G[{1}, yv^(-1)]*
      G[{0, 1, 1/(yu*yv), yu^(-1)}, yw] + 4*G[{1}, yw]*
      G[{0, 1, 1/(yu*yv), yu^(-1)}, yw] + 2*G[{yu}, yv^(-1)]*
      G[{0, 1, 1/(yu*yv), yu^(-1)}, yw] - 4*G[{yv^(-1)}, yw]*
      G[{0, 1, 1/(yu*yv), yu^(-1)}, yw] + 2*G[{1}, yu^(-1)]*
      G[{0, 1, 1/(yu*yv), yv^(-1)}, yw] - 4*G[{1}, yv^(-1)]*
      G[{0, 1, 1/(yu*yv), yv^(-1)}, yw] + 2*G[{1}, yw]*
      G[{0, 1, 1/(yu*yv), yv^(-1)}, yw] + 2*G[{yu^(-1)}, yw]*
      G[{0, 1, 1/(yu*yv), yv^(-1)}, yw] + 2*G[{yu}, yv^(-1)]*
      G[{0, 1, 1/(yu*yv), yv^(-1)}, yw] - 2*G[{yv^(-1)}, yw]*
      G[{0, 1, 1/(yu*yv), yv^(-1)}, yw] - 2*G[{1/(yu*yv)}, yw]*
      G[{0, 1, 1/(yu*yv), yv^(-1)}, yw] - 2*G[{1}, yu^(-1)]*
      G[{0, 1, 1/(yu*yv), 1/(yu*yv)}, yw] + 4*G[{1}, yv^(-1)]*
      G[{0, 1, 1/(yu*yv), 1/(yu*yv)}, yw] - 2*G[{yu}, yv^(-1)]*
      G[{0, 1, 1/(yu*yv), 1/(yu*yv)}, yw] - 2*G[{1}, yw]*
      G[{0, yu^(-1), 0, yv^(-1)}, yw] + 2*G[{yu^(-1)}, yw]*
      G[{0, yu^(-1), 0, yv^(-1)}, yw] + 2*G[{yv^(-1)}, yw]*
      G[{0, yu^(-1), 0, yv^(-1)}, yw] - 2*G[{1/(yu*yv)}, yw]*
      G[{0, yu^(-1), 0, yv^(-1)}, yw] + 2*G[{1}, yu^(-1)]*
      G[{0, yu^(-1), 1, 1}, yw] - 4*G[{1}, yv^(-1)]*G[{0, yu^(-1), 1, 1}, 
       yw] + 2*G[{1}, yw]*G[{0, yu^(-1), 1, 1}, yw] - 
     2*G[{yu^(-1)}, yw]*G[{0, yu^(-1), 1, 1}, yw] + 
     2*G[{yu}, yv^(-1)]*G[{0, yu^(-1), 1, 1}, yw] - 
     2*G[{yv^(-1)}, yw]*G[{0, yu^(-1), 1, 1}, yw] + 
     2*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1), 1, 1}, yw] - 
     2*G[{1}, yu^(-1)]*G[{0, yu^(-1), 1, yu^(-1)}, yw] + 
     4*G[{1}, yv^(-1)]*G[{0, yu^(-1), 1, yu^(-1)}, yw] - 
     4*G[{1}, yw]*G[{0, yu^(-1), 1, yu^(-1)}, yw] - 
     2*G[{yu}, yv^(-1)]*G[{0, yu^(-1), 1, yu^(-1)}, yw] + 
     4*G[{yv^(-1)}, yw]*G[{0, yu^(-1), 1, yu^(-1)}, yw] - 
     2*G[{1}, yu^(-1)]*G[{0, yu^(-1), 1, yv^(-1)}, yw] + 
     4*G[{1}, yv^(-1)]*G[{0, yu^(-1), 1, yv^(-1)}, yw] - 
     2*G[{1}, yw]*G[{0, yu^(-1), 1, yv^(-1)}, yw] - 
     2*G[{yu^(-1)}, yw]*G[{0, yu^(-1), 1, yv^(-1)}, yw] - 
     2*G[{yu}, yv^(-1)]*G[{0, yu^(-1), 1, yv^(-1)}, yw] + 
     2*G[{yv^(-1)}, yw]*G[{0, yu^(-1), 1, yv^(-1)}, yw] + 
     2*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1), 1, yv^(-1)}, yw] + 
     2*G[{1}, yu^(-1)]*G[{0, yu^(-1), 1, 1/(yu*yv)}, yw] - 
     4*G[{1}, yv^(-1)]*G[{0, yu^(-1), 1, 1/(yu*yv)}, yw] + 
     2*G[{yu}, yv^(-1)]*G[{0, yu^(-1), 1, 1/(yu*yv)}, yw] + 
     4*G[{1}, yv^(-1)]*G[{0, yu^(-1), yu^(-1), 1}, yw] - 
     4*G[{1}, yw]*G[{0, yu^(-1), yu^(-1), 1}, yw] - 
     4*G[{yu}, yv^(-1)]*G[{0, yu^(-1), yu^(-1), 1}, yw] + 
     4*G[{yv^(-1)}, yw]*G[{0, yu^(-1), yu^(-1), 1}, yw] + 
     8*G[{yu^(-1)}, yw]*G[{0, yu^(-1), yu^(-1), yu^(-1)}, yw] - 
     8*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1), yu^(-1), yu^(-1)}, yw] + 
     4*G[{1}, yu^(-1)]*G[{0, yu^(-1), yu^(-1), yv^(-1)}, yw] - 
     4*G[{1}, yv^(-1)]*G[{0, yu^(-1), yu^(-1), yv^(-1)}, yw] + 
     4*G[{1}, yw]*G[{0, yu^(-1), yu^(-1), yv^(-1)}, yw] + 
     4*G[{yu^(-1)}, yw]*G[{0, yu^(-1), yu^(-1), yv^(-1)}, yw] - 
     4*G[{yv^(-1)}, yw]*G[{0, yu^(-1), yu^(-1), yv^(-1)}, yw] - 
     4*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1), yu^(-1), yv^(-1)}, yw] - 
     4*G[{1}, yu^(-1)]*G[{0, yu^(-1), yu^(-1), 1/(yu*yv)}, yw] - 
     4*G[{yu^(-1)}, yw]*G[{0, yu^(-1), yu^(-1), 1/(yu*yv)}, yw] + 
     4*G[{yu}, yv^(-1)]*G[{0, yu^(-1), yu^(-1), 1/(yu*yv)}, yw] + 
     4*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1), yu^(-1), 1/(yu*yv)}, yw] - 
     4*G[{1}, yu^(-1)]*G[{0, yu^(-1), yv^(-1), 1}, yw] + 
     4*G[{1}, yv^(-1)]*G[{0, yu^(-1), yv^(-1), 1}, yw] - 
     4*G[{1}, yw]*G[{0, yu^(-1), yv^(-1), 1}, yw] + 
     4*G[{yv^(-1)}, yw]*G[{0, yu^(-1), yv^(-1), 1}, yw] + 
     4*G[{1}, yu^(-1)]*G[{0, yu^(-1), yv^(-1), yu^(-1)}, yw] - 
     4*G[{1}, yv^(-1)]*G[{0, yu^(-1), yv^(-1), yu^(-1)}, yw] + 
     4*G[{1}, yw]*G[{0, yu^(-1), yv^(-1), yu^(-1)}, yw] + 
     4*G[{yu^(-1)}, yw]*G[{0, yu^(-1), yv^(-1), yu^(-1)}, yw] - 
     4*G[{yv^(-1)}, yw]*G[{0, yu^(-1), yv^(-1), yu^(-1)}, yw] - 
     4*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1), yv^(-1), yu^(-1)}, yw] + 
     4*G[{1}, yu^(-1)]*G[{0, yu^(-1), yv^(-1), yv^(-1)}, yw] - 
     4*G[{1}, yv^(-1)]*G[{0, yu^(-1), yv^(-1), yv^(-1)}, yw] + 
     4*G[{1}, yw]*G[{0, yu^(-1), yv^(-1), yv^(-1)}, yw] + 
     4*G[{yu^(-1)}, yw]*G[{0, yu^(-1), yv^(-1), yv^(-1)}, yw] - 
     4*G[{yv^(-1)}, yw]*G[{0, yu^(-1), yv^(-1), yv^(-1)}, yw] - 
     4*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1), yv^(-1), yv^(-1)}, yw] - 
     4*G[{1}, yu^(-1)]*G[{0, yu^(-1), yv^(-1), 1/(yu*yv)}, yw] + 
     4*G[{1}, yv^(-1)]*G[{0, yu^(-1), yv^(-1), 1/(yu*yv)}, yw] - 
     4*G[{yu^(-1)}, yw]*G[{0, yu^(-1), yv^(-1), 1/(yu*yv)}, yw] + 
     4*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1), yv^(-1), 1/(yu*yv)}, yw] + 
     2*G[{1}, yu^(-1)]*G[{0, yu^(-1), 1/(yu*yv), 1}, yw] - 
     4*G[{1}, yv^(-1)]*G[{0, yu^(-1), 1/(yu*yv), 1}, yw] - 
     2*G[{1}, yw]*G[{0, yu^(-1), 1/(yu*yv), 1}, yw] + 
     2*G[{yu^(-1)}, yw]*G[{0, yu^(-1), 1/(yu*yv), 1}, yw] + 
     2*G[{yu}, yv^(-1)]*G[{0, yu^(-1), 1/(yu*yv), 1}, yw] + 
     2*G[{yv^(-1)}, yw]*G[{0, yu^(-1), 1/(yu*yv), 1}, yw] - 
     2*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1), 1/(yu*yv), 1}, yw] - 
     2*G[{1}, yu^(-1)]*G[{0, yu^(-1), 1/(yu*yv), yu^(-1)}, yw] - 
     4*G[{yu^(-1)}, yw]*G[{0, yu^(-1), 1/(yu*yv), yu^(-1)}, yw] + 
     2*G[{yu}, yv^(-1)]*G[{0, yu^(-1), 1/(yu*yv), yu^(-1)}, yw] + 
     4*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1), 1/(yu*yv), yu^(-1)}, yw] - 
     6*G[{1}, yu^(-1)]*G[{0, yu^(-1), 1/(yu*yv), yv^(-1)}, yw] + 
     4*G[{1}, yv^(-1)]*G[{0, yu^(-1), 1/(yu*yv), yv^(-1)}, yw] + 
     2*G[{1}, yw]*G[{0, yu^(-1), 1/(yu*yv), yv^(-1)}, yw] - 
     6*G[{yu^(-1)}, yw]*G[{0, yu^(-1), 1/(yu*yv), yv^(-1)}, yw] + 
     2*G[{yu}, yv^(-1)]*G[{0, yu^(-1), 1/(yu*yv), yv^(-1)}, yw] - 
     2*G[{yv^(-1)}, yw]*G[{0, yu^(-1), 1/(yu*yv), yv^(-1)}, yw] + 
     6*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1), 1/(yu*yv), yv^(-1)}, yw] + 
     6*G[{1}, yu^(-1)]*G[{0, yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] - 
     6*G[{yu}, yv^(-1)]*G[{0, yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] + 
     2*G[{1}, yw]*G[{0, yu, 1, yu}, yv^(-1)] - 6*G[{yu^(-1)}, yw]*
      G[{0, yu, 1, yu}, yv^(-1)] - 2*G[{yv^(-1)}, yw]*
      G[{0, yu, 1, yu}, yv^(-1)] + 6*G[{1/(yu*yv)}, yw]*
      G[{0, yu, 1, yu}, yv^(-1)] - 4*G[{yu^(-1)}, yw]*
      G[{0, yu, yu, 1}, yv^(-1)] + 4*G[{1/(yu*yv)}, yw]*
      G[{0, yu, yu, 1}, yv^(-1)] + 8*G[{yu^(-1)}, yw]*
      G[{0, yu, yu, yu}, yv^(-1)] - 8*G[{1/(yu*yv)}, yw]*
      G[{0, yu, yu, yu}, yv^(-1)] - 2*G[{1}, yw]*
      G[{0, yv^(-1), 0, 1/(yu*yv)}, yw] + 2*G[{yu^(-1)}, yw]*
      G[{0, yv^(-1), 0, 1/(yu*yv)}, yw] + 2*G[{yv^(-1)}, yw]*
      G[{0, yv^(-1), 0, 1/(yu*yv)}, yw] - 2*G[{1/(yu*yv)}, yw]*
      G[{0, yv^(-1), 0, 1/(yu*yv)}, yw] + 6*G[{1}, yu^(-1)]*
      G[{0, yv^(-1), 1, 1}, yw] - 2*G[{1}, yw]*G[{0, yv^(-1), 1, 1}, yw] + 
     2*G[{yu^(-1)}, yw]*G[{0, yv^(-1), 1, 1}, yw] - 
     6*G[{yu}, yv^(-1)]*G[{0, yv^(-1), 1, 1}, yw] + 
     2*G[{yv^(-1)}, yw]*G[{0, yv^(-1), 1, 1}, yw] - 
     2*G[{1/(yu*yv)}, yw]*G[{0, yv^(-1), 1, 1}, yw] - 
     6*G[{1}, yu^(-1)]*G[{0, yv^(-1), 1, yu^(-1)}, yw] + 
     4*G[{1}, yv^(-1)]*G[{0, yv^(-1), 1, yu^(-1)}, yw] - 
     4*G[{1}, yw]*G[{0, yv^(-1), 1, yu^(-1)}, yw] + 
     2*G[{yu}, yv^(-1)]*G[{0, yv^(-1), 1, yu^(-1)}, yw] + 
     4*G[{yv^(-1)}, yw]*G[{0, yv^(-1), 1, yu^(-1)}, yw] - 
     2*G[{1}, yu^(-1)]*G[{0, yv^(-1), 1, yv^(-1)}, yw] - 
     2*G[{1}, yw]*G[{0, yv^(-1), 1, yv^(-1)}, yw] - 
     2*G[{yu^(-1)}, yw]*G[{0, yv^(-1), 1, yv^(-1)}, yw] + 
     2*G[{yu}, yv^(-1)]*G[{0, yv^(-1), 1, yv^(-1)}, yw] + 
     2*G[{yv^(-1)}, yw]*G[{0, yv^(-1), 1, yv^(-1)}, yw] + 
     2*G[{1/(yu*yv)}, yw]*G[{0, yv^(-1), 1, yv^(-1)}, yw] + 
     2*G[{1}, yu^(-1)]*G[{0, yv^(-1), 1, 1/(yu*yv)}, yw] - 
     4*G[{1}, yv^(-1)]*G[{0, yv^(-1), 1, 1/(yu*yv)}, yw] + 
     2*G[{yu}, yv^(-1)]*G[{0, yv^(-1), 1, 1/(yu*yv)}, yw] - 
     4*G[{1}, yu^(-1)]*G[{0, yv^(-1), yu^(-1), 1}, yw] + 
     4*G[{1}, yv^(-1)]*G[{0, yv^(-1), yu^(-1), 1}, yw] - 
     4*G[{1}, yw]*G[{0, yv^(-1), yu^(-1), 1}, yw] + 
     4*G[{yv^(-1)}, yw]*G[{0, yv^(-1), yu^(-1), 1}, yw] + 
     4*G[{1}, yu^(-1)]*G[{0, yv^(-1), yu^(-1), yu^(-1)}, yw] - 
     4*G[{1}, yv^(-1)]*G[{0, yv^(-1), yu^(-1), yu^(-1)}, yw] + 
     4*G[{1}, yw]*G[{0, yv^(-1), yu^(-1), yu^(-1)}, yw] + 
     4*G[{yu^(-1)}, yw]*G[{0, yv^(-1), yu^(-1), yu^(-1)}, yw] - 
     4*G[{yv^(-1)}, yw]*G[{0, yv^(-1), yu^(-1), yu^(-1)}, yw] - 
     4*G[{1/(yu*yv)}, yw]*G[{0, yv^(-1), yu^(-1), yu^(-1)}, yw] + 
     4*G[{1}, yu^(-1)]*G[{0, yv^(-1), yu^(-1), yv^(-1)}, yw] - 
     4*G[{1}, yv^(-1)]*G[{0, yv^(-1), yu^(-1), yv^(-1)}, yw] + 
     4*G[{1}, yw]*G[{0, yv^(-1), yu^(-1), yv^(-1)}, yw] + 
     4*G[{yu^(-1)}, yw]*G[{0, yv^(-1), yu^(-1), yv^(-1)}, yw] - 
     4*G[{yv^(-1)}, yw]*G[{0, yv^(-1), yu^(-1), yv^(-1)}, yw] - 
     4*G[{1/(yu*yv)}, yw]*G[{0, yv^(-1), yu^(-1), yv^(-1)}, yw] - 
     4*G[{1}, yu^(-1)]*G[{0, yv^(-1), yu^(-1), 1/(yu*yv)}, yw] + 
     4*G[{1}, yv^(-1)]*G[{0, yv^(-1), yu^(-1), 1/(yu*yv)}, yw] - 
     4*G[{yu^(-1)}, yw]*G[{0, yv^(-1), yu^(-1), 1/(yu*yv)}, yw] + 
     4*G[{1/(yu*yv)}, yw]*G[{0, yv^(-1), yu^(-1), 1/(yu*yv)}, yw] - 
     4*G[{1}, yu^(-1)]*G[{0, yv^(-1), yv^(-1), 1}, yw] - 
     4*G[{1}, yw]*G[{0, yv^(-1), yv^(-1), 1}, yw] + 
     4*G[{yu}, yv^(-1)]*G[{0, yv^(-1), yv^(-1), 1}, yw] + 
     4*G[{yv^(-1)}, yw]*G[{0, yv^(-1), yv^(-1), 1}, yw] + 
     4*G[{1}, yu^(-1)]*G[{0, yv^(-1), yv^(-1), yu^(-1)}, yw] - 
     4*G[{1}, yv^(-1)]*G[{0, yv^(-1), yv^(-1), yu^(-1)}, yw] + 
     4*G[{1}, yw]*G[{0, yv^(-1), yv^(-1), yu^(-1)}, yw] + 
     4*G[{yu^(-1)}, yw]*G[{0, yv^(-1), yv^(-1), yu^(-1)}, yw] - 
     4*G[{yv^(-1)}, yw]*G[{0, yv^(-1), yv^(-1), yu^(-1)}, yw] - 
     4*G[{1/(yu*yv)}, yw]*G[{0, yv^(-1), yv^(-1), yu^(-1)}, yw] + 
     8*G[{1}, yw]*G[{0, yv^(-1), yv^(-1), yv^(-1)}, yw] - 
     8*G[{yv^(-1)}, yw]*G[{0, yv^(-1), yv^(-1), yv^(-1)}, yw] + 
     4*G[{1}, yv^(-1)]*G[{0, yv^(-1), yv^(-1), 1/(yu*yv)}, yw] - 
     4*G[{yu^(-1)}, yw]*G[{0, yv^(-1), yv^(-1), 1/(yu*yv)}, yw] - 
     4*G[{yu}, yv^(-1)]*G[{0, yv^(-1), yv^(-1), 1/(yu*yv)}, yw] + 
     4*G[{1/(yu*yv)}, yw]*G[{0, yv^(-1), yv^(-1), 1/(yu*yv)}, yw] + 
     2*G[{1}, yu^(-1)]*G[{0, yv^(-1), 1/(yu*yv), 1}, yw] - 
     4*G[{1}, yv^(-1)]*G[{0, yv^(-1), 1/(yu*yv), 1}, yw] + 
     2*G[{1}, yw]*G[{0, yv^(-1), 1/(yu*yv), 1}, yw] - 
     2*G[{yu^(-1)}, yw]*G[{0, yv^(-1), 1/(yu*yv), 1}, yw] + 
     2*G[{yu}, yv^(-1)]*G[{0, yv^(-1), 1/(yu*yv), 1}, yw] - 
     2*G[{yv^(-1)}, yw]*G[{0, yv^(-1), 1/(yu*yv), 1}, yw] + 
     2*G[{1/(yu*yv)}, yw]*G[{0, yv^(-1), 1/(yu*yv), 1}, yw] - 
     2*G[{1}, yu^(-1)]*G[{0, yv^(-1), 1/(yu*yv), yu^(-1)}, yw] + 
     4*G[{1}, yv^(-1)]*G[{0, yv^(-1), 1/(yu*yv), yu^(-1)}, yw] - 
     4*G[{1}, yw]*G[{0, yv^(-1), 1/(yu*yv), yu^(-1)}, yw] - 
     2*G[{yu}, yv^(-1)]*G[{0, yv^(-1), 1/(yu*yv), yu^(-1)}, yw] + 
     4*G[{yv^(-1)}, yw]*G[{0, yv^(-1), 1/(yu*yv), yu^(-1)}, yw] - 
     2*G[{1}, yu^(-1)]*G[{0, yv^(-1), 1/(yu*yv), yv^(-1)}, yw] + 
     4*G[{1}, yv^(-1)]*G[{0, yv^(-1), 1/(yu*yv), yv^(-1)}, yw] - 
     2*G[{1}, yw]*G[{0, yv^(-1), 1/(yu*yv), yv^(-1)}, yw] - 
     2*G[{yu^(-1)}, yw]*G[{0, yv^(-1), 1/(yu*yv), yv^(-1)}, yw] - 
     2*G[{yu}, yv^(-1)]*G[{0, yv^(-1), 1/(yu*yv), yv^(-1)}, yw] + 
     2*G[{yv^(-1)}, yw]*G[{0, yv^(-1), 1/(yu*yv), yv^(-1)}, yw] + 
     2*G[{1/(yu*yv)}, yw]*G[{0, yv^(-1), 1/(yu*yv), yv^(-1)}, yw] + 
     2*G[{1}, yu^(-1)]*G[{0, yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] - 
     4*G[{1}, yv^(-1)]*G[{0, yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] + 
     2*G[{yu}, yv^(-1)]*G[{0, yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] - 
     2*G[{1}, yu^(-1)]*G[{0, 1/(yu*yv), 1, 1}, yw] + 
     4*G[{1}, yv^(-1)]*G[{0, 1/(yu*yv), 1, 1}, yw] - 
     2*G[{1}, yw]*G[{0, 1/(yu*yv), 1, 1}, yw] + 2*G[{yu^(-1)}, yw]*
      G[{0, 1/(yu*yv), 1, 1}, yw] - 2*G[{yu}, yv^(-1)]*
      G[{0, 1/(yu*yv), 1, 1}, yw] + 2*G[{yv^(-1)}, yw]*
      G[{0, 1/(yu*yv), 1, 1}, yw] - 2*G[{1/(yu*yv)}, yw]*
      G[{0, 1/(yu*yv), 1, 1}, yw] + 2*G[{1}, yu^(-1)]*
      G[{0, 1/(yu*yv), 1, yu^(-1)}, yw] - 4*G[{1}, yv^(-1)]*
      G[{0, 1/(yu*yv), 1, yu^(-1)}, yw] + 4*G[{1}, yw]*
      G[{0, 1/(yu*yv), 1, yu^(-1)}, yw] + 2*G[{yu}, yv^(-1)]*
      G[{0, 1/(yu*yv), 1, yu^(-1)}, yw] - 4*G[{yv^(-1)}, yw]*
      G[{0, 1/(yu*yv), 1, yu^(-1)}, yw] + 2*G[{1}, yu^(-1)]*
      G[{0, 1/(yu*yv), 1, yv^(-1)}, yw] - 4*G[{1}, yv^(-1)]*
      G[{0, 1/(yu*yv), 1, yv^(-1)}, yw] + 2*G[{1}, yw]*
      G[{0, 1/(yu*yv), 1, yv^(-1)}, yw] + 2*G[{yu^(-1)}, yw]*
      G[{0, 1/(yu*yv), 1, yv^(-1)}, yw] + 2*G[{yu}, yv^(-1)]*
      G[{0, 1/(yu*yv), 1, yv^(-1)}, yw] - 2*G[{yv^(-1)}, yw]*
      G[{0, 1/(yu*yv), 1, yv^(-1)}, yw] - 2*G[{1/(yu*yv)}, yw]*
      G[{0, 1/(yu*yv), 1, yv^(-1)}, yw] - 2*G[{1}, yu^(-1)]*
      G[{0, 1/(yu*yv), 1, 1/(yu*yv)}, yw] + 4*G[{1}, yv^(-1)]*
      G[{0, 1/(yu*yv), 1, 1/(yu*yv)}, yw] - 2*G[{yu}, yv^(-1)]*
      G[{0, 1/(yu*yv), 1, 1/(yu*yv)}, yw] - 4*G[{1}, yv^(-1)]*
      G[{0, 1/(yu*yv), yu^(-1), 1}, yw] + 4*G[{1}, yw]*
      G[{0, 1/(yu*yv), yu^(-1), 1}, yw] + 4*G[{yu}, yv^(-1)]*
      G[{0, 1/(yu*yv), yu^(-1), 1}, yw] - 4*G[{yv^(-1)}, yw]*
      G[{0, 1/(yu*yv), yu^(-1), 1}, yw] - 8*G[{yu^(-1)}, yw]*
      G[{0, 1/(yu*yv), yu^(-1), yu^(-1)}, yw] + 8*G[{1/(yu*yv)}, yw]*
      G[{0, 1/(yu*yv), yu^(-1), yu^(-1)}, yw] - 4*G[{1}, yu^(-1)]*
      G[{0, 1/(yu*yv), yu^(-1), yv^(-1)}, yw] + 4*G[{1}, yv^(-1)]*
      G[{0, 1/(yu*yv), yu^(-1), yv^(-1)}, yw] - 
     4*G[{1}, yw]*G[{0, 1/(yu*yv), yu^(-1), yv^(-1)}, yw] - 
     4*G[{yu^(-1)}, yw]*G[{0, 1/(yu*yv), yu^(-1), yv^(-1)}, yw] + 
     4*G[{yv^(-1)}, yw]*G[{0, 1/(yu*yv), yu^(-1), yv^(-1)}, yw] + 
     4*G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv), yu^(-1), yv^(-1)}, yw] + 
     4*G[{1}, yu^(-1)]*G[{0, 1/(yu*yv), yu^(-1), 1/(yu*yv)}, yw] + 
     4*G[{yu^(-1)}, yw]*G[{0, 1/(yu*yv), yu^(-1), 1/(yu*yv)}, yw] - 
     4*G[{yu}, yv^(-1)]*G[{0, 1/(yu*yv), yu^(-1), 1/(yu*yv)}, yw] - 
     4*G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv), yu^(-1), 1/(yu*yv)}, yw] + 
     4*G[{1}, yu^(-1)]*G[{0, 1/(yu*yv), yv^(-1), 1}, yw] - 
     4*G[{1}, yv^(-1)]*G[{0, 1/(yu*yv), yv^(-1), 1}, yw] + 
     4*G[{1}, yw]*G[{0, 1/(yu*yv), yv^(-1), 1}, yw] - 
     4*G[{yv^(-1)}, yw]*G[{0, 1/(yu*yv), yv^(-1), 1}, yw] - 
     4*G[{1}, yu^(-1)]*G[{0, 1/(yu*yv), yv^(-1), yu^(-1)}, yw] + 
     4*G[{1}, yv^(-1)]*G[{0, 1/(yu*yv), yv^(-1), yu^(-1)}, yw] - 
     4*G[{1}, yw]*G[{0, 1/(yu*yv), yv^(-1), yu^(-1)}, yw] - 
     4*G[{yu^(-1)}, yw]*G[{0, 1/(yu*yv), yv^(-1), yu^(-1)}, yw] + 
     4*G[{yv^(-1)}, yw]*G[{0, 1/(yu*yv), yv^(-1), yu^(-1)}, yw] + 
     4*G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv), yv^(-1), yu^(-1)}, yw] - 
     4*G[{1}, yu^(-1)]*G[{0, 1/(yu*yv), yv^(-1), yv^(-1)}, yw] + 
     4*G[{1}, yv^(-1)]*G[{0, 1/(yu*yv), yv^(-1), yv^(-1)}, yw] - 
     4*G[{1}, yw]*G[{0, 1/(yu*yv), yv^(-1), yv^(-1)}, yw] - 
     4*G[{yu^(-1)}, yw]*G[{0, 1/(yu*yv), yv^(-1), yv^(-1)}, yw] + 
     4*G[{yv^(-1)}, yw]*G[{0, 1/(yu*yv), yv^(-1), yv^(-1)}, yw] + 
     4*G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv), yv^(-1), yv^(-1)}, yw] + 
     4*G[{1}, yu^(-1)]*G[{0, 1/(yu*yv), yv^(-1), 1/(yu*yv)}, yw] - 
     4*G[{1}, yv^(-1)]*G[{0, 1/(yu*yv), yv^(-1), 1/(yu*yv)}, yw] + 
     4*G[{yu^(-1)}, yw]*G[{0, 1/(yu*yv), yv^(-1), 1/(yu*yv)}, yw] - 
     4*G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv), yv^(-1), 1/(yu*yv)}, yw] - 
     2*G[{1}, yu^(-1)]*G[{0, 1/(yu*yv), 1/(yu*yv), 1}, yw] + 
     4*G[{1}, yv^(-1)]*G[{0, 1/(yu*yv), 1/(yu*yv), 1}, yw] + 
     2*G[{1}, yw]*G[{0, 1/(yu*yv), 1/(yu*yv), 1}, yw] - 
     2*G[{yu^(-1)}, yw]*G[{0, 1/(yu*yv), 1/(yu*yv), 1}, yw] - 
     2*G[{yu}, yv^(-1)]*G[{0, 1/(yu*yv), 1/(yu*yv), 1}, yw] - 
     2*G[{yv^(-1)}, yw]*G[{0, 1/(yu*yv), 1/(yu*yv), 1}, yw] + 
     2*G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv), 1/(yu*yv), 1}, yw] + 
     2*G[{1}, yu^(-1)]*G[{0, 1/(yu*yv), 1/(yu*yv), yu^(-1)}, yw] + 
     4*G[{yu^(-1)}, yw]*G[{0, 1/(yu*yv), 1/(yu*yv), yu^(-1)}, yw] - 
     2*G[{yu}, yv^(-1)]*G[{0, 1/(yu*yv), 1/(yu*yv), yu^(-1)}, yw] - 
     4*G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv), 1/(yu*yv), yu^(-1)}, yw] + 
     6*G[{1}, yu^(-1)]*G[{0, 1/(yu*yv), 1/(yu*yv), yv^(-1)}, yw] - 
     4*G[{1}, yv^(-1)]*G[{0, 1/(yu*yv), 1/(yu*yv), yv^(-1)}, yw] - 
     2*G[{1}, yw]*G[{0, 1/(yu*yv), 1/(yu*yv), yv^(-1)}, yw] + 
     6*G[{yu^(-1)}, yw]*G[{0, 1/(yu*yv), 1/(yu*yv), yv^(-1)}, yw] - 
     2*G[{yu}, yv^(-1)]*G[{0, 1/(yu*yv), 1/(yu*yv), yv^(-1)}, yw] + 
     2*G[{yv^(-1)}, yw]*G[{0, 1/(yu*yv), 1/(yu*yv), yv^(-1)}, yw] - 
     6*G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv), 1/(yu*yv), yv^(-1)}, yw] - 
     6*G[{1}, yu^(-1)]*G[{0, 1/(yu*yv), 1/(yu*yv), 1/(yu*yv)}, yw] + 
     6*G[{yu}, yv^(-1)]*G[{0, 1/(yu*yv), 1/(yu*yv), 1/(yu*yv)}, yw] + 
     4*G[{1}, yv^(-1)]*G[{1, 1, 1, yu^(-1)}, yw] + 
     4*G[{1}, yw]*G[{1, 1, 1, yu^(-1)}, yw] + 4*G[{yu^(-1)}, yw]*
      G[{1, 1, 1, yu^(-1)}, yw] - 4*G[{yu}, yv^(-1)]*
      G[{1, 1, 1, yu^(-1)}, yw] + 4*G[{yv^(-1)}, yw]*
      G[{1, 1, 1, yu^(-1)}, yw] - 4*G[{1/(yu*yv)}, yw]*
      G[{1, 1, 1, yu^(-1)}, yw] - 8*G[{1}, yu^(-1)]*G[{1, 1, 1, yv^(-1)}, 
       yw] - 8*G[{1}, yw]*G[{1, 1, 1, yv^(-1)}, yw] - 
     8*G[{yu^(-1)}, yw]*G[{1, 1, 1, yv^(-1)}, yw] + 
     8*G[{yu}, yv^(-1)]*G[{1, 1, 1, yv^(-1)}, yw] - 
     8*G[{yv^(-1)}, yw]*G[{1, 1, 1, yv^(-1)}, yw] + 
     8*G[{1/(yu*yv)}, yw]*G[{1, 1, 1, yv^(-1)}, yw] - 
     4*G[{1}, yu^(-1)]*G[{1, 1, 1, 1/(yu*yv)}, yw] - 
     4*G[{1}, yv^(-1)]*G[{1, 1, 1, 1/(yu*yv)}, yw] - 
     8*G[{1}, yw]*G[{1, 1, 1, 1/(yu*yv)}, yw] + 8*G[{yu}, yv^(-1)]*
      G[{1, 1, 1, 1/(yu*yv)}, yw] - 4*G[{1}, yu^(-1)]*
      G[{1, 1, yu^(-1), yu^(-1)}, yw] + 4*G[{1}, yv^(-1)]*
      G[{1, 1, yu^(-1), yu^(-1)}, yw] + 8*G[{yv^(-1)}, yw]*
      G[{1, 1, yu^(-1), yu^(-1)}, yw] - 8*G[{1}, yu^(-1)]*
      G[{1, 1, yu^(-1), yv^(-1)}, yw] + 4*G[{1}, yv^(-1)]*
      G[{1, 1, yu^(-1), yv^(-1)}, yw] - 4*G[{1}, yw]*
      G[{1, 1, yu^(-1), yv^(-1)}, yw] + 4*G[{yu}, yv^(-1)]*
      G[{1, 1, yu^(-1), yv^(-1)}, yw] + 4*G[{yv^(-1)}, yw]*
      G[{1, 1, yu^(-1), yv^(-1)}, yw] + 4*G[{1}, yu^(-1)]*
      G[{1, 1, yu^(-1), 1/(yu*yv)}, yw] - 4*G[{1}, yv^(-1)]*
      G[{1, 1, yu^(-1), 1/(yu*yv)}, yw] - 4*G[{yv^(-1)}, yw]*
      G[{1, 1, yu^(-1), 1/(yu*yv)}, yw] + 8*G[{1}, yw]*
      G[{1, 1, yu, yu}, yv^(-1)] - 8*G[{yu^(-1)}, yw]*
      G[{1, 1, yu, yu}, yv^(-1)] - 8*G[{yv^(-1)}, yw]*
      G[{1, 1, yu, yu}, yv^(-1)] + 8*G[{1/(yu*yv)}, yw]*
      G[{1, 1, yu, yu}, yv^(-1)] - 8*G[{1}, yu^(-1)]*
      G[{1, 1, yv^(-1), yu^(-1)}, yw] + 4*G[{1}, yv^(-1)]*
      G[{1, 1, yv^(-1), yu^(-1)}, yw] - 4*G[{1}, yw]*
      G[{1, 1, yv^(-1), yu^(-1)}, yw] + 4*G[{yu}, yv^(-1)]*
      G[{1, 1, yv^(-1), yu^(-1)}, yw] + 4*G[{yv^(-1)}, yw]*
      G[{1, 1, yv^(-1), yu^(-1)}, yw] - 4*G[{yu^(-1)}, yw]*
      G[{1, 1, yv^(-1), yv^(-1)}, yw] + 4*G[{yv^(-1)}, yw]*
      G[{1, 1, yv^(-1), yv^(-1)}, yw] + 4*G[{1/(yu*yv)}, yw]*
      G[{1, 1, yv^(-1), yv^(-1)}, yw] - 4*G[{1}, yv^(-1)]*
      G[{1, 1, yv^(-1), 1/(yu*yv)}, yw] - 4*G[{1}, yw]*
      G[{1, 1, yv^(-1), 1/(yu*yv)}, yw] - 4*G[{yu^(-1)}, yw]*
      G[{1, 1, yv^(-1), 1/(yu*yv)}, yw] + 4*G[{yu}, yv^(-1)]*
      G[{1, 1, yv^(-1), 1/(yu*yv)}, yw] - 8*G[{yv^(-1)}, yw]*
      G[{1, 1, yv^(-1), 1/(yu*yv)}, yw] + 4*G[{1/(yu*yv)}, yw]*
      G[{1, 1, yv^(-1), 1/(yu*yv)}, yw] - 4*G[{yv^(-1)}, yw]*
      G[{1, 1, 1/(yu*yv), yu^(-1)}, yw] - 4*G[{1}, yu^(-1)]*
      G[{1, 1, 1/(yu*yv), yv^(-1)}, yw] - 4*G[{1}, yv^(-1)]*
      G[{1, 1, 1/(yu*yv), yv^(-1)}, yw] - 8*G[{1}, yw]*
      G[{1, 1, 1/(yu*yv), yv^(-1)}, yw] + 8*G[{yu}, yv^(-1)]*
      G[{1, 1, 1/(yu*yv), yv^(-1)}, yw] - 4*G[{yv^(-1)}, yw]*
      G[{1, 1, 1/(yu*yv), yv^(-1)}, yw] - 4*G[{yu^(-1)}, yw]*
      G[{1, 1, 1/(yu*yv), 1/(yu*yv)}, yw] + 4*G[{yv^(-1)}, yw]*
      G[{1, 1, 1/(yu*yv), 1/(yu*yv)}, yw] + 4*G[{1/(yu*yv)}, yw]*
      G[{1, 1, 1/(yu*yv), 1/(yu*yv)}, yw] - 4*G[{1}, yu^(-1)]*
      G[{1, yu^(-1), 1, yv^(-1)}, yw] - 4*G[{1}, yw]*
      G[{1, yu^(-1), 1, yv^(-1)}, yw] + 4*G[{yu}, yv^(-1)]*
      G[{1, yu^(-1), 1, yv^(-1)}, yw] - 8*G[{1}, yu^(-1)]*
      G[{1, yu^(-1), yu^(-1), yu^(-1)}, yw] - 
     8*G[{1}, yw]*G[{1, yu^(-1), yu^(-1), yu^(-1)}, yw] - 
     8*G[{yu^(-1)}, yw]*G[{1, yu^(-1), yu^(-1), yu^(-1)}, yw] + 
     8*G[{yu}, yv^(-1)]*G[{1, yu^(-1), yu^(-1), yu^(-1)}, yw] + 
     8*G[{yv^(-1)}, yw]*G[{1, yu^(-1), yu^(-1), yu^(-1)}, yw] + 
     8*G[{1/(yu*yv)}, yw]*G[{1, yu^(-1), yu^(-1), yu^(-1)}, yw] - 
     4*G[{1}, yu^(-1)]*G[{1, yu^(-1), yu^(-1), yv^(-1)}, yw] + 
     4*G[{1}, yv^(-1)]*G[{1, yu^(-1), yu^(-1), yv^(-1)}, yw] - 
     4*G[{yu^(-1)}, yw]*G[{1, yu^(-1), yu^(-1), yv^(-1)}, yw] + 
     4*G[{yv^(-1)}, yw]*G[{1, yu^(-1), yu^(-1), yv^(-1)}, yw] + 
     4*G[{1/(yu*yv)}, yw]*G[{1, yu^(-1), yu^(-1), yv^(-1)}, yw] + 
     8*G[{1}, yu^(-1)]*G[{1, yu^(-1), yu^(-1), 1/(yu*yv)}, yw] + 
     8*G[{1}, yw]*G[{1, yu^(-1), yu^(-1), 1/(yu*yv)}, yw] + 
     4*G[{yu^(-1)}, yw]*G[{1, yu^(-1), yu^(-1), 1/(yu*yv)}, yw] - 
     8*G[{yu}, yv^(-1)]*G[{1, yu^(-1), yu^(-1), 1/(yu*yv)}, yw] - 
     4*G[{yv^(-1)}, yw]*G[{1, yu^(-1), yu^(-1), 1/(yu*yv)}, yw] - 
     4*G[{1/(yu*yv)}, yw]*G[{1, yu^(-1), yu^(-1), 1/(yu*yv)}, yw] - 
     4*G[{1}, yu^(-1)]*G[{1, yu^(-1), yv^(-1), yu^(-1)}, yw] + 
     4*G[{1}, yv^(-1)]*G[{1, yu^(-1), yv^(-1), yu^(-1)}, yw] - 
     4*G[{yu^(-1)}, yw]*G[{1, yu^(-1), yv^(-1), yu^(-1)}, yw] + 
     4*G[{yv^(-1)}, yw]*G[{1, yu^(-1), yv^(-1), yu^(-1)}, yw] + 
     4*G[{1/(yu*yv)}, yw]*G[{1, yu^(-1), yv^(-1), yu^(-1)}, yw] - 
     4*G[{1}, yu^(-1)]*G[{1, yu^(-1), yv^(-1), yv^(-1)}, yw] + 
     4*G[{1}, yv^(-1)]*G[{1, yu^(-1), yv^(-1), yv^(-1)}, yw] - 
     4*G[{yu^(-1)}, yw]*G[{1, yu^(-1), yv^(-1), yv^(-1)}, yw] + 
     4*G[{yv^(-1)}, yw]*G[{1, yu^(-1), yv^(-1), yv^(-1)}, yw] + 
     4*G[{1/(yu*yv)}, yw]*G[{1, yu^(-1), yv^(-1), yv^(-1)}, yw] + 
     4*G[{1}, yu^(-1)]*G[{1, yu^(-1), yv^(-1), 1/(yu*yv)}, yw] - 
     4*G[{1}, yv^(-1)]*G[{1, yu^(-1), yv^(-1), 1/(yu*yv)}, yw] + 
     4*G[{yu^(-1)}, yw]*G[{1, yu^(-1), yv^(-1), 1/(yu*yv)}, yw] - 
     4*G[{1/(yu*yv)}, yw]*G[{1, yu^(-1), yv^(-1), 1/(yu*yv)}, yw] + 
     4*G[{1}, yu^(-1)]*G[{1, yu^(-1), 1/(yu*yv), yu^(-1)}, yw] + 
     4*G[{1}, yw]*G[{1, yu^(-1), 1/(yu*yv), yu^(-1)}, yw] + 
     4*G[{yu^(-1)}, yw]*G[{1, yu^(-1), 1/(yu*yv), yu^(-1)}, yw] - 
     4*G[{yu}, yv^(-1)]*G[{1, yu^(-1), 1/(yu*yv), yu^(-1)}, yw] - 
     4*G[{yv^(-1)}, yw]*G[{1, yu^(-1), 1/(yu*yv), yu^(-1)}, yw] - 
     4*G[{1/(yu*yv)}, yw]*G[{1, yu^(-1), 1/(yu*yv), yu^(-1)}, yw] + 
     4*G[{1}, yu^(-1)]*G[{1, yu^(-1), 1/(yu*yv), yv^(-1)}, yw] - 
     4*G[{1}, yv^(-1)]*G[{1, yu^(-1), 1/(yu*yv), yv^(-1)}, yw] + 
     4*G[{yu^(-1)}, yw]*G[{1, yu^(-1), 1/(yu*yv), yv^(-1)}, yw] - 
     4*G[{1/(yu*yv)}, yw]*G[{1, yu^(-1), 1/(yu*yv), yv^(-1)}, yw] - 
     4*G[{1}, yu^(-1)]*G[{1, yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] - 
     4*G[{1}, yw]*G[{1, yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] + 
     4*G[{yu}, yv^(-1)]*G[{1, yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] + 
     8*G[{1}, yw]*G[{1, yu, yu, yu}, yv^(-1)] - 8*G[{yu^(-1)}, yw]*
      G[{1, yu, yu, yu}, yv^(-1)] - 8*G[{yv^(-1)}, yw]*
      G[{1, yu, yu, yu}, yv^(-1)] + 8*G[{1/(yu*yv)}, yw]*
      G[{1, yu, yu, yu}, yv^(-1)] - 4*G[{yu^(-1)}, yw]*
      G[{1, yv^(-1), 1, 1/(yu*yv)}, yw] - 4*G[{yv^(-1)}, yw]*
      G[{1, yv^(-1), 1, 1/(yu*yv)}, yw] + 4*G[{1/(yu*yv)}, yw]*
      G[{1, yv^(-1), 1, 1/(yu*yv)}, yw] - 4*G[{1}, yu^(-1)]*
      G[{1, yv^(-1), yu^(-1), yu^(-1)}, yw] + 4*G[{1}, yv^(-1)]*
      G[{1, yv^(-1), yu^(-1), yu^(-1)}, yw] - 4*G[{yu^(-1)}, yw]*
      G[{1, yv^(-1), yu^(-1), yu^(-1)}, yw] + 4*G[{yv^(-1)}, yw]*
      G[{1, yv^(-1), yu^(-1), yu^(-1)}, yw] + 4*G[{1/(yu*yv)}, yw]*
      G[{1, yv^(-1), yu^(-1), yu^(-1)}, yw] - 4*G[{1}, yu^(-1)]*
      G[{1, yv^(-1), yu^(-1), yv^(-1)}, yw] + 4*G[{1}, yv^(-1)]*
      G[{1, yv^(-1), yu^(-1), yv^(-1)}, yw] - 4*G[{yu^(-1)}, yw]*
      G[{1, yv^(-1), yu^(-1), yv^(-1)}, yw] + 4*G[{yv^(-1)}, yw]*
      G[{1, yv^(-1), yu^(-1), yv^(-1)}, yw] + 4*G[{1/(yu*yv)}, yw]*
      G[{1, yv^(-1), yu^(-1), yv^(-1)}, yw] + 4*G[{1}, yu^(-1)]*
      G[{1, yv^(-1), yu^(-1), 1/(yu*yv)}, yw] - 4*G[{1}, yv^(-1)]*
      G[{1, yv^(-1), yu^(-1), 1/(yu*yv)}, yw] + 4*G[{yu^(-1)}, yw]*
      G[{1, yv^(-1), yu^(-1), 1/(yu*yv)}, yw] - 4*G[{1/(yu*yv)}, yw]*
      G[{1, yv^(-1), yu^(-1), 1/(yu*yv)}, yw] - 4*G[{1}, yu^(-1)]*
      G[{1, yv^(-1), yv^(-1), yu^(-1)}, yw] + 4*G[{1}, yv^(-1)]*
      G[{1, yv^(-1), yv^(-1), yu^(-1)}, yw] - 4*G[{yu^(-1)}, yw]*
      G[{1, yv^(-1), yv^(-1), yu^(-1)}, yw] + 4*G[{yv^(-1)}, yw]*
      G[{1, yv^(-1), yv^(-1), yu^(-1)}, yw] + 4*G[{1/(yu*yv)}, yw]*
      G[{1, yv^(-1), yv^(-1), yu^(-1)}, yw] + 8*G[{1}, yu^(-1)]*
      G[{1, yv^(-1), yv^(-1), yv^(-1)}, yw] + 
     8*G[{1}, yw]*G[{1, yv^(-1), yv^(-1), yv^(-1)}, yw] - 
     8*G[{yu}, yv^(-1)]*G[{1, yv^(-1), yv^(-1), yv^(-1)}, yw] + 
     16*G[{yv^(-1)}, yw]*G[{1, yv^(-1), yv^(-1), yv^(-1)}, yw] - 
     4*G[{1}, yu^(-1)]*G[{1, yv^(-1), yv^(-1), 1/(yu*yv)}, yw] - 
     4*G[{1}, yv^(-1)]*G[{1, yv^(-1), yv^(-1), 1/(yu*yv)}, yw] - 
     8*G[{1}, yw]*G[{1, yv^(-1), yv^(-1), 1/(yu*yv)}, yw] + 
     8*G[{yu^(-1)}, yw]*G[{1, yv^(-1), yv^(-1), 1/(yu*yv)}, yw] + 
     8*G[{yu}, yv^(-1)]*G[{1, yv^(-1), yv^(-1), 1/(yu*yv)}, yw] - 
     8*G[{1/(yu*yv)}, yw]*G[{1, yv^(-1), yv^(-1), 1/(yu*yv)}, yw] + 
     4*G[{1}, yu^(-1)]*G[{1, yv^(-1), 1/(yu*yv), yu^(-1)}, yw] - 
     4*G[{1}, yv^(-1)]*G[{1, yv^(-1), 1/(yu*yv), yu^(-1)}, yw] - 
     4*G[{yv^(-1)}, yw]*G[{1, yv^(-1), 1/(yu*yv), yu^(-1)}, yw] - 
     4*G[{1}, yv^(-1)]*G[{1, yv^(-1), 1/(yu*yv), yv^(-1)}, yw] - 
     4*G[{1}, yw]*G[{1, yv^(-1), 1/(yu*yv), yv^(-1)}, yw] + 
     4*G[{yu^(-1)}, yw]*G[{1, yv^(-1), 1/(yu*yv), yv^(-1)}, yw] + 
     4*G[{yu}, yv^(-1)]*G[{1, yv^(-1), 1/(yu*yv), yv^(-1)}, yw] - 
     4*G[{yv^(-1)}, yw]*G[{1, yv^(-1), 1/(yu*yv), yv^(-1)}, yw] - 
     4*G[{1/(yu*yv)}, yw]*G[{1, yv^(-1), 1/(yu*yv), yv^(-1)}, yw] - 
     4*G[{1}, yu^(-1)]*G[{1, yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] + 
     4*G[{1}, yv^(-1)]*G[{1, yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] + 
     4*G[{1}, yu^(-1)]*G[{1, 1/(yu*yv), yu^(-1), yu^(-1)}, yw] + 
     4*G[{1}, yv^(-1)]*G[{1, 1/(yu*yv), yu^(-1), yu^(-1)}, yw] + 
     8*G[{1}, yw]*G[{1, 1/(yu*yv), yu^(-1), yu^(-1)}, yw] + 
     4*G[{yu^(-1)}, yw]*G[{1, 1/(yu*yv), yu^(-1), yu^(-1)}, yw] - 
     8*G[{yu}, yv^(-1)]*G[{1, 1/(yu*yv), yu^(-1), yu^(-1)}, yw] - 
     4*G[{yv^(-1)}, yw]*G[{1, 1/(yu*yv), yu^(-1), yu^(-1)}, yw] - 
     4*G[{1/(yu*yv)}, yw]*G[{1, 1/(yu*yv), yu^(-1), yu^(-1)}, yw] - 
     4*G[{1}, yu^(-1)]*G[{1, 1/(yu*yv), yu^(-1), 1/(yu*yv)}, yw] - 
     4*G[{1}, yv^(-1)]*G[{1, 1/(yu*yv), yu^(-1), 1/(yu*yv)}, yw] - 
     8*G[{1}, yw]*G[{1, 1/(yu*yv), yu^(-1), 1/(yu*yv)}, yw] + 
     8*G[{yu}, yv^(-1)]*G[{1, 1/(yu*yv), yu^(-1), 1/(yu*yv)}, yw] + 
     4*G[{yv^(-1)}, yw]*G[{1, 1/(yu*yv), yu^(-1), 1/(yu*yv)}, yw] - 
     4*G[{1}, yu^(-1)]*G[{1, 1/(yu*yv), yv^(-1), yv^(-1)}, yw] - 
     4*G[{1}, yv^(-1)]*G[{1, 1/(yu*yv), yv^(-1), yv^(-1)}, yw] - 
     8*G[{1}, yw]*G[{1, 1/(yu*yv), yv^(-1), yv^(-1)}, yw] + 
     4*G[{yu^(-1)}, yw]*G[{1, 1/(yu*yv), yv^(-1), yv^(-1)}, yw] + 
     8*G[{yu}, yv^(-1)]*G[{1, 1/(yu*yv), yv^(-1), yv^(-1)}, yw] - 
     4*G[{yv^(-1)}, yw]*G[{1, 1/(yu*yv), yv^(-1), yv^(-1)}, yw] - 
     4*G[{1/(yu*yv)}, yw]*G[{1, 1/(yu*yv), yv^(-1), yv^(-1)}, yw] - 
     4*G[{yu^(-1)}, yw]*G[{1, 1/(yu*yv), yv^(-1), 1/(yu*yv)}, yw] + 
     4*G[{1/(yu*yv)}, yw]*G[{1, 1/(yu*yv), yv^(-1), 1/(yu*yv)}, yw] - 
     4*G[{1}, yu^(-1)]*G[{1, 1/(yu*yv), 1/(yu*yv), yu^(-1)}, yw] - 
     4*G[{1}, yv^(-1)]*G[{1, 1/(yu*yv), 1/(yu*yv), yu^(-1)}, yw] - 
     8*G[{1}, yw]*G[{1, 1/(yu*yv), 1/(yu*yv), yu^(-1)}, yw] - 
     4*G[{yu^(-1)}, yw]*G[{1, 1/(yu*yv), 1/(yu*yv), yu^(-1)}, yw] + 
     8*G[{yu}, yv^(-1)]*G[{1, 1/(yu*yv), 1/(yu*yv), yu^(-1)}, yw] + 
     4*G[{1/(yu*yv)}, yw]*G[{1, 1/(yu*yv), 1/(yu*yv), yu^(-1)}, yw] - 
     4*G[{yu^(-1)}, yw]*G[{1, 1/(yu*yv), 1/(yu*yv), yv^(-1)}, yw] + 
     4*G[{1/(yu*yv)}, yw]*G[{1, 1/(yu*yv), 1/(yu*yv), yv^(-1)}, yw] + 
     4*G[{1}, yu^(-1)]*G[{1, 1/(yu*yv), 1/(yu*yv), 1/(yu*yv)}, yw] + 
     4*G[{1}, yv^(-1)]*G[{1, 1/(yu*yv), 1/(yu*yv), 1/(yu*yv)}, yw] + 
     8*G[{1}, yw]*G[{1, 1/(yu*yv), 1/(yu*yv), 1/(yu*yv)}, yw] - 
     8*G[{yu}, yv^(-1)]*G[{1, 1/(yu*yv), 1/(yu*yv), 1/(yu*yv)}, yw] - 
     8*G[{1}, yu^(-1)]*G[{yu^(-1), yu^(-1), yu^(-1), 1/(yu*yv)}, yw] - 
     8*G[{1}, yw]*G[{yu^(-1), yu^(-1), yu^(-1), 1/(yu*yv)}, yw] + 
     8*G[{yu}, yv^(-1)]*G[{yu^(-1), yu^(-1), yu^(-1), 1/(yu*yv)}, yw] + 
     8*G[{yv^(-1)}, yw]*G[{yu^(-1), yu^(-1), yu^(-1), 1/(yu*yv)}, yw] - 
     8*G[{1/(yu*yv)}, yw]*G[{yu^(-1), yu^(-1), yu^(-1), 1/(yu*yv)}, yw] - 
     4*G[{1}, yu^(-1)]*G[{yu^(-1), yu^(-1), 1/(yu*yv), yv^(-1)}, yw] + 
     4*G[{1}, yv^(-1)]*G[{yu^(-1), yu^(-1), 1/(yu*yv), yv^(-1)}, yw] - 
     4*G[{yu^(-1)}, yw]*G[{yu^(-1), yu^(-1), 1/(yu*yv), yv^(-1)}, yw] + 
     4*G[{yv^(-1)}, yw]*G[{yu^(-1), yu^(-1), 1/(yu*yv), yv^(-1)}, yw] + 
     4*G[{1/(yu*yv)}, yw]*G[{yu^(-1), yu^(-1), 1/(yu*yv), yv^(-1)}, yw] + 
     4*G[{yv^(-1)}, yw]*G[{yu^(-1), yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] - 
     4*G[{1/(yu*yv)}, yw]*G[{yu^(-1), yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] + 
     4*G[{1}, yu^(-1)]*G[{yu^(-1), 1/(yu*yv), yv^(-1), yv^(-1)}, yw] - 
     4*G[{1}, yv^(-1)]*G[{yu^(-1), 1/(yu*yv), yv^(-1), yv^(-1)}, yw] + 
     4*G[{yu^(-1)}, yw]*G[{yu^(-1), 1/(yu*yv), yv^(-1), yv^(-1)}, yw] - 
     4*G[{yv^(-1)}, yw]*G[{yu^(-1), 1/(yu*yv), yv^(-1), yv^(-1)}, yw] - 
     4*G[{1/(yu*yv)}, yw]*G[{yu^(-1), 1/(yu*yv), yv^(-1), yv^(-1)}, yw] - 
     4*G[{1}, yu^(-1)]*G[{yu^(-1), 1/(yu*yv), yv^(-1), 1/(yu*yv)}, yw] + 
     4*G[{1}, yv^(-1)]*G[{yu^(-1), 1/(yu*yv), yv^(-1), 1/(yu*yv)}, yw] - 
     4*G[{yu^(-1)}, yw]*G[{yu^(-1), 1/(yu*yv), yv^(-1), 1/(yu*yv)}, yw] + 
     4*G[{1/(yu*yv)}, yw]*G[{yu^(-1), 1/(yu*yv), yv^(-1), 1/(yu*yv)}, yw] - 
     8*G[{1}, yu^(-1)]*G[{yu^(-1), 1/(yu*yv), 1/(yu*yv), yv^(-1)}, yw] + 
     4*G[{1}, yv^(-1)]*G[{yu^(-1), 1/(yu*yv), 1/(yu*yv), yv^(-1)}, yw] - 
     4*G[{1}, yw]*G[{yu^(-1), 1/(yu*yv), 1/(yu*yv), yv^(-1)}, yw] - 
     4*G[{yu^(-1)}, yw]*G[{yu^(-1), 1/(yu*yv), 1/(yu*yv), yv^(-1)}, yw] + 
     4*G[{yu}, yv^(-1)]*G[{yu^(-1), 1/(yu*yv), 1/(yu*yv), yv^(-1)}, yw] - 
     4*G[{yv^(-1)}, yw]*G[{yu^(-1), 1/(yu*yv), 1/(yu*yv), yv^(-1)}, yw] + 
     8*G[{1/(yu*yv)}, yw]*G[{yu^(-1), 1/(yu*yv), 1/(yu*yv), yv^(-1)}, yw] + 
     8*G[{1}, yu^(-1)]*G[{yu^(-1), 1/(yu*yv), 1/(yu*yv), 1/(yu*yv)}, yw] + 
     8*G[{1}, yw]*G[{yu^(-1), 1/(yu*yv), 1/(yu*yv), 1/(yu*yv)}, yw] - 
     8*G[{yu}, yv^(-1)]*G[{yu^(-1), 1/(yu*yv), 1/(yu*yv), 1/(yu*yv)}, yw] + 
     8*G[{1}, yu^(-1)]*G[{yv^(-1), yv^(-1), yv^(-1), 1/(yu*yv)}, yw] + 
     8*G[{1}, yw]*G[{yv^(-1), yv^(-1), yv^(-1), 1/(yu*yv)}, yw] - 
     8*G[{yu}, yv^(-1)]*G[{yv^(-1), yv^(-1), yv^(-1), 1/(yu*yv)}, yw] - 
     8*G[{yv^(-1)}, yw]*G[{yv^(-1), yv^(-1), yv^(-1), 1/(yu*yv)}, yw] + 
     4*G[{1}, yu^(-1)]*G[{yv^(-1), yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] - 
     4*G[{1}, yv^(-1)]*G[{yv^(-1), yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] + 
     4*G[{yu^(-1)}, yw]*G[{yv^(-1), yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] - 
     4*G[{yv^(-1)}, yw]*G[{yv^(-1), yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] - 
     4*G[{1}, yv^(-1)]*G[{yv^(-1), 1/(yu*yv), 1/(yu*yv), 1/(yu*yv)}, yw] - 
     4*G[{1}, yw]*G[{yv^(-1), 1/(yu*yv), 1/(yu*yv), 1/(yu*yv)}, yw] + 
     4*G[{yu^(-1)}, yw]*G[{yv^(-1), 1/(yu*yv), 1/(yu*yv), 1/(yu*yv)}, yw] + 
     4*G[{yu}, yv^(-1)]*G[{yv^(-1), 1/(yu*yv), 1/(yu*yv), 1/(yu*yv)}, yw] - 
     12*G[{0, 0, 1, 1, 1}, yw] + 4*G[{0, 0, 1, 1, yu^(-1)}, yw] + 
     4*G[{0, 0, 1, 1, yv^(-1)}, yw] - 4*G[{0, 0, 1, 1, 1/(yu*yv)}, yw] + 
     4*G[{0, 0, 1, yu^(-1), 1}, yw] - 4*G[{0, 0, 1, yu^(-1), yu^(-1)}, yw] - 
     4*G[{0, 0, 1, yu^(-1), yv^(-1)}, yw] + 4*G[{0, 0, 1, yv^(-1), 1}, yw] - 
     4*G[{0, 0, 1, yv^(-1), yu^(-1)}, yw] + 
     4*G[{0, 0, 1, yv^(-1), yv^(-1)}, yw] - 
     4*G[{0, 0, 1, 1/(yu*yv), 1}, yw] - 4*G[{0, 0, 1, 1/(yu*yv), 1/(yu*yv)}, 
       yw] + 4*G[{0, 0, yu^(-1), 1, 1}, yw] - 
     4*G[{0, 0, yu^(-1), 1, yv^(-1)}, yw] + 
     4*G[{0, 0, yu^(-1), yu^(-1), 1}, yw] - 
     12*G[{0, 0, yu^(-1), yu^(-1), yu^(-1)}, yw] - 
     4*G[{0, 0, yu^(-1), yu^(-1), yv^(-1)}, yw] + 
     4*G[{0, 0, yu^(-1), yu^(-1), 1/(yu*yv)}, yw] - 
     4*G[{0, 0, yu^(-1), yv^(-1), yu^(-1)}, yw] - 
     4*G[{0, 0, yu^(-1), yv^(-1), yv^(-1)}, yw] + 
     4*G[{0, 0, yu^(-1), yv^(-1), 1/(yu*yv)}, yw] + 
     4*G[{0, 0, yu^(-1), 1/(yu*yv), yu^(-1)}, yw] + 
     4*G[{0, 0, yu^(-1), 1/(yu*yv), yv^(-1)}, yw] + 
     4*G[{0, 0, yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] + 
     4*G[{0, 0, yv^(-1), 1, 1}, yw] - 4*G[{0, 0, yv^(-1), 1, yv^(-1)}, yw] - 
     4*G[{0, 0, yv^(-1), yu^(-1), yu^(-1)}, yw] + 
     4*G[{0, 0, yv^(-1), yu^(-1), 1/(yu*yv)}, yw] - 
     12*G[{0, 0, yv^(-1), yv^(-1), 1}, yw] + 
     4*G[{0, 0, yv^(-1), yv^(-1), yu^(-1)}, yw] + 
     12*G[{0, 0, yv^(-1), yv^(-1), yv^(-1)}, yw] - 
     4*G[{0, 0, yv^(-1), yv^(-1), 1/(yu*yv)}, yw] + 
     4*G[{0, 0, yv^(-1), 1/(yu*yv), 1}, yw] - 
     4*G[{0, 0, yv^(-1), 1/(yu*yv), yv^(-1)}, yw] + 
     4*G[{0, 0, yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] - 
     4*G[{0, 0, 1/(yu*yv), 1, 1}, yw] + 4*G[{0, 0, 1/(yu*yv), 1, yv^(-1)}, 
       yw] + 4*G[{0, 0, 1/(yu*yv), yu^(-1), yu^(-1)}, yw] - 
     4*G[{0, 0, 1/(yu*yv), yu^(-1), 1/(yu*yv)}, yw] + 
     4*G[{0, 0, 1/(yu*yv), yv^(-1), 1}, yw] - 
     4*G[{0, 0, 1/(yu*yv), yv^(-1), yv^(-1)}, yw] + 
     4*G[{0, 0, 1/(yu*yv), 1/(yu*yv), 1}, yw] - 
     12*G[{0, 0, 1/(yu*yv), 1/(yu*yv), yu^(-1)}, yw] - 
     4*G[{0, 0, 1/(yu*yv), 1/(yu*yv), yv^(-1)}, yw] + 
     12*G[{0, 0, 1/(yu*yv), 1/(yu*yv), 1/(yu*yv)}, yw] - 
     4*G[{0, 1, 0, 1, 1}, yw] + 2*G[{0, 1, 0, 1, yu^(-1)}, yw] - 
     2*G[{0, 1, 0, 1, 1/(yu*yv)}, yw] + 2*G[{0, 1, 0, yu^(-1), 1}, yw] - 
     4*G[{0, 1, 0, yu^(-1), yu^(-1)}, yw] - 
     2*G[{0, 1, 0, yu^(-1), yv^(-1)}, yw] + 
     2*G[{0, 1, 0, yu^(-1), 1/(yu*yv)}, yw] - 
     2*G[{0, 1, 0, yv^(-1), yu^(-1)}, yw] + 
     4*G[{0, 1, 0, yv^(-1), yv^(-1)}, yw] - 
     2*G[{0, 1, 0, 1/(yu*yv), 1}, yw] + 2*G[{0, 1, 0, 1/(yu*yv), yu^(-1)}, 
       yw] - 4*G[{0, 1, 0, 1/(yu*yv), 1/(yu*yv)}, yw] - 
     4*G[{0, 1, 1, 0, yv^(-1)}, yw] - 8*G[{0, 1, 1, 1, 1}, yw] + 
     2*G[{0, 1, 1, 1, yu^(-1)}, yw] + 8*G[{0, 1, 1, 1, yv^(-1)}, yw] - 
     2*G[{0, 1, 1, 1, 1/(yu*yv)}, yw] - 2*G[{0, 1, 1, yu^(-1), 1}, yw] + 
     4*G[{0, 1, 1, yu^(-1), yu^(-1)}, yw] - 
     2*G[{0, 1, 1, yu^(-1), yv^(-1)}, yw] - 
     2*G[{0, 1, 1, yv^(-1), yu^(-1)}, yw] + 
     2*G[{0, 1, 1, yv^(-1), 1/(yu*yv)}, yw] + 
     2*G[{0, 1, 1, 1/(yu*yv), 1}, yw] - 4*G[{0, 1, 1, 1/(yu*yv), yu^(-1)}, 
       yw] + 2*G[{0, 1, 1, 1/(yu*yv), yv^(-1)}, yw] - 
     2*G[{0, 1, yu^(-1), 0, yu^(-1)}, yw] + 
     2*G[{0, 1, yu^(-1), 0, yv^(-1)}, yw] + 
     2*G[{0, 1, yu^(-1), 0, 1/(yu*yv)}, yw] - 
     4*G[{0, 1, yu^(-1), 1, 1}, yw] + 4*G[{0, 1, yu^(-1), 1, yu^(-1)}, yw] + 
     4*G[{0, 1, yu^(-1), yu^(-1), 1}, yw] - 
     4*G[{0, 1, yu^(-1), yu^(-1), 1/(yu*yv)}, yw] + 
     4*G[{0, 1, yu^(-1), yv^(-1), 1}, yw] - 
     4*G[{0, 1, yu^(-1), yv^(-1), 1/(yu*yv)}, yw] - 
     4*G[{0, 1, yu^(-1), 1/(yu*yv), yv^(-1)}, yw] + 
     4*G[{0, 1, yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] - 
     2*G[{0, 1, yv^(-1), 0, yu^(-1)}, yw] + 
     4*G[{0, 1, yv^(-1), 0, yv^(-1)}, yw] + 
     4*G[{0, 1, yv^(-1), yu^(-1), 1}, yw] - 
     4*G[{0, 1, yv^(-1), yu^(-1), 1/(yu*yv)}, yw] + 
     8*G[{0, 1, yv^(-1), yv^(-1), 1}, yw] - 
     8*G[{0, 1, yv^(-1), yv^(-1), yv^(-1)}, yw] - 
     4*G[{0, 1, yv^(-1), 1/(yu*yv), 1}, yw] + 
     4*G[{0, 1, yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] - 
     2*G[{0, 1, 1/(yu*yv), 0, yv^(-1)}, yw] - 
     2*G[{0, 1, 1/(yu*yv), 0, 1/(yu*yv)}, yw] + 
     4*G[{0, 1, 1/(yu*yv), 1, 1}, yw] - 6*G[{0, 1, 1/(yu*yv), 1, yu^(-1)}, 
       yw] + 2*G[{0, 1, 1/(yu*yv), 1, 1/(yu*yv)}, yw] - 
     6*G[{0, 1, 1/(yu*yv), yu^(-1), 1}, yw] + 
     4*G[{0, 1, 1/(yu*yv), yu^(-1), yu^(-1)}, yw] + 
     2*G[{0, 1, 1/(yu*yv), yu^(-1), yv^(-1)}, yw] - 
     4*G[{0, 1, 1/(yu*yv), yv^(-1), 1}, yw] + 
     2*G[{0, 1, 1/(yu*yv), yv^(-1), yu^(-1)}, yw] + 
     2*G[{0, 1, 1/(yu*yv), yv^(-1), 1/(yu*yv)}, yw] + 
     2*G[{0, 1, 1/(yu*yv), 1/(yu*yv), 1}, yw] - 
     4*G[{0, 1, 1/(yu*yv), 1/(yu*yv), yu^(-1)}, yw] + 
     2*G[{0, 1, 1/(yu*yv), 1/(yu*yv), yv^(-1)}, yw] + 
     2*G[{0, yu^(-1), 0, yu^(-1), 1}, yw] - 
     4*G[{0, yu^(-1), 0, yu^(-1), yu^(-1)}, yw] - 
     2*G[{0, yu^(-1), 0, yu^(-1), yv^(-1)}, yw] + 
     2*G[{0, yu^(-1), 0, yv^(-1), 1}, yw] - 
     2*G[{0, yu^(-1), 0, yv^(-1), yu^(-1)}, yw] - 
     4*G[{0, yu^(-1), 0, yv^(-1), yv^(-1)}, yw] + 
     2*G[{0, yu^(-1), 0, yv^(-1), 1/(yu*yv)}, yw] + 
     2*G[{0, yu^(-1), 0, 1/(yu*yv), yv^(-1)}, yw] + 
     4*G[{0, yu^(-1), 0, 1/(yu*yv), 1/(yu*yv)}, yw] + 
     2*G[{0, yu^(-1), 1, 0, yv^(-1)}, yw] + 
     2*G[{0, yu^(-1), 1, 0, 1/(yu*yv)}, yw] - 
     4*G[{0, yu^(-1), 1, 1, 1}, yw] + 6*G[{0, yu^(-1), 1, 1, yu^(-1)}, yw] - 
     2*G[{0, yu^(-1), 1, 1, 1/(yu*yv)}, yw] + 
     6*G[{0, yu^(-1), 1, yu^(-1), 1}, yw] - 
     4*G[{0, yu^(-1), 1, yu^(-1), yu^(-1)}, yw] - 
     2*G[{0, yu^(-1), 1, yu^(-1), yv^(-1)}, yw] + 
     4*G[{0, yu^(-1), 1, yv^(-1), 1}, yw] - 
     2*G[{0, yu^(-1), 1, yv^(-1), yu^(-1)}, yw] - 
     2*G[{0, yu^(-1), 1, yv^(-1), 1/(yu*yv)}, yw] - 
     2*G[{0, yu^(-1), 1, 1/(yu*yv), 1}, yw] + 
     4*G[{0, yu^(-1), 1, 1/(yu*yv), yu^(-1)}, yw] - 
     2*G[{0, yu^(-1), 1, 1/(yu*yv), yv^(-1)}, yw] - 
     4*G[{0, yu^(-1), yu^(-1), 0, 1/(yu*yv)}, yw] + 
     8*G[{0, yu^(-1), yu^(-1), 1, 1}, yw] - 
     4*G[{0, yu^(-1), yu^(-1), 1, yu^(-1)}, yw] - 
     4*G[{0, yu^(-1), yu^(-1), 1, yv^(-1)}, yw] - 
     8*G[{0, yu^(-1), yu^(-1), yu^(-1), yu^(-1)}, yw] + 
     8*G[{0, yu^(-1), yu^(-1), yu^(-1), 1/(yu*yv)}, yw] - 
     4*G[{0, yu^(-1), yu^(-1), yv^(-1), 1}, yw] + 
     4*G[{0, yu^(-1), yu^(-1), yv^(-1), 1/(yu*yv)}, yw] - 
     4*G[{0, yu^(-1), yu^(-1), 1/(yu*yv), 1}, yw] + 
     4*G[{0, yu^(-1), yu^(-1), 1/(yu*yv), yu^(-1)}, yw] + 
     4*G[{0, yu^(-1), yu^(-1), 1/(yu*yv), yv^(-1)}, yw] - 
     4*G[{0, yu^(-1), yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] - 
     2*G[{0, yu^(-1), yv^(-1), 0, yv^(-1)}, yw] - 
     2*G[{0, yu^(-1), yv^(-1), 0, 1/(yu*yv)}, yw] + 
     4*G[{0, yu^(-1), yv^(-1), 1, 1}, yw] - 
     4*G[{0, yu^(-1), yv^(-1), 1, yu^(-1)}, yw] - 
     4*G[{0, yu^(-1), yv^(-1), yu^(-1), 1}, yw] + 
     4*G[{0, yu^(-1), yv^(-1), yu^(-1), 1/(yu*yv)}, yw] - 
     4*G[{0, yu^(-1), yv^(-1), yv^(-1), 1}, yw] + 
     4*G[{0, yu^(-1), yv^(-1), yv^(-1), 1/(yu*yv)}, yw] + 
     4*G[{0, yu^(-1), yv^(-1), 1/(yu*yv), yv^(-1)}, yw] - 
     4*G[{0, yu^(-1), yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] + 
     2*G[{0, yu^(-1), 1/(yu*yv), 0, yv^(-1)}, yw] + 
     4*G[{0, yu^(-1), 1/(yu*yv), 0, 1/(yu*yv)}, yw] + 
     2*G[{0, yu^(-1), 1/(yu*yv), 1, yu^(-1)}, yw] - 
     4*G[{0, yu^(-1), 1/(yu*yv), 1, yv^(-1)}, yw] + 
     2*G[{0, yu^(-1), 1/(yu*yv), 1, 1/(yu*yv)}, yw] - 
     2*G[{0, yu^(-1), 1/(yu*yv), yu^(-1), 1}, yw] + 
     4*G[{0, yu^(-1), 1/(yu*yv), yu^(-1), yu^(-1)}, yw] + 
     2*G[{0, yu^(-1), 1/(yu*yv), yu^(-1), yv^(-1)}, yw] - 
     4*G[{0, yu^(-1), 1/(yu*yv), yu^(-1), 1/(yu*yv)}, yw] - 
     4*G[{0, yu^(-1), 1/(yu*yv), yv^(-1), 1}, yw] + 
     2*G[{0, yu^(-1), 1/(yu*yv), yv^(-1), yu^(-1)}, yw] + 
     8*G[{0, yu^(-1), 1/(yu*yv), yv^(-1), yv^(-1)}, yw] - 
     6*G[{0, yu^(-1), 1/(yu*yv), yv^(-1), 1/(yu*yv)}, yw] + 
     6*G[{0, yu^(-1), 1/(yu*yv), 1/(yu*yv), 1}, yw] - 
     6*G[{0, yu^(-1), 1/(yu*yv), 1/(yu*yv), yv^(-1)}, yw] - 
     4*G[{0, yv^(-1), 0, yv^(-1), 1}, yw] + 
     2*G[{0, yv^(-1), 0, yv^(-1), yu^(-1)}, yw] + 
     4*G[{0, yv^(-1), 0, yv^(-1), yv^(-1)}, yw] - 
     2*G[{0, yv^(-1), 0, yv^(-1), 1/(yu*yv)}, yw] + 
     2*G[{0, yv^(-1), 0, 1/(yu*yv), 1}, yw] - 
     2*G[{0, yv^(-1), 0, 1/(yu*yv), yu^(-1)}, yw] - 
     2*G[{0, yv^(-1), 0, 1/(yu*yv), yv^(-1)}, yw] + 
     4*G[{0, yv^(-1), 0, 1/(yu*yv), 1/(yu*yv)}, yw] + 
     8*G[{0, yv^(-1), 1, 1, 1}, yw] - 2*G[{0, yv^(-1), 1, 1, yu^(-1)}, yw] - 
     8*G[{0, yv^(-1), 1, 1, yv^(-1)}, yw] + 
     2*G[{0, yv^(-1), 1, 1, 1/(yu*yv)}, yw] + 
     2*G[{0, yv^(-1), 1, yu^(-1), 1}, yw] - 
     4*G[{0, yv^(-1), 1, yu^(-1), yu^(-1)}, yw] + 
     2*G[{0, yv^(-1), 1, yu^(-1), yv^(-1)}, yw] + 
     2*G[{0, yv^(-1), 1, yv^(-1), yu^(-1)}, yw] - 
     2*G[{0, yv^(-1), 1, yv^(-1), 1/(yu*yv)}, yw] - 
     2*G[{0, yv^(-1), 1, 1/(yu*yv), 1}, yw] + 
     4*G[{0, yv^(-1), 1, 1/(yu*yv), yu^(-1)}, yw] - 
     2*G[{0, yv^(-1), 1, 1/(yu*yv), yv^(-1)}, yw] - 
     2*G[{0, yv^(-1), yu^(-1), 0, 1/(yu*yv)}, yw] + 
     4*G[{0, yv^(-1), yu^(-1), 1, 1}, yw] - 
     4*G[{0, yv^(-1), yu^(-1), 1, yu^(-1)}, yw] - 
     4*G[{0, yv^(-1), yu^(-1), yu^(-1), 1}, yw] + 
     4*G[{0, yv^(-1), yu^(-1), yu^(-1), 1/(yu*yv)}, yw] - 
     4*G[{0, yv^(-1), yu^(-1), yv^(-1), 1}, yw] + 
     4*G[{0, yv^(-1), yu^(-1), yv^(-1), 1/(yu*yv)}, yw] + 
     4*G[{0, yv^(-1), yu^(-1), 1/(yu*yv), yv^(-1)}, yw] - 
     4*G[{0, yv^(-1), yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] - 
     4*G[{0, yv^(-1), yv^(-1), yu^(-1), 1}, yw] + 
     4*G[{0, yv^(-1), yv^(-1), yu^(-1), 1/(yu*yv)}, yw] - 
     8*G[{0, yv^(-1), yv^(-1), yv^(-1), 1}, yw] + 
     8*G[{0, yv^(-1), yv^(-1), yv^(-1), yv^(-1)}, yw] + 
     4*G[{0, yv^(-1), yv^(-1), 1/(yu*yv), 1}, yw] - 
     4*G[{0, yv^(-1), yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] + 
     2*G[{0, yv^(-1), 1/(yu*yv), 0, 1/(yu*yv)}, yw] - 
     4*G[{0, yv^(-1), 1/(yu*yv), 1, 1}, yw] + 
     6*G[{0, yv^(-1), 1/(yu*yv), 1, yu^(-1)}, yw] - 
     2*G[{0, yv^(-1), 1/(yu*yv), 1, 1/(yu*yv)}, yw] + 
     6*G[{0, yv^(-1), 1/(yu*yv), yu^(-1), 1}, yw] - 
     4*G[{0, yv^(-1), 1/(yu*yv), yu^(-1), yu^(-1)}, yw] - 
     2*G[{0, yv^(-1), 1/(yu*yv), yu^(-1), yv^(-1)}, yw] + 
     4*G[{0, yv^(-1), 1/(yu*yv), yv^(-1), 1}, yw] - 
     2*G[{0, yv^(-1), 1/(yu*yv), yv^(-1), yu^(-1)}, yw] - 
     2*G[{0, yv^(-1), 1/(yu*yv), yv^(-1), 1/(yu*yv)}, yw] - 
     2*G[{0, yv^(-1), 1/(yu*yv), 1/(yu*yv), 1}, yw] + 
     4*G[{0, yv^(-1), 1/(yu*yv), 1/(yu*yv), yu^(-1)}, yw] - 
     2*G[{0, yv^(-1), 1/(yu*yv), 1/(yu*yv), yv^(-1)}, yw] + 
     2*G[{0, 1/(yu*yv), 0, 1/(yu*yv), 1}, yw] - 
     4*G[{0, 1/(yu*yv), 0, 1/(yu*yv), yu^(-1)}, yw] - 
     2*G[{0, 1/(yu*yv), 0, 1/(yu*yv), yv^(-1)}, yw] + 
     4*G[{0, 1/(yu*yv), 0, 1/(yu*yv), 1/(yu*yv)}, yw] + 
     4*G[{0, 1/(yu*yv), 1, 1, 1}, yw] - 6*G[{0, 1/(yu*yv), 1, 1, yu^(-1)}, 
       yw] + 2*G[{0, 1/(yu*yv), 1, 1, 1/(yu*yv)}, yw] - 
     6*G[{0, 1/(yu*yv), 1, yu^(-1), 1}, yw] + 
     4*G[{0, 1/(yu*yv), 1, yu^(-1), yu^(-1)}, yw] + 
     2*G[{0, 1/(yu*yv), 1, yu^(-1), yv^(-1)}, yw] - 
     4*G[{0, 1/(yu*yv), 1, yv^(-1), 1}, yw] + 
     2*G[{0, 1/(yu*yv), 1, yv^(-1), yu^(-1)}, yw] + 
     2*G[{0, 1/(yu*yv), 1, yv^(-1), 1/(yu*yv)}, yw] + 
     2*G[{0, 1/(yu*yv), 1, 1/(yu*yv), 1}, yw] - 
     4*G[{0, 1/(yu*yv), 1, 1/(yu*yv), yu^(-1)}, yw] + 
     2*G[{0, 1/(yu*yv), 1, 1/(yu*yv), yv^(-1)}, yw] - 
     8*G[{0, 1/(yu*yv), yu^(-1), 1, 1}, yw] + 
     4*G[{0, 1/(yu*yv), yu^(-1), 1, yu^(-1)}, yw] + 
     4*G[{0, 1/(yu*yv), yu^(-1), 1, yv^(-1)}, yw] + 
     8*G[{0, 1/(yu*yv), yu^(-1), yu^(-1), yu^(-1)}, yw] - 
     8*G[{0, 1/(yu*yv), yu^(-1), yu^(-1), 1/(yu*yv)}, yw] + 
     4*G[{0, 1/(yu*yv), yu^(-1), yv^(-1), 1}, yw] - 
     4*G[{0, 1/(yu*yv), yu^(-1), yv^(-1), 1/(yu*yv)}, yw] + 
     4*G[{0, 1/(yu*yv), yu^(-1), 1/(yu*yv), 1}, yw] - 
     4*G[{0, 1/(yu*yv), yu^(-1), 1/(yu*yv), yu^(-1)}, yw] - 
     4*G[{0, 1/(yu*yv), yu^(-1), 1/(yu*yv), yv^(-1)}, yw] + 
     4*G[{0, 1/(yu*yv), yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] - 
     4*G[{0, 1/(yu*yv), yv^(-1), 1, 1}, yw] + 
     4*G[{0, 1/(yu*yv), yv^(-1), 1, yu^(-1)}, yw] + 
     4*G[{0, 1/(yu*yv), yv^(-1), yu^(-1), 1}, yw] - 
     4*G[{0, 1/(yu*yv), yv^(-1), yu^(-1), 1/(yu*yv)}, yw] + 
     4*G[{0, 1/(yu*yv), yv^(-1), yv^(-1), 1}, yw] - 
     4*G[{0, 1/(yu*yv), yv^(-1), yv^(-1), 1/(yu*yv)}, yw] - 
     4*G[{0, 1/(yu*yv), yv^(-1), 1/(yu*yv), yv^(-1)}, yw] + 
     4*G[{0, 1/(yu*yv), yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] - 
     2*G[{0, 1/(yu*yv), 1/(yu*yv), 1, yu^(-1)}, yw] + 
     4*G[{0, 1/(yu*yv), 1/(yu*yv), 1, yv^(-1)}, yw] - 
     2*G[{0, 1/(yu*yv), 1/(yu*yv), 1, 1/(yu*yv)}, yw] + 
     2*G[{0, 1/(yu*yv), 1/(yu*yv), yu^(-1), 1}, yw] - 
     4*G[{0, 1/(yu*yv), 1/(yu*yv), yu^(-1), yu^(-1)}, yw] - 
     2*G[{0, 1/(yu*yv), 1/(yu*yv), yu^(-1), yv^(-1)}, yw] + 
     4*G[{0, 1/(yu*yv), 1/(yu*yv), yu^(-1), 1/(yu*yv)}, yw] + 
     4*G[{0, 1/(yu*yv), 1/(yu*yv), yv^(-1), 1}, yw] - 
     2*G[{0, 1/(yu*yv), 1/(yu*yv), yv^(-1), yu^(-1)}, yw] - 
     8*G[{0, 1/(yu*yv), 1/(yu*yv), yv^(-1), yv^(-1)}, yw] + 
     6*G[{0, 1/(yu*yv), 1/(yu*yv), yv^(-1), 1/(yu*yv)}, yw] - 
     6*G[{0, 1/(yu*yv), 1/(yu*yv), 1/(yu*yv), 1}, yw] + 
     6*G[{0, 1/(yu*yv), 1/(yu*yv), 1/(yu*yv), yv^(-1)}, yw] - 
     8*G[{1, 1, 1, 1, yu^(-1)}, yw] + 16*G[{1, 1, 1, 1, yv^(-1)}, yw] + 
     8*G[{1, 1, 1, 1, 1/(yu*yv)}, yw] - 8*G[{1, 1, 1, yu^(-1), yu^(-1)}, 
       yw] - 16*G[{1, 1, 1, yu^(-1), yv^(-1)}, yw] + 
     4*G[{1, 1, 1, yu^(-1), 1/(yu*yv)}, yw] - 
     16*G[{1, 1, 1, yv^(-1), yu^(-1)}, yw] - 
     44*G[{1, 1, 1, yv^(-1), yv^(-1)}, yw] + 
     28*G[{1, 1, 1, yv^(-1), 1/(yu*yv)}, yw] + 
     4*G[{1, 1, 1, 1/(yu*yv), yu^(-1)}, yw] + 
     28*G[{1, 1, 1, 1/(yu*yv), yv^(-1)}, yw] - 
     12*G[{1, 1, 1, 1/(yu*yv), 1/(yu*yv)}, yw] - 
     4*G[{1, 1, yu^(-1), 1, yv^(-1)}, yw] - 
     12*G[{1, 1, yu^(-1), yu^(-1), yu^(-1)}, yw] - 
     4*G[{1, 1, yu^(-1), yu^(-1), yv^(-1)}, yw] - 
     4*G[{1, 1, yu^(-1), yv^(-1), yu^(-1)}, yw] - 
     4*G[{1, 1, yu^(-1), yv^(-1), yv^(-1)}, yw] + 
     4*G[{1, 1, yu^(-1), 1/(yu*yv), yu^(-1)}, yw] + 
     8*G[{1, 1, yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] - 
     8*G[{1, 1, yv^(-1), 1, yu^(-1)}, yw] - 
     20*G[{1, 1, yv^(-1), 1, yv^(-1)}, yw] + 
     12*G[{1, 1, yv^(-1), 1, 1/(yu*yv)}, yw] - 
     4*G[{1, 1, yv^(-1), yu^(-1), yu^(-1)}, yw] + 
     4*G[{1, 1, yv^(-1), yu^(-1), yv^(-1)}, yw] + 
     12*G[{1, 1, yv^(-1), yv^(-1), yu^(-1)}, yw] + 
     36*G[{1, 1, yv^(-1), yv^(-1), yv^(-1)}, yw] + 
     12*G[{1, 1, yv^(-1), yv^(-1), 1/(yu*yv)}, yw] + 
     8*G[{1, 1, yv^(-1), 1/(yu*yv), yu^(-1)}, yw] + 
     8*G[{1, 1, yv^(-1), 1/(yu*yv), yv^(-1)}, yw] - 
     4*G[{1, 1, yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] + 
     8*G[{1, 1, 1/(yu*yv), 1, yv^(-1)}, yw] - 
     4*G[{1, 1, 1/(yu*yv), 1, 1/(yu*yv)}, yw] + 
     4*G[{1, 1, 1/(yu*yv), yu^(-1), yv^(-1)}, yw] + 
     4*G[{1, 1, 1/(yu*yv), yv^(-1), yu^(-1)}, yw] + 
     8*G[{1, 1, 1/(yu*yv), yv^(-1), yv^(-1)}, yw] - 
     4*G[{1, 1, 1/(yu*yv), 1/(yu*yv), yu^(-1)}, yw] + 
     4*G[{1, 1, 1/(yu*yv), 1/(yu*yv), yv^(-1)}, yw] + 
     4*G[{1, 1, 1/(yu*yv), 1/(yu*yv), 1/(yu*yv)}, yw] - 
     4*G[{1, yu^(-1), 1, yu^(-1), yu^(-1)}, yw] + 
     4*G[{1, yu^(-1), 1, 1/(yu*yv), 1/(yu*yv)}, yw] - 
     4*G[{1, yu^(-1), yu^(-1), 1, 1/(yu*yv)}, yw] + 
     8*G[{1, yu^(-1), yu^(-1), yu^(-1), yu^(-1)}, yw] - 
     8*G[{1, yu^(-1), yu^(-1), yu^(-1), 1/(yu*yv)}, yw] - 
     4*G[{1, yu^(-1), yu^(-1), yv^(-1), 1/(yu*yv)}, yw] - 
     4*G[{1, yu^(-1), yu^(-1), 1/(yu*yv), yu^(-1)}, yw] - 
     4*G[{1, yu^(-1), yu^(-1), 1/(yu*yv), yv^(-1)}, yw] + 
     4*G[{1, yu^(-1), yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] - 
     4*G[{1, yu^(-1), yv^(-1), 1, yv^(-1)}, yw] - 
     4*G[{1, yu^(-1), yv^(-1), yu^(-1), 1/(yu*yv)}, yw] - 
     4*G[{1, yu^(-1), yv^(-1), yv^(-1), 1/(yu*yv)}, yw] - 
     4*G[{1, yu^(-1), yv^(-1), 1/(yu*yv), yv^(-1)}, yw] + 
     4*G[{1, yu^(-1), yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] + 
     4*G[{1, yu^(-1), 1/(yu*yv), 1, 1/(yu*yv)}, yw] - 
     4*G[{1, yu^(-1), 1/(yu*yv), yu^(-1), yu^(-1)}, yw] + 
     4*G[{1, yu^(-1), 1/(yu*yv), yu^(-1), 1/(yu*yv)}, yw] - 
     4*G[{1, yu^(-1), 1/(yu*yv), yv^(-1), yv^(-1)}, yw] + 
     4*G[{1, yu^(-1), 1/(yu*yv), yv^(-1), 1/(yu*yv)}, yw] + 
     4*G[{1, yu^(-1), 1/(yu*yv), 1/(yu*yv), yv^(-1)}, yw] + 
     4*G[{1, yv^(-1), 1, yv^(-1), yu^(-1)}, yw] + 
     20*G[{1, yv^(-1), 1, yv^(-1), yv^(-1)}, yw] + 
     8*G[{1, yv^(-1), 1, yv^(-1), 1/(yu*yv)}, yw] + 
     4*G[{1, yv^(-1), 1, 1/(yu*yv), yu^(-1)}, yw] + 
     4*G[{1, yv^(-1), 1, 1/(yu*yv), yv^(-1)}, yw] - 
     4*G[{1, yv^(-1), 1, 1/(yu*yv), 1/(yu*yv)}, yw] - 
     4*G[{1, yv^(-1), yu^(-1), yu^(-1), 1/(yu*yv)}, yw] - 
     4*G[{1, yv^(-1), yu^(-1), yv^(-1), 1/(yu*yv)}, yw] - 
     4*G[{1, yv^(-1), yu^(-1), 1/(yu*yv), yv^(-1)}, yw] + 
     4*G[{1, yv^(-1), yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] + 
     12*G[{1, yv^(-1), yv^(-1), 1, 1/(yu*yv)}, yw] - 
     4*G[{1, yv^(-1), yv^(-1), yu^(-1), 1/(yu*yv)}, yw] - 
     24*G[{1, yv^(-1), yv^(-1), yv^(-1), yv^(-1)}, yw] - 
     4*G[{1, yv^(-1), yv^(-1), 1/(yu*yv), yu^(-1)}, yw] + 
     4*G[{1, yv^(-1), yv^(-1), 1/(yu*yv), yv^(-1)}, yw] + 
     8*G[{1, yv^(-1), yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] + 
     4*G[{1, yv^(-1), 1/(yu*yv), yu^(-1), yu^(-1)}, yw] + 
     4*G[{1, yv^(-1), 1/(yu*yv), yv^(-1), yv^(-1)}, yw] + 
     4*G[{1, yv^(-1), 1/(yu*yv), yv^(-1), 1/(yu*yv)}, yw] - 
     4*G[{1, yv^(-1), 1/(yu*yv), 1/(yu*yv), yu^(-1)}, yw] + 
     4*G[{1, yv^(-1), 1/(yu*yv), 1/(yu*yv), yv^(-1)}, yw] - 
     4*G[{1, 1/(yu*yv), 1, 1/(yu*yv), yu^(-1)}, yw] + 
     4*G[{1, 1/(yu*yv), 1, 1/(yu*yv), yv^(-1)}, yw] + 
     4*G[{1, 1/(yu*yv), 1, 1/(yu*yv), 1/(yu*yv)}, yw] - 
     8*G[{1, 1/(yu*yv), yu^(-1), yu^(-1), yu^(-1)}, yw] + 
     4*G[{1, 1/(yu*yv), yu^(-1), yu^(-1), 1/(yu*yv)}, yw] + 
     4*G[{1, 1/(yu*yv), yu^(-1), 1/(yu*yv), yu^(-1)}, yw] + 
     8*G[{1, 1/(yu*yv), yv^(-1), yv^(-1), yv^(-1)}, yw] + 
     4*G[{1, 1/(yu*yv), yv^(-1), yv^(-1), 1/(yu*yv)}, yw] + 
     4*G[{1, 1/(yu*yv), yv^(-1), 1/(yu*yv), yu^(-1)}, yw] - 
     4*G[{1, 1/(yu*yv), yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] + 
     8*G[{1, 1/(yu*yv), 1/(yu*yv), yu^(-1), yu^(-1)}, yw] + 
     4*G[{1, 1/(yu*yv), 1/(yu*yv), yu^(-1), yv^(-1)}, yw] - 
     4*G[{1, 1/(yu*yv), 1/(yu*yv), yu^(-1), 1/(yu*yv)}, yw] + 
     4*G[{1, 1/(yu*yv), 1/(yu*yv), yv^(-1), yu^(-1)}, yw] - 
     4*G[{1, 1/(yu*yv), 1/(yu*yv), yv^(-1), 1/(yu*yv)}, yw] - 
     4*G[{1, 1/(yu*yv), 1/(yu*yv), 1/(yu*yv), yu^(-1)}, yw] - 
     4*G[{1, 1/(yu*yv), 1/(yu*yv), 1/(yu*yv), yv^(-1)}, yw] + 
     8*G[{yu^(-1), yu^(-1), yu^(-1), yu^(-1), 1/(yu*yv)}, yw] - 
     4*G[{yu^(-1), yu^(-1), yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] - 
     4*G[{yu^(-1), yu^(-1), 1/(yu*yv), yu^(-1), 1/(yu*yv)}, yw] - 
     4*G[{yu^(-1), yu^(-1), 1/(yu*yv), yv^(-1), 1/(yu*yv)}, yw] - 
     12*G[{yu^(-1), yu^(-1), 1/(yu*yv), 1/(yu*yv), yv^(-1)}, yw] + 
     12*G[{yu^(-1), yu^(-1), 1/(yu*yv), 1/(yu*yv), 1/(yu*yv)}, yw] - 
     4*G[{yu^(-1), 1/(yu*yv), yu^(-1), 1/(yu*yv), yv^(-1)}, yw] + 
     4*G[{yu^(-1), 1/(yu*yv), yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] + 
     4*G[{yu^(-1), 1/(yu*yv), yv^(-1), yv^(-1), 1/(yu*yv)}, yw] + 
     4*G[{yu^(-1), 1/(yu*yv), yv^(-1), 1/(yu*yv), yv^(-1)}, yw] - 
     4*G[{yu^(-1), 1/(yu*yv), yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] + 
     12*G[{yu^(-1), 1/(yu*yv), 1/(yu*yv), yv^(-1), yv^(-1)}, yw] - 
     8*G[{yu^(-1), 1/(yu*yv), 1/(yu*yv), yv^(-1), 1/(yu*yv)}, yw] - 
     8*G[{yu^(-1), 1/(yu*yv), 1/(yu*yv), 1/(yu*yv), yv^(-1)}, yw] + 
     8*G[{yv^(-1), yv^(-1), yv^(-1), yv^(-1), 1/(yu*yv)}, yw] + 
     12*G[{yv^(-1), yv^(-1), yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] + 
     4*G[{yv^(-1), yv^(-1), 1/(yu*yv), yv^(-1), 1/(yu*yv)}, yw] - 
     (Pi^2*Zeta[3])/3 - 2*G[{0}, yu^(-1)]*G[{1}, yw]*Zeta[3] - 
     2*G[{0}, yv^(-1)]*G[{1}, yw]*Zeta[3] + 2*G[{0}, yw]*G[{1}, yw]*Zeta[3] + 
     2*G[{1}, yu^(-1)]*G[{1}, yw]*Zeta[3] + 2*G[{1}, yv^(-1)]*G[{1}, yw]*
      Zeta[3] - 2*G[{1}, yw]^2*Zeta[3] + 2*G[{0}, yu^(-1)]*G[{yu^(-1)}, yw]*
      Zeta[3] + 2*G[{0}, yv^(-1)]*G[{yu^(-1)}, yw]*Zeta[3] - 
     2*G[{0}, yw]*G[{yu^(-1)}, yw]*Zeta[3] - 2*G[{1}, yu^(-1)]*
      G[{yu^(-1)}, yw]*Zeta[3] - 2*G[{1}, yv^(-1)]*G[{yu^(-1)}, yw]*Zeta[3] + 
     3*G[{yu^(-1)}, yw]^2*Zeta[3] + 2*G[{0}, yu^(-1)]*G[{yv^(-1)}, yw]*
      Zeta[3] + 2*G[{0}, yv^(-1)]*G[{yv^(-1)}, yw]*Zeta[3] - 
     2*G[{0}, yw]*G[{yv^(-1)}, yw]*Zeta[3] - 2*G[{1}, yu^(-1)]*
      G[{yv^(-1)}, yw]*Zeta[3] - 2*G[{1}, yv^(-1)]*G[{yv^(-1)}, yw]*Zeta[3] + 
     4*G[{1}, yw]*G[{yv^(-1)}, yw]*Zeta[3] + 2*G[{yu^(-1)}, yw]*
      G[{yv^(-1)}, yw]*Zeta[3] - G[{yv^(-1)}, yw]^2*Zeta[3] - 
     2*G[{0}, yu^(-1)]*G[{1/(yu*yv)}, yw]*Zeta[3] - 
     2*G[{0}, yv^(-1)]*G[{1/(yu*yv)}, yw]*Zeta[3] + 
     2*G[{0}, yw]*G[{1/(yu*yv)}, yw]*Zeta[3] + 2*G[{1}, yu^(-1)]*
      G[{1/(yu*yv)}, yw]*Zeta[3] + 2*G[{1}, yv^(-1)]*G[{1/(yu*yv)}, yw]*
      Zeta[3] - 6*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*Zeta[3] - 
     2*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*Zeta[3] + 
     2*G[{1/(yu*yv)}, yw]^2*Zeta[3] - 2*G[{0, 1}, yw]*Zeta[3] + 
     2*G[{0, yu^(-1)}, yw]*Zeta[3] + 2*G[{0, yv^(-1)}, yw]*Zeta[3] - 
     2*G[{0, 1/(yu*yv)}, yw]*Zeta[3] - 2*G[{1, yu^(-1)}, yw]*Zeta[3] - 
     2*G[{1, yv^(-1)}, yw]*Zeta[3] + 2*G[{yu^(-1), 1/(yu*yv)}, yw]*Zeta[3] + 
     2*G[{yv^(-1), 1/(yu*yv)}, yw]*Zeta[3] + 2*Zeta[5]
 
NuvwRegII = (-17*Pi^4*G[{0}, yu^(-1)])/180 - (17*Pi^4*G[{0}, yv^(-1)])/180 + 
     (17*Pi^4*G[{0}, yw])/180 + (17*Pi^4*G[{1}, yu^(-1)])/180 - 
     (Pi^2*G[{0}, yu^(-1)]*G[{1}, yu^(-1)]^2)/6 - 
     (Pi^2*G[{0}, yv^(-1)]*G[{1}, yu^(-1)]^2)/6 + 
     (Pi^2*G[{0}, yw]*G[{1}, yu^(-1)]^2)/6 + (Pi^2*G[{1}, yu^(-1)]^3)/9 + 
     (17*Pi^4*G[{1}, yv^(-1)])/180 + (Pi^2*G[{0}, yu^(-1)]*G[{1}, yu^(-1)]*
       G[{1}, yv^(-1)])/3 + (Pi^2*G[{0}, yv^(-1)]*G[{1}, yu^(-1)]*
       G[{1}, yv^(-1)])/3 - (Pi^2*G[{0}, yw]*G[{1}, yu^(-1)]*G[{1}, yv^(-1)])/
      3 - (Pi^2*G[{0}, yu^(-1)]*G[{1}, yv^(-1)]^2)/6 - 
     (Pi^2*G[{0}, yv^(-1)]*G[{1}, yv^(-1)]^2)/6 + 
     (Pi^2*G[{0}, yw]*G[{1}, yv^(-1)]^2)/6 - 
     (Pi^2*G[{1}, yu^(-1)]*G[{1}, yv^(-1)]^2)/3 + (Pi^2*G[{1}, yv^(-1)]^3)/
      9 - (2*G[{0}, yu^(-1)]*G[{1}, yu^(-1)]*G[{1}, yv^(-1)]^3)/3 - 
     (2*G[{0}, yv^(-1)]*G[{1}, yu^(-1)]*G[{1}, yv^(-1)]^3)/3 + 
     (2*G[{0}, yw]*G[{1}, yu^(-1)]*G[{1}, yv^(-1)]^3)/3 + 
     (2*G[{1}, yu^(-1)]^2*G[{1}, yv^(-1)]^3)/3 + 
     (G[{1}, yu^(-1)]*G[{1}, yv^(-1)]^4)/2 - (17*Pi^4*G[{1}, yw])/180 - 
     (Pi^2*G[{0}, yu^(-1)]*G[{1}, yu^(-1)]*G[{1}, yw])/3 - 
     (Pi^2*G[{0}, yv^(-1)]*G[{1}, yu^(-1)]*G[{1}, yw])/3 + 
     (Pi^2*G[{0}, yw]*G[{1}, yu^(-1)]*G[{1}, yw])/3 - 
     (Pi^2*G[{0}, yu^(-1)]*G[{1}, yv^(-1)]*G[{1}, yw])/3 - 
     (Pi^2*G[{0}, yv^(-1)]*G[{1}, yv^(-1)]*G[{1}, yw])/3 + 
     (Pi^2*G[{0}, yw]*G[{1}, yv^(-1)]*G[{1}, yw])/3 + 
     (2*Pi^2*G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*G[{1}, yw])/3 - 
     (2*G[{1}, yu^(-1)]*G[{1}, yv^(-1)]^3*G[{1}, yw])/3 + 
     (Pi^2*G[{0}, yu^(-1)]*G[{1}, yw]^2)/2 + 
     (Pi^2*G[{0}, yv^(-1)]*G[{1}, yw]^2)/2 - (Pi^2*G[{0}, yw]*G[{1}, yw]^2)/
      2 - (Pi^2*G[{1}, yu^(-1)]*G[{1}, yw]^2)/3 - 
     (Pi^2*G[{1}, yv^(-1)]*G[{1}, yw]^2)/3 + 2*G[{0}, yu^(-1)]*
      G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*G[{1}, yw]^2 + 
     2*G[{0}, yv^(-1)]*G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*G[{1}, yw]^2 - 
     2*G[{0}, yw]*G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*G[{1}, yw]^2 - 
     2*G[{1}, yu^(-1)]^2*G[{1}, yv^(-1)]*G[{1}, yw]^2 - 
     G[{1}, yu^(-1)]*G[{1}, yv^(-1)]^2*G[{1}, yw]^2 + (Pi^2*G[{1}, yw]^3)/9 - 
     (2*G[{0}, yu^(-1)]*G[{1}, yu^(-1)]*G[{1}, yw]^3)/3 - 
     (2*G[{0}, yv^(-1)]*G[{1}, yu^(-1)]*G[{1}, yw]^3)/3 + 
     (2*G[{0}, yw]*G[{1}, yu^(-1)]*G[{1}, yw]^3)/3 + 
     (2*G[{1}, yu^(-1)]^2*G[{1}, yw]^3)/3 - 
     (2*G[{0}, yu^(-1)]*G[{1}, yv^(-1)]*G[{1}, yw]^3)/3 - 
     (2*G[{0}, yv^(-1)]*G[{1}, yv^(-1)]*G[{1}, yw]^3)/3 + 
     (2*G[{0}, yw]*G[{1}, yv^(-1)]*G[{1}, yw]^3)/3 + 
     2*G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*G[{1}, yw]^3 + 
     (2*G[{1}, yv^(-1)]^2*G[{1}, yw]^3)/3 - (G[{0}, yu^(-1)]*G[{1}, yw]^4)/
      2 - (G[{0}, yv^(-1)]*G[{1}, yw]^4)/2 + (G[{0}, yw]*G[{1}, yw]^4)/2 + 
     (G[{1}, yu^(-1)]*G[{1}, yw]^4)/2 + (G[{1}, yv^(-1)]*G[{1}, yw]^4)/2 - 
     (Pi^2*G[{1}, yw]^2*G[{yu}, yv^(-1)])/3 - 2*G[{0}, yu^(-1)]*
      G[{1}, yu^(-1)]*G[{1}, yw]^2*G[{yu}, yv^(-1)] - 
     2*G[{0}, yv^(-1)]*G[{1}, yu^(-1)]*G[{1}, yw]^2*G[{yu}, yv^(-1)] + 
     2*G[{0}, yw]*G[{1}, yu^(-1)]*G[{1}, yw]^2*G[{yu}, yv^(-1)] + 
     2*G[{1}, yu^(-1)]^2*G[{1}, yw]^2*G[{yu}, yv^(-1)] - 
     2*G[{0}, yu^(-1)]*G[{1}, yv^(-1)]*G[{1}, yw]^2*G[{yu}, yv^(-1)] - 
     2*G[{0}, yv^(-1)]*G[{1}, yv^(-1)]*G[{1}, yw]^2*G[{yu}, yv^(-1)] + 
     2*G[{0}, yw]*G[{1}, yv^(-1)]*G[{1}, yw]^2*G[{yu}, yv^(-1)] + 
     2*G[{1}, yv^(-1)]^2*G[{1}, yw]^2*G[{yu}, yv^(-1)] + 
     (4*G[{0}, yu^(-1)]*G[{1}, yw]^3*G[{yu}, yv^(-1)])/3 + 
     (4*G[{0}, yv^(-1)]*G[{1}, yw]^3*G[{yu}, yv^(-1)])/3 - 
     (4*G[{0}, yw]*G[{1}, yw]^3*G[{yu}, yv^(-1)])/3 - 
     2*G[{1}, yu^(-1)]*G[{1}, yw]^3*G[{yu}, yv^(-1)] - 
     2*G[{1}, yv^(-1)]*G[{1}, yw]^3*G[{yu}, yv^(-1)] + 
     2*G[{0}, yu^(-1)]*G[{1}, yw]^2*G[{yu}, yv^(-1)]^2 + 
     2*G[{0}, yv^(-1)]*G[{1}, yw]^2*G[{yu}, yv^(-1)]^2 - 
     2*G[{0}, yw]*G[{1}, yw]^2*G[{yu}, yv^(-1)]^2 + 
     (2*G[{1}, yw]^3*G[{yu}, yv^(-1)]^2)/3 - 
     (4*G[{1}, yw]^2*G[{yu}, yv^(-1)]^3)/3 - (17*Pi^4*G[{1/(yu*yv)}, yw])/
      180 + (Pi^2*G[{0}, yu^(-1)]*G[{1}, yu^(-1)]*G[{1/(yu*yv)}, yw])/3 + 
     (Pi^2*G[{0}, yv^(-1)]*G[{1}, yu^(-1)]*G[{1/(yu*yv)}, yw])/3 - 
     (Pi^2*G[{0}, yw]*G[{1}, yu^(-1)]*G[{1/(yu*yv)}, yw])/3 - 
     (Pi^2*G[{1}, yu^(-1)]^2*G[{1/(yu*yv)}, yw])/3 + 
     (Pi^2*G[{0}, yu^(-1)]*G[{1}, yv^(-1)]*G[{1/(yu*yv)}, yw])/3 + 
     (Pi^2*G[{0}, yv^(-1)]*G[{1}, yv^(-1)]*G[{1/(yu*yv)}, yw])/3 - 
     (Pi^2*G[{0}, yw]*G[{1}, yv^(-1)]*G[{1/(yu*yv)}, yw])/3 - 
     (Pi^2*G[{1}, yv^(-1)]^2*G[{1/(yu*yv)}, yw])/3 - 
     (2*G[{1}, yu^(-1)]*G[{1}, yv^(-1)]^3*G[{1/(yu*yv)}, yw])/3 - 
     (Pi^2*G[{0}, yu^(-1)]*G[{1}, yw]*G[{1/(yu*yv)}, yw])/3 - 
     (Pi^2*G[{0}, yv^(-1)]*G[{1}, yw]*G[{1/(yu*yv)}, yw])/3 + 
     (Pi^2*G[{0}, yw]*G[{1}, yw]*G[{1/(yu*yv)}, yw])/3 - 
     4*G[{0}, yu^(-1)]*G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*G[{1}, yw]*
      G[{1/(yu*yv)}, yw] - 4*G[{0}, yv^(-1)]*G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*
      G[{1}, yw]*G[{1/(yu*yv)}, yw] + 4*G[{0}, yw]*G[{1}, yu^(-1)]*
      G[{1}, yv^(-1)]*G[{1}, yw]*G[{1/(yu*yv)}, yw] + 
     4*G[{1}, yu^(-1)]^2*G[{1}, yv^(-1)]*G[{1}, yw]*G[{1/(yu*yv)}, yw] + 
     2*G[{1}, yu^(-1)]*G[{1}, yv^(-1)]^2*G[{1}, yw]*G[{1/(yu*yv)}, yw] - 
     (Pi^2*G[{1}, yw]^2*G[{1/(yu*yv)}, yw])/3 - 2*G[{1}, yu^(-1)]*
      G[{1}, yv^(-1)]*G[{1}, yw]^2*G[{1/(yu*yv)}, yw] + 
     (2*G[{0}, yu^(-1)]*G[{1}, yw]^3*G[{1/(yu*yv)}, yw])/3 + 
     (2*G[{0}, yv^(-1)]*G[{1}, yw]^3*G[{1/(yu*yv)}, yw])/3 - 
     (2*G[{0}, yw]*G[{1}, yw]^3*G[{1/(yu*yv)}, yw])/3 - 
     (2*G[{1}, yu^(-1)]*G[{1}, yw]^3*G[{1/(yu*yv)}, yw])/3 - 
     (2*G[{1}, yv^(-1)]*G[{1}, yw]^3*G[{1/(yu*yv)}, yw])/3 + 
     (2*Pi^2*G[{1}, yw]*G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw])/3 + 
     4*G[{0}, yu^(-1)]*G[{1}, yu^(-1)]*G[{1}, yw]*G[{yu}, yv^(-1)]*
      G[{1/(yu*yv)}, yw] + 4*G[{0}, yv^(-1)]*G[{1}, yu^(-1)]*G[{1}, yw]*
      G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw] - 4*G[{0}, yw]*G[{1}, yu^(-1)]*
      G[{1}, yw]*G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw] - 
     4*G[{1}, yu^(-1)]^2*G[{1}, yw]*G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw] + 
     4*G[{0}, yu^(-1)]*G[{1}, yv^(-1)]*G[{1}, yw]*G[{yu}, yv^(-1)]*
      G[{1/(yu*yv)}, yw] + 4*G[{0}, yv^(-1)]*G[{1}, yv^(-1)]*G[{1}, yw]*
      G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw] - 4*G[{0}, yw]*G[{1}, yv^(-1)]*
      G[{1}, yw]*G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw] - 
     4*G[{1}, yv^(-1)]^2*G[{1}, yw]*G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw] + 
     2*G[{1}, yu^(-1)]*G[{1}, yw]^2*G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw] + 
     2*G[{1}, yv^(-1)]*G[{1}, yw]^2*G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw] - 
     4*G[{0}, yu^(-1)]*G[{1}, yw]*G[{yu}, yv^(-1)]^2*G[{1/(yu*yv)}, yw] - 
     4*G[{0}, yv^(-1)]*G[{1}, yw]*G[{yu}, yv^(-1)]^2*G[{1/(yu*yv)}, yw] + 
     4*G[{0}, yw]*G[{1}, yw]*G[{yu}, yv^(-1)]^2*G[{1/(yu*yv)}, yw] - 
     2*G[{1}, yw]^2*G[{yu}, yv^(-1)]^2*G[{1/(yu*yv)}, yw] + 
     (8*G[{1}, yw]*G[{yu}, yv^(-1)]^3*G[{1/(yu*yv)}, yw])/3 - 
     (Pi^2*G[{0}, yu^(-1)]*G[{1/(yu*yv)}, yw]^2)/6 - 
     (Pi^2*G[{0}, yv^(-1)]*G[{1/(yu*yv)}, yw]^2)/6 + 
     (Pi^2*G[{0}, yw]*G[{1/(yu*yv)}, yw]^2)/6 + 
     (Pi^2*G[{1}, yu^(-1)]*G[{1/(yu*yv)}, yw]^2)/3 + 
     (Pi^2*G[{1}, yv^(-1)]*G[{1/(yu*yv)}, yw]^2)/3 + 
     2*G[{0}, yu^(-1)]*G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*G[{1/(yu*yv)}, yw]^2 + 
     2*G[{0}, yv^(-1)]*G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*G[{1/(yu*yv)}, yw]^2 - 
     2*G[{0}, yw]*G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*G[{1/(yu*yv)}, yw]^2 - 
     2*G[{1}, yu^(-1)]^2*G[{1}, yv^(-1)]*G[{1/(yu*yv)}, yw]^2 - 
     G[{1}, yu^(-1)]*G[{1}, yv^(-1)]^2*G[{1/(yu*yv)}, yw]^2 + 
     (Pi^2*G[{1}, yw]*G[{1/(yu*yv)}, yw]^2)/3 + 2*G[{0}, yu^(-1)]*
      G[{1}, yu^(-1)]*G[{1}, yw]*G[{1/(yu*yv)}, yw]^2 + 
     2*G[{0}, yv^(-1)]*G[{1}, yu^(-1)]*G[{1}, yw]*G[{1/(yu*yv)}, yw]^2 - 
     2*G[{0}, yw]*G[{1}, yu^(-1)]*G[{1}, yw]*G[{1/(yu*yv)}, yw]^2 - 
     2*G[{1}, yu^(-1)]^2*G[{1}, yw]*G[{1/(yu*yv)}, yw]^2 + 
     2*G[{0}, yu^(-1)]*G[{1}, yv^(-1)]*G[{1}, yw]*G[{1/(yu*yv)}, yw]^2 + 
     2*G[{0}, yv^(-1)]*G[{1}, yv^(-1)]*G[{1}, yw]*G[{1/(yu*yv)}, yw]^2 - 
     2*G[{0}, yw]*G[{1}, yv^(-1)]*G[{1}, yw]*G[{1/(yu*yv)}, yw]^2 - 
     2*G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*G[{1}, yw]*G[{1/(yu*yv)}, yw]^2 - 
     2*G[{1}, yv^(-1)]^2*G[{1}, yw]*G[{1/(yu*yv)}, yw]^2 + 
     G[{0}, yu^(-1)]*G[{1}, yw]^2*G[{1/(yu*yv)}, yw]^2 + 
     G[{0}, yv^(-1)]*G[{1}, yw]^2*G[{1/(yu*yv)}, yw]^2 - 
     G[{0}, yw]*G[{1}, yw]^2*G[{1/(yu*yv)}, yw]^2 - 
     G[{1}, yu^(-1)]*G[{1}, yw]^2*G[{1/(yu*yv)}, yw]^2 - 
     G[{1}, yv^(-1)]*G[{1}, yw]^2*G[{1/(yu*yv)}, yw]^2 - 
     (Pi^2*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2)/3 - 
     2*G[{0}, yu^(-1)]*G[{1}, yu^(-1)]*G[{yu^(-1)}, yw]*
      G[{1/(yu*yv)}, yw]^2 - 2*G[{0}, yv^(-1)]*G[{1}, yu^(-1)]*
      G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2 + 2*G[{0}, yw]*G[{1}, yu^(-1)]*
      G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2 + 2*G[{1}, yu^(-1)]^2*
      G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2 + 2*G[{0}, yu^(-1)]*
      G[{1}, yv^(-1)]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2 + 
     2*G[{0}, yv^(-1)]*G[{1}, yv^(-1)]*G[{yu^(-1)}, yw]*
      G[{1/(yu*yv)}, yw]^2 - 2*G[{0}, yw]*G[{1}, yv^(-1)]*G[{yu^(-1)}, yw]*
      G[{1/(yu*yv)}, yw]^2 - 2*G[{1}, yv^(-1)]^2*G[{yu^(-1)}, yw]*
      G[{1/(yu*yv)}, yw]^2 + 2*G[{0}, yu^(-1)]*G[{1}, yw]*G[{yu^(-1)}, yw]*
      G[{1/(yu*yv)}, yw]^2 + 2*G[{0}, yv^(-1)]*G[{1}, yw]*G[{yu^(-1)}, yw]*
      G[{1/(yu*yv)}, yw]^2 - 2*G[{0}, yw]*G[{1}, yw]*G[{yu^(-1)}, yw]*
      G[{1/(yu*yv)}, yw]^2 + 2*G[{1}, yw]^2*G[{yu^(-1)}, yw]*
      G[{1/(yu*yv)}, yw]^2 - 2*G[{0}, yu^(-1)]*G[{yu^(-1)}, yw]^2*
      G[{1/(yu*yv)}, yw]^2 - 2*G[{0}, yv^(-1)]*G[{yu^(-1)}, yw]^2*
      G[{1/(yu*yv)}, yw]^2 + 2*G[{0}, yw]*G[{yu^(-1)}, yw]^2*
      G[{1/(yu*yv)}, yw]^2 + 4*G[{1}, yv^(-1)]*G[{yu^(-1)}, yw]^2*
      G[{1/(yu*yv)}, yw]^2 - (4*G[{yu^(-1)}, yw]^3*G[{1/(yu*yv)}, yw]^2)/3 - 
     (Pi^2*G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw]^2)/3 - 
     2*G[{0}, yu^(-1)]*G[{1}, yu^(-1)]*G[{yu}, yv^(-1)]*
      G[{1/(yu*yv)}, yw]^2 - 2*G[{0}, yv^(-1)]*G[{1}, yu^(-1)]*
      G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw]^2 + 2*G[{0}, yw]*G[{1}, yu^(-1)]*
      G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw]^2 + 2*G[{1}, yu^(-1)]^2*
      G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw]^2 - 2*G[{0}, yu^(-1)]*
      G[{1}, yv^(-1)]*G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw]^2 - 
     2*G[{0}, yv^(-1)]*G[{1}, yv^(-1)]*G[{yu}, yv^(-1)]*
      G[{1/(yu*yv)}, yw]^2 + 2*G[{0}, yw]*G[{1}, yv^(-1)]*G[{yu}, yv^(-1)]*
      G[{1/(yu*yv)}, yw]^2 + 2*G[{1}, yv^(-1)]^2*G[{yu}, yv^(-1)]*
      G[{1/(yu*yv)}, yw]^2 - 4*G[{0}, yu^(-1)]*G[{1}, yw]*G[{yu}, yv^(-1)]*
      G[{1/(yu*yv)}, yw]^2 - 4*G[{0}, yv^(-1)]*G[{1}, yw]*G[{yu}, yv^(-1)]*
      G[{1/(yu*yv)}, yw]^2 + 4*G[{0}, yw]*G[{1}, yw]*G[{yu}, yv^(-1)]*
      G[{1/(yu*yv)}, yw]^2 + 2*G[{1}, yu^(-1)]*G[{1}, yw]*G[{yu}, yv^(-1)]*
      G[{1/(yu*yv)}, yw]^2 + 2*G[{1}, yv^(-1)]*G[{1}, yw]*G[{yu}, yv^(-1)]*
      G[{1/(yu*yv)}, yw]^2 - 4*G[{1}, yw]*G[{yu^(-1)}, yw]*G[{yu}, yv^(-1)]*
      G[{1/(yu*yv)}, yw]^2 + 2*G[{0}, yu^(-1)]*G[{yu}, yv^(-1)]^2*
      G[{1/(yu*yv)}, yw]^2 + 2*G[{0}, yv^(-1)]*G[{yu}, yv^(-1)]^2*
      G[{1/(yu*yv)}, yw]^2 - 2*G[{0}, yw]*G[{yu}, yv^(-1)]^2*
      G[{1/(yu*yv)}, yw]^2 + 2*G[{1}, yw]*G[{yu}, yv^(-1)]^2*
      G[{1/(yu*yv)}, yw]^2 - (4*G[{yu}, yv^(-1)]^3*G[{1/(yu*yv)}, yw]^2)/3 - 
     (Pi^2*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2)/3 + 
     2*G[{0}, yu^(-1)]*G[{1}, yu^(-1)]*G[{yv^(-1)}, yw]*
      G[{1/(yu*yv)}, yw]^2 + 2*G[{0}, yv^(-1)]*G[{1}, yu^(-1)]*
      G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2 - 2*G[{0}, yw]*G[{1}, yu^(-1)]*
      G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2 - 2*G[{1}, yu^(-1)]^2*
      G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2 - 2*G[{0}, yu^(-1)]*
      G[{1}, yv^(-1)]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2 - 
     2*G[{0}, yv^(-1)]*G[{1}, yv^(-1)]*G[{yv^(-1)}, yw]*
      G[{1/(yu*yv)}, yw]^2 + 2*G[{0}, yw]*G[{1}, yv^(-1)]*G[{yv^(-1)}, yw]*
      G[{1/(yu*yv)}, yw]^2 + 2*G[{1}, yv^(-1)]^2*G[{yv^(-1)}, yw]*
      G[{1/(yu*yv)}, yw]^2 + 2*G[{0}, yu^(-1)]*G[{1}, yw]*G[{yv^(-1)}, yw]*
      G[{1/(yu*yv)}, yw]^2 + 2*G[{0}, yv^(-1)]*G[{1}, yw]*G[{yv^(-1)}, yw]*
      G[{1/(yu*yv)}, yw]^2 - 2*G[{0}, yw]*G[{1}, yw]*G[{yv^(-1)}, yw]*
      G[{1/(yu*yv)}, yw]^2 + 2*G[{1}, yw]^2*G[{yv^(-1)}, yw]*
      G[{1/(yu*yv)}, yw]^2 - 4*G[{1}, yw]*G[{yu}, yv^(-1)]*G[{yv^(-1)}, yw]*
      G[{1/(yu*yv)}, yw]^2 - 2*G[{0}, yu^(-1)]*G[{yv^(-1)}, yw]^2*
      G[{1/(yu*yv)}, yw]^2 - 2*G[{0}, yv^(-1)]*G[{yv^(-1)}, yw]^2*
      G[{1/(yu*yv)}, yw]^2 + 2*G[{0}, yw]*G[{yv^(-1)}, yw]^2*
      G[{1/(yu*yv)}, yw]^2 + 4*G[{1}, yu^(-1)]*G[{yv^(-1)}, yw]^2*
      G[{1/(yu*yv)}, yw]^2 - (4*G[{yv^(-1)}, yw]^3*G[{1/(yu*yv)}, yw]^2)/3 - 
     (2*G[{0}, yu^(-1)]*G[{1}, yu^(-1)]*G[{1/(yu*yv)}, yw]^3)/3 - 
     (2*G[{0}, yv^(-1)]*G[{1}, yu^(-1)]*G[{1/(yu*yv)}, yw]^3)/3 + 
     (2*G[{0}, yw]*G[{1}, yu^(-1)]*G[{1/(yu*yv)}, yw]^3)/3 + 
     (2*G[{1}, yu^(-1)]^2*G[{1/(yu*yv)}, yw]^3)/3 - 
     (2*G[{0}, yu^(-1)]*G[{1}, yv^(-1)]*G[{1/(yu*yv)}, yw]^3)/3 - 
     (2*G[{0}, yv^(-1)]*G[{1}, yv^(-1)]*G[{1/(yu*yv)}, yw]^3)/3 + 
     (2*G[{0}, yw]*G[{1}, yv^(-1)]*G[{1/(yu*yv)}, yw]^3)/3 + 
     2*G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*G[{1/(yu*yv)}, yw]^3 + 
     (2*G[{1}, yv^(-1)]^2*G[{1/(yu*yv)}, yw]^3)/3 - 
     (4*G[{0}, yu^(-1)]*G[{1}, yw]*G[{1/(yu*yv)}, yw]^3)/3 - 
     (4*G[{0}, yv^(-1)]*G[{1}, yw]*G[{1/(yu*yv)}, yw]^3)/3 + 
     (4*G[{0}, yw]*G[{1}, yw]*G[{1/(yu*yv)}, yw]^3)/3 + 
     2*G[{1}, yu^(-1)]*G[{1}, yw]*G[{1/(yu*yv)}, yw]^3 + 
     2*G[{1}, yv^(-1)]*G[{1}, yw]*G[{1/(yu*yv)}, yw]^3 + 
     (2*G[{1}, yw]^2*G[{1/(yu*yv)}, yw]^3)/3 + 
     (2*G[{0}, yu^(-1)]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]^3)/3 + 
     (2*G[{0}, yv^(-1)]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]^3)/3 - 
     (2*G[{0}, yw]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]^3)/3 - 
     2*G[{1}, yu^(-1)]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]^3 - 
     (4*G[{1}, yv^(-1)]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]^3)/3 - 
     2*G[{1}, yw]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]^3 + 
     (2*G[{yu^(-1)}, yw]^2*G[{1/(yu*yv)}, yw]^3)/3 + 
     (4*G[{0}, yu^(-1)]*G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw]^3)/3 + 
     (4*G[{0}, yv^(-1)]*G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw]^3)/3 - 
     (4*G[{0}, yw]*G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw]^3)/3 - 
     2*G[{1}, yu^(-1)]*G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw]^3 - 
     2*G[{1}, yv^(-1)]*G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw]^3 - 
     (4*G[{1}, yw]*G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw]^3)/3 + 
     2*G[{yu^(-1)}, yw]*G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw]^3 + 
     (2*G[{yu}, yv^(-1)]^2*G[{1/(yu*yv)}, yw]^3)/3 + 
     (2*G[{0}, yu^(-1)]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]^3)/3 + 
     (2*G[{0}, yv^(-1)]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]^3)/3 - 
     (2*G[{0}, yw]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]^3)/3 - 
     (4*G[{1}, yu^(-1)]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]^3)/3 - 
     2*G[{1}, yv^(-1)]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]^3 - 
     2*G[{1}, yw]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]^3 + 
     2*G[{yu^(-1)}, yw]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]^3 + 
     2*G[{yu}, yv^(-1)]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]^3 + 
     (2*G[{yv^(-1)}, yw]^2*G[{1/(yu*yv)}, yw]^3)/3 + 
     (Pi^2*G[{0}, yu^(-1)]*G[{0, 1}, yu^(-1)])/3 + 
     (Pi^2*G[{0}, yv^(-1)]*G[{0, 1}, yu^(-1)])/3 - 
     (Pi^2*G[{0}, yw]*G[{0, 1}, yu^(-1)])/3 - 
     (Pi^2*G[{1}, yu^(-1)]*G[{0, 1}, yu^(-1)])/3 - 
     G[{0}, yu^(-1)]*G[{1}, yu^(-1)]^2*G[{0, 1}, yu^(-1)] - 
     G[{0}, yv^(-1)]*G[{1}, yu^(-1)]^2*G[{0, 1}, yu^(-1)] + 
     G[{0}, yw]*G[{1}, yu^(-1)]^2*G[{0, 1}, yu^(-1)] + 
     (2*G[{1}, yu^(-1)]^3*G[{0, 1}, yu^(-1)])/3 - 
     (Pi^2*G[{1}, yv^(-1)]*G[{0, 1}, yu^(-1)])/3 + 
     2*G[{0}, yu^(-1)]*G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*G[{0, 1}, yu^(-1)] + 
     2*G[{0}, yv^(-1)]*G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*G[{0, 1}, yu^(-1)] - 
     2*G[{0}, yw]*G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*G[{0, 1}, yu^(-1)] - 
     G[{0}, yu^(-1)]*G[{1}, yv^(-1)]^2*G[{0, 1}, yu^(-1)] - 
     G[{0}, yv^(-1)]*G[{1}, yv^(-1)]^2*G[{0, 1}, yu^(-1)] + 
     G[{0}, yw]*G[{1}, yv^(-1)]^2*G[{0, 1}, yu^(-1)] - 
     2*G[{1}, yu^(-1)]*G[{1}, yv^(-1)]^2*G[{0, 1}, yu^(-1)] + 
     (2*G[{1}, yv^(-1)]^3*G[{0, 1}, yu^(-1)])/3 + 
     (Pi^2*G[{1}, yw]*G[{0, 1}, yu^(-1)])/3 - 2*G[{0}, yu^(-1)]*
      G[{1}, yu^(-1)]*G[{1}, yw]*G[{0, 1}, yu^(-1)] - 
     2*G[{0}, yv^(-1)]*G[{1}, yu^(-1)]*G[{1}, yw]*G[{0, 1}, yu^(-1)] + 
     2*G[{0}, yw]*G[{1}, yu^(-1)]*G[{1}, yw]*G[{0, 1}, yu^(-1)] - 
     2*G[{0}, yu^(-1)]*G[{1}, yv^(-1)]*G[{1}, yw]*G[{0, 1}, yu^(-1)] - 
     2*G[{0}, yv^(-1)]*G[{1}, yv^(-1)]*G[{1}, yw]*G[{0, 1}, yu^(-1)] + 
     2*G[{0}, yw]*G[{1}, yv^(-1)]*G[{1}, yw]*G[{0, 1}, yu^(-1)] + 
     4*G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*G[{1}, yw]*G[{0, 1}, yu^(-1)] + 
     3*G[{0}, yu^(-1)]*G[{1}, yw]^2*G[{0, 1}, yu^(-1)] + 
     3*G[{0}, yv^(-1)]*G[{1}, yw]^2*G[{0, 1}, yu^(-1)] - 
     3*G[{0}, yw]*G[{1}, yw]^2*G[{0, 1}, yu^(-1)] - 
     2*G[{1}, yu^(-1)]*G[{1}, yw]^2*G[{0, 1}, yu^(-1)] - 
     2*G[{1}, yv^(-1)]*G[{1}, yw]^2*G[{0, 1}, yu^(-1)] + 
     (2*G[{1}, yw]^3*G[{0, 1}, yu^(-1)])/3 - 2*G[{1}, yw]^2*G[{yu}, yv^(-1)]*
      G[{0, 1}, yu^(-1)] + (Pi^2*G[{1/(yu*yv)}, yw]*G[{0, 1}, yu^(-1)])/3 + 
     2*G[{0}, yu^(-1)]*G[{1}, yu^(-1)]*G[{1/(yu*yv)}, yw]*
      G[{0, 1}, yu^(-1)] + 2*G[{0}, yv^(-1)]*G[{1}, yu^(-1)]*
      G[{1/(yu*yv)}, yw]*G[{0, 1}, yu^(-1)] - 2*G[{0}, yw]*G[{1}, yu^(-1)]*
      G[{1/(yu*yv)}, yw]*G[{0, 1}, yu^(-1)] - 2*G[{1}, yu^(-1)]^2*
      G[{1/(yu*yv)}, yw]*G[{0, 1}, yu^(-1)] + 2*G[{0}, yu^(-1)]*
      G[{1}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, 1}, yu^(-1)] + 
     2*G[{0}, yv^(-1)]*G[{1}, yv^(-1)]*G[{1/(yu*yv)}, yw]*
      G[{0, 1}, yu^(-1)] - 2*G[{0}, yw]*G[{1}, yv^(-1)]*G[{1/(yu*yv)}, yw]*
      G[{0, 1}, yu^(-1)] - 2*G[{1}, yv^(-1)]^2*G[{1/(yu*yv)}, yw]*
      G[{0, 1}, yu^(-1)] - 2*G[{0}, yu^(-1)]*G[{1}, yw]*G[{1/(yu*yv)}, yw]*
      G[{0, 1}, yu^(-1)] - 2*G[{0}, yv^(-1)]*G[{1}, yw]*G[{1/(yu*yv)}, yw]*
      G[{0, 1}, yu^(-1)] + 2*G[{0}, yw]*G[{1}, yw]*G[{1/(yu*yv)}, yw]*
      G[{0, 1}, yu^(-1)] - 2*G[{1}, yw]^2*G[{1/(yu*yv)}, yw]*
      G[{0, 1}, yu^(-1)] + 4*G[{1}, yw]*G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw]*
      G[{0, 1}, yu^(-1)] - G[{0}, yu^(-1)]*G[{1/(yu*yv)}, yw]^2*
      G[{0, 1}, yu^(-1)] - G[{0}, yv^(-1)]*G[{1/(yu*yv)}, yw]^2*
      G[{0, 1}, yu^(-1)] + G[{0}, yw]*G[{1/(yu*yv)}, yw]^2*
      G[{0, 1}, yu^(-1)] + 2*G[{1}, yu^(-1)]*G[{1/(yu*yv)}, yw]^2*
      G[{0, 1}, yu^(-1)] + 2*G[{1}, yv^(-1)]*G[{1/(yu*yv)}, yw]^2*
      G[{0, 1}, yu^(-1)] + 2*G[{1}, yw]*G[{1/(yu*yv)}, yw]^2*
      G[{0, 1}, yu^(-1)] - 2*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2*
      G[{0, 1}, yu^(-1)] - 2*G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw]^2*
      G[{0, 1}, yu^(-1)] - 2*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2*
      G[{0, 1}, yu^(-1)] + G[{0}, yu^(-1)]*G[{0, 1}, yu^(-1)]^2 + 
     G[{0}, yv^(-1)]*G[{0, 1}, yu^(-1)]^2 - G[{0}, yw]*G[{0, 1}, yu^(-1)]^2 - 
     G[{1}, yu^(-1)]*G[{0, 1}, yu^(-1)]^2 - G[{1}, yv^(-1)]*
      G[{0, 1}, yu^(-1)]^2 + G[{1}, yw]*G[{0, 1}, yu^(-1)]^2 + 
     G[{1/(yu*yv)}, yw]*G[{0, 1}, yu^(-1)]^2 + 
     (Pi^2*G[{0}, yu^(-1)]*G[{0, 1}, yv^(-1)])/3 + 
     (Pi^2*G[{0}, yv^(-1)]*G[{0, 1}, yv^(-1)])/3 - 
     (Pi^2*G[{0}, yw]*G[{0, 1}, yv^(-1)])/3 - 
     (Pi^2*G[{1}, yv^(-1)]*G[{0, 1}, yv^(-1)])/3 + 
     2*G[{0}, yu^(-1)]*G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*G[{0, 1}, yv^(-1)] + 
     2*G[{0}, yv^(-1)]*G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*G[{0, 1}, yv^(-1)] - 
     2*G[{0}, yw]*G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*G[{0, 1}, yv^(-1)] - 
     2*G[{1}, yu^(-1)]^2*G[{1}, yv^(-1)]*G[{0, 1}, yv^(-1)] - 
     G[{0}, yu^(-1)]*G[{1}, yv^(-1)]^2*G[{0, 1}, yv^(-1)] - 
     G[{0}, yv^(-1)]*G[{1}, yv^(-1)]^2*G[{0, 1}, yv^(-1)] + 
     G[{0}, yw]*G[{1}, yv^(-1)]^2*G[{0, 1}, yv^(-1)] - 
     2*G[{1}, yu^(-1)]*G[{1}, yv^(-1)]^2*G[{0, 1}, yv^(-1)] + 
     (2*G[{1}, yv^(-1)]^3*G[{0, 1}, yv^(-1)])/3 + 
     (Pi^2*G[{1}, yw]*G[{0, 1}, yv^(-1)])/3 - 2*G[{0}, yu^(-1)]*
      G[{1}, yu^(-1)]*G[{1}, yw]*G[{0, 1}, yv^(-1)] - 
     2*G[{0}, yv^(-1)]*G[{1}, yu^(-1)]*G[{1}, yw]*G[{0, 1}, yv^(-1)] + 
     2*G[{0}, yw]*G[{1}, yu^(-1)]*G[{1}, yw]*G[{0, 1}, yv^(-1)] + 
     2*G[{1}, yu^(-1)]^2*G[{1}, yw]*G[{0, 1}, yv^(-1)] - 
     2*G[{0}, yu^(-1)]*G[{1}, yv^(-1)]*G[{1}, yw]*G[{0, 1}, yv^(-1)] - 
     2*G[{0}, yv^(-1)]*G[{1}, yv^(-1)]*G[{1}, yw]*G[{0, 1}, yv^(-1)] + 
     2*G[{0}, yw]*G[{1}, yv^(-1)]*G[{1}, yw]*G[{0, 1}, yv^(-1)] + 
     4*G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*G[{1}, yw]*G[{0, 1}, yv^(-1)] + 
     3*G[{0}, yu^(-1)]*G[{1}, yw]^2*G[{0, 1}, yv^(-1)] + 
     3*G[{0}, yv^(-1)]*G[{1}, yw]^2*G[{0, 1}, yv^(-1)] - 
     3*G[{0}, yw]*G[{1}, yw]^2*G[{0, 1}, yv^(-1)] - 
     2*G[{1}, yu^(-1)]*G[{1}, yw]^2*G[{0, 1}, yv^(-1)] - 
     2*G[{1}, yv^(-1)]*G[{1}, yw]^2*G[{0, 1}, yv^(-1)] + 
     (2*G[{1}, yw]^3*G[{0, 1}, yv^(-1)])/3 - 2*G[{1}, yw]^2*G[{yu}, yv^(-1)]*
      G[{0, 1}, yv^(-1)] + (Pi^2*G[{1/(yu*yv)}, yw]*G[{0, 1}, yv^(-1)])/3 + 
     2*G[{0}, yu^(-1)]*G[{1}, yu^(-1)]*G[{1/(yu*yv)}, yw]*
      G[{0, 1}, yv^(-1)] + 2*G[{0}, yv^(-1)]*G[{1}, yu^(-1)]*
      G[{1/(yu*yv)}, yw]*G[{0, 1}, yv^(-1)] - 2*G[{0}, yw]*G[{1}, yu^(-1)]*
      G[{1/(yu*yv)}, yw]*G[{0, 1}, yv^(-1)] - 2*G[{1}, yu^(-1)]^2*
      G[{1/(yu*yv)}, yw]*G[{0, 1}, yv^(-1)] + 2*G[{0}, yu^(-1)]*
      G[{1}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, 1}, yv^(-1)] + 
     2*G[{0}, yv^(-1)]*G[{1}, yv^(-1)]*G[{1/(yu*yv)}, yw]*
      G[{0, 1}, yv^(-1)] - 2*G[{0}, yw]*G[{1}, yv^(-1)]*G[{1/(yu*yv)}, yw]*
      G[{0, 1}, yv^(-1)] - 2*G[{1}, yv^(-1)]^2*G[{1/(yu*yv)}, yw]*
      G[{0, 1}, yv^(-1)] - 2*G[{0}, yu^(-1)]*G[{1}, yw]*G[{1/(yu*yv)}, yw]*
      G[{0, 1}, yv^(-1)] - 2*G[{0}, yv^(-1)]*G[{1}, yw]*G[{1/(yu*yv)}, yw]*
      G[{0, 1}, yv^(-1)] + 2*G[{0}, yw]*G[{1}, yw]*G[{1/(yu*yv)}, yw]*
      G[{0, 1}, yv^(-1)] - 2*G[{1}, yw]^2*G[{1/(yu*yv)}, yw]*
      G[{0, 1}, yv^(-1)] + 4*G[{1}, yw]*G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw]*
      G[{0, 1}, yv^(-1)] - G[{0}, yu^(-1)]*G[{1/(yu*yv)}, yw]^2*
      G[{0, 1}, yv^(-1)] - G[{0}, yv^(-1)]*G[{1/(yu*yv)}, yw]^2*
      G[{0, 1}, yv^(-1)] + G[{0}, yw]*G[{1/(yu*yv)}, yw]^2*
      G[{0, 1}, yv^(-1)] + 2*G[{1}, yu^(-1)]*G[{1/(yu*yv)}, yw]^2*
      G[{0, 1}, yv^(-1)] + 2*G[{1}, yv^(-1)]*G[{1/(yu*yv)}, yw]^2*
      G[{0, 1}, yv^(-1)] + 2*G[{1}, yw]*G[{1/(yu*yv)}, yw]^2*
      G[{0, 1}, yv^(-1)] - 2*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2*
      G[{0, 1}, yv^(-1)] - 2*G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw]^2*
      G[{0, 1}, yv^(-1)] - 2*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2*
      G[{0, 1}, yv^(-1)] + 2*G[{0}, yu^(-1)]*G[{0, 1}, yu^(-1)]*
      G[{0, 1}, yv^(-1)] + 2*G[{0}, yv^(-1)]*G[{0, 1}, yu^(-1)]*
      G[{0, 1}, yv^(-1)] - 2*G[{0}, yw]*G[{0, 1}, yu^(-1)]*
      G[{0, 1}, yv^(-1)] - 2*G[{1}, yv^(-1)]*G[{0, 1}, yu^(-1)]*
      G[{0, 1}, yv^(-1)] + 2*G[{1}, yw]*G[{0, 1}, yu^(-1)]*
      G[{0, 1}, yv^(-1)] + 2*G[{1/(yu*yv)}, yw]*G[{0, 1}, yu^(-1)]*
      G[{0, 1}, yv^(-1)] + G[{0}, yu^(-1)]*G[{0, 1}, yv^(-1)]^2 + 
     G[{0}, yv^(-1)]*G[{0, 1}, yv^(-1)]^2 - G[{0}, yw]*G[{0, 1}, yv^(-1)]^2 - 
     G[{1}, yv^(-1)]*G[{0, 1}, yv^(-1)]^2 + G[{1}, yw]*G[{0, 1}, yv^(-1)]^2 + 
     G[{1/(yu*yv)}, yw]*G[{0, 1}, yv^(-1)]^2 - 
     (Pi^2*G[{0}, yu^(-1)]*G[{0, 1}, yw])/3 - 
     (Pi^2*G[{0}, yv^(-1)]*G[{0, 1}, yw])/3 + (Pi^2*G[{0}, yw]*G[{0, 1}, yw])/
      3 + Pi^2*G[{1}, yw]*G[{0, 1}, yw] + 2*G[{0}, yu^(-1)]*G[{1}, yu^(-1)]*
      G[{1}, yw]*G[{0, 1}, yw] + 2*G[{0}, yv^(-1)]*G[{1}, yu^(-1)]*G[{1}, yw]*
      G[{0, 1}, yw] - 2*G[{0}, yw]*G[{1}, yu^(-1)]*G[{1}, yw]*G[{0, 1}, yw] - 
     2*G[{1}, yu^(-1)]^2*G[{1}, yw]*G[{0, 1}, yw] + 
     2*G[{0}, yu^(-1)]*G[{1}, yv^(-1)]*G[{1}, yw]*G[{0, 1}, yw] + 
     2*G[{0}, yv^(-1)]*G[{1}, yv^(-1)]*G[{1}, yw]*G[{0, 1}, yw] - 
     2*G[{0}, yw]*G[{1}, yv^(-1)]*G[{1}, yw]*G[{0, 1}, yw] - 
     2*G[{1}, yv^(-1)]^2*G[{1}, yw]*G[{0, 1}, yw] + 
     3*G[{0}, yu^(-1)]*G[{1}, yw]^2*G[{0, 1}, yw] + 
     3*G[{0}, yv^(-1)]*G[{1}, yw]^2*G[{0, 1}, yw] - 
     3*G[{0}, yw]*G[{1}, yw]^2*G[{0, 1}, yw] - 4*G[{1}, yu^(-1)]*G[{1}, yw]^2*
      G[{0, 1}, yw] - 4*G[{1}, yv^(-1)]*G[{1}, yw]^2*G[{0, 1}, yw] - 
     (2*G[{1}, yw]^3*G[{0, 1}, yw])/3 - 4*G[{0}, yu^(-1)]*G[{1}, yw]*
      G[{yu}, yv^(-1)]*G[{0, 1}, yw] - 4*G[{0}, yv^(-1)]*G[{1}, yw]*
      G[{yu}, yv^(-1)]*G[{0, 1}, yw] + 4*G[{0}, yw]*G[{1}, yw]*
      G[{yu}, yv^(-1)]*G[{0, 1}, yw] + 2*G[{1}, yw]^2*G[{yu}, yv^(-1)]*
      G[{0, 1}, yw] + 4*G[{1}, yw]*G[{yu}, yv^(-1)]^2*G[{0, 1}, yw] - 
     (Pi^2*G[{1/(yu*yv)}, yw]*G[{0, 1}, yw])/3 - 2*G[{0}, yu^(-1)]*
      G[{1}, yu^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, 1}, yw] - 
     2*G[{0}, yv^(-1)]*G[{1}, yu^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, 1}, yw] + 
     2*G[{0}, yw]*G[{1}, yu^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, 1}, yw] + 
     2*G[{1}, yu^(-1)]^2*G[{1/(yu*yv)}, yw]*G[{0, 1}, yw] - 
     2*G[{0}, yu^(-1)]*G[{1}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, 1}, yw] - 
     2*G[{0}, yv^(-1)]*G[{1}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, 1}, yw] + 
     2*G[{0}, yw]*G[{1}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, 1}, yw] + 
     2*G[{1}, yv^(-1)]^2*G[{1/(yu*yv)}, yw]*G[{0, 1}, yw] - 
     2*G[{0}, yu^(-1)]*G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1}, yw] - 
     2*G[{0}, yv^(-1)]*G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1}, yw] + 
     2*G[{0}, yw]*G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1}, yw] + 
     4*G[{1}, yu^(-1)]*G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1}, yw] + 
     4*G[{1}, yv^(-1)]*G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1}, yw] + 
     2*G[{1}, yw]^2*G[{1/(yu*yv)}, yw]*G[{0, 1}, yw] + 
     4*G[{0}, yu^(-1)]*G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, 1}, yw] + 
     4*G[{0}, yv^(-1)]*G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, 1}, yw] - 
     4*G[{0}, yw]*G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, 1}, yw] - 
     4*G[{1}, yw]*G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, 1}, yw] - 
     4*G[{yu}, yv^(-1)]^2*G[{1/(yu*yv)}, yw]*G[{0, 1}, yw] - 
     G[{0}, yu^(-1)]*G[{1/(yu*yv)}, yw]^2*G[{0, 1}, yw] - 
     G[{0}, yv^(-1)]*G[{1/(yu*yv)}, yw]^2*G[{0, 1}, yw] + 
     G[{0}, yw]*G[{1/(yu*yv)}, yw]^2*G[{0, 1}, yw] - 
     2*G[{1}, yw]*G[{1/(yu*yv)}, yw]^2*G[{0, 1}, yw] + 
     2*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2*G[{0, 1}, yw] + 
     2*G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw]^2*G[{0, 1}, yw] + 
     2*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2*G[{0, 1}, yw] - 
     2*G[{0}, yu^(-1)]*G[{0, 1}, yu^(-1)]*G[{0, 1}, yw] - 
     2*G[{0}, yv^(-1)]*G[{0, 1}, yu^(-1)]*G[{0, 1}, yw] + 
     2*G[{0}, yw]*G[{0, 1}, yu^(-1)]*G[{0, 1}, yw] + 
     6*G[{1}, yw]*G[{0, 1}, yu^(-1)]*G[{0, 1}, yw] - 
     2*G[{1/(yu*yv)}, yw]*G[{0, 1}, yu^(-1)]*G[{0, 1}, yw] - 
     2*G[{0}, yu^(-1)]*G[{0, 1}, yv^(-1)]*G[{0, 1}, yw] - 
     2*G[{0}, yv^(-1)]*G[{0, 1}, yv^(-1)]*G[{0, 1}, yw] + 
     2*G[{0}, yw]*G[{0, 1}, yv^(-1)]*G[{0, 1}, yw] + 
     6*G[{1}, yw]*G[{0, 1}, yv^(-1)]*G[{0, 1}, yw] - 
     2*G[{1/(yu*yv)}, yw]*G[{0, 1}, yv^(-1)]*G[{0, 1}, yw] - 
     G[{0}, yu^(-1)]*G[{0, 1}, yw]^2 - G[{0}, yv^(-1)]*G[{0, 1}, yw]^2 + 
     G[{0}, yw]*G[{0, 1}, yw]^2 - 3*G[{1}, yw]*G[{0, 1}, yw]^2 + 
     2*G[{yu}, yv^(-1)]*G[{0, 1}, yw]^2 + G[{1/(yu*yv)}, yw]*
      G[{0, 1}, yw]^2 - (Pi^2*G[{1}, yw]*G[{0, yu^(-1)}, yw])/3 - 
     2*G[{0}, yu^(-1)]*G[{1}, yu^(-1)]*G[{1}, yw]*G[{0, yu^(-1)}, yw] - 
     2*G[{0}, yv^(-1)]*G[{1}, yu^(-1)]*G[{1}, yw]*G[{0, yu^(-1)}, yw] + 
     2*G[{0}, yw]*G[{1}, yu^(-1)]*G[{1}, yw]*G[{0, yu^(-1)}, yw] + 
     2*G[{1}, yu^(-1)]^2*G[{1}, yw]*G[{0, yu^(-1)}, yw] + 
     2*G[{0}, yu^(-1)]*G[{1}, yv^(-1)]*G[{1}, yw]*G[{0, yu^(-1)}, yw] + 
     2*G[{0}, yv^(-1)]*G[{1}, yv^(-1)]*G[{1}, yw]*G[{0, yu^(-1)}, yw] - 
     2*G[{0}, yw]*G[{1}, yv^(-1)]*G[{1}, yw]*G[{0, yu^(-1)}, yw] - 
     2*G[{1}, yv^(-1)]^2*G[{1}, yw]*G[{0, yu^(-1)}, yw] - 
     3*G[{0}, yu^(-1)]*G[{1}, yw]^2*G[{0, yu^(-1)}, yw] - 
     3*G[{0}, yv^(-1)]*G[{1}, yw]^2*G[{0, yu^(-1)}, yw] + 
     3*G[{0}, yw]*G[{1}, yw]^2*G[{0, yu^(-1)}, yw] + 
     4*G[{1}, yu^(-1)]*G[{1}, yw]^2*G[{0, yu^(-1)}, yw] + 
     4*G[{1}, yv^(-1)]*G[{1}, yw]^2*G[{0, yu^(-1)}, yw] + 
     (2*G[{1}, yw]^3*G[{0, yu^(-1)}, yw])/3 - 2*G[{1}, yw]^2*G[{yu}, yv^(-1)]*
      G[{0, yu^(-1)}, yw] + (Pi^2*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1)}, yw])/3 + 
     2*G[{0}, yu^(-1)]*G[{1}, yu^(-1)]*G[{1/(yu*yv)}, yw]*
      G[{0, yu^(-1)}, yw] + 2*G[{0}, yv^(-1)]*G[{1}, yu^(-1)]*
      G[{1/(yu*yv)}, yw]*G[{0, yu^(-1)}, yw] - 2*G[{0}, yw]*G[{1}, yu^(-1)]*
      G[{1/(yu*yv)}, yw]*G[{0, yu^(-1)}, yw] - 2*G[{1}, yu^(-1)]^2*
      G[{1/(yu*yv)}, yw]*G[{0, yu^(-1)}, yw] - 2*G[{0}, yu^(-1)]*
      G[{1}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1)}, yw] - 
     2*G[{0}, yv^(-1)]*G[{1}, yv^(-1)]*G[{1/(yu*yv)}, yw]*
      G[{0, yu^(-1)}, yw] + 2*G[{0}, yw]*G[{1}, yv^(-1)]*G[{1/(yu*yv)}, yw]*
      G[{0, yu^(-1)}, yw] + 2*G[{1}, yv^(-1)]^2*G[{1/(yu*yv)}, yw]*
      G[{0, yu^(-1)}, yw] + 2*G[{0}, yu^(-1)]*G[{1}, yw]*G[{1/(yu*yv)}, yw]*
      G[{0, yu^(-1)}, yw] + 2*G[{0}, yv^(-1)]*G[{1}, yw]*G[{1/(yu*yv)}, yw]*
      G[{0, yu^(-1)}, yw] - 2*G[{0}, yw]*G[{1}, yw]*G[{1/(yu*yv)}, yw]*
      G[{0, yu^(-1)}, yw] - 4*G[{1}, yu^(-1)]*G[{1}, yw]*G[{1/(yu*yv)}, yw]*
      G[{0, yu^(-1)}, yw] - 4*G[{1}, yv^(-1)]*G[{1}, yw]*G[{1/(yu*yv)}, yw]*
      G[{0, yu^(-1)}, yw] - 2*G[{1}, yw]^2*G[{1/(yu*yv)}, yw]*
      G[{0, yu^(-1)}, yw] + 4*G[{1}, yw]*G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw]*
      G[{0, yu^(-1)}, yw] + G[{0}, yu^(-1)]*G[{1/(yu*yv)}, yw]^2*
      G[{0, yu^(-1)}, yw] + G[{0}, yv^(-1)]*G[{1/(yu*yv)}, yw]^2*
      G[{0, yu^(-1)}, yw] - G[{0}, yw]*G[{1/(yu*yv)}, yw]^2*
      G[{0, yu^(-1)}, yw] + 2*G[{1}, yw]*G[{1/(yu*yv)}, yw]^2*
      G[{0, yu^(-1)}, yw] - 2*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2*
      G[{0, yu^(-1)}, yw] - 2*G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw]^2*
      G[{0, yu^(-1)}, yw] - 2*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2*
      G[{0, yu^(-1)}, yw] - 2*G[{1}, yw]*G[{0, 1}, yu^(-1)]*
      G[{0, yu^(-1)}, yw] + 2*G[{1/(yu*yv)}, yw]*G[{0, 1}, yu^(-1)]*
      G[{0, yu^(-1)}, yw] - 2*G[{1}, yw]*G[{0, 1}, yv^(-1)]*
      G[{0, yu^(-1)}, yw] + 2*G[{1/(yu*yv)}, yw]*G[{0, 1}, yv^(-1)]*
      G[{0, yu^(-1)}, yw] + 2*G[{1}, yw]*G[{0, 1}, yw]*G[{0, yu^(-1)}, yw] - 
     2*G[{1/(yu*yv)}, yw]*G[{0, 1}, yw]*G[{0, yu^(-1)}, yw] - 
     G[{1}, yw]*G[{0, yu^(-1)}, yw]^2 + G[{1/(yu*yv)}, yw]*
      G[{0, yu^(-1)}, yw]^2 - (Pi^2*G[{1}, yv^(-1)]*G[{0, yu}, yv^(-1)])/3 - 
     2*G[{0}, yu^(-1)]*G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*G[{0, yu}, yv^(-1)] - 
     2*G[{0}, yv^(-1)]*G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*G[{0, yu}, yv^(-1)] + 
     2*G[{0}, yw]*G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*G[{0, yu}, yv^(-1)] + 
     2*G[{1}, yu^(-1)]^2*G[{1}, yv^(-1)]*G[{0, yu}, yv^(-1)] + 
     G[{0}, yu^(-1)]*G[{1}, yv^(-1)]^2*G[{0, yu}, yv^(-1)] + 
     G[{0}, yv^(-1)]*G[{1}, yv^(-1)]^2*G[{0, yu}, yv^(-1)] - 
     G[{0}, yw]*G[{1}, yv^(-1)]^2*G[{0, yu}, yv^(-1)] + 
     2*G[{1}, yu^(-1)]*G[{1}, yv^(-1)]^2*G[{0, yu}, yv^(-1)] - 
     (2*G[{1}, yv^(-1)]^3*G[{0, yu}, yv^(-1)])/3 + 
     (Pi^2*G[{1}, yw]*G[{0, yu}, yv^(-1)])/3 + 2*G[{0}, yu^(-1)]*
      G[{1}, yu^(-1)]*G[{1}, yw]*G[{0, yu}, yv^(-1)] + 
     2*G[{0}, yv^(-1)]*G[{1}, yu^(-1)]*G[{1}, yw]*G[{0, yu}, yv^(-1)] - 
     2*G[{0}, yw]*G[{1}, yu^(-1)]*G[{1}, yw]*G[{0, yu}, yv^(-1)] - 
     2*G[{1}, yu^(-1)]^2*G[{1}, yw]*G[{0, yu}, yv^(-1)] + 
     2*G[{0}, yu^(-1)]*G[{1}, yv^(-1)]*G[{1}, yw]*G[{0, yu}, yv^(-1)] + 
     2*G[{0}, yv^(-1)]*G[{1}, yv^(-1)]*G[{1}, yw]*G[{0, yu}, yv^(-1)] - 
     2*G[{0}, yw]*G[{1}, yv^(-1)]*G[{1}, yw]*G[{0, yu}, yv^(-1)] - 
     4*G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*G[{1}, yw]*G[{0, yu}, yv^(-1)] - 
     3*G[{0}, yu^(-1)]*G[{1}, yw]^2*G[{0, yu}, yv^(-1)] - 
     3*G[{0}, yv^(-1)]*G[{1}, yw]^2*G[{0, yu}, yv^(-1)] + 
     3*G[{0}, yw]*G[{1}, yw]^2*G[{0, yu}, yv^(-1)] + 
     2*G[{1}, yu^(-1)]*G[{1}, yw]^2*G[{0, yu}, yv^(-1)] + 
     2*G[{1}, yv^(-1)]*G[{1}, yw]^2*G[{0, yu}, yv^(-1)] - 
     (2*G[{1}, yw]^3*G[{0, yu}, yv^(-1)])/3 + 2*G[{1}, yw]^2*G[{yu}, yv^(-1)]*
      G[{0, yu}, yv^(-1)] - (Pi^2*G[{1/(yu*yv)}, yw]*G[{0, yu}, yv^(-1)])/3 - 
     2*G[{0}, yu^(-1)]*G[{1}, yu^(-1)]*G[{1/(yu*yv)}, yw]*
      G[{0, yu}, yv^(-1)] - 2*G[{0}, yv^(-1)]*G[{1}, yu^(-1)]*
      G[{1/(yu*yv)}, yw]*G[{0, yu}, yv^(-1)] + 2*G[{0}, yw]*G[{1}, yu^(-1)]*
      G[{1/(yu*yv)}, yw]*G[{0, yu}, yv^(-1)] + 2*G[{1}, yu^(-1)]^2*
      G[{1/(yu*yv)}, yw]*G[{0, yu}, yv^(-1)] - 2*G[{0}, yu^(-1)]*
      G[{1}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, yu}, yv^(-1)] - 
     2*G[{0}, yv^(-1)]*G[{1}, yv^(-1)]*G[{1/(yu*yv)}, yw]*
      G[{0, yu}, yv^(-1)] + 2*G[{0}, yw]*G[{1}, yv^(-1)]*G[{1/(yu*yv)}, yw]*
      G[{0, yu}, yv^(-1)] + 2*G[{1}, yv^(-1)]^2*G[{1/(yu*yv)}, yw]*
      G[{0, yu}, yv^(-1)] + 2*G[{0}, yu^(-1)]*G[{1}, yw]*G[{1/(yu*yv)}, yw]*
      G[{0, yu}, yv^(-1)] + 2*G[{0}, yv^(-1)]*G[{1}, yw]*G[{1/(yu*yv)}, yw]*
      G[{0, yu}, yv^(-1)] - 2*G[{0}, yw]*G[{1}, yw]*G[{1/(yu*yv)}, yw]*
      G[{0, yu}, yv^(-1)] + 2*G[{1}, yw]^2*G[{1/(yu*yv)}, yw]*
      G[{0, yu}, yv^(-1)] - 4*G[{1}, yw]*G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw]*
      G[{0, yu}, yv^(-1)] + G[{0}, yu^(-1)]*G[{1/(yu*yv)}, yw]^2*
      G[{0, yu}, yv^(-1)] + G[{0}, yv^(-1)]*G[{1/(yu*yv)}, yw]^2*
      G[{0, yu}, yv^(-1)] - G[{0}, yw]*G[{1/(yu*yv)}, yw]^2*
      G[{0, yu}, yv^(-1)] - 2*G[{1}, yu^(-1)]*G[{1/(yu*yv)}, yw]^2*
      G[{0, yu}, yv^(-1)] - 2*G[{1}, yv^(-1)]*G[{1/(yu*yv)}, yw]^2*
      G[{0, yu}, yv^(-1)] - 2*G[{1}, yw]*G[{1/(yu*yv)}, yw]^2*
      G[{0, yu}, yv^(-1)] + 2*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2*
      G[{0, yu}, yv^(-1)] + 2*G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw]^2*
      G[{0, yu}, yv^(-1)] + 2*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2*
      G[{0, yu}, yv^(-1)] - 2*G[{1}, yv^(-1)]*G[{0, 1}, yu^(-1)]*
      G[{0, yu}, yv^(-1)] + 2*G[{1}, yw]*G[{0, 1}, yu^(-1)]*
      G[{0, yu}, yv^(-1)] - 2*G[{1/(yu*yv)}, yw]*G[{0, 1}, yu^(-1)]*
      G[{0, yu}, yv^(-1)] - 2*G[{1}, yv^(-1)]*G[{0, 1}, yv^(-1)]*
      G[{0, yu}, yv^(-1)] + 2*G[{1}, yw]*G[{0, 1}, yv^(-1)]*
      G[{0, yu}, yv^(-1)] - 2*G[{1/(yu*yv)}, yw]*G[{0, 1}, yv^(-1)]*
      G[{0, yu}, yv^(-1)] + 2*G[{0}, yu^(-1)]*G[{0, 1}, yw]*
      G[{0, yu}, yv^(-1)] + 2*G[{0}, yv^(-1)]*G[{0, 1}, yw]*
      G[{0, yu}, yv^(-1)] - 2*G[{0}, yw]*G[{0, 1}, yw]*G[{0, yu}, yv^(-1)] - 
     6*G[{1}, yw]*G[{0, 1}, yw]*G[{0, yu}, yv^(-1)] + 
     2*G[{1/(yu*yv)}, yw]*G[{0, 1}, yw]*G[{0, yu}, yv^(-1)] + 
     2*G[{1}, yw]*G[{0, yu^(-1)}, yw]*G[{0, yu}, yv^(-1)] - 
     2*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1)}, yw]*G[{0, yu}, yv^(-1)] + 
     G[{1}, yv^(-1)]*G[{0, yu}, yv^(-1)]^2 - 
     G[{1}, yw]*G[{0, yu}, yv^(-1)]^2 + G[{1/(yu*yv)}, yw]*
      G[{0, yu}, yv^(-1)]^2 - (Pi^2*G[{1}, yw]*G[{0, yv^(-1)}, yw])/3 + 
     2*G[{0}, yu^(-1)]*G[{1}, yu^(-1)]*G[{1}, yw]*G[{0, yv^(-1)}, yw] + 
     2*G[{0}, yv^(-1)]*G[{1}, yu^(-1)]*G[{1}, yw]*G[{0, yv^(-1)}, yw] - 
     2*G[{0}, yw]*G[{1}, yu^(-1)]*G[{1}, yw]*G[{0, yv^(-1)}, yw] - 
     2*G[{1}, yu^(-1)]^2*G[{1}, yw]*G[{0, yv^(-1)}, yw] - 
     2*G[{0}, yu^(-1)]*G[{1}, yv^(-1)]*G[{1}, yw]*G[{0, yv^(-1)}, yw] - 
     2*G[{0}, yv^(-1)]*G[{1}, yv^(-1)]*G[{1}, yw]*G[{0, yv^(-1)}, yw] + 
     2*G[{0}, yw]*G[{1}, yv^(-1)]*G[{1}, yw]*G[{0, yv^(-1)}, yw] + 
     2*G[{1}, yv^(-1)]^2*G[{1}, yw]*G[{0, yv^(-1)}, yw] - 
     3*G[{0}, yu^(-1)]*G[{1}, yw]^2*G[{0, yv^(-1)}, yw] - 
     3*G[{0}, yv^(-1)]*G[{1}, yw]^2*G[{0, yv^(-1)}, yw] + 
     3*G[{0}, yw]*G[{1}, yw]^2*G[{0, yv^(-1)}, yw] + 
     4*G[{1}, yu^(-1)]*G[{1}, yw]^2*G[{0, yv^(-1)}, yw] + 
     4*G[{1}, yv^(-1)]*G[{1}, yw]^2*G[{0, yv^(-1)}, yw] + 
     (2*G[{1}, yw]^3*G[{0, yv^(-1)}, yw])/3 - 2*G[{1}, yw]^2*G[{yu}, yv^(-1)]*
      G[{0, yv^(-1)}, yw] + (Pi^2*G[{1/(yu*yv)}, yw]*G[{0, yv^(-1)}, yw])/3 - 
     2*G[{0}, yu^(-1)]*G[{1}, yu^(-1)]*G[{1/(yu*yv)}, yw]*
      G[{0, yv^(-1)}, yw] - 2*G[{0}, yv^(-1)]*G[{1}, yu^(-1)]*
      G[{1/(yu*yv)}, yw]*G[{0, yv^(-1)}, yw] + 2*G[{0}, yw]*G[{1}, yu^(-1)]*
      G[{1/(yu*yv)}, yw]*G[{0, yv^(-1)}, yw] + 2*G[{1}, yu^(-1)]^2*
      G[{1/(yu*yv)}, yw]*G[{0, yv^(-1)}, yw] + 2*G[{0}, yu^(-1)]*
      G[{1}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, yv^(-1)}, yw] + 
     2*G[{0}, yv^(-1)]*G[{1}, yv^(-1)]*G[{1/(yu*yv)}, yw]*
      G[{0, yv^(-1)}, yw] - 2*G[{0}, yw]*G[{1}, yv^(-1)]*G[{1/(yu*yv)}, yw]*
      G[{0, yv^(-1)}, yw] - 2*G[{1}, yv^(-1)]^2*G[{1/(yu*yv)}, yw]*
      G[{0, yv^(-1)}, yw] + 2*G[{0}, yu^(-1)]*G[{1}, yw]*G[{1/(yu*yv)}, yw]*
      G[{0, yv^(-1)}, yw] + 2*G[{0}, yv^(-1)]*G[{1}, yw]*G[{1/(yu*yv)}, yw]*
      G[{0, yv^(-1)}, yw] - 2*G[{0}, yw]*G[{1}, yw]*G[{1/(yu*yv)}, yw]*
      G[{0, yv^(-1)}, yw] - 4*G[{1}, yu^(-1)]*G[{1}, yw]*G[{1/(yu*yv)}, yw]*
      G[{0, yv^(-1)}, yw] - 4*G[{1}, yv^(-1)]*G[{1}, yw]*G[{1/(yu*yv)}, yw]*
      G[{0, yv^(-1)}, yw] - 2*G[{1}, yw]^2*G[{1/(yu*yv)}, yw]*
      G[{0, yv^(-1)}, yw] + 4*G[{1}, yw]*G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw]*
      G[{0, yv^(-1)}, yw] + G[{0}, yu^(-1)]*G[{1/(yu*yv)}, yw]^2*
      G[{0, yv^(-1)}, yw] + G[{0}, yv^(-1)]*G[{1/(yu*yv)}, yw]^2*
      G[{0, yv^(-1)}, yw] - G[{0}, yw]*G[{1/(yu*yv)}, yw]^2*
      G[{0, yv^(-1)}, yw] + 2*G[{1}, yw]*G[{1/(yu*yv)}, yw]^2*
      G[{0, yv^(-1)}, yw] - 2*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2*
      G[{0, yv^(-1)}, yw] - 2*G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw]^2*
      G[{0, yv^(-1)}, yw] - 2*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2*
      G[{0, yv^(-1)}, yw] - 2*G[{1}, yw]*G[{0, 1}, yu^(-1)]*
      G[{0, yv^(-1)}, yw] + 2*G[{1/(yu*yv)}, yw]*G[{0, 1}, yu^(-1)]*
      G[{0, yv^(-1)}, yw] - 2*G[{1}, yw]*G[{0, 1}, yv^(-1)]*
      G[{0, yv^(-1)}, yw] + 2*G[{1/(yu*yv)}, yw]*G[{0, 1}, yv^(-1)]*
      G[{0, yv^(-1)}, yw] + 2*G[{1}, yw]*G[{0, 1}, yw]*G[{0, yv^(-1)}, yw] - 
     2*G[{1/(yu*yv)}, yw]*G[{0, 1}, yw]*G[{0, yv^(-1)}, yw] - 
     2*G[{1}, yw]*G[{0, yu^(-1)}, yw]*G[{0, yv^(-1)}, yw] + 
     2*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1)}, yw]*G[{0, yv^(-1)}, yw] + 
     2*G[{1}, yw]*G[{0, yu}, yv^(-1)]*G[{0, yv^(-1)}, yw] - 
     2*G[{1/(yu*yv)}, yw]*G[{0, yu}, yv^(-1)]*G[{0, yv^(-1)}, yw] - 
     G[{1}, yw]*G[{0, yv^(-1)}, yw]^2 + G[{1/(yu*yv)}, yw]*
      G[{0, yv^(-1)}, yw]^2 + (Pi^2*G[{0}, yu^(-1)]*G[{0, 1/(yu*yv)}, yw])/
      3 + (Pi^2*G[{0}, yv^(-1)]*G[{0, 1/(yu*yv)}, yw])/3 - 
     (Pi^2*G[{0}, yw]*G[{0, 1/(yu*yv)}, yw])/3 - 
     (Pi^2*G[{1}, yw]*G[{0, 1/(yu*yv)}, yw])/3 - 2*G[{0}, yu^(-1)]*
      G[{1}, yu^(-1)]*G[{1}, yw]*G[{0, 1/(yu*yv)}, yw] - 
     2*G[{0}, yv^(-1)]*G[{1}, yu^(-1)]*G[{1}, yw]*G[{0, 1/(yu*yv)}, yw] + 
     2*G[{0}, yw]*G[{1}, yu^(-1)]*G[{1}, yw]*G[{0, 1/(yu*yv)}, yw] + 
     2*G[{1}, yu^(-1)]^2*G[{1}, yw]*G[{0, 1/(yu*yv)}, yw] - 
     2*G[{0}, yu^(-1)]*G[{1}, yv^(-1)]*G[{1}, yw]*G[{0, 1/(yu*yv)}, yw] - 
     2*G[{0}, yv^(-1)]*G[{1}, yv^(-1)]*G[{1}, yw]*G[{0, 1/(yu*yv)}, yw] + 
     2*G[{0}, yw]*G[{1}, yv^(-1)]*G[{1}, yw]*G[{0, 1/(yu*yv)}, yw] + 
     2*G[{1}, yv^(-1)]^2*G[{1}, yw]*G[{0, 1/(yu*yv)}, yw] + 
     3*G[{0}, yu^(-1)]*G[{1}, yw]^2*G[{0, 1/(yu*yv)}, yw] + 
     3*G[{0}, yv^(-1)]*G[{1}, yw]^2*G[{0, 1/(yu*yv)}, yw] - 
     3*G[{0}, yw]*G[{1}, yw]^2*G[{0, 1/(yu*yv)}, yw] - 
     4*G[{1}, yu^(-1)]*G[{1}, yw]^2*G[{0, 1/(yu*yv)}, yw] - 
     4*G[{1}, yv^(-1)]*G[{1}, yw]^2*G[{0, 1/(yu*yv)}, yw] - 
     (2*G[{1}, yw]^3*G[{0, 1/(yu*yv)}, yw])/3 + 4*G[{0}, yu^(-1)]*G[{1}, yw]*
      G[{yu}, yv^(-1)]*G[{0, 1/(yu*yv)}, yw] + 4*G[{0}, yv^(-1)]*G[{1}, yw]*
      G[{yu}, yv^(-1)]*G[{0, 1/(yu*yv)}, yw] - 4*G[{0}, yw]*G[{1}, yw]*
      G[{yu}, yv^(-1)]*G[{0, 1/(yu*yv)}, yw] + 2*G[{1}, yw]^2*
      G[{yu}, yv^(-1)]*G[{0, 1/(yu*yv)}, yw] - 
     4*G[{1}, yw]*G[{yu}, yv^(-1)]^2*G[{0, 1/(yu*yv)}, yw] - 
     (Pi^2*G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv)}, yw])/3 + 
     2*G[{0}, yu^(-1)]*G[{1}, yu^(-1)]*G[{1/(yu*yv)}, yw]*
      G[{0, 1/(yu*yv)}, yw] + 2*G[{0}, yv^(-1)]*G[{1}, yu^(-1)]*
      G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv)}, yw] - 2*G[{0}, yw]*G[{1}, yu^(-1)]*
      G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv)}, yw] - 2*G[{1}, yu^(-1)]^2*
      G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv)}, yw] + 2*G[{0}, yu^(-1)]*
      G[{1}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv)}, yw] + 
     2*G[{0}, yv^(-1)]*G[{1}, yv^(-1)]*G[{1/(yu*yv)}, yw]*
      G[{0, 1/(yu*yv)}, yw] - 2*G[{0}, yw]*G[{1}, yv^(-1)]*G[{1/(yu*yv)}, yw]*
      G[{0, 1/(yu*yv)}, yw] - 2*G[{1}, yv^(-1)]^2*G[{1/(yu*yv)}, yw]*
      G[{0, 1/(yu*yv)}, yw] - 2*G[{0}, yu^(-1)]*G[{1}, yw]*G[{1/(yu*yv)}, yw]*
      G[{0, 1/(yu*yv)}, yw] - 2*G[{0}, yv^(-1)]*G[{1}, yw]*G[{1/(yu*yv)}, yw]*
      G[{0, 1/(yu*yv)}, yw] + 2*G[{0}, yw]*G[{1}, yw]*G[{1/(yu*yv)}, yw]*
      G[{0, 1/(yu*yv)}, yw] + 4*G[{1}, yu^(-1)]*G[{1}, yw]*G[{1/(yu*yv)}, yw]*
      G[{0, 1/(yu*yv)}, yw] + 4*G[{1}, yv^(-1)]*G[{1}, yw]*G[{1/(yu*yv)}, yw]*
      G[{0, 1/(yu*yv)}, yw] + 2*G[{1}, yw]^2*G[{1/(yu*yv)}, yw]*
      G[{0, 1/(yu*yv)}, yw] - 4*G[{0}, yu^(-1)]*G[{yu}, yv^(-1)]*
      G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv)}, yw] - 4*G[{0}, yv^(-1)]*
      G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv)}, yw] + 
     4*G[{0}, yw]*G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv)}, yw] - 
     4*G[{1}, yw]*G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv)}, yw] + 
     4*G[{yu}, yv^(-1)]^2*G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv)}, yw] - 
     G[{0}, yu^(-1)]*G[{1/(yu*yv)}, yw]^2*G[{0, 1/(yu*yv)}, yw] - 
     G[{0}, yv^(-1)]*G[{1/(yu*yv)}, yw]^2*G[{0, 1/(yu*yv)}, yw] + 
     G[{0}, yw]*G[{1/(yu*yv)}, yw]^2*G[{0, 1/(yu*yv)}, yw] - 
     2*G[{1}, yw]*G[{1/(yu*yv)}, yw]^2*G[{0, 1/(yu*yv)}, yw] + 
     2*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2*G[{0, 1/(yu*yv)}, yw] + 
     2*G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw]^2*G[{0, 1/(yu*yv)}, yw] + 
     2*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2*G[{0, 1/(yu*yv)}, yw] + 
     2*G[{0}, yu^(-1)]*G[{0, 1}, yu^(-1)]*G[{0, 1/(yu*yv)}, yw] + 
     2*G[{0}, yv^(-1)]*G[{0, 1}, yu^(-1)]*G[{0, 1/(yu*yv)}, yw] - 
     2*G[{0}, yw]*G[{0, 1}, yu^(-1)]*G[{0, 1/(yu*yv)}, yw] - 
     2*G[{1}, yw]*G[{0, 1}, yu^(-1)]*G[{0, 1/(yu*yv)}, yw] - 
     2*G[{1/(yu*yv)}, yw]*G[{0, 1}, yu^(-1)]*G[{0, 1/(yu*yv)}, yw] + 
     2*G[{0}, yu^(-1)]*G[{0, 1}, yv^(-1)]*G[{0, 1/(yu*yv)}, yw] + 
     2*G[{0}, yv^(-1)]*G[{0, 1}, yv^(-1)]*G[{0, 1/(yu*yv)}, yw] - 
     2*G[{0}, yw]*G[{0, 1}, yv^(-1)]*G[{0, 1/(yu*yv)}, yw] - 
     2*G[{1}, yw]*G[{0, 1}, yv^(-1)]*G[{0, 1/(yu*yv)}, yw] - 
     2*G[{1/(yu*yv)}, yw]*G[{0, 1}, yv^(-1)]*G[{0, 1/(yu*yv)}, yw] + 
     2*G[{0}, yu^(-1)]*G[{0, 1}, yw]*G[{0, 1/(yu*yv)}, yw] + 
     2*G[{0}, yv^(-1)]*G[{0, 1}, yw]*G[{0, 1/(yu*yv)}, yw] - 
     2*G[{0}, yw]*G[{0, 1}, yw]*G[{0, 1/(yu*yv)}, yw] + 
     2*G[{1}, yw]*G[{0, 1}, yw]*G[{0, 1/(yu*yv)}, yw] - 
     4*G[{yu}, yv^(-1)]*G[{0, 1}, yw]*G[{0, 1/(yu*yv)}, yw] + 
     2*G[{1/(yu*yv)}, yw]*G[{0, 1}, yw]*G[{0, 1/(yu*yv)}, yw] - 
     2*G[{0}, yu^(-1)]*G[{0, yu^(-1)}, yw]*G[{0, 1/(yu*yv)}, yw] - 
     2*G[{0}, yv^(-1)]*G[{0, yu^(-1)}, yw]*G[{0, 1/(yu*yv)}, yw] + 
     2*G[{0}, yw]*G[{0, yu^(-1)}, yw]*G[{0, 1/(yu*yv)}, yw] + 
     4*G[{1}, yv^(-1)]*G[{0, yu^(-1)}, yw]*G[{0, 1/(yu*yv)}, yw] - 
     2*G[{1}, yw]*G[{0, yu^(-1)}, yw]*G[{0, 1/(yu*yv)}, yw] - 
     2*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1)}, yw]*G[{0, 1/(yu*yv)}, yw] - 
     2*G[{0}, yu^(-1)]*G[{0, yu}, yv^(-1)]*G[{0, 1/(yu*yv)}, yw] - 
     2*G[{0}, yv^(-1)]*G[{0, yu}, yv^(-1)]*G[{0, 1/(yu*yv)}, yw] + 
     2*G[{0}, yw]*G[{0, yu}, yv^(-1)]*G[{0, 1/(yu*yv)}, yw] + 
     2*G[{1}, yw]*G[{0, yu}, yv^(-1)]*G[{0, 1/(yu*yv)}, yw] + 
     2*G[{1/(yu*yv)}, yw]*G[{0, yu}, yv^(-1)]*G[{0, 1/(yu*yv)}, yw] - 
     2*G[{0}, yu^(-1)]*G[{0, yv^(-1)}, yw]*G[{0, 1/(yu*yv)}, yw] - 
     2*G[{0}, yv^(-1)]*G[{0, yv^(-1)}, yw]*G[{0, 1/(yu*yv)}, yw] + 
     2*G[{0}, yw]*G[{0, yv^(-1)}, yw]*G[{0, 1/(yu*yv)}, yw] + 
     4*G[{1}, yu^(-1)]*G[{0, yv^(-1)}, yw]*G[{0, 1/(yu*yv)}, yw] - 
     2*G[{1}, yw]*G[{0, yv^(-1)}, yw]*G[{0, 1/(yu*yv)}, yw] - 
     2*G[{1/(yu*yv)}, yw]*G[{0, yv^(-1)}, yw]*G[{0, 1/(yu*yv)}, yw] + 
     G[{0}, yu^(-1)]*G[{0, 1/(yu*yv)}, yw]^2 + G[{0}, yv^(-1)]*
      G[{0, 1/(yu*yv)}, yw]^2 - G[{0}, yw]*G[{0, 1/(yu*yv)}, yw]^2 - 
     2*G[{1}, yu^(-1)]*G[{0, 1/(yu*yv)}, yw]^2 - 2*G[{1}, yv^(-1)]*
      G[{0, 1/(yu*yv)}, yw]^2 + G[{1}, yw]*G[{0, 1/(yu*yv)}, yw]^2 + 
     2*G[{yu}, yv^(-1)]*G[{0, 1/(yu*yv)}, yw]^2 + G[{1/(yu*yv)}, yw]*
      G[{0, 1/(yu*yv)}, yw]^2 - 2*G[{0}, yu^(-1)]*G[{1/(yu*yv)}, yw]^2*
      G[{1, yu^(-1)}, yw] - 2*G[{0}, yv^(-1)]*G[{1/(yu*yv)}, yw]^2*
      G[{1, yu^(-1)}, yw] + 2*G[{0}, yw]*G[{1/(yu*yv)}, yw]^2*
      G[{1, yu^(-1)}, yw] + 2*G[{1}, yu^(-1)]*G[{1/(yu*yv)}, yw]^2*
      G[{1, yu^(-1)}, yw] - 2*G[{1}, yw]*G[{1/(yu*yv)}, yw]^2*
      G[{1, yu^(-1)}, yw] + 2*G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw]^2*
      G[{1, yu^(-1)}, yw] + 2*G[{1}, yu^(-1)]*G[{1}, yw]^2*
      G[{1, yu}, yv^(-1)] - 2*G[{1}, yv^(-1)]*G[{1}, yw]^2*
      G[{1, yu}, yv^(-1)] - 4*G[{1}, yu^(-1)]*G[{1}, yw]*G[{1/(yu*yv)}, yw]*
      G[{1, yu}, yv^(-1)] + 4*G[{1}, yv^(-1)]*G[{1}, yw]*G[{1/(yu*yv)}, yw]*
      G[{1, yu}, yv^(-1)] + 2*G[{1}, yu^(-1)]*G[{1/(yu*yv)}, yw]^2*
      G[{1, yu}, yv^(-1)] - 2*G[{1}, yv^(-1)]*G[{1/(yu*yv)}, yw]^2*
      G[{1, yu}, yv^(-1)] - 2*G[{0}, yu^(-1)]*G[{1/(yu*yv)}, yw]^2*
      G[{1, yv^(-1)}, yw] - 2*G[{0}, yv^(-1)]*G[{1/(yu*yv)}, yw]^2*
      G[{1, yv^(-1)}, yw] + 2*G[{0}, yw]*G[{1/(yu*yv)}, yw]^2*
      G[{1, yv^(-1)}, yw] + 2*G[{1}, yv^(-1)]*G[{1/(yu*yv)}, yw]^2*
      G[{1, yv^(-1)}, yw] - 2*G[{1}, yw]*G[{1/(yu*yv)}, yw]^2*
      G[{1, yv^(-1)}, yw] + 2*G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw]^2*
      G[{1, yv^(-1)}, yw] - (2*Pi^2*G[{1/(yu*yv)}, yw]*G[{1, 1/(yu*yv)}, yw])/
      3 - 4*G[{0}, yu^(-1)]*G[{1}, yu^(-1)]*G[{1/(yu*yv)}, yw]*
      G[{1, 1/(yu*yv)}, yw] - 4*G[{0}, yv^(-1)]*G[{1}, yu^(-1)]*
      G[{1/(yu*yv)}, yw]*G[{1, 1/(yu*yv)}, yw] + 4*G[{0}, yw]*G[{1}, yu^(-1)]*
      G[{1/(yu*yv)}, yw]*G[{1, 1/(yu*yv)}, yw] + 4*G[{1}, yu^(-1)]^2*
      G[{1/(yu*yv)}, yw]*G[{1, 1/(yu*yv)}, yw] - 4*G[{0}, yu^(-1)]*
      G[{1}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{1, 1/(yu*yv)}, yw] - 
     4*G[{0}, yv^(-1)]*G[{1}, yv^(-1)]*G[{1/(yu*yv)}, yw]*
      G[{1, 1/(yu*yv)}, yw] + 4*G[{0}, yw]*G[{1}, yv^(-1)]*G[{1/(yu*yv)}, yw]*
      G[{1, 1/(yu*yv)}, yw] + 4*G[{1}, yv^(-1)]^2*G[{1/(yu*yv)}, yw]*
      G[{1, 1/(yu*yv)}, yw] - 4*G[{0}, yu^(-1)]*G[{1}, yw]*G[{1/(yu*yv)}, yw]*
      G[{1, 1/(yu*yv)}, yw] - 4*G[{0}, yv^(-1)]*G[{1}, yw]*G[{1/(yu*yv)}, yw]*
      G[{1, 1/(yu*yv)}, yw] + 4*G[{0}, yw]*G[{1}, yw]*G[{1/(yu*yv)}, yw]*
      G[{1, 1/(yu*yv)}, yw] - 4*G[{1}, yw]^2*G[{1/(yu*yv)}, yw]*
      G[{1, 1/(yu*yv)}, yw] + 8*G[{0}, yu^(-1)]*G[{yu}, yv^(-1)]*
      G[{1/(yu*yv)}, yw]*G[{1, 1/(yu*yv)}, yw] + 8*G[{0}, yv^(-1)]*
      G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{1, 1/(yu*yv)}, yw] - 
     8*G[{0}, yw]*G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{1, 1/(yu*yv)}, yw] + 
     8*G[{1}, yw]*G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{1, 1/(yu*yv)}, yw] - 
     8*G[{yu}, yv^(-1)]^2*G[{1/(yu*yv)}, yw]*G[{1, 1/(yu*yv)}, yw] + 
     2*G[{0}, yu^(-1)]*G[{1/(yu*yv)}, yw]^2*G[{1, 1/(yu*yv)}, yw] + 
     2*G[{0}, yv^(-1)]*G[{1/(yu*yv)}, yw]^2*G[{1, 1/(yu*yv)}, yw] - 
     2*G[{0}, yw]*G[{1/(yu*yv)}, yw]^2*G[{1, 1/(yu*yv)}, yw] - 
     2*G[{1}, yu^(-1)]*G[{1/(yu*yv)}, yw]^2*G[{1, 1/(yu*yv)}, yw] - 
     2*G[{1}, yv^(-1)]*G[{1/(yu*yv)}, yw]^2*G[{1, 1/(yu*yv)}, yw] + 
     4*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2*G[{1, 1/(yu*yv)}, yw] + 
     4*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2*G[{1, 1/(yu*yv)}, yw] - 
     4*G[{1/(yu*yv)}, yw]*G[{0, 1}, yu^(-1)]*G[{1, 1/(yu*yv)}, yw] - 
     4*G[{1/(yu*yv)}, yw]*G[{0, 1}, yv^(-1)]*G[{1, 1/(yu*yv)}, yw] + 
     4*G[{1/(yu*yv)}, yw]*G[{0, 1}, yw]*G[{1, 1/(yu*yv)}, yw] - 
     4*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1)}, yw]*G[{1, 1/(yu*yv)}, yw] + 
     4*G[{1/(yu*yv)}, yw]*G[{0, yu}, yv^(-1)]*G[{1, 1/(yu*yv)}, yw] - 
     4*G[{1/(yu*yv)}, yw]*G[{0, yv^(-1)}, yw]*G[{1, 1/(yu*yv)}, yw] + 
     4*G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv)}, yw]*G[{1, 1/(yu*yv)}, yw] + 
     4*G[{1/(yu*yv)}, yw]*G[{1, 1/(yu*yv)}, yw]^2 + 
     (2*Pi^2*G[{1/(yu*yv)}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw])/3 + 
     4*G[{0}, yu^(-1)]*G[{1}, yu^(-1)]*G[{1/(yu*yv)}, yw]*
      G[{yu^(-1), 1/(yu*yv)}, yw] + 4*G[{0}, yv^(-1)]*G[{1}, yu^(-1)]*
      G[{1/(yu*yv)}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw] - 
     4*G[{0}, yw]*G[{1}, yu^(-1)]*G[{1/(yu*yv)}, yw]*
      G[{yu^(-1), 1/(yu*yv)}, yw] - 4*G[{1}, yu^(-1)]^2*G[{1/(yu*yv)}, yw]*
      G[{yu^(-1), 1/(yu*yv)}, yw] - 4*G[{0}, yu^(-1)]*G[{1}, yv^(-1)]*
      G[{1/(yu*yv)}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw] - 
     4*G[{0}, yv^(-1)]*G[{1}, yv^(-1)]*G[{1/(yu*yv)}, yw]*
      G[{yu^(-1), 1/(yu*yv)}, yw] + 4*G[{0}, yw]*G[{1}, yv^(-1)]*
      G[{1/(yu*yv)}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw] + 
     4*G[{1}, yv^(-1)]^2*G[{1/(yu*yv)}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw] - 
     4*G[{0}, yu^(-1)]*G[{1}, yw]*G[{1/(yu*yv)}, yw]*
      G[{yu^(-1), 1/(yu*yv)}, yw] - 4*G[{0}, yv^(-1)]*G[{1}, yw]*
      G[{1/(yu*yv)}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw] + 
     4*G[{0}, yw]*G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw] - 
     4*G[{1}, yw]^2*G[{1/(yu*yv)}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw] + 
     8*G[{0}, yu^(-1)]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*
      G[{yu^(-1), 1/(yu*yv)}, yw] + 8*G[{0}, yv^(-1)]*G[{yu^(-1)}, yw]*
      G[{1/(yu*yv)}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw] - 
     8*G[{0}, yw]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*
      G[{yu^(-1), 1/(yu*yv)}, yw] - 16*G[{1}, yv^(-1)]*G[{yu^(-1)}, yw]*
      G[{1/(yu*yv)}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw] + 
     8*G[{yu^(-1)}, yw]^2*G[{1/(yu*yv)}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw] + 
     8*G[{1}, yw]*G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw]*
      G[{yu^(-1), 1/(yu*yv)}, yw] + 2*G[{1}, yu^(-1)]*G[{1/(yu*yv)}, yw]^2*
      G[{yu^(-1), 1/(yu*yv)}, yw] + 2*G[{1}, yw]*G[{1/(yu*yv)}, yw]^2*
      G[{yu^(-1), 1/(yu*yv)}, yw] - 2*G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw]^2*
      G[{yu^(-1), 1/(yu*yv)}, yw] - 4*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2*
      G[{yu^(-1), 1/(yu*yv)}, yw] + 4*G[{1/(yu*yv)}, yw]*G[{0, 1}, yu^(-1)]*
      G[{yu^(-1), 1/(yu*yv)}, yw] + 4*G[{1/(yu*yv)}, yw]*G[{0, 1}, yv^(-1)]*
      G[{yu^(-1), 1/(yu*yv)}, yw] - 4*G[{1/(yu*yv)}, yw]*G[{0, 1}, yw]*
      G[{yu^(-1), 1/(yu*yv)}, yw] + 4*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1)}, yw]*
      G[{yu^(-1), 1/(yu*yv)}, yw] - 4*G[{1/(yu*yv)}, yw]*G[{0, yu}, yv^(-1)]*
      G[{yu^(-1), 1/(yu*yv)}, yw] + 4*G[{1/(yu*yv)}, yw]*G[{0, yv^(-1)}, yw]*
      G[{yu^(-1), 1/(yu*yv)}, yw] - 4*G[{1/(yu*yv)}, yw]*
      G[{0, 1/(yu*yv)}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw] - 
     8*G[{1/(yu*yv)}, yw]*G[{1, 1/(yu*yv)}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw] + 
     4*G[{1/(yu*yv)}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw]^2 + 
     (2*Pi^2*G[{1/(yu*yv)}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw])/3 - 
     4*G[{0}, yu^(-1)]*G[{1}, yu^(-1)]*G[{1/(yu*yv)}, yw]*
      G[{yv^(-1), 1/(yu*yv)}, yw] - 4*G[{0}, yv^(-1)]*G[{1}, yu^(-1)]*
      G[{1/(yu*yv)}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw] + 
     4*G[{0}, yw]*G[{1}, yu^(-1)]*G[{1/(yu*yv)}, yw]*
      G[{yv^(-1), 1/(yu*yv)}, yw] + 4*G[{1}, yu^(-1)]^2*G[{1/(yu*yv)}, yw]*
      G[{yv^(-1), 1/(yu*yv)}, yw] + 4*G[{0}, yu^(-1)]*G[{1}, yv^(-1)]*
      G[{1/(yu*yv)}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw] + 
     4*G[{0}, yv^(-1)]*G[{1}, yv^(-1)]*G[{1/(yu*yv)}, yw]*
      G[{yv^(-1), 1/(yu*yv)}, yw] - 4*G[{0}, yw]*G[{1}, yv^(-1)]*
      G[{1/(yu*yv)}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw] - 
     4*G[{1}, yv^(-1)]^2*G[{1/(yu*yv)}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw] - 
     4*G[{0}, yu^(-1)]*G[{1}, yw]*G[{1/(yu*yv)}, yw]*
      G[{yv^(-1), 1/(yu*yv)}, yw] - 4*G[{0}, yv^(-1)]*G[{1}, yw]*
      G[{1/(yu*yv)}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw] + 
     4*G[{0}, yw]*G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw] - 
     4*G[{1}, yw]^2*G[{1/(yu*yv)}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw] + 
     8*G[{1}, yw]*G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw]*
      G[{yv^(-1), 1/(yu*yv)}, yw] + 8*G[{0}, yu^(-1)]*G[{yv^(-1)}, yw]*
      G[{1/(yu*yv)}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw] + 
     8*G[{0}, yv^(-1)]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*
      G[{yv^(-1), 1/(yu*yv)}, yw] - 8*G[{0}, yw]*G[{yv^(-1)}, yw]*
      G[{1/(yu*yv)}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw] - 
     16*G[{1}, yu^(-1)]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*
      G[{yv^(-1), 1/(yu*yv)}, yw] + 8*G[{yv^(-1)}, yw]^2*G[{1/(yu*yv)}, yw]*
      G[{yv^(-1), 1/(yu*yv)}, yw] + 2*G[{1}, yv^(-1)]*G[{1/(yu*yv)}, yw]^2*
      G[{yv^(-1), 1/(yu*yv)}, yw] + 2*G[{1}, yw]*G[{1/(yu*yv)}, yw]^2*
      G[{yv^(-1), 1/(yu*yv)}, yw] - 2*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2*
      G[{yv^(-1), 1/(yu*yv)}, yw] - 2*G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw]^2*
      G[{yv^(-1), 1/(yu*yv)}, yw] + 4*G[{1/(yu*yv)}, yw]*G[{0, 1}, yu^(-1)]*
      G[{yv^(-1), 1/(yu*yv)}, yw] + 4*G[{1/(yu*yv)}, yw]*G[{0, 1}, yv^(-1)]*
      G[{yv^(-1), 1/(yu*yv)}, yw] - 4*G[{1/(yu*yv)}, yw]*G[{0, 1}, yw]*
      G[{yv^(-1), 1/(yu*yv)}, yw] + 4*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1)}, yw]*
      G[{yv^(-1), 1/(yu*yv)}, yw] - 4*G[{1/(yu*yv)}, yw]*G[{0, yu}, yv^(-1)]*
      G[{yv^(-1), 1/(yu*yv)}, yw] + 4*G[{1/(yu*yv)}, yw]*G[{0, yv^(-1)}, yw]*
      G[{yv^(-1), 1/(yu*yv)}, yw] - 4*G[{1/(yu*yv)}, yw]*
      G[{0, 1/(yu*yv)}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw] - 
     8*G[{1/(yu*yv)}, yw]*G[{1, 1/(yu*yv)}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw] + 
     8*G[{1/(yu*yv)}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw]*
      G[{yv^(-1), 1/(yu*yv)}, yw] + 4*G[{1/(yu*yv)}, yw]*
      G[{yv^(-1), 1/(yu*yv)}, yw]^2 - (2*Pi^2*G[{0, 0, 1}, yw])/3 + 
     4*G[{1}, yu^(-1)]*G[{1}, yw]*G[{0, 0, 1}, yw] + 
     4*G[{1}, yv^(-1)]*G[{1}, yw]*G[{0, 0, 1}, yw] + 
     6*G[{1}, yw]^2*G[{0, 0, 1}, yw] - 8*G[{1}, yw]*G[{yu}, yv^(-1)]*
      G[{0, 0, 1}, yw] - 4*G[{1}, yu^(-1)]*G[{1/(yu*yv)}, yw]*
      G[{0, 0, 1}, yw] - 4*G[{1}, yv^(-1)]*G[{1/(yu*yv)}, yw]*
      G[{0, 0, 1}, yw] - 4*G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 0, 1}, yw] + 
     8*G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, 0, 1}, yw] - 
     2*G[{1/(yu*yv)}, yw]^2*G[{0, 0, 1}, yw] - 4*G[{0, 1}, yu^(-1)]*
      G[{0, 0, 1}, yw] - 4*G[{0, 1}, yv^(-1)]*G[{0, 0, 1}, yw] - 
     4*G[{0, 1}, yw]*G[{0, 0, 1}, yw] + 4*G[{0, yu}, yv^(-1)]*
      G[{0, 0, 1}, yw] + 4*G[{0, 1/(yu*yv)}, yw]*G[{0, 0, 1}, yw] - 
     4*G[{1}, yu^(-1)]*G[{1}, yw]*G[{0, 0, yu^(-1)}, yw] + 
     4*G[{1}, yv^(-1)]*G[{1}, yw]*G[{0, 0, yu^(-1)}, yw] - 
     6*G[{1}, yw]^2*G[{0, 0, yu^(-1)}, yw] + 4*G[{1}, yu^(-1)]*
      G[{1/(yu*yv)}, yw]*G[{0, 0, yu^(-1)}, yw] - 
     4*G[{1}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, 0, yu^(-1)}, yw] + 
     4*G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 0, yu^(-1)}, yw] + 
     2*G[{1/(yu*yv)}, yw]^2*G[{0, 0, yu^(-1)}, yw] + 
     4*G[{0, 1}, yw]*G[{0, 0, yu^(-1)}, yw] - 4*G[{0, 1/(yu*yv)}, yw]*
      G[{0, 0, yu^(-1)}, yw] + 4*G[{1}, yu^(-1)]*G[{1}, yw]*
      G[{0, 0, yv^(-1)}, yw] - 4*G[{1}, yv^(-1)]*G[{1}, yw]*
      G[{0, 0, yv^(-1)}, yw] - 6*G[{1}, yw]^2*G[{0, 0, yv^(-1)}, yw] - 
     4*G[{1}, yu^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, 0, yv^(-1)}, yw] + 
     4*G[{1}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, 0, yv^(-1)}, yw] + 
     4*G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 0, yv^(-1)}, yw] + 
     2*G[{1/(yu*yv)}, yw]^2*G[{0, 0, yv^(-1)}, yw] + 
     4*G[{0, 1}, yw]*G[{0, 0, yv^(-1)}, yw] - 4*G[{0, 1/(yu*yv)}, yw]*
      G[{0, 0, yv^(-1)}, yw] + (2*Pi^2*G[{0, 0, 1/(yu*yv)}, yw])/3 - 
     4*G[{1}, yu^(-1)]*G[{1}, yw]*G[{0, 0, 1/(yu*yv)}, yw] - 
     4*G[{1}, yv^(-1)]*G[{1}, yw]*G[{0, 0, 1/(yu*yv)}, yw] + 
     6*G[{1}, yw]^2*G[{0, 0, 1/(yu*yv)}, yw] + 8*G[{1}, yw]*G[{yu}, yv^(-1)]*
      G[{0, 0, 1/(yu*yv)}, yw] + 4*G[{1}, yu^(-1)]*G[{1/(yu*yv)}, yw]*
      G[{0, 0, 1/(yu*yv)}, yw] + 4*G[{1}, yv^(-1)]*G[{1/(yu*yv)}, yw]*
      G[{0, 0, 1/(yu*yv)}, yw] - 4*G[{1}, yw]*G[{1/(yu*yv)}, yw]*
      G[{0, 0, 1/(yu*yv)}, yw] - 8*G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw]*
      G[{0, 0, 1/(yu*yv)}, yw] - 2*G[{1/(yu*yv)}, yw]^2*
      G[{0, 0, 1/(yu*yv)}, yw] + 4*G[{0, 1}, yu^(-1)]*
      G[{0, 0, 1/(yu*yv)}, yw] + 4*G[{0, 1}, yv^(-1)]*
      G[{0, 0, 1/(yu*yv)}, yw] - 4*G[{0, 1}, yw]*G[{0, 0, 1/(yu*yv)}, yw] - 
     4*G[{0, yu}, yv^(-1)]*G[{0, 0, 1/(yu*yv)}, yw] + 
     4*G[{0, 1/(yu*yv)}, yw]*G[{0, 0, 1/(yu*yv)}, yw] + 
     (Pi^2*G[{0, 1, 1}, yu^(-1)])/3 + 4*G[{0}, yu^(-1)]*G[{1}, yu^(-1)]*
      G[{0, 1, 1}, yu^(-1)] + 4*G[{0}, yv^(-1)]*G[{1}, yu^(-1)]*
      G[{0, 1, 1}, yu^(-1)] - 4*G[{0}, yw]*G[{1}, yu^(-1)]*
      G[{0, 1, 1}, yu^(-1)] - 2*G[{1}, yu^(-1)]^2*G[{0, 1, 1}, yu^(-1)] - 
     4*G[{0}, yu^(-1)]*G[{1}, yv^(-1)]*G[{0, 1, 1}, yu^(-1)] - 
     4*G[{0}, yv^(-1)]*G[{1}, yv^(-1)]*G[{0, 1, 1}, yu^(-1)] + 
     4*G[{0}, yw]*G[{1}, yv^(-1)]*G[{0, 1, 1}, yu^(-1)] - 
     4*G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*G[{0, 1, 1}, yu^(-1)] + 
     6*G[{1}, yv^(-1)]^2*G[{0, 1, 1}, yu^(-1)] + 4*G[{0}, yu^(-1)]*G[{1}, yw]*
      G[{0, 1, 1}, yu^(-1)] + 4*G[{0}, yv^(-1)]*G[{1}, yw]*
      G[{0, 1, 1}, yu^(-1)] - 4*G[{0}, yw]*G[{1}, yw]*G[{0, 1, 1}, yu^(-1)] + 
     4*G[{1}, yu^(-1)]*G[{1}, yw]*G[{0, 1, 1}, yu^(-1)] - 
     4*G[{1}, yv^(-1)]*G[{1}, yw]*G[{0, 1, 1}, yu^(-1)] - 
     2*G[{1}, yw]^2*G[{0, 1, 1}, yu^(-1)] - 4*G[{0}, yu^(-1)]*
      G[{1/(yu*yv)}, yw]*G[{0, 1, 1}, yu^(-1)] - 4*G[{0}, yv^(-1)]*
      G[{1/(yu*yv)}, yw]*G[{0, 1, 1}, yu^(-1)] + 
     4*G[{0}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1, 1}, yu^(-1)] + 
     4*G[{1}, yu^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, 1, 1}, yu^(-1)] - 
     4*G[{1}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, 1, 1}, yu^(-1)] + 
     4*G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1, 1}, yu^(-1)] - 
     2*G[{1/(yu*yv)}, yw]^2*G[{0, 1, 1}, yu^(-1)] + 
     2*G[{0, 1}, yu^(-1)]*G[{0, 1, 1}, yu^(-1)] - 4*G[{0, 1}, yv^(-1)]*
      G[{0, 1, 1}, yu^(-1)] + 4*G[{0, 1}, yw]*G[{0, 1, 1}, yu^(-1)] - 
     4*G[{0, 1/(yu*yv)}, yw]*G[{0, 1, 1}, yu^(-1)] + 
     (Pi^2*G[{0, 1, 1}, yv^(-1)])/3 - 2*G[{0}, yu^(-1)]*G[{1}, yu^(-1)]*
      G[{0, 1, 1}, yv^(-1)] - 2*G[{0}, yv^(-1)]*G[{1}, yu^(-1)]*
      G[{0, 1, 1}, yv^(-1)] + 2*G[{0}, yw]*G[{1}, yu^(-1)]*
      G[{0, 1, 1}, yv^(-1)] + 2*G[{1}, yu^(-1)]^2*G[{0, 1, 1}, yv^(-1)] + 
     4*G[{0}, yu^(-1)]*G[{1}, yv^(-1)]*G[{0, 1, 1}, yv^(-1)] + 
     4*G[{0}, yv^(-1)]*G[{1}, yv^(-1)]*G[{0, 1, 1}, yv^(-1)] - 
     4*G[{0}, yw]*G[{1}, yv^(-1)]*G[{0, 1, 1}, yv^(-1)] + 
     4*G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*G[{0, 1, 1}, yv^(-1)] - 
     2*G[{1}, yv^(-1)]^2*G[{0, 1, 1}, yv^(-1)] + 4*G[{0}, yu^(-1)]*G[{1}, yw]*
      G[{0, 1, 1}, yv^(-1)] + 4*G[{0}, yv^(-1)]*G[{1}, yw]*
      G[{0, 1, 1}, yv^(-1)] - 4*G[{0}, yw]*G[{1}, yw]*G[{0, 1, 1}, yv^(-1)] - 
     4*G[{1}, yu^(-1)]*G[{1}, yw]*G[{0, 1, 1}, yv^(-1)] + 
     4*G[{1}, yv^(-1)]*G[{1}, yw]*G[{0, 1, 1}, yv^(-1)] - 
     2*G[{1}, yw]^2*G[{0, 1, 1}, yv^(-1)] - 4*G[{0}, yu^(-1)]*
      G[{1/(yu*yv)}, yw]*G[{0, 1, 1}, yv^(-1)] - 4*G[{0}, yv^(-1)]*
      G[{1/(yu*yv)}, yw]*G[{0, 1, 1}, yv^(-1)] + 
     4*G[{0}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1, 1}, yv^(-1)] + 
     4*G[{1}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, 1, 1}, yv^(-1)] + 
     4*G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1, 1}, yv^(-1)] - 
     2*G[{1/(yu*yv)}, yw]^2*G[{0, 1, 1}, yv^(-1)] + 
     2*G[{0, 1}, yu^(-1)]*G[{0, 1, 1}, yv^(-1)] + 2*G[{0, 1}, yv^(-1)]*
      G[{0, 1, 1}, yv^(-1)] + 4*G[{0, 1}, yw]*G[{0, 1, 1}, yv^(-1)] - 
     4*G[{0, 1/(yu*yv)}, yw]*G[{0, 1, 1}, yv^(-1)] - Pi^2*G[{0, 1, 1}, yw] - 
     2*G[{0}, yu^(-1)]*G[{1}, yu^(-1)]*G[{0, 1, 1}, yw] - 
     2*G[{0}, yv^(-1)]*G[{1}, yu^(-1)]*G[{0, 1, 1}, yw] + 
     2*G[{0}, yw]*G[{1}, yu^(-1)]*G[{0, 1, 1}, yw] + 
     2*G[{1}, yu^(-1)]^2*G[{0, 1, 1}, yw] - 2*G[{0}, yu^(-1)]*G[{1}, yv^(-1)]*
      G[{0, 1, 1}, yw] - 2*G[{0}, yv^(-1)]*G[{1}, yv^(-1)]*G[{0, 1, 1}, yw] + 
     2*G[{0}, yw]*G[{1}, yv^(-1)]*G[{0, 1, 1}, yw] + 
     2*G[{1}, yv^(-1)]^2*G[{0, 1, 1}, yw] - 8*G[{0}, yu^(-1)]*G[{1}, yw]*
      G[{0, 1, 1}, yw] - 8*G[{0}, yv^(-1)]*G[{1}, yw]*G[{0, 1, 1}, yw] + 
     8*G[{0}, yw]*G[{1}, yw]*G[{0, 1, 1}, yw] + 8*G[{1}, yu^(-1)]*G[{1}, yw]*
      G[{0, 1, 1}, yw] + 8*G[{1}, yv^(-1)]*G[{1}, yw]*G[{0, 1, 1}, yw] + 
     4*G[{0}, yu^(-1)]*G[{yu}, yv^(-1)]*G[{0, 1, 1}, yw] + 
     4*G[{0}, yv^(-1)]*G[{yu}, yv^(-1)]*G[{0, 1, 1}, yw] - 
     4*G[{0}, yw]*G[{yu}, yv^(-1)]*G[{0, 1, 1}, yw] - 
     4*G[{yu}, yv^(-1)]^2*G[{0, 1, 1}, yw] - 4*G[{1}, yu^(-1)]*
      G[{1/(yu*yv)}, yw]*G[{0, 1, 1}, yw] - 4*G[{1}, yv^(-1)]*
      G[{1/(yu*yv)}, yw]*G[{0, 1, 1}, yw] + 8*G[{yu}, yv^(-1)]*
      G[{1/(yu*yv)}, yw]*G[{0, 1, 1}, yw] - 6*G[{0, 1}, yu^(-1)]*
      G[{0, 1, 1}, yw] - 6*G[{0, 1}, yv^(-1)]*G[{0, 1, 1}, yw] + 
     6*G[{0, 1}, yw]*G[{0, 1, 1}, yw] + 6*G[{0, yu}, yv^(-1)]*
      G[{0, 1, 1}, yw] + 4*G[{0, 1/(yu*yv)}, yw]*G[{0, 1, 1}, yw] + 
     4*G[{0}, yu^(-1)]*G[{1}, yw]*G[{0, 1, yu^(-1)}, yw] + 
     4*G[{0}, yv^(-1)]*G[{1}, yw]*G[{0, 1, yu^(-1)}, yw] - 
     4*G[{0}, yw]*G[{1}, yw]*G[{0, 1, yu^(-1)}, yw] - 
     8*G[{1}, yv^(-1)]*G[{1}, yw]*G[{0, 1, yu^(-1)}, yw] + 
     6*G[{1}, yw]^2*G[{0, 1, yu^(-1)}, yw] - 4*G[{1}, yw]*G[{1/(yu*yv)}, yw]*
      G[{0, 1, yu^(-1)}, yw] - 2*G[{1/(yu*yv)}, yw]^2*
      G[{0, 1, yu^(-1)}, yw] - 4*G[{0}, yu^(-1)]*G[{1}, yv^(-1)]*
      G[{0, 1, yu}, yv^(-1)] - 4*G[{0}, yv^(-1)]*G[{1}, yv^(-1)]*
      G[{0, 1, yu}, yv^(-1)] + 4*G[{0}, yw]*G[{1}, yv^(-1)]*
      G[{0, 1, yu}, yv^(-1)] + 2*G[{1}, yv^(-1)]^2*G[{0, 1, yu}, yv^(-1)] - 
     4*G[{1}, yv^(-1)]*G[{1}, yw]*G[{0, 1, yu}, yv^(-1)] + 
     2*G[{1}, yw]^2*G[{0, 1, yu}, yv^(-1)] - 4*G[{1}, yv^(-1)]*
      G[{1/(yu*yv)}, yw]*G[{0, 1, yu}, yv^(-1)] - 
     4*G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1, yu}, yv^(-1)] + 
     2*G[{1/(yu*yv)}, yw]^2*G[{0, 1, yu}, yv^(-1)] + 
     4*G[{0}, yu^(-1)]*G[{1}, yw]*G[{0, 1, yv^(-1)}, yw] + 
     4*G[{0}, yv^(-1)]*G[{1}, yw]*G[{0, 1, yv^(-1)}, yw] - 
     4*G[{0}, yw]*G[{1}, yw]*G[{0, 1, yv^(-1)}, yw] - 
     8*G[{1}, yu^(-1)]*G[{1}, yw]*G[{0, 1, yv^(-1)}, yw] + 
     6*G[{1}, yw]^2*G[{0, 1, yv^(-1)}, yw] - 4*G[{1}, yw]*G[{1/(yu*yv)}, yw]*
      G[{0, 1, yv^(-1)}, yw] - 2*G[{1/(yu*yv)}, yw]^2*
      G[{0, 1, yv^(-1)}, yw] + 2*G[{0, yu^(-1)}, yw]*G[{0, 1, yv^(-1)}, yw] + 
     (Pi^2*G[{0, 1, 1/(yu*yv)}, yw])/3 + 2*G[{0}, yu^(-1)]*G[{1}, yu^(-1)]*
      G[{0, 1, 1/(yu*yv)}, yw] + 2*G[{0}, yv^(-1)]*G[{1}, yu^(-1)]*
      G[{0, 1, 1/(yu*yv)}, yw] - 2*G[{0}, yw]*G[{1}, yu^(-1)]*
      G[{0, 1, 1/(yu*yv)}, yw] - 2*G[{1}, yu^(-1)]^2*
      G[{0, 1, 1/(yu*yv)}, yw] + 2*G[{0}, yu^(-1)]*G[{1}, yv^(-1)]*
      G[{0, 1, 1/(yu*yv)}, yw] + 2*G[{0}, yv^(-1)]*G[{1}, yv^(-1)]*
      G[{0, 1, 1/(yu*yv)}, yw] - 2*G[{0}, yw]*G[{1}, yv^(-1)]*
      G[{0, 1, 1/(yu*yv)}, yw] - 2*G[{1}, yv^(-1)]^2*
      G[{0, 1, 1/(yu*yv)}, yw] - 4*G[{0}, yu^(-1)]*G[{1}, yw]*
      G[{0, 1, 1/(yu*yv)}, yw] - 4*G[{0}, yv^(-1)]*G[{1}, yw]*
      G[{0, 1, 1/(yu*yv)}, yw] + 4*G[{0}, yw]*G[{1}, yw]*
      G[{0, 1, 1/(yu*yv)}, yw] + 8*G[{1}, yu^(-1)]*G[{1}, yw]*
      G[{0, 1, 1/(yu*yv)}, yw] + 8*G[{1}, yv^(-1)]*G[{1}, yw]*
      G[{0, 1, 1/(yu*yv)}, yw] - 4*G[{0}, yu^(-1)]*G[{yu}, yv^(-1)]*
      G[{0, 1, 1/(yu*yv)}, yw] - 4*G[{0}, yv^(-1)]*G[{yu}, yv^(-1)]*
      G[{0, 1, 1/(yu*yv)}, yw] + 4*G[{0}, yw]*G[{yu}, yv^(-1)]*
      G[{0, 1, 1/(yu*yv)}, yw] - 8*G[{1}, yw]*G[{yu}, yv^(-1)]*
      G[{0, 1, 1/(yu*yv)}, yw] + 4*G[{yu}, yv^(-1)]^2*
      G[{0, 1, 1/(yu*yv)}, yw] + 4*G[{0}, yu^(-1)]*G[{1/(yu*yv)}, yw]*
      G[{0, 1, 1/(yu*yv)}, yw] + 4*G[{0}, yv^(-1)]*G[{1/(yu*yv)}, yw]*
      G[{0, 1, 1/(yu*yv)}, yw] - 4*G[{0}, yw]*G[{1/(yu*yv)}, yw]*
      G[{0, 1, 1/(yu*yv)}, yw] - 4*G[{1}, yu^(-1)]*G[{1/(yu*yv)}, yw]*
      G[{0, 1, 1/(yu*yv)}, yw] - 4*G[{1}, yv^(-1)]*G[{1/(yu*yv)}, yw]*
      G[{0, 1, 1/(yu*yv)}, yw] + 2*G[{0, 1}, yu^(-1)]*
      G[{0, 1, 1/(yu*yv)}, yw] + 2*G[{0, 1}, yv^(-1)]*
      G[{0, 1, 1/(yu*yv)}, yw] - 2*G[{0, 1}, yw]*G[{0, 1, 1/(yu*yv)}, yw] - 
     2*G[{0, yu^(-1)}, yw]*G[{0, 1, 1/(yu*yv)}, yw] - 
     2*G[{0, yu}, yv^(-1)]*G[{0, 1, 1/(yu*yv)}, yw] - 
     2*G[{0, yv^(-1)}, yw]*G[{0, 1, 1/(yu*yv)}, yw] + 
     (Pi^2*G[{0, yu^(-1), 1}, yw])/3 + 2*G[{0}, yu^(-1)]*G[{1}, yu^(-1)]*
      G[{0, yu^(-1), 1}, yw] + 2*G[{0}, yv^(-1)]*G[{1}, yu^(-1)]*
      G[{0, yu^(-1), 1}, yw] - 2*G[{0}, yw]*G[{1}, yu^(-1)]*
      G[{0, yu^(-1), 1}, yw] - 2*G[{1}, yu^(-1)]^2*G[{0, yu^(-1), 1}, yw] - 
     2*G[{0}, yu^(-1)]*G[{1}, yv^(-1)]*G[{0, yu^(-1), 1}, yw] - 
     2*G[{0}, yv^(-1)]*G[{1}, yv^(-1)]*G[{0, yu^(-1), 1}, yw] + 
     2*G[{0}, yw]*G[{1}, yv^(-1)]*G[{0, yu^(-1), 1}, yw] + 
     2*G[{1}, yv^(-1)]^2*G[{0, yu^(-1), 1}, yw] + 
     8*G[{0}, yu^(-1)]*G[{1}, yw]*G[{0, yu^(-1), 1}, yw] + 
     8*G[{0}, yv^(-1)]*G[{1}, yw]*G[{0, yu^(-1), 1}, yw] - 
     8*G[{0}, yw]*G[{1}, yw]*G[{0, yu^(-1), 1}, yw] - 
     8*G[{1}, yu^(-1)]*G[{1}, yw]*G[{0, yu^(-1), 1}, yw] - 
     8*G[{1}, yv^(-1)]*G[{1}, yw]*G[{0, yu^(-1), 1}, yw] - 
     4*G[{0}, yu^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1), 1}, yw] - 
     4*G[{0}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1), 1}, yw] + 
     4*G[{0}, yw]*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1), 1}, yw] + 
     4*G[{1}, yu^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1), 1}, yw] + 
     4*G[{1}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1), 1}, yw] + 
     2*G[{0, 1}, yu^(-1)]*G[{0, yu^(-1), 1}, yw] + 2*G[{0, 1}, yv^(-1)]*
      G[{0, yu^(-1), 1}, yw] - 2*G[{0, 1}, yw]*G[{0, yu^(-1), 1}, yw] + 
     2*G[{0, yu^(-1)}, yw]*G[{0, yu^(-1), 1}, yw] - 
     2*G[{0, yu}, yv^(-1)]*G[{0, yu^(-1), 1}, yw] - 
     4*G[{0}, yu^(-1)]*G[{1}, yw]*G[{0, yu^(-1), yu^(-1)}, yw] - 
     4*G[{0}, yv^(-1)]*G[{1}, yw]*G[{0, yu^(-1), yu^(-1)}, yw] + 
     4*G[{0}, yw]*G[{1}, yw]*G[{0, yu^(-1), yu^(-1)}, yw] + 
     8*G[{1}, yv^(-1)]*G[{1}, yw]*G[{0, yu^(-1), yu^(-1)}, yw] - 
     6*G[{1}, yw]^2*G[{0, yu^(-1), yu^(-1)}, yw] + 
     4*G[{0}, yu^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1), yu^(-1)}, yw] + 
     4*G[{0}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1), yu^(-1)}, yw] - 
     4*G[{0}, yw]*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1), yu^(-1)}, yw] - 
     8*G[{1}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1), yu^(-1)}, yw] + 
     4*G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1), yu^(-1)}, yw] + 
     2*G[{1/(yu*yv)}, yw]^2*G[{0, yu^(-1), yu^(-1)}, yw] - 
     4*G[{0, 1/(yu*yv)}, yw]*G[{0, yu^(-1), yu^(-1)}, yw] - 
     6*G[{1}, yw]^2*G[{0, yu^(-1), yv^(-1)}, yw] + 
     4*G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1), yv^(-1)}, yw] + 
     2*G[{1/(yu*yv)}, yw]^2*G[{0, yu^(-1), yv^(-1)}, yw] - 
     (Pi^2*G[{0, yu^(-1), 1/(yu*yv)}, yw])/3 - 2*G[{0}, yu^(-1)]*
      G[{1}, yu^(-1)]*G[{0, yu^(-1), 1/(yu*yv)}, yw] - 
     2*G[{0}, yv^(-1)]*G[{1}, yu^(-1)]*G[{0, yu^(-1), 1/(yu*yv)}, yw] + 
     2*G[{0}, yw]*G[{1}, yu^(-1)]*G[{0, yu^(-1), 1/(yu*yv)}, yw] + 
     2*G[{1}, yu^(-1)]^2*G[{0, yu^(-1), 1/(yu*yv)}, yw] + 
     2*G[{0}, yu^(-1)]*G[{1}, yv^(-1)]*G[{0, yu^(-1), 1/(yu*yv)}, yw] + 
     2*G[{0}, yv^(-1)]*G[{1}, yv^(-1)]*G[{0, yu^(-1), 1/(yu*yv)}, yw] - 
     2*G[{0}, yw]*G[{1}, yv^(-1)]*G[{0, yu^(-1), 1/(yu*yv)}, yw] - 
     2*G[{1}, yv^(-1)]^2*G[{0, yu^(-1), 1/(yu*yv)}, yw] - 
     4*G[{0}, yu^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1), 1/(yu*yv)}, yw] - 
     4*G[{0}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1), 1/(yu*yv)}, yw] + 
     4*G[{0}, yw]*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1), 1/(yu*yv)}, yw] + 
     4*G[{1}, yu^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1), 1/(yu*yv)}, yw] + 
     4*G[{1}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1), 1/(yu*yv)}, yw] - 
     2*G[{0, 1}, yu^(-1)]*G[{0, yu^(-1), 1/(yu*yv)}, yw] - 
     2*G[{0, 1}, yv^(-1)]*G[{0, yu^(-1), 1/(yu*yv)}, yw] + 
     2*G[{0, 1}, yw]*G[{0, yu^(-1), 1/(yu*yv)}, yw] - 
     2*G[{0, yu^(-1)}, yw]*G[{0, yu^(-1), 1/(yu*yv)}, yw] + 
     2*G[{0, yu}, yv^(-1)]*G[{0, yu^(-1), 1/(yu*yv)}, yw] + 
     (Pi^2*G[{0, yu, 1}, yv^(-1)])/3 + 2*G[{0}, yu^(-1)]*G[{1}, yu^(-1)]*
      G[{0, yu, 1}, yv^(-1)] + 2*G[{0}, yv^(-1)]*G[{1}, yu^(-1)]*
      G[{0, yu, 1}, yv^(-1)] - 2*G[{0}, yw]*G[{1}, yu^(-1)]*
      G[{0, yu, 1}, yv^(-1)] - 2*G[{1}, yu^(-1)]^2*G[{0, yu, 1}, yv^(-1)] - 
     4*G[{0}, yu^(-1)]*G[{1}, yv^(-1)]*G[{0, yu, 1}, yv^(-1)] - 
     4*G[{0}, yv^(-1)]*G[{1}, yv^(-1)]*G[{0, yu, 1}, yv^(-1)] + 
     4*G[{0}, yw]*G[{1}, yv^(-1)]*G[{0, yu, 1}, yv^(-1)] - 
     4*G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*G[{0, yu, 1}, yv^(-1)] + 
     2*G[{1}, yv^(-1)]^2*G[{0, yu, 1}, yv^(-1)] + 
     4*G[{1}, yu^(-1)]*G[{1}, yw]*G[{0, yu, 1}, yv^(-1)] - 
     4*G[{1}, yv^(-1)]*G[{1}, yw]*G[{0, yu, 1}, yv^(-1)] + 
     2*G[{1}, yw]^2*G[{0, yu, 1}, yv^(-1)] - 4*G[{1}, yv^(-1)]*
      G[{1/(yu*yv)}, yw]*G[{0, yu, 1}, yv^(-1)] - 
     4*G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{0, yu, 1}, yv^(-1)] + 
     2*G[{1/(yu*yv)}, yw]^2*G[{0, yu, 1}, yv^(-1)] + 
     2*G[{0, 1}, yu^(-1)]*G[{0, yu, 1}, yv^(-1)] + 2*G[{0, 1}, yv^(-1)]*
      G[{0, yu, 1}, yv^(-1)] - 2*G[{0, yu}, yv^(-1)]*G[{0, yu, 1}, yv^(-1)] + 
     4*G[{0}, yu^(-1)]*G[{1}, yv^(-1)]*G[{0, yu, yu}, yv^(-1)] + 
     4*G[{0}, yv^(-1)]*G[{1}, yv^(-1)]*G[{0, yu, yu}, yv^(-1)] - 
     4*G[{0}, yw]*G[{1}, yv^(-1)]*G[{0, yu, yu}, yv^(-1)] - 
     2*G[{1}, yv^(-1)]^2*G[{0, yu, yu}, yv^(-1)] - 
     4*G[{0}, yu^(-1)]*G[{1}, yw]*G[{0, yu, yu}, yv^(-1)] - 
     4*G[{0}, yv^(-1)]*G[{1}, yw]*G[{0, yu, yu}, yv^(-1)] + 
     4*G[{0}, yw]*G[{1}, yw]*G[{0, yu, yu}, yv^(-1)] + 
     4*G[{1}, yv^(-1)]*G[{1}, yw]*G[{0, yu, yu}, yv^(-1)] - 
     2*G[{1}, yw]^2*G[{0, yu, yu}, yv^(-1)] + 4*G[{0}, yu^(-1)]*
      G[{1/(yu*yv)}, yw]*G[{0, yu, yu}, yv^(-1)] + 
     4*G[{0}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, yu, yu}, yv^(-1)] - 
     4*G[{0}, yw]*G[{1/(yu*yv)}, yw]*G[{0, yu, yu}, yv^(-1)] + 
     4*G[{1}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, yu, yu}, yv^(-1)] + 
     4*G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{0, yu, yu}, yv^(-1)] - 
     2*G[{1/(yu*yv)}, yw]^2*G[{0, yu, yu}, yv^(-1)] - 
     4*G[{0, 1}, yw]*G[{0, yu, yu}, yv^(-1)] + 4*G[{0, 1/(yu*yv)}, yw]*
      G[{0, yu, yu}, yv^(-1)] + (Pi^2*G[{0, yv^(-1), 1}, yw])/3 - 
     2*G[{0}, yu^(-1)]*G[{1}, yu^(-1)]*G[{0, yv^(-1), 1}, yw] - 
     2*G[{0}, yv^(-1)]*G[{1}, yu^(-1)]*G[{0, yv^(-1), 1}, yw] + 
     2*G[{0}, yw]*G[{1}, yu^(-1)]*G[{0, yv^(-1), 1}, yw] + 
     2*G[{1}, yu^(-1)]^2*G[{0, yv^(-1), 1}, yw] + 
     2*G[{0}, yu^(-1)]*G[{1}, yv^(-1)]*G[{0, yv^(-1), 1}, yw] + 
     2*G[{0}, yv^(-1)]*G[{1}, yv^(-1)]*G[{0, yv^(-1), 1}, yw] - 
     2*G[{0}, yw]*G[{1}, yv^(-1)]*G[{0, yv^(-1), 1}, yw] - 
     2*G[{1}, yv^(-1)]^2*G[{0, yv^(-1), 1}, yw] + 
     8*G[{0}, yu^(-1)]*G[{1}, yw]*G[{0, yv^(-1), 1}, yw] + 
     8*G[{0}, yv^(-1)]*G[{1}, yw]*G[{0, yv^(-1), 1}, yw] - 
     8*G[{0}, yw]*G[{1}, yw]*G[{0, yv^(-1), 1}, yw] - 
     8*G[{1}, yu^(-1)]*G[{1}, yw]*G[{0, yv^(-1), 1}, yw] - 
     8*G[{1}, yv^(-1)]*G[{1}, yw]*G[{0, yv^(-1), 1}, yw] - 
     4*G[{0}, yu^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, yv^(-1), 1}, yw] - 
     4*G[{0}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, yv^(-1), 1}, yw] + 
     4*G[{0}, yw]*G[{1/(yu*yv)}, yw]*G[{0, yv^(-1), 1}, yw] + 
     4*G[{1}, yu^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, yv^(-1), 1}, yw] + 
     4*G[{1}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, yv^(-1), 1}, yw] + 
     2*G[{0, 1}, yu^(-1)]*G[{0, yv^(-1), 1}, yw] + 2*G[{0, 1}, yv^(-1)]*
      G[{0, yv^(-1), 1}, yw] - 2*G[{0, 1}, yw]*G[{0, yv^(-1), 1}, yw] + 
     2*G[{0, yu^(-1)}, yw]*G[{0, yv^(-1), 1}, yw] - 
     2*G[{0, yu}, yv^(-1)]*G[{0, yv^(-1), 1}, yw] + 
     2*G[{0, yv^(-1)}, yw]*G[{0, yv^(-1), 1}, yw] - 
     6*G[{1}, yw]^2*G[{0, yv^(-1), yu^(-1)}, yw] + 
     4*G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{0, yv^(-1), yu^(-1)}, yw] + 
     2*G[{1/(yu*yv)}, yw]^2*G[{0, yv^(-1), yu^(-1)}, yw] - 
     4*G[{0}, yu^(-1)]*G[{1}, yw]*G[{0, yv^(-1), yv^(-1)}, yw] - 
     4*G[{0}, yv^(-1)]*G[{1}, yw]*G[{0, yv^(-1), yv^(-1)}, yw] + 
     4*G[{0}, yw]*G[{1}, yw]*G[{0, yv^(-1), yv^(-1)}, yw] + 
     8*G[{1}, yu^(-1)]*G[{1}, yw]*G[{0, yv^(-1), yv^(-1)}, yw] - 
     6*G[{1}, yw]^2*G[{0, yv^(-1), yv^(-1)}, yw] + 
     4*G[{0}, yu^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, yv^(-1), yv^(-1)}, yw] + 
     4*G[{0}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, yv^(-1), yv^(-1)}, yw] - 
     4*G[{0}, yw]*G[{1/(yu*yv)}, yw]*G[{0, yv^(-1), yv^(-1)}, yw] - 
     8*G[{1}, yu^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, yv^(-1), yv^(-1)}, yw] + 
     4*G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{0, yv^(-1), yv^(-1)}, yw] + 
     2*G[{1/(yu*yv)}, yw]^2*G[{0, yv^(-1), yv^(-1)}, yw] - 
     4*G[{0, 1/(yu*yv)}, yw]*G[{0, yv^(-1), yv^(-1)}, yw] - 
     (Pi^2*G[{0, yv^(-1), 1/(yu*yv)}, yw])/3 + 2*G[{0}, yu^(-1)]*
      G[{1}, yu^(-1)]*G[{0, yv^(-1), 1/(yu*yv)}, yw] + 
     2*G[{0}, yv^(-1)]*G[{1}, yu^(-1)]*G[{0, yv^(-1), 1/(yu*yv)}, yw] - 
     2*G[{0}, yw]*G[{1}, yu^(-1)]*G[{0, yv^(-1), 1/(yu*yv)}, yw] - 
     2*G[{1}, yu^(-1)]^2*G[{0, yv^(-1), 1/(yu*yv)}, yw] - 
     2*G[{0}, yu^(-1)]*G[{1}, yv^(-1)]*G[{0, yv^(-1), 1/(yu*yv)}, yw] - 
     2*G[{0}, yv^(-1)]*G[{1}, yv^(-1)]*G[{0, yv^(-1), 1/(yu*yv)}, yw] + 
     2*G[{0}, yw]*G[{1}, yv^(-1)]*G[{0, yv^(-1), 1/(yu*yv)}, yw] + 
     2*G[{1}, yv^(-1)]^2*G[{0, yv^(-1), 1/(yu*yv)}, yw] - 
     4*G[{0}, yu^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, yv^(-1), 1/(yu*yv)}, yw] - 
     4*G[{0}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, yv^(-1), 1/(yu*yv)}, yw] + 
     4*G[{0}, yw]*G[{1/(yu*yv)}, yw]*G[{0, yv^(-1), 1/(yu*yv)}, yw] + 
     4*G[{1}, yu^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, yv^(-1), 1/(yu*yv)}, yw] + 
     4*G[{1}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, yv^(-1), 1/(yu*yv)}, yw] - 
     2*G[{0, 1}, yu^(-1)]*G[{0, yv^(-1), 1/(yu*yv)}, yw] - 
     2*G[{0, 1}, yv^(-1)]*G[{0, yv^(-1), 1/(yu*yv)}, yw] + 
     2*G[{0, 1}, yw]*G[{0, yv^(-1), 1/(yu*yv)}, yw] - 
     2*G[{0, yu^(-1)}, yw]*G[{0, yv^(-1), 1/(yu*yv)}, yw] + 
     2*G[{0, yu}, yv^(-1)]*G[{0, yv^(-1), 1/(yu*yv)}, yw] - 
     2*G[{0, yv^(-1)}, yw]*G[{0, yv^(-1), 1/(yu*yv)}, yw] + 
     (Pi^2*G[{0, 1/(yu*yv), 1}, yw])/3 + 2*G[{0}, yu^(-1)]*G[{1}, yu^(-1)]*
      G[{0, 1/(yu*yv), 1}, yw] + 2*G[{0}, yv^(-1)]*G[{1}, yu^(-1)]*
      G[{0, 1/(yu*yv), 1}, yw] - 2*G[{0}, yw]*G[{1}, yu^(-1)]*
      G[{0, 1/(yu*yv), 1}, yw] - 2*G[{1}, yu^(-1)]^2*
      G[{0, 1/(yu*yv), 1}, yw] + 2*G[{0}, yu^(-1)]*G[{1}, yv^(-1)]*
      G[{0, 1/(yu*yv), 1}, yw] + 2*G[{0}, yv^(-1)]*G[{1}, yv^(-1)]*
      G[{0, 1/(yu*yv), 1}, yw] - 2*G[{0}, yw]*G[{1}, yv^(-1)]*
      G[{0, 1/(yu*yv), 1}, yw] - 2*G[{1}, yv^(-1)]^2*
      G[{0, 1/(yu*yv), 1}, yw] - 8*G[{0}, yu^(-1)]*G[{1}, yw]*
      G[{0, 1/(yu*yv), 1}, yw] - 8*G[{0}, yv^(-1)]*G[{1}, yw]*
      G[{0, 1/(yu*yv), 1}, yw] + 8*G[{0}, yw]*G[{1}, yw]*
      G[{0, 1/(yu*yv), 1}, yw] + 8*G[{1}, yu^(-1)]*G[{1}, yw]*
      G[{0, 1/(yu*yv), 1}, yw] + 8*G[{1}, yv^(-1)]*G[{1}, yw]*
      G[{0, 1/(yu*yv), 1}, yw] - 4*G[{0}, yu^(-1)]*G[{yu}, yv^(-1)]*
      G[{0, 1/(yu*yv), 1}, yw] - 4*G[{0}, yv^(-1)]*G[{yu}, yv^(-1)]*
      G[{0, 1/(yu*yv), 1}, yw] + 4*G[{0}, yw]*G[{yu}, yv^(-1)]*
      G[{0, 1/(yu*yv), 1}, yw] + 4*G[{yu}, yv^(-1)]^2*
      G[{0, 1/(yu*yv), 1}, yw] + 8*G[{0}, yu^(-1)]*G[{1/(yu*yv)}, yw]*
      G[{0, 1/(yu*yv), 1}, yw] + 8*G[{0}, yv^(-1)]*G[{1/(yu*yv)}, yw]*
      G[{0, 1/(yu*yv), 1}, yw] - 8*G[{0}, yw]*G[{1/(yu*yv)}, yw]*
      G[{0, 1/(yu*yv), 1}, yw] - 4*G[{1}, yu^(-1)]*G[{1/(yu*yv)}, yw]*
      G[{0, 1/(yu*yv), 1}, yw] - 4*G[{1}, yv^(-1)]*G[{1/(yu*yv)}, yw]*
      G[{0, 1/(yu*yv), 1}, yw] - 8*G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw]*
      G[{0, 1/(yu*yv), 1}, yw] + 2*G[{0, 1}, yu^(-1)]*
      G[{0, 1/(yu*yv), 1}, yw] + 2*G[{0, 1}, yv^(-1)]*
      G[{0, 1/(yu*yv), 1}, yw] - 2*G[{0, 1}, yw]*G[{0, 1/(yu*yv), 1}, yw] + 
     2*G[{0, yu^(-1)}, yw]*G[{0, 1/(yu*yv), 1}, yw] - 
     2*G[{0, yu}, yv^(-1)]*G[{0, 1/(yu*yv), 1}, yw] + 
     2*G[{0, yv^(-1)}, yw]*G[{0, 1/(yu*yv), 1}, yw] - 
     2*G[{0, 1/(yu*yv)}, yw]*G[{0, 1/(yu*yv), 1}, yw] + 
     6*G[{1}, yw]^2*G[{0, 1/(yu*yv), yu^(-1)}, yw] - 
     4*G[{0}, yu^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv), yu^(-1)}, yw] - 
     4*G[{0}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv), yu^(-1)}, yw] + 
     4*G[{0}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv), yu^(-1)}, yw] + 
     8*G[{1}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv), yu^(-1)}, yw] - 
     4*G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv), yu^(-1)}, yw] - 
     2*G[{1/(yu*yv)}, yw]^2*G[{0, 1/(yu*yv), yu^(-1)}, yw] + 
     6*G[{1}, yw]^2*G[{0, 1/(yu*yv), yv^(-1)}, yw] - 
     4*G[{0}, yu^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv), yv^(-1)}, yw] - 
     4*G[{0}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv), yv^(-1)}, yw] + 
     4*G[{0}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv), yv^(-1)}, yw] + 
     8*G[{1}, yu^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv), yv^(-1)}, yw] - 
     4*G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv), yv^(-1)}, yw] - 
     2*G[{1/(yu*yv)}, yw]^2*G[{0, 1/(yu*yv), yv^(-1)}, yw] + 
     (Pi^2*G[{0, 1/(yu*yv), 1/(yu*yv)}, yw])/3 - 2*G[{0}, yu^(-1)]*
      G[{1}, yu^(-1)]*G[{0, 1/(yu*yv), 1/(yu*yv)}, yw] - 
     2*G[{0}, yv^(-1)]*G[{1}, yu^(-1)]*G[{0, 1/(yu*yv), 1/(yu*yv)}, yw] + 
     2*G[{0}, yw]*G[{1}, yu^(-1)]*G[{0, 1/(yu*yv), 1/(yu*yv)}, yw] + 
     2*G[{1}, yu^(-1)]^2*G[{0, 1/(yu*yv), 1/(yu*yv)}, yw] - 
     2*G[{0}, yu^(-1)]*G[{1}, yv^(-1)]*G[{0, 1/(yu*yv), 1/(yu*yv)}, yw] - 
     2*G[{0}, yv^(-1)]*G[{1}, yv^(-1)]*G[{0, 1/(yu*yv), 1/(yu*yv)}, yw] + 
     2*G[{0}, yw]*G[{1}, yv^(-1)]*G[{0, 1/(yu*yv), 1/(yu*yv)}, yw] + 
     2*G[{1}, yv^(-1)]^2*G[{0, 1/(yu*yv), 1/(yu*yv)}, yw] + 
     4*G[{0}, yu^(-1)]*G[{1}, yw]*G[{0, 1/(yu*yv), 1/(yu*yv)}, yw] + 
     4*G[{0}, yv^(-1)]*G[{1}, yw]*G[{0, 1/(yu*yv), 1/(yu*yv)}, yw] - 
     4*G[{0}, yw]*G[{1}, yw]*G[{0, 1/(yu*yv), 1/(yu*yv)}, yw] - 
     8*G[{1}, yu^(-1)]*G[{1}, yw]*G[{0, 1/(yu*yv), 1/(yu*yv)}, yw] - 
     8*G[{1}, yv^(-1)]*G[{1}, yw]*G[{0, 1/(yu*yv), 1/(yu*yv)}, yw] + 
     4*G[{0}, yu^(-1)]*G[{yu}, yv^(-1)]*G[{0, 1/(yu*yv), 1/(yu*yv)}, yw] + 
     4*G[{0}, yv^(-1)]*G[{yu}, yv^(-1)]*G[{0, 1/(yu*yv), 1/(yu*yv)}, yw] - 
     4*G[{0}, yw]*G[{yu}, yv^(-1)]*G[{0, 1/(yu*yv), 1/(yu*yv)}, yw] + 
     8*G[{1}, yw]*G[{yu}, yv^(-1)]*G[{0, 1/(yu*yv), 1/(yu*yv)}, yw] - 
     4*G[{yu}, yv^(-1)]^2*G[{0, 1/(yu*yv), 1/(yu*yv)}, yw] + 
     4*G[{0}, yu^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv), 1/(yu*yv)}, yw] + 
     4*G[{0}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv), 1/(yu*yv)}, yw] - 
     4*G[{0}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv), 1/(yu*yv)}, yw] - 
     4*G[{1}, yu^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv), 1/(yu*yv)}, yw] - 
     4*G[{1}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv), 1/(yu*yv)}, yw] + 
     2*G[{0, 1}, yu^(-1)]*G[{0, 1/(yu*yv), 1/(yu*yv)}, yw] + 
     2*G[{0, 1}, yv^(-1)]*G[{0, 1/(yu*yv), 1/(yu*yv)}, yw] - 
     2*G[{0, 1}, yw]*G[{0, 1/(yu*yv), 1/(yu*yv)}, yw] + 
     2*G[{0, yu^(-1)}, yw]*G[{0, 1/(yu*yv), 1/(yu*yv)}, yw] - 
     2*G[{0, yu}, yv^(-1)]*G[{0, 1/(yu*yv), 1/(yu*yv)}, yw] + 
     2*G[{0, yv^(-1)}, yw]*G[{0, 1/(yu*yv), 1/(yu*yv)}, yw] - 
     2*G[{0, 1/(yu*yv)}, yw]*G[{0, 1/(yu*yv), 1/(yu*yv)}, yw] + 
     (2*Pi^2*G[{1, 1, yu^(-1)}, yw])/3 + 4*G[{0}, yu^(-1)]*G[{1}, yu^(-1)]*
      G[{1, 1, yu^(-1)}, yw] + 4*G[{0}, yv^(-1)]*G[{1}, yu^(-1)]*
      G[{1, 1, yu^(-1)}, yw] - 4*G[{0}, yw]*G[{1}, yu^(-1)]*
      G[{1, 1, yu^(-1)}, yw] - 4*G[{1}, yu^(-1)]^2*G[{1, 1, yu^(-1)}, yw] - 
     4*G[{0}, yu^(-1)]*G[{1}, yv^(-1)]*G[{1, 1, yu^(-1)}, yw] - 
     4*G[{0}, yv^(-1)]*G[{1}, yv^(-1)]*G[{1, 1, yu^(-1)}, yw] + 
     4*G[{0}, yw]*G[{1}, yv^(-1)]*G[{1, 1, yu^(-1)}, yw] + 
     4*G[{1}, yv^(-1)]^2*G[{1, 1, yu^(-1)}, yw] - 
     4*G[{0}, yu^(-1)]*G[{1}, yw]*G[{1, 1, yu^(-1)}, yw] - 
     4*G[{0}, yv^(-1)]*G[{1}, yw]*G[{1, 1, yu^(-1)}, yw] + 
     4*G[{0}, yw]*G[{1}, yw]*G[{1, 1, yu^(-1)}, yw] - 
     4*G[{1}, yw]^2*G[{1, 1, yu^(-1)}, yw] + 8*G[{1}, yw]*G[{yu}, yv^(-1)]*
      G[{1, 1, yu^(-1)}, yw] - 4*G[{0}, yu^(-1)]*G[{1/(yu*yv)}, yw]*
      G[{1, 1, yu^(-1)}, yw] - 4*G[{0}, yv^(-1)]*G[{1/(yu*yv)}, yw]*
      G[{1, 1, yu^(-1)}, yw] + 4*G[{0}, yw]*G[{1/(yu*yv)}, yw]*
      G[{1, 1, yu^(-1)}, yw] + 4*G[{1}, yu^(-1)]*G[{1/(yu*yv)}, yw]*
      G[{1, 1, yu^(-1)}, yw] + 8*G[{1}, yv^(-1)]*G[{1/(yu*yv)}, yw]*
      G[{1, 1, yu^(-1)}, yw] + 4*G[{1}, yw]*G[{1/(yu*yv)}, yw]*
      G[{1, 1, yu^(-1)}, yw] - 4*G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw]*
      G[{1, 1, yu^(-1)}, yw] + 2*G[{1/(yu*yv)}, yw]^2*
      G[{1, 1, yu^(-1)}, yw] + 4*G[{0, 1}, yu^(-1)]*G[{1, 1, yu^(-1)}, yw] + 
     4*G[{0, 1}, yv^(-1)]*G[{1, 1, yu^(-1)}, yw] - 
     4*G[{0, 1}, yw]*G[{1, 1, yu^(-1)}, yw] + 4*G[{0, yu^(-1)}, yw]*
      G[{1, 1, yu^(-1)}, yw] - 4*G[{0, yu}, yv^(-1)]*G[{1, 1, yu^(-1)}, yw] + 
     4*G[{0, yv^(-1)}, yw]*G[{1, 1, yu^(-1)}, yw] - 
     4*G[{0, 1/(yu*yv)}, yw]*G[{1, 1, yu^(-1)}, yw] + 
     (2*Pi^2*G[{1, 1, yu}, yv^(-1)])/3 + 4*G[{0}, yu^(-1)]*G[{1}, yu^(-1)]*
      G[{1, 1, yu}, yv^(-1)] + 4*G[{0}, yv^(-1)]*G[{1}, yu^(-1)]*
      G[{1, 1, yu}, yv^(-1)] - 4*G[{0}, yw]*G[{1}, yu^(-1)]*
      G[{1, 1, yu}, yv^(-1)] - 4*G[{1}, yu^(-1)]^2*G[{1, 1, yu}, yv^(-1)] + 
     4*G[{0}, yu^(-1)]*G[{1}, yv^(-1)]*G[{1, 1, yu}, yv^(-1)] + 
     4*G[{0}, yv^(-1)]*G[{1}, yv^(-1)]*G[{1, 1, yu}, yv^(-1)] - 
     4*G[{0}, yw]*G[{1}, yv^(-1)]*G[{1, 1, yu}, yv^(-1)] - 
     4*G[{1}, yv^(-1)]^2*G[{1, 1, yu}, yv^(-1)] + 
     4*G[{1}, yu^(-1)]*G[{1}, yw]*G[{1, 1, yu}, yv^(-1)] + 
     4*G[{1}, yv^(-1)]*G[{1}, yw]*G[{1, 1, yu}, yv^(-1)] + 
     2*G[{1}, yw]^2*G[{1, 1, yu}, yv^(-1)] + 4*G[{1}, yu^(-1)]*
      G[{1/(yu*yv)}, yw]*G[{1, 1, yu}, yv^(-1)] + 
     4*G[{1}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{1, 1, yu}, yv^(-1)] - 
     4*G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{1, 1, yu}, yv^(-1)] + 
     2*G[{1/(yu*yv)}, yw]^2*G[{1, 1, yu}, yv^(-1)] + 
     4*G[{0, 1}, yu^(-1)]*G[{1, 1, yu}, yv^(-1)] + 4*G[{0, 1}, yv^(-1)]*
      G[{1, 1, yu}, yv^(-1)] - 4*G[{0, yu}, yv^(-1)]*G[{1, 1, yu}, yv^(-1)] + 
     (2*Pi^2*G[{1, 1, yv^(-1)}, yw])/3 - 4*G[{0}, yu^(-1)]*G[{1}, yu^(-1)]*
      G[{1, 1, yv^(-1)}, yw] - 4*G[{0}, yv^(-1)]*G[{1}, yu^(-1)]*
      G[{1, 1, yv^(-1)}, yw] + 4*G[{0}, yw]*G[{1}, yu^(-1)]*
      G[{1, 1, yv^(-1)}, yw] + 4*G[{1}, yu^(-1)]^2*G[{1, 1, yv^(-1)}, yw] + 
     4*G[{0}, yu^(-1)]*G[{1}, yv^(-1)]*G[{1, 1, yv^(-1)}, yw] + 
     4*G[{0}, yv^(-1)]*G[{1}, yv^(-1)]*G[{1, 1, yv^(-1)}, yw] - 
     4*G[{0}, yw]*G[{1}, yv^(-1)]*G[{1, 1, yv^(-1)}, yw] - 
     4*G[{1}, yv^(-1)]^2*G[{1, 1, yv^(-1)}, yw] - 
     4*G[{0}, yu^(-1)]*G[{1}, yw]*G[{1, 1, yv^(-1)}, yw] - 
     4*G[{0}, yv^(-1)]*G[{1}, yw]*G[{1, 1, yv^(-1)}, yw] + 
     4*G[{0}, yw]*G[{1}, yw]*G[{1, 1, yv^(-1)}, yw] - 
     4*G[{1}, yw]^2*G[{1, 1, yv^(-1)}, yw] + 8*G[{1}, yw]*G[{yu}, yv^(-1)]*
      G[{1, 1, yv^(-1)}, yw] - 4*G[{0}, yu^(-1)]*G[{1/(yu*yv)}, yw]*
      G[{1, 1, yv^(-1)}, yw] - 4*G[{0}, yv^(-1)]*G[{1/(yu*yv)}, yw]*
      G[{1, 1, yv^(-1)}, yw] + 4*G[{0}, yw]*G[{1/(yu*yv)}, yw]*
      G[{1, 1, yv^(-1)}, yw] + 8*G[{1}, yu^(-1)]*G[{1/(yu*yv)}, yw]*
      G[{1, 1, yv^(-1)}, yw] + 4*G[{1}, yv^(-1)]*G[{1/(yu*yv)}, yw]*
      G[{1, 1, yv^(-1)}, yw] + 4*G[{1}, yw]*G[{1/(yu*yv)}, yw]*
      G[{1, 1, yv^(-1)}, yw] - 4*G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw]*
      G[{1, 1, yv^(-1)}, yw] + 2*G[{1/(yu*yv)}, yw]^2*
      G[{1, 1, yv^(-1)}, yw] + 4*G[{0, 1}, yu^(-1)]*G[{1, 1, yv^(-1)}, yw] + 
     4*G[{0, 1}, yv^(-1)]*G[{1, 1, yv^(-1)}, yw] - 
     4*G[{0, 1}, yw]*G[{1, 1, yv^(-1)}, yw] + 4*G[{0, yu^(-1)}, yw]*
      G[{1, 1, yv^(-1)}, yw] - 4*G[{0, yu}, yv^(-1)]*G[{1, 1, yv^(-1)}, yw] + 
     4*G[{0, yv^(-1)}, yw]*G[{1, 1, yv^(-1)}, yw] - 
     4*G[{0, 1/(yu*yv)}, yw]*G[{1, 1, yv^(-1)}, yw] + 
     (2*Pi^2*G[{1, 1, 1/(yu*yv)}, yw])/3 + 4*G[{0}, yu^(-1)]*G[{1}, yu^(-1)]*
      G[{1, 1, 1/(yu*yv)}, yw] + 4*G[{0}, yv^(-1)]*G[{1}, yu^(-1)]*
      G[{1, 1, 1/(yu*yv)}, yw] - 4*G[{0}, yw]*G[{1}, yu^(-1)]*
      G[{1, 1, 1/(yu*yv)}, yw] - 4*G[{1}, yu^(-1)]^2*
      G[{1, 1, 1/(yu*yv)}, yw] + 4*G[{0}, yu^(-1)]*G[{1}, yv^(-1)]*
      G[{1, 1, 1/(yu*yv)}, yw] + 4*G[{0}, yv^(-1)]*G[{1}, yv^(-1)]*
      G[{1, 1, 1/(yu*yv)}, yw] - 4*G[{0}, yw]*G[{1}, yv^(-1)]*
      G[{1, 1, 1/(yu*yv)}, yw] - 4*G[{1}, yv^(-1)]^2*
      G[{1, 1, 1/(yu*yv)}, yw] + 4*G[{0}, yu^(-1)]*G[{1}, yw]*
      G[{1, 1, 1/(yu*yv)}, yw] + 4*G[{0}, yv^(-1)]*G[{1}, yw]*
      G[{1, 1, 1/(yu*yv)}, yw] - 4*G[{0}, yw]*G[{1}, yw]*
      G[{1, 1, 1/(yu*yv)}, yw] + 4*G[{1}, yw]^2*G[{1, 1, 1/(yu*yv)}, yw] - 
     8*G[{0}, yu^(-1)]*G[{yu}, yv^(-1)]*G[{1, 1, 1/(yu*yv)}, yw] - 
     8*G[{0}, yv^(-1)]*G[{yu}, yv^(-1)]*G[{1, 1, 1/(yu*yv)}, yw] + 
     8*G[{0}, yw]*G[{yu}, yv^(-1)]*G[{1, 1, 1/(yu*yv)}, yw] - 
     8*G[{1}, yw]*G[{yu}, yv^(-1)]*G[{1, 1, 1/(yu*yv)}, yw] + 
     8*G[{yu}, yv^(-1)]^2*G[{1, 1, 1/(yu*yv)}, yw] + 
     8*G[{0}, yu^(-1)]*G[{1/(yu*yv)}, yw]*G[{1, 1, 1/(yu*yv)}, yw] + 
     8*G[{0}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{1, 1, 1/(yu*yv)}, yw] - 
     8*G[{0}, yw]*G[{1/(yu*yv)}, yw]*G[{1, 1, 1/(yu*yv)}, yw] - 
     4*G[{1}, yu^(-1)]*G[{1/(yu*yv)}, yw]*G[{1, 1, 1/(yu*yv)}, yw] - 
     4*G[{1}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{1, 1, 1/(yu*yv)}, yw] + 
     8*G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{1, 1, 1/(yu*yv)}, yw] - 
     8*G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{1, 1, 1/(yu*yv)}, yw] - 
     4*G[{1/(yu*yv)}, yw]^2*G[{1, 1, 1/(yu*yv)}, yw] + 
     4*G[{0, 1}, yu^(-1)]*G[{1, 1, 1/(yu*yv)}, yw] + 
     4*G[{0, 1}, yv^(-1)]*G[{1, 1, 1/(yu*yv)}, yw] - 
     4*G[{0, 1}, yw]*G[{1, 1, 1/(yu*yv)}, yw] + 4*G[{0, yu^(-1)}, yw]*
      G[{1, 1, 1/(yu*yv)}, yw] - 4*G[{0, yu}, yv^(-1)]*
      G[{1, 1, 1/(yu*yv)}, yw] + 4*G[{0, yv^(-1)}, yw]*
      G[{1, 1, 1/(yu*yv)}, yw] - 4*G[{0, 1/(yu*yv)}, yw]*
      G[{1, 1, 1/(yu*yv)}, yw] - 2*G[{1/(yu*yv)}, yw]^2*
      G[{1, yu^(-1), yv^(-1)}, yw] + 4*G[{0}, yu^(-1)]*G[{1/(yu*yv)}, yw]*
      G[{1, yu^(-1), 1/(yu*yv)}, yw] + 4*G[{0}, yv^(-1)]*G[{1/(yu*yv)}, yw]*
      G[{1, yu^(-1), 1/(yu*yv)}, yw] - 4*G[{0}, yw]*G[{1/(yu*yv)}, yw]*
      G[{1, yu^(-1), 1/(yu*yv)}, yw] - 4*G[{1}, yu^(-1)]*G[{1/(yu*yv)}, yw]*
      G[{1, yu^(-1), 1/(yu*yv)}, yw] + 4*G[{1}, yw]*G[{1/(yu*yv)}, yw]*
      G[{1, yu^(-1), 1/(yu*yv)}, yw] - 4*G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw]*
      G[{1, yu^(-1), 1/(yu*yv)}, yw] - 2*G[{1/(yu*yv)}, yw]^2*
      G[{1, yv^(-1), yu^(-1)}, yw] + 4*G[{0}, yu^(-1)]*G[{1/(yu*yv)}, yw]*
      G[{1, yv^(-1), 1/(yu*yv)}, yw] + 4*G[{0}, yv^(-1)]*G[{1/(yu*yv)}, yw]*
      G[{1, yv^(-1), 1/(yu*yv)}, yw] - 4*G[{0}, yw]*G[{1/(yu*yv)}, yw]*
      G[{1, yv^(-1), 1/(yu*yv)}, yw] - 4*G[{1}, yv^(-1)]*G[{1/(yu*yv)}, yw]*
      G[{1, yv^(-1), 1/(yu*yv)}, yw] + 4*G[{1}, yw]*G[{1/(yu*yv)}, yw]*
      G[{1, yv^(-1), 1/(yu*yv)}, yw] - 4*G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw]*
      G[{1, yv^(-1), 1/(yu*yv)}, yw] - 2*G[{1/(yu*yv)}, yw]^2*
      G[{1, 1/(yu*yv), yu^(-1)}, yw] - 2*G[{1/(yu*yv)}, yw]^2*
      G[{1, 1/(yu*yv), yv^(-1)}, yw] + 
     (2*Pi^2*G[{1, 1/(yu*yv), 1/(yu*yv)}, yw])/3 + 
     4*G[{0}, yu^(-1)]*G[{1}, yu^(-1)]*G[{1, 1/(yu*yv), 1/(yu*yv)}, yw] + 
     4*G[{0}, yv^(-1)]*G[{1}, yu^(-1)]*G[{1, 1/(yu*yv), 1/(yu*yv)}, yw] - 
     4*G[{0}, yw]*G[{1}, yu^(-1)]*G[{1, 1/(yu*yv), 1/(yu*yv)}, yw] - 
     4*G[{1}, yu^(-1)]^2*G[{1, 1/(yu*yv), 1/(yu*yv)}, yw] + 
     4*G[{0}, yu^(-1)]*G[{1}, yv^(-1)]*G[{1, 1/(yu*yv), 1/(yu*yv)}, yw] + 
     4*G[{0}, yv^(-1)]*G[{1}, yv^(-1)]*G[{1, 1/(yu*yv), 1/(yu*yv)}, yw] - 
     4*G[{0}, yw]*G[{1}, yv^(-1)]*G[{1, 1/(yu*yv), 1/(yu*yv)}, yw] - 
     4*G[{1}, yv^(-1)]^2*G[{1, 1/(yu*yv), 1/(yu*yv)}, yw] + 
     4*G[{0}, yu^(-1)]*G[{1}, yw]*G[{1, 1/(yu*yv), 1/(yu*yv)}, yw] + 
     4*G[{0}, yv^(-1)]*G[{1}, yw]*G[{1, 1/(yu*yv), 1/(yu*yv)}, yw] - 
     4*G[{0}, yw]*G[{1}, yw]*G[{1, 1/(yu*yv), 1/(yu*yv)}, yw] + 
     4*G[{1}, yw]^2*G[{1, 1/(yu*yv), 1/(yu*yv)}, yw] - 
     8*G[{0}, yu^(-1)]*G[{yu}, yv^(-1)]*G[{1, 1/(yu*yv), 1/(yu*yv)}, yw] - 
     8*G[{0}, yv^(-1)]*G[{yu}, yv^(-1)]*G[{1, 1/(yu*yv), 1/(yu*yv)}, yw] + 
     8*G[{0}, yw]*G[{yu}, yv^(-1)]*G[{1, 1/(yu*yv), 1/(yu*yv)}, yw] - 
     8*G[{1}, yw]*G[{yu}, yv^(-1)]*G[{1, 1/(yu*yv), 1/(yu*yv)}, yw] + 
     8*G[{yu}, yv^(-1)]^2*G[{1, 1/(yu*yv), 1/(yu*yv)}, yw] - 
     4*G[{1}, yu^(-1)]*G[{1/(yu*yv)}, yw]*G[{1, 1/(yu*yv), 1/(yu*yv)}, yw] - 
     4*G[{1}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{1, 1/(yu*yv), 1/(yu*yv)}, yw] - 
     8*G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{1, 1/(yu*yv), 1/(yu*yv)}, yw] + 
     8*G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{1, 1/(yu*yv), 1/(yu*yv)}, yw] + 
     4*G[{0, 1}, yu^(-1)]*G[{1, 1/(yu*yv), 1/(yu*yv)}, yw] + 
     4*G[{0, 1}, yv^(-1)]*G[{1, 1/(yu*yv), 1/(yu*yv)}, yw] - 
     4*G[{0, 1}, yw]*G[{1, 1/(yu*yv), 1/(yu*yv)}, yw] + 
     4*G[{0, yu^(-1)}, yw]*G[{1, 1/(yu*yv), 1/(yu*yv)}, yw] - 
     4*G[{0, yu}, yv^(-1)]*G[{1, 1/(yu*yv), 1/(yu*yv)}, yw] + 
     4*G[{0, yv^(-1)}, yw]*G[{1, 1/(yu*yv), 1/(yu*yv)}, yw] - 
     4*G[{0, 1/(yu*yv)}, yw]*G[{1, 1/(yu*yv), 1/(yu*yv)}, yw] - 
     8*G[{1, 1/(yu*yv)}, yw]*G[{1, 1/(yu*yv), 1/(yu*yv)}, yw] - 
     8*G[{0}, yu^(-1)]*G[{1/(yu*yv)}, yw]*G[{yu^(-1), yu^(-1), 1/(yu*yv)}, 
       yw] - 8*G[{0}, yv^(-1)]*G[{1/(yu*yv)}, yw]*
      G[{yu^(-1), yu^(-1), 1/(yu*yv)}, yw] + 8*G[{0}, yw]*G[{1/(yu*yv)}, yw]*
      G[{yu^(-1), yu^(-1), 1/(yu*yv)}, yw] + 16*G[{1}, yv^(-1)]*
      G[{1/(yu*yv)}, yw]*G[{yu^(-1), yu^(-1), 1/(yu*yv)}, yw] - 
     16*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{yu^(-1), yu^(-1), 1/(yu*yv)}, 
       yw] - 4*G[{1/(yu*yv)}, yw]^2*G[{yu^(-1), yu^(-1), 1/(yu*yv)}, yw] + 
     2*G[{1/(yu*yv)}, yw]^2*G[{yu^(-1), 1/(yu*yv), yv^(-1)}, yw] - 
     (2*Pi^2*G[{yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/3 - 
     4*G[{0}, yu^(-1)]*G[{1}, yu^(-1)]*G[{yu^(-1), 1/(yu*yv), 1/(yu*yv)}, 
       yw] - 4*G[{0}, yv^(-1)]*G[{1}, yu^(-1)]*
      G[{yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] + 4*G[{0}, yw]*G[{1}, yu^(-1)]*
      G[{yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] + 4*G[{1}, yu^(-1)]^2*
      G[{yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] + 4*G[{0}, yu^(-1)]*
      G[{1}, yv^(-1)]*G[{yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] + 
     4*G[{0}, yv^(-1)]*G[{1}, yv^(-1)]*G[{yu^(-1), 1/(yu*yv), 1/(yu*yv)}, 
       yw] - 4*G[{0}, yw]*G[{1}, yv^(-1)]*G[{yu^(-1), 1/(yu*yv), 1/(yu*yv)}, 
       yw] - 4*G[{1}, yv^(-1)]^2*G[{yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] + 
     4*G[{0}, yu^(-1)]*G[{1}, yw]*G[{yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] + 
     4*G[{0}, yv^(-1)]*G[{1}, yw]*G[{yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] - 
     4*G[{0}, yw]*G[{1}, yw]*G[{yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] + 
     4*G[{1}, yw]^2*G[{yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] - 
     8*G[{0}, yu^(-1)]*G[{yu^(-1)}, yw]*G[{yu^(-1), 1/(yu*yv), 1/(yu*yv)}, 
       yw] - 8*G[{0}, yv^(-1)]*G[{yu^(-1)}, yw]*
      G[{yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] + 8*G[{0}, yw]*G[{yu^(-1)}, yw]*
      G[{yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] + 16*G[{1}, yv^(-1)]*
      G[{yu^(-1)}, yw]*G[{yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] - 
     8*G[{yu^(-1)}, yw]^2*G[{yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] - 
     8*G[{1}, yw]*G[{yu}, yv^(-1)]*G[{yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] - 
     4*G[{0}, yu^(-1)]*G[{1/(yu*yv)}, yw]*G[{yu^(-1), 1/(yu*yv), 1/(yu*yv)}, 
       yw] - 4*G[{0}, yv^(-1)]*G[{1/(yu*yv)}, yw]*
      G[{yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] + 
     4*G[{0}, yw]*G[{1/(yu*yv)}, yw]*G[{yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] + 
     4*G[{1}, yu^(-1)]*G[{1/(yu*yv)}, yw]*G[{yu^(-1), 1/(yu*yv), 1/(yu*yv)}, 
       yw] + 8*G[{1}, yv^(-1)]*G[{1/(yu*yv)}, yw]*
      G[{yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] + 
     4*G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] - 
     8*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{yu^(-1), 1/(yu*yv), 1/(yu*yv)}, 
       yw] - 4*G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw]*
      G[{yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] - 4*G[{0, 1}, yu^(-1)]*
      G[{yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] - 4*G[{0, 1}, yv^(-1)]*
      G[{yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] + 4*G[{0, 1}, yw]*
      G[{yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] - 4*G[{0, yu^(-1)}, yw]*
      G[{yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] + 4*G[{0, yu}, yv^(-1)]*
      G[{yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] - 4*G[{0, yv^(-1)}, yw]*
      G[{yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] + 4*G[{0, 1/(yu*yv)}, yw]*
      G[{yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] + 8*G[{1, 1/(yu*yv)}, yw]*
      G[{yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] - 8*G[{yu^(-1), 1/(yu*yv)}, yw]*
      G[{yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] - 8*G[{0}, yu^(-1)]*
      G[{1/(yu*yv)}, yw]*G[{yv^(-1), yv^(-1), 1/(yu*yv)}, yw] - 
     8*G[{0}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{yv^(-1), yv^(-1), 1/(yu*yv)}, 
       yw] + 8*G[{0}, yw]*G[{1/(yu*yv)}, yw]*G[{yv^(-1), yv^(-1), 1/(yu*yv)}, 
       yw] + 16*G[{1}, yu^(-1)]*G[{1/(yu*yv)}, yw]*
      G[{yv^(-1), yv^(-1), 1/(yu*yv)}, yw] - 16*G[{yv^(-1)}, yw]*
      G[{1/(yu*yv)}, yw]*G[{yv^(-1), yv^(-1), 1/(yu*yv)}, yw] - 
     4*G[{1/(yu*yv)}, yw]^2*G[{yv^(-1), yv^(-1), 1/(yu*yv)}, yw] - 
     (2*Pi^2*G[{yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/3 + 
     4*G[{0}, yu^(-1)]*G[{1}, yu^(-1)]*G[{yv^(-1), 1/(yu*yv), 1/(yu*yv)}, 
       yw] + 4*G[{0}, yv^(-1)]*G[{1}, yu^(-1)]*
      G[{yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] - 4*G[{0}, yw]*G[{1}, yu^(-1)]*
      G[{yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] - 4*G[{1}, yu^(-1)]^2*
      G[{yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] - 4*G[{0}, yu^(-1)]*
      G[{1}, yv^(-1)]*G[{yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] - 
     4*G[{0}, yv^(-1)]*G[{1}, yv^(-1)]*G[{yv^(-1), 1/(yu*yv), 1/(yu*yv)}, 
       yw] + 4*G[{0}, yw]*G[{1}, yv^(-1)]*G[{yv^(-1), 1/(yu*yv), 1/(yu*yv)}, 
       yw] + 4*G[{1}, yv^(-1)]^2*G[{yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] + 
     4*G[{0}, yu^(-1)]*G[{1}, yw]*G[{yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] + 
     4*G[{0}, yv^(-1)]*G[{1}, yw]*G[{yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] - 
     4*G[{0}, yw]*G[{1}, yw]*G[{yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] + 
     4*G[{1}, yw]^2*G[{yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] - 
     8*G[{1}, yw]*G[{yu}, yv^(-1)]*G[{yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] - 
     8*G[{0}, yu^(-1)]*G[{yv^(-1)}, yw]*G[{yv^(-1), 1/(yu*yv), 1/(yu*yv)}, 
       yw] - 8*G[{0}, yv^(-1)]*G[{yv^(-1)}, yw]*
      G[{yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] + 8*G[{0}, yw]*G[{yv^(-1)}, yw]*
      G[{yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] + 16*G[{1}, yu^(-1)]*
      G[{yv^(-1)}, yw]*G[{yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] - 
     8*G[{yv^(-1)}, yw]^2*G[{yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] - 
     4*G[{0}, yu^(-1)]*G[{1/(yu*yv)}, yw]*G[{yv^(-1), 1/(yu*yv), 1/(yu*yv)}, 
       yw] - 4*G[{0}, yv^(-1)]*G[{1/(yu*yv)}, yw]*
      G[{yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] + 
     4*G[{0}, yw]*G[{1/(yu*yv)}, yw]*G[{yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] + 
     8*G[{1}, yu^(-1)]*G[{1/(yu*yv)}, yw]*G[{yv^(-1), 1/(yu*yv), 1/(yu*yv)}, 
       yw] + 4*G[{1}, yv^(-1)]*G[{1/(yu*yv)}, yw]*
      G[{yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] + 
     4*G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] - 
     4*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{yv^(-1), 1/(yu*yv), 1/(yu*yv)}, 
       yw] - 4*G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw]*
      G[{yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] - 8*G[{yv^(-1)}, yw]*
      G[{1/(yu*yv)}, yw]*G[{yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] - 
     4*G[{0, 1}, yu^(-1)]*G[{yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] - 
     4*G[{0, 1}, yv^(-1)]*G[{yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] + 
     4*G[{0, 1}, yw]*G[{yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] - 
     4*G[{0, yu^(-1)}, yw]*G[{yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] + 
     4*G[{0, yu}, yv^(-1)]*G[{yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] - 
     4*G[{0, yv^(-1)}, yw]*G[{yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] + 
     4*G[{0, 1/(yu*yv)}, yw]*G[{yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] + 
     8*G[{1, 1/(yu*yv)}, yw]*G[{yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] - 
     8*G[{yu^(-1), 1/(yu*yv)}, yw]*G[{yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] - 
     8*G[{yv^(-1), 1/(yu*yv)}, yw]*G[{yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] - 
     4*G[{0}, yu^(-1)]*G[{0, 0, 1, 1}, yu^(-1)] - 
     4*G[{0}, yv^(-1)]*G[{0, 0, 1, 1}, yu^(-1)] + 
     4*G[{0}, yw]*G[{0, 0, 1, 1}, yu^(-1)] + 4*G[{1}, yu^(-1)]*
      G[{0, 0, 1, 1}, yu^(-1)] + 4*G[{1}, yv^(-1)]*G[{0, 0, 1, 1}, yu^(-1)] - 
     4*G[{1}, yw]*G[{0, 0, 1, 1}, yu^(-1)] - 4*G[{1/(yu*yv)}, yw]*
      G[{0, 0, 1, 1}, yu^(-1)] - 4*G[{0}, yu^(-1)]*G[{0, 0, 1, 1}, yv^(-1)] - 
     4*G[{0}, yv^(-1)]*G[{0, 0, 1, 1}, yv^(-1)] + 
     4*G[{0}, yw]*G[{0, 0, 1, 1}, yv^(-1)] + 4*G[{1}, yv^(-1)]*
      G[{0, 0, 1, 1}, yv^(-1)] - 4*G[{1}, yw]*G[{0, 0, 1, 1}, yv^(-1)] - 
     4*G[{1/(yu*yv)}, yw]*G[{0, 0, 1, 1}, yv^(-1)] + 
     4*G[{0}, yu^(-1)]*G[{0, 0, 1, 1}, yw] + 4*G[{0}, yv^(-1)]*
      G[{0, 0, 1, 1}, yw] - 4*G[{0}, yw]*G[{0, 0, 1, 1}, yw] - 
     4*G[{1}, yu^(-1)]*G[{0, 0, 1, 1}, yw] - 4*G[{1}, yv^(-1)]*
      G[{0, 0, 1, 1}, yw] - 4*G[{1}, yw]*G[{0, 0, 1, 1}, yw] - 
     4*G[{1/(yu*yv)}, yw]*G[{0, 0, 1, 1}, yw] + 
     4*G[{1}, yw]*G[{0, 0, 1, yu^(-1)}, yw] + 4*G[{1/(yu*yv)}, yw]*
      G[{0, 0, 1, yu^(-1)}, yw] + 4*G[{1}, yv^(-1)]*
      G[{0, 0, 1, yu}, yv^(-1)] - 4*G[{1}, yw]*G[{0, 0, 1, yu}, yv^(-1)] + 
     4*G[{1/(yu*yv)}, yw]*G[{0, 0, 1, yu}, yv^(-1)] + 
     4*G[{1}, yw]*G[{0, 0, 1, yv^(-1)}, yw] + 4*G[{1/(yu*yv)}, yw]*
      G[{0, 0, 1, yv^(-1)}, yw] - 4*G[{0}, yu^(-1)]*G[{0, 0, 1, 1/(yu*yv)}, 
       yw] - 4*G[{0}, yv^(-1)]*G[{0, 0, 1, 1/(yu*yv)}, yw] + 
     4*G[{0}, yw]*G[{0, 0, 1, 1/(yu*yv)}, yw] + 4*G[{1}, yu^(-1)]*
      G[{0, 0, 1, 1/(yu*yv)}, yw] + 4*G[{1}, yv^(-1)]*
      G[{0, 0, 1, 1/(yu*yv)}, yw] - 12*G[{1}, yw]*G[{0, 0, 1, 1/(yu*yv)}, 
       yw] + 4*G[{1/(yu*yv)}, yw]*G[{0, 0, 1, 1/(yu*yv)}, yw] + 
     4*G[{1}, yu^(-1)]*G[{0, 0, yu^(-1), 1}, yw] - 
     4*G[{1}, yv^(-1)]*G[{0, 0, yu^(-1), 1}, yw] + 
     12*G[{1}, yw]*G[{0, 0, yu^(-1), 1}, yw] - 4*G[{1/(yu*yv)}, yw]*
      G[{0, 0, yu^(-1), 1}, yw] - 4*G[{1}, yw]*G[{0, 0, yu^(-1), yu^(-1)}, 
       yw] + 4*G[{1/(yu*yv)}, yw]*G[{0, 0, yu^(-1), yu^(-1)}, yw] + 
     4*G[{1}, yw]*G[{0, 0, yu^(-1), yv^(-1)}, yw] - 
     4*G[{1/(yu*yv)}, yw]*G[{0, 0, yu^(-1), yv^(-1)}, yw] + 
     4*G[{0}, yu^(-1)]*G[{0, 0, yu^(-1), 1/(yu*yv)}, yw] + 
     4*G[{0}, yv^(-1)]*G[{0, 0, yu^(-1), 1/(yu*yv)}, yw] - 
     4*G[{0}, yw]*G[{0, 0, yu^(-1), 1/(yu*yv)}, yw] - 
     4*G[{1}, yu^(-1)]*G[{0, 0, yu^(-1), 1/(yu*yv)}, yw] - 
     4*G[{1}, yv^(-1)]*G[{0, 0, yu^(-1), 1/(yu*yv)}, yw] + 
     4*G[{1}, yw]*G[{0, 0, yu^(-1), 1/(yu*yv)}, yw] - 
     4*G[{1/(yu*yv)}, yw]*G[{0, 0, yu^(-1), 1/(yu*yv)}, yw] + 
     4*G[{1}, yv^(-1)]*G[{0, 0, yu, 1}, yv^(-1)] - 
     4*G[{1}, yw]*G[{0, 0, yu, 1}, yv^(-1)] + 4*G[{1/(yu*yv)}, yw]*
      G[{0, 0, yu, 1}, yv^(-1)] - 4*G[{1}, yv^(-1)]*
      G[{0, 0, yu, yu}, yv^(-1)] + 4*G[{1}, yw]*G[{0, 0, yu, yu}, yv^(-1)] - 
     4*G[{1/(yu*yv)}, yw]*G[{0, 0, yu, yu}, yv^(-1)] - 
     4*G[{1}, yu^(-1)]*G[{0, 0, yv^(-1), 1}, yw] + 
     4*G[{1}, yv^(-1)]*G[{0, 0, yv^(-1), 1}, yw] + 
     12*G[{1}, yw]*G[{0, 0, yv^(-1), 1}, yw] - 4*G[{1/(yu*yv)}, yw]*
      G[{0, 0, yv^(-1), 1}, yw] + 4*G[{1}, yw]*G[{0, 0, yv^(-1), yu^(-1)}, 
       yw] - 4*G[{1/(yu*yv)}, yw]*G[{0, 0, yv^(-1), yu^(-1)}, yw] - 
     4*G[{1}, yw]*G[{0, 0, yv^(-1), yv^(-1)}, yw] + 
     4*G[{1/(yu*yv)}, yw]*G[{0, 0, yv^(-1), yv^(-1)}, yw] + 
     4*G[{0}, yu^(-1)]*G[{0, 0, yv^(-1), 1/(yu*yv)}, yw] + 
     4*G[{0}, yv^(-1)]*G[{0, 0, yv^(-1), 1/(yu*yv)}, yw] - 
     4*G[{0}, yw]*G[{0, 0, yv^(-1), 1/(yu*yv)}, yw] - 
     4*G[{1}, yu^(-1)]*G[{0, 0, yv^(-1), 1/(yu*yv)}, yw] - 
     4*G[{1}, yv^(-1)]*G[{0, 0, yv^(-1), 1/(yu*yv)}, yw] + 
     4*G[{1}, yw]*G[{0, 0, yv^(-1), 1/(yu*yv)}, yw] - 
     4*G[{1/(yu*yv)}, yw]*G[{0, 0, yv^(-1), 1/(yu*yv)}, yw] - 
     4*G[{0}, yu^(-1)]*G[{0, 0, 1/(yu*yv), 1}, yw] - 
     4*G[{0}, yv^(-1)]*G[{0, 0, 1/(yu*yv), 1}, yw] + 
     4*G[{0}, yw]*G[{0, 0, 1/(yu*yv), 1}, yw] + 4*G[{1}, yu^(-1)]*
      G[{0, 0, 1/(yu*yv), 1}, yw] + 4*G[{1}, yv^(-1)]*
      G[{0, 0, 1/(yu*yv), 1}, yw] - 20*G[{1}, yw]*G[{0, 0, 1/(yu*yv), 1}, 
       yw] + 12*G[{1/(yu*yv)}, yw]*G[{0, 0, 1/(yu*yv), 1}, yw] + 
     4*G[{0}, yu^(-1)]*G[{0, 0, 1/(yu*yv), yu^(-1)}, yw] + 
     4*G[{0}, yv^(-1)]*G[{0, 0, 1/(yu*yv), yu^(-1)}, yw] - 
     4*G[{0}, yw]*G[{0, 0, 1/(yu*yv), yu^(-1)}, yw] - 
     8*G[{1}, yv^(-1)]*G[{0, 0, 1/(yu*yv), yu^(-1)}, yw] + 
     4*G[{1}, yw]*G[{0, 0, 1/(yu*yv), yu^(-1)}, yw] - 
     4*G[{1/(yu*yv)}, yw]*G[{0, 0, 1/(yu*yv), yu^(-1)}, yw] + 
     4*G[{0}, yu^(-1)]*G[{0, 0, 1/(yu*yv), yv^(-1)}, yw] + 
     4*G[{0}, yv^(-1)]*G[{0, 0, 1/(yu*yv), yv^(-1)}, yw] - 
     4*G[{0}, yw]*G[{0, 0, 1/(yu*yv), yv^(-1)}, yw] - 
     8*G[{1}, yu^(-1)]*G[{0, 0, 1/(yu*yv), yv^(-1)}, yw] + 
     4*G[{1}, yw]*G[{0, 0, 1/(yu*yv), yv^(-1)}, yw] - 
     4*G[{1/(yu*yv)}, yw]*G[{0, 0, 1/(yu*yv), yv^(-1)}, yw] - 
     4*G[{0}, yu^(-1)]*G[{0, 0, 1/(yu*yv), 1/(yu*yv)}, yw] - 
     4*G[{0}, yv^(-1)]*G[{0, 0, 1/(yu*yv), 1/(yu*yv)}, yw] + 
     4*G[{0}, yw]*G[{0, 0, 1/(yu*yv), 1/(yu*yv)}, yw] + 
     4*G[{1}, yu^(-1)]*G[{0, 0, 1/(yu*yv), 1/(yu*yv)}, yw] + 
     4*G[{1}, yv^(-1)]*G[{0, 0, 1/(yu*yv), 1/(yu*yv)}, yw] + 
     4*G[{1}, yw]*G[{0, 0, 1/(yu*yv), 1/(yu*yv)}, yw] + 
     4*G[{1/(yu*yv)}, yw]*G[{0, 0, 1/(yu*yv), 1/(yu*yv)}, yw] + 
     2*G[{0}, yu^(-1)]*G[{0, 1, 0, yu^(-1)}, yw] + 
     2*G[{0}, yv^(-1)]*G[{0, 1, 0, yu^(-1)}, yw] - 
     2*G[{0}, yw]*G[{0, 1, 0, yu^(-1)}, yw] - 4*G[{1}, yv^(-1)]*
      G[{0, 1, 0, yu^(-1)}, yw] + 4*G[{1}, yw]*G[{0, 1, 0, yu^(-1)}, yw] - 
     2*G[{0}, yu^(-1)]*G[{0, 1, 0, yu}, yv^(-1)] - 
     2*G[{0}, yv^(-1)]*G[{0, 1, 0, yu}, yv^(-1)] + 
     2*G[{0}, yw]*G[{0, 1, 0, yu}, yv^(-1)] + 4*G[{1}, yv^(-1)]*
      G[{0, 1, 0, yu}, yv^(-1)] - 4*G[{1}, yw]*G[{0, 1, 0, yu}, yv^(-1)] + 
     2*G[{0}, yu^(-1)]*G[{0, 1, 0, yv^(-1)}, yw] + 
     2*G[{0}, yv^(-1)]*G[{0, 1, 0, yv^(-1)}, yw] - 
     2*G[{0}, yw]*G[{0, 1, 0, yv^(-1)}, yw] - 4*G[{1}, yu^(-1)]*
      G[{0, 1, 0, yv^(-1)}, yw] + 4*G[{1}, yw]*G[{0, 1, 0, yv^(-1)}, yw] - 
     4*G[{0}, yu^(-1)]*G[{0, 1, 0, 1/(yu*yv)}, yw] - 
     4*G[{0}, yv^(-1)]*G[{0, 1, 0, 1/(yu*yv)}, yw] + 
     4*G[{0}, yw]*G[{0, 1, 0, 1/(yu*yv)}, yw] + 4*G[{1}, yu^(-1)]*
      G[{0, 1, 0, 1/(yu*yv)}, yw] + 4*G[{1}, yv^(-1)]*
      G[{0, 1, 0, 1/(yu*yv)}, yw] - 8*G[{1}, yw]*G[{0, 1, 0, 1/(yu*yv)}, 
       yw] - 6*G[{0}, yu^(-1)]*G[{0, 1, 1, 1}, yu^(-1)] - 
     6*G[{0}, yv^(-1)]*G[{0, 1, 1, 1}, yu^(-1)] + 
     6*G[{0}, yw]*G[{0, 1, 1, 1}, yu^(-1)] + 12*G[{1}, yv^(-1)]*
      G[{0, 1, 1, 1}, yu^(-1)] - 12*G[{1}, yw]*G[{0, 1, 1, 1}, yu^(-1)] - 
     6*G[{0}, yu^(-1)]*G[{0, 1, 1, 1}, yv^(-1)] - 
     6*G[{0}, yv^(-1)]*G[{0, 1, 1, 1}, yv^(-1)] + 
     6*G[{0}, yw]*G[{0, 1, 1, 1}, yv^(-1)] - 4*G[{1}, yu^(-1)]*
      G[{0, 1, 1, 1}, yv^(-1)] - 12*G[{1}, yw]*G[{0, 1, 1, 1}, yv^(-1)] + 
     10*G[{0}, yu^(-1)]*G[{0, 1, 1, 1}, yw] + 10*G[{0}, yv^(-1)]*
      G[{0, 1, 1, 1}, yw] - 10*G[{0}, yw]*G[{0, 1, 1, 1}, yw] - 
     8*G[{1}, yu^(-1)]*G[{0, 1, 1, 1}, yw] - 8*G[{1}, yv^(-1)]*
      G[{0, 1, 1, 1}, yw] - 4*G[{yu}, yv^(-1)]*G[{0, 1, 1, 1}, yw] - 
     8*G[{1/(yu*yv)}, yw]*G[{0, 1, 1, 1}, yw] - 4*G[{0}, yu^(-1)]*
      G[{0, 1, 1, yu^(-1)}, yw] - 4*G[{0}, yv^(-1)]*G[{0, 1, 1, yu^(-1)}, 
       yw] + 4*G[{0}, yw]*G[{0, 1, 1, yu^(-1)}, yw] + 
     8*G[{1}, yv^(-1)]*G[{0, 1, 1, yu^(-1)}, yw] - 
     8*G[{1}, yw]*G[{0, 1, 1, yu^(-1)}, yw] + 4*G[{1/(yu*yv)}, yw]*
      G[{0, 1, 1, yu^(-1)}, yw] + 4*G[{0}, yu^(-1)]*
      G[{0, 1, 1, yu}, yv^(-1)] + 4*G[{0}, yv^(-1)]*
      G[{0, 1, 1, yu}, yv^(-1)] - 4*G[{0}, yw]*G[{0, 1, 1, yu}, yv^(-1)] - 
     8*G[{1}, yv^(-1)]*G[{0, 1, 1, yu}, yv^(-1)] + 
     4*G[{1}, yw]*G[{0, 1, 1, yu}, yv^(-1)] + 4*G[{1/(yu*yv)}, yw]*
      G[{0, 1, 1, yu}, yv^(-1)] - 4*G[{0}, yu^(-1)]*G[{0, 1, 1, yv^(-1)}, 
       yw] - 4*G[{0}, yv^(-1)]*G[{0, 1, 1, yv^(-1)}, yw] + 
     4*G[{0}, yw]*G[{0, 1, 1, yv^(-1)}, yw] + 8*G[{1}, yu^(-1)]*
      G[{0, 1, 1, yv^(-1)}, yw] - 8*G[{1}, yw]*G[{0, 1, 1, yv^(-1)}, yw] + 
     4*G[{1/(yu*yv)}, yw]*G[{0, 1, 1, yv^(-1)}, yw] + 
     6*G[{0}, yu^(-1)]*G[{0, 1, 1, 1/(yu*yv)}, yw] + 
     6*G[{0}, yv^(-1)]*G[{0, 1, 1, 1/(yu*yv)}, yw] - 
     6*G[{0}, yw]*G[{0, 1, 1, 1/(yu*yv)}, yw] - 8*G[{1}, yu^(-1)]*
      G[{0, 1, 1, 1/(yu*yv)}, yw] - 8*G[{1}, yv^(-1)]*
      G[{0, 1, 1, 1/(yu*yv)}, yw] + 4*G[{yu}, yv^(-1)]*
      G[{0, 1, 1, 1/(yu*yv)}, yw] - 4*G[{0}, yu^(-1)]*
      G[{0, 1, yu^(-1), 1}, yw] - 4*G[{0}, yv^(-1)]*G[{0, 1, yu^(-1), 1}, 
       yw] + 4*G[{0}, yw]*G[{0, 1, yu^(-1), 1}, yw] + 
     8*G[{1}, yv^(-1)]*G[{0, 1, yu^(-1), 1}, yw] - 
     12*G[{1}, yw]*G[{0, 1, yu^(-1), 1}, yw] + 4*G[{1/(yu*yv)}, yw]*
      G[{0, 1, yu^(-1), 1}, yw] + 8*G[{1}, yw]*G[{0, 1, yu^(-1), yu^(-1)}, 
       yw] + 4*G[{1}, yw]*G[{0, 1, yu^(-1), 1/(yu*yv)}, yw] + 
     4*G[{1/(yu*yv)}, yw]*G[{0, 1, yu^(-1), 1/(yu*yv)}, yw] + 
     4*G[{0}, yu^(-1)]*G[{0, 1, yu, 1}, yv^(-1)] + 
     4*G[{0}, yv^(-1)]*G[{0, 1, yu, 1}, yv^(-1)] - 
     4*G[{0}, yw]*G[{0, 1, yu, 1}, yv^(-1)] - 4*G[{1}, yv^(-1)]*
      G[{0, 1, yu, 1}, yv^(-1)] + 4*G[{1}, yw]*G[{0, 1, yu, 1}, yv^(-1)] + 
     4*G[{1/(yu*yv)}, yw]*G[{0, 1, yu, 1}, yv^(-1)] + 
     8*G[{1}, yv^(-1)]*G[{0, 1, yu, yu}, yv^(-1)] - 
     4*G[{0}, yu^(-1)]*G[{0, 1, yv^(-1), 1}, yw] - 
     4*G[{0}, yv^(-1)]*G[{0, 1, yv^(-1), 1}, yw] + 
     4*G[{0}, yw]*G[{0, 1, yv^(-1), 1}, yw] + 8*G[{1}, yu^(-1)]*
      G[{0, 1, yv^(-1), 1}, yw] - 12*G[{1}, yw]*G[{0, 1, yv^(-1), 1}, yw] + 
     4*G[{1/(yu*yv)}, yw]*G[{0, 1, yv^(-1), 1}, yw] + 
     8*G[{1}, yw]*G[{0, 1, yv^(-1), yv^(-1)}, yw] + 
     4*G[{1}, yw]*G[{0, 1, yv^(-1), 1/(yu*yv)}, yw] + 
     4*G[{1/(yu*yv)}, yw]*G[{0, 1, yv^(-1), 1/(yu*yv)}, yw] + 
     6*G[{0}, yu^(-1)]*G[{0, 1, 1/(yu*yv), 1}, yw] + 
     6*G[{0}, yv^(-1)]*G[{0, 1, 1/(yu*yv), 1}, yw] - 
     6*G[{0}, yw]*G[{0, 1, 1/(yu*yv), 1}, yw] - 8*G[{1}, yu^(-1)]*
      G[{0, 1, 1/(yu*yv), 1}, yw] - 8*G[{1}, yv^(-1)]*
      G[{0, 1, 1/(yu*yv), 1}, yw] + 8*G[{1}, yw]*G[{0, 1, 1/(yu*yv), 1}, 
       yw] + 4*G[{yu}, yv^(-1)]*G[{0, 1, 1/(yu*yv), 1}, yw] - 
     8*G[{1}, yw]*G[{0, 1, 1/(yu*yv), yu^(-1)}, yw] + 
     4*G[{1/(yu*yv)}, yw]*G[{0, 1, 1/(yu*yv), yu^(-1)}, yw] - 
     8*G[{1}, yw]*G[{0, 1, 1/(yu*yv), yv^(-1)}, yw] + 
     4*G[{1/(yu*yv)}, yw]*G[{0, 1, 1/(yu*yv), yv^(-1)}, yw] - 
     6*G[{0}, yu^(-1)]*G[{0, 1, 1/(yu*yv), 1/(yu*yv)}, yw] - 
     6*G[{0}, yv^(-1)]*G[{0, 1, 1/(yu*yv), 1/(yu*yv)}, yw] + 
     6*G[{0}, yw]*G[{0, 1, 1/(yu*yv), 1/(yu*yv)}, yw] + 
     8*G[{1}, yu^(-1)]*G[{0, 1, 1/(yu*yv), 1/(yu*yv)}, yw] + 
     8*G[{1}, yv^(-1)]*G[{0, 1, 1/(yu*yv), 1/(yu*yv)}, yw] - 
     4*G[{yu}, yv^(-1)]*G[{0, 1, 1/(yu*yv), 1/(yu*yv)}, yw] + 
     2*G[{0}, yu^(-1)]*G[{0, yu^(-1), 0, 1/(yu*yv)}, yw] + 
     2*G[{0}, yv^(-1)]*G[{0, yu^(-1), 0, 1/(yu*yv)}, yw] - 
     2*G[{0}, yw]*G[{0, yu^(-1), 0, 1/(yu*yv)}, yw] - 
     4*G[{1}, yv^(-1)]*G[{0, yu^(-1), 0, 1/(yu*yv)}, yw] + 
     4*G[{1}, yw]*G[{0, yu^(-1), 0, 1/(yu*yv)}, yw] - 
     10*G[{0}, yu^(-1)]*G[{0, yu^(-1), 1, 1}, yw] - 
     10*G[{0}, yv^(-1)]*G[{0, yu^(-1), 1, 1}, yw] + 
     10*G[{0}, yw]*G[{0, yu^(-1), 1, 1}, yw] + 8*G[{1}, yu^(-1)]*
      G[{0, yu^(-1), 1, 1}, yw] + 8*G[{1}, yv^(-1)]*G[{0, yu^(-1), 1, 1}, 
       yw] + 4*G[{yu}, yv^(-1)]*G[{0, yu^(-1), 1, 1}, yw] + 
     4*G[{0}, yu^(-1)]*G[{0, yu^(-1), 1, yu^(-1)}, yw] + 
     4*G[{0}, yv^(-1)]*G[{0, yu^(-1), 1, yu^(-1)}, yw] - 
     4*G[{0}, yw]*G[{0, yu^(-1), 1, yu^(-1)}, yw] - 
     8*G[{1}, yv^(-1)]*G[{0, yu^(-1), 1, yu^(-1)}, yw] + 
     8*G[{1}, yw]*G[{0, yu^(-1), 1, yu^(-1)}, yw] - 
     4*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1), 1, yu^(-1)}, yw] + 
     8*G[{1}, yw]*G[{0, yu^(-1), 1, yv^(-1)}, yw] - 
     4*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1), 1, yv^(-1)}, yw] + 
     2*G[{0}, yu^(-1)]*G[{0, yu^(-1), 1, 1/(yu*yv)}, yw] + 
     2*G[{0}, yv^(-1)]*G[{0, yu^(-1), 1, 1/(yu*yv)}, yw] - 
     2*G[{0}, yw]*G[{0, yu^(-1), 1, 1/(yu*yv)}, yw] - 
     4*G[{yu}, yv^(-1)]*G[{0, yu^(-1), 1, 1/(yu*yv)}, yw] + 
     4*G[{0}, yu^(-1)]*G[{0, yu^(-1), yu^(-1), 1}, yw] + 
     4*G[{0}, yv^(-1)]*G[{0, yu^(-1), yu^(-1), 1}, yw] - 
     4*G[{0}, yw]*G[{0, yu^(-1), yu^(-1), 1}, yw] - 
     8*G[{1}, yv^(-1)]*G[{0, yu^(-1), yu^(-1), 1}, yw] + 
     12*G[{1}, yw]*G[{0, yu^(-1), yu^(-1), 1}, yw] - 
     4*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1), yu^(-1), 1}, yw] - 
     8*G[{1}, yw]*G[{0, yu^(-1), yu^(-1), yu^(-1)}, yw] + 
     8*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1), yu^(-1), yu^(-1)}, yw] - 
     4*G[{0}, yu^(-1)]*G[{0, yu^(-1), yu^(-1), 1/(yu*yv)}, yw] - 
     4*G[{0}, yv^(-1)]*G[{0, yu^(-1), yu^(-1), 1/(yu*yv)}, yw] + 
     4*G[{0}, yw]*G[{0, yu^(-1), yu^(-1), 1/(yu*yv)}, yw] + 
     8*G[{1}, yv^(-1)]*G[{0, yu^(-1), yu^(-1), 1/(yu*yv)}, yw] - 
     4*G[{1}, yw]*G[{0, yu^(-1), yu^(-1), 1/(yu*yv)}, yw] - 
     4*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1), yu^(-1), 1/(yu*yv)}, yw] + 
     12*G[{1}, yw]*G[{0, yu^(-1), yv^(-1), 1}, yw] - 
     4*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1), yv^(-1), 1}, yw] - 
     4*G[{1}, yw]*G[{0, yu^(-1), yv^(-1), 1/(yu*yv)}, yw] - 
     4*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1), yv^(-1), 1/(yu*yv)}, yw] + 
     2*G[{0}, yu^(-1)]*G[{0, yu^(-1), 1/(yu*yv), 1}, yw] + 
     2*G[{0}, yv^(-1)]*G[{0, yu^(-1), 1/(yu*yv), 1}, yw] - 
     2*G[{0}, yw]*G[{0, yu^(-1), 1/(yu*yv), 1}, yw] - 
     4*G[{yu}, yv^(-1)]*G[{0, yu^(-1), 1/(yu*yv), 1}, yw] - 
     4*G[{0}, yu^(-1)]*G[{0, yu^(-1), 1/(yu*yv), yu^(-1)}, yw] - 
     4*G[{0}, yv^(-1)]*G[{0, yu^(-1), 1/(yu*yv), yu^(-1)}, yw] + 
     4*G[{0}, yw]*G[{0, yu^(-1), 1/(yu*yv), yu^(-1)}, yw] + 
     8*G[{1}, yv^(-1)]*G[{0, yu^(-1), 1/(yu*yv), yu^(-1)}, yw] - 
     4*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1), 1/(yu*yv), yu^(-1)}, yw] - 
     4*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1), 1/(yu*yv), yv^(-1)}, yw] + 
     6*G[{0}, yu^(-1)]*G[{0, yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] + 
     6*G[{0}, yv^(-1)]*G[{0, yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] - 
     6*G[{0}, yw]*G[{0, yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] - 
     8*G[{1}, yu^(-1)]*G[{0, yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] - 
     8*G[{1}, yv^(-1)]*G[{0, yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] + 
     4*G[{yu}, yv^(-1)]*G[{0, yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] + 
     6*G[{0}, yu^(-1)]*G[{0, yu, 1, 1}, yv^(-1)] + 
     6*G[{0}, yv^(-1)]*G[{0, yu, 1, 1}, yv^(-1)] - 
     6*G[{0}, yw]*G[{0, yu, 1, 1}, yv^(-1)] + 4*G[{1}, yu^(-1)]*
      G[{0, yu, 1, 1}, yv^(-1)] + 4*G[{1}, yw]*G[{0, yu, 1, 1}, yv^(-1)] + 
     8*G[{1/(yu*yv)}, yw]*G[{0, yu, 1, 1}, yv^(-1)] - 
     4*G[{0}, yu^(-1)]*G[{0, yu, 1, yu}, yv^(-1)] - 
     4*G[{0}, yv^(-1)]*G[{0, yu, 1, yu}, yv^(-1)] + 
     4*G[{0}, yw]*G[{0, yu, 1, yu}, yv^(-1)] + 8*G[{1}, yv^(-1)]*
      G[{0, yu, 1, yu}, yv^(-1)] - 4*G[{1}, yw]*G[{0, yu, 1, yu}, yv^(-1)] - 
     4*G[{1/(yu*yv)}, yw]*G[{0, yu, 1, yu}, yv^(-1)] - 
     4*G[{0}, yu^(-1)]*G[{0, yu, yu, 1}, yv^(-1)] - 
     4*G[{0}, yv^(-1)]*G[{0, yu, yu, 1}, yv^(-1)] + 
     4*G[{0}, yw]*G[{0, yu, yu, 1}, yv^(-1)] + 4*G[{1}, yv^(-1)]*
      G[{0, yu, yu, 1}, yv^(-1)] - 4*G[{1}, yw]*G[{0, yu, yu, 1}, yv^(-1)] - 
     4*G[{1/(yu*yv)}, yw]*G[{0, yu, yu, 1}, yv^(-1)] - 
     8*G[{1}, yv^(-1)]*G[{0, yu, yu, yu}, yv^(-1)] + 
     8*G[{1}, yw]*G[{0, yu, yu, yu}, yv^(-1)] - 8*G[{1/(yu*yv)}, yw]*
      G[{0, yu, yu, yu}, yv^(-1)] + 2*G[{0}, yu^(-1)]*
      G[{0, yv^(-1), 0, 1/(yu*yv)}, yw] + 2*G[{0}, yv^(-1)]*
      G[{0, yv^(-1), 0, 1/(yu*yv)}, yw] - 2*G[{0}, yw]*
      G[{0, yv^(-1), 0, 1/(yu*yv)}, yw] - 4*G[{1}, yu^(-1)]*
      G[{0, yv^(-1), 0, 1/(yu*yv)}, yw] + 4*G[{1}, yw]*
      G[{0, yv^(-1), 0, 1/(yu*yv)}, yw] - 10*G[{0}, yu^(-1)]*
      G[{0, yv^(-1), 1, 1}, yw] - 10*G[{0}, yv^(-1)]*
      G[{0, yv^(-1), 1, 1}, yw] + 10*G[{0}, yw]*G[{0, yv^(-1), 1, 1}, yw] + 
     8*G[{1}, yu^(-1)]*G[{0, yv^(-1), 1, 1}, yw] + 
     8*G[{1}, yv^(-1)]*G[{0, yv^(-1), 1, 1}, yw] + 
     4*G[{yu}, yv^(-1)]*G[{0, yv^(-1), 1, 1}, yw] + 
     8*G[{1}, yw]*G[{0, yv^(-1), 1, yu^(-1)}, yw] - 
     4*G[{1/(yu*yv)}, yw]*G[{0, yv^(-1), 1, yu^(-1)}, yw] + 
     4*G[{0}, yu^(-1)]*G[{0, yv^(-1), 1, yv^(-1)}, yw] + 
     4*G[{0}, yv^(-1)]*G[{0, yv^(-1), 1, yv^(-1)}, yw] - 
     4*G[{0}, yw]*G[{0, yv^(-1), 1, yv^(-1)}, yw] - 
     8*G[{1}, yu^(-1)]*G[{0, yv^(-1), 1, yv^(-1)}, yw] + 
     8*G[{1}, yw]*G[{0, yv^(-1), 1, yv^(-1)}, yw] - 
     4*G[{1/(yu*yv)}, yw]*G[{0, yv^(-1), 1, yv^(-1)}, yw] + 
     2*G[{0}, yu^(-1)]*G[{0, yv^(-1), 1, 1/(yu*yv)}, yw] + 
     2*G[{0}, yv^(-1)]*G[{0, yv^(-1), 1, 1/(yu*yv)}, yw] - 
     2*G[{0}, yw]*G[{0, yv^(-1), 1, 1/(yu*yv)}, yw] - 
     4*G[{yu}, yv^(-1)]*G[{0, yv^(-1), 1, 1/(yu*yv)}, yw] + 
     12*G[{1}, yw]*G[{0, yv^(-1), yu^(-1), 1}, yw] - 
     4*G[{1/(yu*yv)}, yw]*G[{0, yv^(-1), yu^(-1), 1}, yw] - 
     4*G[{1}, yw]*G[{0, yv^(-1), yu^(-1), 1/(yu*yv)}, yw] - 
     4*G[{1/(yu*yv)}, yw]*G[{0, yv^(-1), yu^(-1), 1/(yu*yv)}, yw] + 
     4*G[{0}, yu^(-1)]*G[{0, yv^(-1), yv^(-1), 1}, yw] + 
     4*G[{0}, yv^(-1)]*G[{0, yv^(-1), yv^(-1), 1}, yw] - 
     4*G[{0}, yw]*G[{0, yv^(-1), yv^(-1), 1}, yw] - 
     8*G[{1}, yu^(-1)]*G[{0, yv^(-1), yv^(-1), 1}, yw] + 
     12*G[{1}, yw]*G[{0, yv^(-1), yv^(-1), 1}, yw] - 
     4*G[{1/(yu*yv)}, yw]*G[{0, yv^(-1), yv^(-1), 1}, yw] - 
     8*G[{1}, yw]*G[{0, yv^(-1), yv^(-1), yv^(-1)}, yw] + 
     8*G[{1/(yu*yv)}, yw]*G[{0, yv^(-1), yv^(-1), yv^(-1)}, yw] - 
     4*G[{0}, yu^(-1)]*G[{0, yv^(-1), yv^(-1), 1/(yu*yv)}, yw] - 
     4*G[{0}, yv^(-1)]*G[{0, yv^(-1), yv^(-1), 1/(yu*yv)}, yw] + 
     4*G[{0}, yw]*G[{0, yv^(-1), yv^(-1), 1/(yu*yv)}, yw] + 
     8*G[{1}, yu^(-1)]*G[{0, yv^(-1), yv^(-1), 1/(yu*yv)}, yw] - 
     4*G[{1}, yw]*G[{0, yv^(-1), yv^(-1), 1/(yu*yv)}, yw] - 
     4*G[{1/(yu*yv)}, yw]*G[{0, yv^(-1), yv^(-1), 1/(yu*yv)}, yw] + 
     2*G[{0}, yu^(-1)]*G[{0, yv^(-1), 1/(yu*yv), 1}, yw] + 
     2*G[{0}, yv^(-1)]*G[{0, yv^(-1), 1/(yu*yv), 1}, yw] - 
     2*G[{0}, yw]*G[{0, yv^(-1), 1/(yu*yv), 1}, yw] - 
     4*G[{yu}, yv^(-1)]*G[{0, yv^(-1), 1/(yu*yv), 1}, yw] - 
     4*G[{1/(yu*yv)}, yw]*G[{0, yv^(-1), 1/(yu*yv), yu^(-1)}, yw] - 
     4*G[{0}, yu^(-1)]*G[{0, yv^(-1), 1/(yu*yv), yv^(-1)}, yw] - 
     4*G[{0}, yv^(-1)]*G[{0, yv^(-1), 1/(yu*yv), yv^(-1)}, yw] + 
     4*G[{0}, yw]*G[{0, yv^(-1), 1/(yu*yv), yv^(-1)}, yw] + 
     8*G[{1}, yu^(-1)]*G[{0, yv^(-1), 1/(yu*yv), yv^(-1)}, yw] - 
     4*G[{1/(yu*yv)}, yw]*G[{0, yv^(-1), 1/(yu*yv), yv^(-1)}, yw] + 
     6*G[{0}, yu^(-1)]*G[{0, yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] + 
     6*G[{0}, yv^(-1)]*G[{0, yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] - 
     6*G[{0}, yw]*G[{0, yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] - 
     8*G[{1}, yu^(-1)]*G[{0, yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] - 
     8*G[{1}, yv^(-1)]*G[{0, yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] + 
     4*G[{yu}, yv^(-1)]*G[{0, yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] + 
     10*G[{0}, yu^(-1)]*G[{0, 1/(yu*yv), 1, 1}, yw] + 
     10*G[{0}, yv^(-1)]*G[{0, 1/(yu*yv), 1, 1}, yw] - 
     10*G[{0}, yw]*G[{0, 1/(yu*yv), 1, 1}, yw] - 8*G[{1}, yu^(-1)]*
      G[{0, 1/(yu*yv), 1, 1}, yw] - 8*G[{1}, yv^(-1)]*
      G[{0, 1/(yu*yv), 1, 1}, yw] - 4*G[{yu}, yv^(-1)]*
      G[{0, 1/(yu*yv), 1, 1}, yw] + 8*G[{1/(yu*yv)}, yw]*
      G[{0, 1/(yu*yv), 1, 1}, yw] - 8*G[{1}, yw]*
      G[{0, 1/(yu*yv), 1, yu^(-1)}, yw] + 4*G[{1/(yu*yv)}, yw]*
      G[{0, 1/(yu*yv), 1, yu^(-1)}, yw] - 8*G[{1}, yw]*
      G[{0, 1/(yu*yv), 1, yv^(-1)}, yw] + 4*G[{1/(yu*yv)}, yw]*
      G[{0, 1/(yu*yv), 1, yv^(-1)}, yw] - 10*G[{0}, yu^(-1)]*
      G[{0, 1/(yu*yv), 1, 1/(yu*yv)}, yw] - 10*G[{0}, yv^(-1)]*
      G[{0, 1/(yu*yv), 1, 1/(yu*yv)}, yw] + 10*G[{0}, yw]*
      G[{0, 1/(yu*yv), 1, 1/(yu*yv)}, yw] + 8*G[{1}, yu^(-1)]*
      G[{0, 1/(yu*yv), 1, 1/(yu*yv)}, yw] + 8*G[{1}, yv^(-1)]*
      G[{0, 1/(yu*yv), 1, 1/(yu*yv)}, yw] + 4*G[{yu}, yv^(-1)]*
      G[{0, 1/(yu*yv), 1, 1/(yu*yv)}, yw] - 12*G[{1}, yw]*
      G[{0, 1/(yu*yv), yu^(-1), 1}, yw] + 4*G[{1/(yu*yv)}, yw]*
      G[{0, 1/(yu*yv), yu^(-1), 1}, yw] - 8*G[{1/(yu*yv)}, yw]*
      G[{0, 1/(yu*yv), yu^(-1), yu^(-1)}, yw] + 4*G[{0}, yu^(-1)]*
      G[{0, 1/(yu*yv), yu^(-1), 1/(yu*yv)}, yw] + 
     4*G[{0}, yv^(-1)]*G[{0, 1/(yu*yv), yu^(-1), 1/(yu*yv)}, yw] - 
     4*G[{0}, yw]*G[{0, 1/(yu*yv), yu^(-1), 1/(yu*yv)}, yw] - 
     8*G[{1}, yv^(-1)]*G[{0, 1/(yu*yv), yu^(-1), 1/(yu*yv)}, yw] + 
     4*G[{1}, yw]*G[{0, 1/(yu*yv), yu^(-1), 1/(yu*yv)}, yw] + 
     4*G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv), yu^(-1), 1/(yu*yv)}, yw] - 
     12*G[{1}, yw]*G[{0, 1/(yu*yv), yv^(-1), 1}, yw] + 
     4*G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv), yv^(-1), 1}, yw] - 
     8*G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv), yv^(-1), yv^(-1)}, yw] + 
     4*G[{0}, yu^(-1)]*G[{0, 1/(yu*yv), yv^(-1), 1/(yu*yv)}, yw] + 
     4*G[{0}, yv^(-1)]*G[{0, 1/(yu*yv), yv^(-1), 1/(yu*yv)}, yw] - 
     4*G[{0}, yw]*G[{0, 1/(yu*yv), yv^(-1), 1/(yu*yv)}, yw] - 
     8*G[{1}, yu^(-1)]*G[{0, 1/(yu*yv), yv^(-1), 1/(yu*yv)}, yw] + 
     4*G[{1}, yw]*G[{0, 1/(yu*yv), yv^(-1), 1/(yu*yv)}, yw] + 
     4*G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv), yv^(-1), 1/(yu*yv)}, yw] - 
     10*G[{0}, yu^(-1)]*G[{0, 1/(yu*yv), 1/(yu*yv), 1}, yw] - 
     10*G[{0}, yv^(-1)]*G[{0, 1/(yu*yv), 1/(yu*yv), 1}, yw] + 
     10*G[{0}, yw]*G[{0, 1/(yu*yv), 1/(yu*yv), 1}, yw] + 
     8*G[{1}, yu^(-1)]*G[{0, 1/(yu*yv), 1/(yu*yv), 1}, yw] + 
     8*G[{1}, yv^(-1)]*G[{0, 1/(yu*yv), 1/(yu*yv), 1}, yw] - 
     8*G[{1}, yw]*G[{0, 1/(yu*yv), 1/(yu*yv), 1}, yw] + 
     4*G[{yu}, yv^(-1)]*G[{0, 1/(yu*yv), 1/(yu*yv), 1}, yw] + 
     4*G[{0}, yu^(-1)]*G[{0, 1/(yu*yv), 1/(yu*yv), yu^(-1)}, yw] + 
     4*G[{0}, yv^(-1)]*G[{0, 1/(yu*yv), 1/(yu*yv), yu^(-1)}, yw] - 
     4*G[{0}, yw]*G[{0, 1/(yu*yv), 1/(yu*yv), yu^(-1)}, yw] - 
     8*G[{1}, yv^(-1)]*G[{0, 1/(yu*yv), 1/(yu*yv), yu^(-1)}, yw] + 
     8*G[{1}, yw]*G[{0, 1/(yu*yv), 1/(yu*yv), yu^(-1)}, yw] + 
     4*G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv), 1/(yu*yv), yu^(-1)}, yw] + 
     4*G[{0}, yu^(-1)]*G[{0, 1/(yu*yv), 1/(yu*yv), yv^(-1)}, yw] + 
     4*G[{0}, yv^(-1)]*G[{0, 1/(yu*yv), 1/(yu*yv), yv^(-1)}, yw] - 
     4*G[{0}, yw]*G[{0, 1/(yu*yv), 1/(yu*yv), yv^(-1)}, yw] - 
     8*G[{1}, yu^(-1)]*G[{0, 1/(yu*yv), 1/(yu*yv), yv^(-1)}, yw] + 
     8*G[{1}, yw]*G[{0, 1/(yu*yv), 1/(yu*yv), yv^(-1)}, yw] + 
     4*G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv), 1/(yu*yv), yv^(-1)}, yw] - 
     6*G[{0}, yu^(-1)]*G[{0, 1/(yu*yv), 1/(yu*yv), 1/(yu*yv)}, yw] - 
     6*G[{0}, yv^(-1)]*G[{0, 1/(yu*yv), 1/(yu*yv), 1/(yu*yv)}, yw] + 
     6*G[{0}, yw]*G[{0, 1/(yu*yv), 1/(yu*yv), 1/(yu*yv)}, yw] + 
     8*G[{1}, yu^(-1)]*G[{0, 1/(yu*yv), 1/(yu*yv), 1/(yu*yv)}, yw] + 
     8*G[{1}, yv^(-1)]*G[{0, 1/(yu*yv), 1/(yu*yv), 1/(yu*yv)}, yw] - 
     4*G[{yu}, yv^(-1)]*G[{0, 1/(yu*yv), 1/(yu*yv), 1/(yu*yv)}, yw] + 
     20*G[{0}, yu^(-1)]*G[{1, 1, 1, yu^(-1)}, yw] + 
     20*G[{0}, yv^(-1)]*G[{1, 1, 1, yu^(-1)}, yw] - 
     20*G[{0}, yw]*G[{1, 1, 1, yu^(-1)}, yw] - 12*G[{1}, yu^(-1)]*
      G[{1, 1, 1, yu^(-1)}, yw] - 16*G[{1}, yv^(-1)]*
      G[{1, 1, 1, yu^(-1)}, yw] + 12*G[{1}, yw]*G[{1, 1, 1, yu^(-1)}, yw] - 
     12*G[{yu}, yv^(-1)]*G[{1, 1, 1, yu^(-1)}, yw] - 
     8*G[{1/(yu*yv)}, yw]*G[{1, 1, 1, yu^(-1)}, yw] - 
     8*G[{0}, yu^(-1)]*G[{1, 1, 1, yu}, yv^(-1)] - 
     8*G[{0}, yv^(-1)]*G[{1, 1, 1, yu}, yv^(-1)] + 
     8*G[{0}, yw]*G[{1, 1, 1, yu}, yv^(-1)] - 12*G[{1}, yu^(-1)]*
      G[{1, 1, 1, yu}, yv^(-1)] + 12*G[{1}, yv^(-1)]*
      G[{1, 1, 1, yu}, yv^(-1)] - 8*G[{1}, yw]*G[{1, 1, 1, yu}, yv^(-1)] - 
     8*G[{1/(yu*yv)}, yw]*G[{1, 1, 1, yu}, yv^(-1)] + 
     20*G[{0}, yu^(-1)]*G[{1, 1, 1, yv^(-1)}, yw] + 
     20*G[{0}, yv^(-1)]*G[{1, 1, 1, yv^(-1)}, yw] - 
     20*G[{0}, yw]*G[{1, 1, 1, yv^(-1)}, yw] - 16*G[{1}, yu^(-1)]*
      G[{1, 1, 1, yv^(-1)}, yw] - 12*G[{1}, yv^(-1)]*
      G[{1, 1, 1, yv^(-1)}, yw] + 12*G[{1}, yw]*G[{1, 1, 1, yv^(-1)}, yw] - 
     12*G[{yu}, yv^(-1)]*G[{1, 1, 1, yv^(-1)}, yw] - 
     8*G[{1/(yu*yv)}, yw]*G[{1, 1, 1, yv^(-1)}, yw] - 
     20*G[{0}, yu^(-1)]*G[{1, 1, 1, 1/(yu*yv)}, yw] - 
     20*G[{0}, yv^(-1)]*G[{1, 1, 1, 1/(yu*yv)}, yw] + 
     20*G[{0}, yw]*G[{1, 1, 1, 1/(yu*yv)}, yw] + 12*G[{1}, yu^(-1)]*
      G[{1, 1, 1, 1/(yu*yv)}, yw] + 12*G[{1}, yv^(-1)]*
      G[{1, 1, 1, 1/(yu*yv)}, yw] - 16*G[{1}, yw]*G[{1, 1, 1, 1/(yu*yv)}, 
       yw] + 16*G[{yu}, yv^(-1)]*G[{1, 1, 1, 1/(yu*yv)}, yw] + 
     8*G[{0}, yu^(-1)]*G[{1, 1, yu^(-1), yu^(-1)}, yw] + 
     8*G[{0}, yv^(-1)]*G[{1, 1, yu^(-1), yu^(-1)}, yw] - 
     8*G[{0}, yw]*G[{1, 1, yu^(-1), yu^(-1)}, yw] - 
     16*G[{1}, yv^(-1)]*G[{1, 1, yu^(-1), yu^(-1)}, yw] - 
     8*G[{1/(yu*yv)}, yw]*G[{1, 1, yu^(-1), yu^(-1)}, yw] - 
     4*G[{1/(yu*yv)}, yw]*G[{1, 1, yu^(-1), yv^(-1)}, yw] + 
     4*G[{1}, yu^(-1)]*G[{1, 1, yu^(-1), 1/(yu*yv)}, yw] + 
     4*G[{1}, yw]*G[{1, 1, yu^(-1), 1/(yu*yv)}, yw] - 
     4*G[{yu}, yv^(-1)]*G[{1, 1, yu^(-1), 1/(yu*yv)}, yw] - 
     4*G[{1/(yu*yv)}, yw]*G[{1, 1, yu^(-1), 1/(yu*yv)}, yw] - 
     8*G[{0}, yu^(-1)]*G[{1, 1, yu, yu}, yv^(-1)] - 
     8*G[{0}, yv^(-1)]*G[{1, 1, yu, yu}, yv^(-1)] + 
     8*G[{0}, yw]*G[{1, 1, yu, yu}, yv^(-1)] - 
     8*G[{1}, yw]*G[{1, 1, yu, yu}, yv^(-1)] - 8*G[{1/(yu*yv)}, yw]*
      G[{1, 1, yu, yu}, yv^(-1)] - 4*G[{1/(yu*yv)}, yw]*
      G[{1, 1, yv^(-1), yu^(-1)}, yw] + 8*G[{0}, yu^(-1)]*
      G[{1, 1, yv^(-1), yv^(-1)}, yw] + 8*G[{0}, yv^(-1)]*
      G[{1, 1, yv^(-1), yv^(-1)}, yw] - 8*G[{0}, yw]*
      G[{1, 1, yv^(-1), yv^(-1)}, yw] - 16*G[{1}, yu^(-1)]*
      G[{1, 1, yv^(-1), yv^(-1)}, yw] - 8*G[{1/(yu*yv)}, yw]*
      G[{1, 1, yv^(-1), yv^(-1)}, yw] + 4*G[{1}, yv^(-1)]*
      G[{1, 1, yv^(-1), 1/(yu*yv)}, yw] + 4*G[{1}, yw]*
      G[{1, 1, yv^(-1), 1/(yu*yv)}, yw] - 4*G[{yu}, yv^(-1)]*
      G[{1, 1, yv^(-1), 1/(yu*yv)}, yw] - 4*G[{1/(yu*yv)}, yw]*
      G[{1, 1, yv^(-1), 1/(yu*yv)}, yw] + 4*G[{1/(yu*yv)}, yw]*
      G[{1, 1, 1/(yu*yv), yu^(-1)}, yw] + 4*G[{1/(yu*yv)}, yw]*
      G[{1, 1, 1/(yu*yv), yv^(-1)}, yw] - 12*G[{0}, yu^(-1)]*
      G[{1, 1, 1/(yu*yv), 1/(yu*yv)}, yw] - 12*G[{0}, yv^(-1)]*
      G[{1, 1, 1/(yu*yv), 1/(yu*yv)}, yw] + 12*G[{0}, yw]*
      G[{1, 1, 1/(yu*yv), 1/(yu*yv)}, yw] + 12*G[{1}, yu^(-1)]*
      G[{1, 1, 1/(yu*yv), 1/(yu*yv)}, yw] + 12*G[{1}, yv^(-1)]*
      G[{1, 1, 1/(yu*yv), 1/(yu*yv)}, yw] + 8*G[{1/(yu*yv)}, yw]*
      G[{1, 1, 1/(yu*yv), 1/(yu*yv)}, yw] + 4*G[{1/(yu*yv)}, yw]*
      G[{1, yu^(-1), yv^(-1), 1/(yu*yv)}, yw] + 4*G[{1/(yu*yv)}, yw]*
      G[{1, yu^(-1), 1/(yu*yv), yv^(-1)}, yw] - 4*G[{0}, yu^(-1)]*
      G[{1, yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] - 
     4*G[{0}, yv^(-1)]*G[{1, yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] + 
     4*G[{0}, yw]*G[{1, yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] + 
     4*G[{1}, yu^(-1)]*G[{1, yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] - 
     4*G[{1}, yw]*G[{1, yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] + 
     4*G[{yu}, yv^(-1)]*G[{1, yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] + 
     4*G[{1/(yu*yv)}, yw]*G[{1, yv^(-1), yu^(-1), 1/(yu*yv)}, yw] + 
     4*G[{1/(yu*yv)}, yw]*G[{1, yv^(-1), 1/(yu*yv), yu^(-1)}, yw] - 
     4*G[{0}, yu^(-1)]*G[{1, yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] - 
     4*G[{0}, yv^(-1)]*G[{1, yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] + 
     4*G[{0}, yw]*G[{1, yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] + 
     4*G[{1}, yv^(-1)]*G[{1, yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] - 
     4*G[{1}, yw]*G[{1, yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] + 
     4*G[{yu}, yv^(-1)]*G[{1, yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] + 
     4*G[{1/(yu*yv)}, yw]*G[{1, 1/(yu*yv), yu^(-1), 1/(yu*yv)}, yw] + 
     4*G[{1/(yu*yv)}, yw]*G[{1, 1/(yu*yv), yv^(-1), 1/(yu*yv)}, yw] + 
     4*G[{1/(yu*yv)}, yw]*G[{1, 1/(yu*yv), 1/(yu*yv), yu^(-1)}, yw] + 
     4*G[{1/(yu*yv)}, yw]*G[{1, 1/(yu*yv), 1/(yu*yv), yv^(-1)}, yw] - 
     4*G[{0}, yu^(-1)]*G[{1, 1/(yu*yv), 1/(yu*yv), 1/(yu*yv)}, yw] - 
     4*G[{0}, yv^(-1)]*G[{1, 1/(yu*yv), 1/(yu*yv), 1/(yu*yv)}, yw] + 
     4*G[{0}, yw]*G[{1, 1/(yu*yv), 1/(yu*yv), 1/(yu*yv)}, yw] + 
     12*G[{1}, yu^(-1)]*G[{1, 1/(yu*yv), 1/(yu*yv), 1/(yu*yv)}, yw] + 
     12*G[{1}, yv^(-1)]*G[{1, 1/(yu*yv), 1/(yu*yv), 1/(yu*yv)}, yw] + 
     16*G[{1}, yw]*G[{1, 1/(yu*yv), 1/(yu*yv), 1/(yu*yv)}, yw] - 
     16*G[{yu}, yv^(-1)]*G[{1, 1/(yu*yv), 1/(yu*yv), 1/(yu*yv)}, yw] + 
     16*G[{1/(yu*yv)}, yw]*G[{yu^(-1), yu^(-1), yu^(-1), 1/(yu*yv)}, yw] + 
     8*G[{0}, yu^(-1)]*G[{yu^(-1), yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] + 
     8*G[{0}, yv^(-1)]*G[{yu^(-1), yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] - 
     8*G[{0}, yw]*G[{yu^(-1), yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] - 
     16*G[{1}, yv^(-1)]*G[{yu^(-1), yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] + 
     16*G[{yu^(-1)}, yw]*G[{yu^(-1), yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] + 
     8*G[{1/(yu*yv)}, yw]*G[{yu^(-1), yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] - 
     4*G[{1/(yu*yv)}, yw]*G[{yu^(-1), 1/(yu*yv), yv^(-1), 1/(yu*yv)}, yw] - 
     4*G[{1/(yu*yv)}, yw]*G[{yu^(-1), 1/(yu*yv), 1/(yu*yv), yv^(-1)}, yw] + 
     8*G[{0}, yu^(-1)]*G[{yu^(-1), 1/(yu*yv), 1/(yu*yv), 1/(yu*yv)}, yw] + 
     8*G[{0}, yv^(-1)]*G[{yu^(-1), 1/(yu*yv), 1/(yu*yv), 1/(yu*yv)}, yw] - 
     8*G[{0}, yw]*G[{yu^(-1), 1/(yu*yv), 1/(yu*yv), 1/(yu*yv)}, yw] - 
     12*G[{1}, yu^(-1)]*G[{yu^(-1), 1/(yu*yv), 1/(yu*yv), 1/(yu*yv)}, yw] - 
     16*G[{1}, yv^(-1)]*G[{yu^(-1), 1/(yu*yv), 1/(yu*yv), 1/(yu*yv)}, yw] - 
     12*G[{1}, yw]*G[{yu^(-1), 1/(yu*yv), 1/(yu*yv), 1/(yu*yv)}, yw] + 
     16*G[{yu^(-1)}, yw]*G[{yu^(-1), 1/(yu*yv), 1/(yu*yv), 1/(yu*yv)}, yw] + 
     12*G[{yu}, yv^(-1)]*G[{yu^(-1), 1/(yu*yv), 1/(yu*yv), 1/(yu*yv)}, yw] + 
     16*G[{1/(yu*yv)}, yw]*G[{yv^(-1), yv^(-1), yv^(-1), 1/(yu*yv)}, yw] + 
     8*G[{0}, yu^(-1)]*G[{yv^(-1), yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] + 
     8*G[{0}, yv^(-1)]*G[{yv^(-1), yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] - 
     8*G[{0}, yw]*G[{yv^(-1), yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] - 
     16*G[{1}, yu^(-1)]*G[{yv^(-1), yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] + 
     16*G[{yv^(-1)}, yw]*G[{yv^(-1), yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] + 
     8*G[{1/(yu*yv)}, yw]*G[{yv^(-1), yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] + 
     8*G[{0}, yu^(-1)]*G[{yv^(-1), 1/(yu*yv), 1/(yu*yv), 1/(yu*yv)}, yw] + 
     8*G[{0}, yv^(-1)]*G[{yv^(-1), 1/(yu*yv), 1/(yu*yv), 1/(yu*yv)}, yw] - 
     8*G[{0}, yw]*G[{yv^(-1), 1/(yu*yv), 1/(yu*yv), 1/(yu*yv)}, yw] - 
     16*G[{1}, yu^(-1)]*G[{yv^(-1), 1/(yu*yv), 1/(yu*yv), 1/(yu*yv)}, yw] - 
     12*G[{1}, yv^(-1)]*G[{yv^(-1), 1/(yu*yv), 1/(yu*yv), 1/(yu*yv)}, yw] - 
     12*G[{1}, yw]*G[{yv^(-1), 1/(yu*yv), 1/(yu*yv), 1/(yu*yv)}, yw] + 
     12*G[{yu^(-1)}, yw]*G[{yv^(-1), 1/(yu*yv), 1/(yu*yv), 1/(yu*yv)}, yw] + 
     12*G[{yu}, yv^(-1)]*G[{yv^(-1), 1/(yu*yv), 1/(yu*yv), 1/(yu*yv)}, yw] + 
     16*G[{yv^(-1)}, yw]*G[{yv^(-1), 1/(yu*yv), 1/(yu*yv), 1/(yu*yv)}, yw] + 
     24*G[{0, 0, 0, 1, 1}, yw] - 12*G[{0, 0, 0, 1, yu^(-1)}, yw] - 
     12*G[{0, 0, 0, 1, yv^(-1)}, yw] - 12*G[{0, 0, 0, yu^(-1), 1}, yw] + 
     12*G[{0, 0, 0, yu^(-1), 1/(yu*yv)}, yw] - 
     12*G[{0, 0, 0, yv^(-1), 1}, yw] + 12*G[{0, 0, 0, yv^(-1), 1/(yu*yv)}, 
       yw] + 12*G[{0, 0, 0, 1/(yu*yv), yu^(-1)}, yw] + 
     12*G[{0, 0, 0, 1/(yu*yv), yv^(-1)}, yw] - 
     24*G[{0, 0, 0, 1/(yu*yv), 1/(yu*yv)}, yw] + 8*G[{0, 0, 1, 0, 1}, yw] - 
     4*G[{0, 0, 1, 0, yu^(-1)}, yw] - 4*G[{0, 0, 1, 0, yv^(-1)}, yw] - 
     12*G[{0, 0, 1, 1, 1}, yu^(-1)] - 12*G[{0, 0, 1, 1, 1}, yv^(-1)] - 
     16*G[{0, 0, 1, 1, 1}, yw] - 8*G[{0, 0, 1, 1, yu^(-1)}, yw] - 
     8*G[{0, 0, 1, 1, yv^(-1)}, yw] + 12*G[{0, 0, 1, 1, 1/(yu*yv)}, yw] - 
     4*G[{0, 0, 1, yu^(-1), 1}, yw] - 4*G[{0, 0, 1, yu^(-1), yv^(-1)}, yw] - 
     4*G[{0, 0, 1, yu, 1}, yv^(-1)] - 4*G[{0, 0, 1, yv^(-1), 1}, yw] - 
     4*G[{0, 0, 1, yv^(-1), yu^(-1)}, yw] + 
     12*G[{0, 0, 1, 1/(yu*yv), 1}, yw] + 4*G[{0, 0, 1, 1/(yu*yv), yu^(-1)}, 
       yw] + 4*G[{0, 0, 1, 1/(yu*yv), yv^(-1)}, yw] - 
     8*G[{0, 0, 1, 1/(yu*yv), 1/(yu*yv)}, yw] - 
     4*G[{0, 0, yu^(-1), 0, 1}, yw] + 4*G[{0, 0, yu^(-1), 0, 1/(yu*yv)}, 
       yw] - 12*G[{0, 0, yu^(-1), 1, 1}, yw] + 
     4*G[{0, 0, yu^(-1), 1, yu^(-1)}, yw] - 
     4*G[{0, 0, yu^(-1), 1, yv^(-1)}, yw] + 
     4*G[{0, 0, yu^(-1), 1, 1/(yu*yv)}, yw] + 
     8*G[{0, 0, yu^(-1), yu^(-1), 1/(yu*yv)}, yw] - 
     4*G[{0, 0, yu^(-1), yv^(-1), 1}, yw] + 
     4*G[{0, 0, yu^(-1), yv^(-1), 1/(yu*yv)}, yw] - 
     4*G[{0, 0, yu^(-1), 1/(yu*yv), 1}, yw] + 
     4*G[{0, 0, yu^(-1), 1/(yu*yv), yu^(-1)}, yw] + 
     8*G[{0, 0, yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] - 
     8*G[{0, 0, yu, 1, 1}, yv^(-1)] + 4*G[{0, 0, yu, 1, yu}, yv^(-1)] + 
     8*G[{0, 0, yu, yu, 1}, yv^(-1)] - 4*G[{0, 0, yv^(-1), 0, 1}, yw] + 
     4*G[{0, 0, yv^(-1), 0, 1/(yu*yv)}, yw] - 
     12*G[{0, 0, yv^(-1), 1, 1}, yw] - 4*G[{0, 0, yv^(-1), 1, yu^(-1)}, yw] + 
     4*G[{0, 0, yv^(-1), 1, yv^(-1)}, yw] + 
     4*G[{0, 0, yv^(-1), 1, 1/(yu*yv)}, yw] - 
     4*G[{0, 0, yv^(-1), yu^(-1), 1}, yw] + 
     4*G[{0, 0, yv^(-1), yu^(-1), 1/(yu*yv)}, yw] + 
     8*G[{0, 0, yv^(-1), yv^(-1), 1/(yu*yv)}, yw] - 
     4*G[{0, 0, yv^(-1), 1/(yu*yv), 1}, yw] + 
     4*G[{0, 0, yv^(-1), 1/(yu*yv), yu^(-1)}, yw] + 
     4*G[{0, 0, yv^(-1), 1/(yu*yv), yv^(-1)}, yw] + 
     8*G[{0, 0, yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] + 
     4*G[{0, 0, 1/(yu*yv), 0, yu^(-1)}, yw] + 
     4*G[{0, 0, 1/(yu*yv), 0, yv^(-1)}, yw] - 
     8*G[{0, 0, 1/(yu*yv), 0, 1/(yu*yv)}, yw] + 
     20*G[{0, 0, 1/(yu*yv), 1, 1}, yw] - 4*G[{0, 0, 1/(yu*yv), 1, yu^(-1)}, 
       yw] - 4*G[{0, 0, 1/(yu*yv), 1, yv^(-1)}, yw] - 
     12*G[{0, 0, 1/(yu*yv), 1, 1/(yu*yv)}, yw] - 
     4*G[{0, 0, 1/(yu*yv), yu^(-1), 1}, yw] + 
     8*G[{0, 0, 1/(yu*yv), yu^(-1), yu^(-1)}, yw] + 
     4*G[{0, 0, 1/(yu*yv), yu^(-1), 1/(yu*yv)}, yw] - 
     4*G[{0, 0, 1/(yu*yv), yv^(-1), 1}, yw] + 
     8*G[{0, 0, 1/(yu*yv), yv^(-1), yv^(-1)}, yw] + 
     4*G[{0, 0, 1/(yu*yv), yv^(-1), 1/(yu*yv)}, yw] - 
     8*G[{0, 0, 1/(yu*yv), 1/(yu*yv), 1}, yw] + 
     4*G[{0, 0, 1/(yu*yv), 1/(yu*yv), yu^(-1)}, yw] + 
     4*G[{0, 0, 1/(yu*yv), 1/(yu*yv), yv^(-1)}, yw] - 
     6*G[{0, 1, 0, 1, 1}, yu^(-1)] - 6*G[{0, 1, 0, 1, 1}, yv^(-1)] - 
     10*G[{0, 1, 0, 1, 1}, yw] - 6*G[{0, 1, 0, 1, yu^(-1)}, yw] - 
     2*G[{0, 1, 0, 1, yu}, yv^(-1)] - 6*G[{0, 1, 0, 1, yv^(-1)}, yw] + 
     4*G[{0, 1, 0, 1, 1/(yu*yv)}, yw] - 4*G[{0, 1, 0, yu^(-1), 1}, yw] + 
     4*G[{0, 1, 0, yu^(-1), yu^(-1)}, yw] - 
     2*G[{0, 1, 0, yu^(-1), yv^(-1)}, yw] + 
     2*G[{0, 1, 0, yu^(-1), 1/(yu*yv)}, yw] - 
     4*G[{0, 1, 0, yu, 1}, yv^(-1)] + 4*G[{0, 1, 0, yu, yu}, yv^(-1)] - 
     4*G[{0, 1, 0, yv^(-1), 1}, yw] - 2*G[{0, 1, 0, yv^(-1), yu^(-1)}, yw] + 
     4*G[{0, 1, 0, yv^(-1), yv^(-1)}, yw] + 
     2*G[{0, 1, 0, yv^(-1), 1/(yu*yv)}, yw] + 
     8*G[{0, 1, 0, 1/(yu*yv), 1}, yw] - 2*G[{0, 1, 0, 1/(yu*yv), 1/(yu*yv)}, 
       yw] - 6*G[{0, 1, 1, 0, yu^(-1)}, yw] - 
     2*G[{0, 1, 1, 0, yu}, yv^(-1)] - 6*G[{0, 1, 1, 0, yv^(-1)}, yw] + 
     2*G[{0, 1, 1, 0, 1/(yu*yv)}, yw] + 8*G[{0, 1, 1, 1, 1}, yu^(-1)] + 
     8*G[{0, 1, 1, 1, 1}, yv^(-1)] + 4*G[{0, 1, 1, 1, 1}, yw] + 
     8*G[{0, 1, 1, 1, yu^(-1)}, yw] + 8*G[{0, 1, 1, 1, yu}, yv^(-1)] + 
     8*G[{0, 1, 1, 1, yv^(-1)}, yw] + 8*G[{0, 1, 1, 1, 1/(yu*yv)}, yw] + 
     8*G[{0, 1, 1, yu^(-1), 1}, yw] - 8*G[{0, 1, 1, yu^(-1), yu^(-1)}, yw] - 
     4*G[{0, 1, 1, yu^(-1), 1/(yu*yv)}, yw] + 
     8*G[{0, 1, 1, yu, 1}, yv^(-1)] - 8*G[{0, 1, 1, yu, yu}, yv^(-1)] + 
     8*G[{0, 1, 1, yv^(-1), 1}, yw] - 8*G[{0, 1, 1, yv^(-1), yv^(-1)}, yw] - 
     4*G[{0, 1, 1, yv^(-1), 1/(yu*yv)}, yw] - 
     4*G[{0, 1, 1, 1/(yu*yv), 1}, yw] + 8*G[{0, 1, 1, 1/(yu*yv), yu^(-1)}, 
       yw] + 8*G[{0, 1, 1, 1/(yu*yv), yv^(-1)}, yw] + 
     12*G[{0, 1, yu^(-1), 1, 1}, yw] - 8*G[{0, 1, yu^(-1), 1, yu^(-1)}, yw] - 
     4*G[{0, 1, yu^(-1), 1, 1/(yu*yv)}, yw] - 
     8*G[{0, 1, yu^(-1), yu^(-1), 1}, yw] - 
     4*G[{0, 1, yu^(-1), 1/(yu*yv), 1}, yw] - 
     4*G[{0, 1, yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] + 
     4*G[{0, 1, yu, 1, 1}, yv^(-1)] - 8*G[{0, 1, yu, 1, yu}, yv^(-1)] - 
     8*G[{0, 1, yu, yu, 1}, yv^(-1)] - 2*G[{0, 1, yv^(-1), 0, yu^(-1)}, yw] + 
     12*G[{0, 1, yv^(-1), 1, 1}, yw] - 8*G[{0, 1, yv^(-1), 1, yv^(-1)}, yw] - 
     4*G[{0, 1, yv^(-1), 1, 1/(yu*yv)}, yw] - 
     8*G[{0, 1, yv^(-1), yv^(-1), 1}, yw] - 
     4*G[{0, 1, yv^(-1), 1/(yu*yv), 1}, yw] - 
     4*G[{0, 1, yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] + 
     4*G[{0, 1, 1/(yu*yv), 0, yu^(-1)}, yw] + 
     4*G[{0, 1, 1/(yu*yv), 0, yv^(-1)}, yw] - 
     2*G[{0, 1, 1/(yu*yv), 0, 1/(yu*yv)}, yw] - 
     12*G[{0, 1, 1/(yu*yv), 1, 1}, yw] + 8*G[{0, 1, 1/(yu*yv), 1, yu^(-1)}, 
       yw] + 8*G[{0, 1, 1/(yu*yv), 1, yv^(-1)}, yw] + 
     8*G[{0, 1, 1/(yu*yv), yu^(-1), 1}, yw] - 
     4*G[{0, 1, 1/(yu*yv), yu^(-1), 1/(yu*yv)}, yw] + 
     8*G[{0, 1, 1/(yu*yv), yv^(-1), 1}, yw] - 
     4*G[{0, 1, 1/(yu*yv), yv^(-1), 1/(yu*yv)}, yw] + 
     4*G[{0, 1, 1/(yu*yv), 1/(yu*yv), 1}, yw] - 
     8*G[{0, 1, 1/(yu*yv), 1/(yu*yv), yu^(-1)}, yw] - 
     8*G[{0, 1, 1/(yu*yv), 1/(yu*yv), yv^(-1)}, yw] - 
     2*G[{0, yu^(-1), 0, yu^(-1), 1}, yw] + 
     6*G[{0, yu^(-1), 0, yu^(-1), 1/(yu*yv)}, yw] - 
     4*G[{0, yu^(-1), 0, 1/(yu*yv), 1}, yw] + 
     4*G[{0, yu^(-1), 0, 1/(yu*yv), yu^(-1)}, yw] - 
     2*G[{0, yu^(-1), 0, 1/(yu*yv), yv^(-1)}, yw] + 
     2*G[{0, yu^(-1), 0, 1/(yu*yv), 1/(yu*yv)}, yw] + 
     2*G[{0, yu^(-1), 1, 0, yv^(-1)}, yw] - 
     2*G[{0, yu^(-1), 1, 0, 1/(yu*yv)}, yw] - 
     4*G[{0, yu^(-1), 1, 1, 1}, yw] - 8*G[{0, yu^(-1), 1, 1, yu^(-1)}, yw] - 
     8*G[{0, yu^(-1), 1, 1, yv^(-1)}, yw] - 
     8*G[{0, yu^(-1), 1, yu^(-1), 1}, yw] + 
     8*G[{0, yu^(-1), 1, yu^(-1), yu^(-1)}, yw] + 
     4*G[{0, yu^(-1), 1, yu^(-1), 1/(yu*yv)}, yw] - 
     8*G[{0, yu^(-1), 1, yv^(-1), 1}, yw] + 
     4*G[{0, yu^(-1), 1, yv^(-1), 1/(yu*yv)}, yw] + 
     4*G[{0, yu^(-1), 1, 1/(yu*yv), 1}, yw] + 
     4*G[{0, yu^(-1), yu^(-1), 0, 1/(yu*yv)}, yw] - 
     12*G[{0, yu^(-1), yu^(-1), 1, 1}, yw] + 
     8*G[{0, yu^(-1), yu^(-1), 1, yu^(-1)}, yw] + 
     4*G[{0, yu^(-1), yu^(-1), 1, 1/(yu*yv)}, yw] + 
     8*G[{0, yu^(-1), yu^(-1), yu^(-1), 1}, yw] - 
     8*G[{0, yu^(-1), yu^(-1), yu^(-1), 1/(yu*yv)}, yw] + 
     4*G[{0, yu^(-1), yu^(-1), 1/(yu*yv), 1}, yw] - 
     8*G[{0, yu^(-1), yu^(-1), 1/(yu*yv), yu^(-1)}, yw] + 
     4*G[{0, yu^(-1), yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] - 
     12*G[{0, yu^(-1), yv^(-1), 1, 1}, yw] + 
     4*G[{0, yu^(-1), yv^(-1), 1, 1/(yu*yv)}, yw] + 
     4*G[{0, yu^(-1), yv^(-1), 1/(yu*yv), 1}, yw] + 
     4*G[{0, yu^(-1), yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] - 
     2*G[{0, yu^(-1), 1/(yu*yv), 0, yv^(-1)}, yw] + 
     2*G[{0, yu^(-1), 1/(yu*yv), 0, 1/(yu*yv)}, yw] + 
     4*G[{0, yu^(-1), 1/(yu*yv), 1, 1}, yw] - 
     8*G[{0, yu^(-1), 1/(yu*yv), yu^(-1), yu^(-1)}, yw] + 
     4*G[{0, yu^(-1), 1/(yu*yv), yu^(-1), 1/(yu*yv)}, yw] + 
     4*G[{0, yu^(-1), 1/(yu*yv), yv^(-1), 1/(yu*yv)}, yw] - 
     4*G[{0, yu^(-1), 1/(yu*yv), 1/(yu*yv), 1}, yw] + 
     8*G[{0, yu^(-1), 1/(yu*yv), 1/(yu*yv), yu^(-1)}, yw] + 
     8*G[{0, yu^(-1), 1/(yu*yv), 1/(yu*yv), yv^(-1)}, yw] + 
     2*G[{0, yu, 0, yu, 1}, yv^(-1)] - 8*G[{0, yu, 1, 1, 1}, yv^(-1)] - 
     8*G[{0, yu, 1, 1, yu}, yv^(-1)] - 8*G[{0, yu, 1, yu, 1}, yv^(-1)] + 
     8*G[{0, yu, 1, yu, yu}, yv^(-1)] - 4*G[{0, yu, yu, 1, 1}, yv^(-1)] + 
     8*G[{0, yu, yu, 1, yu}, yv^(-1)] + 8*G[{0, yu, yu, yu, 1}, yv^(-1)] - 
     2*G[{0, yv^(-1), 0, yv^(-1), 1}, yw] + 
     6*G[{0, yv^(-1), 0, yv^(-1), 1/(yu*yv)}, yw] - 
     4*G[{0, yv^(-1), 0, 1/(yu*yv), 1}, yw] + 
     4*G[{0, yv^(-1), 0, 1/(yu*yv), yv^(-1)}, yw] + 
     2*G[{0, yv^(-1), 0, 1/(yu*yv), 1/(yu*yv)}, yw] - 
     2*G[{0, yv^(-1), 1, 0, 1/(yu*yv)}, yw] - 
     4*G[{0, yv^(-1), 1, 1, 1}, yw] - 8*G[{0, yv^(-1), 1, 1, yu^(-1)}, yw] - 
     8*G[{0, yv^(-1), 1, 1, yv^(-1)}, yw] - 
     8*G[{0, yv^(-1), 1, yu^(-1), 1}, yw] + 
     4*G[{0, yv^(-1), 1, yu^(-1), 1/(yu*yv)}, yw] - 
     8*G[{0, yv^(-1), 1, yv^(-1), 1}, yw] + 
     8*G[{0, yv^(-1), 1, yv^(-1), yv^(-1)}, yw] + 
     4*G[{0, yv^(-1), 1, yv^(-1), 1/(yu*yv)}, yw] + 
     4*G[{0, yv^(-1), 1, 1/(yu*yv), 1}, yw] - 
     12*G[{0, yv^(-1), yu^(-1), 1, 1}, yw] + 
     4*G[{0, yv^(-1), yu^(-1), 1, 1/(yu*yv)}, yw] + 
     4*G[{0, yv^(-1), yu^(-1), 1/(yu*yv), 1}, yw] + 
     4*G[{0, yv^(-1), yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] + 
     4*G[{0, yv^(-1), yv^(-1), 0, 1/(yu*yv)}, yw] - 
     12*G[{0, yv^(-1), yv^(-1), 1, 1}, yw] + 
     8*G[{0, yv^(-1), yv^(-1), 1, yv^(-1)}, yw] + 
     4*G[{0, yv^(-1), yv^(-1), 1, 1/(yu*yv)}, yw] + 
     8*G[{0, yv^(-1), yv^(-1), yv^(-1), 1}, yw] - 
     8*G[{0, yv^(-1), yv^(-1), yv^(-1), 1/(yu*yv)}, yw] + 
     4*G[{0, yv^(-1), yv^(-1), 1/(yu*yv), 1}, yw] - 
     8*G[{0, yv^(-1), yv^(-1), 1/(yu*yv), yv^(-1)}, yw] + 
     4*G[{0, yv^(-1), yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] + 
     2*G[{0, yv^(-1), 1/(yu*yv), 0, 1/(yu*yv)}, yw] + 
     4*G[{0, yv^(-1), 1/(yu*yv), 1, 1}, yw] + 
     4*G[{0, yv^(-1), 1/(yu*yv), yu^(-1), 1/(yu*yv)}, yw] - 
     8*G[{0, yv^(-1), 1/(yu*yv), yv^(-1), yv^(-1)}, yw] + 
     4*G[{0, yv^(-1), 1/(yu*yv), yv^(-1), 1/(yu*yv)}, yw] - 
     4*G[{0, yv^(-1), 1/(yu*yv), 1/(yu*yv), 1}, yw] + 
     8*G[{0, yv^(-1), 1/(yu*yv), 1/(yu*yv), yu^(-1)}, yw] + 
     8*G[{0, yv^(-1), 1/(yu*yv), 1/(yu*yv), yv^(-1)}, yw] - 
     2*G[{0, 1/(yu*yv), 0, 1/(yu*yv), 1}, yw] + 
     4*G[{0, 1/(yu*yv), 0, 1/(yu*yv), yu^(-1)}, yw] + 
     4*G[{0, 1/(yu*yv), 0, 1/(yu*yv), yv^(-1)}, yw] + 
     2*G[{0, 1/(yu*yv), 0, 1/(yu*yv), 1/(yu*yv)}, yw] + 
     4*G[{0, 1/(yu*yv), 1, 1, 1}, yw] + 8*G[{0, 1/(yu*yv), 1, 1, yu^(-1)}, 
       yw] + 8*G[{0, 1/(yu*yv), 1, 1, yv^(-1)}, yw] - 
     8*G[{0, 1/(yu*yv), 1, 1, 1/(yu*yv)}, yw] + 
     8*G[{0, 1/(yu*yv), 1, yu^(-1), 1}, yw] - 
     4*G[{0, 1/(yu*yv), 1, yu^(-1), 1/(yu*yv)}, yw] + 
     8*G[{0, 1/(yu*yv), 1, yv^(-1), 1}, yw] - 
     4*G[{0, 1/(yu*yv), 1, yv^(-1), 1/(yu*yv)}, yw] - 
     4*G[{0, 1/(yu*yv), 1, 1/(yu*yv), 1}, yw] - 
     8*G[{0, 1/(yu*yv), 1, 1/(yu*yv), yu^(-1)}, yw] - 
     8*G[{0, 1/(yu*yv), 1, 1/(yu*yv), yv^(-1)}, yw] + 
     12*G[{0, 1/(yu*yv), yu^(-1), 1, 1}, yw] - 
     4*G[{0, 1/(yu*yv), yu^(-1), 1, 1/(yu*yv)}, yw] + 
     8*G[{0, 1/(yu*yv), yu^(-1), yu^(-1), 1/(yu*yv)}, yw] - 
     4*G[{0, 1/(yu*yv), yu^(-1), 1/(yu*yv), 1}, yw] + 
     8*G[{0, 1/(yu*yv), yu^(-1), 1/(yu*yv), yu^(-1)}, yw] - 
     4*G[{0, 1/(yu*yv), yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] + 
     12*G[{0, 1/(yu*yv), yv^(-1), 1, 1}, yw] - 
     4*G[{0, 1/(yu*yv), yv^(-1), 1, 1/(yu*yv)}, yw] + 
     8*G[{0, 1/(yu*yv), yv^(-1), yv^(-1), 1/(yu*yv)}, yw] - 
     4*G[{0, 1/(yu*yv), yv^(-1), 1/(yu*yv), 1}, yw] + 
     8*G[{0, 1/(yu*yv), yv^(-1), 1/(yu*yv), yv^(-1)}, yw] - 
     4*G[{0, 1/(yu*yv), yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] + 
     4*G[{0, 1/(yu*yv), 1/(yu*yv), 1, 1}, yw] - 
     8*G[{0, 1/(yu*yv), 1/(yu*yv), 1, yu^(-1)}, yw] - 
     8*G[{0, 1/(yu*yv), 1/(yu*yv), 1, yv^(-1)}, yw] - 
     8*G[{0, 1/(yu*yv), 1/(yu*yv), yu^(-1), 1}, yw] + 
     8*G[{0, 1/(yu*yv), 1/(yu*yv), yu^(-1), yu^(-1)}, yw] - 
     4*G[{0, 1/(yu*yv), 1/(yu*yv), yu^(-1), 1/(yu*yv)}, yw] - 
     8*G[{0, 1/(yu*yv), 1/(yu*yv), yv^(-1), 1}, yw] + 
     8*G[{0, 1/(yu*yv), 1/(yu*yv), yv^(-1), yv^(-1)}, yw] - 
     4*G[{0, 1/(yu*yv), 1/(yu*yv), yv^(-1), 1/(yu*yv)}, yw] + 
     4*G[{0, 1/(yu*yv), 1/(yu*yv), 1/(yu*yv), 1}, yw] - 
     8*G[{0, 1/(yu*yv), 1/(yu*yv), 1/(yu*yv), yu^(-1)}, yw] - 
     8*G[{0, 1/(yu*yv), 1/(yu*yv), 1/(yu*yv), yv^(-1)}, yw] - 
     12*G[{1, 1, 1, 1, yu^(-1)}, yw] - 12*G[{1, 1, 1, 1, yu}, yv^(-1)] - 
     12*G[{1, 1, 1, 1, yv^(-1)}, yw] + 16*G[{1, 1, 1, 1, 1/(yu*yv)}, yw] + 
     16*G[{1, 1, 1, yu^(-1), yu^(-1)}, yw] + 
     12*G[{1, 1, 1, yu^(-1), yv^(-1)}, yw] - 
     16*G[{1, 1, 1, yu^(-1), 1/(yu*yv)}, yw] + 
     16*G[{1, 1, 1, yu, yu}, yv^(-1)] + 12*G[{1, 1, 1, yv^(-1), yu^(-1)}, 
       yw] + 16*G[{1, 1, 1, yv^(-1), yv^(-1)}, yw] - 
     16*G[{1, 1, 1, yv^(-1), 1/(yu*yv)}, yw] - 
     12*G[{1, 1, 1, 1/(yu*yv), yu^(-1)}, yw] - 
     12*G[{1, 1, 1, 1/(yu*yv), yv^(-1)}, yw] - 
     24*G[{1, 1, 1, 1/(yu*yv), 1/(yu*yv)}, yw] - 
     8*G[{1, 1, yu^(-1), 1, 1/(yu*yv)}, yw] + 
     16*G[{1, 1, yu^(-1), yu^(-1), yu^(-1)}, yw] + 
     8*G[{1, 1, yu^(-1), yu^(-1), 1/(yu*yv)}, yw] + 
     4*G[{1, 1, yu^(-1), yv^(-1), 1/(yu*yv)}, yw] - 
     4*G[{1, 1, yu^(-1), 1/(yu*yv), yv^(-1)}, yw] + 
     4*G[{1, 1, yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] + 
     16*G[{1, 1, yu, yu, yu}, yv^(-1)] - 8*G[{1, 1, yv^(-1), 1, 1/(yu*yv)}, 
       yw] + 4*G[{1, 1, yv^(-1), yu^(-1), 1/(yu*yv)}, yw] + 
     16*G[{1, 1, yv^(-1), yv^(-1), yv^(-1)}, yw] + 
     8*G[{1, 1, yv^(-1), yv^(-1), 1/(yu*yv)}, yw] - 
     4*G[{1, 1, yv^(-1), 1/(yu*yv), yu^(-1)}, yw] + 
     4*G[{1, 1, yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] - 
     8*G[{1, 1, 1/(yu*yv), 1, 1/(yu*yv)}, yw] - 
     4*G[{1, 1, 1/(yu*yv), yu^(-1), 1/(yu*yv)}, yw] - 
     4*G[{1, 1, 1/(yu*yv), yv^(-1), 1/(yu*yv)}, yw] - 
     12*G[{1, 1, 1/(yu*yv), 1/(yu*yv), yu^(-1)}, yw] - 
     12*G[{1, 1, 1/(yu*yv), 1/(yu*yv), yv^(-1)}, yw] + 
     8*G[{1, 1, 1/(yu*yv), 1/(yu*yv), 1/(yu*yv)}, yw] - 
     4*G[{1, yu^(-1), yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] - 
     4*G[{1, yu^(-1), 1/(yu*yv), yv^(-1), 1/(yu*yv)}, yw] - 
     4*G[{1, yu^(-1), 1/(yu*yv), 1/(yu*yv), yv^(-1)}, yw] - 
     4*G[{1, yv^(-1), yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] - 
     4*G[{1, yv^(-1), 1/(yu*yv), yu^(-1), 1/(yu*yv)}, yw] - 
     4*G[{1, yv^(-1), 1/(yu*yv), 1/(yu*yv), yu^(-1)}, yw] + 
     8*G[{1, 1/(yu*yv), 1, 1/(yu*yv), 1/(yu*yv)}, yw] - 
     4*G[{1, 1/(yu*yv), yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] - 
     4*G[{1, 1/(yu*yv), yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] - 
     4*G[{1, 1/(yu*yv), 1/(yu*yv), yu^(-1), 1/(yu*yv)}, yw] - 
     4*G[{1, 1/(yu*yv), 1/(yu*yv), yv^(-1), 1/(yu*yv)}, yw] - 
     12*G[{1, 1/(yu*yv), 1/(yu*yv), 1/(yu*yv), yu^(-1)}, yw] - 
     12*G[{1, 1/(yu*yv), 1/(yu*yv), 1/(yu*yv), yv^(-1)}, yw] - 
     16*G[{yu^(-1), yu^(-1), yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] + 
     8*G[{yu^(-1), yu^(-1), 1/(yu*yv), 1/(yu*yv), 1/(yu*yv)}, yw] + 
     8*G[{yu^(-1), 1/(yu*yv), yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] + 
     4*G[{yu^(-1), 1/(yu*yv), yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] + 
     4*G[{yu^(-1), 1/(yu*yv), 1/(yu*yv), yv^(-1), 1/(yu*yv)}, yw] + 
     12*G[{yu^(-1), 1/(yu*yv), 1/(yu*yv), 1/(yu*yv), yv^(-1)}, yw] - 
     16*G[{yv^(-1), yv^(-1), yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] + 
     8*G[{yv^(-1), yv^(-1), 1/(yu*yv), 1/(yu*yv), 1/(yu*yv)}, yw] + 
     8*G[{yv^(-1), 1/(yu*yv), yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] + 
     Pi^2*Zeta[3] - 2*G[{1}, yu^(-1)]^2*Zeta[3] + 
     4*G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*Zeta[3] - 2*G[{1}, yv^(-1)]^2*
      Zeta[3] - 4*G[{1}, yu^(-1)]*G[{1}, yw]*Zeta[3] - 
     4*G[{1}, yv^(-1)]*G[{1}, yw]*Zeta[3] + 6*G[{1}, yw]^2*Zeta[3] + 
     4*G[{1}, yu^(-1)]*G[{1/(yu*yv)}, yw]*Zeta[3] + 
     4*G[{1}, yv^(-1)]*G[{1/(yu*yv)}, yw]*Zeta[3] - 
     4*G[{1}, yw]*G[{1/(yu*yv)}, yw]*Zeta[3] - 2*G[{1/(yu*yv)}, yw]^2*
      Zeta[3] + 4*G[{0, 1}, yu^(-1)]*Zeta[3] + 4*G[{0, 1}, yv^(-1)]*Zeta[3] - 
     4*G[{0, 1}, yw]*Zeta[3] + 4*G[{0, 1/(yu*yv)}, yw]*Zeta[3] - 7*Zeta[5]
 
OuvwRegII = -(Pi^2*G[{1}, yu^(-1)]^2*G[{1}, yv^(-1)])/4 + 
     (Pi^2*G[{1}, yu^(-1)]*G[{1}, yv^(-1)]^2)/6 + 
     (G[{1}, yu^(-1)]^2*G[{1}, yv^(-1)]^3)/6 - 
     (G[{1}, yu^(-1)]*G[{1}, yv^(-1)]^4)/12 - (7*Pi^4*G[{1}, yw])/360 + 
     (Pi^2*G[{0}, yu^(-1)]*G[{1}, yu^(-1)]*G[{1}, yw])/3 + 
     (Pi^2*G[{0}, yv^(-1)]*G[{1}, yu^(-1)]*G[{1}, yw])/3 - 
     (Pi^2*G[{0}, yw]*G[{1}, yu^(-1)]*G[{1}, yw])/3 - 
     (Pi^2*G[{1}, yu^(-1)]^2*G[{1}, yw])/6 + 
     (Pi^2*G[{0}, yu^(-1)]*G[{1}, yv^(-1)]*G[{1}, yw])/3 + 
     (Pi^2*G[{0}, yv^(-1)]*G[{1}, yv^(-1)]*G[{1}, yw])/3 - 
     (Pi^2*G[{0}, yw]*G[{1}, yv^(-1)]*G[{1}, yw])/3 - 
     (2*Pi^2*G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*G[{1}, yw])/3 + 
     (G[{0}, yu^(-1)]^2*G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*G[{1}, yw])/2 + 
     G[{0}, yu^(-1)]*G[{0}, yv^(-1)]*G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*
      G[{1}, yw] + (G[{0}, yv^(-1)]^2*G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*
       G[{1}, yw])/2 - G[{0}, yu^(-1)]*G[{0}, yw]*G[{1}, yu^(-1)]*
      G[{1}, yv^(-1)]*G[{1}, yw] - G[{0}, yv^(-1)]*G[{0}, yw]*G[{1}, yu^(-1)]*
      G[{1}, yv^(-1)]*G[{1}, yw] + (G[{0}, yw]^2*G[{1}, yu^(-1)]*
       G[{1}, yv^(-1)]*G[{1}, yw])/2 - (3*G[{0}, yu^(-1)]*G[{1}, yu^(-1)]^2*
       G[{1}, yv^(-1)]*G[{1}, yw])/2 - (3*G[{0}, yv^(-1)]*G[{1}, yu^(-1)]^2*
       G[{1}, yv^(-1)]*G[{1}, yw])/2 + (3*G[{0}, yw]*G[{1}, yu^(-1)]^2*
       G[{1}, yv^(-1)]*G[{1}, yw])/2 + G[{1}, yu^(-1)]^3*G[{1}, yv^(-1)]*
      G[{1}, yw] - (Pi^2*G[{1}, yv^(-1)]^2*G[{1}, yw])/6 + 
     (G[{1}, yu^(-1)]^2*G[{1}, yv^(-1)]^2*G[{1}, yw])/2 - 
     (G[{1}, yu^(-1)]*G[{1}, yv^(-1)]^3*G[{1}, yw])/6 - 
     (Pi^2*G[{0}, yu^(-1)]*G[{1}, yw]^2)/12 - 
     (Pi^2*G[{0}, yv^(-1)]*G[{1}, yw]^2)/12 + (Pi^2*G[{0}, yw]*G[{1}, yw]^2)/
      12 + (Pi^2*G[{1}, yu^(-1)]*G[{1}, yw]^2)/12 + 
     (Pi^2*G[{1}, yv^(-1)]*G[{1}, yw]^2)/12 + (Pi^2*G[{1}, yw]^3)/18 + 
     (G[{0}, yu^(-1)]^2*G[{1}, yw]^3)/6 + 
     (G[{0}, yu^(-1)]*G[{0}, yv^(-1)]*G[{1}, yw]^3)/3 + 
     (G[{0}, yv^(-1)]^2*G[{1}, yw]^3)/6 - 
     (G[{0}, yu^(-1)]*G[{0}, yw]*G[{1}, yw]^3)/3 - 
     (G[{0}, yv^(-1)]*G[{0}, yw]*G[{1}, yw]^3)/3 + 
     (G[{0}, yw]^2*G[{1}, yw]^3)/6 - (G[{0}, yu^(-1)]*G[{1}, yu^(-1)]*
       G[{1}, yw]^3)/3 - (G[{0}, yv^(-1)]*G[{1}, yu^(-1)]*G[{1}, yw]^3)/3 + 
     (G[{0}, yw]*G[{1}, yu^(-1)]*G[{1}, yw]^3)/3 + 
     (G[{1}, yu^(-1)]^2*G[{1}, yw]^3)/6 - 
     (G[{0}, yu^(-1)]*G[{1}, yv^(-1)]*G[{1}, yw]^3)/3 - 
     (G[{0}, yv^(-1)]*G[{1}, yv^(-1)]*G[{1}, yw]^3)/3 + 
     (G[{0}, yw]*G[{1}, yv^(-1)]*G[{1}, yw]^3)/3 + 
     (G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*G[{1}, yw]^3)/3 + 
     (G[{1}, yv^(-1)]^2*G[{1}, yw]^3)/6 + (G[{0}, yu^(-1)]*G[{1}, yw]^4)/12 + 
     (G[{0}, yv^(-1)]*G[{1}, yw]^4)/12 - (G[{0}, yw]*G[{1}, yw]^4)/12 - 
     (G[{1}, yu^(-1)]*G[{1}, yw]^4)/12 - (G[{1}, yv^(-1)]*G[{1}, yw]^4)/12 + 
     (7*Pi^4*G[{yu^(-1)}, yw])/360 - (Pi^2*G[{0}, yu^(-1)]*G[{1}, yu^(-1)]*
       G[{yu^(-1)}, yw])/3 - (Pi^2*G[{0}, yv^(-1)]*G[{1}, yu^(-1)]*
       G[{yu^(-1)}, yw])/3 + (Pi^2*G[{0}, yw]*G[{1}, yu^(-1)]*
       G[{yu^(-1)}, yw])/3 + (Pi^2*G[{1}, yu^(-1)]^2*G[{yu^(-1)}, yw])/6 - 
     (Pi^2*G[{0}, yu^(-1)]*G[{1}, yv^(-1)]*G[{yu^(-1)}, yw])/3 - 
     (Pi^2*G[{0}, yv^(-1)]*G[{1}, yv^(-1)]*G[{yu^(-1)}, yw])/3 + 
     (Pi^2*G[{0}, yw]*G[{1}, yv^(-1)]*G[{yu^(-1)}, yw])/3 + 
     Pi^2*G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*G[{yu^(-1)}, yw] - 
     (G[{0}, yu^(-1)]^2*G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*G[{yu^(-1)}, yw])/2 - 
     G[{0}, yu^(-1)]*G[{0}, yv^(-1)]*G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*
      G[{yu^(-1)}, yw] - (G[{0}, yv^(-1)]^2*G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*
       G[{yu^(-1)}, yw])/2 + G[{0}, yu^(-1)]*G[{0}, yw]*G[{1}, yu^(-1)]*
      G[{1}, yv^(-1)]*G[{yu^(-1)}, yw] + G[{0}, yv^(-1)]*G[{0}, yw]*
      G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*G[{yu^(-1)}, yw] - 
     (G[{0}, yw]^2*G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*G[{yu^(-1)}, yw])/2 + 
     (3*G[{0}, yu^(-1)]*G[{1}, yu^(-1)]^2*G[{1}, yv^(-1)]*G[{yu^(-1)}, yw])/
      2 + (3*G[{0}, yv^(-1)]*G[{1}, yu^(-1)]^2*G[{1}, yv^(-1)]*
       G[{yu^(-1)}, yw])/2 - (3*G[{0}, yw]*G[{1}, yu^(-1)]^2*G[{1}, yv^(-1)]*
       G[{yu^(-1)}, yw])/2 - G[{1}, yu^(-1)]^3*G[{1}, yv^(-1)]*
      G[{yu^(-1)}, yw] + (5*Pi^2*G[{1}, yv^(-1)]^2*G[{yu^(-1)}, yw])/12 - 
     G[{1}, yu^(-1)]^2*G[{1}, yv^(-1)]^2*G[{yu^(-1)}, yw] + 
     (G[{1}, yu^(-1)]*G[{1}, yv^(-1)]^3*G[{yu^(-1)}, yw])/3 - 
     (Pi^2*G[{0}, yu^(-1)]*G[{1}, yw]*G[{yu^(-1)}, yw])/6 - 
     (Pi^2*G[{0}, yv^(-1)]*G[{1}, yw]*G[{yu^(-1)}, yw])/6 + 
     (Pi^2*G[{0}, yw]*G[{1}, yw]*G[{yu^(-1)}, yw])/6 + 
     (Pi^2*G[{1}, yu^(-1)]*G[{1}, yw]*G[{yu^(-1)}, yw])/6 + 
     (2*Pi^2*G[{1}, yv^(-1)]*G[{1}, yw]*G[{yu^(-1)}, yw])/3 - 
     (G[{0}, yu^(-1)]^2*G[{1}, yv^(-1)]*G[{1}, yw]*G[{yu^(-1)}, yw])/2 - 
     G[{0}, yu^(-1)]*G[{0}, yv^(-1)]*G[{1}, yv^(-1)]*G[{1}, yw]*
      G[{yu^(-1)}, yw] - (G[{0}, yv^(-1)]^2*G[{1}, yv^(-1)]*G[{1}, yw]*
       G[{yu^(-1)}, yw])/2 + G[{0}, yu^(-1)]*G[{0}, yw]*G[{1}, yv^(-1)]*
      G[{1}, yw]*G[{yu^(-1)}, yw] + G[{0}, yv^(-1)]*G[{0}, yw]*
      G[{1}, yv^(-1)]*G[{1}, yw]*G[{yu^(-1)}, yw] - 
     (G[{0}, yw]^2*G[{1}, yv^(-1)]*G[{1}, yw]*G[{yu^(-1)}, yw])/2 - 
     G[{0}, yu^(-1)]*G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*G[{1}, yw]*
      G[{yu^(-1)}, yw] - G[{0}, yv^(-1)]*G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*
      G[{1}, yw]*G[{yu^(-1)}, yw] + G[{0}, yw]*G[{1}, yu^(-1)]*
      G[{1}, yv^(-1)]*G[{1}, yw]*G[{yu^(-1)}, yw] + 
     G[{1}, yu^(-1)]^2*G[{1}, yv^(-1)]*G[{1}, yw]*G[{yu^(-1)}, yw] + 
     (3*G[{0}, yu^(-1)]*G[{1}, yv^(-1)]^2*G[{1}, yw]*G[{yu^(-1)}, yw])/2 + 
     (3*G[{0}, yv^(-1)]*G[{1}, yv^(-1)]^2*G[{1}, yw]*G[{yu^(-1)}, yw])/2 - 
     (3*G[{0}, yw]*G[{1}, yv^(-1)]^2*G[{1}, yw]*G[{yu^(-1)}, yw])/2 + 
     (3*G[{1}, yu^(-1)]*G[{1}, yv^(-1)]^2*G[{1}, yw]*G[{yu^(-1)}, yw])/2 - 
     G[{1}, yv^(-1)]^3*G[{1}, yw]*G[{yu^(-1)}, yw] + 
     (Pi^2*G[{1}, yw]^2*G[{yu^(-1)}, yw])/12 - G[{0}, yu^(-1)]^2*G[{1}, yw]^2*
      G[{yu^(-1)}, yw] - 2*G[{0}, yu^(-1)]*G[{0}, yv^(-1)]*G[{1}, yw]^2*
      G[{yu^(-1)}, yw] - G[{0}, yv^(-1)]^2*G[{1}, yw]^2*G[{yu^(-1)}, yw] + 
     2*G[{0}, yu^(-1)]*G[{0}, yw]*G[{1}, yw]^2*G[{yu^(-1)}, yw] + 
     2*G[{0}, yv^(-1)]*G[{0}, yw]*G[{1}, yw]^2*G[{yu^(-1)}, yw] - 
     G[{0}, yw]^2*G[{1}, yw]^2*G[{yu^(-1)}, yw] + 
     2*G[{0}, yu^(-1)]*G[{1}, yu^(-1)]*G[{1}, yw]^2*G[{yu^(-1)}, yw] + 
     2*G[{0}, yv^(-1)]*G[{1}, yu^(-1)]*G[{1}, yw]^2*G[{yu^(-1)}, yw] - 
     2*G[{0}, yw]*G[{1}, yu^(-1)]*G[{1}, yw]^2*G[{yu^(-1)}, yw] - 
     G[{1}, yu^(-1)]^2*G[{1}, yw]^2*G[{yu^(-1)}, yw] + 
     2*G[{0}, yu^(-1)]*G[{1}, yv^(-1)]*G[{1}, yw]^2*G[{yu^(-1)}, yw] + 
     2*G[{0}, yv^(-1)]*G[{1}, yv^(-1)]*G[{1}, yw]^2*G[{yu^(-1)}, yw] - 
     2*G[{0}, yw]*G[{1}, yv^(-1)]*G[{1}, yw]^2*G[{yu^(-1)}, yw] - 
     (3*G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*G[{1}, yw]^2*G[{yu^(-1)}, yw])/2 - 
     G[{1}, yv^(-1)]^2*G[{1}, yw]^2*G[{yu^(-1)}, yw] - 
     (G[{0}, yu^(-1)]*G[{1}, yw]^3*G[{yu^(-1)}, yw])/2 - 
     (G[{0}, yv^(-1)]*G[{1}, yw]^3*G[{yu^(-1)}, yw])/2 + 
     (G[{0}, yw]*G[{1}, yw]^3*G[{yu^(-1)}, yw])/2 + 
     (G[{1}, yu^(-1)]*G[{1}, yw]^3*G[{yu^(-1)}, yw])/2 + 
     (G[{1}, yv^(-1)]*G[{1}, yw]^3*G[{yu^(-1)}, yw])/2 + 
     (Pi^2*G[{0}, yu^(-1)]*G[{yu^(-1)}, yw]^2)/4 + 
     (Pi^2*G[{0}, yv^(-1)]*G[{yu^(-1)}, yw]^2)/4 - 
     (Pi^2*G[{0}, yw]*G[{yu^(-1)}, yw]^2)/4 - 
     (Pi^2*G[{1}, yu^(-1)]*G[{yu^(-1)}, yw]^2)/4 - 
     (Pi^2*G[{1}, yv^(-1)]*G[{yu^(-1)}, yw]^2)/2 + 
     (G[{0}, yu^(-1)]^2*G[{1}, yv^(-1)]*G[{yu^(-1)}, yw]^2)/2 + 
     G[{0}, yu^(-1)]*G[{0}, yv^(-1)]*G[{1}, yv^(-1)]*G[{yu^(-1)}, yw]^2 + 
     (G[{0}, yv^(-1)]^2*G[{1}, yv^(-1)]*G[{yu^(-1)}, yw]^2)/2 - 
     G[{0}, yu^(-1)]*G[{0}, yw]*G[{1}, yv^(-1)]*G[{yu^(-1)}, yw]^2 - 
     G[{0}, yv^(-1)]*G[{0}, yw]*G[{1}, yv^(-1)]*G[{yu^(-1)}, yw]^2 + 
     (G[{0}, yw]^2*G[{1}, yv^(-1)]*G[{yu^(-1)}, yw]^2)/2 + 
     (G[{0}, yu^(-1)]*G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*G[{yu^(-1)}, yw]^2)/2 + 
     (G[{0}, yv^(-1)]*G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*G[{yu^(-1)}, yw]^2)/2 - 
     (G[{0}, yw]*G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*G[{yu^(-1)}, yw]^2)/2 - 
     (G[{1}, yu^(-1)]^2*G[{1}, yv^(-1)]*G[{yu^(-1)}, yw]^2)/2 - 
     (3*G[{0}, yu^(-1)]*G[{1}, yv^(-1)]^2*G[{yu^(-1)}, yw]^2)/2 - 
     (3*G[{0}, yv^(-1)]*G[{1}, yv^(-1)]^2*G[{yu^(-1)}, yw]^2)/2 + 
     (3*G[{0}, yw]*G[{1}, yv^(-1)]^2*G[{yu^(-1)}, yw]^2)/2 - 
     (3*G[{1}, yu^(-1)]*G[{1}, yv^(-1)]^2*G[{yu^(-1)}, yw]^2)/2 + 
     G[{1}, yv^(-1)]^3*G[{yu^(-1)}, yw]^2 - 
     (Pi^2*G[{1}, yw]*G[{yu^(-1)}, yw]^2)/4 + 
     (3*G[{0}, yu^(-1)]^2*G[{1}, yw]*G[{yu^(-1)}, yw]^2)/4 + 
     (3*G[{0}, yu^(-1)]*G[{0}, yv^(-1)]*G[{1}, yw]*G[{yu^(-1)}, yw]^2)/2 + 
     (3*G[{0}, yv^(-1)]^2*G[{1}, yw]*G[{yu^(-1)}, yw]^2)/4 - 
     (3*G[{0}, yu^(-1)]*G[{0}, yw]*G[{1}, yw]*G[{yu^(-1)}, yw]^2)/2 - 
     (3*G[{0}, yv^(-1)]*G[{0}, yw]*G[{1}, yw]*G[{yu^(-1)}, yw]^2)/2 + 
     (3*G[{0}, yw]^2*G[{1}, yw]*G[{yu^(-1)}, yw]^2)/4 - 
     (3*G[{0}, yu^(-1)]*G[{1}, yu^(-1)]*G[{1}, yw]*G[{yu^(-1)}, yw]^2)/2 - 
     (3*G[{0}, yv^(-1)]*G[{1}, yu^(-1)]*G[{1}, yw]*G[{yu^(-1)}, yw]^2)/2 + 
     (3*G[{0}, yw]*G[{1}, yu^(-1)]*G[{1}, yw]*G[{yu^(-1)}, yw]^2)/2 + 
     (3*G[{1}, yu^(-1)]^2*G[{1}, yw]*G[{yu^(-1)}, yw]^2)/4 - 
     G[{0}, yu^(-1)]*G[{1}, yv^(-1)]*G[{1}, yw]*G[{yu^(-1)}, yw]^2 - 
     G[{0}, yv^(-1)]*G[{1}, yv^(-1)]*G[{1}, yw]*G[{yu^(-1)}, yw]^2 + 
     G[{0}, yw]*G[{1}, yv^(-1)]*G[{1}, yw]*G[{yu^(-1)}, yw]^2 - 
     (G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*G[{1}, yw]*G[{yu^(-1)}, yw]^2)/2 + 
     (G[{1}, yv^(-1)]^2*G[{1}, yw]*G[{yu^(-1)}, yw]^2)/4 + 
     G[{0}, yu^(-1)]*G[{1}, yw]^2*G[{yu^(-1)}, yw]^2 + 
     G[{0}, yv^(-1)]*G[{1}, yw]^2*G[{yu^(-1)}, yw]^2 - 
     G[{0}, yw]*G[{1}, yw]^2*G[{yu^(-1)}, yw]^2 - 
     G[{1}, yu^(-1)]*G[{1}, yw]^2*G[{yu^(-1)}, yw]^2 - 
     G[{1}, yv^(-1)]*G[{1}, yw]^2*G[{yu^(-1)}, yw]^2 + 
     (Pi^2*G[{yu^(-1)}, yw]^3)/6 - (G[{0}, yu^(-1)]^2*G[{yu^(-1)}, yw]^3)/4 - 
     (G[{0}, yu^(-1)]*G[{0}, yv^(-1)]*G[{yu^(-1)}, yw]^3)/2 - 
     (G[{0}, yv^(-1)]^2*G[{yu^(-1)}, yw]^3)/4 + 
     (G[{0}, yu^(-1)]*G[{0}, yw]*G[{yu^(-1)}, yw]^3)/2 + 
     (G[{0}, yv^(-1)]*G[{0}, yw]*G[{yu^(-1)}, yw]^3)/2 - 
     (G[{0}, yw]^2*G[{yu^(-1)}, yw]^3)/4 + 
     (G[{0}, yu^(-1)]*G[{1}, yu^(-1)]*G[{yu^(-1)}, yw]^3)/2 + 
     (G[{0}, yv^(-1)]*G[{1}, yu^(-1)]*G[{yu^(-1)}, yw]^3)/2 - 
     (G[{0}, yw]*G[{1}, yu^(-1)]*G[{yu^(-1)}, yw]^3)/2 - 
     (G[{1}, yu^(-1)]^2*G[{yu^(-1)}, yw]^3)/4 + 
     (G[{0}, yu^(-1)]*G[{1}, yv^(-1)]*G[{yu^(-1)}, yw]^3)/6 + 
     (G[{0}, yv^(-1)]*G[{1}, yv^(-1)]*G[{yu^(-1)}, yw]^3)/6 - 
     (G[{0}, yw]*G[{1}, yv^(-1)]*G[{yu^(-1)}, yw]^3)/6 + 
     (5*G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*G[{yu^(-1)}, yw]^3)/6 - 
     (G[{1}, yv^(-1)]^2*G[{yu^(-1)}, yw]^3)/6 - 
     (4*G[{0}, yu^(-1)]*G[{1}, yw]*G[{yu^(-1)}, yw]^3)/3 - 
     (4*G[{0}, yv^(-1)]*G[{1}, yw]*G[{yu^(-1)}, yw]^3)/3 + 
     (4*G[{0}, yw]*G[{1}, yw]*G[{yu^(-1)}, yw]^3)/3 + 
     (4*G[{1}, yu^(-1)]*G[{1}, yw]*G[{yu^(-1)}, yw]^3)/3 + 
     (5*G[{1}, yv^(-1)]*G[{1}, yw]*G[{yu^(-1)}, yw]^3)/6 - 
     (G[{1}, yw]^2*G[{yu^(-1)}, yw]^3)/4 + 
     (5*G[{0}, yu^(-1)]*G[{yu^(-1)}, yw]^4)/24 + 
     (5*G[{0}, yv^(-1)]*G[{yu^(-1)}, yw]^4)/24 - 
     (5*G[{0}, yw]*G[{yu^(-1)}, yw]^4)/24 - 
     (5*G[{1}, yu^(-1)]*G[{yu^(-1)}, yw]^4)/24 - 
     (5*G[{1}, yv^(-1)]*G[{yu^(-1)}, yw]^4)/12 - 
     (5*G[{1}, yw]*G[{yu^(-1)}, yw]^4)/24 + G[{yu^(-1)}, yw]^5/12 + 
     (Pi^2*G[{1}, yu^(-1)]^2*G[{yu}, yv^(-1)])/4 + 
     (Pi^2*G[{1}, yv^(-1)]^2*G[{yu}, yv^(-1)])/4 - 
     G[{1}, yu^(-1)]^2*G[{1}, yv^(-1)]^2*G[{yu}, yv^(-1)] + 
     (G[{1}, yu^(-1)]*G[{1}, yv^(-1)]^3*G[{yu}, yv^(-1)])/2 - 
     (Pi^2*G[{0}, yu^(-1)]*G[{1}, yw]*G[{yu}, yv^(-1)])/3 - 
     (Pi^2*G[{0}, yv^(-1)]*G[{1}, yw]*G[{yu}, yv^(-1)])/3 + 
     (Pi^2*G[{0}, yw]*G[{1}, yw]*G[{yu}, yv^(-1)])/3 + 
     (Pi^2*G[{1}, yu^(-1)]*G[{1}, yw]*G[{yu}, yv^(-1)])/3 - 
     (G[{0}, yu^(-1)]^2*G[{1}, yu^(-1)]*G[{1}, yw]*G[{yu}, yv^(-1)])/2 - 
     G[{0}, yu^(-1)]*G[{0}, yv^(-1)]*G[{1}, yu^(-1)]*G[{1}, yw]*
      G[{yu}, yv^(-1)] - (G[{0}, yv^(-1)]^2*G[{1}, yu^(-1)]*G[{1}, yw]*
       G[{yu}, yv^(-1)])/2 + G[{0}, yu^(-1)]*G[{0}, yw]*G[{1}, yu^(-1)]*
      G[{1}, yw]*G[{yu}, yv^(-1)] + G[{0}, yv^(-1)]*G[{0}, yw]*
      G[{1}, yu^(-1)]*G[{1}, yw]*G[{yu}, yv^(-1)] - 
     (G[{0}, yw]^2*G[{1}, yu^(-1)]*G[{1}, yw]*G[{yu}, yv^(-1)])/2 + 
     (3*G[{0}, yu^(-1)]*G[{1}, yu^(-1)]^2*G[{1}, yw]*G[{yu}, yv^(-1)])/2 + 
     (3*G[{0}, yv^(-1)]*G[{1}, yu^(-1)]^2*G[{1}, yw]*G[{yu}, yv^(-1)])/2 - 
     (3*G[{0}, yw]*G[{1}, yu^(-1)]^2*G[{1}, yw]*G[{yu}, yv^(-1)])/2 - 
     G[{1}, yu^(-1)]^3*G[{1}, yw]*G[{yu}, yv^(-1)] + 
     (Pi^2*G[{1}, yv^(-1)]*G[{1}, yw]*G[{yu}, yv^(-1)])/3 - 
     (G[{0}, yu^(-1)]^2*G[{1}, yv^(-1)]*G[{1}, yw]*G[{yu}, yv^(-1)])/2 - 
     G[{0}, yu^(-1)]*G[{0}, yv^(-1)]*G[{1}, yv^(-1)]*G[{1}, yw]*
      G[{yu}, yv^(-1)] - (G[{0}, yv^(-1)]^2*G[{1}, yv^(-1)]*G[{1}, yw]*
       G[{yu}, yv^(-1)])/2 + G[{0}, yu^(-1)]*G[{0}, yw]*G[{1}, yv^(-1)]*
      G[{1}, yw]*G[{yu}, yv^(-1)] + G[{0}, yv^(-1)]*G[{0}, yw]*
      G[{1}, yv^(-1)]*G[{1}, yw]*G[{yu}, yv^(-1)] - 
     (G[{0}, yw]^2*G[{1}, yv^(-1)]*G[{1}, yw]*G[{yu}, yv^(-1)])/2 - 
     2*G[{0}, yu^(-1)]*G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*G[{1}, yw]*
      G[{yu}, yv^(-1)] - 2*G[{0}, yv^(-1)]*G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*
      G[{1}, yw]*G[{yu}, yv^(-1)] + 2*G[{0}, yw]*G[{1}, yu^(-1)]*
      G[{1}, yv^(-1)]*G[{1}, yw]*G[{yu}, yv^(-1)] + 
     2*G[{1}, yu^(-1)]^2*G[{1}, yv^(-1)]*G[{1}, yw]*G[{yu}, yv^(-1)] + 
     (3*G[{0}, yu^(-1)]*G[{1}, yv^(-1)]^2*G[{1}, yw]*G[{yu}, yv^(-1)])/2 + 
     (3*G[{0}, yv^(-1)]*G[{1}, yv^(-1)]^2*G[{1}, yw]*G[{yu}, yv^(-1)])/2 - 
     (3*G[{0}, yw]*G[{1}, yv^(-1)]^2*G[{1}, yw]*G[{yu}, yv^(-1)])/2 + 
     2*G[{1}, yu^(-1)]*G[{1}, yv^(-1)]^2*G[{1}, yw]*G[{yu}, yv^(-1)] - 
     G[{1}, yv^(-1)]^3*G[{1}, yw]*G[{yu}, yv^(-1)] + 
     (Pi^2*G[{0}, yu^(-1)]*G[{yu^(-1)}, yw]*G[{yu}, yv^(-1)])/3 + 
     (Pi^2*G[{0}, yv^(-1)]*G[{yu^(-1)}, yw]*G[{yu}, yv^(-1)])/3 - 
     (Pi^2*G[{0}, yw]*G[{yu^(-1)}, yw]*G[{yu}, yv^(-1)])/3 - 
     (2*Pi^2*G[{1}, yu^(-1)]*G[{yu^(-1)}, yw]*G[{yu}, yv^(-1)])/3 + 
     (G[{0}, yu^(-1)]^2*G[{1}, yu^(-1)]*G[{yu^(-1)}, yw]*G[{yu}, yv^(-1)])/
      2 + G[{0}, yu^(-1)]*G[{0}, yv^(-1)]*G[{1}, yu^(-1)]*G[{yu^(-1)}, yw]*
      G[{yu}, yv^(-1)] + (G[{0}, yv^(-1)]^2*G[{1}, yu^(-1)]*G[{yu^(-1)}, yw]*
       G[{yu}, yv^(-1)])/2 - G[{0}, yu^(-1)]*G[{0}, yw]*G[{1}, yu^(-1)]*
      G[{yu^(-1)}, yw]*G[{yu}, yv^(-1)] - G[{0}, yv^(-1)]*G[{0}, yw]*
      G[{1}, yu^(-1)]*G[{yu^(-1)}, yw]*G[{yu}, yv^(-1)] + 
     (G[{0}, yw]^2*G[{1}, yu^(-1)]*G[{yu^(-1)}, yw]*G[{yu}, yv^(-1)])/2 - 
     (3*G[{0}, yu^(-1)]*G[{1}, yu^(-1)]^2*G[{yu^(-1)}, yw]*G[{yu}, yv^(-1)])/
      2 - (3*G[{0}, yv^(-1)]*G[{1}, yu^(-1)]^2*G[{yu^(-1)}, yw]*
       G[{yu}, yv^(-1)])/2 + (3*G[{0}, yw]*G[{1}, yu^(-1)]^2*G[{yu^(-1)}, yw]*
       G[{yu}, yv^(-1)])/2 + G[{1}, yu^(-1)]^3*G[{yu^(-1)}, yw]*
      G[{yu}, yv^(-1)] - (Pi^2*G[{1}, yv^(-1)]*G[{yu^(-1)}, yw]*
       G[{yu}, yv^(-1)])/2 + (G[{0}, yu^(-1)]^2*G[{1}, yv^(-1)]*
       G[{yu^(-1)}, yw]*G[{yu}, yv^(-1)])/2 + G[{0}, yu^(-1)]*G[{0}, yv^(-1)]*
      G[{1}, yv^(-1)]*G[{yu^(-1)}, yw]*G[{yu}, yv^(-1)] + 
     (G[{0}, yv^(-1)]^2*G[{1}, yv^(-1)]*G[{yu^(-1)}, yw]*G[{yu}, yv^(-1)])/
      2 - G[{0}, yu^(-1)]*G[{0}, yw]*G[{1}, yv^(-1)]*G[{yu^(-1)}, yw]*
      G[{yu}, yv^(-1)] - G[{0}, yv^(-1)]*G[{0}, yw]*G[{1}, yv^(-1)]*
      G[{yu^(-1)}, yw]*G[{yu}, yv^(-1)] + 
     (G[{0}, yw]^2*G[{1}, yv^(-1)]*G[{yu^(-1)}, yw]*G[{yu}, yv^(-1)])/2 + 
     2*G[{0}, yu^(-1)]*G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*G[{yu^(-1)}, yw]*
      G[{yu}, yv^(-1)] + 2*G[{0}, yv^(-1)]*G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*
      G[{yu^(-1)}, yw]*G[{yu}, yv^(-1)] - 2*G[{0}, yw]*G[{1}, yu^(-1)]*
      G[{1}, yv^(-1)]*G[{yu^(-1)}, yw]*G[{yu}, yv^(-1)] - 
     G[{1}, yu^(-1)]^2*G[{1}, yv^(-1)]*G[{yu^(-1)}, yw]*G[{yu}, yv^(-1)] - 
     (3*G[{0}, yu^(-1)]*G[{1}, yv^(-1)]^2*G[{yu^(-1)}, yw]*G[{yu}, yv^(-1)])/
      2 - (3*G[{0}, yv^(-1)]*G[{1}, yv^(-1)]^2*G[{yu^(-1)}, yw]*
       G[{yu}, yv^(-1)])/2 + (3*G[{0}, yw]*G[{1}, yv^(-1)]^2*G[{yu^(-1)}, yw]*
       G[{yu}, yv^(-1)])/2 - (5*G[{1}, yu^(-1)]*G[{1}, yv^(-1)]^2*
       G[{yu^(-1)}, yw]*G[{yu}, yv^(-1)])/2 + G[{1}, yv^(-1)]^3*
      G[{yu^(-1)}, yw]*G[{yu}, yv^(-1)] - 
     (Pi^2*G[{1}, yw]*G[{yu^(-1)}, yw]*G[{yu}, yv^(-1)])/2 + 
     (G[{0}, yu^(-1)]^2*G[{1}, yw]*G[{yu^(-1)}, yw]*G[{yu}, yv^(-1)])/2 + 
     G[{0}, yu^(-1)]*G[{0}, yv^(-1)]*G[{1}, yw]*G[{yu^(-1)}, yw]*
      G[{yu}, yv^(-1)] + (G[{0}, yv^(-1)]^2*G[{1}, yw]*G[{yu^(-1)}, yw]*
       G[{yu}, yv^(-1)])/2 - G[{0}, yu^(-1)]*G[{0}, yw]*G[{1}, yw]*
      G[{yu^(-1)}, yw]*G[{yu}, yv^(-1)] - G[{0}, yv^(-1)]*G[{0}, yw]*
      G[{1}, yw]*G[{yu^(-1)}, yw]*G[{yu}, yv^(-1)] + 
     (G[{0}, yw]^2*G[{1}, yw]*G[{yu^(-1)}, yw]*G[{yu}, yv^(-1)])/2 + 
     G[{0}, yu^(-1)]*G[{1}, yu^(-1)]*G[{1}, yw]*G[{yu^(-1)}, yw]*
      G[{yu}, yv^(-1)] + G[{0}, yv^(-1)]*G[{1}, yu^(-1)]*G[{1}, yw]*
      G[{yu^(-1)}, yw]*G[{yu}, yv^(-1)] - G[{0}, yw]*G[{1}, yu^(-1)]*
      G[{1}, yw]*G[{yu^(-1)}, yw]*G[{yu}, yv^(-1)] - 
     G[{1}, yu^(-1)]^2*G[{1}, yw]*G[{yu^(-1)}, yw]*G[{yu}, yv^(-1)] - 
     4*G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*G[{1}, yw]*G[{yu^(-1)}, yw]*
      G[{yu}, yv^(-1)] - (3*G[{1}, yv^(-1)]^2*G[{1}, yw]*G[{yu^(-1)}, yw]*
       G[{yu}, yv^(-1)])/2 - (G[{1}, yu^(-1)]*G[{1}, yw]^2*G[{yu^(-1)}, yw]*
       G[{yu}, yv^(-1)])/2 - G[{1}, yv^(-1)]*G[{1}, yw]^2*G[{yu^(-1)}, yw]*
      G[{yu}, yv^(-1)] + (Pi^2*G[{yu^(-1)}, yw]^2*G[{yu}, yv^(-1)])/4 - 
     (G[{0}, yu^(-1)]^2*G[{yu^(-1)}, yw]^2*G[{yu}, yv^(-1)])/2 - 
     G[{0}, yu^(-1)]*G[{0}, yv^(-1)]*G[{yu^(-1)}, yw]^2*G[{yu}, yv^(-1)] - 
     (G[{0}, yv^(-1)]^2*G[{yu^(-1)}, yw]^2*G[{yu}, yv^(-1)])/2 + 
     G[{0}, yu^(-1)]*G[{0}, yw]*G[{yu^(-1)}, yw]^2*G[{yu}, yv^(-1)] + 
     G[{0}, yv^(-1)]*G[{0}, yw]*G[{yu^(-1)}, yw]^2*G[{yu}, yv^(-1)] - 
     (G[{0}, yw]^2*G[{yu^(-1)}, yw]^2*G[{yu}, yv^(-1)])/2 - 
     (G[{0}, yu^(-1)]*G[{1}, yu^(-1)]*G[{yu^(-1)}, yw]^2*G[{yu}, yv^(-1)])/
      2 - (G[{0}, yv^(-1)]*G[{1}, yu^(-1)]*G[{yu^(-1)}, yw]^2*
       G[{yu}, yv^(-1)])/2 + (G[{0}, yw]*G[{1}, yu^(-1)]*G[{yu^(-1)}, yw]^2*
       G[{yu}, yv^(-1)])/2 + (G[{1}, yu^(-1)]^2*G[{yu^(-1)}, yw]^2*
       G[{yu}, yv^(-1)])/2 + (G[{0}, yu^(-1)]*G[{1}, yv^(-1)]*
       G[{yu^(-1)}, yw]^2*G[{yu}, yv^(-1)])/2 + 
     (G[{0}, yv^(-1)]*G[{1}, yv^(-1)]*G[{yu^(-1)}, yw]^2*G[{yu}, yv^(-1)])/
      2 - (G[{0}, yw]*G[{1}, yv^(-1)]*G[{yu^(-1)}, yw]^2*G[{yu}, yv^(-1)])/
      2 + 4*G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*G[{yu^(-1)}, yw]^2*
      G[{yu}, yv^(-1)] - (G[{1}, yv^(-1)]^2*G[{yu^(-1)}, yw]^2*
       G[{yu}, yv^(-1)])/4 - (G[{0}, yu^(-1)]*G[{1}, yw]*G[{yu^(-1)}, yw]^2*
       G[{yu}, yv^(-1)])/2 - (G[{0}, yv^(-1)]*G[{1}, yw]*G[{yu^(-1)}, yw]^2*
       G[{yu}, yv^(-1)])/2 + (G[{0}, yw]*G[{1}, yw]*G[{yu^(-1)}, yw]^2*
       G[{yu}, yv^(-1)])/2 + 2*G[{1}, yu^(-1)]*G[{1}, yw]*G[{yu^(-1)}, yw]^2*
      G[{yu}, yv^(-1)] + 2*G[{1}, yv^(-1)]*G[{1}, yw]*G[{yu^(-1)}, yw]^2*
      G[{yu}, yv^(-1)] + (G[{0}, yu^(-1)]*G[{yu^(-1)}, yw]^3*
       G[{yu}, yv^(-1)])/3 + (G[{0}, yv^(-1)]*G[{yu^(-1)}, yw]^3*
       G[{yu}, yv^(-1)])/3 - (G[{0}, yw]*G[{yu^(-1)}, yw]^3*G[{yu}, yv^(-1)])/
      3 - (4*G[{1}, yu^(-1)]*G[{yu^(-1)}, yw]^3*G[{yu}, yv^(-1)])/3 - 
     (5*G[{1}, yv^(-1)]*G[{yu^(-1)}, yw]^3*G[{yu}, yv^(-1)])/6 + 
     (G[{1}, yw]*G[{yu^(-1)}, yw]^3*G[{yu}, yv^(-1)])/2 + 
     (5*G[{yu^(-1)}, yw]^4*G[{yu}, yv^(-1)])/24 - 
     (Pi^2*G[{1}, yu^(-1)]*G[{yu}, yv^(-1)]^2)/4 - 
     (Pi^2*G[{1}, yv^(-1)]*G[{yu}, yv^(-1)]^2)/4 + 
     (3*G[{1}, yu^(-1)]^2*G[{1}, yv^(-1)]*G[{yu}, yv^(-1)]^2)/4 - 
     G[{1}, yu^(-1)]*G[{1}, yv^(-1)]^2*G[{yu}, yv^(-1)]^2 + 
     (G[{0}, yu^(-1)]^2*G[{1}, yw]*G[{yu}, yv^(-1)]^2)/2 + 
     G[{0}, yu^(-1)]*G[{0}, yv^(-1)]*G[{1}, yw]*G[{yu}, yv^(-1)]^2 + 
     (G[{0}, yv^(-1)]^2*G[{1}, yw]*G[{yu}, yv^(-1)]^2)/2 - 
     G[{0}, yu^(-1)]*G[{0}, yw]*G[{1}, yw]*G[{yu}, yv^(-1)]^2 - 
     G[{0}, yv^(-1)]*G[{0}, yw]*G[{1}, yw]*G[{yu}, yv^(-1)]^2 + 
     (G[{0}, yw]^2*G[{1}, yw]*G[{yu}, yv^(-1)]^2)/2 + 
     (G[{0}, yu^(-1)]*G[{1}, yu^(-1)]*G[{1}, yw]*G[{yu}, yv^(-1)]^2)/2 + 
     (G[{0}, yv^(-1)]*G[{1}, yu^(-1)]*G[{1}, yw]*G[{yu}, yv^(-1)]^2)/2 - 
     (G[{0}, yw]*G[{1}, yu^(-1)]*G[{1}, yw]*G[{yu}, yv^(-1)]^2)/2 - 
     G[{1}, yu^(-1)]^2*G[{1}, yw]*G[{yu}, yv^(-1)]^2 + 
     (G[{0}, yu^(-1)]*G[{1}, yv^(-1)]*G[{1}, yw]*G[{yu}, yv^(-1)]^2)/2 + 
     (G[{0}, yv^(-1)]*G[{1}, yv^(-1)]*G[{1}, yw]*G[{yu}, yv^(-1)]^2)/2 - 
     (G[{0}, yw]*G[{1}, yv^(-1)]*G[{1}, yw]*G[{yu}, yv^(-1)]^2)/2 - 
     2*G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*G[{1}, yw]*G[{yu}, yv^(-1)]^2 - 
     G[{1}, yv^(-1)]^2*G[{1}, yw]*G[{yu}, yv^(-1)]^2 + 
     (Pi^2*G[{yu^(-1)}, yw]*G[{yu}, yv^(-1)]^2)/4 - 
     (G[{0}, yu^(-1)]^2*G[{yu^(-1)}, yw]*G[{yu}, yv^(-1)]^2)/2 - 
     G[{0}, yu^(-1)]*G[{0}, yv^(-1)]*G[{yu^(-1)}, yw]*G[{yu}, yv^(-1)]^2 - 
     (G[{0}, yv^(-1)]^2*G[{yu^(-1)}, yw]*G[{yu}, yv^(-1)]^2)/2 + 
     G[{0}, yu^(-1)]*G[{0}, yw]*G[{yu^(-1)}, yw]*G[{yu}, yv^(-1)]^2 + 
     G[{0}, yv^(-1)]*G[{0}, yw]*G[{yu^(-1)}, yw]*G[{yu}, yv^(-1)]^2 - 
     (G[{0}, yw]^2*G[{yu^(-1)}, yw]*G[{yu}, yv^(-1)]^2)/2 - 
     (G[{0}, yu^(-1)]*G[{1}, yu^(-1)]*G[{yu^(-1)}, yw]*G[{yu}, yv^(-1)]^2)/
      2 - (G[{0}, yv^(-1)]*G[{1}, yu^(-1)]*G[{yu^(-1)}, yw]*
       G[{yu}, yv^(-1)]^2)/2 + (G[{0}, yw]*G[{1}, yu^(-1)]*G[{yu^(-1)}, yw]*
       G[{yu}, yv^(-1)]^2)/2 + (G[{1}, yu^(-1)]^2*G[{yu^(-1)}, yw]*
       G[{yu}, yv^(-1)]^2)/2 - (G[{0}, yu^(-1)]*G[{1}, yv^(-1)]*
       G[{yu^(-1)}, yw]*G[{yu}, yv^(-1)]^2)/2 - 
     (G[{0}, yv^(-1)]*G[{1}, yv^(-1)]*G[{yu^(-1)}, yw]*G[{yu}, yv^(-1)]^2)/
      2 + (G[{0}, yw]*G[{1}, yv^(-1)]*G[{yu^(-1)}, yw]*G[{yu}, yv^(-1)]^2)/
      2 + 4*G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*G[{yu^(-1)}, yw]*
      G[{yu}, yv^(-1)]^2 + (3*G[{1}, yv^(-1)]^2*G[{yu^(-1)}, yw]*
       G[{yu}, yv^(-1)]^2)/4 - (3*G[{0}, yu^(-1)]*G[{1}, yw]*G[{yu^(-1)}, yw]*
       G[{yu}, yv^(-1)]^2)/2 - (3*G[{0}, yv^(-1)]*G[{1}, yw]*G[{yu^(-1)}, yw]*
       G[{yu}, yv^(-1)]^2)/2 + (3*G[{0}, yw]*G[{1}, yw]*G[{yu^(-1)}, yw]*
       G[{yu}, yv^(-1)]^2)/2 + 2*G[{1}, yu^(-1)]*G[{1}, yw]*G[{yu^(-1)}, yw]*
      G[{yu}, yv^(-1)]^2 + 3*G[{1}, yv^(-1)]*G[{1}, yw]*G[{yu^(-1)}, yw]*
      G[{yu}, yv^(-1)]^2 + (3*G[{1}, yw]^2*G[{yu^(-1)}, yw]*
       G[{yu}, yv^(-1)]^2)/4 + G[{0}, yu^(-1)]*G[{yu^(-1)}, yw]^2*
      G[{yu}, yv^(-1)]^2 + G[{0}, yv^(-1)]*G[{yu^(-1)}, yw]^2*
      G[{yu}, yv^(-1)]^2 - G[{0}, yw]*G[{yu^(-1)}, yw]^2*G[{yu}, yv^(-1)]^2 - 
     2*G[{1}, yu^(-1)]*G[{yu^(-1)}, yw]^2*G[{yu}, yv^(-1)]^2 - 
     (9*G[{1}, yv^(-1)]*G[{yu^(-1)}, yw]^2*G[{yu}, yv^(-1)]^2)/4 - 
     (3*G[{1}, yw]*G[{yu^(-1)}, yw]^2*G[{yu}, yv^(-1)]^2)/2 + 
     (3*G[{yu^(-1)}, yw]^3*G[{yu}, yv^(-1)]^2)/4 + (Pi^2*G[{yu}, yv^(-1)]^3)/
      6 - (G[{1}, yu^(-1)]^2*G[{yu}, yv^(-1)]^3)/4 + 
     (4*G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*G[{yu}, yv^(-1)]^3)/3 - 
     (G[{1}, yv^(-1)]^2*G[{yu}, yv^(-1)]^3)/4 - G[{0}, yu^(-1)]*G[{1}, yw]*
      G[{yu}, yv^(-1)]^3 - G[{0}, yv^(-1)]*G[{1}, yw]*G[{yu}, yv^(-1)]^3 + 
     G[{0}, yw]*G[{1}, yw]*G[{yu}, yv^(-1)]^3 + G[{1}, yu^(-1)]*G[{1}, yw]*
      G[{yu}, yv^(-1)]^3 + G[{1}, yv^(-1)]*G[{1}, yw]*G[{yu}, yv^(-1)]^3 + 
     G[{0}, yu^(-1)]*G[{yu^(-1)}, yw]*G[{yu}, yv^(-1)]^3 + 
     G[{0}, yv^(-1)]*G[{yu^(-1)}, yw]*G[{yu}, yv^(-1)]^3 - 
     G[{0}, yw]*G[{yu^(-1)}, yw]*G[{yu}, yv^(-1)]^3 - 
     (4*G[{1}, yu^(-1)]*G[{yu^(-1)}, yw]*G[{yu}, yv^(-1)]^3)/3 - 
     (3*G[{1}, yv^(-1)]*G[{yu^(-1)}, yw]*G[{yu}, yv^(-1)]^3)/2 - 
     (2*G[{1}, yw]*G[{yu^(-1)}, yw]*G[{yu}, yv^(-1)]^3)/3 + 
     (3*G[{yu^(-1)}, yw]^2*G[{yu}, yv^(-1)]^3)/4 - 
     (5*G[{1}, yu^(-1)]*G[{yu}, yv^(-1)]^4)/24 - 
     (5*G[{1}, yv^(-1)]*G[{yu}, yv^(-1)]^4)/24 + 
     (5*G[{yu^(-1)}, yw]*G[{yu}, yv^(-1)]^4)/24 + G[{yu}, yv^(-1)]^5/12 + 
     (7*Pi^4*G[{yv^(-1)}, yw])/360 - (Pi^2*G[{0}, yu^(-1)]*G[{1}, yu^(-1)]*
       G[{yv^(-1)}, yw])/3 - (Pi^2*G[{0}, yv^(-1)]*G[{1}, yu^(-1)]*
       G[{yv^(-1)}, yw])/3 + (Pi^2*G[{0}, yw]*G[{1}, yu^(-1)]*
       G[{yv^(-1)}, yw])/3 + (5*Pi^2*G[{1}, yu^(-1)]^2*G[{yv^(-1)}, yw])/12 - 
     (Pi^2*G[{0}, yu^(-1)]*G[{1}, yv^(-1)]*G[{yv^(-1)}, yw])/3 - 
     (Pi^2*G[{0}, yv^(-1)]*G[{1}, yv^(-1)]*G[{yv^(-1)}, yw])/3 + 
     (Pi^2*G[{0}, yw]*G[{1}, yv^(-1)]*G[{yv^(-1)}, yw])/3 + 
     (Pi^2*G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*G[{yv^(-1)}, yw])/3 - 
     (G[{0}, yu^(-1)]^2*G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*G[{yv^(-1)}, yw])/2 - 
     G[{0}, yu^(-1)]*G[{0}, yv^(-1)]*G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*
      G[{yv^(-1)}, yw] - (G[{0}, yv^(-1)]^2*G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*
       G[{yv^(-1)}, yw])/2 + G[{0}, yu^(-1)]*G[{0}, yw]*G[{1}, yu^(-1)]*
      G[{1}, yv^(-1)]*G[{yv^(-1)}, yw] + G[{0}, yv^(-1)]*G[{0}, yw]*
      G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*G[{yv^(-1)}, yw] - 
     (G[{0}, yw]^2*G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*G[{yv^(-1)}, yw])/2 + 
     (3*G[{0}, yu^(-1)]*G[{1}, yu^(-1)]^2*G[{1}, yv^(-1)]*G[{yv^(-1)}, yw])/
      2 + (3*G[{0}, yv^(-1)]*G[{1}, yu^(-1)]^2*G[{1}, yv^(-1)]*
       G[{yv^(-1)}, yw])/2 - (3*G[{0}, yw]*G[{1}, yu^(-1)]^2*G[{1}, yv^(-1)]*
       G[{yv^(-1)}, yw])/2 - G[{1}, yu^(-1)]^3*G[{1}, yv^(-1)]*
      G[{yv^(-1)}, yw] + (Pi^2*G[{1}, yv^(-1)]^2*G[{yv^(-1)}, yw])/6 - 
     G[{1}, yu^(-1)]^2*G[{1}, yv^(-1)]^2*G[{yv^(-1)}, yw] + 
     (G[{1}, yu^(-1)]*G[{1}, yv^(-1)]^3*G[{yv^(-1)}, yw])/2 - 
     (Pi^2*G[{0}, yu^(-1)]*G[{1}, yw]*G[{yv^(-1)}, yw])/6 - 
     (Pi^2*G[{0}, yv^(-1)]*G[{1}, yw]*G[{yv^(-1)}, yw])/6 + 
     (Pi^2*G[{0}, yw]*G[{1}, yw]*G[{yv^(-1)}, yw])/6 + 
     (2*Pi^2*G[{1}, yu^(-1)]*G[{1}, yw]*G[{yv^(-1)}, yw])/3 - 
     (G[{0}, yu^(-1)]^2*G[{1}, yu^(-1)]*G[{1}, yw]*G[{yv^(-1)}, yw])/2 - 
     G[{0}, yu^(-1)]*G[{0}, yv^(-1)]*G[{1}, yu^(-1)]*G[{1}, yw]*
      G[{yv^(-1)}, yw] - (G[{0}, yv^(-1)]^2*G[{1}, yu^(-1)]*G[{1}, yw]*
       G[{yv^(-1)}, yw])/2 + G[{0}, yu^(-1)]*G[{0}, yw]*G[{1}, yu^(-1)]*
      G[{1}, yw]*G[{yv^(-1)}, yw] + G[{0}, yv^(-1)]*G[{0}, yw]*
      G[{1}, yu^(-1)]*G[{1}, yw]*G[{yv^(-1)}, yw] - 
     (G[{0}, yw]^2*G[{1}, yu^(-1)]*G[{1}, yw]*G[{yv^(-1)}, yw])/2 + 
     (3*G[{0}, yu^(-1)]*G[{1}, yu^(-1)]^2*G[{1}, yw]*G[{yv^(-1)}, yw])/2 + 
     (3*G[{0}, yv^(-1)]*G[{1}, yu^(-1)]^2*G[{1}, yw]*G[{yv^(-1)}, yw])/2 - 
     (3*G[{0}, yw]*G[{1}, yu^(-1)]^2*G[{1}, yw]*G[{yv^(-1)}, yw])/2 - 
     G[{1}, yu^(-1)]^3*G[{1}, yw]*G[{yv^(-1)}, yw] + 
     (Pi^2*G[{1}, yv^(-1)]*G[{1}, yw]*G[{yv^(-1)}, yw])/6 - 
     G[{0}, yu^(-1)]*G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*G[{1}, yw]*
      G[{yv^(-1)}, yw] - G[{0}, yv^(-1)]*G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*
      G[{1}, yw]*G[{yv^(-1)}, yw] + G[{0}, yw]*G[{1}, yu^(-1)]*
      G[{1}, yv^(-1)]*G[{1}, yw]*G[{yv^(-1)}, yw] + 
     (3*G[{1}, yu^(-1)]^2*G[{1}, yv^(-1)]*G[{1}, yw]*G[{yv^(-1)}, yw])/2 + 
     (G[{1}, yu^(-1)]*G[{1}, yv^(-1)]^2*G[{1}, yw]*G[{yv^(-1)}, yw])/2 + 
     (Pi^2*G[{1}, yw]^2*G[{yv^(-1)}, yw])/12 - G[{0}, yu^(-1)]^2*G[{1}, yw]^2*
      G[{yv^(-1)}, yw] - 2*G[{0}, yu^(-1)]*G[{0}, yv^(-1)]*G[{1}, yw]^2*
      G[{yv^(-1)}, yw] - G[{0}, yv^(-1)]^2*G[{1}, yw]^2*G[{yv^(-1)}, yw] + 
     2*G[{0}, yu^(-1)]*G[{0}, yw]*G[{1}, yw]^2*G[{yv^(-1)}, yw] + 
     2*G[{0}, yv^(-1)]*G[{0}, yw]*G[{1}, yw]^2*G[{yv^(-1)}, yw] - 
     G[{0}, yw]^2*G[{1}, yw]^2*G[{yv^(-1)}, yw] + 
     2*G[{0}, yu^(-1)]*G[{1}, yu^(-1)]*G[{1}, yw]^2*G[{yv^(-1)}, yw] + 
     2*G[{0}, yv^(-1)]*G[{1}, yu^(-1)]*G[{1}, yw]^2*G[{yv^(-1)}, yw] - 
     2*G[{0}, yw]*G[{1}, yu^(-1)]*G[{1}, yw]^2*G[{yv^(-1)}, yw] - 
     G[{1}, yu^(-1)]^2*G[{1}, yw]^2*G[{yv^(-1)}, yw] + 
     2*G[{0}, yu^(-1)]*G[{1}, yv^(-1)]*G[{1}, yw]^2*G[{yv^(-1)}, yw] + 
     2*G[{0}, yv^(-1)]*G[{1}, yv^(-1)]*G[{1}, yw]^2*G[{yv^(-1)}, yw] - 
     2*G[{0}, yw]*G[{1}, yv^(-1)]*G[{1}, yw]^2*G[{yv^(-1)}, yw] - 
     G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*G[{1}, yw]^2*G[{yv^(-1)}, yw] - 
     G[{1}, yv^(-1)]^2*G[{1}, yw]^2*G[{yv^(-1)}, yw] - 
     (G[{0}, yu^(-1)]*G[{1}, yw]^3*G[{yv^(-1)}, yw])/2 - 
     (G[{0}, yv^(-1)]*G[{1}, yw]^3*G[{yv^(-1)}, yw])/2 + 
     (G[{0}, yw]*G[{1}, yw]^3*G[{yv^(-1)}, yw])/2 + 
     (G[{1}, yu^(-1)]*G[{1}, yw]^3*G[{yv^(-1)}, yw])/2 + 
     (G[{1}, yv^(-1)]*G[{1}, yw]^3*G[{yv^(-1)}, yw])/2 + 
     (Pi^2*G[{0}, yu^(-1)]*G[{yu^(-1)}, yw]*G[{yv^(-1)}, yw])/6 + 
     (Pi^2*G[{0}, yv^(-1)]*G[{yu^(-1)}, yw]*G[{yv^(-1)}, yw])/6 - 
     (Pi^2*G[{0}, yw]*G[{yu^(-1)}, yw]*G[{yv^(-1)}, yw])/6 - 
     (Pi^2*G[{1}, yu^(-1)]*G[{yu^(-1)}, yw]*G[{yv^(-1)}, yw])/2 + 
     (G[{0}, yu^(-1)]^2*G[{1}, yu^(-1)]*G[{yu^(-1)}, yw]*G[{yv^(-1)}, yw])/
      2 + G[{0}, yu^(-1)]*G[{0}, yv^(-1)]*G[{1}, yu^(-1)]*G[{yu^(-1)}, yw]*
      G[{yv^(-1)}, yw] + (G[{0}, yv^(-1)]^2*G[{1}, yu^(-1)]*G[{yu^(-1)}, yw]*
       G[{yv^(-1)}, yw])/2 - G[{0}, yu^(-1)]*G[{0}, yw]*G[{1}, yu^(-1)]*
      G[{yu^(-1)}, yw]*G[{yv^(-1)}, yw] - G[{0}, yv^(-1)]*G[{0}, yw]*
      G[{1}, yu^(-1)]*G[{yu^(-1)}, yw]*G[{yv^(-1)}, yw] + 
     (G[{0}, yw]^2*G[{1}, yu^(-1)]*G[{yu^(-1)}, yw]*G[{yv^(-1)}, yw])/2 - 
     (3*G[{0}, yu^(-1)]*G[{1}, yu^(-1)]^2*G[{yu^(-1)}, yw]*G[{yv^(-1)}, yw])/
      2 - (3*G[{0}, yv^(-1)]*G[{1}, yu^(-1)]^2*G[{yu^(-1)}, yw]*
       G[{yv^(-1)}, yw])/2 + (3*G[{0}, yw]*G[{1}, yu^(-1)]^2*G[{yu^(-1)}, yw]*
       G[{yv^(-1)}, yw])/2 + G[{1}, yu^(-1)]^3*G[{yu^(-1)}, yw]*
      G[{yv^(-1)}, yw] - (Pi^2*G[{1}, yv^(-1)]*G[{yu^(-1)}, yw]*
       G[{yv^(-1)}, yw])/2 + (G[{0}, yu^(-1)]^2*G[{1}, yv^(-1)]*
       G[{yu^(-1)}, yw]*G[{yv^(-1)}, yw])/2 + G[{0}, yu^(-1)]*G[{0}, yv^(-1)]*
      G[{1}, yv^(-1)]*G[{yu^(-1)}, yw]*G[{yv^(-1)}, yw] + 
     (G[{0}, yv^(-1)]^2*G[{1}, yv^(-1)]*G[{yu^(-1)}, yw]*G[{yv^(-1)}, yw])/
      2 - G[{0}, yu^(-1)]*G[{0}, yw]*G[{1}, yv^(-1)]*G[{yu^(-1)}, yw]*
      G[{yv^(-1)}, yw] - G[{0}, yv^(-1)]*G[{0}, yw]*G[{1}, yv^(-1)]*
      G[{yu^(-1)}, yw]*G[{yv^(-1)}, yw] + 
     (G[{0}, yw]^2*G[{1}, yv^(-1)]*G[{yu^(-1)}, yw]*G[{yv^(-1)}, yw])/2 + 
     G[{0}, yu^(-1)]*G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*G[{yu^(-1)}, yw]*
      G[{yv^(-1)}, yw] + G[{0}, yv^(-1)]*G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*
      G[{yu^(-1)}, yw]*G[{yv^(-1)}, yw] - G[{0}, yw]*G[{1}, yu^(-1)]*
      G[{1}, yv^(-1)]*G[{yu^(-1)}, yw]*G[{yv^(-1)}, yw] - 
     (3*G[{0}, yu^(-1)]*G[{1}, yv^(-1)]^2*G[{yu^(-1)}, yw]*G[{yv^(-1)}, yw])/
      2 - (3*G[{0}, yv^(-1)]*G[{1}, yv^(-1)]^2*G[{yu^(-1)}, yw]*
       G[{yv^(-1)}, yw])/2 + (3*G[{0}, yw]*G[{1}, yv^(-1)]^2*G[{yu^(-1)}, yw]*
       G[{yv^(-1)}, yw])/2 - (5*G[{1}, yu^(-1)]*G[{1}, yv^(-1)]^2*
       G[{yu^(-1)}, yw]*G[{yv^(-1)}, yw])/2 + G[{1}, yv^(-1)]^3*
      G[{yu^(-1)}, yw]*G[{yv^(-1)}, yw] - 
     (2*Pi^2*G[{1}, yw]*G[{yu^(-1)}, yw]*G[{yv^(-1)}, yw])/3 + 
     G[{0}, yu^(-1)]^2*G[{1}, yw]*G[{yu^(-1)}, yw]*G[{yv^(-1)}, yw] + 
     2*G[{0}, yu^(-1)]*G[{0}, yv^(-1)]*G[{1}, yw]*G[{yu^(-1)}, yw]*
      G[{yv^(-1)}, yw] + G[{0}, yv^(-1)]^2*G[{1}, yw]*G[{yu^(-1)}, yw]*
      G[{yv^(-1)}, yw] - 2*G[{0}, yu^(-1)]*G[{0}, yw]*G[{1}, yw]*
      G[{yu^(-1)}, yw]*G[{yv^(-1)}, yw] - 2*G[{0}, yv^(-1)]*G[{0}, yw]*
      G[{1}, yw]*G[{yu^(-1)}, yw]*G[{yv^(-1)}, yw] + 
     G[{0}, yw]^2*G[{1}, yw]*G[{yu^(-1)}, yw]*G[{yv^(-1)}, yw] + 
     G[{0}, yu^(-1)]*G[{1}, yu^(-1)]*G[{1}, yw]*G[{yu^(-1)}, yw]*
      G[{yv^(-1)}, yw] + G[{0}, yv^(-1)]*G[{1}, yu^(-1)]*G[{1}, yw]*
      G[{yu^(-1)}, yw]*G[{yv^(-1)}, yw] - G[{0}, yw]*G[{1}, yu^(-1)]*
      G[{1}, yw]*G[{yu^(-1)}, yw]*G[{yv^(-1)}, yw] - 
     (3*G[{1}, yu^(-1)]^2*G[{1}, yw]*G[{yu^(-1)}, yw]*G[{yv^(-1)}, yw])/2 + 
     G[{0}, yu^(-1)]*G[{1}, yv^(-1)]*G[{1}, yw]*G[{yu^(-1)}, yw]*
      G[{yv^(-1)}, yw] + G[{0}, yv^(-1)]*G[{1}, yv^(-1)]*G[{1}, yw]*
      G[{yu^(-1)}, yw]*G[{yv^(-1)}, yw] - G[{0}, yw]*G[{1}, yv^(-1)]*
      G[{1}, yw]*G[{yu^(-1)}, yw]*G[{yv^(-1)}, yw] - 
     6*G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*G[{1}, yw]*G[{yu^(-1)}, yw]*
      G[{yv^(-1)}, yw] - (3*G[{1}, yv^(-1)]^2*G[{1}, yw]*G[{yu^(-1)}, yw]*
       G[{yv^(-1)}, yw])/2 + 5*G[{0}, yu^(-1)]*G[{1}, yw]^2*G[{yu^(-1)}, yw]*
      G[{yv^(-1)}, yw] + 5*G[{0}, yv^(-1)]*G[{1}, yw]^2*G[{yu^(-1)}, yw]*
      G[{yv^(-1)}, yw] - 5*G[{0}, yw]*G[{1}, yw]^2*G[{yu^(-1)}, yw]*
      G[{yv^(-1)}, yw] - (7*G[{1}, yu^(-1)]*G[{1}, yw]^2*G[{yu^(-1)}, yw]*
       G[{yv^(-1)}, yw])/2 - (7*G[{1}, yv^(-1)]*G[{1}, yw]^2*G[{yu^(-1)}, yw]*
       G[{yv^(-1)}, yw])/2 + G[{1}, yw]^3*G[{yu^(-1)}, yw]*G[{yv^(-1)}, yw] + 
     (Pi^2*G[{yu^(-1)}, yw]^2*G[{yv^(-1)}, yw])/4 - 
     (G[{0}, yu^(-1)]^2*G[{yu^(-1)}, yw]^2*G[{yv^(-1)}, yw])/4 - 
     (G[{0}, yu^(-1)]*G[{0}, yv^(-1)]*G[{yu^(-1)}, yw]^2*G[{yv^(-1)}, yw])/
      2 - (G[{0}, yv^(-1)]^2*G[{yu^(-1)}, yw]^2*G[{yv^(-1)}, yw])/4 + 
     (G[{0}, yu^(-1)]*G[{0}, yw]*G[{yu^(-1)}, yw]^2*G[{yv^(-1)}, yw])/2 + 
     (G[{0}, yv^(-1)]*G[{0}, yw]*G[{yu^(-1)}, yw]^2*G[{yv^(-1)}, yw])/2 - 
     (G[{0}, yw]^2*G[{yu^(-1)}, yw]^2*G[{yv^(-1)}, yw])/4 - 
     G[{0}, yu^(-1)]*G[{1}, yu^(-1)]*G[{yu^(-1)}, yw]^2*G[{yv^(-1)}, yw] - 
     G[{0}, yv^(-1)]*G[{1}, yu^(-1)]*G[{yu^(-1)}, yw]^2*G[{yv^(-1)}, yw] + 
     G[{0}, yw]*G[{1}, yu^(-1)]*G[{yu^(-1)}, yw]^2*G[{yv^(-1)}, yw] + 
     (3*G[{1}, yu^(-1)]^2*G[{yu^(-1)}, yw]^2*G[{yv^(-1)}, yw])/4 + 
     (9*G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*G[{yu^(-1)}, yw]^2*G[{yv^(-1)}, yw])/
      2 - (G[{1}, yv^(-1)]^2*G[{yu^(-1)}, yw]^2*G[{yv^(-1)}, yw])/4 - 
     (7*G[{0}, yu^(-1)]*G[{1}, yw]*G[{yu^(-1)}, yw]^2*G[{yv^(-1)}, yw])/2 - 
     (7*G[{0}, yv^(-1)]*G[{1}, yw]*G[{yu^(-1)}, yw]^2*G[{yv^(-1)}, yw])/2 + 
     (7*G[{0}, yw]*G[{1}, yw]*G[{yu^(-1)}, yw]^2*G[{yv^(-1)}, yw])/2 + 
     4*G[{1}, yu^(-1)]*G[{1}, yw]*G[{yu^(-1)}, yw]^2*G[{yv^(-1)}, yw] + 
     4*G[{1}, yv^(-1)]*G[{1}, yw]*G[{yu^(-1)}, yw]^2*G[{yv^(-1)}, yw] + 
     (G[{1}, yw]^2*G[{yu^(-1)}, yw]^2*G[{yv^(-1)}, yw])/2 + 
     (G[{0}, yu^(-1)]*G[{yu^(-1)}, yw]^3*G[{yv^(-1)}, yw])/2 + 
     (G[{0}, yv^(-1)]*G[{yu^(-1)}, yw]^3*G[{yv^(-1)}, yw])/2 - 
     (G[{0}, yw]*G[{yu^(-1)}, yw]^3*G[{yv^(-1)}, yw])/2 - 
     (3*G[{1}, yu^(-1)]*G[{yu^(-1)}, yw]^3*G[{yv^(-1)}, yw])/2 - 
     (5*G[{1}, yv^(-1)]*G[{yu^(-1)}, yw]^3*G[{yv^(-1)}, yw])/6 - 
     (4*G[{1}, yw]*G[{yu^(-1)}, yw]^3*G[{yv^(-1)}, yw])/3 + 
     (5*G[{yu^(-1)}, yw]^4*G[{yv^(-1)}, yw])/24 + 
     (Pi^2*G[{0}, yu^(-1)]*G[{yu}, yv^(-1)]*G[{yv^(-1)}, yw])/3 + 
     (Pi^2*G[{0}, yv^(-1)]*G[{yu}, yv^(-1)]*G[{yv^(-1)}, yw])/3 - 
     (Pi^2*G[{0}, yw]*G[{yu}, yv^(-1)]*G[{yv^(-1)}, yw])/3 - 
     (Pi^2*G[{1}, yu^(-1)]*G[{yu}, yv^(-1)]*G[{yv^(-1)}, yw])/2 + 
     (G[{0}, yu^(-1)]^2*G[{1}, yu^(-1)]*G[{yu}, yv^(-1)]*G[{yv^(-1)}, yw])/
      2 + G[{0}, yu^(-1)]*G[{0}, yv^(-1)]*G[{1}, yu^(-1)]*G[{yu}, yv^(-1)]*
      G[{yv^(-1)}, yw] + (G[{0}, yv^(-1)]^2*G[{1}, yu^(-1)]*G[{yu}, yv^(-1)]*
       G[{yv^(-1)}, yw])/2 - G[{0}, yu^(-1)]*G[{0}, yw]*G[{1}, yu^(-1)]*
      G[{yu}, yv^(-1)]*G[{yv^(-1)}, yw] - G[{0}, yv^(-1)]*G[{0}, yw]*
      G[{1}, yu^(-1)]*G[{yu}, yv^(-1)]*G[{yv^(-1)}, yw] + 
     (G[{0}, yw]^2*G[{1}, yu^(-1)]*G[{yu}, yv^(-1)]*G[{yv^(-1)}, yw])/2 - 
     (3*G[{0}, yu^(-1)]*G[{1}, yu^(-1)]^2*G[{yu}, yv^(-1)]*G[{yv^(-1)}, yw])/
      2 - (3*G[{0}, yv^(-1)]*G[{1}, yu^(-1)]^2*G[{yu}, yv^(-1)]*
       G[{yv^(-1)}, yw])/2 + (3*G[{0}, yw]*G[{1}, yu^(-1)]^2*G[{yu}, yv^(-1)]*
       G[{yv^(-1)}, yw])/2 + G[{1}, yu^(-1)]^3*G[{yu}, yv^(-1)]*
      G[{yv^(-1)}, yw] - (2*Pi^2*G[{1}, yv^(-1)]*G[{yu}, yv^(-1)]*
       G[{yv^(-1)}, yw])/3 + (G[{0}, yu^(-1)]^2*G[{1}, yv^(-1)]*
       G[{yu}, yv^(-1)]*G[{yv^(-1)}, yw])/2 + G[{0}, yu^(-1)]*G[{0}, yv^(-1)]*
      G[{1}, yv^(-1)]*G[{yu}, yv^(-1)]*G[{yv^(-1)}, yw] + 
     (G[{0}, yv^(-1)]^2*G[{1}, yv^(-1)]*G[{yu}, yv^(-1)]*G[{yv^(-1)}, yw])/
      2 - G[{0}, yu^(-1)]*G[{0}, yw]*G[{1}, yv^(-1)]*G[{yu}, yv^(-1)]*
      G[{yv^(-1)}, yw] - G[{0}, yv^(-1)]*G[{0}, yw]*G[{1}, yv^(-1)]*
      G[{yu}, yv^(-1)]*G[{yv^(-1)}, yw] + 
     (G[{0}, yw]^2*G[{1}, yv^(-1)]*G[{yu}, yv^(-1)]*G[{yv^(-1)}, yw])/2 + 
     2*G[{0}, yu^(-1)]*G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*G[{yu}, yv^(-1)]*
      G[{yv^(-1)}, yw] + 2*G[{0}, yv^(-1)]*G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*
      G[{yu}, yv^(-1)]*G[{yv^(-1)}, yw] - 2*G[{0}, yw]*G[{1}, yu^(-1)]*
      G[{1}, yv^(-1)]*G[{yu}, yv^(-1)]*G[{yv^(-1)}, yw] - 
     (3*G[{1}, yu^(-1)]^2*G[{1}, yv^(-1)]*G[{yu}, yv^(-1)]*G[{yv^(-1)}, yw])/
      2 - (3*G[{0}, yu^(-1)]*G[{1}, yv^(-1)]^2*G[{yu}, yv^(-1)]*
       G[{yv^(-1)}, yw])/2 - (3*G[{0}, yv^(-1)]*G[{1}, yv^(-1)]^2*
       G[{yu}, yv^(-1)]*G[{yv^(-1)}, yw])/2 + 
     (3*G[{0}, yw]*G[{1}, yv^(-1)]^2*G[{yu}, yv^(-1)]*G[{yv^(-1)}, yw])/2 - 
     (7*G[{1}, yu^(-1)]*G[{1}, yv^(-1)]^2*G[{yu}, yv^(-1)]*G[{yv^(-1)}, yw])/
      2 + G[{1}, yv^(-1)]^3*G[{yu}, yv^(-1)]*G[{yv^(-1)}, yw] - 
     (Pi^2*G[{1}, yw]*G[{yu}, yv^(-1)]*G[{yv^(-1)}, yw])/2 + 
     (G[{0}, yu^(-1)]^2*G[{1}, yw]*G[{yu}, yv^(-1)]*G[{yv^(-1)}, yw])/2 + 
     G[{0}, yu^(-1)]*G[{0}, yv^(-1)]*G[{1}, yw]*G[{yu}, yv^(-1)]*
      G[{yv^(-1)}, yw] + (G[{0}, yv^(-1)]^2*G[{1}, yw]*G[{yu}, yv^(-1)]*
       G[{yv^(-1)}, yw])/2 - G[{0}, yu^(-1)]*G[{0}, yw]*G[{1}, yw]*
      G[{yu}, yv^(-1)]*G[{yv^(-1)}, yw] - G[{0}, yv^(-1)]*G[{0}, yw]*
      G[{1}, yw]*G[{yu}, yv^(-1)]*G[{yv^(-1)}, yw] + 
     (G[{0}, yw]^2*G[{1}, yw]*G[{yu}, yv^(-1)]*G[{yv^(-1)}, yw])/2 - 
     (3*G[{1}, yu^(-1)]^2*G[{1}, yw]*G[{yu}, yv^(-1)]*G[{yv^(-1)}, yw])/2 + 
     G[{0}, yu^(-1)]*G[{1}, yv^(-1)]*G[{1}, yw]*G[{yu}, yv^(-1)]*
      G[{yv^(-1)}, yw] + G[{0}, yv^(-1)]*G[{1}, yv^(-1)]*G[{1}, yw]*
      G[{yu}, yv^(-1)]*G[{yv^(-1)}, yw] - G[{0}, yw]*G[{1}, yv^(-1)]*
      G[{1}, yw]*G[{yu}, yv^(-1)]*G[{yv^(-1)}, yw] - 
     3*G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*G[{1}, yw]*G[{yu}, yv^(-1)]*
      G[{yv^(-1)}, yw] - G[{1}, yv^(-1)]^2*G[{1}, yw]*G[{yu}, yv^(-1)]*
      G[{yv^(-1)}, yw] - G[{1}, yu^(-1)]*G[{1}, yw]^2*G[{yu}, yv^(-1)]*
      G[{yv^(-1)}, yw] - (G[{1}, yv^(-1)]*G[{1}, yw]^2*G[{yu}, yv^(-1)]*
       G[{yv^(-1)}, yw])/2 + (2*Pi^2*G[{yu^(-1)}, yw]*G[{yu}, yv^(-1)]*
       G[{yv^(-1)}, yw])/3 - G[{0}, yu^(-1)]^2*G[{yu^(-1)}, yw]*
      G[{yu}, yv^(-1)]*G[{yv^(-1)}, yw] - 2*G[{0}, yu^(-1)]*G[{0}, yv^(-1)]*
      G[{yu^(-1)}, yw]*G[{yu}, yv^(-1)]*G[{yv^(-1)}, yw] - 
     G[{0}, yv^(-1)]^2*G[{yu^(-1)}, yw]*G[{yu}, yv^(-1)]*G[{yv^(-1)}, yw] + 
     2*G[{0}, yu^(-1)]*G[{0}, yw]*G[{yu^(-1)}, yw]*G[{yu}, yv^(-1)]*
      G[{yv^(-1)}, yw] + 2*G[{0}, yv^(-1)]*G[{0}, yw]*G[{yu^(-1)}, yw]*
      G[{yu}, yv^(-1)]*G[{yv^(-1)}, yw] - G[{0}, yw]^2*G[{yu^(-1)}, yw]*
      G[{yu}, yv^(-1)]*G[{yv^(-1)}, yw] + 8*G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*
      G[{yu^(-1)}, yw]*G[{yu}, yv^(-1)]*G[{yv^(-1)}, yw] - 
     6*G[{0}, yu^(-1)]*G[{1}, yw]*G[{yu^(-1)}, yw]*G[{yu}, yv^(-1)]*
      G[{yv^(-1)}, yw] - 6*G[{0}, yv^(-1)]*G[{1}, yw]*G[{yu^(-1)}, yw]*
      G[{yu}, yv^(-1)]*G[{yv^(-1)}, yw] + 6*G[{0}, yw]*G[{1}, yw]*
      G[{yu^(-1)}, yw]*G[{yu}, yv^(-1)]*G[{yv^(-1)}, yw] + 
     7*G[{1}, yu^(-1)]*G[{1}, yw]*G[{yu^(-1)}, yw]*G[{yu}, yv^(-1)]*
      G[{yv^(-1)}, yw] + 7*G[{1}, yv^(-1)]*G[{1}, yw]*G[{yu^(-1)}, yw]*
      G[{yu}, yv^(-1)]*G[{yv^(-1)}, yw] - 3*G[{1}, yw]^2*G[{yu^(-1)}, yw]*
      G[{yu}, yv^(-1)]*G[{yv^(-1)}, yw] + 2*G[{0}, yu^(-1)]*
      G[{yu^(-1)}, yw]^2*G[{yu}, yv^(-1)]*G[{yv^(-1)}, yw] + 
     2*G[{0}, yv^(-1)]*G[{yu^(-1)}, yw]^2*G[{yu}, yv^(-1)]*G[{yv^(-1)}, yw] - 
     2*G[{0}, yw]*G[{yu^(-1)}, yw]^2*G[{yu}, yv^(-1)]*G[{yv^(-1)}, yw] - 
     4*G[{1}, yu^(-1)]*G[{yu^(-1)}, yw]^2*G[{yu}, yv^(-1)]*G[{yv^(-1)}, yw] - 
     4*G[{1}, yv^(-1)]*G[{yu^(-1)}, yw]^2*G[{yu}, yv^(-1)]*G[{yv^(-1)}, yw] - 
     G[{1}, yw]*G[{yu^(-1)}, yw]^2*G[{yu}, yv^(-1)]*G[{yv^(-1)}, yw] + 
     (4*G[{yu^(-1)}, yw]^3*G[{yu}, yv^(-1)]*G[{yv^(-1)}, yw])/3 + 
     (Pi^2*G[{yu}, yv^(-1)]^2*G[{yv^(-1)}, yw])/4 - 
     (G[{0}, yu^(-1)]^2*G[{yu}, yv^(-1)]^2*G[{yv^(-1)}, yw])/2 - 
     G[{0}, yu^(-1)]*G[{0}, yv^(-1)]*G[{yu}, yv^(-1)]^2*G[{yv^(-1)}, yw] - 
     (G[{0}, yv^(-1)]^2*G[{yu}, yv^(-1)]^2*G[{yv^(-1)}, yw])/2 + 
     G[{0}, yu^(-1)]*G[{0}, yw]*G[{yu}, yv^(-1)]^2*G[{yv^(-1)}, yw] + 
     G[{0}, yv^(-1)]*G[{0}, yw]*G[{yu}, yv^(-1)]^2*G[{yv^(-1)}, yw] - 
     (G[{0}, yw]^2*G[{yu}, yv^(-1)]^2*G[{yv^(-1)}, yw])/2 - 
     (G[{0}, yu^(-1)]*G[{1}, yu^(-1)]*G[{yu}, yv^(-1)]^2*G[{yv^(-1)}, yw])/
      2 - (G[{0}, yv^(-1)]*G[{1}, yu^(-1)]*G[{yu}, yv^(-1)]^2*
       G[{yv^(-1)}, yw])/2 + (G[{0}, yw]*G[{1}, yu^(-1)]*G[{yu}, yv^(-1)]^2*
       G[{yv^(-1)}, yw])/2 + (3*G[{1}, yu^(-1)]^2*G[{yu}, yv^(-1)]^2*
       G[{yv^(-1)}, yw])/4 - (G[{0}, yu^(-1)]*G[{1}, yv^(-1)]*
       G[{yu}, yv^(-1)]^2*G[{yv^(-1)}, yw])/2 - 
     (G[{0}, yv^(-1)]*G[{1}, yv^(-1)]*G[{yu}, yv^(-1)]^2*G[{yv^(-1)}, yw])/
      2 + (G[{0}, yw]*G[{1}, yv^(-1)]*G[{yu}, yv^(-1)]^2*G[{yv^(-1)}, yw])/
      2 + 4*G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*G[{yu}, yv^(-1)]^2*
      G[{yv^(-1)}, yw] + (G[{1}, yv^(-1)]^2*G[{yu}, yv^(-1)]^2*
       G[{yv^(-1)}, yw])/2 - (3*G[{0}, yu^(-1)]*G[{1}, yw]*G[{yu}, yv^(-1)]^2*
       G[{yv^(-1)}, yw])/2 - (3*G[{0}, yv^(-1)]*G[{1}, yw]*G[{yu}, yv^(-1)]^2*
       G[{yv^(-1)}, yw])/2 + (3*G[{0}, yw]*G[{1}, yw]*G[{yu}, yv^(-1)]^2*
       G[{yv^(-1)}, yw])/2 + 3*G[{1}, yu^(-1)]*G[{1}, yw]*G[{yu}, yv^(-1)]^2*
      G[{yv^(-1)}, yw] + 2*G[{1}, yv^(-1)]*G[{1}, yw]*G[{yu}, yv^(-1)]^2*
      G[{yv^(-1)}, yw] + (3*G[{1}, yw]^2*G[{yu}, yv^(-1)]^2*G[{yv^(-1)}, yw])/
      4 + 2*G[{0}, yu^(-1)]*G[{yu^(-1)}, yw]*G[{yu}, yv^(-1)]^2*
      G[{yv^(-1)}, yw] + 2*G[{0}, yv^(-1)]*G[{yu^(-1)}, yw]*
      G[{yu}, yv^(-1)]^2*G[{yv^(-1)}, yw] - 2*G[{0}, yw]*G[{yu^(-1)}, yw]*
      G[{yu}, yv^(-1)]^2*G[{yv^(-1)}, yw] - 4*G[{1}, yu^(-1)]*
      G[{yu^(-1)}, yw]*G[{yu}, yv^(-1)]^2*G[{yv^(-1)}, yw] - 
     4*G[{1}, yv^(-1)]*G[{yu^(-1)}, yw]*G[{yu}, yv^(-1)]^2*G[{yv^(-1)}, yw] - 
     G[{1}, yw]*G[{yu^(-1)}, yw]*G[{yu}, yv^(-1)]^2*G[{yv^(-1)}, yw] + 
     2*G[{yu^(-1)}, yw]^2*G[{yu}, yv^(-1)]^2*G[{yv^(-1)}, yw] + 
     G[{0}, yu^(-1)]*G[{yu}, yv^(-1)]^3*G[{yv^(-1)}, yw] + 
     G[{0}, yv^(-1)]*G[{yu}, yv^(-1)]^3*G[{yv^(-1)}, yw] - 
     G[{0}, yw]*G[{yu}, yv^(-1)]^3*G[{yv^(-1)}, yw] - 
     (3*G[{1}, yu^(-1)]*G[{yu}, yv^(-1)]^3*G[{yv^(-1)}, yw])/2 - 
     (4*G[{1}, yv^(-1)]*G[{yu}, yv^(-1)]^3*G[{yv^(-1)}, yw])/3 - 
     (2*G[{1}, yw]*G[{yu}, yv^(-1)]^3*G[{yv^(-1)}, yw])/3 + 
     (4*G[{yu^(-1)}, yw]*G[{yu}, yv^(-1)]^3*G[{yv^(-1)}, yw])/3 + 
     (5*G[{yu}, yv^(-1)]^4*G[{yv^(-1)}, yw])/24 + 
     (Pi^2*G[{0}, yu^(-1)]*G[{yv^(-1)}, yw]^2)/4 + 
     (Pi^2*G[{0}, yv^(-1)]*G[{yv^(-1)}, yw]^2)/4 - 
     (Pi^2*G[{0}, yw]*G[{yv^(-1)}, yw]^2)/4 - 
     (Pi^2*G[{1}, yu^(-1)]*G[{yv^(-1)}, yw]^2)/2 + 
     (G[{0}, yu^(-1)]^2*G[{1}, yu^(-1)]*G[{yv^(-1)}, yw]^2)/2 + 
     G[{0}, yu^(-1)]*G[{0}, yv^(-1)]*G[{1}, yu^(-1)]*G[{yv^(-1)}, yw]^2 + 
     (G[{0}, yv^(-1)]^2*G[{1}, yu^(-1)]*G[{yv^(-1)}, yw]^2)/2 - 
     G[{0}, yu^(-1)]*G[{0}, yw]*G[{1}, yu^(-1)]*G[{yv^(-1)}, yw]^2 - 
     G[{0}, yv^(-1)]*G[{0}, yw]*G[{1}, yu^(-1)]*G[{yv^(-1)}, yw]^2 + 
     (G[{0}, yw]^2*G[{1}, yu^(-1)]*G[{yv^(-1)}, yw]^2)/2 - 
     (3*G[{0}, yu^(-1)]*G[{1}, yu^(-1)]^2*G[{yv^(-1)}, yw]^2)/2 - 
     (3*G[{0}, yv^(-1)]*G[{1}, yu^(-1)]^2*G[{yv^(-1)}, yw]^2)/2 + 
     (3*G[{0}, yw]*G[{1}, yu^(-1)]^2*G[{yv^(-1)}, yw]^2)/2 + 
     G[{1}, yu^(-1)]^3*G[{yv^(-1)}, yw]^2 - 
     (Pi^2*G[{1}, yv^(-1)]*G[{yv^(-1)}, yw]^2)/4 + 
     (G[{0}, yu^(-1)]*G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*G[{yv^(-1)}, yw]^2)/2 + 
     (G[{0}, yv^(-1)]*G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*G[{yv^(-1)}, yw]^2)/2 - 
     (G[{0}, yw]*G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*G[{yv^(-1)}, yw]^2)/2 + 
     (G[{1}, yu^(-1)]^2*G[{1}, yv^(-1)]*G[{yv^(-1)}, yw]^2)/4 - 
     G[{1}, yu^(-1)]*G[{1}, yv^(-1)]^2*G[{yv^(-1)}, yw]^2 - 
     (Pi^2*G[{1}, yw]*G[{yv^(-1)}, yw]^2)/4 + 
     (3*G[{0}, yu^(-1)]^2*G[{1}, yw]*G[{yv^(-1)}, yw]^2)/4 + 
     (3*G[{0}, yu^(-1)]*G[{0}, yv^(-1)]*G[{1}, yw]*G[{yv^(-1)}, yw]^2)/2 + 
     (3*G[{0}, yv^(-1)]^2*G[{1}, yw]*G[{yv^(-1)}, yw]^2)/4 - 
     (3*G[{0}, yu^(-1)]*G[{0}, yw]*G[{1}, yw]*G[{yv^(-1)}, yw]^2)/2 - 
     (3*G[{0}, yv^(-1)]*G[{0}, yw]*G[{1}, yw]*G[{yv^(-1)}, yw]^2)/2 + 
     (3*G[{0}, yw]^2*G[{1}, yw]*G[{yv^(-1)}, yw]^2)/4 - 
     G[{0}, yu^(-1)]*G[{1}, yu^(-1)]*G[{1}, yw]*G[{yv^(-1)}, yw]^2 - 
     G[{0}, yv^(-1)]*G[{1}, yu^(-1)]*G[{1}, yw]*G[{yv^(-1)}, yw]^2 + 
     G[{0}, yw]*G[{1}, yu^(-1)]*G[{1}, yw]*G[{yv^(-1)}, yw]^2 + 
     (G[{1}, yu^(-1)]^2*G[{1}, yw]*G[{yv^(-1)}, yw]^2)/4 - 
     (3*G[{0}, yu^(-1)]*G[{1}, yv^(-1)]*G[{1}, yw]*G[{yv^(-1)}, yw]^2)/2 - 
     (3*G[{0}, yv^(-1)]*G[{1}, yv^(-1)]*G[{1}, yw]*G[{yv^(-1)}, yw]^2)/2 + 
     (3*G[{0}, yw]*G[{1}, yv^(-1)]*G[{1}, yw]*G[{yv^(-1)}, yw]^2)/2 - 
     (G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*G[{1}, yw]*G[{yv^(-1)}, yw]^2)/2 + 
     (3*G[{1}, yv^(-1)]^2*G[{1}, yw]*G[{yv^(-1)}, yw]^2)/4 + 
     G[{0}, yu^(-1)]*G[{1}, yw]^2*G[{yv^(-1)}, yw]^2 + 
     G[{0}, yv^(-1)]*G[{1}, yw]^2*G[{yv^(-1)}, yw]^2 - 
     G[{0}, yw]*G[{1}, yw]^2*G[{yv^(-1)}, yw]^2 - 
     G[{1}, yu^(-1)]*G[{1}, yw]^2*G[{yv^(-1)}, yw]^2 - 
     G[{1}, yv^(-1)]*G[{1}, yw]^2*G[{yv^(-1)}, yw]^2 + 
     (Pi^2*G[{yu^(-1)}, yw]*G[{yv^(-1)}, yw]^2)/4 - 
     (G[{0}, yu^(-1)]^2*G[{yu^(-1)}, yw]*G[{yv^(-1)}, yw]^2)/4 - 
     (G[{0}, yu^(-1)]*G[{0}, yv^(-1)]*G[{yu^(-1)}, yw]*G[{yv^(-1)}, yw]^2)/
      2 - (G[{0}, yv^(-1)]^2*G[{yu^(-1)}, yw]*G[{yv^(-1)}, yw]^2)/4 + 
     (G[{0}, yu^(-1)]*G[{0}, yw]*G[{yu^(-1)}, yw]*G[{yv^(-1)}, yw]^2)/2 + 
     (G[{0}, yv^(-1)]*G[{0}, yw]*G[{yu^(-1)}, yw]*G[{yv^(-1)}, yw]^2)/2 - 
     (G[{0}, yw]^2*G[{yu^(-1)}, yw]*G[{yv^(-1)}, yw]^2)/4 - 
     (G[{1}, yu^(-1)]^2*G[{yu^(-1)}, yw]*G[{yv^(-1)}, yw]^2)/4 - 
     G[{0}, yu^(-1)]*G[{1}, yv^(-1)]*G[{yu^(-1)}, yw]*G[{yv^(-1)}, yw]^2 - 
     G[{0}, yv^(-1)]*G[{1}, yv^(-1)]*G[{yu^(-1)}, yw]*G[{yv^(-1)}, yw]^2 + 
     G[{0}, yw]*G[{1}, yv^(-1)]*G[{yu^(-1)}, yw]*G[{yv^(-1)}, yw]^2 + 
     (9*G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*G[{yu^(-1)}, yw]*G[{yv^(-1)}, yw]^2)/
      2 + (3*G[{1}, yv^(-1)]^2*G[{yu^(-1)}, yw]*G[{yv^(-1)}, yw]^2)/4 - 
     (7*G[{0}, yu^(-1)]*G[{1}, yw]*G[{yu^(-1)}, yw]*G[{yv^(-1)}, yw]^2)/2 - 
     (7*G[{0}, yv^(-1)]*G[{1}, yw]*G[{yu^(-1)}, yw]*G[{yv^(-1)}, yw]^2)/2 + 
     (7*G[{0}, yw]*G[{1}, yw]*G[{yu^(-1)}, yw]*G[{yv^(-1)}, yw]^2)/2 + 
     4*G[{1}, yu^(-1)]*G[{1}, yw]*G[{yu^(-1)}, yw]*G[{yv^(-1)}, yw]^2 + 
     4*G[{1}, yv^(-1)]*G[{1}, yw]*G[{yu^(-1)}, yw]*G[{yv^(-1)}, yw]^2 + 
     (G[{1}, yw]^2*G[{yu^(-1)}, yw]*G[{yv^(-1)}, yw]^2)/2 + 
     (5*G[{0}, yu^(-1)]*G[{yu^(-1)}, yw]^2*G[{yv^(-1)}, yw]^2)/4 + 
     (5*G[{0}, yv^(-1)]*G[{yu^(-1)}, yw]^2*G[{yv^(-1)}, yw]^2)/4 - 
     (5*G[{0}, yw]*G[{yu^(-1)}, yw]^2*G[{yv^(-1)}, yw]^2)/4 - 
     (9*G[{1}, yu^(-1)]*G[{yu^(-1)}, yw]^2*G[{yv^(-1)}, yw]^2)/4 - 
     (9*G[{1}, yv^(-1)]*G[{yu^(-1)}, yw]^2*G[{yv^(-1)}, yw]^2)/4 - 
     2*G[{1}, yw]*G[{yu^(-1)}, yw]^2*G[{yv^(-1)}, yw]^2 + 
     (3*G[{yu^(-1)}, yw]^3*G[{yv^(-1)}, yw]^2)/4 + 
     (Pi^2*G[{yu}, yv^(-1)]*G[{yv^(-1)}, yw]^2)/4 - 
     (G[{0}, yu^(-1)]^2*G[{yu}, yv^(-1)]*G[{yv^(-1)}, yw]^2)/2 - 
     G[{0}, yu^(-1)]*G[{0}, yv^(-1)]*G[{yu}, yv^(-1)]*G[{yv^(-1)}, yw]^2 - 
     (G[{0}, yv^(-1)]^2*G[{yu}, yv^(-1)]*G[{yv^(-1)}, yw]^2)/2 + 
     G[{0}, yu^(-1)]*G[{0}, yw]*G[{yu}, yv^(-1)]*G[{yv^(-1)}, yw]^2 + 
     G[{0}, yv^(-1)]*G[{0}, yw]*G[{yu}, yv^(-1)]*G[{yv^(-1)}, yw]^2 - 
     (G[{0}, yw]^2*G[{yu}, yv^(-1)]*G[{yv^(-1)}, yw]^2)/2 + 
     (G[{0}, yu^(-1)]*G[{1}, yu^(-1)]*G[{yu}, yv^(-1)]*G[{yv^(-1)}, yw]^2)/
      2 + (G[{0}, yv^(-1)]*G[{1}, yu^(-1)]*G[{yu}, yv^(-1)]*
       G[{yv^(-1)}, yw]^2)/2 - (G[{0}, yw]*G[{1}, yu^(-1)]*G[{yu}, yv^(-1)]*
       G[{yv^(-1)}, yw]^2)/2 - (G[{1}, yu^(-1)]^2*G[{yu}, yv^(-1)]*
       G[{yv^(-1)}, yw]^2)/4 - (G[{0}, yu^(-1)]*G[{1}, yv^(-1)]*
       G[{yu}, yv^(-1)]*G[{yv^(-1)}, yw]^2)/2 - 
     (G[{0}, yv^(-1)]*G[{1}, yv^(-1)]*G[{yu}, yv^(-1)]*G[{yv^(-1)}, yw]^2)/
      2 + (G[{0}, yw]*G[{1}, yv^(-1)]*G[{yu}, yv^(-1)]*G[{yv^(-1)}, yw]^2)/
      2 + 4*G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*G[{yu}, yv^(-1)]*
      G[{yv^(-1)}, yw]^2 + (G[{1}, yv^(-1)]^2*G[{yu}, yv^(-1)]*
       G[{yv^(-1)}, yw]^2)/2 - (G[{0}, yu^(-1)]*G[{1}, yw]*G[{yu}, yv^(-1)]*
       G[{yv^(-1)}, yw]^2)/2 - (G[{0}, yv^(-1)]*G[{1}, yw]*G[{yu}, yv^(-1)]*
       G[{yv^(-1)}, yw]^2)/2 + (G[{0}, yw]*G[{1}, yw]*G[{yu}, yv^(-1)]*
       G[{yv^(-1)}, yw]^2)/2 + 2*G[{1}, yu^(-1)]*G[{1}, yw]*G[{yu}, yv^(-1)]*
      G[{yv^(-1)}, yw]^2 + 2*G[{1}, yv^(-1)]*G[{1}, yw]*G[{yu}, yv^(-1)]*
      G[{yv^(-1)}, yw]^2 + 2*G[{0}, yu^(-1)]*G[{yu^(-1)}, yw]*
      G[{yu}, yv^(-1)]*G[{yv^(-1)}, yw]^2 + 2*G[{0}, yv^(-1)]*
      G[{yu^(-1)}, yw]*G[{yu}, yv^(-1)]*G[{yv^(-1)}, yw]^2 - 
     2*G[{0}, yw]*G[{yu^(-1)}, yw]*G[{yu}, yv^(-1)]*G[{yv^(-1)}, yw]^2 - 
     4*G[{1}, yu^(-1)]*G[{yu^(-1)}, yw]*G[{yu}, yv^(-1)]*G[{yv^(-1)}, yw]^2 - 
     4*G[{1}, yv^(-1)]*G[{yu^(-1)}, yw]*G[{yu}, yv^(-1)]*G[{yv^(-1)}, yw]^2 - 
     G[{1}, yw]*G[{yu^(-1)}, yw]*G[{yu}, yv^(-1)]*G[{yv^(-1)}, yw]^2 + 
     2*G[{yu^(-1)}, yw]^2*G[{yu}, yv^(-1)]*G[{yv^(-1)}, yw]^2 + 
     G[{0}, yu^(-1)]*G[{yu}, yv^(-1)]^2*G[{yv^(-1)}, yw]^2 + 
     G[{0}, yv^(-1)]*G[{yu}, yv^(-1)]^2*G[{yv^(-1)}, yw]^2 - 
     G[{0}, yw]*G[{yu}, yv^(-1)]^2*G[{yv^(-1)}, yw]^2 - 
     (9*G[{1}, yu^(-1)]*G[{yu}, yv^(-1)]^2*G[{yv^(-1)}, yw]^2)/4 - 
     2*G[{1}, yv^(-1)]*G[{yu}, yv^(-1)]^2*G[{yv^(-1)}, yw]^2 - 
     (3*G[{1}, yw]*G[{yu}, yv^(-1)]^2*G[{yv^(-1)}, yw]^2)/2 + 
     2*G[{yu^(-1)}, yw]*G[{yu}, yv^(-1)]^2*G[{yv^(-1)}, yw]^2 + 
     (3*G[{yu}, yv^(-1)]^3*G[{yv^(-1)}, yw]^2)/4 + (Pi^2*G[{yv^(-1)}, yw]^3)/
      6 - (G[{0}, yu^(-1)]^2*G[{yv^(-1)}, yw]^3)/4 - 
     (G[{0}, yu^(-1)]*G[{0}, yv^(-1)]*G[{yv^(-1)}, yw]^3)/2 - 
     (G[{0}, yv^(-1)]^2*G[{yv^(-1)}, yw]^3)/4 + 
     (G[{0}, yu^(-1)]*G[{0}, yw]*G[{yv^(-1)}, yw]^3)/2 + 
     (G[{0}, yv^(-1)]*G[{0}, yw]*G[{yv^(-1)}, yw]^3)/2 - 
     (G[{0}, yw]^2*G[{yv^(-1)}, yw]^3)/4 + 
     (G[{0}, yu^(-1)]*G[{1}, yu^(-1)]*G[{yv^(-1)}, yw]^3)/6 + 
     (G[{0}, yv^(-1)]*G[{1}, yu^(-1)]*G[{yv^(-1)}, yw]^3)/6 - 
     (G[{0}, yw]*G[{1}, yu^(-1)]*G[{yv^(-1)}, yw]^3)/6 - 
     (G[{1}, yu^(-1)]^2*G[{yv^(-1)}, yw]^3)/6 + 
     (G[{0}, yu^(-1)]*G[{1}, yv^(-1)]*G[{yv^(-1)}, yw]^3)/2 + 
     (G[{0}, yv^(-1)]*G[{1}, yv^(-1)]*G[{yv^(-1)}, yw]^3)/2 - 
     (G[{0}, yw]*G[{1}, yv^(-1)]*G[{yv^(-1)}, yw]^3)/2 + 
     (5*G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*G[{yv^(-1)}, yw]^3)/6 - 
     (G[{1}, yv^(-1)]^2*G[{yv^(-1)}, yw]^3)/4 - 
     (4*G[{0}, yu^(-1)]*G[{1}, yw]*G[{yv^(-1)}, yw]^3)/3 - 
     (4*G[{0}, yv^(-1)]*G[{1}, yw]*G[{yv^(-1)}, yw]^3)/3 + 
     (4*G[{0}, yw]*G[{1}, yw]*G[{yv^(-1)}, yw]^3)/3 + 
     (5*G[{1}, yu^(-1)]*G[{1}, yw]*G[{yv^(-1)}, yw]^3)/6 + 
     (4*G[{1}, yv^(-1)]*G[{1}, yw]*G[{yv^(-1)}, yw]^3)/3 - 
     (G[{1}, yw]^2*G[{yv^(-1)}, yw]^3)/4 + 
     (G[{0}, yu^(-1)]*G[{yu^(-1)}, yw]*G[{yv^(-1)}, yw]^3)/2 + 
     (G[{0}, yv^(-1)]*G[{yu^(-1)}, yw]*G[{yv^(-1)}, yw]^3)/2 - 
     (G[{0}, yw]*G[{yu^(-1)}, yw]*G[{yv^(-1)}, yw]^3)/2 - 
     (5*G[{1}, yu^(-1)]*G[{yu^(-1)}, yw]*G[{yv^(-1)}, yw]^3)/6 - 
     (3*G[{1}, yv^(-1)]*G[{yu^(-1)}, yw]*G[{yv^(-1)}, yw]^3)/2 - 
     (4*G[{1}, yw]*G[{yu^(-1)}, yw]*G[{yv^(-1)}, yw]^3)/3 + 
     (3*G[{yu^(-1)}, yw]^2*G[{yv^(-1)}, yw]^3)/4 + 
     (G[{0}, yu^(-1)]*G[{yu}, yv^(-1)]*G[{yv^(-1)}, yw]^3)/3 + 
     (G[{0}, yv^(-1)]*G[{yu}, yv^(-1)]*G[{yv^(-1)}, yw]^3)/3 - 
     (G[{0}, yw]*G[{yu}, yv^(-1)]*G[{yv^(-1)}, yw]^3)/3 - 
     (5*G[{1}, yu^(-1)]*G[{yu}, yv^(-1)]*G[{yv^(-1)}, yw]^3)/6 - 
     (4*G[{1}, yv^(-1)]*G[{yu}, yv^(-1)]*G[{yv^(-1)}, yw]^3)/3 + 
     (G[{1}, yw]*G[{yu}, yv^(-1)]*G[{yv^(-1)}, yw]^3)/2 + 
     (4*G[{yu^(-1)}, yw]*G[{yu}, yv^(-1)]*G[{yv^(-1)}, yw]^3)/3 + 
     (3*G[{yu}, yv^(-1)]^2*G[{yv^(-1)}, yw]^3)/4 + 
     (5*G[{0}, yu^(-1)]*G[{yv^(-1)}, yw]^4)/24 + 
     (5*G[{0}, yv^(-1)]*G[{yv^(-1)}, yw]^4)/24 - 
     (5*G[{0}, yw]*G[{yv^(-1)}, yw]^4)/24 - 
     (5*G[{1}, yu^(-1)]*G[{yv^(-1)}, yw]^4)/12 - 
     (5*G[{1}, yv^(-1)]*G[{yv^(-1)}, yw]^4)/24 - 
     (5*G[{1}, yw]*G[{yv^(-1)}, yw]^4)/24 + 
     (5*G[{yu^(-1)}, yw]*G[{yv^(-1)}, yw]^4)/24 + 
     (5*G[{yu}, yv^(-1)]*G[{yv^(-1)}, yw]^4)/24 + G[{yv^(-1)}, yw]^5/12 - 
     (7*Pi^4*G[{1/(yu*yv)}, yw])/360 + (Pi^2*G[{0}, yu^(-1)]*G[{1}, yu^(-1)]*
       G[{1/(yu*yv)}, yw])/3 + (Pi^2*G[{0}, yv^(-1)]*G[{1}, yu^(-1)]*
       G[{1/(yu*yv)}, yw])/3 - (Pi^2*G[{0}, yw]*G[{1}, yu^(-1)]*
       G[{1/(yu*yv)}, yw])/3 - (5*Pi^2*G[{1}, yu^(-1)]^2*G[{1/(yu*yv)}, yw])/
      12 + (Pi^2*G[{0}, yu^(-1)]*G[{1}, yv^(-1)]*G[{1/(yu*yv)}, yw])/3 + 
     (Pi^2*G[{0}, yv^(-1)]*G[{1}, yv^(-1)]*G[{1/(yu*yv)}, yw])/3 - 
     (Pi^2*G[{0}, yw]*G[{1}, yv^(-1)]*G[{1/(yu*yv)}, yw])/3 - 
     (2*Pi^2*G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*G[{1/(yu*yv)}, yw])/3 + 
     (G[{0}, yu^(-1)]^2*G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*G[{1/(yu*yv)}, yw])/
      2 + G[{0}, yu^(-1)]*G[{0}, yv^(-1)]*G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*
      G[{1/(yu*yv)}, yw] + (G[{0}, yv^(-1)]^2*G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*
       G[{1/(yu*yv)}, yw])/2 - G[{0}, yu^(-1)]*G[{0}, yw]*G[{1}, yu^(-1)]*
      G[{1}, yv^(-1)]*G[{1/(yu*yv)}, yw] - G[{0}, yv^(-1)]*G[{0}, yw]*
      G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*G[{1/(yu*yv)}, yw] + 
     (G[{0}, yw]^2*G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*G[{1/(yu*yv)}, yw])/2 - 
     (3*G[{0}, yu^(-1)]*G[{1}, yu^(-1)]^2*G[{1}, yv^(-1)]*G[{1/(yu*yv)}, yw])/
      2 - (3*G[{0}, yv^(-1)]*G[{1}, yu^(-1)]^2*G[{1}, yv^(-1)]*
       G[{1/(yu*yv)}, yw])/2 + (3*G[{0}, yw]*G[{1}, yu^(-1)]^2*
       G[{1}, yv^(-1)]*G[{1/(yu*yv)}, yw])/2 + G[{1}, yu^(-1)]^3*
      G[{1}, yv^(-1)]*G[{1/(yu*yv)}, yw] - 
     (5*Pi^2*G[{1}, yv^(-1)]^2*G[{1/(yu*yv)}, yw])/12 + 
     (3*G[{1}, yu^(-1)]^2*G[{1}, yv^(-1)]^2*G[{1/(yu*yv)}, yw])/2 - 
     (2*G[{1}, yu^(-1)]*G[{1}, yv^(-1)]^3*G[{1/(yu*yv)}, yw])/3 + 
     (Pi^2*G[{0}, yu^(-1)]*G[{1}, yw]*G[{1/(yu*yv)}, yw])/2 + 
     (Pi^2*G[{0}, yv^(-1)]*G[{1}, yw]*G[{1/(yu*yv)}, yw])/2 - 
     (Pi^2*G[{0}, yw]*G[{1}, yw]*G[{1/(yu*yv)}, yw])/2 - 
     Pi^2*G[{1}, yu^(-1)]*G[{1}, yw]*G[{1/(yu*yv)}, yw] + 
     (G[{0}, yu^(-1)]^2*G[{1}, yu^(-1)]*G[{1}, yw]*G[{1/(yu*yv)}, yw])/2 + 
     G[{0}, yu^(-1)]*G[{0}, yv^(-1)]*G[{1}, yu^(-1)]*G[{1}, yw]*
      G[{1/(yu*yv)}, yw] + (G[{0}, yv^(-1)]^2*G[{1}, yu^(-1)]*G[{1}, yw]*
       G[{1/(yu*yv)}, yw])/2 - G[{0}, yu^(-1)]*G[{0}, yw]*G[{1}, yu^(-1)]*
      G[{1}, yw]*G[{1/(yu*yv)}, yw] - G[{0}, yv^(-1)]*G[{0}, yw]*
      G[{1}, yu^(-1)]*G[{1}, yw]*G[{1/(yu*yv)}, yw] + 
     (G[{0}, yw]^2*G[{1}, yu^(-1)]*G[{1}, yw]*G[{1/(yu*yv)}, yw])/2 - 
     (3*G[{0}, yu^(-1)]*G[{1}, yu^(-1)]^2*G[{1}, yw]*G[{1/(yu*yv)}, yw])/2 - 
     (3*G[{0}, yv^(-1)]*G[{1}, yu^(-1)]^2*G[{1}, yw]*G[{1/(yu*yv)}, yw])/2 + 
     (3*G[{0}, yw]*G[{1}, yu^(-1)]^2*G[{1}, yw]*G[{1/(yu*yv)}, yw])/2 + 
     G[{1}, yu^(-1)]^3*G[{1}, yw]*G[{1/(yu*yv)}, yw] - 
     Pi^2*G[{1}, yv^(-1)]*G[{1}, yw]*G[{1/(yu*yv)}, yw] + 
     (G[{0}, yu^(-1)]^2*G[{1}, yv^(-1)]*G[{1}, yw]*G[{1/(yu*yv)}, yw])/2 + 
     G[{0}, yu^(-1)]*G[{0}, yv^(-1)]*G[{1}, yv^(-1)]*G[{1}, yw]*
      G[{1/(yu*yv)}, yw] + (G[{0}, yv^(-1)]^2*G[{1}, yv^(-1)]*G[{1}, yw]*
       G[{1/(yu*yv)}, yw])/2 - G[{0}, yu^(-1)]*G[{0}, yw]*G[{1}, yv^(-1)]*
      G[{1}, yw]*G[{1/(yu*yv)}, yw] - G[{0}, yv^(-1)]*G[{0}, yw]*
      G[{1}, yv^(-1)]*G[{1}, yw]*G[{1/(yu*yv)}, yw] + 
     (G[{0}, yw]^2*G[{1}, yv^(-1)]*G[{1}, yw]*G[{1/(yu*yv)}, yw])/2 + 
     2*G[{0}, yu^(-1)]*G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*G[{1}, yw]*
      G[{1/(yu*yv)}, yw] + 2*G[{0}, yv^(-1)]*G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*
      G[{1}, yw]*G[{1/(yu*yv)}, yw] - 2*G[{0}, yw]*G[{1}, yu^(-1)]*
      G[{1}, yv^(-1)]*G[{1}, yw]*G[{1/(yu*yv)}, yw] - 
     (5*G[{1}, yu^(-1)]^2*G[{1}, yv^(-1)]*G[{1}, yw]*G[{1/(yu*yv)}, yw])/2 - 
     (3*G[{0}, yu^(-1)]*G[{1}, yv^(-1)]^2*G[{1}, yw]*G[{1/(yu*yv)}, yw])/2 - 
     (3*G[{0}, yv^(-1)]*G[{1}, yv^(-1)]^2*G[{1}, yw]*G[{1/(yu*yv)}, yw])/2 + 
     (3*G[{0}, yw]*G[{1}, yv^(-1)]^2*G[{1}, yw]*G[{1/(yu*yv)}, yw])/2 - 
     2*G[{1}, yu^(-1)]*G[{1}, yv^(-1)]^2*G[{1}, yw]*G[{1/(yu*yv)}, yw] + 
     G[{1}, yv^(-1)]^3*G[{1}, yw]*G[{1/(yu*yv)}, yw] - 
     (Pi^2*G[{1}, yw]^2*G[{1/(yu*yv)}, yw])/3 + 
     (3*G[{0}, yu^(-1)]^2*G[{1}, yw]^2*G[{1/(yu*yv)}, yw])/2 + 
     3*G[{0}, yu^(-1)]*G[{0}, yv^(-1)]*G[{1}, yw]^2*G[{1/(yu*yv)}, yw] + 
     (3*G[{0}, yv^(-1)]^2*G[{1}, yw]^2*G[{1/(yu*yv)}, yw])/2 - 
     3*G[{0}, yu^(-1)]*G[{0}, yw]*G[{1}, yw]^2*G[{1/(yu*yv)}, yw] - 
     3*G[{0}, yv^(-1)]*G[{0}, yw]*G[{1}, yw]^2*G[{1/(yu*yv)}, yw] + 
     (3*G[{0}, yw]^2*G[{1}, yw]^2*G[{1/(yu*yv)}, yw])/2 - 
     3*G[{0}, yu^(-1)]*G[{1}, yu^(-1)]*G[{1}, yw]^2*G[{1/(yu*yv)}, yw] - 
     3*G[{0}, yv^(-1)]*G[{1}, yu^(-1)]*G[{1}, yw]^2*G[{1/(yu*yv)}, yw] + 
     3*G[{0}, yw]*G[{1}, yu^(-1)]*G[{1}, yw]^2*G[{1/(yu*yv)}, yw] + 
     (3*G[{1}, yu^(-1)]^2*G[{1}, yw]^2*G[{1/(yu*yv)}, yw])/2 - 
     3*G[{0}, yu^(-1)]*G[{1}, yv^(-1)]*G[{1}, yw]^2*G[{1/(yu*yv)}, yw] - 
     3*G[{0}, yv^(-1)]*G[{1}, yv^(-1)]*G[{1}, yw]^2*G[{1/(yu*yv)}, yw] + 
     3*G[{0}, yw]*G[{1}, yv^(-1)]*G[{1}, yw]^2*G[{1/(yu*yv)}, yw] + 
     (3*G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*G[{1}, yw]^2*G[{1/(yu*yv)}, yw])/2 + 
     (3*G[{1}, yv^(-1)]^2*G[{1}, yw]^2*G[{1/(yu*yv)}, yw])/2 + 
     (2*G[{0}, yu^(-1)]*G[{1}, yw]^3*G[{1/(yu*yv)}, yw])/3 + 
     (2*G[{0}, yv^(-1)]*G[{1}, yw]^3*G[{1/(yu*yv)}, yw])/3 - 
     (2*G[{0}, yw]*G[{1}, yw]^3*G[{1/(yu*yv)}, yw])/3 - 
     (2*G[{1}, yu^(-1)]*G[{1}, yw]^3*G[{1/(yu*yv)}, yw])/3 - 
     (2*G[{1}, yv^(-1)]*G[{1}, yw]^3*G[{1/(yu*yv)}, yw])/3 - 
     (Pi^2*G[{0}, yu^(-1)]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw])/2 - 
     (Pi^2*G[{0}, yv^(-1)]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw])/2 + 
     (Pi^2*G[{0}, yw]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw])/2 + 
     (5*Pi^2*G[{1}, yu^(-1)]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw])/6 - 
     (G[{0}, yu^(-1)]^2*G[{1}, yu^(-1)]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw])/
      2 - G[{0}, yu^(-1)]*G[{0}, yv^(-1)]*G[{1}, yu^(-1)]*G[{yu^(-1)}, yw]*
      G[{1/(yu*yv)}, yw] - (G[{0}, yv^(-1)]^2*G[{1}, yu^(-1)]*
       G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw])/2 + G[{0}, yu^(-1)]*G[{0}, yw]*
      G[{1}, yu^(-1)]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw] + 
     G[{0}, yv^(-1)]*G[{0}, yw]*G[{1}, yu^(-1)]*G[{yu^(-1)}, yw]*
      G[{1/(yu*yv)}, yw] - (G[{0}, yw]^2*G[{1}, yu^(-1)]*G[{yu^(-1)}, yw]*
       G[{1/(yu*yv)}, yw])/2 + (3*G[{0}, yu^(-1)]*G[{1}, yu^(-1)]^2*
       G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw])/2 + 
     (3*G[{0}, yv^(-1)]*G[{1}, yu^(-1)]^2*G[{yu^(-1)}, yw]*
       G[{1/(yu*yv)}, yw])/2 - (3*G[{0}, yw]*G[{1}, yu^(-1)]^2*
       G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw])/2 - G[{1}, yu^(-1)]^3*
      G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw] + Pi^2*G[{1}, yv^(-1)]*
      G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw] - G[{0}, yu^(-1)]^2*G[{1}, yv^(-1)]*
      G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw] - 2*G[{0}, yu^(-1)]*G[{0}, yv^(-1)]*
      G[{1}, yv^(-1)]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw] - 
     G[{0}, yv^(-1)]^2*G[{1}, yv^(-1)]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw] + 
     2*G[{0}, yu^(-1)]*G[{0}, yw]*G[{1}, yv^(-1)]*G[{yu^(-1)}, yw]*
      G[{1/(yu*yv)}, yw] + 2*G[{0}, yv^(-1)]*G[{0}, yw]*G[{1}, yv^(-1)]*
      G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw] - G[{0}, yw]^2*G[{1}, yv^(-1)]*
      G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw] - 2*G[{0}, yu^(-1)]*G[{1}, yu^(-1)]*
      G[{1}, yv^(-1)]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw] - 
     2*G[{0}, yv^(-1)]*G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*G[{yu^(-1)}, yw]*
      G[{1/(yu*yv)}, yw] + 2*G[{0}, yw]*G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*
      G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw] + G[{1}, yu^(-1)]^2*G[{1}, yv^(-1)]*
      G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw] + 3*G[{0}, yu^(-1)]*
      G[{1}, yv^(-1)]^2*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw] + 
     3*G[{0}, yv^(-1)]*G[{1}, yv^(-1)]^2*G[{yu^(-1)}, yw]*
      G[{1/(yu*yv)}, yw] - 3*G[{0}, yw]*G[{1}, yv^(-1)]^2*G[{yu^(-1)}, yw]*
      G[{1/(yu*yv)}, yw] + 4*G[{1}, yu^(-1)]*G[{1}, yv^(-1)]^2*
      G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw] - 2*G[{1}, yv^(-1)]^3*
      G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw] + 
     (5*Pi^2*G[{1}, yw]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw])/6 - 
     2*G[{0}, yu^(-1)]^2*G[{1}, yw]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw] - 
     4*G[{0}, yu^(-1)]*G[{0}, yv^(-1)]*G[{1}, yw]*G[{yu^(-1)}, yw]*
      G[{1/(yu*yv)}, yw] - 2*G[{0}, yv^(-1)]^2*G[{1}, yw]*G[{yu^(-1)}, yw]*
      G[{1/(yu*yv)}, yw] + 4*G[{0}, yu^(-1)]*G[{0}, yw]*G[{1}, yw]*
      G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw] + 4*G[{0}, yv^(-1)]*G[{0}, yw]*
      G[{1}, yw]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw] - 
     2*G[{0}, yw]^2*G[{1}, yw]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw] + 
     G[{0}, yu^(-1)]*G[{1}, yu^(-1)]*G[{1}, yw]*G[{yu^(-1)}, yw]*
      G[{1/(yu*yv)}, yw] + G[{0}, yv^(-1)]*G[{1}, yu^(-1)]*G[{1}, yw]*
      G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw] - G[{0}, yw]*G[{1}, yu^(-1)]*
      G[{1}, yw]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw] + 
     (G[{1}, yu^(-1)]^2*G[{1}, yw]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw])/2 + 
     G[{0}, yu^(-1)]*G[{1}, yv^(-1)]*G[{1}, yw]*G[{yu^(-1)}, yw]*
      G[{1/(yu*yv)}, yw] + G[{0}, yv^(-1)]*G[{1}, yv^(-1)]*G[{1}, yw]*
      G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw] - G[{0}, yw]*G[{1}, yv^(-1)]*
      G[{1}, yw]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw] + 
     5*G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*G[{1}, yw]*G[{yu^(-1)}, yw]*
      G[{1/(yu*yv)}, yw] + (G[{1}, yv^(-1)]^2*G[{1}, yw]*G[{yu^(-1)}, yw]*
       G[{1/(yu*yv)}, yw])/2 - (11*G[{0}, yu^(-1)]*G[{1}, yw]^2*
       G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw])/2 - 
     (11*G[{0}, yv^(-1)]*G[{1}, yw]^2*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw])/
      2 + (11*G[{0}, yw]*G[{1}, yw]^2*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw])/
      2 + 4*G[{1}, yu^(-1)]*G[{1}, yw]^2*G[{yu^(-1)}, yw]*
      G[{1/(yu*yv)}, yw] + 4*G[{1}, yv^(-1)]*G[{1}, yw]^2*G[{yu^(-1)}, yw]*
      G[{1/(yu*yv)}, yw] - G[{1}, yw]^3*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw] - 
     (Pi^2*G[{yu^(-1)}, yw]^2*G[{1/(yu*yv)}, yw])/2 + 
     (3*G[{0}, yu^(-1)]^2*G[{yu^(-1)}, yw]^2*G[{1/(yu*yv)}, yw])/4 + 
     (3*G[{0}, yu^(-1)]*G[{0}, yv^(-1)]*G[{yu^(-1)}, yw]^2*
       G[{1/(yu*yv)}, yw])/2 + (3*G[{0}, yv^(-1)]^2*G[{yu^(-1)}, yw]^2*
       G[{1/(yu*yv)}, yw])/4 - (3*G[{0}, yu^(-1)]*G[{0}, yw]*
       G[{yu^(-1)}, yw]^2*G[{1/(yu*yv)}, yw])/2 - 
     (3*G[{0}, yv^(-1)]*G[{0}, yw]*G[{yu^(-1)}, yw]^2*G[{1/(yu*yv)}, yw])/2 + 
     (3*G[{0}, yw]^2*G[{yu^(-1)}, yw]^2*G[{1/(yu*yv)}, yw])/4 - 
     (G[{1}, yu^(-1)]^2*G[{yu^(-1)}, yw]^2*G[{1/(yu*yv)}, yw])/4 - 
     (G[{0}, yu^(-1)]*G[{1}, yv^(-1)]*G[{yu^(-1)}, yw]^2*G[{1/(yu*yv)}, yw])/
      2 - (G[{0}, yv^(-1)]*G[{1}, yv^(-1)]*G[{yu^(-1)}, yw]^2*
       G[{1/(yu*yv)}, yw])/2 + (G[{0}, yw]*G[{1}, yv^(-1)]*G[{yu^(-1)}, yw]^2*
       G[{1/(yu*yv)}, yw])/2 - (11*G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*
       G[{yu^(-1)}, yw]^2*G[{1/(yu*yv)}, yw])/2 + 
     (G[{1}, yv^(-1)]^2*G[{yu^(-1)}, yw]^2*G[{1/(yu*yv)}, yw])/2 + 
     (11*G[{0}, yu^(-1)]*G[{1}, yw]*G[{yu^(-1)}, yw]^2*G[{1/(yu*yv)}, yw])/
      2 + (11*G[{0}, yv^(-1)]*G[{1}, yw]*G[{yu^(-1)}, yw]^2*
       G[{1/(yu*yv)}, yw])/2 - (11*G[{0}, yw]*G[{1}, yw]*G[{yu^(-1)}, yw]^2*
       G[{1/(yu*yv)}, yw])/2 - 6*G[{1}, yu^(-1)]*G[{1}, yw]*
      G[{yu^(-1)}, yw]^2*G[{1/(yu*yv)}, yw] - 
     (11*G[{1}, yv^(-1)]*G[{1}, yw]*G[{yu^(-1)}, yw]^2*G[{1/(yu*yv)}, yw])/
      2 - (G[{1}, yw]^2*G[{yu^(-1)}, yw]^2*G[{1/(yu*yv)}, yw])/4 - 
     (5*G[{0}, yu^(-1)]*G[{yu^(-1)}, yw]^3*G[{1/(yu*yv)}, yw])/6 - 
     (5*G[{0}, yv^(-1)]*G[{yu^(-1)}, yw]^3*G[{1/(yu*yv)}, yw])/6 + 
     (5*G[{0}, yw]*G[{yu^(-1)}, yw]^3*G[{1/(yu*yv)}, yw])/6 + 
     (11*G[{1}, yu^(-1)]*G[{yu^(-1)}, yw]^3*G[{1/(yu*yv)}, yw])/6 + 
     (5*G[{1}, yv^(-1)]*G[{yu^(-1)}, yw]^3*G[{1/(yu*yv)}, yw])/3 + 
     (11*G[{1}, yw]*G[{yu^(-1)}, yw]^3*G[{1/(yu*yv)}, yw])/6 - 
     (5*G[{yu^(-1)}, yw]^4*G[{1/(yu*yv)}, yw])/12 - 
     (Pi^2*G[{0}, yu^(-1)]*G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw])/3 - 
     (Pi^2*G[{0}, yv^(-1)]*G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw])/3 + 
     (Pi^2*G[{0}, yw]*G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw])/3 + 
     (5*Pi^2*G[{1}, yu^(-1)]*G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw])/6 - 
     (G[{0}, yu^(-1)]^2*G[{1}, yu^(-1)]*G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw])/
      2 - G[{0}, yu^(-1)]*G[{0}, yv^(-1)]*G[{1}, yu^(-1)]*G[{yu}, yv^(-1)]*
      G[{1/(yu*yv)}, yw] - (G[{0}, yv^(-1)]^2*G[{1}, yu^(-1)]*
       G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw])/2 + G[{0}, yu^(-1)]*G[{0}, yw]*
      G[{1}, yu^(-1)]*G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw] + 
     G[{0}, yv^(-1)]*G[{0}, yw]*G[{1}, yu^(-1)]*G[{yu}, yv^(-1)]*
      G[{1/(yu*yv)}, yw] - (G[{0}, yw]^2*G[{1}, yu^(-1)]*G[{yu}, yv^(-1)]*
       G[{1/(yu*yv)}, yw])/2 + (3*G[{0}, yu^(-1)]*G[{1}, yu^(-1)]^2*
       G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw])/2 + 
     (3*G[{0}, yv^(-1)]*G[{1}, yu^(-1)]^2*G[{yu}, yv^(-1)]*
       G[{1/(yu*yv)}, yw])/2 - (3*G[{0}, yw]*G[{1}, yu^(-1)]^2*
       G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw])/2 - G[{1}, yu^(-1)]^3*
      G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw] + 
     (5*Pi^2*G[{1}, yv^(-1)]*G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw])/6 - 
     (G[{0}, yu^(-1)]^2*G[{1}, yv^(-1)]*G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw])/
      2 - G[{0}, yu^(-1)]*G[{0}, yv^(-1)]*G[{1}, yv^(-1)]*G[{yu}, yv^(-1)]*
      G[{1/(yu*yv)}, yw] - (G[{0}, yv^(-1)]^2*G[{1}, yv^(-1)]*
       G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw])/2 + G[{0}, yu^(-1)]*G[{0}, yw]*
      G[{1}, yv^(-1)]*G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw] + 
     G[{0}, yv^(-1)]*G[{0}, yw]*G[{1}, yv^(-1)]*G[{yu}, yv^(-1)]*
      G[{1/(yu*yv)}, yw] - (G[{0}, yw]^2*G[{1}, yv^(-1)]*G[{yu}, yv^(-1)]*
       G[{1/(yu*yv)}, yw])/2 - 2*G[{0}, yu^(-1)]*G[{1}, yu^(-1)]*
      G[{1}, yv^(-1)]*G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw] - 
     2*G[{0}, yv^(-1)]*G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*G[{yu}, yv^(-1)]*
      G[{1/(yu*yv)}, yw] + 2*G[{0}, yw]*G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*
      G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw] + 
     (G[{1}, yu^(-1)]^2*G[{1}, yv^(-1)]*G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw])/
      2 + (3*G[{0}, yu^(-1)]*G[{1}, yv^(-1)]^2*G[{yu}, yv^(-1)]*
       G[{1/(yu*yv)}, yw])/2 + (3*G[{0}, yv^(-1)]*G[{1}, yv^(-1)]^2*
       G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw])/2 - 
     (3*G[{0}, yw]*G[{1}, yv^(-1)]^2*G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw])/2 + 
     4*G[{1}, yu^(-1)]*G[{1}, yv^(-1)]^2*G[{yu}, yv^(-1)]*
      G[{1/(yu*yv)}, yw] - G[{1}, yv^(-1)]^3*G[{yu}, yv^(-1)]*
      G[{1/(yu*yv)}, yw] + Pi^2*G[{1}, yw]*G[{yu}, yv^(-1)]*
      G[{1/(yu*yv)}, yw] - G[{0}, yu^(-1)]^2*G[{1}, yw]*G[{yu}, yv^(-1)]*
      G[{1/(yu*yv)}, yw] - 2*G[{0}, yu^(-1)]*G[{0}, yv^(-1)]*G[{1}, yw]*
      G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw] - G[{0}, yv^(-1)]^2*G[{1}, yw]*
      G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw] + 2*G[{0}, yu^(-1)]*G[{0}, yw]*
      G[{1}, yw]*G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw] + 
     2*G[{0}, yv^(-1)]*G[{0}, yw]*G[{1}, yw]*G[{yu}, yv^(-1)]*
      G[{1/(yu*yv)}, yw] - G[{0}, yw]^2*G[{1}, yw]*G[{yu}, yv^(-1)]*
      G[{1/(yu*yv)}, yw] - G[{0}, yu^(-1)]*G[{1}, yu^(-1)]*G[{1}, yw]*
      G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw] - G[{0}, yv^(-1)]*G[{1}, yu^(-1)]*
      G[{1}, yw]*G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw] + 
     G[{0}, yw]*G[{1}, yu^(-1)]*G[{1}, yw]*G[{yu}, yv^(-1)]*
      G[{1/(yu*yv)}, yw] + (5*G[{1}, yu^(-1)]^2*G[{1}, yw]*G[{yu}, yv^(-1)]*
       G[{1/(yu*yv)}, yw])/2 - G[{0}, yu^(-1)]*G[{1}, yv^(-1)]*G[{1}, yw]*
      G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw] - G[{0}, yv^(-1)]*G[{1}, yv^(-1)]*
      G[{1}, yw]*G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw] + 
     G[{0}, yw]*G[{1}, yv^(-1)]*G[{1}, yw]*G[{yu}, yv^(-1)]*
      G[{1/(yu*yv)}, yw] + 7*G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*G[{1}, yw]*
      G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw] + 
     (5*G[{1}, yv^(-1)]^2*G[{1}, yw]*G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw])/2 + 
     (3*G[{1}, yu^(-1)]*G[{1}, yw]^2*G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw])/2 + 
     (3*G[{1}, yv^(-1)]*G[{1}, yw]^2*G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw])/2 - 
     (5*Pi^2*G[{yu^(-1)}, yw]*G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw])/6 + 
     (3*G[{0}, yu^(-1)]^2*G[{yu^(-1)}, yw]*G[{yu}, yv^(-1)]*
       G[{1/(yu*yv)}, yw])/2 + 3*G[{0}, yu^(-1)]*G[{0}, yv^(-1)]*
      G[{yu^(-1)}, yw]*G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw] + 
     (3*G[{0}, yv^(-1)]^2*G[{yu^(-1)}, yw]*G[{yu}, yv^(-1)]*
       G[{1/(yu*yv)}, yw])/2 - 3*G[{0}, yu^(-1)]*G[{0}, yw]*G[{yu^(-1)}, yw]*
      G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw] - 3*G[{0}, yv^(-1)]*G[{0}, yw]*
      G[{yu^(-1)}, yw]*G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw] + 
     (3*G[{0}, yw]^2*G[{yu^(-1)}, yw]*G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw])/
      2 + G[{0}, yu^(-1)]*G[{1}, yu^(-1)]*G[{yu^(-1)}, yw]*G[{yu}, yv^(-1)]*
      G[{1/(yu*yv)}, yw] + G[{0}, yv^(-1)]*G[{1}, yu^(-1)]*G[{yu^(-1)}, yw]*
      G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw] - G[{0}, yw]*G[{1}, yu^(-1)]*
      G[{yu^(-1)}, yw]*G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw] - 
     G[{1}, yu^(-1)]^2*G[{yu^(-1)}, yw]*G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw] - 
     12*G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*G[{yu^(-1)}, yw]*G[{yu}, yv^(-1)]*
      G[{1/(yu*yv)}, yw] - (G[{1}, yv^(-1)]^2*G[{yu^(-1)}, yw]*
       G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw])/2 + 6*G[{0}, yu^(-1)]*G[{1}, yw]*
      G[{yu^(-1)}, yw]*G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw] + 
     6*G[{0}, yv^(-1)]*G[{1}, yw]*G[{yu^(-1)}, yw]*G[{yu}, yv^(-1)]*
      G[{1/(yu*yv)}, yw] - 6*G[{0}, yw]*G[{1}, yw]*G[{yu^(-1)}, yw]*
      G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw] - 8*G[{1}, yu^(-1)]*G[{1}, yw]*
      G[{yu^(-1)}, yw]*G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw] - 
     8*G[{1}, yv^(-1)]*G[{1}, yw]*G[{yu^(-1)}, yw]*G[{yu}, yv^(-1)]*
      G[{1/(yu*yv)}, yw] + 3*G[{1}, yw]^2*G[{yu^(-1)}, yw]*G[{yu}, yv^(-1)]*
      G[{1/(yu*yv)}, yw] - (5*G[{0}, yu^(-1)]*G[{yu^(-1)}, yw]^2*
       G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw])/2 - 
     (5*G[{0}, yv^(-1)]*G[{yu^(-1)}, yw]^2*G[{yu}, yv^(-1)]*
       G[{1/(yu*yv)}, yw])/2 + (5*G[{0}, yw]*G[{yu^(-1)}, yw]^2*
       G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw])/2 + 6*G[{1}, yu^(-1)]*
      G[{yu^(-1)}, yw]^2*G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw] + 
     (11*G[{1}, yv^(-1)]*G[{yu^(-1)}, yw]^2*G[{yu}, yv^(-1)]*
       G[{1/(yu*yv)}, yw])/2 + (G[{1}, yw]*G[{yu^(-1)}, yw]^2*
       G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw])/2 - 
     (11*G[{yu^(-1)}, yw]^3*G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw])/6 - 
     (Pi^2*G[{yu}, yv^(-1)]^2*G[{1/(yu*yv)}, yw])/2 + 
     (G[{0}, yu^(-1)]^2*G[{yu}, yv^(-1)]^2*G[{1/(yu*yv)}, yw])/2 + 
     G[{0}, yu^(-1)]*G[{0}, yv^(-1)]*G[{yu}, yv^(-1)]^2*G[{1/(yu*yv)}, yw] + 
     (G[{0}, yv^(-1)]^2*G[{yu}, yv^(-1)]^2*G[{1/(yu*yv)}, yw])/2 - 
     G[{0}, yu^(-1)]*G[{0}, yw]*G[{yu}, yv^(-1)]^2*G[{1/(yu*yv)}, yw] - 
     G[{0}, yv^(-1)]*G[{0}, yw]*G[{yu}, yv^(-1)]^2*G[{1/(yu*yv)}, yw] + 
     (G[{0}, yw]^2*G[{yu}, yv^(-1)]^2*G[{1/(yu*yv)}, yw])/2 + 
     (G[{0}, yu^(-1)]*G[{1}, yu^(-1)]*G[{yu}, yv^(-1)]^2*G[{1/(yu*yv)}, yw])/
      2 + (G[{0}, yv^(-1)]*G[{1}, yu^(-1)]*G[{yu}, yv^(-1)]^2*
       G[{1/(yu*yv)}, yw])/2 - (G[{0}, yw]*G[{1}, yu^(-1)]*G[{yu}, yv^(-1)]^2*
       G[{1/(yu*yv)}, yw])/2 - (G[{1}, yu^(-1)]^2*G[{yu}, yv^(-1)]^2*
       G[{1/(yu*yv)}, yw])/4 + (G[{0}, yu^(-1)]*G[{1}, yv^(-1)]*
       G[{yu}, yv^(-1)]^2*G[{1/(yu*yv)}, yw])/2 + 
     (G[{0}, yv^(-1)]*G[{1}, yv^(-1)]*G[{yu}, yv^(-1)]^2*G[{1/(yu*yv)}, yw])/
      2 - (G[{0}, yw]*G[{1}, yv^(-1)]*G[{yu}, yv^(-1)]^2*G[{1/(yu*yv)}, yw])/
      2 - 6*G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*G[{yu}, yv^(-1)]^2*
      G[{1/(yu*yv)}, yw] - (G[{1}, yv^(-1)]^2*G[{yu}, yv^(-1)]^2*
       G[{1/(yu*yv)}, yw])/4 + 3*G[{0}, yu^(-1)]*G[{1}, yw]*
      G[{yu}, yv^(-1)]^2*G[{1/(yu*yv)}, yw] + 3*G[{0}, yv^(-1)]*G[{1}, yw]*
      G[{yu}, yv^(-1)]^2*G[{1/(yu*yv)}, yw] - 3*G[{0}, yw]*G[{1}, yw]*
      G[{yu}, yv^(-1)]^2*G[{1/(yu*yv)}, yw] - 5*G[{1}, yu^(-1)]*G[{1}, yw]*
      G[{yu}, yv^(-1)]^2*G[{1/(yu*yv)}, yw] - 5*G[{1}, yv^(-1)]*G[{1}, yw]*
      G[{yu}, yv^(-1)]^2*G[{1/(yu*yv)}, yw] - 
     (3*G[{1}, yw]^2*G[{yu}, yv^(-1)]^2*G[{1/(yu*yv)}, yw])/2 - 
     (7*G[{0}, yu^(-1)]*G[{yu^(-1)}, yw]*G[{yu}, yv^(-1)]^2*
       G[{1/(yu*yv)}, yw])/2 - (7*G[{0}, yv^(-1)]*G[{yu^(-1)}, yw]*
       G[{yu}, yv^(-1)]^2*G[{1/(yu*yv)}, yw])/2 + 
     (7*G[{0}, yw]*G[{yu^(-1)}, yw]*G[{yu}, yv^(-1)]^2*G[{1/(yu*yv)}, yw])/
      2 + 6*G[{1}, yu^(-1)]*G[{yu^(-1)}, yw]*G[{yu}, yv^(-1)]^2*
      G[{1/(yu*yv)}, yw] + (13*G[{1}, yv^(-1)]*G[{yu^(-1)}, yw]*
       G[{yu}, yv^(-1)]^2*G[{1/(yu*yv)}, yw])/2 + 
     2*G[{1}, yw]*G[{yu^(-1)}, yw]*G[{yu}, yv^(-1)]^2*G[{1/(yu*yv)}, yw] - 
     (13*G[{yu^(-1)}, yw]^2*G[{yu}, yv^(-1)]^2*G[{1/(yu*yv)}, yw])/4 - 
     G[{0}, yu^(-1)]*G[{yu}, yv^(-1)]^3*G[{1/(yu*yv)}, yw] - 
     G[{0}, yv^(-1)]*G[{yu}, yv^(-1)]^3*G[{1/(yu*yv)}, yw] + 
     G[{0}, yw]*G[{yu}, yv^(-1)]^3*G[{1/(yu*yv)}, yw] + 
     (11*G[{1}, yu^(-1)]*G[{yu}, yv^(-1)]^3*G[{1/(yu*yv)}, yw])/6 + 
     (11*G[{1}, yv^(-1)]*G[{yu}, yv^(-1)]^3*G[{1/(yu*yv)}, yw])/6 + 
     (4*G[{1}, yw]*G[{yu}, yv^(-1)]^3*G[{1/(yu*yv)}, yw])/3 - 
     (11*G[{yu^(-1)}, yw]*G[{yu}, yv^(-1)]^3*G[{1/(yu*yv)}, yw])/6 - 
     (5*G[{yu}, yv^(-1)]^4*G[{1/(yu*yv)}, yw])/12 - 
     (Pi^2*G[{0}, yu^(-1)]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw])/2 - 
     (Pi^2*G[{0}, yv^(-1)]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw])/2 + 
     (Pi^2*G[{0}, yw]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw])/2 + 
     Pi^2*G[{1}, yu^(-1)]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw] - 
     G[{0}, yu^(-1)]^2*G[{1}, yu^(-1)]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw] - 
     2*G[{0}, yu^(-1)]*G[{0}, yv^(-1)]*G[{1}, yu^(-1)]*G[{yv^(-1)}, yw]*
      G[{1/(yu*yv)}, yw] - G[{0}, yv^(-1)]^2*G[{1}, yu^(-1)]*G[{yv^(-1)}, yw]*
      G[{1/(yu*yv)}, yw] + 2*G[{0}, yu^(-1)]*G[{0}, yw]*G[{1}, yu^(-1)]*
      G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw] + 2*G[{0}, yv^(-1)]*G[{0}, yw]*
      G[{1}, yu^(-1)]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw] - 
     G[{0}, yw]^2*G[{1}, yu^(-1)]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw] + 
     3*G[{0}, yu^(-1)]*G[{1}, yu^(-1)]^2*G[{yv^(-1)}, yw]*
      G[{1/(yu*yv)}, yw] + 3*G[{0}, yv^(-1)]*G[{1}, yu^(-1)]^2*
      G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw] - 3*G[{0}, yw]*G[{1}, yu^(-1)]^2*
      G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw] - 2*G[{1}, yu^(-1)]^3*
      G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw] + 
     (5*Pi^2*G[{1}, yv^(-1)]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw])/6 - 
     (G[{0}, yu^(-1)]^2*G[{1}, yv^(-1)]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw])/
      2 - G[{0}, yu^(-1)]*G[{0}, yv^(-1)]*G[{1}, yv^(-1)]*G[{yv^(-1)}, yw]*
      G[{1/(yu*yv)}, yw] - (G[{0}, yv^(-1)]^2*G[{1}, yv^(-1)]*
       G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw])/2 + G[{0}, yu^(-1)]*G[{0}, yw]*
      G[{1}, yv^(-1)]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw] + 
     G[{0}, yv^(-1)]*G[{0}, yw]*G[{1}, yv^(-1)]*G[{yv^(-1)}, yw]*
      G[{1/(yu*yv)}, yw] - (G[{0}, yw]^2*G[{1}, yv^(-1)]*G[{yv^(-1)}, yw]*
       G[{1/(yu*yv)}, yw])/2 - 2*G[{0}, yu^(-1)]*G[{1}, yu^(-1)]*
      G[{1}, yv^(-1)]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw] - 
     2*G[{0}, yv^(-1)]*G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*G[{yv^(-1)}, yw]*
      G[{1/(yu*yv)}, yw] + 2*G[{0}, yw]*G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*
      G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw] + 
     (G[{1}, yu^(-1)]^2*G[{1}, yv^(-1)]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw])/
      2 + (3*G[{0}, yu^(-1)]*G[{1}, yv^(-1)]^2*G[{yv^(-1)}, yw]*
       G[{1/(yu*yv)}, yw])/2 + (3*G[{0}, yv^(-1)]*G[{1}, yv^(-1)]^2*
       G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw])/2 - 
     (3*G[{0}, yw]*G[{1}, yv^(-1)]^2*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw])/2 + 
     4*G[{1}, yu^(-1)]*G[{1}, yv^(-1)]^2*G[{yv^(-1)}, yw]*
      G[{1/(yu*yv)}, yw] - G[{1}, yv^(-1)]^3*G[{yv^(-1)}, yw]*
      G[{1/(yu*yv)}, yw] + (5*Pi^2*G[{1}, yw]*G[{yv^(-1)}, yw]*
       G[{1/(yu*yv)}, yw])/6 - 2*G[{0}, yu^(-1)]^2*G[{1}, yw]*
      G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw] - 4*G[{0}, yu^(-1)]*G[{0}, yv^(-1)]*
      G[{1}, yw]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw] - 
     2*G[{0}, yv^(-1)]^2*G[{1}, yw]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw] + 
     4*G[{0}, yu^(-1)]*G[{0}, yw]*G[{1}, yw]*G[{yv^(-1)}, yw]*
      G[{1/(yu*yv)}, yw] + 4*G[{0}, yv^(-1)]*G[{0}, yw]*G[{1}, yw]*
      G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw] - 2*G[{0}, yw]^2*G[{1}, yw]*
      G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw] + G[{0}, yu^(-1)]*G[{1}, yu^(-1)]*
      G[{1}, yw]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw] + 
     G[{0}, yv^(-1)]*G[{1}, yu^(-1)]*G[{1}, yw]*G[{yv^(-1)}, yw]*
      G[{1/(yu*yv)}, yw] - G[{0}, yw]*G[{1}, yu^(-1)]*G[{1}, yw]*
      G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw] + 
     (G[{1}, yu^(-1)]^2*G[{1}, yw]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw])/2 + 
     G[{0}, yu^(-1)]*G[{1}, yv^(-1)]*G[{1}, yw]*G[{yv^(-1)}, yw]*
      G[{1/(yu*yv)}, yw] + G[{0}, yv^(-1)]*G[{1}, yv^(-1)]*G[{1}, yw]*
      G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw] - G[{0}, yw]*G[{1}, yv^(-1)]*
      G[{1}, yw]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw] + 
     5*G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*G[{1}, yw]*G[{yv^(-1)}, yw]*
      G[{1/(yu*yv)}, yw] + (G[{1}, yv^(-1)]^2*G[{1}, yw]*G[{yv^(-1)}, yw]*
       G[{1/(yu*yv)}, yw])/2 - (11*G[{0}, yu^(-1)]*G[{1}, yw]^2*
       G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw])/2 - 
     (11*G[{0}, yv^(-1)]*G[{1}, yw]^2*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw])/
      2 + (11*G[{0}, yw]*G[{1}, yw]^2*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw])/
      2 + 4*G[{1}, yu^(-1)]*G[{1}, yw]^2*G[{yv^(-1)}, yw]*
      G[{1/(yu*yv)}, yw] + 4*G[{1}, yv^(-1)]*G[{1}, yw]^2*G[{yv^(-1)}, yw]*
      G[{1/(yu*yv)}, yw] - G[{1}, yw]^3*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw] - 
     (5*Pi^2*G[{yu^(-1)}, yw]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw])/6 + 
     G[{0}, yu^(-1)]^2*G[{yu^(-1)}, yw]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw] + 
     2*G[{0}, yu^(-1)]*G[{0}, yv^(-1)]*G[{yu^(-1)}, yw]*G[{yv^(-1)}, yw]*
      G[{1/(yu*yv)}, yw] + G[{0}, yv^(-1)]^2*G[{yu^(-1)}, yw]*
      G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw] - 2*G[{0}, yu^(-1)]*G[{0}, yw]*
      G[{yu^(-1)}, yw]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw] - 
     2*G[{0}, yv^(-1)]*G[{0}, yw]*G[{yu^(-1)}, yw]*G[{yv^(-1)}, yw]*
      G[{1/(yu*yv)}, yw] + G[{0}, yw]^2*G[{yu^(-1)}, yw]*G[{yv^(-1)}, yw]*
      G[{1/(yu*yv)}, yw] + G[{0}, yu^(-1)]*G[{1}, yu^(-1)]*G[{yu^(-1)}, yw]*
      G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw] + G[{0}, yv^(-1)]*G[{1}, yu^(-1)]*
      G[{yu^(-1)}, yw]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw] - 
     G[{0}, yw]*G[{1}, yu^(-1)]*G[{yu^(-1)}, yw]*G[{yv^(-1)}, yw]*
      G[{1/(yu*yv)}, yw] - (G[{1}, yu^(-1)]^2*G[{yu^(-1)}, yw]*
       G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw])/2 + G[{0}, yu^(-1)]*
      G[{1}, yv^(-1)]*G[{yu^(-1)}, yw]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw] + 
     G[{0}, yv^(-1)]*G[{1}, yv^(-1)]*G[{yu^(-1)}, yw]*G[{yv^(-1)}, yw]*
      G[{1/(yu*yv)}, yw] - G[{0}, yw]*G[{1}, yv^(-1)]*G[{yu^(-1)}, yw]*
      G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw] - 13*G[{1}, yu^(-1)]*
      G[{1}, yv^(-1)]*G[{yu^(-1)}, yw]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw] - 
     (G[{1}, yv^(-1)]^2*G[{yu^(-1)}, yw]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw])/
      2 + 11*G[{0}, yu^(-1)]*G[{1}, yw]*G[{yu^(-1)}, yw]*G[{yv^(-1)}, yw]*
      G[{1/(yu*yv)}, yw] + 11*G[{0}, yv^(-1)]*G[{1}, yw]*G[{yu^(-1)}, yw]*
      G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw] - 11*G[{0}, yw]*G[{1}, yw]*
      G[{yu^(-1)}, yw]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw] - 
     12*G[{1}, yu^(-1)]*G[{1}, yw]*G[{yu^(-1)}, yw]*G[{yv^(-1)}, yw]*
      G[{1/(yu*yv)}, yw] - 12*G[{1}, yv^(-1)]*G[{1}, yw]*G[{yu^(-1)}, yw]*
      G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw] - G[{1}, yw]^2*G[{yu^(-1)}, yw]*
      G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw] - 3*G[{0}, yu^(-1)]*
      G[{yu^(-1)}, yw]^2*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw] - 
     3*G[{0}, yv^(-1)]*G[{yu^(-1)}, yw]^2*G[{yv^(-1)}, yw]*
      G[{1/(yu*yv)}, yw] + 3*G[{0}, yw]*G[{yu^(-1)}, yw]^2*G[{yv^(-1)}, yw]*
      G[{1/(yu*yv)}, yw] + (13*G[{1}, yu^(-1)]*G[{yu^(-1)}, yw]^2*
       G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw])/2 + 
     (11*G[{1}, yv^(-1)]*G[{yu^(-1)}, yw]^2*G[{yv^(-1)}, yw]*
       G[{1/(yu*yv)}, yw])/2 + 6*G[{1}, yw]*G[{yu^(-1)}, yw]^2*
      G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw] - 
     (11*G[{yu^(-1)}, yw]^3*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw])/6 - 
     (5*Pi^2*G[{yu}, yv^(-1)]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw])/6 + 
     (3*G[{0}, yu^(-1)]^2*G[{yu}, yv^(-1)]*G[{yv^(-1)}, yw]*
       G[{1/(yu*yv)}, yw])/2 + 3*G[{0}, yu^(-1)]*G[{0}, yv^(-1)]*
      G[{yu}, yv^(-1)]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw] + 
     (3*G[{0}, yv^(-1)]^2*G[{yu}, yv^(-1)]*G[{yv^(-1)}, yw]*
       G[{1/(yu*yv)}, yw])/2 - 3*G[{0}, yu^(-1)]*G[{0}, yw]*G[{yu}, yv^(-1)]*
      G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw] - 3*G[{0}, yv^(-1)]*G[{0}, yw]*
      G[{yu}, yv^(-1)]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw] + 
     (3*G[{0}, yw]^2*G[{yu}, yv^(-1)]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw])/
      2 - (G[{1}, yu^(-1)]^2*G[{yu}, yv^(-1)]*G[{yv^(-1)}, yw]*
       G[{1/(yu*yv)}, yw])/2 + G[{0}, yu^(-1)]*G[{1}, yv^(-1)]*
      G[{yu}, yv^(-1)]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw] + 
     G[{0}, yv^(-1)]*G[{1}, yv^(-1)]*G[{yu}, yv^(-1)]*G[{yv^(-1)}, yw]*
      G[{1/(yu*yv)}, yw] - G[{0}, yw]*G[{1}, yv^(-1)]*G[{yu}, yv^(-1)]*
      G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw] - 12*G[{1}, yu^(-1)]*
      G[{1}, yv^(-1)]*G[{yu}, yv^(-1)]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw] - 
     G[{1}, yv^(-1)]^2*G[{yu}, yv^(-1)]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw] + 
     6*G[{0}, yu^(-1)]*G[{1}, yw]*G[{yu}, yv^(-1)]*G[{yv^(-1)}, yw]*
      G[{1/(yu*yv)}, yw] + 6*G[{0}, yv^(-1)]*G[{1}, yw]*G[{yu}, yv^(-1)]*
      G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw] - 6*G[{0}, yw]*G[{1}, yw]*
      G[{yu}, yv^(-1)]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw] - 
     8*G[{1}, yu^(-1)]*G[{1}, yw]*G[{yu}, yv^(-1)]*G[{yv^(-1)}, yw]*
      G[{1/(yu*yv)}, yw] - 8*G[{1}, yv^(-1)]*G[{1}, yw]*G[{yu}, yv^(-1)]*
      G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw] + 3*G[{1}, yw]^2*G[{yu}, yv^(-1)]*
      G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw] - 6*G[{0}, yu^(-1)]*
      G[{yu^(-1)}, yw]*G[{yu}, yv^(-1)]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw] - 
     6*G[{0}, yv^(-1)]*G[{yu^(-1)}, yw]*G[{yu}, yv^(-1)]*G[{yv^(-1)}, yw]*
      G[{1/(yu*yv)}, yw] + 6*G[{0}, yw]*G[{yu^(-1)}, yw]*G[{yu}, yv^(-1)]*
      G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw] + 12*G[{1}, yu^(-1)]*
      G[{yu^(-1)}, yw]*G[{yu}, yv^(-1)]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw] + 
     12*G[{1}, yv^(-1)]*G[{yu^(-1)}, yw]*G[{yu}, yv^(-1)]*G[{yv^(-1)}, yw]*
      G[{1/(yu*yv)}, yw] + 2*G[{1}, yw]*G[{yu^(-1)}, yw]*G[{yu}, yv^(-1)]*
      G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw] - 6*G[{yu^(-1)}, yw]^2*
      G[{yu}, yv^(-1)]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw] - 
     (7*G[{0}, yu^(-1)]*G[{yu}, yv^(-1)]^2*G[{yv^(-1)}, yw]*
       G[{1/(yu*yv)}, yw])/2 - (7*G[{0}, yv^(-1)]*G[{yu}, yv^(-1)]^2*
       G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw])/2 + 
     (7*G[{0}, yw]*G[{yu}, yv^(-1)]^2*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw])/
      2 + (13*G[{1}, yu^(-1)]*G[{yu}, yv^(-1)]^2*G[{yv^(-1)}, yw]*
       G[{1/(yu*yv)}, yw])/2 + 6*G[{1}, yv^(-1)]*G[{yu}, yv^(-1)]^2*
      G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw] + 2*G[{1}, yw]*G[{yu}, yv^(-1)]^2*
      G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw] - 6*G[{yu^(-1)}, yw]*
      G[{yu}, yv^(-1)]^2*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw] - 
     (11*G[{yu}, yv^(-1)]^3*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw])/6 - 
     (Pi^2*G[{yv^(-1)}, yw]^2*G[{1/(yu*yv)}, yw])/2 + 
     (3*G[{0}, yu^(-1)]^2*G[{yv^(-1)}, yw]^2*G[{1/(yu*yv)}, yw])/4 + 
     (3*G[{0}, yu^(-1)]*G[{0}, yv^(-1)]*G[{yv^(-1)}, yw]^2*
       G[{1/(yu*yv)}, yw])/2 + (3*G[{0}, yv^(-1)]^2*G[{yv^(-1)}, yw]^2*
       G[{1/(yu*yv)}, yw])/4 - (3*G[{0}, yu^(-1)]*G[{0}, yw]*
       G[{yv^(-1)}, yw]^2*G[{1/(yu*yv)}, yw])/2 - 
     (3*G[{0}, yv^(-1)]*G[{0}, yw]*G[{yv^(-1)}, yw]^2*G[{1/(yu*yv)}, yw])/2 + 
     (3*G[{0}, yw]^2*G[{yv^(-1)}, yw]^2*G[{1/(yu*yv)}, yw])/4 - 
     (G[{0}, yu^(-1)]*G[{1}, yu^(-1)]*G[{yv^(-1)}, yw]^2*G[{1/(yu*yv)}, yw])/
      2 - (G[{0}, yv^(-1)]*G[{1}, yu^(-1)]*G[{yv^(-1)}, yw]^2*
       G[{1/(yu*yv)}, yw])/2 + (G[{0}, yw]*G[{1}, yu^(-1)]*G[{yv^(-1)}, yw]^2*
       G[{1/(yu*yv)}, yw])/2 + (G[{1}, yu^(-1)]^2*G[{yv^(-1)}, yw]^2*
       G[{1/(yu*yv)}, yw])/2 - (11*G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*
       G[{yv^(-1)}, yw]^2*G[{1/(yu*yv)}, yw])/2 - 
     (G[{1}, yv^(-1)]^2*G[{yv^(-1)}, yw]^2*G[{1/(yu*yv)}, yw])/4 + 
     (11*G[{0}, yu^(-1)]*G[{1}, yw]*G[{yv^(-1)}, yw]^2*G[{1/(yu*yv)}, yw])/
      2 + (11*G[{0}, yv^(-1)]*G[{1}, yw]*G[{yv^(-1)}, yw]^2*
       G[{1/(yu*yv)}, yw])/2 - (11*G[{0}, yw]*G[{1}, yw]*G[{yv^(-1)}, yw]^2*
       G[{1/(yu*yv)}, yw])/2 - (11*G[{1}, yu^(-1)]*G[{1}, yw]*
       G[{yv^(-1)}, yw]^2*G[{1/(yu*yv)}, yw])/2 - 
     6*G[{1}, yv^(-1)]*G[{1}, yw]*G[{yv^(-1)}, yw]^2*G[{1/(yu*yv)}, yw] - 
     (G[{1}, yw]^2*G[{yv^(-1)}, yw]^2*G[{1/(yu*yv)}, yw])/4 - 
     3*G[{0}, yu^(-1)]*G[{yu^(-1)}, yw]*G[{yv^(-1)}, yw]^2*
      G[{1/(yu*yv)}, yw] - 3*G[{0}, yv^(-1)]*G[{yu^(-1)}, yw]*
      G[{yv^(-1)}, yw]^2*G[{1/(yu*yv)}, yw] + 3*G[{0}, yw]*G[{yu^(-1)}, yw]*
      G[{yv^(-1)}, yw]^2*G[{1/(yu*yv)}, yw] + 
     (11*G[{1}, yu^(-1)]*G[{yu^(-1)}, yw]*G[{yv^(-1)}, yw]^2*
       G[{1/(yu*yv)}, yw])/2 + (13*G[{1}, yv^(-1)]*G[{yu^(-1)}, yw]*
       G[{yv^(-1)}, yw]^2*G[{1/(yu*yv)}, yw])/2 + 
     6*G[{1}, yw]*G[{yu^(-1)}, yw]*G[{yv^(-1)}, yw]^2*G[{1/(yu*yv)}, yw] - 
     (13*G[{yu^(-1)}, yw]^2*G[{yv^(-1)}, yw]^2*G[{1/(yu*yv)}, yw])/4 - 
     (5*G[{0}, yu^(-1)]*G[{yu}, yv^(-1)]*G[{yv^(-1)}, yw]^2*
       G[{1/(yu*yv)}, yw])/2 - (5*G[{0}, yv^(-1)]*G[{yu}, yv^(-1)]*
       G[{yv^(-1)}, yw]^2*G[{1/(yu*yv)}, yw])/2 + 
     (5*G[{0}, yw]*G[{yu}, yv^(-1)]*G[{yv^(-1)}, yw]^2*G[{1/(yu*yv)}, yw])/
      2 + (11*G[{1}, yu^(-1)]*G[{yu}, yv^(-1)]*G[{yv^(-1)}, yw]^2*
       G[{1/(yu*yv)}, yw])/2 + 6*G[{1}, yv^(-1)]*G[{yu}, yv^(-1)]*
      G[{yv^(-1)}, yw]^2*G[{1/(yu*yv)}, yw] + 
     (G[{1}, yw]*G[{yu}, yv^(-1)]*G[{yv^(-1)}, yw]^2*G[{1/(yu*yv)}, yw])/2 - 
     6*G[{yu^(-1)}, yw]*G[{yu}, yv^(-1)]*G[{yv^(-1)}, yw]^2*
      G[{1/(yu*yv)}, yw] - (13*G[{yu}, yv^(-1)]^2*G[{yv^(-1)}, yw]^2*
       G[{1/(yu*yv)}, yw])/4 - (5*G[{0}, yu^(-1)]*G[{yv^(-1)}, yw]^3*
       G[{1/(yu*yv)}, yw])/6 - (5*G[{0}, yv^(-1)]*G[{yv^(-1)}, yw]^3*
       G[{1/(yu*yv)}, yw])/6 + (5*G[{0}, yw]*G[{yv^(-1)}, yw]^3*
       G[{1/(yu*yv)}, yw])/6 + (5*G[{1}, yu^(-1)]*G[{yv^(-1)}, yw]^3*
       G[{1/(yu*yv)}, yw])/3 + (11*G[{1}, yv^(-1)]*G[{yv^(-1)}, yw]^3*
       G[{1/(yu*yv)}, yw])/6 + (11*G[{1}, yw]*G[{yv^(-1)}, yw]^3*
       G[{1/(yu*yv)}, yw])/6 - (11*G[{yu^(-1)}, yw]*G[{yv^(-1)}, yw]^3*
       G[{1/(yu*yv)}, yw])/6 - (11*G[{yu}, yv^(-1)]*G[{yv^(-1)}, yw]^3*
       G[{1/(yu*yv)}, yw])/6 - (5*G[{yv^(-1)}, yw]^4*G[{1/(yu*yv)}, yw])/12 + 
     (Pi^2*G[{0}, yu^(-1)]*G[{1/(yu*yv)}, yw]^2)/12 + 
     (Pi^2*G[{0}, yv^(-1)]*G[{1/(yu*yv)}, yw]^2)/12 - 
     (Pi^2*G[{0}, yw]*G[{1/(yu*yv)}, yw]^2)/12 - 
     (Pi^2*G[{1}, yu^(-1)]*G[{1/(yu*yv)}, yw]^2)/12 + 
     (G[{0}, yu^(-1)]^2*G[{1}, yu^(-1)]*G[{1/(yu*yv)}, yw]^2)/2 + 
     G[{0}, yu^(-1)]*G[{0}, yv^(-1)]*G[{1}, yu^(-1)]*G[{1/(yu*yv)}, yw]^2 + 
     (G[{0}, yv^(-1)]^2*G[{1}, yu^(-1)]*G[{1/(yu*yv)}, yw]^2)/2 - 
     G[{0}, yu^(-1)]*G[{0}, yw]*G[{1}, yu^(-1)]*G[{1/(yu*yv)}, yw]^2 - 
     G[{0}, yv^(-1)]*G[{0}, yw]*G[{1}, yu^(-1)]*G[{1/(yu*yv)}, yw]^2 + 
     (G[{0}, yw]^2*G[{1}, yu^(-1)]*G[{1/(yu*yv)}, yw]^2)/2 - 
     (3*G[{0}, yu^(-1)]*G[{1}, yu^(-1)]^2*G[{1/(yu*yv)}, yw]^2)/2 - 
     (3*G[{0}, yv^(-1)]*G[{1}, yu^(-1)]^2*G[{1/(yu*yv)}, yw]^2)/2 + 
     (3*G[{0}, yw]*G[{1}, yu^(-1)]^2*G[{1/(yu*yv)}, yw]^2)/2 + 
     G[{1}, yu^(-1)]^3*G[{1/(yu*yv)}, yw]^2 - 
     (Pi^2*G[{1}, yv^(-1)]*G[{1/(yu*yv)}, yw]^2)/12 + 
     (G[{0}, yu^(-1)]^2*G[{1}, yv^(-1)]*G[{1/(yu*yv)}, yw]^2)/2 + 
     G[{0}, yu^(-1)]*G[{0}, yv^(-1)]*G[{1}, yv^(-1)]*G[{1/(yu*yv)}, yw]^2 + 
     (G[{0}, yv^(-1)]^2*G[{1}, yv^(-1)]*G[{1/(yu*yv)}, yw]^2)/2 - 
     G[{0}, yu^(-1)]*G[{0}, yw]*G[{1}, yv^(-1)]*G[{1/(yu*yv)}, yw]^2 - 
     G[{0}, yv^(-1)]*G[{0}, yw]*G[{1}, yv^(-1)]*G[{1/(yu*yv)}, yw]^2 + 
     (G[{0}, yw]^2*G[{1}, yv^(-1)]*G[{1/(yu*yv)}, yw]^2)/2 + 
     2*G[{0}, yu^(-1)]*G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*G[{1/(yu*yv)}, yw]^2 + 
     2*G[{0}, yv^(-1)]*G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*G[{1/(yu*yv)}, yw]^2 - 
     2*G[{0}, yw]*G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*G[{1/(yu*yv)}, yw]^2 - 
     G[{1}, yu^(-1)]^2*G[{1}, yv^(-1)]*G[{1/(yu*yv)}, yw]^2 - 
     (3*G[{0}, yu^(-1)]*G[{1}, yv^(-1)]^2*G[{1/(yu*yv)}, yw]^2)/2 - 
     (3*G[{0}, yv^(-1)]*G[{1}, yv^(-1)]^2*G[{1/(yu*yv)}, yw]^2)/2 + 
     (3*G[{0}, yw]*G[{1}, yv^(-1)]^2*G[{1/(yu*yv)}, yw]^2)/2 - 
     3*G[{1}, yu^(-1)]*G[{1}, yv^(-1)]^2*G[{1/(yu*yv)}, yw]^2 + 
     G[{1}, yv^(-1)]^3*G[{1/(yu*yv)}, yw]^2 + 
     (Pi^2*G[{1}, yw]*G[{1/(yu*yv)}, yw]^2)/6 + 
     (3*G[{0}, yu^(-1)]^2*G[{1}, yw]*G[{1/(yu*yv)}, yw]^2)/2 + 
     3*G[{0}, yu^(-1)]*G[{0}, yv^(-1)]*G[{1}, yw]*G[{1/(yu*yv)}, yw]^2 + 
     (3*G[{0}, yv^(-1)]^2*G[{1}, yw]*G[{1/(yu*yv)}, yw]^2)/2 - 
     3*G[{0}, yu^(-1)]*G[{0}, yw]*G[{1}, yw]*G[{1/(yu*yv)}, yw]^2 - 
     3*G[{0}, yv^(-1)]*G[{0}, yw]*G[{1}, yw]*G[{1/(yu*yv)}, yw]^2 + 
     (3*G[{0}, yw]^2*G[{1}, yw]*G[{1/(yu*yv)}, yw]^2)/2 - 
     G[{1}, yu^(-1)]^2*G[{1}, yw]*G[{1/(yu*yv)}, yw]^2 - 
     (5*G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*G[{1}, yw]*G[{1/(yu*yv)}, yw]^2)/2 - 
     G[{1}, yv^(-1)]^2*G[{1}, yw]*G[{1/(yu*yv)}, yw]^2 + 
     (9*G[{0}, yu^(-1)]*G[{1}, yw]^2*G[{1/(yu*yv)}, yw]^2)/2 + 
     (9*G[{0}, yv^(-1)]*G[{1}, yw]^2*G[{1/(yu*yv)}, yw]^2)/2 - 
     (9*G[{0}, yw]*G[{1}, yw]^2*G[{1/(yu*yv)}, yw]^2)/2 - 
     3*G[{1}, yu^(-1)]*G[{1}, yw]^2*G[{1/(yu*yv)}, yw]^2 - 
     3*G[{1}, yv^(-1)]*G[{1}, yw]^2*G[{1/(yu*yv)}, yw]^2 + 
     G[{1}, yw]^3*G[{1/(yu*yv)}, yw]^2 - 
     (Pi^2*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2)/12 - 
     G[{0}, yu^(-1)]^2*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2 - 
     2*G[{0}, yu^(-1)]*G[{0}, yv^(-1)]*G[{yu^(-1)}, yw]*
      G[{1/(yu*yv)}, yw]^2 - G[{0}, yv^(-1)]^2*G[{yu^(-1)}, yw]*
      G[{1/(yu*yv)}, yw]^2 + 2*G[{0}, yu^(-1)]*G[{0}, yw]*G[{yu^(-1)}, yw]*
      G[{1/(yu*yv)}, yw]^2 + 2*G[{0}, yv^(-1)]*G[{0}, yw]*G[{yu^(-1)}, yw]*
      G[{1/(yu*yv)}, yw]^2 - G[{0}, yw]^2*G[{yu^(-1)}, yw]*
      G[{1/(yu*yv)}, yw]^2 - G[{0}, yu^(-1)]*G[{1}, yu^(-1)]*G[{yu^(-1)}, yw]*
      G[{1/(yu*yv)}, yw]^2 - G[{0}, yv^(-1)]*G[{1}, yu^(-1)]*G[{yu^(-1)}, yw]*
      G[{1/(yu*yv)}, yw]^2 + G[{0}, yw]*G[{1}, yu^(-1)]*G[{yu^(-1)}, yw]*
      G[{1/(yu*yv)}, yw]^2 + G[{1}, yu^(-1)]^2*G[{yu^(-1)}, yw]*
      G[{1/(yu*yv)}, yw]^2 + 2*G[{0}, yu^(-1)]*G[{1}, yv^(-1)]*
      G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2 + 2*G[{0}, yv^(-1)]*
      G[{1}, yv^(-1)]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2 - 
     2*G[{0}, yw]*G[{1}, yv^(-1)]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2 + 
     6*G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*G[{yu^(-1)}, yw]*
      G[{1/(yu*yv)}, yw]^2 - 2*G[{1}, yv^(-1)]^2*G[{yu^(-1)}, yw]*
      G[{1/(yu*yv)}, yw]^2 - (11*G[{0}, yu^(-1)]*G[{1}, yw]*G[{yu^(-1)}, yw]*
       G[{1/(yu*yv)}, yw]^2)/2 - (11*G[{0}, yv^(-1)]*G[{1}, yw]*
       G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2)/2 + 
     (11*G[{0}, yw]*G[{1}, yw]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2)/2 + 
     (13*G[{1}, yu^(-1)]*G[{1}, yw]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2)/
      2 + (13*G[{1}, yv^(-1)]*G[{1}, yw]*G[{yu^(-1)}, yw]*
       G[{1/(yu*yv)}, yw]^2)/2 + G[{1}, yw]^2*G[{yu^(-1)}, yw]*
      G[{1/(yu*yv)}, yw]^2 + (G[{0}, yu^(-1)]*G[{yu^(-1)}, yw]^2*
       G[{1/(yu*yv)}, yw]^2)/4 + (G[{0}, yv^(-1)]*G[{yu^(-1)}, yw]^2*
       G[{1/(yu*yv)}, yw]^2)/4 - (G[{0}, yw]*G[{yu^(-1)}, yw]^2*
       G[{1/(yu*yv)}, yw]^2)/4 - (13*G[{1}, yu^(-1)]*G[{yu^(-1)}, yw]^2*
       G[{1/(yu*yv)}, yw]^2)/4 - (G[{1}, yv^(-1)]*G[{yu^(-1)}, yw]^2*
       G[{1/(yu*yv)}, yw]^2)/2 - (13*G[{1}, yw]*G[{yu^(-1)}, yw]^2*
       G[{1/(yu*yv)}, yw]^2)/4 + (G[{yu^(-1)}, yw]^3*G[{1/(yu*yv)}, yw]^2)/
      6 - G[{0}, yu^(-1)]^2*G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw]^2 - 
     2*G[{0}, yu^(-1)]*G[{0}, yv^(-1)]*G[{yu}, yv^(-1)]*
      G[{1/(yu*yv)}, yw]^2 - G[{0}, yv^(-1)]^2*G[{yu}, yv^(-1)]*
      G[{1/(yu*yv)}, yw]^2 + 2*G[{0}, yu^(-1)]*G[{0}, yw]*G[{yu}, yv^(-1)]*
      G[{1/(yu*yv)}, yw]^2 + 2*G[{0}, yv^(-1)]*G[{0}, yw]*G[{yu}, yv^(-1)]*
      G[{1/(yu*yv)}, yw]^2 - G[{0}, yw]^2*G[{yu}, yv^(-1)]*
      G[{1/(yu*yv)}, yw]^2 - G[{0}, yu^(-1)]*G[{1}, yu^(-1)]*G[{yu}, yv^(-1)]*
      G[{1/(yu*yv)}, yw]^2 - G[{0}, yv^(-1)]*G[{1}, yu^(-1)]*G[{yu}, yv^(-1)]*
      G[{1/(yu*yv)}, yw]^2 + G[{0}, yw]*G[{1}, yu^(-1)]*G[{yu}, yv^(-1)]*
      G[{1/(yu*yv)}, yw]^2 + G[{1}, yu^(-1)]^2*G[{yu}, yv^(-1)]*
      G[{1/(yu*yv)}, yw]^2 - G[{0}, yu^(-1)]*G[{1}, yv^(-1)]*G[{yu}, yv^(-1)]*
      G[{1/(yu*yv)}, yw]^2 - G[{0}, yv^(-1)]*G[{1}, yv^(-1)]*G[{yu}, yv^(-1)]*
      G[{1/(yu*yv)}, yw]^2 + G[{0}, yw]*G[{1}, yv^(-1)]*G[{yu}, yv^(-1)]*
      G[{1/(yu*yv)}, yw]^2 + (13*G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*
       G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw]^2)/2 + 
     G[{1}, yv^(-1)]^2*G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw]^2 - 
     6*G[{0}, yu^(-1)]*G[{1}, yw]*G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw]^2 - 
     6*G[{0}, yv^(-1)]*G[{1}, yw]*G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw]^2 + 
     6*G[{0}, yw]*G[{1}, yw]*G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw]^2 + 
     (9*G[{1}, yu^(-1)]*G[{1}, yw]*G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw]^2)/2 + 
     (9*G[{1}, yv^(-1)]*G[{1}, yw]*G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw]^2)/2 - 
     3*G[{1}, yw]^2*G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw]^2 + 
     3*G[{0}, yu^(-1)]*G[{yu^(-1)}, yw]*G[{yu}, yv^(-1)]*
      G[{1/(yu*yv)}, yw]^2 + 3*G[{0}, yv^(-1)]*G[{yu^(-1)}, yw]*
      G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw]^2 - 3*G[{0}, yw]*G[{yu^(-1)}, yw]*
      G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw]^2 - 6*G[{1}, yu^(-1)]*
      G[{yu^(-1)}, yw]*G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw]^2 - 
     (13*G[{1}, yv^(-1)]*G[{yu^(-1)}, yw]*G[{yu}, yv^(-1)]*
       G[{1/(yu*yv)}, yw]^2)/2 - 2*G[{1}, yw]*G[{yu^(-1)}, yw]*
      G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw]^2 + 
     (13*G[{yu^(-1)}, yw]^2*G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw]^2)/4 + 
     3*G[{0}, yu^(-1)]*G[{yu}, yv^(-1)]^2*G[{1/(yu*yv)}, yw]^2 + 
     3*G[{0}, yv^(-1)]*G[{yu}, yv^(-1)]^2*G[{1/(yu*yv)}, yw]^2 - 
     3*G[{0}, yw]*G[{yu}, yv^(-1)]^2*G[{1/(yu*yv)}, yw]^2 - 
     (13*G[{1}, yu^(-1)]*G[{yu}, yv^(-1)]^2*G[{1/(yu*yv)}, yw]^2)/4 - 
     (13*G[{1}, yv^(-1)]*G[{yu}, yv^(-1)]^2*G[{1/(yu*yv)}, yw]^2)/4 + 
     (3*G[{1}, yw]*G[{yu}, yv^(-1)]^2*G[{1/(yu*yv)}, yw]^2)/2 + 
     (13*G[{yu^(-1)}, yw]*G[{yu}, yv^(-1)]^2*G[{1/(yu*yv)}, yw]^2)/4 + 
     (G[{yu}, yv^(-1)]^3*G[{1/(yu*yv)}, yw]^2)/6 - 
     (Pi^2*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2)/12 - 
     G[{0}, yu^(-1)]^2*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2 - 
     2*G[{0}, yu^(-1)]*G[{0}, yv^(-1)]*G[{yv^(-1)}, yw]*
      G[{1/(yu*yv)}, yw]^2 - G[{0}, yv^(-1)]^2*G[{yv^(-1)}, yw]*
      G[{1/(yu*yv)}, yw]^2 + 2*G[{0}, yu^(-1)]*G[{0}, yw]*G[{yv^(-1)}, yw]*
      G[{1/(yu*yv)}, yw]^2 + 2*G[{0}, yv^(-1)]*G[{0}, yw]*G[{yv^(-1)}, yw]*
      G[{1/(yu*yv)}, yw]^2 - G[{0}, yw]^2*G[{yv^(-1)}, yw]*
      G[{1/(yu*yv)}, yw]^2 + 2*G[{0}, yu^(-1)]*G[{1}, yu^(-1)]*
      G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2 + 2*G[{0}, yv^(-1)]*
      G[{1}, yu^(-1)]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2 - 
     2*G[{0}, yw]*G[{1}, yu^(-1)]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2 - 
     2*G[{1}, yu^(-1)]^2*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2 - 
     G[{0}, yu^(-1)]*G[{1}, yv^(-1)]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2 - 
     G[{0}, yv^(-1)]*G[{1}, yv^(-1)]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2 + 
     G[{0}, yw]*G[{1}, yv^(-1)]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2 + 
     (13*G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*G[{yv^(-1)}, yw]*
       G[{1/(yu*yv)}, yw]^2)/2 + G[{1}, yv^(-1)]^2*G[{yv^(-1)}, yw]*
      G[{1/(yu*yv)}, yw]^2 - (11*G[{0}, yu^(-1)]*G[{1}, yw]*G[{yv^(-1)}, yw]*
       G[{1/(yu*yv)}, yw]^2)/2 - (11*G[{0}, yv^(-1)]*G[{1}, yw]*
       G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2)/2 + 
     (11*G[{0}, yw]*G[{1}, yw]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2)/2 + 
     (13*G[{1}, yu^(-1)]*G[{1}, yw]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2)/
      2 + (13*G[{1}, yv^(-1)]*G[{1}, yw]*G[{yv^(-1)}, yw]*
       G[{1/(yu*yv)}, yw]^2)/2 + G[{1}, yw]^2*G[{yv^(-1)}, yw]*
      G[{1/(yu*yv)}, yw]^2 + (7*G[{0}, yu^(-1)]*G[{yu^(-1)}, yw]*
       G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2)/2 + 
     (7*G[{0}, yv^(-1)]*G[{yu^(-1)}, yw]*G[{yv^(-1)}, yw]*
       G[{1/(yu*yv)}, yw]^2)/2 - (7*G[{0}, yw]*G[{yu^(-1)}, yw]*
       G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2)/2 - 
     (13*G[{1}, yu^(-1)]*G[{yu^(-1)}, yw]*G[{yv^(-1)}, yw]*
       G[{1/(yu*yv)}, yw]^2)/2 - (13*G[{1}, yv^(-1)]*G[{yu^(-1)}, yw]*
       G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2)/2 - 
     6*G[{1}, yw]*G[{yu^(-1)}, yw]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2 + 
     (13*G[{yu^(-1)}, yw]^2*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2)/4 + 
     3*G[{0}, yu^(-1)]*G[{yu}, yv^(-1)]*G[{yv^(-1)}, yw]*
      G[{1/(yu*yv)}, yw]^2 + 3*G[{0}, yv^(-1)]*G[{yu}, yv^(-1)]*
      G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2 - 3*G[{0}, yw]*G[{yu}, yv^(-1)]*
      G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2 - 
     (13*G[{1}, yu^(-1)]*G[{yu}, yv^(-1)]*G[{yv^(-1)}, yw]*
       G[{1/(yu*yv)}, yw]^2)/2 - 6*G[{1}, yv^(-1)]*G[{yu}, yv^(-1)]*
      G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2 - 2*G[{1}, yw]*G[{yu}, yv^(-1)]*
      G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2 + 6*G[{yu^(-1)}, yw]*
      G[{yu}, yv^(-1)]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2 + 
     (13*G[{yu}, yv^(-1)]^2*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2)/4 + 
     (G[{0}, yu^(-1)]*G[{yv^(-1)}, yw]^2*G[{1/(yu*yv)}, yw]^2)/4 + 
     (G[{0}, yv^(-1)]*G[{yv^(-1)}, yw]^2*G[{1/(yu*yv)}, yw]^2)/4 - 
     (G[{0}, yw]*G[{yv^(-1)}, yw]^2*G[{1/(yu*yv)}, yw]^2)/4 - 
     (G[{1}, yu^(-1)]*G[{yv^(-1)}, yw]^2*G[{1/(yu*yv)}, yw]^2)/2 - 
     (13*G[{1}, yv^(-1)]*G[{yv^(-1)}, yw]^2*G[{1/(yu*yv)}, yw]^2)/4 - 
     (13*G[{1}, yw]*G[{yv^(-1)}, yw]^2*G[{1/(yu*yv)}, yw]^2)/4 + 
     (13*G[{yu^(-1)}, yw]*G[{yv^(-1)}, yw]^2*G[{1/(yu*yv)}, yw]^2)/4 + 
     (13*G[{yu}, yv^(-1)]*G[{yv^(-1)}, yw]^2*G[{1/(yu*yv)}, yw]^2)/4 + 
     (G[{yv^(-1)}, yw]^3*G[{1/(yu*yv)}, yw]^2)/6 + 
     (Pi^2*G[{1/(yu*yv)}, yw]^3)/18 + 
     (G[{0}, yu^(-1)]^2*G[{1/(yu*yv)}, yw]^3)/6 + 
     (G[{0}, yu^(-1)]*G[{0}, yv^(-1)]*G[{1/(yu*yv)}, yw]^3)/3 + 
     (G[{0}, yv^(-1)]^2*G[{1/(yu*yv)}, yw]^3)/6 - 
     (G[{0}, yu^(-1)]*G[{0}, yw]*G[{1/(yu*yv)}, yw]^3)/3 - 
     (G[{0}, yv^(-1)]*G[{0}, yw]*G[{1/(yu*yv)}, yw]^3)/3 + 
     (G[{0}, yw]^2*G[{1/(yu*yv)}, yw]^3)/6 + 
     (G[{0}, yu^(-1)]*G[{1}, yu^(-1)]*G[{1/(yu*yv)}, yw]^3)/3 + 
     (G[{0}, yv^(-1)]*G[{1}, yu^(-1)]*G[{1/(yu*yv)}, yw]^3)/3 - 
     (G[{0}, yw]*G[{1}, yu^(-1)]*G[{1/(yu*yv)}, yw]^3)/3 - 
     (G[{1}, yu^(-1)]^2*G[{1/(yu*yv)}, yw]^3)/3 + 
     (G[{0}, yu^(-1)]*G[{1}, yv^(-1)]*G[{1/(yu*yv)}, yw]^3)/3 + 
     (G[{0}, yv^(-1)]*G[{1}, yv^(-1)]*G[{1/(yu*yv)}, yw]^3)/3 - 
     (G[{0}, yw]*G[{1}, yv^(-1)]*G[{1/(yu*yv)}, yw]^3)/3 - 
     2*G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*G[{1/(yu*yv)}, yw]^3 - 
     (G[{1}, yv^(-1)]^2*G[{1/(yu*yv)}, yw]^3)/3 + 
     (5*G[{0}, yu^(-1)]*G[{1}, yw]*G[{1/(yu*yv)}, yw]^3)/3 + 
     (5*G[{0}, yv^(-1)]*G[{1}, yw]*G[{1/(yu*yv)}, yw]^3)/3 - 
     (5*G[{0}, yw]*G[{1}, yw]*G[{1/(yu*yv)}, yw]^3)/3 - 
     2*G[{1}, yu^(-1)]*G[{1}, yw]*G[{1/(yu*yv)}, yw]^3 - 
     2*G[{1}, yv^(-1)]*G[{1}, yw]*G[{1/(yu*yv)}, yw]^3 - 
     (G[{1}, yw]^2*G[{1/(yu*yv)}, yw]^3)/3 - 
     (2*G[{0}, yu^(-1)]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]^3)/3 - 
     (2*G[{0}, yv^(-1)]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]^3)/3 + 
     (2*G[{0}, yw]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]^3)/3 + 
     2*G[{1}, yu^(-1)]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]^3 + 
     (4*G[{1}, yv^(-1)]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]^3)/3 + 
     2*G[{1}, yw]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]^3 - 
     (2*G[{yu^(-1)}, yw]^2*G[{1/(yu*yv)}, yw]^3)/3 - 
     (4*G[{0}, yu^(-1)]*G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw]^3)/3 - 
     (4*G[{0}, yv^(-1)]*G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw]^3)/3 + 
     (4*G[{0}, yw]*G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw]^3)/3 + 
     2*G[{1}, yu^(-1)]*G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw]^3 + 
     2*G[{1}, yv^(-1)]*G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw]^3 + 
     (2*G[{1}, yw]*G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw]^3)/3 - 
     2*G[{yu^(-1)}, yw]*G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw]^3 - 
     (2*G[{yu}, yv^(-1)]^2*G[{1/(yu*yv)}, yw]^3)/3 - 
     (2*G[{0}, yu^(-1)]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]^3)/3 - 
     (2*G[{0}, yv^(-1)]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]^3)/3 + 
     (2*G[{0}, yw]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]^3)/3 + 
     (4*G[{1}, yu^(-1)]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]^3)/3 + 
     2*G[{1}, yv^(-1)]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]^3 + 
     2*G[{1}, yw]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]^3 - 
     2*G[{yu^(-1)}, yw]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]^3 - 
     2*G[{yu}, yv^(-1)]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]^3 - 
     (2*G[{yv^(-1)}, yw]^2*G[{1/(yu*yv)}, yw]^3)/3 + 
     (G[{0}, yu^(-1)]*G[{1/(yu*yv)}, yw]^4)/12 + 
     (G[{0}, yv^(-1)]*G[{1/(yu*yv)}, yw]^4)/12 - 
     (G[{0}, yw]*G[{1/(yu*yv)}, yw]^4)/12 - 
     (G[{1}, yu^(-1)]*G[{1/(yu*yv)}, yw]^4)/6 - 
     (G[{1}, yv^(-1)]*G[{1/(yu*yv)}, yw]^4)/6 - 
     (G[{1}, yw]*G[{1/(yu*yv)}, yw]^4)/6 + 
     (G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]^4)/6 + 
     (G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw]^4)/6 + 
     (G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]^4)/6 + 
     (Pi^2*G[{1}, yv^(-1)]*G[{0, 1}, yu^(-1)])/3 - 
     G[{1}, yu^(-1)]^2*G[{1}, yv^(-1)]*G[{0, 1}, yu^(-1)] + 
     (G[{1}, yu^(-1)]*G[{1}, yv^(-1)]^2*G[{0, 1}, yu^(-1)])/2 - 
     (G[{1}, yv^(-1)]^3*G[{0, 1}, yu^(-1)])/3 - 
     (Pi^2*G[{1}, yw]*G[{0, 1}, yu^(-1)])/3 + 
     (G[{0}, yu^(-1)]^2*G[{1}, yw]*G[{0, 1}, yu^(-1)])/2 + 
     G[{0}, yu^(-1)]*G[{0}, yv^(-1)]*G[{1}, yw]*G[{0, 1}, yu^(-1)] + 
     (G[{0}, yv^(-1)]^2*G[{1}, yw]*G[{0, 1}, yu^(-1)])/2 - 
     G[{0}, yu^(-1)]*G[{0}, yw]*G[{1}, yw]*G[{0, 1}, yu^(-1)] - 
     G[{0}, yv^(-1)]*G[{0}, yw]*G[{1}, yw]*G[{0, 1}, yu^(-1)] + 
     (G[{0}, yw]^2*G[{1}, yw]*G[{0, 1}, yu^(-1)])/2 + 
     G[{0}, yu^(-1)]*G[{1}, yu^(-1)]*G[{1}, yw]*G[{0, 1}, yu^(-1)] + 
     G[{0}, yv^(-1)]*G[{1}, yu^(-1)]*G[{1}, yw]*G[{0, 1}, yu^(-1)] - 
     G[{0}, yw]*G[{1}, yu^(-1)]*G[{1}, yw]*G[{0, 1}, yu^(-1)] - 
     (G[{1}, yu^(-1)]^2*G[{1}, yw]*G[{0, 1}, yu^(-1)])/2 + 
     G[{0}, yu^(-1)]*G[{1}, yv^(-1)]*G[{1}, yw]*G[{0, 1}, yu^(-1)] + 
     G[{0}, yv^(-1)]*G[{1}, yv^(-1)]*G[{1}, yw]*G[{0, 1}, yu^(-1)] - 
     G[{0}, yw]*G[{1}, yv^(-1)]*G[{1}, yw]*G[{0, 1}, yu^(-1)] - 
     3*G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*G[{1}, yw]*G[{0, 1}, yu^(-1)] - 
     (G[{1}, yv^(-1)]^2*G[{1}, yw]*G[{0, 1}, yu^(-1)])/2 + 
     (Pi^2*G[{yu^(-1)}, yw]*G[{0, 1}, yu^(-1)])/3 - 
     (G[{0}, yu^(-1)]^2*G[{yu^(-1)}, yw]*G[{0, 1}, yu^(-1)])/2 - 
     G[{0}, yu^(-1)]*G[{0}, yv^(-1)]*G[{yu^(-1)}, yw]*G[{0, 1}, yu^(-1)] - 
     (G[{0}, yv^(-1)]^2*G[{yu^(-1)}, yw]*G[{0, 1}, yu^(-1)])/2 + 
     G[{0}, yu^(-1)]*G[{0}, yw]*G[{yu^(-1)}, yw]*G[{0, 1}, yu^(-1)] + 
     G[{0}, yv^(-1)]*G[{0}, yw]*G[{yu^(-1)}, yw]*G[{0, 1}, yu^(-1)] - 
     (G[{0}, yw]^2*G[{yu^(-1)}, yw]*G[{0, 1}, yu^(-1)])/2 - 
     G[{0}, yu^(-1)]*G[{1}, yu^(-1)]*G[{yu^(-1)}, yw]*G[{0, 1}, yu^(-1)] - 
     G[{0}, yv^(-1)]*G[{1}, yu^(-1)]*G[{yu^(-1)}, yw]*G[{0, 1}, yu^(-1)] + 
     G[{0}, yw]*G[{1}, yu^(-1)]*G[{yu^(-1)}, yw]*G[{0, 1}, yu^(-1)] + 
     (G[{1}, yu^(-1)]^2*G[{yu^(-1)}, yw]*G[{0, 1}, yu^(-1)])/2 - 
     G[{0}, yu^(-1)]*G[{1}, yv^(-1)]*G[{yu^(-1)}, yw]*G[{0, 1}, yu^(-1)] - 
     G[{0}, yv^(-1)]*G[{1}, yv^(-1)]*G[{yu^(-1)}, yw]*G[{0, 1}, yu^(-1)] + 
     G[{0}, yw]*G[{1}, yv^(-1)]*G[{yu^(-1)}, yw]*G[{0, 1}, yu^(-1)] + 
     5*G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*G[{yu^(-1)}, yw]*G[{0, 1}, yu^(-1)] + 
     G[{1}, yv^(-1)]^2*G[{yu^(-1)}, yw]*G[{0, 1}, yu^(-1)] - 
     2*G[{0}, yu^(-1)]*G[{1}, yw]*G[{yu^(-1)}, yw]*G[{0, 1}, yu^(-1)] - 
     2*G[{0}, yv^(-1)]*G[{1}, yw]*G[{yu^(-1)}, yw]*G[{0, 1}, yu^(-1)] + 
     2*G[{0}, yw]*G[{1}, yw]*G[{yu^(-1)}, yw]*G[{0, 1}, yu^(-1)] + 
     2*G[{1}, yu^(-1)]*G[{1}, yw]*G[{yu^(-1)}, yw]*G[{0, 1}, yu^(-1)] + 
     3*G[{1}, yv^(-1)]*G[{1}, yw]*G[{yu^(-1)}, yw]*G[{0, 1}, yu^(-1)] + 
     (G[{1}, yw]^2*G[{yu^(-1)}, yw]*G[{0, 1}, yu^(-1)])/2 + 
     (3*G[{0}, yu^(-1)]*G[{yu^(-1)}, yw]^2*G[{0, 1}, yu^(-1)])/2 + 
     (3*G[{0}, yv^(-1)]*G[{yu^(-1)}, yw]^2*G[{0, 1}, yu^(-1)])/2 - 
     (3*G[{0}, yw]*G[{yu^(-1)}, yw]^2*G[{0, 1}, yu^(-1)])/2 - 
     (3*G[{1}, yu^(-1)]*G[{yu^(-1)}, yw]^2*G[{0, 1}, yu^(-1)])/2 - 
     3*G[{1}, yv^(-1)]*G[{yu^(-1)}, yw]^2*G[{0, 1}, yu^(-1)] - 
     (3*G[{1}, yw]*G[{yu^(-1)}, yw]^2*G[{0, 1}, yu^(-1)])/2 + 
     G[{yu^(-1)}, yw]^3*G[{0, 1}, yu^(-1)] - 
     (Pi^2*G[{yu}, yv^(-1)]*G[{0, 1}, yu^(-1)])/3 + 
     G[{1}, yu^(-1)]^2*G[{yu}, yv^(-1)]*G[{0, 1}, yu^(-1)] + 
     G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*G[{yu}, yv^(-1)]*G[{0, 1}, yu^(-1)] + 
     (3*G[{1}, yv^(-1)]^2*G[{yu}, yv^(-1)]*G[{0, 1}, yu^(-1)])/2 - 
     2*G[{0}, yu^(-1)]*G[{1}, yw]*G[{yu}, yv^(-1)]*G[{0, 1}, yu^(-1)] - 
     2*G[{0}, yv^(-1)]*G[{1}, yw]*G[{yu}, yv^(-1)]*G[{0, 1}, yu^(-1)] + 
     2*G[{0}, yw]*G[{1}, yw]*G[{yu}, yv^(-1)]*G[{0, 1}, yu^(-1)] + 
     2*G[{1}, yu^(-1)]*G[{1}, yw]*G[{yu}, yv^(-1)]*G[{0, 1}, yu^(-1)] + 
     2*G[{1}, yv^(-1)]*G[{1}, yw]*G[{yu}, yv^(-1)]*G[{0, 1}, yu^(-1)] + 
     2*G[{0}, yu^(-1)]*G[{yu^(-1)}, yw]*G[{yu}, yv^(-1)]*G[{0, 1}, yu^(-1)] + 
     2*G[{0}, yv^(-1)]*G[{yu^(-1)}, yw]*G[{yu}, yv^(-1)]*G[{0, 1}, yu^(-1)] - 
     2*G[{0}, yw]*G[{yu^(-1)}, yw]*G[{yu}, yv^(-1)]*G[{0, 1}, yu^(-1)] - 
     4*G[{1}, yu^(-1)]*G[{yu^(-1)}, yw]*G[{yu}, yv^(-1)]*G[{0, 1}, yu^(-1)] - 
     3*G[{1}, yv^(-1)]*G[{yu^(-1)}, yw]*G[{yu}, yv^(-1)]*G[{0, 1}, yu^(-1)] - 
     G[{1}, yw]*G[{yu^(-1)}, yw]*G[{yu}, yv^(-1)]*G[{0, 1}, yu^(-1)] + 
     (3*G[{yu^(-1)}, yw]^2*G[{yu}, yv^(-1)]*G[{0, 1}, yu^(-1)])/2 - 
     (3*G[{1}, yu^(-1)]*G[{yu}, yv^(-1)]^2*G[{0, 1}, yu^(-1)])/2 - 
     (3*G[{1}, yv^(-1)]*G[{yu}, yv^(-1)]^2*G[{0, 1}, yu^(-1)])/2 + 
     (3*G[{yu^(-1)}, yw]*G[{yu}, yv^(-1)]^2*G[{0, 1}, yu^(-1)])/2 + 
     G[{yu}, yv^(-1)]^3*G[{0, 1}, yu^(-1)] - 
     (G[{0}, yu^(-1)]^2*G[{yv^(-1)}, yw]*G[{0, 1}, yu^(-1)])/2 - 
     G[{0}, yu^(-1)]*G[{0}, yv^(-1)]*G[{yv^(-1)}, yw]*G[{0, 1}, yu^(-1)] - 
     (G[{0}, yv^(-1)]^2*G[{yv^(-1)}, yw]*G[{0, 1}, yu^(-1)])/2 + 
     G[{0}, yu^(-1)]*G[{0}, yw]*G[{yv^(-1)}, yw]*G[{0, 1}, yu^(-1)] + 
     G[{0}, yv^(-1)]*G[{0}, yw]*G[{yv^(-1)}, yw]*G[{0, 1}, yu^(-1)] - 
     (G[{0}, yw]^2*G[{yv^(-1)}, yw]*G[{0, 1}, yu^(-1)])/2 - 
     G[{0}, yu^(-1)]*G[{1}, yu^(-1)]*G[{yv^(-1)}, yw]*G[{0, 1}, yu^(-1)] - 
     G[{0}, yv^(-1)]*G[{1}, yu^(-1)]*G[{yv^(-1)}, yw]*G[{0, 1}, yu^(-1)] + 
     G[{0}, yw]*G[{1}, yu^(-1)]*G[{yv^(-1)}, yw]*G[{0, 1}, yu^(-1)] + 
     (3*G[{1}, yu^(-1)]^2*G[{yv^(-1)}, yw]*G[{0, 1}, yu^(-1)])/2 - 
     G[{0}, yu^(-1)]*G[{1}, yv^(-1)]*G[{yv^(-1)}, yw]*G[{0, 1}, yu^(-1)] - 
     G[{0}, yv^(-1)]*G[{1}, yv^(-1)]*G[{yv^(-1)}, yw]*G[{0, 1}, yu^(-1)] + 
     G[{0}, yw]*G[{1}, yv^(-1)]*G[{yv^(-1)}, yw]*G[{0, 1}, yu^(-1)] + 
     2*G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*G[{yv^(-1)}, yw]*G[{0, 1}, yu^(-1)] + 
     (3*G[{1}, yv^(-1)]^2*G[{yv^(-1)}, yw]*G[{0, 1}, yu^(-1)])/2 - 
     2*G[{0}, yu^(-1)]*G[{1}, yw]*G[{yv^(-1)}, yw]*G[{0, 1}, yu^(-1)] - 
     2*G[{0}, yv^(-1)]*G[{1}, yw]*G[{yv^(-1)}, yw]*G[{0, 1}, yu^(-1)] + 
     2*G[{0}, yw]*G[{1}, yw]*G[{yv^(-1)}, yw]*G[{0, 1}, yu^(-1)] + 
     4*G[{1}, yu^(-1)]*G[{1}, yw]*G[{yv^(-1)}, yw]*G[{0, 1}, yu^(-1)] + 
     G[{1}, yw]^2*G[{yv^(-1)}, yw]*G[{0, 1}, yu^(-1)] + 
     G[{0}, yu^(-1)]*G[{yu^(-1)}, yw]*G[{yv^(-1)}, yw]*G[{0, 1}, yu^(-1)] + 
     G[{0}, yv^(-1)]*G[{yu^(-1)}, yw]*G[{yv^(-1)}, yw]*G[{0, 1}, yu^(-1)] - 
     G[{0}, yw]*G[{yu^(-1)}, yw]*G[{yv^(-1)}, yw]*G[{0, 1}, yu^(-1)] - 
     3*G[{1}, yu^(-1)]*G[{yu^(-1)}, yw]*G[{yv^(-1)}, yw]*G[{0, 1}, yu^(-1)] - 
     3*G[{1}, yv^(-1)]*G[{yu^(-1)}, yw]*G[{yv^(-1)}, yw]*G[{0, 1}, yu^(-1)] - 
     4*G[{1}, yw]*G[{yu^(-1)}, yw]*G[{yv^(-1)}, yw]*G[{0, 1}, yu^(-1)] + 
     (3*G[{yu^(-1)}, yw]^2*G[{yv^(-1)}, yw]*G[{0, 1}, yu^(-1)])/2 + 
     2*G[{0}, yu^(-1)]*G[{yu}, yv^(-1)]*G[{yv^(-1)}, yw]*G[{0, 1}, yu^(-1)] + 
     2*G[{0}, yv^(-1)]*G[{yu}, yv^(-1)]*G[{yv^(-1)}, yw]*G[{0, 1}, yu^(-1)] - 
     2*G[{0}, yw]*G[{yu}, yv^(-1)]*G[{yv^(-1)}, yw]*G[{0, 1}, yu^(-1)] - 
     3*G[{1}, yu^(-1)]*G[{yu}, yv^(-1)]*G[{yv^(-1)}, yw]*G[{0, 1}, yu^(-1)] - 
     4*G[{1}, yv^(-1)]*G[{yu}, yv^(-1)]*G[{yv^(-1)}, yw]*G[{0, 1}, yu^(-1)] + 
     4*G[{yu^(-1)}, yw]*G[{yu}, yv^(-1)]*G[{yv^(-1)}, yw]*
      G[{0, 1}, yu^(-1)] + (3*G[{yu}, yv^(-1)]^2*G[{yv^(-1)}, yw]*
       G[{0, 1}, yu^(-1)])/2 + (3*G[{0}, yu^(-1)]*G[{yv^(-1)}, yw]^2*
       G[{0, 1}, yu^(-1)])/2 + (3*G[{0}, yv^(-1)]*G[{yv^(-1)}, yw]^2*
       G[{0, 1}, yu^(-1)])/2 - (3*G[{0}, yw]*G[{yv^(-1)}, yw]^2*
       G[{0, 1}, yu^(-1)])/2 - 3*G[{1}, yu^(-1)]*G[{yv^(-1)}, yw]^2*
      G[{0, 1}, yu^(-1)] - (3*G[{1}, yv^(-1)]*G[{yv^(-1)}, yw]^2*
       G[{0, 1}, yu^(-1)])/2 - (3*G[{1}, yw]*G[{yv^(-1)}, yw]^2*
       G[{0, 1}, yu^(-1)])/2 + (3*G[{yu^(-1)}, yw]*G[{yv^(-1)}, yw]^2*
       G[{0, 1}, yu^(-1)])/2 + (3*G[{yu}, yv^(-1)]*G[{yv^(-1)}, yw]^2*
       G[{0, 1}, yu^(-1)])/2 + G[{yv^(-1)}, yw]^3*G[{0, 1}, yu^(-1)] + 
     (G[{0}, yu^(-1)]^2*G[{1/(yu*yv)}, yw]*G[{0, 1}, yu^(-1)])/2 + 
     G[{0}, yu^(-1)]*G[{0}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, 1}, yu^(-1)] + 
     (G[{0}, yv^(-1)]^2*G[{1/(yu*yv)}, yw]*G[{0, 1}, yu^(-1)])/2 - 
     G[{0}, yu^(-1)]*G[{0}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1}, yu^(-1)] - 
     G[{0}, yv^(-1)]*G[{0}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1}, yu^(-1)] + 
     (G[{0}, yw]^2*G[{1/(yu*yv)}, yw]*G[{0, 1}, yu^(-1)])/2 + 
     G[{0}, yu^(-1)]*G[{1}, yu^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, 1}, yu^(-1)] + 
     G[{0}, yv^(-1)]*G[{1}, yu^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, 1}, yu^(-1)] - 
     G[{0}, yw]*G[{1}, yu^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, 1}, yu^(-1)] - 
     (3*G[{1}, yu^(-1)]^2*G[{1/(yu*yv)}, yw]*G[{0, 1}, yu^(-1)])/2 + 
     G[{0}, yu^(-1)]*G[{1}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, 1}, yu^(-1)] + 
     G[{0}, yv^(-1)]*G[{1}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, 1}, yu^(-1)] - 
     G[{0}, yw]*G[{1}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, 1}, yu^(-1)] - 
     4*G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*G[{1/(yu*yv)}, yw]*
      G[{0, 1}, yu^(-1)] - 2*G[{1}, yv^(-1)]^2*G[{1/(yu*yv)}, yw]*
      G[{0, 1}, yu^(-1)] + 4*G[{0}, yu^(-1)]*G[{1}, yw]*G[{1/(yu*yv)}, yw]*
      G[{0, 1}, yu^(-1)] + 4*G[{0}, yv^(-1)]*G[{1}, yw]*G[{1/(yu*yv)}, yw]*
      G[{0, 1}, yu^(-1)] - 4*G[{0}, yw]*G[{1}, yw]*G[{1/(yu*yv)}, yw]*
      G[{0, 1}, yu^(-1)] - 6*G[{1}, yu^(-1)]*G[{1}, yw]*G[{1/(yu*yv)}, yw]*
      G[{0, 1}, yu^(-1)] - 3*G[{1}, yv^(-1)]*G[{1}, yw]*G[{1/(yu*yv)}, yw]*
      G[{0, 1}, yu^(-1)] - (3*G[{1}, yw]^2*G[{1/(yu*yv)}, yw]*
       G[{0, 1}, yu^(-1)])/2 - 3*G[{0}, yu^(-1)]*G[{yu^(-1)}, yw]*
      G[{1/(yu*yv)}, yw]*G[{0, 1}, yu^(-1)] - 3*G[{0}, yv^(-1)]*
      G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1}, yu^(-1)] + 
     3*G[{0}, yw]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1}, yu^(-1)] + 
     5*G[{1}, yu^(-1)]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*
      G[{0, 1}, yu^(-1)] + 6*G[{1}, yv^(-1)]*G[{yu^(-1)}, yw]*
      G[{1/(yu*yv)}, yw]*G[{0, 1}, yu^(-1)] + 5*G[{1}, yw]*G[{yu^(-1)}, yw]*
      G[{1/(yu*yv)}, yw]*G[{0, 1}, yu^(-1)] - 3*G[{yu^(-1)}, yw]^2*
      G[{1/(yu*yv)}, yw]*G[{0, 1}, yu^(-1)] - 2*G[{0}, yu^(-1)]*
      G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, 1}, yu^(-1)] - 
     2*G[{0}, yv^(-1)]*G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw]*
      G[{0, 1}, yu^(-1)] + 2*G[{0}, yw]*G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw]*
      G[{0, 1}, yu^(-1)] + 5*G[{1}, yu^(-1)]*G[{yu}, yv^(-1)]*
      G[{1/(yu*yv)}, yw]*G[{0, 1}, yu^(-1)] + 5*G[{1}, yv^(-1)]*
      G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, 1}, yu^(-1)] + 
     G[{1}, yw]*G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, 1}, yu^(-1)] - 
     5*G[{yu^(-1)}, yw]*G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw]*
      G[{0, 1}, yu^(-1)] - 3*G[{yu}, yv^(-1)]^2*G[{1/(yu*yv)}, yw]*
      G[{0, 1}, yu^(-1)] - 3*G[{0}, yu^(-1)]*G[{yv^(-1)}, yw]*
      G[{1/(yu*yv)}, yw]*G[{0, 1}, yu^(-1)] - 3*G[{0}, yv^(-1)]*
      G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1}, yu^(-1)] + 
     3*G[{0}, yw]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1}, yu^(-1)] + 
     6*G[{1}, yu^(-1)]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*
      G[{0, 1}, yu^(-1)] + 5*G[{1}, yv^(-1)]*G[{yv^(-1)}, yw]*
      G[{1/(yu*yv)}, yw]*G[{0, 1}, yu^(-1)] + 5*G[{1}, yw]*G[{yv^(-1)}, yw]*
      G[{1/(yu*yv)}, yw]*G[{0, 1}, yu^(-1)] - 5*G[{yu^(-1)}, yw]*
      G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1}, yu^(-1)] - 
     5*G[{yu}, yv^(-1)]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*
      G[{0, 1}, yu^(-1)] - 3*G[{yv^(-1)}, yw]^2*G[{1/(yu*yv)}, yw]*
      G[{0, 1}, yu^(-1)] + G[{0}, yu^(-1)]*G[{1/(yu*yv)}, yw]^2*
      G[{0, 1}, yu^(-1)] + G[{0}, yv^(-1)]*G[{1/(yu*yv)}, yw]^2*
      G[{0, 1}, yu^(-1)] - G[{0}, yw]*G[{1/(yu*yv)}, yw]^2*
      G[{0, 1}, yu^(-1)] - (3*G[{1}, yu^(-1)]*G[{1/(yu*yv)}, yw]^2*
       G[{0, 1}, yu^(-1)])/2 - 3*G[{1}, yv^(-1)]*G[{1/(yu*yv)}, yw]^2*
      G[{0, 1}, yu^(-1)] - (3*G[{1}, yw]*G[{1/(yu*yv)}, yw]^2*
       G[{0, 1}, yu^(-1)])/2 + 2*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2*
      G[{0, 1}, yu^(-1)] + (5*G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw]^2*
       G[{0, 1}, yu^(-1)])/2 + (5*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2*
       G[{0, 1}, yu^(-1)])/2 - (G[{1/(yu*yv)}, yw]^3*G[{0, 1}, yu^(-1)])/3 - 
     (G[{1}, yv^(-1)]*G[{0, 1}, yu^(-1)]^2)/2 - 
     G[{1}, yw]*G[{0, 1}, yu^(-1)]^2 + G[{yu^(-1)}, yw]*
      G[{0, 1}, yu^(-1)]^2 + (G[{yu}, yv^(-1)]*G[{0, 1}, yu^(-1)]^2)/2 + 
     (3*G[{yv^(-1)}, yw]*G[{0, 1}, yu^(-1)]^2)/2 - 
     (3*G[{1/(yu*yv)}, yw]*G[{0, 1}, yu^(-1)]^2)/2 - 
     (Pi^2*G[{1}, yu^(-1)]*G[{0, 1}, yv^(-1)])/3 + 
     (G[{1}, yu^(-1)]^2*G[{1}, yv^(-1)]*G[{0, 1}, yv^(-1)])/2 - 
     (Pi^2*G[{1}, yw]*G[{0, 1}, yv^(-1)])/3 + 
     (G[{0}, yu^(-1)]^2*G[{1}, yw]*G[{0, 1}, yv^(-1)])/2 + 
     G[{0}, yu^(-1)]*G[{0}, yv^(-1)]*G[{1}, yw]*G[{0, 1}, yv^(-1)] + 
     (G[{0}, yv^(-1)]^2*G[{1}, yw]*G[{0, 1}, yv^(-1)])/2 - 
     G[{0}, yu^(-1)]*G[{0}, yw]*G[{1}, yw]*G[{0, 1}, yv^(-1)] - 
     G[{0}, yv^(-1)]*G[{0}, yw]*G[{1}, yw]*G[{0, 1}, yv^(-1)] + 
     (G[{0}, yw]^2*G[{1}, yw]*G[{0, 1}, yv^(-1)])/2 + 
     G[{0}, yu^(-1)]*G[{1}, yu^(-1)]*G[{1}, yw]*G[{0, 1}, yv^(-1)] + 
     G[{0}, yv^(-1)]*G[{1}, yu^(-1)]*G[{1}, yw]*G[{0, 1}, yv^(-1)] - 
     G[{0}, yw]*G[{1}, yu^(-1)]*G[{1}, yw]*G[{0, 1}, yv^(-1)] - 
     (3*G[{1}, yu^(-1)]^2*G[{1}, yw]*G[{0, 1}, yv^(-1)])/2 + 
     G[{0}, yu^(-1)]*G[{1}, yv^(-1)]*G[{1}, yw]*G[{0, 1}, yv^(-1)] + 
     G[{0}, yv^(-1)]*G[{1}, yv^(-1)]*G[{1}, yw]*G[{0, 1}, yv^(-1)] - 
     G[{0}, yw]*G[{1}, yv^(-1)]*G[{1}, yw]*G[{0, 1}, yv^(-1)] - 
     3*G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*G[{1}, yw]*G[{0, 1}, yv^(-1)] - 
     (G[{1}, yv^(-1)]^2*G[{1}, yw]*G[{0, 1}, yv^(-1)])/2 - 
     (G[{0}, yu^(-1)]^2*G[{yu^(-1)}, yw]*G[{0, 1}, yv^(-1)])/2 - 
     G[{0}, yu^(-1)]*G[{0}, yv^(-1)]*G[{yu^(-1)}, yw]*G[{0, 1}, yv^(-1)] - 
     (G[{0}, yv^(-1)]^2*G[{yu^(-1)}, yw]*G[{0, 1}, yv^(-1)])/2 + 
     G[{0}, yu^(-1)]*G[{0}, yw]*G[{yu^(-1)}, yw]*G[{0, 1}, yv^(-1)] + 
     G[{0}, yv^(-1)]*G[{0}, yw]*G[{yu^(-1)}, yw]*G[{0, 1}, yv^(-1)] - 
     (G[{0}, yw]^2*G[{yu^(-1)}, yw]*G[{0, 1}, yv^(-1)])/2 - 
     G[{0}, yu^(-1)]*G[{1}, yu^(-1)]*G[{yu^(-1)}, yw]*G[{0, 1}, yv^(-1)] - 
     G[{0}, yv^(-1)]*G[{1}, yu^(-1)]*G[{yu^(-1)}, yw]*G[{0, 1}, yv^(-1)] + 
     G[{0}, yw]*G[{1}, yu^(-1)]*G[{yu^(-1)}, yw]*G[{0, 1}, yv^(-1)] + 
     (3*G[{1}, yu^(-1)]^2*G[{yu^(-1)}, yw]*G[{0, 1}, yv^(-1)])/2 - 
     G[{0}, yu^(-1)]*G[{1}, yv^(-1)]*G[{yu^(-1)}, yw]*G[{0, 1}, yv^(-1)] - 
     G[{0}, yv^(-1)]*G[{1}, yv^(-1)]*G[{yu^(-1)}, yw]*G[{0, 1}, yv^(-1)] + 
     G[{0}, yw]*G[{1}, yv^(-1)]*G[{yu^(-1)}, yw]*G[{0, 1}, yv^(-1)] + 
     5*G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*G[{yu^(-1)}, yw]*G[{0, 1}, yv^(-1)] + 
     (3*G[{1}, yv^(-1)]^2*G[{yu^(-1)}, yw]*G[{0, 1}, yv^(-1)])/2 - 
     2*G[{0}, yu^(-1)]*G[{1}, yw]*G[{yu^(-1)}, yw]*G[{0, 1}, yv^(-1)] - 
     2*G[{0}, yv^(-1)]*G[{1}, yw]*G[{yu^(-1)}, yw]*G[{0, 1}, yv^(-1)] + 
     2*G[{0}, yw]*G[{1}, yw]*G[{yu^(-1)}, yw]*G[{0, 1}, yv^(-1)] + 
     2*G[{1}, yu^(-1)]*G[{1}, yw]*G[{yu^(-1)}, yw]*G[{0, 1}, yv^(-1)] + 
     4*G[{1}, yv^(-1)]*G[{1}, yw]*G[{yu^(-1)}, yw]*G[{0, 1}, yv^(-1)] + 
     G[{1}, yw]^2*G[{yu^(-1)}, yw]*G[{0, 1}, yv^(-1)] + 
     (3*G[{0}, yu^(-1)]*G[{yu^(-1)}, yw]^2*G[{0, 1}, yv^(-1)])/2 + 
     (3*G[{0}, yv^(-1)]*G[{yu^(-1)}, yw]^2*G[{0, 1}, yv^(-1)])/2 - 
     (3*G[{0}, yw]*G[{yu^(-1)}, yw]^2*G[{0, 1}, yv^(-1)])/2 - 
     (3*G[{1}, yu^(-1)]*G[{yu^(-1)}, yw]^2*G[{0, 1}, yv^(-1)])/2 - 
     3*G[{1}, yv^(-1)]*G[{yu^(-1)}, yw]^2*G[{0, 1}, yv^(-1)] - 
     (3*G[{1}, yw]*G[{yu^(-1)}, yw]^2*G[{0, 1}, yv^(-1)])/2 + 
     G[{yu^(-1)}, yw]^3*G[{0, 1}, yv^(-1)] - 
     (Pi^2*G[{yu}, yv^(-1)]*G[{0, 1}, yv^(-1)])/3 - 
     (G[{1}, yu^(-1)]^2*G[{yu}, yv^(-1)]*G[{0, 1}, yv^(-1)])/2 + 
     2*G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*G[{yu}, yv^(-1)]*G[{0, 1}, yv^(-1)] + 
     G[{1}, yv^(-1)]^2*G[{yu}, yv^(-1)]*G[{0, 1}, yv^(-1)] - 
     2*G[{0}, yu^(-1)]*G[{1}, yw]*G[{yu}, yv^(-1)]*G[{0, 1}, yv^(-1)] - 
     2*G[{0}, yv^(-1)]*G[{1}, yw]*G[{yu}, yv^(-1)]*G[{0, 1}, yv^(-1)] + 
     2*G[{0}, yw]*G[{1}, yw]*G[{yu}, yv^(-1)]*G[{0, 1}, yv^(-1)] + 
     2*G[{1}, yu^(-1)]*G[{1}, yw]*G[{yu}, yv^(-1)]*G[{0, 1}, yv^(-1)] + 
     2*G[{1}, yv^(-1)]*G[{1}, yw]*G[{yu}, yv^(-1)]*G[{0, 1}, yv^(-1)] + 
     2*G[{0}, yu^(-1)]*G[{yu^(-1)}, yw]*G[{yu}, yv^(-1)]*G[{0, 1}, yv^(-1)] + 
     2*G[{0}, yv^(-1)]*G[{yu^(-1)}, yw]*G[{yu}, yv^(-1)]*G[{0, 1}, yv^(-1)] - 
     2*G[{0}, yw]*G[{yu^(-1)}, yw]*G[{yu}, yv^(-1)]*G[{0, 1}, yv^(-1)] - 
     4*G[{1}, yu^(-1)]*G[{yu^(-1)}, yw]*G[{yu}, yv^(-1)]*G[{0, 1}, yv^(-1)] - 
     3*G[{1}, yv^(-1)]*G[{yu^(-1)}, yw]*G[{yu}, yv^(-1)]*G[{0, 1}, yv^(-1)] + 
     (3*G[{yu^(-1)}, yw]^2*G[{yu}, yv^(-1)]*G[{0, 1}, yv^(-1)])/2 - 
     (3*G[{1}, yu^(-1)]*G[{yu}, yv^(-1)]^2*G[{0, 1}, yv^(-1)])/2 - 
     (3*G[{1}, yv^(-1)]*G[{yu}, yv^(-1)]^2*G[{0, 1}, yv^(-1)])/2 + 
     (3*G[{yu^(-1)}, yw]*G[{yu}, yv^(-1)]^2*G[{0, 1}, yv^(-1)])/2 + 
     G[{yu}, yv^(-1)]^3*G[{0, 1}, yv^(-1)] + 
     (Pi^2*G[{yv^(-1)}, yw]*G[{0, 1}, yv^(-1)])/3 - 
     (G[{0}, yu^(-1)]^2*G[{yv^(-1)}, yw]*G[{0, 1}, yv^(-1)])/2 - 
     G[{0}, yu^(-1)]*G[{0}, yv^(-1)]*G[{yv^(-1)}, yw]*G[{0, 1}, yv^(-1)] - 
     (G[{0}, yv^(-1)]^2*G[{yv^(-1)}, yw]*G[{0, 1}, yv^(-1)])/2 + 
     G[{0}, yu^(-1)]*G[{0}, yw]*G[{yv^(-1)}, yw]*G[{0, 1}, yv^(-1)] + 
     G[{0}, yv^(-1)]*G[{0}, yw]*G[{yv^(-1)}, yw]*G[{0, 1}, yv^(-1)] - 
     (G[{0}, yw]^2*G[{yv^(-1)}, yw]*G[{0, 1}, yv^(-1)])/2 - 
     G[{0}, yu^(-1)]*G[{1}, yu^(-1)]*G[{yv^(-1)}, yw]*G[{0, 1}, yv^(-1)] - 
     G[{0}, yv^(-1)]*G[{1}, yu^(-1)]*G[{yv^(-1)}, yw]*G[{0, 1}, yv^(-1)] + 
     G[{0}, yw]*G[{1}, yu^(-1)]*G[{yv^(-1)}, yw]*G[{0, 1}, yv^(-1)] + 
     G[{1}, yu^(-1)]^2*G[{yv^(-1)}, yw]*G[{0, 1}, yv^(-1)] - 
     G[{0}, yu^(-1)]*G[{1}, yv^(-1)]*G[{yv^(-1)}, yw]*G[{0, 1}, yv^(-1)] - 
     G[{0}, yv^(-1)]*G[{1}, yv^(-1)]*G[{yv^(-1)}, yw]*G[{0, 1}, yv^(-1)] + 
     G[{0}, yw]*G[{1}, yv^(-1)]*G[{yv^(-1)}, yw]*G[{0, 1}, yv^(-1)] + 
     3*G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*G[{yv^(-1)}, yw]*G[{0, 1}, yv^(-1)] + 
     (G[{1}, yv^(-1)]^2*G[{yv^(-1)}, yw]*G[{0, 1}, yv^(-1)])/2 - 
     2*G[{0}, yu^(-1)]*G[{1}, yw]*G[{yv^(-1)}, yw]*G[{0, 1}, yv^(-1)] - 
     2*G[{0}, yv^(-1)]*G[{1}, yw]*G[{yv^(-1)}, yw]*G[{0, 1}, yv^(-1)] + 
     2*G[{0}, yw]*G[{1}, yw]*G[{yv^(-1)}, yw]*G[{0, 1}, yv^(-1)] + 
     3*G[{1}, yu^(-1)]*G[{1}, yw]*G[{yv^(-1)}, yw]*G[{0, 1}, yv^(-1)] + 
     2*G[{1}, yv^(-1)]*G[{1}, yw]*G[{yv^(-1)}, yw]*G[{0, 1}, yv^(-1)] + 
     (G[{1}, yw]^2*G[{yv^(-1)}, yw]*G[{0, 1}, yv^(-1)])/2 + 
     G[{0}, yu^(-1)]*G[{yu^(-1)}, yw]*G[{yv^(-1)}, yw]*G[{0, 1}, yv^(-1)] + 
     G[{0}, yv^(-1)]*G[{yu^(-1)}, yw]*G[{yv^(-1)}, yw]*G[{0, 1}, yv^(-1)] - 
     G[{0}, yw]*G[{yu^(-1)}, yw]*G[{yv^(-1)}, yw]*G[{0, 1}, yv^(-1)] - 
     3*G[{1}, yu^(-1)]*G[{yu^(-1)}, yw]*G[{yv^(-1)}, yw]*G[{0, 1}, yv^(-1)] - 
     3*G[{1}, yv^(-1)]*G[{yu^(-1)}, yw]*G[{yv^(-1)}, yw]*G[{0, 1}, yv^(-1)] - 
     4*G[{1}, yw]*G[{yu^(-1)}, yw]*G[{yv^(-1)}, yw]*G[{0, 1}, yv^(-1)] + 
     (3*G[{yu^(-1)}, yw]^2*G[{yv^(-1)}, yw]*G[{0, 1}, yv^(-1)])/2 + 
     2*G[{0}, yu^(-1)]*G[{yu}, yv^(-1)]*G[{yv^(-1)}, yw]*G[{0, 1}, yv^(-1)] + 
     2*G[{0}, yv^(-1)]*G[{yu}, yv^(-1)]*G[{yv^(-1)}, yw]*G[{0, 1}, yv^(-1)] - 
     2*G[{0}, yw]*G[{yu}, yv^(-1)]*G[{yv^(-1)}, yw]*G[{0, 1}, yv^(-1)] - 
     3*G[{1}, yu^(-1)]*G[{yu}, yv^(-1)]*G[{yv^(-1)}, yw]*G[{0, 1}, yv^(-1)] - 
     4*G[{1}, yv^(-1)]*G[{yu}, yv^(-1)]*G[{yv^(-1)}, yw]*G[{0, 1}, yv^(-1)] - 
     G[{1}, yw]*G[{yu}, yv^(-1)]*G[{yv^(-1)}, yw]*G[{0, 1}, yv^(-1)] + 
     4*G[{yu^(-1)}, yw]*G[{yu}, yv^(-1)]*G[{yv^(-1)}, yw]*
      G[{0, 1}, yv^(-1)] + (3*G[{yu}, yv^(-1)]^2*G[{yv^(-1)}, yw]*
       G[{0, 1}, yv^(-1)])/2 + (3*G[{0}, yu^(-1)]*G[{yv^(-1)}, yw]^2*
       G[{0, 1}, yv^(-1)])/2 + (3*G[{0}, yv^(-1)]*G[{yv^(-1)}, yw]^2*
       G[{0, 1}, yv^(-1)])/2 - (3*G[{0}, yw]*G[{yv^(-1)}, yw]^2*
       G[{0, 1}, yv^(-1)])/2 - 3*G[{1}, yu^(-1)]*G[{yv^(-1)}, yw]^2*
      G[{0, 1}, yv^(-1)] - (3*G[{1}, yv^(-1)]*G[{yv^(-1)}, yw]^2*
       G[{0, 1}, yv^(-1)])/2 - (3*G[{1}, yw]*G[{yv^(-1)}, yw]^2*
       G[{0, 1}, yv^(-1)])/2 + (3*G[{yu^(-1)}, yw]*G[{yv^(-1)}, yw]^2*
       G[{0, 1}, yv^(-1)])/2 + (3*G[{yu}, yv^(-1)]*G[{yv^(-1)}, yw]^2*
       G[{0, 1}, yv^(-1)])/2 + G[{yv^(-1)}, yw]^3*G[{0, 1}, yv^(-1)] + 
     (G[{0}, yu^(-1)]^2*G[{1/(yu*yv)}, yw]*G[{0, 1}, yv^(-1)])/2 + 
     G[{0}, yu^(-1)]*G[{0}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, 1}, yv^(-1)] + 
     (G[{0}, yv^(-1)]^2*G[{1/(yu*yv)}, yw]*G[{0, 1}, yv^(-1)])/2 - 
     G[{0}, yu^(-1)]*G[{0}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1}, yv^(-1)] - 
     G[{0}, yv^(-1)]*G[{0}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1}, yv^(-1)] + 
     (G[{0}, yw]^2*G[{1/(yu*yv)}, yw]*G[{0, 1}, yv^(-1)])/2 + 
     G[{0}, yu^(-1)]*G[{1}, yu^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, 1}, yv^(-1)] + 
     G[{0}, yv^(-1)]*G[{1}, yu^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, 1}, yv^(-1)] - 
     G[{0}, yw]*G[{1}, yu^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, 1}, yv^(-1)] - 
     G[{1}, yu^(-1)]^2*G[{1/(yu*yv)}, yw]*G[{0, 1}, yv^(-1)] + 
     G[{0}, yu^(-1)]*G[{1}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, 1}, yv^(-1)] + 
     G[{0}, yv^(-1)]*G[{1}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, 1}, yv^(-1)] - 
     G[{0}, yw]*G[{1}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, 1}, yv^(-1)] - 
     5*G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*G[{1/(yu*yv)}, yw]*
      G[{0, 1}, yv^(-1)] - (3*G[{1}, yv^(-1)]^2*G[{1/(yu*yv)}, yw]*
       G[{0, 1}, yv^(-1)])/2 + 4*G[{0}, yu^(-1)]*G[{1}, yw]*
      G[{1/(yu*yv)}, yw]*G[{0, 1}, yv^(-1)] + 4*G[{0}, yv^(-1)]*G[{1}, yw]*
      G[{1/(yu*yv)}, yw]*G[{0, 1}, yv^(-1)] - 4*G[{0}, yw]*G[{1}, yw]*
      G[{1/(yu*yv)}, yw]*G[{0, 1}, yv^(-1)] - 5*G[{1}, yu^(-1)]*G[{1}, yw]*
      G[{1/(yu*yv)}, yw]*G[{0, 1}, yv^(-1)] - 6*G[{1}, yv^(-1)]*G[{1}, yw]*
      G[{1/(yu*yv)}, yw]*G[{0, 1}, yv^(-1)] - 
     (3*G[{1}, yw]^2*G[{1/(yu*yv)}, yw]*G[{0, 1}, yv^(-1)])/2 - 
     3*G[{0}, yu^(-1)]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*
      G[{0, 1}, yv^(-1)] - 3*G[{0}, yv^(-1)]*G[{yu^(-1)}, yw]*
      G[{1/(yu*yv)}, yw]*G[{0, 1}, yv^(-1)] + 3*G[{0}, yw]*G[{yu^(-1)}, yw]*
      G[{1/(yu*yv)}, yw]*G[{0, 1}, yv^(-1)] + 5*G[{1}, yu^(-1)]*
      G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1}, yv^(-1)] + 
     6*G[{1}, yv^(-1)]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*
      G[{0, 1}, yv^(-1)] + 5*G[{1}, yw]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*
      G[{0, 1}, yv^(-1)] - 3*G[{yu^(-1)}, yw]^2*G[{1/(yu*yv)}, yw]*
      G[{0, 1}, yv^(-1)] - 2*G[{0}, yu^(-1)]*G[{yu}, yv^(-1)]*
      G[{1/(yu*yv)}, yw]*G[{0, 1}, yv^(-1)] - 2*G[{0}, yv^(-1)]*
      G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, 1}, yv^(-1)] + 
     2*G[{0}, yw]*G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, 1}, yv^(-1)] + 
     5*G[{1}, yu^(-1)]*G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw]*
      G[{0, 1}, yv^(-1)] + 5*G[{1}, yv^(-1)]*G[{yu}, yv^(-1)]*
      G[{1/(yu*yv)}, yw]*G[{0, 1}, yv^(-1)] + G[{1}, yw]*G[{yu}, yv^(-1)]*
      G[{1/(yu*yv)}, yw]*G[{0, 1}, yv^(-1)] - 5*G[{yu^(-1)}, yw]*
      G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, 1}, yv^(-1)] - 
     3*G[{yu}, yv^(-1)]^2*G[{1/(yu*yv)}, yw]*G[{0, 1}, yv^(-1)] - 
     3*G[{0}, yu^(-1)]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*
      G[{0, 1}, yv^(-1)] - 3*G[{0}, yv^(-1)]*G[{yv^(-1)}, yw]*
      G[{1/(yu*yv)}, yw]*G[{0, 1}, yv^(-1)] + 3*G[{0}, yw]*G[{yv^(-1)}, yw]*
      G[{1/(yu*yv)}, yw]*G[{0, 1}, yv^(-1)] + 6*G[{1}, yu^(-1)]*
      G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1}, yv^(-1)] + 
     5*G[{1}, yv^(-1)]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*
      G[{0, 1}, yv^(-1)] + 5*G[{1}, yw]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*
      G[{0, 1}, yv^(-1)] - 5*G[{yu^(-1)}, yw]*G[{yv^(-1)}, yw]*
      G[{1/(yu*yv)}, yw]*G[{0, 1}, yv^(-1)] - 5*G[{yu}, yv^(-1)]*
      G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1}, yv^(-1)] - 
     3*G[{yv^(-1)}, yw]^2*G[{1/(yu*yv)}, yw]*G[{0, 1}, yv^(-1)] + 
     G[{0}, yu^(-1)]*G[{1/(yu*yv)}, yw]^2*G[{0, 1}, yv^(-1)] + 
     G[{0}, yv^(-1)]*G[{1/(yu*yv)}, yw]^2*G[{0, 1}, yv^(-1)] - 
     G[{0}, yw]*G[{1/(yu*yv)}, yw]^2*G[{0, 1}, yv^(-1)] - 
     2*G[{1}, yu^(-1)]*G[{1/(yu*yv)}, yw]^2*G[{0, 1}, yv^(-1)] - 
     (3*G[{1}, yv^(-1)]*G[{1/(yu*yv)}, yw]^2*G[{0, 1}, yv^(-1)])/2 - 
     (3*G[{1}, yw]*G[{1/(yu*yv)}, yw]^2*G[{0, 1}, yv^(-1)])/2 + 
     (5*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2*G[{0, 1}, yv^(-1)])/2 + 
     (5*G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw]^2*G[{0, 1}, yv^(-1)])/2 + 
     2*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2*G[{0, 1}, yv^(-1)] - 
     (G[{1/(yu*yv)}, yw]^3*G[{0, 1}, yv^(-1)])/3 - 
     2*G[{1}, yu^(-1)]*G[{0, 1}, yu^(-1)]*G[{0, 1}, yv^(-1)] - 
     2*G[{1}, yw]*G[{0, 1}, yu^(-1)]*G[{0, 1}, yv^(-1)] + 
     2*G[{yu^(-1)}, yw]*G[{0, 1}, yu^(-1)]*G[{0, 1}, yv^(-1)] + 
     2*G[{yv^(-1)}, yw]*G[{0, 1}, yu^(-1)]*G[{0, 1}, yv^(-1)] - 
     2*G[{1/(yu*yv)}, yw]*G[{0, 1}, yu^(-1)]*G[{0, 1}, yv^(-1)] - 
     G[{1}, yu^(-1)]*G[{0, 1}, yv^(-1)]^2 - G[{1}, yw]*G[{0, 1}, yv^(-1)]^2 + 
     (3*G[{yu^(-1)}, yw]*G[{0, 1}, yv^(-1)]^2)/2 + 
     (G[{yu}, yv^(-1)]*G[{0, 1}, yv^(-1)]^2)/2 + G[{yv^(-1)}, yw]*
      G[{0, 1}, yv^(-1)]^2 - (3*G[{1/(yu*yv)}, yw]*G[{0, 1}, yv^(-1)]^2)/2 + 
     (Pi^2*G[{1}, yu^(-1)]*G[{0, 1}, yw])/3 + 
     (Pi^2*G[{1}, yv^(-1)]*G[{0, 1}, yw])/3 + G[{0}, yu^(-1)]*G[{1}, yu^(-1)]*
      G[{1}, yv^(-1)]*G[{0, 1}, yw] + G[{0}, yv^(-1)]*G[{1}, yu^(-1)]*
      G[{1}, yv^(-1)]*G[{0, 1}, yw] - G[{0}, yw]*G[{1}, yu^(-1)]*
      G[{1}, yv^(-1)]*G[{0, 1}, yw] - (3*G[{1}, yu^(-1)]^2*G[{1}, yv^(-1)]*
       G[{0, 1}, yw])/2 - (5*Pi^2*G[{1}, yw]*G[{0, 1}, yw])/6 - 
     G[{0}, yu^(-1)]^2*G[{1}, yw]*G[{0, 1}, yw] - 
     2*G[{0}, yu^(-1)]*G[{0}, yv^(-1)]*G[{1}, yw]*G[{0, 1}, yw] - 
     G[{0}, yv^(-1)]^2*G[{1}, yw]*G[{0, 1}, yw] + 
     2*G[{0}, yu^(-1)]*G[{0}, yw]*G[{1}, yw]*G[{0, 1}, yw] + 
     2*G[{0}, yv^(-1)]*G[{0}, yw]*G[{1}, yw]*G[{0, 1}, yw] - 
     G[{0}, yw]^2*G[{1}, yw]*G[{0, 1}, yw] + 2*G[{0}, yu^(-1)]*
      G[{1}, yu^(-1)]*G[{1}, yw]*G[{0, 1}, yw] + 2*G[{0}, yv^(-1)]*
      G[{1}, yu^(-1)]*G[{1}, yw]*G[{0, 1}, yw] - 2*G[{0}, yw]*G[{1}, yu^(-1)]*
      G[{1}, yw]*G[{0, 1}, yw] - G[{1}, yu^(-1)]^2*G[{1}, yw]*G[{0, 1}, yw] + 
     2*G[{0}, yu^(-1)]*G[{1}, yv^(-1)]*G[{1}, yw]*G[{0, 1}, yw] + 
     2*G[{0}, yv^(-1)]*G[{1}, yv^(-1)]*G[{1}, yw]*G[{0, 1}, yw] - 
     2*G[{0}, yw]*G[{1}, yv^(-1)]*G[{1}, yw]*G[{0, 1}, yw] - 
     4*G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*G[{1}, yw]*G[{0, 1}, yw] - 
     G[{1}, yv^(-1)]^2*G[{1}, yw]*G[{0, 1}, yw] + 
     (G[{0}, yu^(-1)]*G[{1}, yw]^2*G[{0, 1}, yw])/2 + 
     (G[{0}, yv^(-1)]*G[{1}, yw]^2*G[{0, 1}, yw])/2 - 
     (G[{0}, yw]*G[{1}, yw]^2*G[{0, 1}, yw])/2 - 
     (G[{1}, yu^(-1)]*G[{1}, yw]^2*G[{0, 1}, yw])/2 - 
     (G[{1}, yv^(-1)]*G[{1}, yw]^2*G[{0, 1}, yw])/2 + 
     (G[{1}, yw]^3*G[{0, 1}, yw])/3 + (Pi^2*G[{yu^(-1)}, yw]*G[{0, 1}, yw])/
      2 + G[{0}, yu^(-1)]^2*G[{yu^(-1)}, yw]*G[{0, 1}, yw] + 
     2*G[{0}, yu^(-1)]*G[{0}, yv^(-1)]*G[{yu^(-1)}, yw]*G[{0, 1}, yw] + 
     G[{0}, yv^(-1)]^2*G[{yu^(-1)}, yw]*G[{0, 1}, yw] - 
     2*G[{0}, yu^(-1)]*G[{0}, yw]*G[{yu^(-1)}, yw]*G[{0, 1}, yw] - 
     2*G[{0}, yv^(-1)]*G[{0}, yw]*G[{yu^(-1)}, yw]*G[{0, 1}, yw] + 
     G[{0}, yw]^2*G[{yu^(-1)}, yw]*G[{0, 1}, yw] - 
     2*G[{0}, yu^(-1)]*G[{1}, yu^(-1)]*G[{yu^(-1)}, yw]*G[{0, 1}, yw] - 
     2*G[{0}, yv^(-1)]*G[{1}, yu^(-1)]*G[{yu^(-1)}, yw]*G[{0, 1}, yw] + 
     2*G[{0}, yw]*G[{1}, yu^(-1)]*G[{yu^(-1)}, yw]*G[{0, 1}, yw] + 
     G[{1}, yu^(-1)]^2*G[{yu^(-1)}, yw]*G[{0, 1}, yw] - 
     3*G[{0}, yu^(-1)]*G[{1}, yv^(-1)]*G[{yu^(-1)}, yw]*G[{0, 1}, yw] - 
     3*G[{0}, yv^(-1)]*G[{1}, yv^(-1)]*G[{yu^(-1)}, yw]*G[{0, 1}, yw] + 
     3*G[{0}, yw]*G[{1}, yv^(-1)]*G[{yu^(-1)}, yw]*G[{0, 1}, yw] + 
     3*G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*G[{yu^(-1)}, yw]*G[{0, 1}, yw] + 
     (5*G[{1}, yv^(-1)]^2*G[{yu^(-1)}, yw]*G[{0, 1}, yw])/2 - 
     4*G[{0}, yu^(-1)]*G[{1}, yw]*G[{yu^(-1)}, yw]*G[{0, 1}, yw] - 
     4*G[{0}, yv^(-1)]*G[{1}, yw]*G[{yu^(-1)}, yw]*G[{0, 1}, yw] + 
     4*G[{0}, yw]*G[{1}, yw]*G[{yu^(-1)}, yw]*G[{0, 1}, yw] + 
     4*G[{1}, yu^(-1)]*G[{1}, yw]*G[{yu^(-1)}, yw]*G[{0, 1}, yw] + 
     3*G[{1}, yv^(-1)]*G[{1}, yw]*G[{yu^(-1)}, yw]*G[{0, 1}, yw] - 
     (3*G[{1}, yw]^2*G[{yu^(-1)}, yw]*G[{0, 1}, yw])/2 + 
     2*G[{0}, yu^(-1)]*G[{yu^(-1)}, yw]^2*G[{0, 1}, yw] + 
     2*G[{0}, yv^(-1)]*G[{yu^(-1)}, yw]^2*G[{0, 1}, yw] - 
     2*G[{0}, yw]*G[{yu^(-1)}, yw]^2*G[{0, 1}, yw] - 
     2*G[{1}, yu^(-1)]*G[{yu^(-1)}, yw]^2*G[{0, 1}, yw] - 
     (G[{1}, yv^(-1)]*G[{yu^(-1)}, yw]^2*G[{0, 1}, yw])/2 + 
     (3*G[{1}, yw]*G[{yu^(-1)}, yw]^2*G[{0, 1}, yw])/2 - 
     G[{yu^(-1)}, yw]^3*G[{0, 1}, yw] - (Pi^2*G[{yu}, yv^(-1)]*G[{0, 1}, yw])/
      3 - G[{0}, yu^(-1)]*G[{1}, yu^(-1)]*G[{yu}, yv^(-1)]*G[{0, 1}, yw] - 
     G[{0}, yv^(-1)]*G[{1}, yu^(-1)]*G[{yu}, yv^(-1)]*G[{0, 1}, yw] + 
     G[{0}, yw]*G[{1}, yu^(-1)]*G[{yu}, yv^(-1)]*G[{0, 1}, yw] + 
     (3*G[{1}, yu^(-1)]^2*G[{yu}, yv^(-1)]*G[{0, 1}, yw])/2 - 
     G[{0}, yu^(-1)]*G[{1}, yv^(-1)]*G[{yu}, yv^(-1)]*G[{0, 1}, yw] - 
     G[{0}, yv^(-1)]*G[{1}, yv^(-1)]*G[{yu}, yv^(-1)]*G[{0, 1}, yw] + 
     G[{0}, yw]*G[{1}, yv^(-1)]*G[{yu}, yv^(-1)]*G[{0, 1}, yw] - 
     2*G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*G[{yu}, yv^(-1)]*G[{0, 1}, yw] + 
     (3*G[{1}, yv^(-1)]^2*G[{yu}, yv^(-1)]*G[{0, 1}, yw])/2 + 
     2*G[{1}, yu^(-1)]*G[{1}, yw]*G[{yu}, yv^(-1)]*G[{0, 1}, yw] + 
     2*G[{1}, yv^(-1)]*G[{1}, yw]*G[{yu}, yv^(-1)]*G[{0, 1}, yw] + 
     G[{0}, yu^(-1)]*G[{yu^(-1)}, yw]*G[{yu}, yv^(-1)]*G[{0, 1}, yw] + 
     G[{0}, yv^(-1)]*G[{yu^(-1)}, yw]*G[{yu}, yv^(-1)]*G[{0, 1}, yw] - 
     G[{0}, yw]*G[{yu^(-1)}, yw]*G[{yu}, yv^(-1)]*G[{0, 1}, yw] - 
     G[{1}, yu^(-1)]*G[{yu^(-1)}, yw]*G[{yu}, yv^(-1)]*G[{0, 1}, yw] - 
     2*G[{1}, yv^(-1)]*G[{yu^(-1)}, yw]*G[{yu}, yv^(-1)]*G[{0, 1}, yw] + 
     G[{1}, yw]*G[{yu^(-1)}, yw]*G[{yu}, yv^(-1)]*G[{0, 1}, yw] - 
     (3*G[{yu^(-1)}, yw]^2*G[{yu}, yv^(-1)]*G[{0, 1}, yw])/2 + 
     G[{0}, yu^(-1)]*G[{yu}, yv^(-1)]^2*G[{0, 1}, yw] + 
     G[{0}, yv^(-1)]*G[{yu}, yv^(-1)]^2*G[{0, 1}, yw] - 
     G[{0}, yw]*G[{yu}, yv^(-1)]^2*G[{0, 1}, yw] + 
     (G[{1}, yu^(-1)]*G[{yu}, yv^(-1)]^2*G[{0, 1}, yw])/2 + 
     (G[{1}, yv^(-1)]*G[{yu}, yv^(-1)]^2*G[{0, 1}, yw])/2 - 
     2*G[{1}, yw]*G[{yu}, yv^(-1)]^2*G[{0, 1}, yw] + 
     (G[{yu^(-1)}, yw]*G[{yu}, yv^(-1)]^2*G[{0, 1}, yw])/2 - 
     G[{yu}, yv^(-1)]^3*G[{0, 1}, yw] + (Pi^2*G[{yv^(-1)}, yw]*G[{0, 1}, yw])/
      2 + G[{0}, yu^(-1)]^2*G[{yv^(-1)}, yw]*G[{0, 1}, yw] + 
     2*G[{0}, yu^(-1)]*G[{0}, yv^(-1)]*G[{yv^(-1)}, yw]*G[{0, 1}, yw] + 
     G[{0}, yv^(-1)]^2*G[{yv^(-1)}, yw]*G[{0, 1}, yw] - 
     2*G[{0}, yu^(-1)]*G[{0}, yw]*G[{yv^(-1)}, yw]*G[{0, 1}, yw] - 
     2*G[{0}, yv^(-1)]*G[{0}, yw]*G[{yv^(-1)}, yw]*G[{0, 1}, yw] + 
     G[{0}, yw]^2*G[{yv^(-1)}, yw]*G[{0, 1}, yw] - 
     3*G[{0}, yu^(-1)]*G[{1}, yu^(-1)]*G[{yv^(-1)}, yw]*G[{0, 1}, yw] - 
     3*G[{0}, yv^(-1)]*G[{1}, yu^(-1)]*G[{yv^(-1)}, yw]*G[{0, 1}, yw] + 
     3*G[{0}, yw]*G[{1}, yu^(-1)]*G[{yv^(-1)}, yw]*G[{0, 1}, yw] + 
     (5*G[{1}, yu^(-1)]^2*G[{yv^(-1)}, yw]*G[{0, 1}, yw])/2 - 
     2*G[{0}, yu^(-1)]*G[{1}, yv^(-1)]*G[{yv^(-1)}, yw]*G[{0, 1}, yw] - 
     2*G[{0}, yv^(-1)]*G[{1}, yv^(-1)]*G[{yv^(-1)}, yw]*G[{0, 1}, yw] + 
     2*G[{0}, yw]*G[{1}, yv^(-1)]*G[{yv^(-1)}, yw]*G[{0, 1}, yw] + 
     3*G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*G[{yv^(-1)}, yw]*G[{0, 1}, yw] + 
     G[{1}, yv^(-1)]^2*G[{yv^(-1)}, yw]*G[{0, 1}, yw] - 
     4*G[{0}, yu^(-1)]*G[{1}, yw]*G[{yv^(-1)}, yw]*G[{0, 1}, yw] - 
     4*G[{0}, yv^(-1)]*G[{1}, yw]*G[{yv^(-1)}, yw]*G[{0, 1}, yw] + 
     4*G[{0}, yw]*G[{1}, yw]*G[{yv^(-1)}, yw]*G[{0, 1}, yw] + 
     3*G[{1}, yu^(-1)]*G[{1}, yw]*G[{yv^(-1)}, yw]*G[{0, 1}, yw] + 
     4*G[{1}, yv^(-1)]*G[{1}, yw]*G[{yv^(-1)}, yw]*G[{0, 1}, yw] - 
     (3*G[{1}, yw]^2*G[{yv^(-1)}, yw]*G[{0, 1}, yw])/2 + 
     G[{0}, yu^(-1)]*G[{yu^(-1)}, yw]*G[{yv^(-1)}, yw]*G[{0, 1}, yw] + 
     G[{0}, yv^(-1)]*G[{yu^(-1)}, yw]*G[{yv^(-1)}, yw]*G[{0, 1}, yw] - 
     G[{0}, yw]*G[{yu^(-1)}, yw]*G[{yv^(-1)}, yw]*G[{0, 1}, yw] + 
     G[{1}, yu^(-1)]*G[{yu^(-1)}, yw]*G[{yv^(-1)}, yw]*G[{0, 1}, yw] + 
     G[{1}, yv^(-1)]*G[{yu^(-1)}, yw]*G[{yv^(-1)}, yw]*G[{0, 1}, yw] + 
     4*G[{1}, yw]*G[{yu^(-1)}, yw]*G[{yv^(-1)}, yw]*G[{0, 1}, yw] - 
     (3*G[{yu^(-1)}, yw]^2*G[{yv^(-1)}, yw]*G[{0, 1}, yw])/2 + 
     G[{0}, yu^(-1)]*G[{yu}, yv^(-1)]*G[{yv^(-1)}, yw]*G[{0, 1}, yw] + 
     G[{0}, yv^(-1)]*G[{yu}, yv^(-1)]*G[{yv^(-1)}, yw]*G[{0, 1}, yw] - 
     G[{0}, yw]*G[{yu}, yv^(-1)]*G[{yv^(-1)}, yw]*G[{0, 1}, yw] - 
     2*G[{1}, yu^(-1)]*G[{yu}, yv^(-1)]*G[{yv^(-1)}, yw]*G[{0, 1}, yw] - 
     G[{1}, yv^(-1)]*G[{yu}, yv^(-1)]*G[{yv^(-1)}, yw]*G[{0, 1}, yw] + 
     G[{1}, yw]*G[{yu}, yv^(-1)]*G[{yv^(-1)}, yw]*G[{0, 1}, yw] - 
     4*G[{yu^(-1)}, yw]*G[{yu}, yv^(-1)]*G[{yv^(-1)}, yw]*G[{0, 1}, yw] + 
     (G[{yu}, yv^(-1)]^2*G[{yv^(-1)}, yw]*G[{0, 1}, yw])/2 + 
     2*G[{0}, yu^(-1)]*G[{yv^(-1)}, yw]^2*G[{0, 1}, yw] + 
     2*G[{0}, yv^(-1)]*G[{yv^(-1)}, yw]^2*G[{0, 1}, yw] - 
     2*G[{0}, yw]*G[{yv^(-1)}, yw]^2*G[{0, 1}, yw] - 
     (G[{1}, yu^(-1)]*G[{yv^(-1)}, yw]^2*G[{0, 1}, yw])/2 - 
     2*G[{1}, yv^(-1)]*G[{yv^(-1)}, yw]^2*G[{0, 1}, yw] + 
     (3*G[{1}, yw]*G[{yv^(-1)}, yw]^2*G[{0, 1}, yw])/2 - 
     (3*G[{yu^(-1)}, yw]*G[{yv^(-1)}, yw]^2*G[{0, 1}, yw])/2 - 
     (3*G[{yu}, yv^(-1)]*G[{yv^(-1)}, yw]^2*G[{0, 1}, yw])/2 - 
     G[{yv^(-1)}, yw]^3*G[{0, 1}, yw] - 
     (Pi^2*G[{1/(yu*yv)}, yw]*G[{0, 1}, yw])/6 - G[{0}, yu^(-1)]^2*
      G[{1/(yu*yv)}, yw]*G[{0, 1}, yw] - 2*G[{0}, yu^(-1)]*G[{0}, yv^(-1)]*
      G[{1/(yu*yv)}, yw]*G[{0, 1}, yw] - G[{0}, yv^(-1)]^2*G[{1/(yu*yv)}, yw]*
      G[{0, 1}, yw] + 2*G[{0}, yu^(-1)]*G[{0}, yw]*G[{1/(yu*yv)}, yw]*
      G[{0, 1}, yw] + 2*G[{0}, yv^(-1)]*G[{0}, yw]*G[{1/(yu*yv)}, yw]*
      G[{0, 1}, yw] - G[{0}, yw]^2*G[{1/(yu*yv)}, yw]*G[{0, 1}, yw] + 
     3*G[{0}, yu^(-1)]*G[{1}, yu^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, 1}, yw] + 
     3*G[{0}, yv^(-1)]*G[{1}, yu^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, 1}, yw] - 
     3*G[{0}, yw]*G[{1}, yu^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, 1}, yw] - 
     (5*G[{1}, yu^(-1)]^2*G[{1/(yu*yv)}, yw]*G[{0, 1}, yw])/2 + 
     3*G[{0}, yu^(-1)]*G[{1}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, 1}, yw] + 
     3*G[{0}, yv^(-1)]*G[{1}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, 1}, yw] - 
     3*G[{0}, yw]*G[{1}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, 1}, yw] - 
     2*G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, 1}, yw] - 
     (5*G[{1}, yv^(-1)]^2*G[{1/(yu*yv)}, yw]*G[{0, 1}, yw])/2 + 
     7*G[{0}, yu^(-1)]*G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1}, yw] + 
     7*G[{0}, yv^(-1)]*G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1}, yw] - 
     7*G[{0}, yw]*G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1}, yw] - 
     6*G[{1}, yu^(-1)]*G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1}, yw] - 
     6*G[{1}, yv^(-1)]*G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1}, yw] + 
     2*G[{1}, yw]^2*G[{1/(yu*yv)}, yw]*G[{0, 1}, yw] - 
     4*G[{0}, yu^(-1)]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1}, yw] - 
     4*G[{0}, yv^(-1)]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1}, yw] + 
     4*G[{0}, yw]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1}, yw] + 
     2*G[{1}, yu^(-1)]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1}, yw] + 
     G[{1}, yv^(-1)]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1}, yw] - 
     5*G[{1}, yw]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1}, yw] + 
     3*G[{yu^(-1)}, yw]^2*G[{1/(yu*yv)}, yw]*G[{0, 1}, yw] - 
     2*G[{0}, yu^(-1)]*G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, 1}, yw] - 
     2*G[{0}, yv^(-1)]*G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, 1}, yw] + 
     2*G[{0}, yw]*G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, 1}, yw] + 
     G[{1}, yu^(-1)]*G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, 1}, yw] + 
     G[{1}, yv^(-1)]*G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, 1}, yw] - 
     2*G[{1}, yw]*G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, 1}, yw] + 
     5*G[{yu^(-1)}, yw]*G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, 1}, yw] + 
     G[{yu}, yv^(-1)]^2*G[{1/(yu*yv)}, yw]*G[{0, 1}, yw] - 
     4*G[{0}, yu^(-1)]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1}, yw] - 
     4*G[{0}, yv^(-1)]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1}, yw] + 
     4*G[{0}, yw]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1}, yw] + 
     G[{1}, yu^(-1)]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1}, yw] + 
     2*G[{1}, yv^(-1)]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1}, yw] - 
     5*G[{1}, yw]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1}, yw] + 
     5*G[{yu^(-1)}, yw]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1}, yw] + 
     5*G[{yu}, yv^(-1)]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1}, yw] + 
     3*G[{yv^(-1)}, yw]^2*G[{1/(yu*yv)}, yw]*G[{0, 1}, yw] + 
     (3*G[{0}, yu^(-1)]*G[{1/(yu*yv)}, yw]^2*G[{0, 1}, yw])/2 + 
     (3*G[{0}, yv^(-1)]*G[{1/(yu*yv)}, yw]^2*G[{0, 1}, yw])/2 - 
     (3*G[{0}, yw]*G[{1/(yu*yv)}, yw]^2*G[{0, 1}, yw])/2 - 
     (G[{1}, yu^(-1)]*G[{1/(yu*yv)}, yw]^2*G[{0, 1}, yw])/2 - 
     (G[{1}, yv^(-1)]*G[{1/(yu*yv)}, yw]^2*G[{0, 1}, yw])/2 + 
     3*G[{1}, yw]*G[{1/(yu*yv)}, yw]^2*G[{0, 1}, yw] - 
     (5*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2*G[{0, 1}, yw])/2 - 
     2*G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw]^2*G[{0, 1}, yw] - 
     (5*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2*G[{0, 1}, yw])/2 + 
     (G[{1/(yu*yv)}, yw]^3*G[{0, 1}, yw])/3 + G[{0}, yu^(-1)]*
      G[{0, 1}, yu^(-1)]*G[{0, 1}, yw] + G[{0}, yv^(-1)]*G[{0, 1}, yu^(-1)]*
      G[{0, 1}, yw] - G[{0}, yw]*G[{0, 1}, yu^(-1)]*G[{0, 1}, yw] + 
     G[{1}, yu^(-1)]*G[{0, 1}, yu^(-1)]*G[{0, 1}, yw] + 
     G[{1}, yv^(-1)]*G[{0, 1}, yu^(-1)]*G[{0, 1}, yw] - 
     2*G[{1}, yw]*G[{0, 1}, yu^(-1)]*G[{0, 1}, yw] - 
     2*G[{yu}, yv^(-1)]*G[{0, 1}, yu^(-1)]*G[{0, 1}, yw] + 
     2*G[{1/(yu*yv)}, yw]*G[{0, 1}, yu^(-1)]*G[{0, 1}, yw] + 
     G[{0}, yu^(-1)]*G[{0, 1}, yv^(-1)]*G[{0, 1}, yw] + 
     G[{0}, yv^(-1)]*G[{0, 1}, yv^(-1)]*G[{0, 1}, yw] - 
     G[{0}, yw]*G[{0, 1}, yv^(-1)]*G[{0, 1}, yw] + 
     G[{1}, yu^(-1)]*G[{0, 1}, yv^(-1)]*G[{0, 1}, yw] + 
     G[{1}, yv^(-1)]*G[{0, 1}, yv^(-1)]*G[{0, 1}, yw] - 
     2*G[{1}, yw]*G[{0, 1}, yv^(-1)]*G[{0, 1}, yw] - 
     2*G[{yu}, yv^(-1)]*G[{0, 1}, yv^(-1)]*G[{0, 1}, yw] + 
     2*G[{1/(yu*yv)}, yw]*G[{0, 1}, yv^(-1)]*G[{0, 1}, yw] + 
     G[{0}, yu^(-1)]*G[{0, 1}, yw]^2 + G[{0}, yv^(-1)]*G[{0, 1}, yw]^2 - 
     G[{0}, yw]*G[{0, 1}, yw]^2 - G[{1}, yu^(-1)]*G[{0, 1}, yw]^2 - 
     G[{1}, yv^(-1)]*G[{0, 1}, yw]^2 + (G[{1}, yw]*G[{0, 1}, yw]^2)/2 + 
     (G[{yu^(-1)}, yw]*G[{0, 1}, yw]^2)/2 + 
     (G[{yv^(-1)}, yw]*G[{0, 1}, yw]^2)/2 - 
     (3*G[{1/(yu*yv)}, yw]*G[{0, 1}, yw]^2)/2 - 
     (Pi^2*G[{1}, yu^(-1)]*G[{0, yu^(-1)}, yw])/3 - 
     (Pi^2*G[{1}, yv^(-1)]*G[{0, yu^(-1)}, yw])/3 - 
     G[{0}, yu^(-1)]*G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*G[{0, yu^(-1)}, yw] - 
     G[{0}, yv^(-1)]*G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*G[{0, yu^(-1)}, yw] + 
     G[{0}, yw]*G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*G[{0, yu^(-1)}, yw] + 
     (3*G[{1}, yu^(-1)]^2*G[{1}, yv^(-1)]*G[{0, yu^(-1)}, yw])/2 + 
     (Pi^2*G[{1}, yw]*G[{0, yu^(-1)}, yw])/2 + G[{0}, yu^(-1)]^2*G[{1}, yw]*
      G[{0, yu^(-1)}, yw] + 2*G[{0}, yu^(-1)]*G[{0}, yv^(-1)]*G[{1}, yw]*
      G[{0, yu^(-1)}, yw] + G[{0}, yv^(-1)]^2*G[{1}, yw]*
      G[{0, yu^(-1)}, yw] - 2*G[{0}, yu^(-1)]*G[{0}, yw]*G[{1}, yw]*
      G[{0, yu^(-1)}, yw] - 2*G[{0}, yv^(-1)]*G[{0}, yw]*G[{1}, yw]*
      G[{0, yu^(-1)}, yw] + G[{0}, yw]^2*G[{1}, yw]*G[{0, yu^(-1)}, yw] - 
     2*G[{0}, yu^(-1)]*G[{1}, yu^(-1)]*G[{1}, yw]*G[{0, yu^(-1)}, yw] - 
     2*G[{0}, yv^(-1)]*G[{1}, yu^(-1)]*G[{1}, yw]*G[{0, yu^(-1)}, yw] + 
     2*G[{0}, yw]*G[{1}, yu^(-1)]*G[{1}, yw]*G[{0, yu^(-1)}, yw] + 
     G[{1}, yu^(-1)]^2*G[{1}, yw]*G[{0, yu^(-1)}, yw] - 
     4*G[{0}, yu^(-1)]*G[{1}, yv^(-1)]*G[{1}, yw]*G[{0, yu^(-1)}, yw] - 
     4*G[{0}, yv^(-1)]*G[{1}, yv^(-1)]*G[{1}, yw]*G[{0, yu^(-1)}, yw] + 
     4*G[{0}, yw]*G[{1}, yv^(-1)]*G[{1}, yw]*G[{0, yu^(-1)}, yw] + 
     4*G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*G[{1}, yw]*G[{0, yu^(-1)}, yw] + 
     3*G[{1}, yv^(-1)]^2*G[{1}, yw]*G[{0, yu^(-1)}, yw] - 
     (G[{0}, yu^(-1)]*G[{1}, yw]^2*G[{0, yu^(-1)}, yw])/2 - 
     (G[{0}, yv^(-1)]*G[{1}, yw]^2*G[{0, yu^(-1)}, yw])/2 + 
     (G[{0}, yw]*G[{1}, yw]^2*G[{0, yu^(-1)}, yw])/2 + 
     (G[{1}, yu^(-1)]*G[{1}, yw]^2*G[{0, yu^(-1)}, yw])/2 + 
     (G[{1}, yv^(-1)]*G[{1}, yw]^2*G[{0, yu^(-1)}, yw])/2 - 
     (G[{1}, yw]^3*G[{0, yu^(-1)}, yw])/3 - 
     (Pi^2*G[{yu^(-1)}, yw]*G[{0, yu^(-1)}, yw])/6 - 
     G[{0}, yu^(-1)]^2*G[{yu^(-1)}, yw]*G[{0, yu^(-1)}, yw] - 
     2*G[{0}, yu^(-1)]*G[{0}, yv^(-1)]*G[{yu^(-1)}, yw]*G[{0, yu^(-1)}, yw] - 
     G[{0}, yv^(-1)]^2*G[{yu^(-1)}, yw]*G[{0, yu^(-1)}, yw] + 
     2*G[{0}, yu^(-1)]*G[{0}, yw]*G[{yu^(-1)}, yw]*G[{0, yu^(-1)}, yw] + 
     2*G[{0}, yv^(-1)]*G[{0}, yw]*G[{yu^(-1)}, yw]*G[{0, yu^(-1)}, yw] - 
     G[{0}, yw]^2*G[{yu^(-1)}, yw]*G[{0, yu^(-1)}, yw] + 
     2*G[{0}, yu^(-1)]*G[{1}, yu^(-1)]*G[{yu^(-1)}, yw]*G[{0, yu^(-1)}, yw] + 
     2*G[{0}, yv^(-1)]*G[{1}, yu^(-1)]*G[{yu^(-1)}, yw]*G[{0, yu^(-1)}, yw] - 
     2*G[{0}, yw]*G[{1}, yu^(-1)]*G[{yu^(-1)}, yw]*G[{0, yu^(-1)}, yw] - 
     G[{1}, yu^(-1)]^2*G[{yu^(-1)}, yw]*G[{0, yu^(-1)}, yw] + 
     5*G[{0}, yu^(-1)]*G[{1}, yv^(-1)]*G[{yu^(-1)}, yw]*G[{0, yu^(-1)}, yw] + 
     5*G[{0}, yv^(-1)]*G[{1}, yv^(-1)]*G[{yu^(-1)}, yw]*G[{0, yu^(-1)}, yw] - 
     5*G[{0}, yw]*G[{1}, yv^(-1)]*G[{yu^(-1)}, yw]*G[{0, yu^(-1)}, yw] - 
     3*G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*G[{yu^(-1)}, yw]*G[{0, yu^(-1)}, yw] - 
     (9*G[{1}, yv^(-1)]^2*G[{yu^(-1)}, yw]*G[{0, yu^(-1)}, yw])/2 + 
     4*G[{0}, yu^(-1)]*G[{1}, yw]*G[{yu^(-1)}, yw]*G[{0, yu^(-1)}, yw] + 
     4*G[{0}, yv^(-1)]*G[{1}, yw]*G[{yu^(-1)}, yw]*G[{0, yu^(-1)}, yw] - 
     4*G[{0}, yw]*G[{1}, yw]*G[{yu^(-1)}, yw]*G[{0, yu^(-1)}, yw] - 
     4*G[{1}, yu^(-1)]*G[{1}, yw]*G[{yu^(-1)}, yw]*G[{0, yu^(-1)}, yw] - 
     3*G[{1}, yv^(-1)]*G[{1}, yw]*G[{yu^(-1)}, yw]*G[{0, yu^(-1)}, yw] + 
     (3*G[{1}, yw]^2*G[{yu^(-1)}, yw]*G[{0, yu^(-1)}, yw])/2 - 
     2*G[{0}, yu^(-1)]*G[{yu^(-1)}, yw]^2*G[{0, yu^(-1)}, yw] - 
     2*G[{0}, yv^(-1)]*G[{yu^(-1)}, yw]^2*G[{0, yu^(-1)}, yw] + 
     2*G[{0}, yw]*G[{yu^(-1)}, yw]^2*G[{0, yu^(-1)}, yw] + 
     2*G[{1}, yu^(-1)]*G[{yu^(-1)}, yw]^2*G[{0, yu^(-1)}, yw] + 
     (G[{1}, yv^(-1)]*G[{yu^(-1)}, yw]^2*G[{0, yu^(-1)}, yw])/2 - 
     (3*G[{1}, yw]*G[{yu^(-1)}, yw]^2*G[{0, yu^(-1)}, yw])/2 + 
     G[{yu^(-1)}, yw]^3*G[{0, yu^(-1)}, yw] + 
     (Pi^2*G[{yu}, yv^(-1)]*G[{0, yu^(-1)}, yw])/3 + 
     G[{0}, yu^(-1)]*G[{1}, yu^(-1)]*G[{yu}, yv^(-1)]*G[{0, yu^(-1)}, yw] + 
     G[{0}, yv^(-1)]*G[{1}, yu^(-1)]*G[{yu}, yv^(-1)]*G[{0, yu^(-1)}, yw] - 
     G[{0}, yw]*G[{1}, yu^(-1)]*G[{yu}, yv^(-1)]*G[{0, yu^(-1)}, yw] - 
     (3*G[{1}, yu^(-1)]^2*G[{yu}, yv^(-1)]*G[{0, yu^(-1)}, yw])/2 + 
     G[{0}, yu^(-1)]*G[{1}, yv^(-1)]*G[{yu}, yv^(-1)]*G[{0, yu^(-1)}, yw] + 
     G[{0}, yv^(-1)]*G[{1}, yv^(-1)]*G[{yu}, yv^(-1)]*G[{0, yu^(-1)}, yw] - 
     G[{0}, yw]*G[{1}, yv^(-1)]*G[{yu}, yv^(-1)]*G[{0, yu^(-1)}, yw] + 
     2*G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*G[{yu}, yv^(-1)]*G[{0, yu^(-1)}, yw] - 
     (3*G[{1}, yv^(-1)]^2*G[{yu}, yv^(-1)]*G[{0, yu^(-1)}, yw])/2 + 
     2*G[{0}, yu^(-1)]*G[{1}, yw]*G[{yu}, yv^(-1)]*G[{0, yu^(-1)}, yw] + 
     2*G[{0}, yv^(-1)]*G[{1}, yw]*G[{yu}, yv^(-1)]*G[{0, yu^(-1)}, yw] - 
     2*G[{0}, yw]*G[{1}, yw]*G[{yu}, yv^(-1)]*G[{0, yu^(-1)}, yw] - 
     2*G[{1}, yu^(-1)]*G[{1}, yw]*G[{yu}, yv^(-1)]*G[{0, yu^(-1)}, yw] - 
     2*G[{1}, yv^(-1)]*G[{1}, yw]*G[{yu}, yv^(-1)]*G[{0, yu^(-1)}, yw] - 
     3*G[{0}, yu^(-1)]*G[{yu^(-1)}, yw]*G[{yu}, yv^(-1)]*
      G[{0, yu^(-1)}, yw] - 3*G[{0}, yv^(-1)]*G[{yu^(-1)}, yw]*
      G[{yu}, yv^(-1)]*G[{0, yu^(-1)}, yw] + 3*G[{0}, yw]*G[{yu^(-1)}, yw]*
      G[{yu}, yv^(-1)]*G[{0, yu^(-1)}, yw] + G[{1}, yu^(-1)]*G[{yu^(-1)}, yw]*
      G[{yu}, yv^(-1)]*G[{0, yu^(-1)}, yw] + 2*G[{1}, yv^(-1)]*
      G[{yu^(-1)}, yw]*G[{yu}, yv^(-1)]*G[{0, yu^(-1)}, yw] - 
     G[{1}, yw]*G[{yu^(-1)}, yw]*G[{yu}, yv^(-1)]*G[{0, yu^(-1)}, yw] + 
     (3*G[{yu^(-1)}, yw]^2*G[{yu}, yv^(-1)]*G[{0, yu^(-1)}, yw])/2 - 
     G[{0}, yu^(-1)]*G[{yu}, yv^(-1)]^2*G[{0, yu^(-1)}, yw] - 
     G[{0}, yv^(-1)]*G[{yu}, yv^(-1)]^2*G[{0, yu^(-1)}, yw] + 
     G[{0}, yw]*G[{yu}, yv^(-1)]^2*G[{0, yu^(-1)}, yw] - 
     (G[{1}, yu^(-1)]*G[{yu}, yv^(-1)]^2*G[{0, yu^(-1)}, yw])/2 - 
     (G[{1}, yv^(-1)]*G[{yu}, yv^(-1)]^2*G[{0, yu^(-1)}, yw])/2 + 
     (3*G[{yu^(-1)}, yw]*G[{yu}, yv^(-1)]^2*G[{0, yu^(-1)}, yw])/2 + 
     G[{yu}, yv^(-1)]^3*G[{0, yu^(-1)}, yw] - 
     (Pi^2*G[{yv^(-1)}, yw]*G[{0, yu^(-1)}, yw])/2 - 
     G[{0}, yu^(-1)]^2*G[{yv^(-1)}, yw]*G[{0, yu^(-1)}, yw] - 
     2*G[{0}, yu^(-1)]*G[{0}, yv^(-1)]*G[{yv^(-1)}, yw]*G[{0, yu^(-1)}, yw] - 
     G[{0}, yv^(-1)]^2*G[{yv^(-1)}, yw]*G[{0, yu^(-1)}, yw] + 
     2*G[{0}, yu^(-1)]*G[{0}, yw]*G[{yv^(-1)}, yw]*G[{0, yu^(-1)}, yw] + 
     2*G[{0}, yv^(-1)]*G[{0}, yw]*G[{yv^(-1)}, yw]*G[{0, yu^(-1)}, yw] - 
     G[{0}, yw]^2*G[{yv^(-1)}, yw]*G[{0, yu^(-1)}, yw] + 
     3*G[{0}, yu^(-1)]*G[{1}, yu^(-1)]*G[{yv^(-1)}, yw]*G[{0, yu^(-1)}, yw] + 
     3*G[{0}, yv^(-1)]*G[{1}, yu^(-1)]*G[{yv^(-1)}, yw]*G[{0, yu^(-1)}, yw] - 
     3*G[{0}, yw]*G[{1}, yu^(-1)]*G[{yv^(-1)}, yw]*G[{0, yu^(-1)}, yw] - 
     (5*G[{1}, yu^(-1)]^2*G[{yv^(-1)}, yw]*G[{0, yu^(-1)}, yw])/2 + 
     4*G[{0}, yu^(-1)]*G[{1}, yv^(-1)]*G[{yv^(-1)}, yw]*G[{0, yu^(-1)}, yw] + 
     4*G[{0}, yv^(-1)]*G[{1}, yv^(-1)]*G[{yv^(-1)}, yw]*G[{0, yu^(-1)}, yw] - 
     4*G[{0}, yw]*G[{1}, yv^(-1)]*G[{yv^(-1)}, yw]*G[{0, yu^(-1)}, yw] - 
     3*G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*G[{yv^(-1)}, yw]*G[{0, yu^(-1)}, yw] - 
     3*G[{1}, yv^(-1)]^2*G[{yv^(-1)}, yw]*G[{0, yu^(-1)}, yw] + 
     4*G[{0}, yu^(-1)]*G[{1}, yw]*G[{yv^(-1)}, yw]*G[{0, yu^(-1)}, yw] + 
     4*G[{0}, yv^(-1)]*G[{1}, yw]*G[{yv^(-1)}, yw]*G[{0, yu^(-1)}, yw] - 
     4*G[{0}, yw]*G[{1}, yw]*G[{yv^(-1)}, yw]*G[{0, yu^(-1)}, yw] - 
     3*G[{1}, yu^(-1)]*G[{1}, yw]*G[{yv^(-1)}, yw]*G[{0, yu^(-1)}, yw] - 
     4*G[{1}, yv^(-1)]*G[{1}, yw]*G[{yv^(-1)}, yw]*G[{0, yu^(-1)}, yw] + 
     (3*G[{1}, yw]^2*G[{yv^(-1)}, yw]*G[{0, yu^(-1)}, yw])/2 - 
     G[{0}, yu^(-1)]*G[{yu^(-1)}, yw]*G[{yv^(-1)}, yw]*G[{0, yu^(-1)}, yw] - 
     G[{0}, yv^(-1)]*G[{yu^(-1)}, yw]*G[{yv^(-1)}, yw]*G[{0, yu^(-1)}, yw] + 
     G[{0}, yw]*G[{yu^(-1)}, yw]*G[{yv^(-1)}, yw]*G[{0, yu^(-1)}, yw] - 
     G[{1}, yu^(-1)]*G[{yu^(-1)}, yw]*G[{yv^(-1)}, yw]*G[{0, yu^(-1)}, yw] - 
     G[{1}, yv^(-1)]*G[{yu^(-1)}, yw]*G[{yv^(-1)}, yw]*G[{0, yu^(-1)}, yw] - 
     4*G[{1}, yw]*G[{yu^(-1)}, yw]*G[{yv^(-1)}, yw]*G[{0, yu^(-1)}, yw] + 
     (3*G[{yu^(-1)}, yw]^2*G[{yv^(-1)}, yw]*G[{0, yu^(-1)}, yw])/2 - 
     3*G[{0}, yu^(-1)]*G[{yu}, yv^(-1)]*G[{yv^(-1)}, yw]*
      G[{0, yu^(-1)}, yw] - 3*G[{0}, yv^(-1)]*G[{yu}, yv^(-1)]*
      G[{yv^(-1)}, yw]*G[{0, yu^(-1)}, yw] + 3*G[{0}, yw]*G[{yu}, yv^(-1)]*
      G[{yv^(-1)}, yw]*G[{0, yu^(-1)}, yw] + 2*G[{1}, yu^(-1)]*
      G[{yu}, yv^(-1)]*G[{yv^(-1)}, yw]*G[{0, yu^(-1)}, yw] + 
     G[{1}, yv^(-1)]*G[{yu}, yv^(-1)]*G[{yv^(-1)}, yw]*G[{0, yu^(-1)}, yw] - 
     G[{1}, yw]*G[{yu}, yv^(-1)]*G[{yv^(-1)}, yw]*G[{0, yu^(-1)}, yw] + 
     4*G[{yu^(-1)}, yw]*G[{yu}, yv^(-1)]*G[{yv^(-1)}, yw]*
      G[{0, yu^(-1)}, yw] + (3*G[{yu}, yv^(-1)]^2*G[{yv^(-1)}, yw]*
       G[{0, yu^(-1)}, yw])/2 - 2*G[{0}, yu^(-1)]*G[{yv^(-1)}, yw]^2*
      G[{0, yu^(-1)}, yw] - 2*G[{0}, yv^(-1)]*G[{yv^(-1)}, yw]^2*
      G[{0, yu^(-1)}, yw] + 2*G[{0}, yw]*G[{yv^(-1)}, yw]^2*
      G[{0, yu^(-1)}, yw] + (G[{1}, yu^(-1)]*G[{yv^(-1)}, yw]^2*
       G[{0, yu^(-1)}, yw])/2 + 2*G[{1}, yv^(-1)]*G[{yv^(-1)}, yw]^2*
      G[{0, yu^(-1)}, yw] - (3*G[{1}, yw]*G[{yv^(-1)}, yw]^2*
       G[{0, yu^(-1)}, yw])/2 + (3*G[{yu^(-1)}, yw]*G[{yv^(-1)}, yw]^2*
       G[{0, yu^(-1)}, yw])/2 + (3*G[{yu}, yv^(-1)]*G[{yv^(-1)}, yw]^2*
       G[{0, yu^(-1)}, yw])/2 + G[{yv^(-1)}, yw]^3*G[{0, yu^(-1)}, yw] + 
     (Pi^2*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1)}, yw])/6 + 
     G[{0}, yu^(-1)]^2*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1)}, yw] + 
     2*G[{0}, yu^(-1)]*G[{0}, yv^(-1)]*G[{1/(yu*yv)}, yw]*
      G[{0, yu^(-1)}, yw] + G[{0}, yv^(-1)]^2*G[{1/(yu*yv)}, yw]*
      G[{0, yu^(-1)}, yw] - 2*G[{0}, yu^(-1)]*G[{0}, yw]*G[{1/(yu*yv)}, yw]*
      G[{0, yu^(-1)}, yw] - 2*G[{0}, yv^(-1)]*G[{0}, yw]*G[{1/(yu*yv)}, yw]*
      G[{0, yu^(-1)}, yw] + G[{0}, yw]^2*G[{1/(yu*yv)}, yw]*
      G[{0, yu^(-1)}, yw] - 3*G[{0}, yu^(-1)]*G[{1}, yu^(-1)]*
      G[{1/(yu*yv)}, yw]*G[{0, yu^(-1)}, yw] - 3*G[{0}, yv^(-1)]*
      G[{1}, yu^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1)}, yw] + 
     3*G[{0}, yw]*G[{1}, yu^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1)}, yw] + 
     (5*G[{1}, yu^(-1)]^2*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1)}, yw])/2 - 
     5*G[{0}, yu^(-1)]*G[{1}, yv^(-1)]*G[{1/(yu*yv)}, yw]*
      G[{0, yu^(-1)}, yw] - 5*G[{0}, yv^(-1)]*G[{1}, yv^(-1)]*
      G[{1/(yu*yv)}, yw]*G[{0, yu^(-1)}, yw] + 5*G[{0}, yw]*G[{1}, yv^(-1)]*
      G[{1/(yu*yv)}, yw]*G[{0, yu^(-1)}, yw] + 2*G[{1}, yu^(-1)]*
      G[{1}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1)}, yw] + 
     (9*G[{1}, yv^(-1)]^2*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1)}, yw])/2 - 
     7*G[{0}, yu^(-1)]*G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1)}, yw] - 
     7*G[{0}, yv^(-1)]*G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1)}, yw] + 
     7*G[{0}, yw]*G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1)}, yw] + 
     6*G[{1}, yu^(-1)]*G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1)}, yw] + 
     6*G[{1}, yv^(-1)]*G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1)}, yw] - 
     2*G[{1}, yw]^2*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1)}, yw] + 
     4*G[{0}, yu^(-1)]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*
      G[{0, yu^(-1)}, yw] + 4*G[{0}, yv^(-1)]*G[{yu^(-1)}, yw]*
      G[{1/(yu*yv)}, yw]*G[{0, yu^(-1)}, yw] - 4*G[{0}, yw]*G[{yu^(-1)}, yw]*
      G[{1/(yu*yv)}, yw]*G[{0, yu^(-1)}, yw] - 2*G[{1}, yu^(-1)]*
      G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1)}, yw] - 
     G[{1}, yv^(-1)]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*
      G[{0, yu^(-1)}, yw] + 5*G[{1}, yw]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*
      G[{0, yu^(-1)}, yw] - 3*G[{yu^(-1)}, yw]^2*G[{1/(yu*yv)}, yw]*
      G[{0, yu^(-1)}, yw] + 4*G[{0}, yu^(-1)]*G[{yu}, yv^(-1)]*
      G[{1/(yu*yv)}, yw]*G[{0, yu^(-1)}, yw] + 4*G[{0}, yv^(-1)]*
      G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1)}, yw] - 
     4*G[{0}, yw]*G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1)}, yw] - 
     G[{1}, yu^(-1)]*G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw]*
      G[{0, yu^(-1)}, yw] - G[{1}, yv^(-1)]*G[{yu}, yv^(-1)]*
      G[{1/(yu*yv)}, yw]*G[{0, yu^(-1)}, yw] + 2*G[{1}, yw]*G[{yu}, yv^(-1)]*
      G[{1/(yu*yv)}, yw]*G[{0, yu^(-1)}, yw] - 5*G[{yu^(-1)}, yw]*
      G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1)}, yw] - 
     3*G[{yu}, yv^(-1)]^2*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1)}, yw] + 
     4*G[{0}, yu^(-1)]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*
      G[{0, yu^(-1)}, yw] + 4*G[{0}, yv^(-1)]*G[{yv^(-1)}, yw]*
      G[{1/(yu*yv)}, yw]*G[{0, yu^(-1)}, yw] - 4*G[{0}, yw]*G[{yv^(-1)}, yw]*
      G[{1/(yu*yv)}, yw]*G[{0, yu^(-1)}, yw] - G[{1}, yu^(-1)]*
      G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1)}, yw] - 
     2*G[{1}, yv^(-1)]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*
      G[{0, yu^(-1)}, yw] + 5*G[{1}, yw]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*
      G[{0, yu^(-1)}, yw] - 5*G[{yu^(-1)}, yw]*G[{yv^(-1)}, yw]*
      G[{1/(yu*yv)}, yw]*G[{0, yu^(-1)}, yw] - 5*G[{yu}, yv^(-1)]*
      G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1)}, yw] - 
     3*G[{yv^(-1)}, yw]^2*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1)}, yw] - 
     (3*G[{0}, yu^(-1)]*G[{1/(yu*yv)}, yw]^2*G[{0, yu^(-1)}, yw])/2 - 
     (3*G[{0}, yv^(-1)]*G[{1/(yu*yv)}, yw]^2*G[{0, yu^(-1)}, yw])/2 + 
     (3*G[{0}, yw]*G[{1/(yu*yv)}, yw]^2*G[{0, yu^(-1)}, yw])/2 + 
     (G[{1}, yu^(-1)]*G[{1/(yu*yv)}, yw]^2*G[{0, yu^(-1)}, yw])/2 + 
     (G[{1}, yv^(-1)]*G[{1/(yu*yv)}, yw]^2*G[{0, yu^(-1)}, yw])/2 - 
     3*G[{1}, yw]*G[{1/(yu*yv)}, yw]^2*G[{0, yu^(-1)}, yw] + 
     (5*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2*G[{0, yu^(-1)}, yw])/2 + 
     2*G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw]^2*G[{0, yu^(-1)}, yw] + 
     (5*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2*G[{0, yu^(-1)}, yw])/2 - 
     (G[{1/(yu*yv)}, yw]^3*G[{0, yu^(-1)}, yw])/3 - 
     G[{0}, yu^(-1)]*G[{0, 1}, yu^(-1)]*G[{0, yu^(-1)}, yw] - 
     G[{0}, yv^(-1)]*G[{0, 1}, yu^(-1)]*G[{0, yu^(-1)}, yw] + 
     G[{0}, yw]*G[{0, 1}, yu^(-1)]*G[{0, yu^(-1)}, yw] - 
     G[{1}, yu^(-1)]*G[{0, 1}, yu^(-1)]*G[{0, yu^(-1)}, yw] - 
     G[{1}, yv^(-1)]*G[{0, 1}, yu^(-1)]*G[{0, yu^(-1)}, yw] + 
     2*G[{yu^(-1)}, yw]*G[{0, 1}, yu^(-1)]*G[{0, yu^(-1)}, yw] + 
     2*G[{yu}, yv^(-1)]*G[{0, 1}, yu^(-1)]*G[{0, yu^(-1)}, yw] - 
     2*G[{1/(yu*yv)}, yw]*G[{0, 1}, yu^(-1)]*G[{0, yu^(-1)}, yw] - 
     G[{0}, yu^(-1)]*G[{0, 1}, yv^(-1)]*G[{0, yu^(-1)}, yw] - 
     G[{0}, yv^(-1)]*G[{0, 1}, yv^(-1)]*G[{0, yu^(-1)}, yw] + 
     G[{0}, yw]*G[{0, 1}, yv^(-1)]*G[{0, yu^(-1)}, yw] - 
     G[{1}, yu^(-1)]*G[{0, 1}, yv^(-1)]*G[{0, yu^(-1)}, yw] - 
     G[{1}, yv^(-1)]*G[{0, 1}, yv^(-1)]*G[{0, yu^(-1)}, yw] + 
     2*G[{yu^(-1)}, yw]*G[{0, 1}, yv^(-1)]*G[{0, yu^(-1)}, yw] + 
     2*G[{yu}, yv^(-1)]*G[{0, 1}, yv^(-1)]*G[{0, yu^(-1)}, yw] - 
     2*G[{1/(yu*yv)}, yw]*G[{0, 1}, yv^(-1)]*G[{0, yu^(-1)}, yw] - 
     2*G[{0}, yu^(-1)]*G[{0, 1}, yw]*G[{0, yu^(-1)}, yw] - 
     2*G[{0}, yv^(-1)]*G[{0, 1}, yw]*G[{0, yu^(-1)}, yw] + 
     2*G[{0}, yw]*G[{0, 1}, yw]*G[{0, yu^(-1)}, yw] + 
     2*G[{1}, yu^(-1)]*G[{0, 1}, yw]*G[{0, yu^(-1)}, yw] + 
     2*G[{1}, yv^(-1)]*G[{0, 1}, yw]*G[{0, yu^(-1)}, yw] + 
     G[{1}, yw]*G[{0, 1}, yw]*G[{0, yu^(-1)}, yw] - 
     3*G[{yu^(-1)}, yw]*G[{0, 1}, yw]*G[{0, yu^(-1)}, yw] - 
     G[{yv^(-1)}, yw]*G[{0, 1}, yw]*G[{0, yu^(-1)}, yw] + 
     3*G[{1/(yu*yv)}, yw]*G[{0, 1}, yw]*G[{0, yu^(-1)}, yw] + 
     G[{0}, yu^(-1)]*G[{0, yu^(-1)}, yw]^2 + G[{0}, yv^(-1)]*
      G[{0, yu^(-1)}, yw]^2 - G[{0}, yw]*G[{0, yu^(-1)}, yw]^2 - 
     G[{1}, yu^(-1)]*G[{0, yu^(-1)}, yw]^2 - 2*G[{1}, yv^(-1)]*
      G[{0, yu^(-1)}, yw]^2 - (G[{1}, yw]*G[{0, yu^(-1)}, yw]^2)/2 + 
     (3*G[{yu^(-1)}, yw]*G[{0, yu^(-1)}, yw]^2)/2 + 
     G[{yu}, yv^(-1)]*G[{0, yu^(-1)}, yw]^2 + 
     (G[{yv^(-1)}, yw]*G[{0, yu^(-1)}, yw]^2)/2 - 
     (3*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1)}, yw]^2)/2 + 
     (Pi^2*G[{1}, yu^(-1)]*G[{0, yu}, yv^(-1)])/3 + 
     (Pi^2*G[{1}, yv^(-1)]*G[{0, yu}, yv^(-1)])/3 - 
     (G[{1}, yu^(-1)]^2*G[{1}, yv^(-1)]*G[{0, yu}, yv^(-1)])/2 - 
     (G[{0}, yu^(-1)]^2*G[{1}, yw]*G[{0, yu}, yv^(-1)])/2 - 
     G[{0}, yu^(-1)]*G[{0}, yv^(-1)]*G[{1}, yw]*G[{0, yu}, yv^(-1)] - 
     (G[{0}, yv^(-1)]^2*G[{1}, yw]*G[{0, yu}, yv^(-1)])/2 + 
     G[{0}, yu^(-1)]*G[{0}, yw]*G[{1}, yw]*G[{0, yu}, yv^(-1)] + 
     G[{0}, yv^(-1)]*G[{0}, yw]*G[{1}, yw]*G[{0, yu}, yv^(-1)] - 
     (G[{0}, yw]^2*G[{1}, yw]*G[{0, yu}, yv^(-1)])/2 - 
     G[{0}, yu^(-1)]*G[{1}, yu^(-1)]*G[{1}, yw]*G[{0, yu}, yv^(-1)] - 
     G[{0}, yv^(-1)]*G[{1}, yu^(-1)]*G[{1}, yw]*G[{0, yu}, yv^(-1)] + 
     G[{0}, yw]*G[{1}, yu^(-1)]*G[{1}, yw]*G[{0, yu}, yv^(-1)] + 
     (3*G[{1}, yu^(-1)]^2*G[{1}, yw]*G[{0, yu}, yv^(-1)])/2 - 
     G[{0}, yu^(-1)]*G[{1}, yv^(-1)]*G[{1}, yw]*G[{0, yu}, yv^(-1)] - 
     G[{0}, yv^(-1)]*G[{1}, yv^(-1)]*G[{1}, yw]*G[{0, yu}, yv^(-1)] + 
     G[{0}, yw]*G[{1}, yv^(-1)]*G[{1}, yw]*G[{0, yu}, yv^(-1)] + 
     3*G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*G[{1}, yw]*G[{0, yu}, yv^(-1)] + 
     (G[{1}, yv^(-1)]^2*G[{1}, yw]*G[{0, yu}, yv^(-1)])/2 + 
     (Pi^2*G[{yu^(-1)}, yw]*G[{0, yu}, yv^(-1)])/3 + 
     (G[{0}, yu^(-1)]^2*G[{yu^(-1)}, yw]*G[{0, yu}, yv^(-1)])/2 + 
     G[{0}, yu^(-1)]*G[{0}, yv^(-1)]*G[{yu^(-1)}, yw]*G[{0, yu}, yv^(-1)] + 
     (G[{0}, yv^(-1)]^2*G[{yu^(-1)}, yw]*G[{0, yu}, yv^(-1)])/2 - 
     G[{0}, yu^(-1)]*G[{0}, yw]*G[{yu^(-1)}, yw]*G[{0, yu}, yv^(-1)] - 
     G[{0}, yv^(-1)]*G[{0}, yw]*G[{yu^(-1)}, yw]*G[{0, yu}, yv^(-1)] + 
     (G[{0}, yw]^2*G[{yu^(-1)}, yw]*G[{0, yu}, yv^(-1)])/2 + 
     G[{0}, yu^(-1)]*G[{1}, yu^(-1)]*G[{yu^(-1)}, yw]*G[{0, yu}, yv^(-1)] + 
     G[{0}, yv^(-1)]*G[{1}, yu^(-1)]*G[{yu^(-1)}, yw]*G[{0, yu}, yv^(-1)] - 
     G[{0}, yw]*G[{1}, yu^(-1)]*G[{yu^(-1)}, yw]*G[{0, yu}, yv^(-1)] - 
     (3*G[{1}, yu^(-1)]^2*G[{yu^(-1)}, yw]*G[{0, yu}, yv^(-1)])/2 + 
     G[{0}, yu^(-1)]*G[{1}, yv^(-1)]*G[{yu^(-1)}, yw]*G[{0, yu}, yv^(-1)] + 
     G[{0}, yv^(-1)]*G[{1}, yv^(-1)]*G[{yu^(-1)}, yw]*G[{0, yu}, yv^(-1)] - 
     G[{0}, yw]*G[{1}, yv^(-1)]*G[{yu^(-1)}, yw]*G[{0, yu}, yv^(-1)] - 
     5*G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*G[{yu^(-1)}, yw]*G[{0, yu}, yv^(-1)] - 
     (3*G[{1}, yv^(-1)]^2*G[{yu^(-1)}, yw]*G[{0, yu}, yv^(-1)])/2 + 
     2*G[{0}, yu^(-1)]*G[{1}, yw]*G[{yu^(-1)}, yw]*G[{0, yu}, yv^(-1)] + 
     2*G[{0}, yv^(-1)]*G[{1}, yw]*G[{yu^(-1)}, yw]*G[{0, yu}, yv^(-1)] - 
     2*G[{0}, yw]*G[{1}, yw]*G[{yu^(-1)}, yw]*G[{0, yu}, yv^(-1)] - 
     2*G[{1}, yu^(-1)]*G[{1}, yw]*G[{yu^(-1)}, yw]*G[{0, yu}, yv^(-1)] - 
     4*G[{1}, yv^(-1)]*G[{1}, yw]*G[{yu^(-1)}, yw]*G[{0, yu}, yv^(-1)] - 
     G[{1}, yw]^2*G[{yu^(-1)}, yw]*G[{0, yu}, yv^(-1)] - 
     (3*G[{0}, yu^(-1)]*G[{yu^(-1)}, yw]^2*G[{0, yu}, yv^(-1)])/2 - 
     (3*G[{0}, yv^(-1)]*G[{yu^(-1)}, yw]^2*G[{0, yu}, yv^(-1)])/2 + 
     (3*G[{0}, yw]*G[{yu^(-1)}, yw]^2*G[{0, yu}, yv^(-1)])/2 + 
     (3*G[{1}, yu^(-1)]*G[{yu^(-1)}, yw]^2*G[{0, yu}, yv^(-1)])/2 + 
     3*G[{1}, yv^(-1)]*G[{yu^(-1)}, yw]^2*G[{0, yu}, yv^(-1)] + 
     (3*G[{1}, yw]*G[{yu^(-1)}, yw]^2*G[{0, yu}, yv^(-1)])/2 - 
     G[{yu^(-1)}, yw]^3*G[{0, yu}, yv^(-1)] + 
     (G[{1}, yu^(-1)]^2*G[{yu}, yv^(-1)]*G[{0, yu}, yv^(-1)])/2 - 
     2*G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*G[{yu}, yv^(-1)]*G[{0, yu}, yv^(-1)] - 
     G[{1}, yv^(-1)]^2*G[{yu}, yv^(-1)]*G[{0, yu}, yv^(-1)] + 
     2*G[{0}, yu^(-1)]*G[{1}, yw]*G[{yu}, yv^(-1)]*G[{0, yu}, yv^(-1)] + 
     2*G[{0}, yv^(-1)]*G[{1}, yw]*G[{yu}, yv^(-1)]*G[{0, yu}, yv^(-1)] - 
     2*G[{0}, yw]*G[{1}, yw]*G[{yu}, yv^(-1)]*G[{0, yu}, yv^(-1)] - 
     2*G[{1}, yu^(-1)]*G[{1}, yw]*G[{yu}, yv^(-1)]*G[{0, yu}, yv^(-1)] - 
     2*G[{1}, yv^(-1)]*G[{1}, yw]*G[{yu}, yv^(-1)]*G[{0, yu}, yv^(-1)] - 
     2*G[{0}, yu^(-1)]*G[{yu^(-1)}, yw]*G[{yu}, yv^(-1)]*
      G[{0, yu}, yv^(-1)] - 2*G[{0}, yv^(-1)]*G[{yu^(-1)}, yw]*
      G[{yu}, yv^(-1)]*G[{0, yu}, yv^(-1)] + 2*G[{0}, yw]*G[{yu^(-1)}, yw]*
      G[{yu}, yv^(-1)]*G[{0, yu}, yv^(-1)] + 4*G[{1}, yu^(-1)]*
      G[{yu^(-1)}, yw]*G[{yu}, yv^(-1)]*G[{0, yu}, yv^(-1)] + 
     3*G[{1}, yv^(-1)]*G[{yu^(-1)}, yw]*G[{yu}, yv^(-1)]*
      G[{0, yu}, yv^(-1)] - (3*G[{yu^(-1)}, yw]^2*G[{yu}, yv^(-1)]*
       G[{0, yu}, yv^(-1)])/2 + (3*G[{1}, yu^(-1)]*G[{yu}, yv^(-1)]^2*
       G[{0, yu}, yv^(-1)])/2 + (3*G[{1}, yv^(-1)]*G[{yu}, yv^(-1)]^2*
       G[{0, yu}, yv^(-1)])/2 - (3*G[{yu^(-1)}, yw]*G[{yu}, yv^(-1)]^2*
       G[{0, yu}, yv^(-1)])/2 - G[{yu}, yv^(-1)]^3*G[{0, yu}, yv^(-1)] - 
     (Pi^2*G[{yv^(-1)}, yw]*G[{0, yu}, yv^(-1)])/3 + 
     (G[{0}, yu^(-1)]^2*G[{yv^(-1)}, yw]*G[{0, yu}, yv^(-1)])/2 + 
     G[{0}, yu^(-1)]*G[{0}, yv^(-1)]*G[{yv^(-1)}, yw]*G[{0, yu}, yv^(-1)] + 
     (G[{0}, yv^(-1)]^2*G[{yv^(-1)}, yw]*G[{0, yu}, yv^(-1)])/2 - 
     G[{0}, yu^(-1)]*G[{0}, yw]*G[{yv^(-1)}, yw]*G[{0, yu}, yv^(-1)] - 
     G[{0}, yv^(-1)]*G[{0}, yw]*G[{yv^(-1)}, yw]*G[{0, yu}, yv^(-1)] + 
     (G[{0}, yw]^2*G[{yv^(-1)}, yw]*G[{0, yu}, yv^(-1)])/2 + 
     G[{0}, yu^(-1)]*G[{1}, yu^(-1)]*G[{yv^(-1)}, yw]*G[{0, yu}, yv^(-1)] + 
     G[{0}, yv^(-1)]*G[{1}, yu^(-1)]*G[{yv^(-1)}, yw]*G[{0, yu}, yv^(-1)] - 
     G[{0}, yw]*G[{1}, yu^(-1)]*G[{yv^(-1)}, yw]*G[{0, yu}, yv^(-1)] - 
     G[{1}, yu^(-1)]^2*G[{yv^(-1)}, yw]*G[{0, yu}, yv^(-1)] + 
     G[{0}, yu^(-1)]*G[{1}, yv^(-1)]*G[{yv^(-1)}, yw]*G[{0, yu}, yv^(-1)] + 
     G[{0}, yv^(-1)]*G[{1}, yv^(-1)]*G[{yv^(-1)}, yw]*G[{0, yu}, yv^(-1)] - 
     G[{0}, yw]*G[{1}, yv^(-1)]*G[{yv^(-1)}, yw]*G[{0, yu}, yv^(-1)] - 
     3*G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*G[{yv^(-1)}, yw]*G[{0, yu}, yv^(-1)] - 
     (G[{1}, yv^(-1)]^2*G[{yv^(-1)}, yw]*G[{0, yu}, yv^(-1)])/2 + 
     2*G[{0}, yu^(-1)]*G[{1}, yw]*G[{yv^(-1)}, yw]*G[{0, yu}, yv^(-1)] + 
     2*G[{0}, yv^(-1)]*G[{1}, yw]*G[{yv^(-1)}, yw]*G[{0, yu}, yv^(-1)] - 
     2*G[{0}, yw]*G[{1}, yw]*G[{yv^(-1)}, yw]*G[{0, yu}, yv^(-1)] - 
     3*G[{1}, yu^(-1)]*G[{1}, yw]*G[{yv^(-1)}, yw]*G[{0, yu}, yv^(-1)] - 
     2*G[{1}, yv^(-1)]*G[{1}, yw]*G[{yv^(-1)}, yw]*G[{0, yu}, yv^(-1)] - 
     (G[{1}, yw]^2*G[{yv^(-1)}, yw]*G[{0, yu}, yv^(-1)])/2 - 
     G[{0}, yu^(-1)]*G[{yu^(-1)}, yw]*G[{yv^(-1)}, yw]*G[{0, yu}, yv^(-1)] - 
     G[{0}, yv^(-1)]*G[{yu^(-1)}, yw]*G[{yv^(-1)}, yw]*G[{0, yu}, yv^(-1)] + 
     G[{0}, yw]*G[{yu^(-1)}, yw]*G[{yv^(-1)}, yw]*G[{0, yu}, yv^(-1)] + 
     3*G[{1}, yu^(-1)]*G[{yu^(-1)}, yw]*G[{yv^(-1)}, yw]*
      G[{0, yu}, yv^(-1)] + 3*G[{1}, yv^(-1)]*G[{yu^(-1)}, yw]*
      G[{yv^(-1)}, yw]*G[{0, yu}, yv^(-1)] + 4*G[{1}, yw]*G[{yu^(-1)}, yw]*
      G[{yv^(-1)}, yw]*G[{0, yu}, yv^(-1)] - 
     (3*G[{yu^(-1)}, yw]^2*G[{yv^(-1)}, yw]*G[{0, yu}, yv^(-1)])/2 - 
     2*G[{0}, yu^(-1)]*G[{yu}, yv^(-1)]*G[{yv^(-1)}, yw]*
      G[{0, yu}, yv^(-1)] - 2*G[{0}, yv^(-1)]*G[{yu}, yv^(-1)]*
      G[{yv^(-1)}, yw]*G[{0, yu}, yv^(-1)] + 2*G[{0}, yw]*G[{yu}, yv^(-1)]*
      G[{yv^(-1)}, yw]*G[{0, yu}, yv^(-1)] + 3*G[{1}, yu^(-1)]*
      G[{yu}, yv^(-1)]*G[{yv^(-1)}, yw]*G[{0, yu}, yv^(-1)] + 
     4*G[{1}, yv^(-1)]*G[{yu}, yv^(-1)]*G[{yv^(-1)}, yw]*
      G[{0, yu}, yv^(-1)] + G[{1}, yw]*G[{yu}, yv^(-1)]*G[{yv^(-1)}, yw]*
      G[{0, yu}, yv^(-1)] - 4*G[{yu^(-1)}, yw]*G[{yu}, yv^(-1)]*
      G[{yv^(-1)}, yw]*G[{0, yu}, yv^(-1)] - 
     (3*G[{yu}, yv^(-1)]^2*G[{yv^(-1)}, yw]*G[{0, yu}, yv^(-1)])/2 - 
     (3*G[{0}, yu^(-1)]*G[{yv^(-1)}, yw]^2*G[{0, yu}, yv^(-1)])/2 - 
     (3*G[{0}, yv^(-1)]*G[{yv^(-1)}, yw]^2*G[{0, yu}, yv^(-1)])/2 + 
     (3*G[{0}, yw]*G[{yv^(-1)}, yw]^2*G[{0, yu}, yv^(-1)])/2 + 
     3*G[{1}, yu^(-1)]*G[{yv^(-1)}, yw]^2*G[{0, yu}, yv^(-1)] + 
     (3*G[{1}, yv^(-1)]*G[{yv^(-1)}, yw]^2*G[{0, yu}, yv^(-1)])/2 + 
     (3*G[{1}, yw]*G[{yv^(-1)}, yw]^2*G[{0, yu}, yv^(-1)])/2 - 
     (3*G[{yu^(-1)}, yw]*G[{yv^(-1)}, yw]^2*G[{0, yu}, yv^(-1)])/2 - 
     (3*G[{yu}, yv^(-1)]*G[{yv^(-1)}, yw]^2*G[{0, yu}, yv^(-1)])/2 - 
     G[{yv^(-1)}, yw]^3*G[{0, yu}, yv^(-1)] - 
     (G[{0}, yu^(-1)]^2*G[{1/(yu*yv)}, yw]*G[{0, yu}, yv^(-1)])/2 - 
     G[{0}, yu^(-1)]*G[{0}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, yu}, yv^(-1)] - 
     (G[{0}, yv^(-1)]^2*G[{1/(yu*yv)}, yw]*G[{0, yu}, yv^(-1)])/2 + 
     G[{0}, yu^(-1)]*G[{0}, yw]*G[{1/(yu*yv)}, yw]*G[{0, yu}, yv^(-1)] + 
     G[{0}, yv^(-1)]*G[{0}, yw]*G[{1/(yu*yv)}, yw]*G[{0, yu}, yv^(-1)] - 
     (G[{0}, yw]^2*G[{1/(yu*yv)}, yw]*G[{0, yu}, yv^(-1)])/2 - 
     G[{0}, yu^(-1)]*G[{1}, yu^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, yu}, yv^(-1)] - 
     G[{0}, yv^(-1)]*G[{1}, yu^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, yu}, yv^(-1)] + 
     G[{0}, yw]*G[{1}, yu^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, yu}, yv^(-1)] + 
     G[{1}, yu^(-1)]^2*G[{1/(yu*yv)}, yw]*G[{0, yu}, yv^(-1)] - 
     G[{0}, yu^(-1)]*G[{1}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, yu}, yv^(-1)] - 
     G[{0}, yv^(-1)]*G[{1}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, yu}, yv^(-1)] + 
     G[{0}, yw]*G[{1}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, yu}, yv^(-1)] + 
     5*G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*G[{1/(yu*yv)}, yw]*
      G[{0, yu}, yv^(-1)] + (3*G[{1}, yv^(-1)]^2*G[{1/(yu*yv)}, yw]*
       G[{0, yu}, yv^(-1)])/2 - 4*G[{0}, yu^(-1)]*G[{1}, yw]*
      G[{1/(yu*yv)}, yw]*G[{0, yu}, yv^(-1)] - 4*G[{0}, yv^(-1)]*G[{1}, yw]*
      G[{1/(yu*yv)}, yw]*G[{0, yu}, yv^(-1)] + 4*G[{0}, yw]*G[{1}, yw]*
      G[{1/(yu*yv)}, yw]*G[{0, yu}, yv^(-1)] + 5*G[{1}, yu^(-1)]*G[{1}, yw]*
      G[{1/(yu*yv)}, yw]*G[{0, yu}, yv^(-1)] + 6*G[{1}, yv^(-1)]*G[{1}, yw]*
      G[{1/(yu*yv)}, yw]*G[{0, yu}, yv^(-1)] + 
     (3*G[{1}, yw]^2*G[{1/(yu*yv)}, yw]*G[{0, yu}, yv^(-1)])/2 + 
     3*G[{0}, yu^(-1)]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*
      G[{0, yu}, yv^(-1)] + 3*G[{0}, yv^(-1)]*G[{yu^(-1)}, yw]*
      G[{1/(yu*yv)}, yw]*G[{0, yu}, yv^(-1)] - 3*G[{0}, yw]*G[{yu^(-1)}, yw]*
      G[{1/(yu*yv)}, yw]*G[{0, yu}, yv^(-1)] - 5*G[{1}, yu^(-1)]*
      G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{0, yu}, yv^(-1)] - 
     6*G[{1}, yv^(-1)]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*
      G[{0, yu}, yv^(-1)] - 5*G[{1}, yw]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*
      G[{0, yu}, yv^(-1)] + 3*G[{yu^(-1)}, yw]^2*G[{1/(yu*yv)}, yw]*
      G[{0, yu}, yv^(-1)] + 2*G[{0}, yu^(-1)]*G[{yu}, yv^(-1)]*
      G[{1/(yu*yv)}, yw]*G[{0, yu}, yv^(-1)] + 2*G[{0}, yv^(-1)]*
      G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, yu}, yv^(-1)] - 
     2*G[{0}, yw]*G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, yu}, yv^(-1)] - 
     5*G[{1}, yu^(-1)]*G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw]*
      G[{0, yu}, yv^(-1)] - 5*G[{1}, yv^(-1)]*G[{yu}, yv^(-1)]*
      G[{1/(yu*yv)}, yw]*G[{0, yu}, yv^(-1)] - G[{1}, yw]*G[{yu}, yv^(-1)]*
      G[{1/(yu*yv)}, yw]*G[{0, yu}, yv^(-1)] + 5*G[{yu^(-1)}, yw]*
      G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, yu}, yv^(-1)] + 
     3*G[{yu}, yv^(-1)]^2*G[{1/(yu*yv)}, yw]*G[{0, yu}, yv^(-1)] + 
     3*G[{0}, yu^(-1)]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*
      G[{0, yu}, yv^(-1)] + 3*G[{0}, yv^(-1)]*G[{yv^(-1)}, yw]*
      G[{1/(yu*yv)}, yw]*G[{0, yu}, yv^(-1)] - 3*G[{0}, yw]*G[{yv^(-1)}, yw]*
      G[{1/(yu*yv)}, yw]*G[{0, yu}, yv^(-1)] - 6*G[{1}, yu^(-1)]*
      G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{0, yu}, yv^(-1)] - 
     5*G[{1}, yv^(-1)]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*
      G[{0, yu}, yv^(-1)] - 5*G[{1}, yw]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*
      G[{0, yu}, yv^(-1)] + 5*G[{yu^(-1)}, yw]*G[{yv^(-1)}, yw]*
      G[{1/(yu*yv)}, yw]*G[{0, yu}, yv^(-1)] + 5*G[{yu}, yv^(-1)]*
      G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{0, yu}, yv^(-1)] + 
     3*G[{yv^(-1)}, yw]^2*G[{1/(yu*yv)}, yw]*G[{0, yu}, yv^(-1)] - 
     G[{0}, yu^(-1)]*G[{1/(yu*yv)}, yw]^2*G[{0, yu}, yv^(-1)] - 
     G[{0}, yv^(-1)]*G[{1/(yu*yv)}, yw]^2*G[{0, yu}, yv^(-1)] + 
     G[{0}, yw]*G[{1/(yu*yv)}, yw]^2*G[{0, yu}, yv^(-1)] + 
     2*G[{1}, yu^(-1)]*G[{1/(yu*yv)}, yw]^2*G[{0, yu}, yv^(-1)] + 
     (3*G[{1}, yv^(-1)]*G[{1/(yu*yv)}, yw]^2*G[{0, yu}, yv^(-1)])/2 + 
     (3*G[{1}, yw]*G[{1/(yu*yv)}, yw]^2*G[{0, yu}, yv^(-1)])/2 - 
     (5*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2*G[{0, yu}, yv^(-1)])/2 - 
     (5*G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw]^2*G[{0, yu}, yv^(-1)])/2 - 
     2*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2*G[{0, yu}, yv^(-1)] + 
     (G[{1/(yu*yv)}, yw]^3*G[{0, yu}, yv^(-1)])/3 + 
     2*G[{1}, yu^(-1)]*G[{0, 1}, yu^(-1)]*G[{0, yu}, yv^(-1)] + 
     2*G[{1}, yv^(-1)]*G[{0, 1}, yu^(-1)]*G[{0, yu}, yv^(-1)] - 
     2*G[{yu}, yv^(-1)]*G[{0, 1}, yu^(-1)]*G[{0, yu}, yv^(-1)] - 
     2*G[{yv^(-1)}, yw]*G[{0, 1}, yu^(-1)]*G[{0, yu}, yv^(-1)] + 
     2*G[{1/(yu*yv)}, yw]*G[{0, 1}, yu^(-1)]*G[{0, yu}, yv^(-1)] + 
     2*G[{1}, yu^(-1)]*G[{0, 1}, yv^(-1)]*G[{0, yu}, yv^(-1)] + 
     2*G[{1}, yv^(-1)]*G[{0, 1}, yv^(-1)]*G[{0, yu}, yv^(-1)] - 
     G[{yu^(-1)}, yw]*G[{0, 1}, yv^(-1)]*G[{0, yu}, yv^(-1)] - 
     3*G[{yu}, yv^(-1)]*G[{0, 1}, yv^(-1)]*G[{0, yu}, yv^(-1)] - 
     2*G[{yv^(-1)}, yw]*G[{0, 1}, yv^(-1)]*G[{0, yu}, yv^(-1)] + 
     3*G[{1/(yu*yv)}, yw]*G[{0, 1}, yv^(-1)]*G[{0, yu}, yv^(-1)] - 
     G[{0}, yu^(-1)]*G[{0, 1}, yw]*G[{0, yu}, yv^(-1)] - 
     G[{0}, yv^(-1)]*G[{0, 1}, yw]*G[{0, yu}, yv^(-1)] + 
     G[{0}, yw]*G[{0, 1}, yw]*G[{0, yu}, yv^(-1)] - 
     G[{1}, yu^(-1)]*G[{0, 1}, yw]*G[{0, yu}, yv^(-1)] - 
     G[{1}, yv^(-1)]*G[{0, 1}, yw]*G[{0, yu}, yv^(-1)] + 
     2*G[{1}, yw]*G[{0, 1}, yw]*G[{0, yu}, yv^(-1)] + 
     2*G[{yu}, yv^(-1)]*G[{0, 1}, yw]*G[{0, yu}, yv^(-1)] - 
     2*G[{1/(yu*yv)}, yw]*G[{0, 1}, yw]*G[{0, yu}, yv^(-1)] + 
     G[{0}, yu^(-1)]*G[{0, yu^(-1)}, yw]*G[{0, yu}, yv^(-1)] + 
     G[{0}, yv^(-1)]*G[{0, yu^(-1)}, yw]*G[{0, yu}, yv^(-1)] - 
     G[{0}, yw]*G[{0, yu^(-1)}, yw]*G[{0, yu}, yv^(-1)] + 
     G[{1}, yu^(-1)]*G[{0, yu^(-1)}, yw]*G[{0, yu}, yv^(-1)] + 
     G[{1}, yv^(-1)]*G[{0, yu^(-1)}, yw]*G[{0, yu}, yv^(-1)] - 
     2*G[{yu^(-1)}, yw]*G[{0, yu^(-1)}, yw]*G[{0, yu}, yv^(-1)] - 
     2*G[{yu}, yv^(-1)]*G[{0, yu^(-1)}, yw]*G[{0, yu}, yv^(-1)] + 
     2*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1)}, yw]*G[{0, yu}, yv^(-1)] - 
     G[{1}, yu^(-1)]*G[{0, yu}, yv^(-1)]^2 - G[{1}, yv^(-1)]*
      G[{0, yu}, yv^(-1)]^2 + (G[{yu^(-1)}, yw]*G[{0, yu}, yv^(-1)]^2)/2 + 
     (3*G[{yu}, yv^(-1)]*G[{0, yu}, yv^(-1)]^2)/2 + 
     G[{yv^(-1)}, yw]*G[{0, yu}, yv^(-1)]^2 - 
     (3*G[{1/(yu*yv)}, yw]*G[{0, yu}, yv^(-1)]^2)/2 - 
     (Pi^2*G[{1}, yu^(-1)]*G[{0, yv^(-1)}, yw])/3 - 
     (Pi^2*G[{1}, yv^(-1)]*G[{0, yv^(-1)}, yw])/3 - 
     G[{0}, yu^(-1)]*G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*G[{0, yv^(-1)}, yw] - 
     G[{0}, yv^(-1)]*G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*G[{0, yv^(-1)}, yw] + 
     G[{0}, yw]*G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*G[{0, yv^(-1)}, yw] + 
     (3*G[{1}, yu^(-1)]^2*G[{1}, yv^(-1)]*G[{0, yv^(-1)}, yw])/2 + 
     (Pi^2*G[{1}, yw]*G[{0, yv^(-1)}, yw])/2 + G[{0}, yu^(-1)]^2*G[{1}, yw]*
      G[{0, yv^(-1)}, yw] + 2*G[{0}, yu^(-1)]*G[{0}, yv^(-1)]*G[{1}, yw]*
      G[{0, yv^(-1)}, yw] + G[{0}, yv^(-1)]^2*G[{1}, yw]*
      G[{0, yv^(-1)}, yw] - 2*G[{0}, yu^(-1)]*G[{0}, yw]*G[{1}, yw]*
      G[{0, yv^(-1)}, yw] - 2*G[{0}, yv^(-1)]*G[{0}, yw]*G[{1}, yw]*
      G[{0, yv^(-1)}, yw] + G[{0}, yw]^2*G[{1}, yw]*G[{0, yv^(-1)}, yw] - 
     4*G[{0}, yu^(-1)]*G[{1}, yu^(-1)]*G[{1}, yw]*G[{0, yv^(-1)}, yw] - 
     4*G[{0}, yv^(-1)]*G[{1}, yu^(-1)]*G[{1}, yw]*G[{0, yv^(-1)}, yw] + 
     4*G[{0}, yw]*G[{1}, yu^(-1)]*G[{1}, yw]*G[{0, yv^(-1)}, yw] + 
     3*G[{1}, yu^(-1)]^2*G[{1}, yw]*G[{0, yv^(-1)}, yw] - 
     2*G[{0}, yu^(-1)]*G[{1}, yv^(-1)]*G[{1}, yw]*G[{0, yv^(-1)}, yw] - 
     2*G[{0}, yv^(-1)]*G[{1}, yv^(-1)]*G[{1}, yw]*G[{0, yv^(-1)}, yw] + 
     2*G[{0}, yw]*G[{1}, yv^(-1)]*G[{1}, yw]*G[{0, yv^(-1)}, yw] + 
     4*G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*G[{1}, yw]*G[{0, yv^(-1)}, yw] + 
     G[{1}, yv^(-1)]^2*G[{1}, yw]*G[{0, yv^(-1)}, yw] - 
     (G[{0}, yu^(-1)]*G[{1}, yw]^2*G[{0, yv^(-1)}, yw])/2 - 
     (G[{0}, yv^(-1)]*G[{1}, yw]^2*G[{0, yv^(-1)}, yw])/2 + 
     (G[{0}, yw]*G[{1}, yw]^2*G[{0, yv^(-1)}, yw])/2 + 
     (G[{1}, yu^(-1)]*G[{1}, yw]^2*G[{0, yv^(-1)}, yw])/2 + 
     (G[{1}, yv^(-1)]*G[{1}, yw]^2*G[{0, yv^(-1)}, yw])/2 - 
     (G[{1}, yw]^3*G[{0, yv^(-1)}, yw])/3 - 
     (Pi^2*G[{yu^(-1)}, yw]*G[{0, yv^(-1)}, yw])/2 - 
     G[{0}, yu^(-1)]^2*G[{yu^(-1)}, yw]*G[{0, yv^(-1)}, yw] - 
     2*G[{0}, yu^(-1)]*G[{0}, yv^(-1)]*G[{yu^(-1)}, yw]*G[{0, yv^(-1)}, yw] - 
     G[{0}, yv^(-1)]^2*G[{yu^(-1)}, yw]*G[{0, yv^(-1)}, yw] + 
     2*G[{0}, yu^(-1)]*G[{0}, yw]*G[{yu^(-1)}, yw]*G[{0, yv^(-1)}, yw] + 
     2*G[{0}, yv^(-1)]*G[{0}, yw]*G[{yu^(-1)}, yw]*G[{0, yv^(-1)}, yw] - 
     G[{0}, yw]^2*G[{yu^(-1)}, yw]*G[{0, yv^(-1)}, yw] + 
     4*G[{0}, yu^(-1)]*G[{1}, yu^(-1)]*G[{yu^(-1)}, yw]*G[{0, yv^(-1)}, yw] + 
     4*G[{0}, yv^(-1)]*G[{1}, yu^(-1)]*G[{yu^(-1)}, yw]*G[{0, yv^(-1)}, yw] - 
     4*G[{0}, yw]*G[{1}, yu^(-1)]*G[{yu^(-1)}, yw]*G[{0, yv^(-1)}, yw] - 
     3*G[{1}, yu^(-1)]^2*G[{yu^(-1)}, yw]*G[{0, yv^(-1)}, yw] + 
     3*G[{0}, yu^(-1)]*G[{1}, yv^(-1)]*G[{yu^(-1)}, yw]*G[{0, yv^(-1)}, yw] + 
     3*G[{0}, yv^(-1)]*G[{1}, yv^(-1)]*G[{yu^(-1)}, yw]*G[{0, yv^(-1)}, yw] - 
     3*G[{0}, yw]*G[{1}, yv^(-1)]*G[{yu^(-1)}, yw]*G[{0, yv^(-1)}, yw] - 
     3*G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*G[{yu^(-1)}, yw]*G[{0, yv^(-1)}, yw] - 
     (5*G[{1}, yv^(-1)]^2*G[{yu^(-1)}, yw]*G[{0, yv^(-1)}, yw])/2 + 
     4*G[{0}, yu^(-1)]*G[{1}, yw]*G[{yu^(-1)}, yw]*G[{0, yv^(-1)}, yw] + 
     4*G[{0}, yv^(-1)]*G[{1}, yw]*G[{yu^(-1)}, yw]*G[{0, yv^(-1)}, yw] - 
     4*G[{0}, yw]*G[{1}, yw]*G[{yu^(-1)}, yw]*G[{0, yv^(-1)}, yw] - 
     4*G[{1}, yu^(-1)]*G[{1}, yw]*G[{yu^(-1)}, yw]*G[{0, yv^(-1)}, yw] - 
     3*G[{1}, yv^(-1)]*G[{1}, yw]*G[{yu^(-1)}, yw]*G[{0, yv^(-1)}, yw] + 
     (3*G[{1}, yw]^2*G[{yu^(-1)}, yw]*G[{0, yv^(-1)}, yw])/2 - 
     2*G[{0}, yu^(-1)]*G[{yu^(-1)}, yw]^2*G[{0, yv^(-1)}, yw] - 
     2*G[{0}, yv^(-1)]*G[{yu^(-1)}, yw]^2*G[{0, yv^(-1)}, yw] + 
     2*G[{0}, yw]*G[{yu^(-1)}, yw]^2*G[{0, yv^(-1)}, yw] + 
     2*G[{1}, yu^(-1)]*G[{yu^(-1)}, yw]^2*G[{0, yv^(-1)}, yw] + 
     (G[{1}, yv^(-1)]*G[{yu^(-1)}, yw]^2*G[{0, yv^(-1)}, yw])/2 - 
     (3*G[{1}, yw]*G[{yu^(-1)}, yw]^2*G[{0, yv^(-1)}, yw])/2 + 
     G[{yu^(-1)}, yw]^3*G[{0, yv^(-1)}, yw] + 
     (Pi^2*G[{yu}, yv^(-1)]*G[{0, yv^(-1)}, yw])/3 + 
     G[{0}, yu^(-1)]*G[{1}, yu^(-1)]*G[{yu}, yv^(-1)]*G[{0, yv^(-1)}, yw] + 
     G[{0}, yv^(-1)]*G[{1}, yu^(-1)]*G[{yu}, yv^(-1)]*G[{0, yv^(-1)}, yw] - 
     G[{0}, yw]*G[{1}, yu^(-1)]*G[{yu}, yv^(-1)]*G[{0, yv^(-1)}, yw] - 
     (3*G[{1}, yu^(-1)]^2*G[{yu}, yv^(-1)]*G[{0, yv^(-1)}, yw])/2 + 
     G[{0}, yu^(-1)]*G[{1}, yv^(-1)]*G[{yu}, yv^(-1)]*G[{0, yv^(-1)}, yw] + 
     G[{0}, yv^(-1)]*G[{1}, yv^(-1)]*G[{yu}, yv^(-1)]*G[{0, yv^(-1)}, yw] - 
     G[{0}, yw]*G[{1}, yv^(-1)]*G[{yu}, yv^(-1)]*G[{0, yv^(-1)}, yw] + 
     2*G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*G[{yu}, yv^(-1)]*G[{0, yv^(-1)}, yw] - 
     (3*G[{1}, yv^(-1)]^2*G[{yu}, yv^(-1)]*G[{0, yv^(-1)}, yw])/2 + 
     2*G[{0}, yu^(-1)]*G[{1}, yw]*G[{yu}, yv^(-1)]*G[{0, yv^(-1)}, yw] + 
     2*G[{0}, yv^(-1)]*G[{1}, yw]*G[{yu}, yv^(-1)]*G[{0, yv^(-1)}, yw] - 
     2*G[{0}, yw]*G[{1}, yw]*G[{yu}, yv^(-1)]*G[{0, yv^(-1)}, yw] - 
     2*G[{1}, yu^(-1)]*G[{1}, yw]*G[{yu}, yv^(-1)]*G[{0, yv^(-1)}, yw] - 
     2*G[{1}, yv^(-1)]*G[{1}, yw]*G[{yu}, yv^(-1)]*G[{0, yv^(-1)}, yw] - 
     3*G[{0}, yu^(-1)]*G[{yu^(-1)}, yw]*G[{yu}, yv^(-1)]*
      G[{0, yv^(-1)}, yw] - 3*G[{0}, yv^(-1)]*G[{yu^(-1)}, yw]*
      G[{yu}, yv^(-1)]*G[{0, yv^(-1)}, yw] + 3*G[{0}, yw]*G[{yu^(-1)}, yw]*
      G[{yu}, yv^(-1)]*G[{0, yv^(-1)}, yw] + G[{1}, yu^(-1)]*G[{yu^(-1)}, yw]*
      G[{yu}, yv^(-1)]*G[{0, yv^(-1)}, yw] + 2*G[{1}, yv^(-1)]*
      G[{yu^(-1)}, yw]*G[{yu}, yv^(-1)]*G[{0, yv^(-1)}, yw] - 
     G[{1}, yw]*G[{yu^(-1)}, yw]*G[{yu}, yv^(-1)]*G[{0, yv^(-1)}, yw] + 
     (3*G[{yu^(-1)}, yw]^2*G[{yu}, yv^(-1)]*G[{0, yv^(-1)}, yw])/2 - 
     G[{0}, yu^(-1)]*G[{yu}, yv^(-1)]^2*G[{0, yv^(-1)}, yw] - 
     G[{0}, yv^(-1)]*G[{yu}, yv^(-1)]^2*G[{0, yv^(-1)}, yw] + 
     G[{0}, yw]*G[{yu}, yv^(-1)]^2*G[{0, yv^(-1)}, yw] - 
     (G[{1}, yu^(-1)]*G[{yu}, yv^(-1)]^2*G[{0, yv^(-1)}, yw])/2 - 
     (G[{1}, yv^(-1)]*G[{yu}, yv^(-1)]^2*G[{0, yv^(-1)}, yw])/2 + 
     (3*G[{yu^(-1)}, yw]*G[{yu}, yv^(-1)]^2*G[{0, yv^(-1)}, yw])/2 + 
     G[{yu}, yv^(-1)]^3*G[{0, yv^(-1)}, yw] - 
     (Pi^2*G[{yv^(-1)}, yw]*G[{0, yv^(-1)}, yw])/6 - 
     G[{0}, yu^(-1)]^2*G[{yv^(-1)}, yw]*G[{0, yv^(-1)}, yw] - 
     2*G[{0}, yu^(-1)]*G[{0}, yv^(-1)]*G[{yv^(-1)}, yw]*G[{0, yv^(-1)}, yw] - 
     G[{0}, yv^(-1)]^2*G[{yv^(-1)}, yw]*G[{0, yv^(-1)}, yw] + 
     2*G[{0}, yu^(-1)]*G[{0}, yw]*G[{yv^(-1)}, yw]*G[{0, yv^(-1)}, yw] + 
     2*G[{0}, yv^(-1)]*G[{0}, yw]*G[{yv^(-1)}, yw]*G[{0, yv^(-1)}, yw] - 
     G[{0}, yw]^2*G[{yv^(-1)}, yw]*G[{0, yv^(-1)}, yw] + 
     5*G[{0}, yu^(-1)]*G[{1}, yu^(-1)]*G[{yv^(-1)}, yw]*G[{0, yv^(-1)}, yw] + 
     5*G[{0}, yv^(-1)]*G[{1}, yu^(-1)]*G[{yv^(-1)}, yw]*G[{0, yv^(-1)}, yw] - 
     5*G[{0}, yw]*G[{1}, yu^(-1)]*G[{yv^(-1)}, yw]*G[{0, yv^(-1)}, yw] - 
     (9*G[{1}, yu^(-1)]^2*G[{yv^(-1)}, yw]*G[{0, yv^(-1)}, yw])/2 + 
     2*G[{0}, yu^(-1)]*G[{1}, yv^(-1)]*G[{yv^(-1)}, yw]*G[{0, yv^(-1)}, yw] + 
     2*G[{0}, yv^(-1)]*G[{1}, yv^(-1)]*G[{yv^(-1)}, yw]*G[{0, yv^(-1)}, yw] - 
     2*G[{0}, yw]*G[{1}, yv^(-1)]*G[{yv^(-1)}, yw]*G[{0, yv^(-1)}, yw] - 
     3*G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*G[{yv^(-1)}, yw]*G[{0, yv^(-1)}, yw] - 
     G[{1}, yv^(-1)]^2*G[{yv^(-1)}, yw]*G[{0, yv^(-1)}, yw] + 
     4*G[{0}, yu^(-1)]*G[{1}, yw]*G[{yv^(-1)}, yw]*G[{0, yv^(-1)}, yw] + 
     4*G[{0}, yv^(-1)]*G[{1}, yw]*G[{yv^(-1)}, yw]*G[{0, yv^(-1)}, yw] - 
     4*G[{0}, yw]*G[{1}, yw]*G[{yv^(-1)}, yw]*G[{0, yv^(-1)}, yw] - 
     3*G[{1}, yu^(-1)]*G[{1}, yw]*G[{yv^(-1)}, yw]*G[{0, yv^(-1)}, yw] - 
     4*G[{1}, yv^(-1)]*G[{1}, yw]*G[{yv^(-1)}, yw]*G[{0, yv^(-1)}, yw] + 
     (3*G[{1}, yw]^2*G[{yv^(-1)}, yw]*G[{0, yv^(-1)}, yw])/2 - 
     G[{0}, yu^(-1)]*G[{yu^(-1)}, yw]*G[{yv^(-1)}, yw]*G[{0, yv^(-1)}, yw] - 
     G[{0}, yv^(-1)]*G[{yu^(-1)}, yw]*G[{yv^(-1)}, yw]*G[{0, yv^(-1)}, yw] + 
     G[{0}, yw]*G[{yu^(-1)}, yw]*G[{yv^(-1)}, yw]*G[{0, yv^(-1)}, yw] - 
     G[{1}, yu^(-1)]*G[{yu^(-1)}, yw]*G[{yv^(-1)}, yw]*G[{0, yv^(-1)}, yw] - 
     G[{1}, yv^(-1)]*G[{yu^(-1)}, yw]*G[{yv^(-1)}, yw]*G[{0, yv^(-1)}, yw] - 
     4*G[{1}, yw]*G[{yu^(-1)}, yw]*G[{yv^(-1)}, yw]*G[{0, yv^(-1)}, yw] + 
     (3*G[{yu^(-1)}, yw]^2*G[{yv^(-1)}, yw]*G[{0, yv^(-1)}, yw])/2 - 
     3*G[{0}, yu^(-1)]*G[{yu}, yv^(-1)]*G[{yv^(-1)}, yw]*
      G[{0, yv^(-1)}, yw] - 3*G[{0}, yv^(-1)]*G[{yu}, yv^(-1)]*
      G[{yv^(-1)}, yw]*G[{0, yv^(-1)}, yw] + 3*G[{0}, yw]*G[{yu}, yv^(-1)]*
      G[{yv^(-1)}, yw]*G[{0, yv^(-1)}, yw] + 2*G[{1}, yu^(-1)]*
      G[{yu}, yv^(-1)]*G[{yv^(-1)}, yw]*G[{0, yv^(-1)}, yw] + 
     G[{1}, yv^(-1)]*G[{yu}, yv^(-1)]*G[{yv^(-1)}, yw]*G[{0, yv^(-1)}, yw] - 
     G[{1}, yw]*G[{yu}, yv^(-1)]*G[{yv^(-1)}, yw]*G[{0, yv^(-1)}, yw] + 
     4*G[{yu^(-1)}, yw]*G[{yu}, yv^(-1)]*G[{yv^(-1)}, yw]*
      G[{0, yv^(-1)}, yw] + (3*G[{yu}, yv^(-1)]^2*G[{yv^(-1)}, yw]*
       G[{0, yv^(-1)}, yw])/2 - 2*G[{0}, yu^(-1)]*G[{yv^(-1)}, yw]^2*
      G[{0, yv^(-1)}, yw] - 2*G[{0}, yv^(-1)]*G[{yv^(-1)}, yw]^2*
      G[{0, yv^(-1)}, yw] + 2*G[{0}, yw]*G[{yv^(-1)}, yw]^2*
      G[{0, yv^(-1)}, yw] + (G[{1}, yu^(-1)]*G[{yv^(-1)}, yw]^2*
       G[{0, yv^(-1)}, yw])/2 + 2*G[{1}, yv^(-1)]*G[{yv^(-1)}, yw]^2*
      G[{0, yv^(-1)}, yw] - (3*G[{1}, yw]*G[{yv^(-1)}, yw]^2*
       G[{0, yv^(-1)}, yw])/2 + (3*G[{yu^(-1)}, yw]*G[{yv^(-1)}, yw]^2*
       G[{0, yv^(-1)}, yw])/2 + (3*G[{yu}, yv^(-1)]*G[{yv^(-1)}, yw]^2*
       G[{0, yv^(-1)}, yw])/2 + G[{yv^(-1)}, yw]^3*G[{0, yv^(-1)}, yw] + 
     (Pi^2*G[{1/(yu*yv)}, yw]*G[{0, yv^(-1)}, yw])/6 + 
     G[{0}, yu^(-1)]^2*G[{1/(yu*yv)}, yw]*G[{0, yv^(-1)}, yw] + 
     2*G[{0}, yu^(-1)]*G[{0}, yv^(-1)]*G[{1/(yu*yv)}, yw]*
      G[{0, yv^(-1)}, yw] + G[{0}, yv^(-1)]^2*G[{1/(yu*yv)}, yw]*
      G[{0, yv^(-1)}, yw] - 2*G[{0}, yu^(-1)]*G[{0}, yw]*G[{1/(yu*yv)}, yw]*
      G[{0, yv^(-1)}, yw] - 2*G[{0}, yv^(-1)]*G[{0}, yw]*G[{1/(yu*yv)}, yw]*
      G[{0, yv^(-1)}, yw] + G[{0}, yw]^2*G[{1/(yu*yv)}, yw]*
      G[{0, yv^(-1)}, yw] - 5*G[{0}, yu^(-1)]*G[{1}, yu^(-1)]*
      G[{1/(yu*yv)}, yw]*G[{0, yv^(-1)}, yw] - 5*G[{0}, yv^(-1)]*
      G[{1}, yu^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, yv^(-1)}, yw] + 
     5*G[{0}, yw]*G[{1}, yu^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, yv^(-1)}, yw] + 
     (9*G[{1}, yu^(-1)]^2*G[{1/(yu*yv)}, yw]*G[{0, yv^(-1)}, yw])/2 - 
     3*G[{0}, yu^(-1)]*G[{1}, yv^(-1)]*G[{1/(yu*yv)}, yw]*
      G[{0, yv^(-1)}, yw] - 3*G[{0}, yv^(-1)]*G[{1}, yv^(-1)]*
      G[{1/(yu*yv)}, yw]*G[{0, yv^(-1)}, yw] + 3*G[{0}, yw]*G[{1}, yv^(-1)]*
      G[{1/(yu*yv)}, yw]*G[{0, yv^(-1)}, yw] + 2*G[{1}, yu^(-1)]*
      G[{1}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, yv^(-1)}, yw] + 
     (5*G[{1}, yv^(-1)]^2*G[{1/(yu*yv)}, yw]*G[{0, yv^(-1)}, yw])/2 - 
     7*G[{0}, yu^(-1)]*G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{0, yv^(-1)}, yw] - 
     7*G[{0}, yv^(-1)]*G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{0, yv^(-1)}, yw] + 
     7*G[{0}, yw]*G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{0, yv^(-1)}, yw] + 
     6*G[{1}, yu^(-1)]*G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{0, yv^(-1)}, yw] + 
     6*G[{1}, yv^(-1)]*G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{0, yv^(-1)}, yw] - 
     2*G[{1}, yw]^2*G[{1/(yu*yv)}, yw]*G[{0, yv^(-1)}, yw] + 
     4*G[{0}, yu^(-1)]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*
      G[{0, yv^(-1)}, yw] + 4*G[{0}, yv^(-1)]*G[{yu^(-1)}, yw]*
      G[{1/(yu*yv)}, yw]*G[{0, yv^(-1)}, yw] - 4*G[{0}, yw]*G[{yu^(-1)}, yw]*
      G[{1/(yu*yv)}, yw]*G[{0, yv^(-1)}, yw] - 2*G[{1}, yu^(-1)]*
      G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{0, yv^(-1)}, yw] - 
     G[{1}, yv^(-1)]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*
      G[{0, yv^(-1)}, yw] + 5*G[{1}, yw]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*
      G[{0, yv^(-1)}, yw] - 3*G[{yu^(-1)}, yw]^2*G[{1/(yu*yv)}, yw]*
      G[{0, yv^(-1)}, yw] + 4*G[{0}, yu^(-1)]*G[{yu}, yv^(-1)]*
      G[{1/(yu*yv)}, yw]*G[{0, yv^(-1)}, yw] + 4*G[{0}, yv^(-1)]*
      G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, yv^(-1)}, yw] - 
     4*G[{0}, yw]*G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, yv^(-1)}, yw] - 
     G[{1}, yu^(-1)]*G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw]*
      G[{0, yv^(-1)}, yw] - G[{1}, yv^(-1)]*G[{yu}, yv^(-1)]*
      G[{1/(yu*yv)}, yw]*G[{0, yv^(-1)}, yw] + 2*G[{1}, yw]*G[{yu}, yv^(-1)]*
      G[{1/(yu*yv)}, yw]*G[{0, yv^(-1)}, yw] - 5*G[{yu^(-1)}, yw]*
      G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, yv^(-1)}, yw] - 
     3*G[{yu}, yv^(-1)]^2*G[{1/(yu*yv)}, yw]*G[{0, yv^(-1)}, yw] + 
     4*G[{0}, yu^(-1)]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*
      G[{0, yv^(-1)}, yw] + 4*G[{0}, yv^(-1)]*G[{yv^(-1)}, yw]*
      G[{1/(yu*yv)}, yw]*G[{0, yv^(-1)}, yw] - 4*G[{0}, yw]*G[{yv^(-1)}, yw]*
      G[{1/(yu*yv)}, yw]*G[{0, yv^(-1)}, yw] - G[{1}, yu^(-1)]*
      G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{0, yv^(-1)}, yw] - 
     2*G[{1}, yv^(-1)]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*
      G[{0, yv^(-1)}, yw] + 5*G[{1}, yw]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*
      G[{0, yv^(-1)}, yw] - 5*G[{yu^(-1)}, yw]*G[{yv^(-1)}, yw]*
      G[{1/(yu*yv)}, yw]*G[{0, yv^(-1)}, yw] - 5*G[{yu}, yv^(-1)]*
      G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{0, yv^(-1)}, yw] - 
     3*G[{yv^(-1)}, yw]^2*G[{1/(yu*yv)}, yw]*G[{0, yv^(-1)}, yw] - 
     (3*G[{0}, yu^(-1)]*G[{1/(yu*yv)}, yw]^2*G[{0, yv^(-1)}, yw])/2 - 
     (3*G[{0}, yv^(-1)]*G[{1/(yu*yv)}, yw]^2*G[{0, yv^(-1)}, yw])/2 + 
     (3*G[{0}, yw]*G[{1/(yu*yv)}, yw]^2*G[{0, yv^(-1)}, yw])/2 + 
     (G[{1}, yu^(-1)]*G[{1/(yu*yv)}, yw]^2*G[{0, yv^(-1)}, yw])/2 + 
     (G[{1}, yv^(-1)]*G[{1/(yu*yv)}, yw]^2*G[{0, yv^(-1)}, yw])/2 - 
     3*G[{1}, yw]*G[{1/(yu*yv)}, yw]^2*G[{0, yv^(-1)}, yw] + 
     (5*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2*G[{0, yv^(-1)}, yw])/2 + 
     2*G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw]^2*G[{0, yv^(-1)}, yw] + 
     (5*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2*G[{0, yv^(-1)}, yw])/2 - 
     (G[{1/(yu*yv)}, yw]^3*G[{0, yv^(-1)}, yw])/3 - 
     G[{0}, yu^(-1)]*G[{0, 1}, yu^(-1)]*G[{0, yv^(-1)}, yw] - 
     G[{0}, yv^(-1)]*G[{0, 1}, yu^(-1)]*G[{0, yv^(-1)}, yw] + 
     G[{0}, yw]*G[{0, 1}, yu^(-1)]*G[{0, yv^(-1)}, yw] - 
     G[{1}, yu^(-1)]*G[{0, 1}, yu^(-1)]*G[{0, yv^(-1)}, yw] - 
     G[{1}, yv^(-1)]*G[{0, 1}, yu^(-1)]*G[{0, yv^(-1)}, yw] + 
     2*G[{yu}, yv^(-1)]*G[{0, 1}, yu^(-1)]*G[{0, yv^(-1)}, yw] + 
     2*G[{yv^(-1)}, yw]*G[{0, 1}, yu^(-1)]*G[{0, yv^(-1)}, yw] - 
     2*G[{1/(yu*yv)}, yw]*G[{0, 1}, yu^(-1)]*G[{0, yv^(-1)}, yw] - 
     G[{0}, yu^(-1)]*G[{0, 1}, yv^(-1)]*G[{0, yv^(-1)}, yw] - 
     G[{0}, yv^(-1)]*G[{0, 1}, yv^(-1)]*G[{0, yv^(-1)}, yw] + 
     G[{0}, yw]*G[{0, 1}, yv^(-1)]*G[{0, yv^(-1)}, yw] - 
     G[{1}, yu^(-1)]*G[{0, 1}, yv^(-1)]*G[{0, yv^(-1)}, yw] - 
     G[{1}, yv^(-1)]*G[{0, 1}, yv^(-1)]*G[{0, yv^(-1)}, yw] + 
     2*G[{yu}, yv^(-1)]*G[{0, 1}, yv^(-1)]*G[{0, yv^(-1)}, yw] + 
     2*G[{yv^(-1)}, yw]*G[{0, 1}, yv^(-1)]*G[{0, yv^(-1)}, yw] - 
     2*G[{1/(yu*yv)}, yw]*G[{0, 1}, yv^(-1)]*G[{0, yv^(-1)}, yw] - 
     2*G[{0}, yu^(-1)]*G[{0, 1}, yw]*G[{0, yv^(-1)}, yw] - 
     2*G[{0}, yv^(-1)]*G[{0, 1}, yw]*G[{0, yv^(-1)}, yw] + 
     2*G[{0}, yw]*G[{0, 1}, yw]*G[{0, yv^(-1)}, yw] + 
     2*G[{1}, yu^(-1)]*G[{0, 1}, yw]*G[{0, yv^(-1)}, yw] + 
     2*G[{1}, yv^(-1)]*G[{0, 1}, yw]*G[{0, yv^(-1)}, yw] + 
     G[{1}, yw]*G[{0, 1}, yw]*G[{0, yv^(-1)}, yw] - 
     G[{yu^(-1)}, yw]*G[{0, 1}, yw]*G[{0, yv^(-1)}, yw] - 
     3*G[{yv^(-1)}, yw]*G[{0, 1}, yw]*G[{0, yv^(-1)}, yw] + 
     3*G[{1/(yu*yv)}, yw]*G[{0, 1}, yw]*G[{0, yv^(-1)}, yw] + 
     2*G[{0}, yu^(-1)]*G[{0, yu^(-1)}, yw]*G[{0, yv^(-1)}, yw] + 
     2*G[{0}, yv^(-1)]*G[{0, yu^(-1)}, yw]*G[{0, yv^(-1)}, yw] - 
     2*G[{0}, yw]*G[{0, yu^(-1)}, yw]*G[{0, yv^(-1)}, yw] - 
     2*G[{1}, yu^(-1)]*G[{0, yu^(-1)}, yw]*G[{0, yv^(-1)}, yw] - 
     4*G[{1}, yv^(-1)]*G[{0, yu^(-1)}, yw]*G[{0, yv^(-1)}, yw] - 
     G[{1}, yw]*G[{0, yu^(-1)}, yw]*G[{0, yv^(-1)}, yw] + 
     G[{yu^(-1)}, yw]*G[{0, yu^(-1)}, yw]*G[{0, yv^(-1)}, yw] + 
     2*G[{yu}, yv^(-1)]*G[{0, yu^(-1)}, yw]*G[{0, yv^(-1)}, yw] + 
     3*G[{yv^(-1)}, yw]*G[{0, yu^(-1)}, yw]*G[{0, yv^(-1)}, yw] - 
     3*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1)}, yw]*G[{0, yv^(-1)}, yw] + 
     G[{0}, yu^(-1)]*G[{0, yu}, yv^(-1)]*G[{0, yv^(-1)}, yw] + 
     G[{0}, yv^(-1)]*G[{0, yu}, yv^(-1)]*G[{0, yv^(-1)}, yw] - 
     G[{0}, yw]*G[{0, yu}, yv^(-1)]*G[{0, yv^(-1)}, yw] + 
     G[{1}, yu^(-1)]*G[{0, yu}, yv^(-1)]*G[{0, yv^(-1)}, yw] + 
     G[{1}, yv^(-1)]*G[{0, yu}, yv^(-1)]*G[{0, yv^(-1)}, yw] - 
     2*G[{yu}, yv^(-1)]*G[{0, yu}, yv^(-1)]*G[{0, yv^(-1)}, yw] - 
     2*G[{yv^(-1)}, yw]*G[{0, yu}, yv^(-1)]*G[{0, yv^(-1)}, yw] + 
     2*G[{1/(yu*yv)}, yw]*G[{0, yu}, yv^(-1)]*G[{0, yv^(-1)}, yw] + 
     G[{0}, yu^(-1)]*G[{0, yv^(-1)}, yw]^2 + G[{0}, yv^(-1)]*
      G[{0, yv^(-1)}, yw]^2 - G[{0}, yw]*G[{0, yv^(-1)}, yw]^2 - 
     2*G[{1}, yu^(-1)]*G[{0, yv^(-1)}, yw]^2 - G[{1}, yv^(-1)]*
      G[{0, yv^(-1)}, yw]^2 - (G[{1}, yw]*G[{0, yv^(-1)}, yw]^2)/2 + 
     (G[{yu^(-1)}, yw]*G[{0, yv^(-1)}, yw]^2)/2 + 
     G[{yu}, yv^(-1)]*G[{0, yv^(-1)}, yw]^2 + 
     (3*G[{yv^(-1)}, yw]*G[{0, yv^(-1)}, yw]^2)/2 - 
     (3*G[{1/(yu*yv)}, yw]*G[{0, yv^(-1)}, yw]^2)/2 + 
     (Pi^2*G[{1}, yu^(-1)]*G[{0, 1/(yu*yv)}, yw])/3 + 
     (Pi^2*G[{1}, yv^(-1)]*G[{0, 1/(yu*yv)}, yw])/3 + 
     G[{0}, yu^(-1)]*G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*G[{0, 1/(yu*yv)}, yw] + 
     G[{0}, yv^(-1)]*G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*G[{0, 1/(yu*yv)}, yw] - 
     G[{0}, yw]*G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*G[{0, 1/(yu*yv)}, yw] - 
     (3*G[{1}, yu^(-1)]^2*G[{1}, yv^(-1)]*G[{0, 1/(yu*yv)}, yw])/2 - 
     (Pi^2*G[{1}, yw]*G[{0, 1/(yu*yv)}, yw])/6 - G[{0}, yu^(-1)]^2*G[{1}, yw]*
      G[{0, 1/(yu*yv)}, yw] - 2*G[{0}, yu^(-1)]*G[{0}, yv^(-1)]*G[{1}, yw]*
      G[{0, 1/(yu*yv)}, yw] - G[{0}, yv^(-1)]^2*G[{1}, yw]*
      G[{0, 1/(yu*yv)}, yw] + 2*G[{0}, yu^(-1)]*G[{0}, yw]*G[{1}, yw]*
      G[{0, 1/(yu*yv)}, yw] + 2*G[{0}, yv^(-1)]*G[{0}, yw]*G[{1}, yw]*
      G[{0, 1/(yu*yv)}, yw] - G[{0}, yw]^2*G[{1}, yw]*G[{0, 1/(yu*yv)}, yw] + 
     4*G[{0}, yu^(-1)]*G[{1}, yu^(-1)]*G[{1}, yw]*G[{0, 1/(yu*yv)}, yw] + 
     4*G[{0}, yv^(-1)]*G[{1}, yu^(-1)]*G[{1}, yw]*G[{0, 1/(yu*yv)}, yw] - 
     4*G[{0}, yw]*G[{1}, yu^(-1)]*G[{1}, yw]*G[{0, 1/(yu*yv)}, yw] - 
     3*G[{1}, yu^(-1)]^2*G[{1}, yw]*G[{0, 1/(yu*yv)}, yw] + 
     4*G[{0}, yu^(-1)]*G[{1}, yv^(-1)]*G[{1}, yw]*G[{0, 1/(yu*yv)}, yw] + 
     4*G[{0}, yv^(-1)]*G[{1}, yv^(-1)]*G[{1}, yw]*G[{0, 1/(yu*yv)}, yw] - 
     4*G[{0}, yw]*G[{1}, yv^(-1)]*G[{1}, yw]*G[{0, 1/(yu*yv)}, yw] - 
     4*G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*G[{1}, yw]*G[{0, 1/(yu*yv)}, yw] - 
     3*G[{1}, yv^(-1)]^2*G[{1}, yw]*G[{0, 1/(yu*yv)}, yw] + 
     (G[{0}, yu^(-1)]*G[{1}, yw]^2*G[{0, 1/(yu*yv)}, yw])/2 + 
     (G[{0}, yv^(-1)]*G[{1}, yw]^2*G[{0, 1/(yu*yv)}, yw])/2 - 
     (G[{0}, yw]*G[{1}, yw]^2*G[{0, 1/(yu*yv)}, yw])/2 - 
     (G[{1}, yu^(-1)]*G[{1}, yw]^2*G[{0, 1/(yu*yv)}, yw])/2 - 
     (G[{1}, yv^(-1)]*G[{1}, yw]^2*G[{0, 1/(yu*yv)}, yw])/2 + 
     (G[{1}, yw]^3*G[{0, 1/(yu*yv)}, yw])/3 + 
     (Pi^2*G[{yu^(-1)}, yw]*G[{0, 1/(yu*yv)}, yw])/6 + 
     G[{0}, yu^(-1)]^2*G[{yu^(-1)}, yw]*G[{0, 1/(yu*yv)}, yw] + 
     2*G[{0}, yu^(-1)]*G[{0}, yv^(-1)]*G[{yu^(-1)}, yw]*
      G[{0, 1/(yu*yv)}, yw] + G[{0}, yv^(-1)]^2*G[{yu^(-1)}, yw]*
      G[{0, 1/(yu*yv)}, yw] - 2*G[{0}, yu^(-1)]*G[{0}, yw]*G[{yu^(-1)}, yw]*
      G[{0, 1/(yu*yv)}, yw] - 2*G[{0}, yv^(-1)]*G[{0}, yw]*G[{yu^(-1)}, yw]*
      G[{0, 1/(yu*yv)}, yw] + G[{0}, yw]^2*G[{yu^(-1)}, yw]*
      G[{0, 1/(yu*yv)}, yw] - 4*G[{0}, yu^(-1)]*G[{1}, yu^(-1)]*
      G[{yu^(-1)}, yw]*G[{0, 1/(yu*yv)}, yw] - 4*G[{0}, yv^(-1)]*
      G[{1}, yu^(-1)]*G[{yu^(-1)}, yw]*G[{0, 1/(yu*yv)}, yw] + 
     4*G[{0}, yw]*G[{1}, yu^(-1)]*G[{yu^(-1)}, yw]*G[{0, 1/(yu*yv)}, yw] + 
     3*G[{1}, yu^(-1)]^2*G[{yu^(-1)}, yw]*G[{0, 1/(yu*yv)}, yw] - 
     5*G[{0}, yu^(-1)]*G[{1}, yv^(-1)]*G[{yu^(-1)}, yw]*
      G[{0, 1/(yu*yv)}, yw] - 5*G[{0}, yv^(-1)]*G[{1}, yv^(-1)]*
      G[{yu^(-1)}, yw]*G[{0, 1/(yu*yv)}, yw] + 5*G[{0}, yw]*G[{1}, yv^(-1)]*
      G[{yu^(-1)}, yw]*G[{0, 1/(yu*yv)}, yw] + 3*G[{1}, yu^(-1)]*
      G[{1}, yv^(-1)]*G[{yu^(-1)}, yw]*G[{0, 1/(yu*yv)}, yw] + 
     (9*G[{1}, yv^(-1)]^2*G[{yu^(-1)}, yw]*G[{0, 1/(yu*yv)}, yw])/2 - 
     4*G[{0}, yu^(-1)]*G[{1}, yw]*G[{yu^(-1)}, yw]*G[{0, 1/(yu*yv)}, yw] - 
     4*G[{0}, yv^(-1)]*G[{1}, yw]*G[{yu^(-1)}, yw]*G[{0, 1/(yu*yv)}, yw] + 
     4*G[{0}, yw]*G[{1}, yw]*G[{yu^(-1)}, yw]*G[{0, 1/(yu*yv)}, yw] + 
     4*G[{1}, yu^(-1)]*G[{1}, yw]*G[{yu^(-1)}, yw]*G[{0, 1/(yu*yv)}, yw] + 
     3*G[{1}, yv^(-1)]*G[{1}, yw]*G[{yu^(-1)}, yw]*G[{0, 1/(yu*yv)}, yw] - 
     (3*G[{1}, yw]^2*G[{yu^(-1)}, yw]*G[{0, 1/(yu*yv)}, yw])/2 + 
     2*G[{0}, yu^(-1)]*G[{yu^(-1)}, yw]^2*G[{0, 1/(yu*yv)}, yw] + 
     2*G[{0}, yv^(-1)]*G[{yu^(-1)}, yw]^2*G[{0, 1/(yu*yv)}, yw] - 
     2*G[{0}, yw]*G[{yu^(-1)}, yw]^2*G[{0, 1/(yu*yv)}, yw] - 
     2*G[{1}, yu^(-1)]*G[{yu^(-1)}, yw]^2*G[{0, 1/(yu*yv)}, yw] - 
     (G[{1}, yv^(-1)]*G[{yu^(-1)}, yw]^2*G[{0, 1/(yu*yv)}, yw])/2 + 
     (3*G[{1}, yw]*G[{yu^(-1)}, yw]^2*G[{0, 1/(yu*yv)}, yw])/2 - 
     G[{yu^(-1)}, yw]^3*G[{0, 1/(yu*yv)}, yw] - 
     (Pi^2*G[{yu}, yv^(-1)]*G[{0, 1/(yu*yv)}, yw])/3 - 
     G[{0}, yu^(-1)]*G[{1}, yu^(-1)]*G[{yu}, yv^(-1)]*G[{0, 1/(yu*yv)}, yw] - 
     G[{0}, yv^(-1)]*G[{1}, yu^(-1)]*G[{yu}, yv^(-1)]*G[{0, 1/(yu*yv)}, yw] + 
     G[{0}, yw]*G[{1}, yu^(-1)]*G[{yu}, yv^(-1)]*G[{0, 1/(yu*yv)}, yw] + 
     (3*G[{1}, yu^(-1)]^2*G[{yu}, yv^(-1)]*G[{0, 1/(yu*yv)}, yw])/2 - 
     G[{0}, yu^(-1)]*G[{1}, yv^(-1)]*G[{yu}, yv^(-1)]*G[{0, 1/(yu*yv)}, yw] - 
     G[{0}, yv^(-1)]*G[{1}, yv^(-1)]*G[{yu}, yv^(-1)]*G[{0, 1/(yu*yv)}, yw] + 
     G[{0}, yw]*G[{1}, yv^(-1)]*G[{yu}, yv^(-1)]*G[{0, 1/(yu*yv)}, yw] - 
     2*G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*G[{yu}, yv^(-1)]*
      G[{0, 1/(yu*yv)}, yw] + (3*G[{1}, yv^(-1)]^2*G[{yu}, yv^(-1)]*
       G[{0, 1/(yu*yv)}, yw])/2 - 4*G[{0}, yu^(-1)]*G[{1}, yw]*
      G[{yu}, yv^(-1)]*G[{0, 1/(yu*yv)}, yw] - 4*G[{0}, yv^(-1)]*G[{1}, yw]*
      G[{yu}, yv^(-1)]*G[{0, 1/(yu*yv)}, yw] + 4*G[{0}, yw]*G[{1}, yw]*
      G[{yu}, yv^(-1)]*G[{0, 1/(yu*yv)}, yw] + 2*G[{1}, yu^(-1)]*G[{1}, yw]*
      G[{yu}, yv^(-1)]*G[{0, 1/(yu*yv)}, yw] + 2*G[{1}, yv^(-1)]*G[{1}, yw]*
      G[{yu}, yv^(-1)]*G[{0, 1/(yu*yv)}, yw] + 5*G[{0}, yu^(-1)]*
      G[{yu^(-1)}, yw]*G[{yu}, yv^(-1)]*G[{0, 1/(yu*yv)}, yw] + 
     5*G[{0}, yv^(-1)]*G[{yu^(-1)}, yw]*G[{yu}, yv^(-1)]*
      G[{0, 1/(yu*yv)}, yw] - 5*G[{0}, yw]*G[{yu^(-1)}, yw]*G[{yu}, yv^(-1)]*
      G[{0, 1/(yu*yv)}, yw] - G[{1}, yu^(-1)]*G[{yu^(-1)}, yw]*
      G[{yu}, yv^(-1)]*G[{0, 1/(yu*yv)}, yw] - 2*G[{1}, yv^(-1)]*
      G[{yu^(-1)}, yw]*G[{yu}, yv^(-1)]*G[{0, 1/(yu*yv)}, yw] + 
     G[{1}, yw]*G[{yu^(-1)}, yw]*G[{yu}, yv^(-1)]*G[{0, 1/(yu*yv)}, yw] - 
     (3*G[{yu^(-1)}, yw]^2*G[{yu}, yv^(-1)]*G[{0, 1/(yu*yv)}, yw])/2 + 
     G[{0}, yu^(-1)]*G[{yu}, yv^(-1)]^2*G[{0, 1/(yu*yv)}, yw] + 
     G[{0}, yv^(-1)]*G[{yu}, yv^(-1)]^2*G[{0, 1/(yu*yv)}, yw] - 
     G[{0}, yw]*G[{yu}, yv^(-1)]^2*G[{0, 1/(yu*yv)}, yw] + 
     (G[{1}, yu^(-1)]*G[{yu}, yv^(-1)]^2*G[{0, 1/(yu*yv)}, yw])/2 + 
     (G[{1}, yv^(-1)]*G[{yu}, yv^(-1)]^2*G[{0, 1/(yu*yv)}, yw])/2 + 
     2*G[{1}, yw]*G[{yu}, yv^(-1)]^2*G[{0, 1/(yu*yv)}, yw] - 
     (7*G[{yu^(-1)}, yw]*G[{yu}, yv^(-1)]^2*G[{0, 1/(yu*yv)}, yw])/2 - 
     G[{yu}, yv^(-1)]^3*G[{0, 1/(yu*yv)}, yw] + 
     (Pi^2*G[{yv^(-1)}, yw]*G[{0, 1/(yu*yv)}, yw])/6 + 
     G[{0}, yu^(-1)]^2*G[{yv^(-1)}, yw]*G[{0, 1/(yu*yv)}, yw] + 
     2*G[{0}, yu^(-1)]*G[{0}, yv^(-1)]*G[{yv^(-1)}, yw]*
      G[{0, 1/(yu*yv)}, yw] + G[{0}, yv^(-1)]^2*G[{yv^(-1)}, yw]*
      G[{0, 1/(yu*yv)}, yw] - 2*G[{0}, yu^(-1)]*G[{0}, yw]*G[{yv^(-1)}, yw]*
      G[{0, 1/(yu*yv)}, yw] - 2*G[{0}, yv^(-1)]*G[{0}, yw]*G[{yv^(-1)}, yw]*
      G[{0, 1/(yu*yv)}, yw] + G[{0}, yw]^2*G[{yv^(-1)}, yw]*
      G[{0, 1/(yu*yv)}, yw] - 5*G[{0}, yu^(-1)]*G[{1}, yu^(-1)]*
      G[{yv^(-1)}, yw]*G[{0, 1/(yu*yv)}, yw] - 5*G[{0}, yv^(-1)]*
      G[{1}, yu^(-1)]*G[{yv^(-1)}, yw]*G[{0, 1/(yu*yv)}, yw] + 
     5*G[{0}, yw]*G[{1}, yu^(-1)]*G[{yv^(-1)}, yw]*G[{0, 1/(yu*yv)}, yw] + 
     (9*G[{1}, yu^(-1)]^2*G[{yv^(-1)}, yw]*G[{0, 1/(yu*yv)}, yw])/2 - 
     4*G[{0}, yu^(-1)]*G[{1}, yv^(-1)]*G[{yv^(-1)}, yw]*
      G[{0, 1/(yu*yv)}, yw] - 4*G[{0}, yv^(-1)]*G[{1}, yv^(-1)]*
      G[{yv^(-1)}, yw]*G[{0, 1/(yu*yv)}, yw] + 4*G[{0}, yw]*G[{1}, yv^(-1)]*
      G[{yv^(-1)}, yw]*G[{0, 1/(yu*yv)}, yw] + 3*G[{1}, yu^(-1)]*
      G[{1}, yv^(-1)]*G[{yv^(-1)}, yw]*G[{0, 1/(yu*yv)}, yw] + 
     3*G[{1}, yv^(-1)]^2*G[{yv^(-1)}, yw]*G[{0, 1/(yu*yv)}, yw] - 
     4*G[{0}, yu^(-1)]*G[{1}, yw]*G[{yv^(-1)}, yw]*G[{0, 1/(yu*yv)}, yw] - 
     4*G[{0}, yv^(-1)]*G[{1}, yw]*G[{yv^(-1)}, yw]*G[{0, 1/(yu*yv)}, yw] + 
     4*G[{0}, yw]*G[{1}, yw]*G[{yv^(-1)}, yw]*G[{0, 1/(yu*yv)}, yw] + 
     3*G[{1}, yu^(-1)]*G[{1}, yw]*G[{yv^(-1)}, yw]*G[{0, 1/(yu*yv)}, yw] + 
     4*G[{1}, yv^(-1)]*G[{1}, yw]*G[{yv^(-1)}, yw]*G[{0, 1/(yu*yv)}, yw] - 
     (3*G[{1}, yw]^2*G[{yv^(-1)}, yw]*G[{0, 1/(yu*yv)}, yw])/2 + 
     G[{0}, yu^(-1)]*G[{yu^(-1)}, yw]*G[{yv^(-1)}, yw]*
      G[{0, 1/(yu*yv)}, yw] + G[{0}, yv^(-1)]*G[{yu^(-1)}, yw]*
      G[{yv^(-1)}, yw]*G[{0, 1/(yu*yv)}, yw] - G[{0}, yw]*G[{yu^(-1)}, yw]*
      G[{yv^(-1)}, yw]*G[{0, 1/(yu*yv)}, yw] + G[{1}, yu^(-1)]*
      G[{yu^(-1)}, yw]*G[{yv^(-1)}, yw]*G[{0, 1/(yu*yv)}, yw] + 
     G[{1}, yv^(-1)]*G[{yu^(-1)}, yw]*G[{yv^(-1)}, yw]*
      G[{0, 1/(yu*yv)}, yw] + 4*G[{1}, yw]*G[{yu^(-1)}, yw]*G[{yv^(-1)}, yw]*
      G[{0, 1/(yu*yv)}, yw] - (3*G[{yu^(-1)}, yw]^2*G[{yv^(-1)}, yw]*
       G[{0, 1/(yu*yv)}, yw])/2 + 5*G[{0}, yu^(-1)]*G[{yu}, yv^(-1)]*
      G[{yv^(-1)}, yw]*G[{0, 1/(yu*yv)}, yw] + 5*G[{0}, yv^(-1)]*
      G[{yu}, yv^(-1)]*G[{yv^(-1)}, yw]*G[{0, 1/(yu*yv)}, yw] - 
     5*G[{0}, yw]*G[{yu}, yv^(-1)]*G[{yv^(-1)}, yw]*G[{0, 1/(yu*yv)}, yw] - 
     2*G[{1}, yu^(-1)]*G[{yu}, yv^(-1)]*G[{yv^(-1)}, yw]*
      G[{0, 1/(yu*yv)}, yw] - G[{1}, yv^(-1)]*G[{yu}, yv^(-1)]*
      G[{yv^(-1)}, yw]*G[{0, 1/(yu*yv)}, yw] + G[{1}, yw]*G[{yu}, yv^(-1)]*
      G[{yv^(-1)}, yw]*G[{0, 1/(yu*yv)}, yw] - 4*G[{yu^(-1)}, yw]*
      G[{yu}, yv^(-1)]*G[{yv^(-1)}, yw]*G[{0, 1/(yu*yv)}, yw] - 
     (7*G[{yu}, yv^(-1)]^2*G[{yv^(-1)}, yw]*G[{0, 1/(yu*yv)}, yw])/2 + 
     2*G[{0}, yu^(-1)]*G[{yv^(-1)}, yw]^2*G[{0, 1/(yu*yv)}, yw] + 
     2*G[{0}, yv^(-1)]*G[{yv^(-1)}, yw]^2*G[{0, 1/(yu*yv)}, yw] - 
     2*G[{0}, yw]*G[{yv^(-1)}, yw]^2*G[{0, 1/(yu*yv)}, yw] - 
     (G[{1}, yu^(-1)]*G[{yv^(-1)}, yw]^2*G[{0, 1/(yu*yv)}, yw])/2 - 
     2*G[{1}, yv^(-1)]*G[{yv^(-1)}, yw]^2*G[{0, 1/(yu*yv)}, yw] + 
     (3*G[{1}, yw]*G[{yv^(-1)}, yw]^2*G[{0, 1/(yu*yv)}, yw])/2 - 
     (3*G[{yu^(-1)}, yw]*G[{yv^(-1)}, yw]^2*G[{0, 1/(yu*yv)}, yw])/2 - 
     (3*G[{yu}, yv^(-1)]*G[{yv^(-1)}, yw]^2*G[{0, 1/(yu*yv)}, yw])/2 - 
     G[{yv^(-1)}, yw]^3*G[{0, 1/(yu*yv)}, yw] - 
     (Pi^2*G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv)}, yw])/6 - 
     G[{0}, yu^(-1)]^2*G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv)}, yw] - 
     2*G[{0}, yu^(-1)]*G[{0}, yv^(-1)]*G[{1/(yu*yv)}, yw]*
      G[{0, 1/(yu*yv)}, yw] - G[{0}, yv^(-1)]^2*G[{1/(yu*yv)}, yw]*
      G[{0, 1/(yu*yv)}, yw] + 2*G[{0}, yu^(-1)]*G[{0}, yw]*G[{1/(yu*yv)}, yw]*
      G[{0, 1/(yu*yv)}, yw] + 2*G[{0}, yv^(-1)]*G[{0}, yw]*G[{1/(yu*yv)}, yw]*
      G[{0, 1/(yu*yv)}, yw] - G[{0}, yw]^2*G[{1/(yu*yv)}, yw]*
      G[{0, 1/(yu*yv)}, yw] + 5*G[{0}, yu^(-1)]*G[{1}, yu^(-1)]*
      G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv)}, yw] + 5*G[{0}, yv^(-1)]*
      G[{1}, yu^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv)}, yw] - 
     5*G[{0}, yw]*G[{1}, yu^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv)}, yw] - 
     (9*G[{1}, yu^(-1)]^2*G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv)}, yw])/2 + 
     5*G[{0}, yu^(-1)]*G[{1}, yv^(-1)]*G[{1/(yu*yv)}, yw]*
      G[{0, 1/(yu*yv)}, yw] + 5*G[{0}, yv^(-1)]*G[{1}, yv^(-1)]*
      G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv)}, yw] - 5*G[{0}, yw]*G[{1}, yv^(-1)]*
      G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv)}, yw] - 2*G[{1}, yu^(-1)]*
      G[{1}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv)}, yw] - 
     (9*G[{1}, yv^(-1)]^2*G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv)}, yw])/2 + 
     7*G[{0}, yu^(-1)]*G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv)}, yw] + 
     7*G[{0}, yv^(-1)]*G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv)}, yw] - 
     7*G[{0}, yw]*G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv)}, yw] - 
     6*G[{1}, yu^(-1)]*G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv)}, yw] - 
     6*G[{1}, yv^(-1)]*G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv)}, yw] + 
     2*G[{1}, yw]^2*G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv)}, yw] - 
     4*G[{0}, yu^(-1)]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*
      G[{0, 1/(yu*yv)}, yw] - 4*G[{0}, yv^(-1)]*G[{yu^(-1)}, yw]*
      G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv)}, yw] + 
     4*G[{0}, yw]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv)}, yw] + 
     2*G[{1}, yu^(-1)]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*
      G[{0, 1/(yu*yv)}, yw] + G[{1}, yv^(-1)]*G[{yu^(-1)}, yw]*
      G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv)}, yw] - 
     5*G[{1}, yw]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv)}, yw] + 
     3*G[{yu^(-1)}, yw]^2*G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv)}, yw] - 
     6*G[{0}, yu^(-1)]*G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw]*
      G[{0, 1/(yu*yv)}, yw] - 6*G[{0}, yv^(-1)]*G[{yu}, yv^(-1)]*
      G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv)}, yw] + 
     6*G[{0}, yw]*G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv)}, yw] + 
     G[{1}, yu^(-1)]*G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw]*
      G[{0, 1/(yu*yv)}, yw] + G[{1}, yv^(-1)]*G[{yu}, yv^(-1)]*
      G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv)}, yw] - 
     2*G[{1}, yw]*G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv)}, yw] + 
     5*G[{yu^(-1)}, yw]*G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw]*
      G[{0, 1/(yu*yv)}, yw] + 5*G[{yu}, yv^(-1)]^2*G[{1/(yu*yv)}, yw]*
      G[{0, 1/(yu*yv)}, yw] - 4*G[{0}, yu^(-1)]*G[{yv^(-1)}, yw]*
      G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv)}, yw] - 4*G[{0}, yv^(-1)]*
      G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv)}, yw] + 
     4*G[{0}, yw]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv)}, yw] + 
     G[{1}, yu^(-1)]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*
      G[{0, 1/(yu*yv)}, yw] + 2*G[{1}, yv^(-1)]*G[{yv^(-1)}, yw]*
      G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv)}, yw] - 
     5*G[{1}, yw]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv)}, yw] + 
     5*G[{yu^(-1)}, yw]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*
      G[{0, 1/(yu*yv)}, yw] + 5*G[{yu}, yv^(-1)]*G[{yv^(-1)}, yw]*
      G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv)}, yw] + 3*G[{yv^(-1)}, yw]^2*
      G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv)}, yw] + 
     (3*G[{0}, yu^(-1)]*G[{1/(yu*yv)}, yw]^2*G[{0, 1/(yu*yv)}, yw])/2 + 
     (3*G[{0}, yv^(-1)]*G[{1/(yu*yv)}, yw]^2*G[{0, 1/(yu*yv)}, yw])/2 - 
     (3*G[{0}, yw]*G[{1/(yu*yv)}, yw]^2*G[{0, 1/(yu*yv)}, yw])/2 - 
     (G[{1}, yu^(-1)]*G[{1/(yu*yv)}, yw]^2*G[{0, 1/(yu*yv)}, yw])/2 - 
     (G[{1}, yv^(-1)]*G[{1/(yu*yv)}, yw]^2*G[{0, 1/(yu*yv)}, yw])/2 + 
     3*G[{1}, yw]*G[{1/(yu*yv)}, yw]^2*G[{0, 1/(yu*yv)}, yw] - 
     (5*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2*G[{0, 1/(yu*yv)}, yw])/2 - 
     2*G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw]^2*G[{0, 1/(yu*yv)}, yw] - 
     (5*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2*G[{0, 1/(yu*yv)}, yw])/2 + 
     (G[{1/(yu*yv)}, yw]^3*G[{0, 1/(yu*yv)}, yw])/3 + 
     G[{0}, yu^(-1)]*G[{0, 1}, yu^(-1)]*G[{0, 1/(yu*yv)}, yw] + 
     G[{0}, yv^(-1)]*G[{0, 1}, yu^(-1)]*G[{0, 1/(yu*yv)}, yw] - 
     G[{0}, yw]*G[{0, 1}, yu^(-1)]*G[{0, 1/(yu*yv)}, yw] + 
     G[{1}, yu^(-1)]*G[{0, 1}, yu^(-1)]*G[{0, 1/(yu*yv)}, yw] + 
     G[{1}, yv^(-1)]*G[{0, 1}, yu^(-1)]*G[{0, 1/(yu*yv)}, yw] + 
     2*G[{1}, yw]*G[{0, 1}, yu^(-1)]*G[{0, 1/(yu*yv)}, yw] - 
     2*G[{yu^(-1)}, yw]*G[{0, 1}, yu^(-1)]*G[{0, 1/(yu*yv)}, yw] - 
     2*G[{yu}, yv^(-1)]*G[{0, 1}, yu^(-1)]*G[{0, 1/(yu*yv)}, yw] - 
     2*G[{yv^(-1)}, yw]*G[{0, 1}, yu^(-1)]*G[{0, 1/(yu*yv)}, yw] + 
     2*G[{1/(yu*yv)}, yw]*G[{0, 1}, yu^(-1)]*G[{0, 1/(yu*yv)}, yw] + 
     G[{0}, yu^(-1)]*G[{0, 1}, yv^(-1)]*G[{0, 1/(yu*yv)}, yw] + 
     G[{0}, yv^(-1)]*G[{0, 1}, yv^(-1)]*G[{0, 1/(yu*yv)}, yw] - 
     G[{0}, yw]*G[{0, 1}, yv^(-1)]*G[{0, 1/(yu*yv)}, yw] + 
     G[{1}, yu^(-1)]*G[{0, 1}, yv^(-1)]*G[{0, 1/(yu*yv)}, yw] + 
     G[{1}, yv^(-1)]*G[{0, 1}, yv^(-1)]*G[{0, 1/(yu*yv)}, yw] + 
     2*G[{1}, yw]*G[{0, 1}, yv^(-1)]*G[{0, 1/(yu*yv)}, yw] - 
     2*G[{yu^(-1)}, yw]*G[{0, 1}, yv^(-1)]*G[{0, 1/(yu*yv)}, yw] - 
     2*G[{yu}, yv^(-1)]*G[{0, 1}, yv^(-1)]*G[{0, 1/(yu*yv)}, yw] - 
     2*G[{yv^(-1)}, yw]*G[{0, 1}, yv^(-1)]*G[{0, 1/(yu*yv)}, yw] + 
     2*G[{1/(yu*yv)}, yw]*G[{0, 1}, yv^(-1)]*G[{0, 1/(yu*yv)}, yw] + 
     2*G[{0}, yu^(-1)]*G[{0, 1}, yw]*G[{0, 1/(yu*yv)}, yw] + 
     2*G[{0}, yv^(-1)]*G[{0, 1}, yw]*G[{0, 1/(yu*yv)}, yw] - 
     2*G[{0}, yw]*G[{0, 1}, yw]*G[{0, 1/(yu*yv)}, yw] - 
     2*G[{1}, yu^(-1)]*G[{0, 1}, yw]*G[{0, 1/(yu*yv)}, yw] - 
     2*G[{1}, yv^(-1)]*G[{0, 1}, yw]*G[{0, 1/(yu*yv)}, yw] - 
     3*G[{1}, yw]*G[{0, 1}, yw]*G[{0, 1/(yu*yv)}, yw] + 
     3*G[{yu^(-1)}, yw]*G[{0, 1}, yw]*G[{0, 1/(yu*yv)}, yw] + 
     3*G[{yv^(-1)}, yw]*G[{0, 1}, yw]*G[{0, 1/(yu*yv)}, yw] - 
     3*G[{1/(yu*yv)}, yw]*G[{0, 1}, yw]*G[{0, 1/(yu*yv)}, yw] - 
     2*G[{0}, yu^(-1)]*G[{0, yu^(-1)}, yw]*G[{0, 1/(yu*yv)}, yw] - 
     2*G[{0}, yv^(-1)]*G[{0, yu^(-1)}, yw]*G[{0, 1/(yu*yv)}, yw] + 
     2*G[{0}, yw]*G[{0, yu^(-1)}, yw]*G[{0, 1/(yu*yv)}, yw] + 
     2*G[{1}, yu^(-1)]*G[{0, yu^(-1)}, yw]*G[{0, 1/(yu*yv)}, yw] + 
     4*G[{1}, yv^(-1)]*G[{0, yu^(-1)}, yw]*G[{0, 1/(yu*yv)}, yw] + 
     3*G[{1}, yw]*G[{0, yu^(-1)}, yw]*G[{0, 1/(yu*yv)}, yw] - 
     3*G[{yu^(-1)}, yw]*G[{0, yu^(-1)}, yw]*G[{0, 1/(yu*yv)}, yw] - 
     2*G[{yu}, yv^(-1)]*G[{0, yu^(-1)}, yw]*G[{0, 1/(yu*yv)}, yw] - 
     3*G[{yv^(-1)}, yw]*G[{0, yu^(-1)}, yw]*G[{0, 1/(yu*yv)}, yw] + 
     3*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1)}, yw]*G[{0, 1/(yu*yv)}, yw] - 
     G[{0}, yu^(-1)]*G[{0, yu}, yv^(-1)]*G[{0, 1/(yu*yv)}, yw] - 
     G[{0}, yv^(-1)]*G[{0, yu}, yv^(-1)]*G[{0, 1/(yu*yv)}, yw] + 
     G[{0}, yw]*G[{0, yu}, yv^(-1)]*G[{0, 1/(yu*yv)}, yw] - 
     G[{1}, yu^(-1)]*G[{0, yu}, yv^(-1)]*G[{0, 1/(yu*yv)}, yw] - 
     G[{1}, yv^(-1)]*G[{0, yu}, yv^(-1)]*G[{0, 1/(yu*yv)}, yw] - 
     2*G[{1}, yw]*G[{0, yu}, yv^(-1)]*G[{0, 1/(yu*yv)}, yw] + 
     2*G[{yu^(-1)}, yw]*G[{0, yu}, yv^(-1)]*G[{0, 1/(yu*yv)}, yw] + 
     2*G[{yu}, yv^(-1)]*G[{0, yu}, yv^(-1)]*G[{0, 1/(yu*yv)}, yw] + 
     2*G[{yv^(-1)}, yw]*G[{0, yu}, yv^(-1)]*G[{0, 1/(yu*yv)}, yw] - 
     2*G[{1/(yu*yv)}, yw]*G[{0, yu}, yv^(-1)]*G[{0, 1/(yu*yv)}, yw] - 
     2*G[{0}, yu^(-1)]*G[{0, yv^(-1)}, yw]*G[{0, 1/(yu*yv)}, yw] - 
     2*G[{0}, yv^(-1)]*G[{0, yv^(-1)}, yw]*G[{0, 1/(yu*yv)}, yw] + 
     2*G[{0}, yw]*G[{0, yv^(-1)}, yw]*G[{0, 1/(yu*yv)}, yw] + 
     4*G[{1}, yu^(-1)]*G[{0, yv^(-1)}, yw]*G[{0, 1/(yu*yv)}, yw] + 
     2*G[{1}, yv^(-1)]*G[{0, yv^(-1)}, yw]*G[{0, 1/(yu*yv)}, yw] + 
     3*G[{1}, yw]*G[{0, yv^(-1)}, yw]*G[{0, 1/(yu*yv)}, yw] - 
     3*G[{yu^(-1)}, yw]*G[{0, yv^(-1)}, yw]*G[{0, 1/(yu*yv)}, yw] - 
     2*G[{yu}, yv^(-1)]*G[{0, yv^(-1)}, yw]*G[{0, 1/(yu*yv)}, yw] - 
     3*G[{yv^(-1)}, yw]*G[{0, yv^(-1)}, yw]*G[{0, 1/(yu*yv)}, yw] + 
     3*G[{1/(yu*yv)}, yw]*G[{0, yv^(-1)}, yw]*G[{0, 1/(yu*yv)}, yw] + 
     G[{0}, yu^(-1)]*G[{0, 1/(yu*yv)}, yw]^2 + G[{0}, yv^(-1)]*
      G[{0, 1/(yu*yv)}, yw]^2 - G[{0}, yw]*G[{0, 1/(yu*yv)}, yw]^2 - 
     2*G[{1}, yu^(-1)]*G[{0, 1/(yu*yv)}, yw]^2 - 2*G[{1}, yv^(-1)]*
      G[{0, 1/(yu*yv)}, yw]^2 - (3*G[{1}, yw]*G[{0, 1/(yu*yv)}, yw]^2)/2 + 
     (3*G[{yu^(-1)}, yw]*G[{0, 1/(yu*yv)}, yw]^2)/2 + 
     2*G[{yu}, yv^(-1)]*G[{0, 1/(yu*yv)}, yw]^2 + 
     (3*G[{yv^(-1)}, yw]*G[{0, 1/(yu*yv)}, yw]^2)/2 - 
     (3*G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv)}, yw]^2)/2 - 
     (Pi^2*G[{1}, yv^(-1)]*G[{1, yu^(-1)}, yw])/6 + 
     G[{0}, yu^(-1)]*G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*G[{1, yu^(-1)}, yw] + 
     G[{0}, yv^(-1)]*G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*G[{1, yu^(-1)}, yw] - 
     G[{0}, yw]*G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*G[{1, yu^(-1)}, yw] - 
     G[{1}, yu^(-1)]^2*G[{1}, yv^(-1)]*G[{1, yu^(-1)}, yw] + 
     (Pi^2*G[{1}, yw]*G[{1, yu^(-1)}, yw])/6 + 
     (3*G[{0}, yu^(-1)]^2*G[{1}, yw]*G[{1, yu^(-1)}, yw])/2 + 
     3*G[{0}, yu^(-1)]*G[{0}, yv^(-1)]*G[{1}, yw]*G[{1, yu^(-1)}, yw] + 
     (3*G[{0}, yv^(-1)]^2*G[{1}, yw]*G[{1, yu^(-1)}, yw])/2 - 
     3*G[{0}, yu^(-1)]*G[{0}, yw]*G[{1}, yw]*G[{1, yu^(-1)}, yw] - 
     3*G[{0}, yv^(-1)]*G[{0}, yw]*G[{1}, yw]*G[{1, yu^(-1)}, yw] + 
     (3*G[{0}, yw]^2*G[{1}, yw]*G[{1, yu^(-1)}, yw])/2 - 
     3*G[{0}, yu^(-1)]*G[{1}, yu^(-1)]*G[{1}, yw]*G[{1, yu^(-1)}, yw] - 
     3*G[{0}, yv^(-1)]*G[{1}, yu^(-1)]*G[{1}, yw]*G[{1, yu^(-1)}, yw] + 
     3*G[{0}, yw]*G[{1}, yu^(-1)]*G[{1}, yw]*G[{1, yu^(-1)}, yw] + 
     (3*G[{1}, yu^(-1)]^2*G[{1}, yw]*G[{1, yu^(-1)}, yw])/2 - 
     4*G[{0}, yu^(-1)]*G[{1}, yv^(-1)]*G[{1}, yw]*G[{1, yu^(-1)}, yw] - 
     4*G[{0}, yv^(-1)]*G[{1}, yv^(-1)]*G[{1}, yw]*G[{1, yu^(-1)}, yw] + 
     4*G[{0}, yw]*G[{1}, yv^(-1)]*G[{1}, yw]*G[{1, yu^(-1)}, yw] + 
     5*G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*G[{1}, yw]*G[{1, yu^(-1)}, yw] + 
     (5*G[{1}, yv^(-1)]^2*G[{1}, yw]*G[{1, yu^(-1)}, yw])/2 + 
     (Pi^2*G[{yu^(-1)}, yw]*G[{1, yu^(-1)}, yw])/6 + 
     (G[{0}, yu^(-1)]^2*G[{yu^(-1)}, yw]*G[{1, yu^(-1)}, yw])/2 + 
     G[{0}, yu^(-1)]*G[{0}, yv^(-1)]*G[{yu^(-1)}, yw]*G[{1, yu^(-1)}, yw] + 
     (G[{0}, yv^(-1)]^2*G[{yu^(-1)}, yw]*G[{1, yu^(-1)}, yw])/2 - 
     G[{0}, yu^(-1)]*G[{0}, yw]*G[{yu^(-1)}, yw]*G[{1, yu^(-1)}, yw] - 
     G[{0}, yv^(-1)]*G[{0}, yw]*G[{yu^(-1)}, yw]*G[{1, yu^(-1)}, yw] + 
     (G[{0}, yw]^2*G[{yu^(-1)}, yw]*G[{1, yu^(-1)}, yw])/2 - 
     G[{0}, yu^(-1)]*G[{1}, yu^(-1)]*G[{yu^(-1)}, yw]*G[{1, yu^(-1)}, yw] - 
     G[{0}, yv^(-1)]*G[{1}, yu^(-1)]*G[{yu^(-1)}, yw]*G[{1, yu^(-1)}, yw] + 
     G[{0}, yw]*G[{1}, yu^(-1)]*G[{yu^(-1)}, yw]*G[{1, yu^(-1)}, yw] + 
     (G[{1}, yu^(-1)]^2*G[{yu^(-1)}, yw]*G[{1, yu^(-1)}, yw])/2 - 
     G[{0}, yu^(-1)]*G[{1}, yv^(-1)]*G[{yu^(-1)}, yw]*G[{1, yu^(-1)}, yw] - 
     G[{0}, yv^(-1)]*G[{1}, yv^(-1)]*G[{yu^(-1)}, yw]*G[{1, yu^(-1)}, yw] + 
     G[{0}, yw]*G[{1}, yv^(-1)]*G[{yu^(-1)}, yw]*G[{1, yu^(-1)}, yw] + 
     G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*G[{yu^(-1)}, yw]*G[{1, yu^(-1)}, yw] + 
     G[{0}, yu^(-1)]*G[{1}, yw]*G[{yu^(-1)}, yw]*G[{1, yu^(-1)}, yw] + 
     G[{0}, yv^(-1)]*G[{1}, yw]*G[{yu^(-1)}, yw]*G[{1, yu^(-1)}, yw] - 
     G[{0}, yw]*G[{1}, yw]*G[{yu^(-1)}, yw]*G[{1, yu^(-1)}, yw] - 
     G[{1}, yu^(-1)]*G[{1}, yw]*G[{yu^(-1)}, yw]*G[{1, yu^(-1)}, yw] - 
     2*G[{1}, yv^(-1)]*G[{1}, yw]*G[{yu^(-1)}, yw]*G[{1, yu^(-1)}, yw] - 
     (G[{1}, yw]^2*G[{yu^(-1)}, yw]*G[{1, yu^(-1)}, yw])/2 + 
     (7*G[{0}, yu^(-1)]*G[{yu^(-1)}, yw]^2*G[{1, yu^(-1)}, yw])/2 + 
     (7*G[{0}, yv^(-1)]*G[{yu^(-1)}, yw]^2*G[{1, yu^(-1)}, yw])/2 - 
     (7*G[{0}, yw]*G[{yu^(-1)}, yw]^2*G[{1, yu^(-1)}, yw])/2 - 
     (7*G[{1}, yu^(-1)]*G[{yu^(-1)}, yw]^2*G[{1, yu^(-1)}, yw])/2 + 
     (7*G[{1}, yw]*G[{yu^(-1)}, yw]^2*G[{1, yu^(-1)}, yw])/2 + 
     (Pi^2*G[{yu}, yv^(-1)]*G[{1, yu^(-1)}, yw])/6 - 
     G[{0}, yu^(-1)]*G[{1}, yu^(-1)]*G[{yu}, yv^(-1)]*G[{1, yu^(-1)}, yw] - 
     G[{0}, yv^(-1)]*G[{1}, yu^(-1)]*G[{yu}, yv^(-1)]*G[{1, yu^(-1)}, yw] + 
     G[{0}, yw]*G[{1}, yu^(-1)]*G[{yu}, yv^(-1)]*G[{1, yu^(-1)}, yw] + 
     G[{1}, yu^(-1)]^2*G[{yu}, yv^(-1)]*G[{1, yu^(-1)}, yw] - 
     G[{0}, yu^(-1)]*G[{1}, yv^(-1)]*G[{yu}, yv^(-1)]*G[{1, yu^(-1)}, yw] - 
     G[{0}, yv^(-1)]*G[{1}, yv^(-1)]*G[{yu}, yv^(-1)]*G[{1, yu^(-1)}, yw] + 
     G[{0}, yw]*G[{1}, yv^(-1)]*G[{yu}, yv^(-1)]*G[{1, yu^(-1)}, yw] + 
     (5*G[{1}, yv^(-1)]^2*G[{yu}, yv^(-1)]*G[{1, yu^(-1)}, yw])/2 + 
     G[{0}, yu^(-1)]*G[{1}, yw]*G[{yu}, yv^(-1)]*G[{1, yu^(-1)}, yw] + 
     G[{0}, yv^(-1)]*G[{1}, yw]*G[{yu}, yv^(-1)]*G[{1, yu^(-1)}, yw] - 
     G[{0}, yw]*G[{1}, yw]*G[{yu}, yv^(-1)]*G[{1, yu^(-1)}, yw] - 
     2*G[{1}, yu^(-1)]*G[{1}, yw]*G[{yu}, yv^(-1)]*G[{1, yu^(-1)}, yw] - 
     G[{1}, yv^(-1)]*G[{1}, yw]*G[{yu}, yv^(-1)]*G[{1, yu^(-1)}, yw] + 
     G[{1}, yw]*G[{yu^(-1)}, yw]*G[{yu}, yv^(-1)]*G[{1, yu^(-1)}, yw] - 
     (7*G[{yu^(-1)}, yw]^2*G[{yu}, yv^(-1)]*G[{1, yu^(-1)}, yw])/2 + 
     G[{0}, yu^(-1)]*G[{yu}, yv^(-1)]^2*G[{1, yu^(-1)}, yw] + 
     G[{0}, yv^(-1)]*G[{yu}, yv^(-1)]^2*G[{1, yu^(-1)}, yw] - 
     G[{0}, yw]*G[{yu}, yv^(-1)]^2*G[{1, yu^(-1)}, yw] - 
     G[{1}, yv^(-1)]*G[{yu}, yv^(-1)]^2*G[{1, yu^(-1)}, yw] + 
     (G[{1}, yw]*G[{yu}, yv^(-1)]^2*G[{1, yu^(-1)}, yw])/2 - 
     (G[{yu}, yv^(-1)]^3*G[{1, yu^(-1)}, yw])/3 + 
     (5*Pi^2*G[{yv^(-1)}, yw]*G[{1, yu^(-1)}, yw])/6 + 
     (G[{0}, yu^(-1)]^2*G[{yv^(-1)}, yw]*G[{1, yu^(-1)}, yw])/2 + 
     G[{0}, yu^(-1)]*G[{0}, yv^(-1)]*G[{yv^(-1)}, yw]*G[{1, yu^(-1)}, yw] + 
     (G[{0}, yv^(-1)]^2*G[{yv^(-1)}, yw]*G[{1, yu^(-1)}, yw])/2 - 
     G[{0}, yu^(-1)]*G[{0}, yw]*G[{yv^(-1)}, yw]*G[{1, yu^(-1)}, yw] - 
     G[{0}, yv^(-1)]*G[{0}, yw]*G[{yv^(-1)}, yw]*G[{1, yu^(-1)}, yw] + 
     (G[{0}, yw]^2*G[{yv^(-1)}, yw]*G[{1, yu^(-1)}, yw])/2 - 
     4*G[{0}, yu^(-1)]*G[{1}, yu^(-1)]*G[{yv^(-1)}, yw]*G[{1, yu^(-1)}, yw] - 
     4*G[{0}, yv^(-1)]*G[{1}, yu^(-1)]*G[{yv^(-1)}, yw]*G[{1, yu^(-1)}, yw] + 
     4*G[{0}, yw]*G[{1}, yu^(-1)]*G[{yv^(-1)}, yw]*G[{1, yu^(-1)}, yw] + 
     (7*G[{1}, yu^(-1)]^2*G[{yv^(-1)}, yw]*G[{1, yu^(-1)}, yw])/2 - 
     2*G[{0}, yu^(-1)]*G[{1}, yv^(-1)]*G[{yv^(-1)}, yw]*G[{1, yu^(-1)}, yw] - 
     2*G[{0}, yv^(-1)]*G[{1}, yv^(-1)]*G[{yv^(-1)}, yw]*G[{1, yu^(-1)}, yw] + 
     2*G[{0}, yw]*G[{1}, yv^(-1)]*G[{yv^(-1)}, yw]*G[{1, yu^(-1)}, yw] + 
     4*G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*G[{yv^(-1)}, yw]*G[{1, yu^(-1)}, yw] + 
     (3*G[{1}, yv^(-1)]^2*G[{yv^(-1)}, yw]*G[{1, yu^(-1)}, yw])/2 - 
     5*G[{0}, yu^(-1)]*G[{1}, yw]*G[{yv^(-1)}, yw]*G[{1, yu^(-1)}, yw] - 
     5*G[{0}, yv^(-1)]*G[{1}, yw]*G[{yv^(-1)}, yw]*G[{1, yu^(-1)}, yw] + 
     5*G[{0}, yw]*G[{1}, yw]*G[{yv^(-1)}, yw]*G[{1, yu^(-1)}, yw] + 
     2*G[{1}, yu^(-1)]*G[{1}, yw]*G[{yv^(-1)}, yw]*G[{1, yu^(-1)}, yw] + 
     2*G[{1}, yv^(-1)]*G[{1}, yw]*G[{yv^(-1)}, yw]*G[{1, yu^(-1)}, yw] - 
     3*G[{1}, yw]^2*G[{yv^(-1)}, yw]*G[{1, yu^(-1)}, yw] + 
     2*G[{0}, yu^(-1)]*G[{yu^(-1)}, yw]*G[{yv^(-1)}, yw]*
      G[{1, yu^(-1)}, yw] + 2*G[{0}, yv^(-1)]*G[{yu^(-1)}, yw]*
      G[{yv^(-1)}, yw]*G[{1, yu^(-1)}, yw] - 2*G[{0}, yw]*G[{yu^(-1)}, yw]*
      G[{yv^(-1)}, yw]*G[{1, yu^(-1)}, yw] - 2*G[{1}, yu^(-1)]*
      G[{yu^(-1)}, yw]*G[{yv^(-1)}, yw]*G[{1, yu^(-1)}, yw] + 
     3*G[{1}, yv^(-1)]*G[{yu^(-1)}, yw]*G[{yv^(-1)}, yw]*
      G[{1, yu^(-1)}, yw] + 5*G[{1}, yw]*G[{yu^(-1)}, yw]*G[{yv^(-1)}, yw]*
      G[{1, yu^(-1)}, yw] + 4*G[{0}, yu^(-1)]*G[{yu}, yv^(-1)]*
      G[{yv^(-1)}, yw]*G[{1, yu^(-1)}, yw] + 4*G[{0}, yv^(-1)]*
      G[{yu}, yv^(-1)]*G[{yv^(-1)}, yw]*G[{1, yu^(-1)}, yw] - 
     4*G[{0}, yw]*G[{yu}, yv^(-1)]*G[{yv^(-1)}, yw]*G[{1, yu^(-1)}, yw] - 
     3*G[{1}, yu^(-1)]*G[{yu}, yv^(-1)]*G[{yv^(-1)}, yw]*
      G[{1, yu^(-1)}, yw] - 3*G[{1}, yv^(-1)]*G[{yu}, yv^(-1)]*
      G[{yv^(-1)}, yw]*G[{1, yu^(-1)}, yw] + 6*G[{1}, yw]*G[{yu}, yv^(-1)]*
      G[{yv^(-1)}, yw]*G[{1, yu^(-1)}, yw] - 5*G[{yu^(-1)}, yw]*
      G[{yu}, yv^(-1)]*G[{yv^(-1)}, yw]*G[{1, yu^(-1)}, yw] - 
     G[{yu}, yv^(-1)]^2*G[{yv^(-1)}, yw]*G[{1, yu^(-1)}, yw] + 
     (7*G[{0}, yu^(-1)]*G[{yv^(-1)}, yw]^2*G[{1, yu^(-1)}, yw])/2 + 
     (7*G[{0}, yv^(-1)]*G[{yv^(-1)}, yw]^2*G[{1, yu^(-1)}, yw])/2 - 
     (7*G[{0}, yw]*G[{yv^(-1)}, yw]^2*G[{1, yu^(-1)}, yw])/2 - 
     (7*G[{1}, yu^(-1)]*G[{yv^(-1)}, yw]^2*G[{1, yu^(-1)}, yw])/2 - 
     (5*G[{1}, yv^(-1)]*G[{yv^(-1)}, yw]^2*G[{1, yu^(-1)}, yw])/2 + 
     G[{1}, yw]*G[{yv^(-1)}, yw]^2*G[{1, yu^(-1)}, yw] - 
     G[{yu}, yv^(-1)]*G[{yv^(-1)}, yw]^2*G[{1, yu^(-1)}, yw] - 
     (Pi^2*G[{1/(yu*yv)}, yw]*G[{1, yu^(-1)}, yw])/6 - 
     (G[{0}, yu^(-1)]^2*G[{1/(yu*yv)}, yw]*G[{1, yu^(-1)}, yw])/2 - 
     G[{0}, yu^(-1)]*G[{0}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{1, yu^(-1)}, yw] - 
     (G[{0}, yv^(-1)]^2*G[{1/(yu*yv)}, yw]*G[{1, yu^(-1)}, yw])/2 + 
     G[{0}, yu^(-1)]*G[{0}, yw]*G[{1/(yu*yv)}, yw]*G[{1, yu^(-1)}, yw] + 
     G[{0}, yv^(-1)]*G[{0}, yw]*G[{1/(yu*yv)}, yw]*G[{1, yu^(-1)}, yw] - 
     (G[{0}, yw]^2*G[{1/(yu*yv)}, yw]*G[{1, yu^(-1)}, yw])/2 + 
     4*G[{0}, yu^(-1)]*G[{1}, yu^(-1)]*G[{1/(yu*yv)}, yw]*
      G[{1, yu^(-1)}, yw] + 4*G[{0}, yv^(-1)]*G[{1}, yu^(-1)]*
      G[{1/(yu*yv)}, yw]*G[{1, yu^(-1)}, yw] - 4*G[{0}, yw]*G[{1}, yu^(-1)]*
      G[{1/(yu*yv)}, yw]*G[{1, yu^(-1)}, yw] - 
     (7*G[{1}, yu^(-1)]^2*G[{1/(yu*yv)}, yw]*G[{1, yu^(-1)}, yw])/2 + 
     G[{0}, yu^(-1)]*G[{1}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{1, yu^(-1)}, yw] + 
     G[{0}, yv^(-1)]*G[{1}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{1, yu^(-1)}, yw] - 
     G[{0}, yw]*G[{1}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{1, yu^(-1)}, yw] - 
     G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{1, yu^(-1)}, yw] + 
     2*G[{0}, yu^(-1)]*G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{1, yu^(-1)}, yw] + 
     2*G[{0}, yv^(-1)]*G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{1, yu^(-1)}, yw] - 
     2*G[{0}, yw]*G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{1, yu^(-1)}, yw] + 
     G[{1}, yu^(-1)]*G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{1, yu^(-1)}, yw] + 
     2*G[{1}, yv^(-1)]*G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{1, yu^(-1)}, yw] + 
     (7*G[{1}, yw]^2*G[{1/(yu*yv)}, yw]*G[{1, yu^(-1)}, yw])/2 - 
     7*G[{0}, yu^(-1)]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*
      G[{1, yu^(-1)}, yw] - 7*G[{0}, yv^(-1)]*G[{yu^(-1)}, yw]*
      G[{1/(yu*yv)}, yw]*G[{1, yu^(-1)}, yw] + 7*G[{0}, yw]*G[{yu^(-1)}, yw]*
      G[{1/(yu*yv)}, yw]*G[{1, yu^(-1)}, yw] + 7*G[{1}, yu^(-1)]*
      G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{1, yu^(-1)}, yw] - 
     7*G[{1}, yw]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{1, yu^(-1)}, yw] - 
     3*G[{0}, yu^(-1)]*G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw]*
      G[{1, yu^(-1)}, yw] - 3*G[{0}, yv^(-1)]*G[{yu}, yv^(-1)]*
      G[{1/(yu*yv)}, yw]*G[{1, yu^(-1)}, yw] + 3*G[{0}, yw]*G[{yu}, yv^(-1)]*
      G[{1/(yu*yv)}, yw]*G[{1, yu^(-1)}, yw] - 7*G[{1}, yw]*G[{yu}, yv^(-1)]*
      G[{1/(yu*yv)}, yw]*G[{1, yu^(-1)}, yw] + 7*G[{yu^(-1)}, yw]*
      G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{1, yu^(-1)}, yw] + 
     3*G[{yu}, yv^(-1)]^2*G[{1/(yu*yv)}, yw]*G[{1, yu^(-1)}, yw] - 
     7*G[{0}, yu^(-1)]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*
      G[{1, yu^(-1)}, yw] - 7*G[{0}, yv^(-1)]*G[{yv^(-1)}, yw]*
      G[{1/(yu*yv)}, yw]*G[{1, yu^(-1)}, yw] + 7*G[{0}, yw]*G[{yv^(-1)}, yw]*
      G[{1/(yu*yv)}, yw]*G[{1, yu^(-1)}, yw] + 7*G[{1}, yu^(-1)]*
      G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{1, yu^(-1)}, yw] + 
     G[{1}, yv^(-1)]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*
      G[{1, yu^(-1)}, yw] - 6*G[{1}, yw]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*
      G[{1, yu^(-1)}, yw] + 6*G[{yu}, yv^(-1)]*G[{yv^(-1)}, yw]*
      G[{1/(yu*yv)}, yw]*G[{1, yu^(-1)}, yw] + 
     (5*G[{0}, yu^(-1)]*G[{1/(yu*yv)}, yw]^2*G[{1, yu^(-1)}, yw])/2 + 
     (5*G[{0}, yv^(-1)]*G[{1/(yu*yv)}, yw]^2*G[{1, yu^(-1)}, yw])/2 - 
     (5*G[{0}, yw]*G[{1/(yu*yv)}, yw]^2*G[{1, yu^(-1)}, yw])/2 - 
     (5*G[{1}, yu^(-1)]*G[{1/(yu*yv)}, yw]^2*G[{1, yu^(-1)}, yw])/2 + 
     (5*G[{1}, yw]*G[{1/(yu*yv)}, yw]^2*G[{1, yu^(-1)}, yw])/2 - 
     (5*G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw]^2*G[{1, yu^(-1)}, yw])/2 - 
     (G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2*G[{1, yu^(-1)}, yw])/2 + 
     G[{0}, yu^(-1)]*G[{0, 1}, yu^(-1)]*G[{1, yu^(-1)}, yw] + 
     G[{0}, yv^(-1)]*G[{0, 1}, yu^(-1)]*G[{1, yu^(-1)}, yw] - 
     G[{0}, yw]*G[{0, 1}, yu^(-1)]*G[{1, yu^(-1)}, yw] - 
     G[{1}, yu^(-1)]*G[{0, 1}, yu^(-1)]*G[{1, yu^(-1)}, yw] + 
     G[{1}, yw]*G[{0, 1}, yu^(-1)]*G[{1, yu^(-1)}, yw] - 
     G[{yu}, yv^(-1)]*G[{0, 1}, yu^(-1)]*G[{1, yu^(-1)}, yw] + 
     2*G[{yv^(-1)}, yw]*G[{0, 1}, yu^(-1)]*G[{1, yu^(-1)}, yw] + 
     G[{0}, yu^(-1)]*G[{0, 1}, yv^(-1)]*G[{1, yu^(-1)}, yw] + 
     G[{0}, yv^(-1)]*G[{0, 1}, yv^(-1)]*G[{1, yu^(-1)}, yw] - 
     G[{0}, yw]*G[{0, 1}, yv^(-1)]*G[{1, yu^(-1)}, yw] - 
     G[{1}, yu^(-1)]*G[{0, 1}, yv^(-1)]*G[{1, yu^(-1)}, yw] - 
     G[{1}, yv^(-1)]*G[{0, 1}, yv^(-1)]*G[{1, yu^(-1)}, yw] + 
     G[{yu^(-1)}, yw]*G[{0, 1}, yv^(-1)]*G[{1, yu^(-1)}, yw] - 
     2*G[{yu}, yv^(-1)]*G[{0, 1}, yv^(-1)]*G[{1, yu^(-1)}, yw] + 
     2*G[{yv^(-1)}, yw]*G[{0, 1}, yv^(-1)]*G[{1, yu^(-1)}, yw] - 
     G[{1/(yu*yv)}, yw]*G[{0, 1}, yv^(-1)]*G[{1, yu^(-1)}, yw] + 
     3*G[{0}, yu^(-1)]*G[{0, 1}, yw]*G[{1, yu^(-1)}, yw] + 
     3*G[{0}, yv^(-1)]*G[{0, 1}, yw]*G[{1, yu^(-1)}, yw] - 
     3*G[{0}, yw]*G[{0, 1}, yw]*G[{1, yu^(-1)}, yw] - 
     3*G[{1}, yu^(-1)]*G[{0, 1}, yw]*G[{1, yu^(-1)}, yw] - 
     4*G[{1}, yv^(-1)]*G[{0, 1}, yw]*G[{1, yu^(-1)}, yw] + 
     G[{1}, yw]*G[{0, 1}, yw]*G[{1, yu^(-1)}, yw] + 
     G[{yu^(-1)}, yw]*G[{0, 1}, yw]*G[{1, yu^(-1)}, yw] + 
     G[{yu}, yv^(-1)]*G[{0, 1}, yw]*G[{1, yu^(-1)}, yw] - 
     G[{yv^(-1)}, yw]*G[{0, 1}, yw]*G[{1, yu^(-1)}, yw] - 
     G[{1/(yu*yv)}, yw]*G[{0, 1}, yw]*G[{1, yu^(-1)}, yw] - 
     3*G[{0}, yu^(-1)]*G[{0, yu^(-1)}, yw]*G[{1, yu^(-1)}, yw] - 
     3*G[{0}, yv^(-1)]*G[{0, yu^(-1)}, yw]*G[{1, yu^(-1)}, yw] + 
     3*G[{0}, yw]*G[{0, yu^(-1)}, yw]*G[{1, yu^(-1)}, yw] + 
     3*G[{1}, yu^(-1)]*G[{0, yu^(-1)}, yw]*G[{1, yu^(-1)}, yw] + 
     4*G[{1}, yv^(-1)]*G[{0, yu^(-1)}, yw]*G[{1, yu^(-1)}, yw] - 
     G[{1}, yw]*G[{0, yu^(-1)}, yw]*G[{1, yu^(-1)}, yw] - 
     G[{yu^(-1)}, yw]*G[{0, yu^(-1)}, yw]*G[{1, yu^(-1)}, yw] - 
     G[{yu}, yv^(-1)]*G[{0, yu^(-1)}, yw]*G[{1, yu^(-1)}, yw] + 
     G[{yv^(-1)}, yw]*G[{0, yu^(-1)}, yw]*G[{1, yu^(-1)}, yw] + 
     G[{1/(yu*yv)}, yw]*G[{0, yu^(-1)}, yw]*G[{1, yu^(-1)}, yw] - 
     G[{0}, yu^(-1)]*G[{0, yu}, yv^(-1)]*G[{1, yu^(-1)}, yw] - 
     G[{0}, yv^(-1)]*G[{0, yu}, yv^(-1)]*G[{1, yu^(-1)}, yw] + 
     G[{0}, yw]*G[{0, yu}, yv^(-1)]*G[{1, yu^(-1)}, yw] + 
     G[{1}, yu^(-1)]*G[{0, yu}, yv^(-1)]*G[{1, yu^(-1)}, yw] + 
     G[{1}, yv^(-1)]*G[{0, yu}, yv^(-1)]*G[{1, yu^(-1)}, yw] - 
     G[{yu^(-1)}, yw]*G[{0, yu}, yv^(-1)]*G[{1, yu^(-1)}, yw] + 
     2*G[{yu}, yv^(-1)]*G[{0, yu}, yv^(-1)]*G[{1, yu^(-1)}, yw] - 
     2*G[{yv^(-1)}, yw]*G[{0, yu}, yv^(-1)]*G[{1, yu^(-1)}, yw] + 
     G[{1/(yu*yv)}, yw]*G[{0, yu}, yv^(-1)]*G[{1, yu^(-1)}, yw] - 
     3*G[{0}, yu^(-1)]*G[{0, yv^(-1)}, yw]*G[{1, yu^(-1)}, yw] - 
     3*G[{0}, yv^(-1)]*G[{0, yv^(-1)}, yw]*G[{1, yu^(-1)}, yw] + 
     3*G[{0}, yw]*G[{0, yv^(-1)}, yw]*G[{1, yu^(-1)}, yw] + 
     3*G[{1}, yu^(-1)]*G[{0, yv^(-1)}, yw]*G[{1, yu^(-1)}, yw] + 
     4*G[{1}, yv^(-1)]*G[{0, yv^(-1)}, yw]*G[{1, yu^(-1)}, yw] - 
     G[{1}, yw]*G[{0, yv^(-1)}, yw]*G[{1, yu^(-1)}, yw] - 
     G[{yu^(-1)}, yw]*G[{0, yv^(-1)}, yw]*G[{1, yu^(-1)}, yw] - 
     G[{yu}, yv^(-1)]*G[{0, yv^(-1)}, yw]*G[{1, yu^(-1)}, yw] + 
     G[{yv^(-1)}, yw]*G[{0, yv^(-1)}, yw]*G[{1, yu^(-1)}, yw] + 
     G[{1/(yu*yv)}, yw]*G[{0, yv^(-1)}, yw]*G[{1, yu^(-1)}, yw] + 
     3*G[{0}, yu^(-1)]*G[{0, 1/(yu*yv)}, yw]*G[{1, yu^(-1)}, yw] + 
     3*G[{0}, yv^(-1)]*G[{0, 1/(yu*yv)}, yw]*G[{1, yu^(-1)}, yw] - 
     3*G[{0}, yw]*G[{0, 1/(yu*yv)}, yw]*G[{1, yu^(-1)}, yw] - 
     3*G[{1}, yu^(-1)]*G[{0, 1/(yu*yv)}, yw]*G[{1, yu^(-1)}, yw] - 
     4*G[{1}, yv^(-1)]*G[{0, 1/(yu*yv)}, yw]*G[{1, yu^(-1)}, yw] + 
     G[{1}, yw]*G[{0, 1/(yu*yv)}, yw]*G[{1, yu^(-1)}, yw] + 
     G[{yu^(-1)}, yw]*G[{0, 1/(yu*yv)}, yw]*G[{1, yu^(-1)}, yw] + 
     G[{yu}, yv^(-1)]*G[{0, 1/(yu*yv)}, yw]*G[{1, yu^(-1)}, yw] - 
     G[{yv^(-1)}, yw]*G[{0, 1/(yu*yv)}, yw]*G[{1, yu^(-1)}, yw] - 
     G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv)}, yw]*G[{1, yu^(-1)}, yw] + 
     2*G[{0}, yu^(-1)]*G[{1, yu^(-1)}, yw]^2 + 2*G[{0}, yv^(-1)]*
      G[{1, yu^(-1)}, yw]^2 - 2*G[{0}, yw]*G[{1, yu^(-1)}, yw]^2 - 
     2*G[{1}, yu^(-1)]*G[{1, yu^(-1)}, yw]^2 - 4*G[{1}, yv^(-1)]*
      G[{1, yu^(-1)}, yw]^2 - 2*G[{1}, yw]*G[{1, yu^(-1)}, yw]^2 + 
     G[{yu^(-1)}, yw]*G[{1, yu^(-1)}, yw]^2 + 2*G[{yu}, yv^(-1)]*
      G[{1, yu^(-1)}, yw]^2 + (G[{yv^(-1)}, yw]*G[{1, yu^(-1)}, yw]^2)/2 - 
     G[{1/(yu*yv)}, yw]*G[{1, yu^(-1)}, yw]^2 + 
     (Pi^2*G[{1}, yu^(-1)]*G[{1, yu}, yv^(-1)])/6 - 
     (Pi^2*G[{1}, yv^(-1)]*G[{1, yu}, yv^(-1)])/6 + 
     (3*G[{1}, yu^(-1)]^2*G[{1}, yv^(-1)]*G[{1, yu}, yv^(-1)])/2 + 
     3*G[{0}, yu^(-1)]*G[{1}, yu^(-1)]*G[{1}, yw]*G[{1, yu}, yv^(-1)] + 
     3*G[{0}, yv^(-1)]*G[{1}, yu^(-1)]*G[{1}, yw]*G[{1, yu}, yv^(-1)] - 
     3*G[{0}, yw]*G[{1}, yu^(-1)]*G[{1}, yw]*G[{1, yu}, yv^(-1)] - 
     3*G[{1}, yu^(-1)]^2*G[{1}, yw]*G[{1, yu}, yv^(-1)] - 
     3*G[{0}, yu^(-1)]*G[{1}, yv^(-1)]*G[{1}, yw]*G[{1, yu}, yv^(-1)] - 
     3*G[{0}, yv^(-1)]*G[{1}, yv^(-1)]*G[{1}, yw]*G[{1, yu}, yv^(-1)] + 
     3*G[{0}, yw]*G[{1}, yv^(-1)]*G[{1}, yw]*G[{1, yu}, yv^(-1)] + 
     3*G[{1}, yv^(-1)]^2*G[{1}, yw]*G[{1, yu}, yv^(-1)] - 
     (2*Pi^2*G[{yu^(-1)}, yw]*G[{1, yu}, yv^(-1)])/3 - 
     3*G[{0}, yu^(-1)]*G[{1}, yu^(-1)]*G[{yu^(-1)}, yw]*G[{1, yu}, yv^(-1)] - 
     3*G[{0}, yv^(-1)]*G[{1}, yu^(-1)]*G[{yu^(-1)}, yw]*G[{1, yu}, yv^(-1)] + 
     3*G[{0}, yw]*G[{1}, yu^(-1)]*G[{yu^(-1)}, yw]*G[{1, yu}, yv^(-1)] + 
     3*G[{1}, yu^(-1)]^2*G[{yu^(-1)}, yw]*G[{1, yu}, yv^(-1)] + 
     3*G[{0}, yu^(-1)]*G[{1}, yv^(-1)]*G[{yu^(-1)}, yw]*G[{1, yu}, yv^(-1)] + 
     3*G[{0}, yv^(-1)]*G[{1}, yv^(-1)]*G[{yu^(-1)}, yw]*G[{1, yu}, yv^(-1)] - 
     3*G[{0}, yw]*G[{1}, yv^(-1)]*G[{yu^(-1)}, yw]*G[{1, yu}, yv^(-1)] - 
     3*G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*G[{yu^(-1)}, yw]*G[{1, yu}, yv^(-1)] - 
     (7*G[{1}, yv^(-1)]^2*G[{yu^(-1)}, yw]*G[{1, yu}, yv^(-1)])/2 + 
     G[{1}, yu^(-1)]*G[{1}, yw]*G[{yu^(-1)}, yw]*G[{1, yu}, yv^(-1)] - 
     G[{1}, yv^(-1)]*G[{1}, yw]*G[{yu^(-1)}, yw]*G[{1, yu}, yv^(-1)] + 
     (G[{1}, yw]^2*G[{yu^(-1)}, yw]*G[{1, yu}, yv^(-1)])/2 - 
     G[{1}, yu^(-1)]*G[{yu^(-1)}, yw]^2*G[{1, yu}, yv^(-1)] + 
     (7*G[{1}, yv^(-1)]*G[{yu^(-1)}, yw]^2*G[{1, yu}, yv^(-1)])/2 + 
     (G[{1}, yu^(-1)]^2*G[{yu}, yv^(-1)]*G[{1, yu}, yv^(-1)])/2 - 
     G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*G[{yu}, yv^(-1)]*G[{1, yu}, yv^(-1)] - 
     (G[{1}, yv^(-1)]^2*G[{yu}, yv^(-1)]*G[{1, yu}, yv^(-1)])/2 - 
     5*G[{1}, yu^(-1)]*G[{yu^(-1)}, yw]*G[{yu}, yv^(-1)]*
      G[{1, yu}, yv^(-1)] + 2*G[{1}, yv^(-1)]*G[{yu^(-1)}, yw]*
      G[{yu}, yv^(-1)]*G[{1, yu}, yv^(-1)] + G[{1}, yw]*G[{yu^(-1)}, yw]*
      G[{yu}, yv^(-1)]*G[{1, yu}, yv^(-1)] - 
     (7*G[{1}, yu^(-1)]*G[{yu}, yv^(-1)]^2*G[{1, yu}, yv^(-1)])/2 + 
     (7*G[{1}, yv^(-1)]*G[{yu}, yv^(-1)]^2*G[{1, yu}, yv^(-1)])/2 + 
     (2*Pi^2*G[{yv^(-1)}, yw]*G[{1, yu}, yv^(-1)])/3 - 
     3*G[{0}, yu^(-1)]*G[{1}, yu^(-1)]*G[{yv^(-1)}, yw]*G[{1, yu}, yv^(-1)] - 
     3*G[{0}, yv^(-1)]*G[{1}, yu^(-1)]*G[{yv^(-1)}, yw]*G[{1, yu}, yv^(-1)] + 
     3*G[{0}, yw]*G[{1}, yu^(-1)]*G[{yv^(-1)}, yw]*G[{1, yu}, yv^(-1)] + 
     (7*G[{1}, yu^(-1)]^2*G[{yv^(-1)}, yw]*G[{1, yu}, yv^(-1)])/2 + 
     3*G[{0}, yu^(-1)]*G[{1}, yv^(-1)]*G[{yv^(-1)}, yw]*G[{1, yu}, yv^(-1)] + 
     3*G[{0}, yv^(-1)]*G[{1}, yv^(-1)]*G[{yv^(-1)}, yw]*G[{1, yu}, yv^(-1)] - 
     3*G[{0}, yw]*G[{1}, yv^(-1)]*G[{yv^(-1)}, yw]*G[{1, yu}, yv^(-1)] + 
     2*G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*G[{yv^(-1)}, yw]*G[{1, yu}, yv^(-1)] - 
     3*G[{1}, yv^(-1)]^2*G[{yv^(-1)}, yw]*G[{1, yu}, yv^(-1)] + 
     G[{1}, yu^(-1)]*G[{1}, yw]*G[{yv^(-1)}, yw]*G[{1, yu}, yv^(-1)] - 
     G[{1}, yv^(-1)]*G[{1}, yw]*G[{yv^(-1)}, yw]*G[{1, yu}, yv^(-1)] - 
     (G[{1}, yw]^2*G[{yv^(-1)}, yw]*G[{1, yu}, yv^(-1)])/2 - 
     5*G[{1}, yu^(-1)]*G[{yu^(-1)}, yw]*G[{yv^(-1)}, yw]*
      G[{1, yu}, yv^(-1)] + 5*G[{1}, yv^(-1)]*G[{yu^(-1)}, yw]*
      G[{yv^(-1)}, yw]*G[{1, yu}, yv^(-1)] - 2*G[{1}, yu^(-1)]*
      G[{yu}, yv^(-1)]*G[{yv^(-1)}, yw]*G[{1, yu}, yv^(-1)] + 
     5*G[{1}, yv^(-1)]*G[{yu}, yv^(-1)]*G[{yv^(-1)}, yw]*
      G[{1, yu}, yv^(-1)] - G[{1}, yw]*G[{yu}, yv^(-1)]*G[{yv^(-1)}, yw]*
      G[{1, yu}, yv^(-1)] - (7*G[{1}, yu^(-1)]*G[{yv^(-1)}, yw]^2*
       G[{1, yu}, yv^(-1)])/2 + G[{1}, yv^(-1)]*G[{yv^(-1)}, yw]^2*
      G[{1, yu}, yv^(-1)] + 3*G[{0}, yu^(-1)]*G[{1}, yu^(-1)]*
      G[{1/(yu*yv)}, yw]*G[{1, yu}, yv^(-1)] + 3*G[{0}, yv^(-1)]*
      G[{1}, yu^(-1)]*G[{1/(yu*yv)}, yw]*G[{1, yu}, yv^(-1)] - 
     3*G[{0}, yw]*G[{1}, yu^(-1)]*G[{1/(yu*yv)}, yw]*G[{1, yu}, yv^(-1)] - 
     (7*G[{1}, yu^(-1)]^2*G[{1/(yu*yv)}, yw]*G[{1, yu}, yv^(-1)])/2 - 
     3*G[{0}, yu^(-1)]*G[{1}, yv^(-1)]*G[{1/(yu*yv)}, yw]*
      G[{1, yu}, yv^(-1)] - 3*G[{0}, yv^(-1)]*G[{1}, yv^(-1)]*
      G[{1/(yu*yv)}, yw]*G[{1, yu}, yv^(-1)] + 3*G[{0}, yw]*G[{1}, yv^(-1)]*
      G[{1/(yu*yv)}, yw]*G[{1, yu}, yv^(-1)] + G[{1}, yu^(-1)]*
      G[{1}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{1, yu}, yv^(-1)] + 
     (7*G[{1}, yv^(-1)]^2*G[{1/(yu*yv)}, yw]*G[{1, yu}, yv^(-1)])/2 - 
     2*G[{1}, yu^(-1)]*G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{1, yu}, yv^(-1)] + 
     2*G[{1}, yv^(-1)]*G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{1, yu}, yv^(-1)] + 
     6*G[{1}, yu^(-1)]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*
      G[{1, yu}, yv^(-1)] - 7*G[{1}, yv^(-1)]*G[{yu^(-1)}, yw]*
      G[{1/(yu*yv)}, yw]*G[{1, yu}, yv^(-1)] + 7*G[{1}, yu^(-1)]*
      G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{1, yu}, yv^(-1)] - 
     7*G[{1}, yv^(-1)]*G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw]*
      G[{1, yu}, yv^(-1)] + 7*G[{1}, yu^(-1)]*G[{yv^(-1)}, yw]*
      G[{1/(yu*yv)}, yw]*G[{1, yu}, yv^(-1)] - 6*G[{1}, yv^(-1)]*
      G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{1, yu}, yv^(-1)] - 
     (5*G[{1}, yu^(-1)]*G[{1/(yu*yv)}, yw]^2*G[{1, yu}, yv^(-1)])/2 + 
     (5*G[{1}, yv^(-1)]*G[{1/(yu*yv)}, yw]^2*G[{1, yu}, yv^(-1)])/2 + 
     (G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2*G[{1, yu}, yv^(-1)])/2 - 
     (G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2*G[{1, yu}, yv^(-1)])/2 - 
     G[{1}, yv^(-1)]*G[{0, 1}, yu^(-1)]*G[{1, yu}, yv^(-1)] - 
     2*G[{yu^(-1)}, yw]*G[{0, 1}, yu^(-1)]*G[{1, yu}, yv^(-1)] - 
     G[{yu}, yv^(-1)]*G[{0, 1}, yu^(-1)]*G[{1, yu}, yv^(-1)] + 
     G[{yv^(-1)}, yw]*G[{0, 1}, yu^(-1)]*G[{1, yu}, yv^(-1)] + 
     G[{1/(yu*yv)}, yw]*G[{0, 1}, yu^(-1)]*G[{1, yu}, yv^(-1)] - 
     G[{1}, yu^(-1)]*G[{0, 1}, yv^(-1)]*G[{1, yu}, yv^(-1)] - 
     G[{yu^(-1)}, yw]*G[{0, 1}, yv^(-1)]*G[{1, yu}, yv^(-1)] + 
     G[{yu}, yv^(-1)]*G[{0, 1}, yv^(-1)]*G[{1, yu}, yv^(-1)] + 
     2*G[{yv^(-1)}, yw]*G[{0, 1}, yv^(-1)]*G[{1, yu}, yv^(-1)] - 
     G[{1/(yu*yv)}, yw]*G[{0, 1}, yv^(-1)]*G[{1, yu}, yv^(-1)] + 
     3*G[{1}, yu^(-1)]*G[{0, 1}, yw]*G[{1, yu}, yv^(-1)] - 
     3*G[{1}, yv^(-1)]*G[{0, 1}, yw]*G[{1, yu}, yv^(-1)] - 
     3*G[{1}, yu^(-1)]*G[{0, yu^(-1)}, yw]*G[{1, yu}, yv^(-1)] + 
     3*G[{1}, yv^(-1)]*G[{0, yu^(-1)}, yw]*G[{1, yu}, yv^(-1)] + 
     G[{1}, yu^(-1)]*G[{0, yu}, yv^(-1)]*G[{1, yu}, yv^(-1)] + 
     G[{yu^(-1)}, yw]*G[{0, yu}, yv^(-1)]*G[{1, yu}, yv^(-1)] - 
     G[{yu}, yv^(-1)]*G[{0, yu}, yv^(-1)]*G[{1, yu}, yv^(-1)] - 
     2*G[{yv^(-1)}, yw]*G[{0, yu}, yv^(-1)]*G[{1, yu}, yv^(-1)] + 
     G[{1/(yu*yv)}, yw]*G[{0, yu}, yv^(-1)]*G[{1, yu}, yv^(-1)] - 
     3*G[{1}, yu^(-1)]*G[{0, yv^(-1)}, yw]*G[{1, yu}, yv^(-1)] + 
     3*G[{1}, yv^(-1)]*G[{0, yv^(-1)}, yw]*G[{1, yu}, yv^(-1)] + 
     3*G[{1}, yu^(-1)]*G[{0, 1/(yu*yv)}, yw]*G[{1, yu}, yv^(-1)] - 
     3*G[{1}, yv^(-1)]*G[{0, 1/(yu*yv)}, yw]*G[{1, yu}, yv^(-1)] - 
     4*G[{1}, yv^(-1)]*G[{1, yu^(-1)}, yw]*G[{1, yu}, yv^(-1)] - 
     G[{1}, yw]*G[{1, yu^(-1)}, yw]*G[{1, yu}, yv^(-1)] + 
     G[{yu^(-1)}, yw]*G[{1, yu^(-1)}, yw]*G[{1, yu}, yv^(-1)] - 
     G[{yu}, yv^(-1)]*G[{1, yu^(-1)}, yw]*G[{1, yu}, yv^(-1)] - 
     G[{1/(yu*yv)}, yw]*G[{1, yu^(-1)}, yw]*G[{1, yu}, yv^(-1)] - 
     2*G[{1}, yu^(-1)]*G[{1, yu}, yv^(-1)]^2 - 2*G[{1}, yv^(-1)]*
      G[{1, yu}, yv^(-1)]^2 + (G[{yu^(-1)}, yw]*G[{1, yu}, yv^(-1)]^2)/2 + 
     G[{yu}, yv^(-1)]*G[{1, yu}, yv^(-1)]^2 + 
     (G[{yv^(-1)}, yw]*G[{1, yu}, yv^(-1)]^2)/2 - G[{1/(yu*yv)}, yw]*
      G[{1, yu}, yv^(-1)]^2 - (Pi^2*G[{1}, yu^(-1)]*G[{1, yv^(-1)}, yw])/6 + 
     G[{0}, yu^(-1)]*G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*G[{1, yv^(-1)}, yw] + 
     G[{0}, yv^(-1)]*G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*G[{1, yv^(-1)}, yw] - 
     G[{0}, yw]*G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*G[{1, yv^(-1)}, yw] - 
     (5*G[{1}, yu^(-1)]^2*G[{1}, yv^(-1)]*G[{1, yv^(-1)}, yw])/2 + 
     (Pi^2*G[{1}, yw]*G[{1, yv^(-1)}, yw])/6 + 
     (3*G[{0}, yu^(-1)]^2*G[{1}, yw]*G[{1, yv^(-1)}, yw])/2 + 
     3*G[{0}, yu^(-1)]*G[{0}, yv^(-1)]*G[{1}, yw]*G[{1, yv^(-1)}, yw] + 
     (3*G[{0}, yv^(-1)]^2*G[{1}, yw]*G[{1, yv^(-1)}, yw])/2 - 
     3*G[{0}, yu^(-1)]*G[{0}, yw]*G[{1}, yw]*G[{1, yv^(-1)}, yw] - 
     3*G[{0}, yv^(-1)]*G[{0}, yw]*G[{1}, yw]*G[{1, yv^(-1)}, yw] + 
     (3*G[{0}, yw]^2*G[{1}, yw]*G[{1, yv^(-1)}, yw])/2 - 
     4*G[{0}, yu^(-1)]*G[{1}, yu^(-1)]*G[{1}, yw]*G[{1, yv^(-1)}, yw] - 
     4*G[{0}, yv^(-1)]*G[{1}, yu^(-1)]*G[{1}, yw]*G[{1, yv^(-1)}, yw] + 
     4*G[{0}, yw]*G[{1}, yu^(-1)]*G[{1}, yw]*G[{1, yv^(-1)}, yw] + 
     (5*G[{1}, yu^(-1)]^2*G[{1}, yw]*G[{1, yv^(-1)}, yw])/2 - 
     3*G[{0}, yu^(-1)]*G[{1}, yv^(-1)]*G[{1}, yw]*G[{1, yv^(-1)}, yw] - 
     3*G[{0}, yv^(-1)]*G[{1}, yv^(-1)]*G[{1}, yw]*G[{1, yv^(-1)}, yw] + 
     3*G[{0}, yw]*G[{1}, yv^(-1)]*G[{1}, yw]*G[{1, yv^(-1)}, yw] + 
     4*G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*G[{1}, yw]*G[{1, yv^(-1)}, yw] + 
     (3*G[{1}, yv^(-1)]^2*G[{1}, yw]*G[{1, yv^(-1)}, yw])/2 + 
     (5*Pi^2*G[{yu^(-1)}, yw]*G[{1, yv^(-1)}, yw])/6 + 
     (G[{0}, yu^(-1)]^2*G[{yu^(-1)}, yw]*G[{1, yv^(-1)}, yw])/2 + 
     G[{0}, yu^(-1)]*G[{0}, yv^(-1)]*G[{yu^(-1)}, yw]*G[{1, yv^(-1)}, yw] + 
     (G[{0}, yv^(-1)]^2*G[{yu^(-1)}, yw]*G[{1, yv^(-1)}, yw])/2 - 
     G[{0}, yu^(-1)]*G[{0}, yw]*G[{yu^(-1)}, yw]*G[{1, yv^(-1)}, yw] - 
     G[{0}, yv^(-1)]*G[{0}, yw]*G[{yu^(-1)}, yw]*G[{1, yv^(-1)}, yw] + 
     (G[{0}, yw]^2*G[{yu^(-1)}, yw]*G[{1, yv^(-1)}, yw])/2 - 
     2*G[{0}, yu^(-1)]*G[{1}, yu^(-1)]*G[{yu^(-1)}, yw]*G[{1, yv^(-1)}, yw] - 
     2*G[{0}, yv^(-1)]*G[{1}, yu^(-1)]*G[{yu^(-1)}, yw]*G[{1, yv^(-1)}, yw] + 
     2*G[{0}, yw]*G[{1}, yu^(-1)]*G[{yu^(-1)}, yw]*G[{1, yv^(-1)}, yw] + 
     (3*G[{1}, yu^(-1)]^2*G[{yu^(-1)}, yw]*G[{1, yv^(-1)}, yw])/2 - 
     4*G[{0}, yu^(-1)]*G[{1}, yv^(-1)]*G[{yu^(-1)}, yw]*G[{1, yv^(-1)}, yw] - 
     4*G[{0}, yv^(-1)]*G[{1}, yv^(-1)]*G[{yu^(-1)}, yw]*G[{1, yv^(-1)}, yw] + 
     4*G[{0}, yw]*G[{1}, yv^(-1)]*G[{yu^(-1)}, yw]*G[{1, yv^(-1)}, yw] + 
     4*G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*G[{yu^(-1)}, yw]*G[{1, yv^(-1)}, yw] + 
     (7*G[{1}, yv^(-1)]^2*G[{yu^(-1)}, yw]*G[{1, yv^(-1)}, yw])/2 - 
     5*G[{0}, yu^(-1)]*G[{1}, yw]*G[{yu^(-1)}, yw]*G[{1, yv^(-1)}, yw] - 
     5*G[{0}, yv^(-1)]*G[{1}, yw]*G[{yu^(-1)}, yw]*G[{1, yv^(-1)}, yw] + 
     5*G[{0}, yw]*G[{1}, yw]*G[{yu^(-1)}, yw]*G[{1, yv^(-1)}, yw] + 
     2*G[{1}, yu^(-1)]*G[{1}, yw]*G[{yu^(-1)}, yw]*G[{1, yv^(-1)}, yw] + 
     2*G[{1}, yv^(-1)]*G[{1}, yw]*G[{yu^(-1)}, yw]*G[{1, yv^(-1)}, yw] - 
     3*G[{1}, yw]^2*G[{yu^(-1)}, yw]*G[{1, yv^(-1)}, yw] + 
     (7*G[{0}, yu^(-1)]*G[{yu^(-1)}, yw]^2*G[{1, yv^(-1)}, yw])/2 + 
     (7*G[{0}, yv^(-1)]*G[{yu^(-1)}, yw]^2*G[{1, yv^(-1)}, yw])/2 - 
     (7*G[{0}, yw]*G[{yu^(-1)}, yw]^2*G[{1, yv^(-1)}, yw])/2 - 
     (5*G[{1}, yu^(-1)]*G[{yu^(-1)}, yw]^2*G[{1, yv^(-1)}, yw])/2 - 
     (7*G[{1}, yv^(-1)]*G[{yu^(-1)}, yw]^2*G[{1, yv^(-1)}, yw])/2 + 
     G[{1}, yw]*G[{yu^(-1)}, yw]^2*G[{1, yv^(-1)}, yw] + 
     (Pi^2*G[{yu}, yv^(-1)]*G[{1, yv^(-1)}, yw])/6 - 
     G[{0}, yu^(-1)]*G[{1}, yu^(-1)]*G[{yu}, yv^(-1)]*G[{1, yv^(-1)}, yw] - 
     G[{0}, yv^(-1)]*G[{1}, yu^(-1)]*G[{yu}, yv^(-1)]*G[{1, yv^(-1)}, yw] + 
     G[{0}, yw]*G[{1}, yu^(-1)]*G[{yu}, yv^(-1)]*G[{1, yv^(-1)}, yw] + 
     (5*G[{1}, yu^(-1)]^2*G[{yu}, yv^(-1)]*G[{1, yv^(-1)}, yw])/2 - 
     G[{0}, yu^(-1)]*G[{1}, yv^(-1)]*G[{yu}, yv^(-1)]*G[{1, yv^(-1)}, yw] - 
     G[{0}, yv^(-1)]*G[{1}, yv^(-1)]*G[{yu}, yv^(-1)]*G[{1, yv^(-1)}, yw] + 
     G[{0}, yw]*G[{1}, yv^(-1)]*G[{yu}, yv^(-1)]*G[{1, yv^(-1)}, yw] - 
     G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*G[{yu}, yv^(-1)]*G[{1, yv^(-1)}, yw] + 
     G[{1}, yv^(-1)]^2*G[{yu}, yv^(-1)]*G[{1, yv^(-1)}, yw] + 
     G[{0}, yu^(-1)]*G[{1}, yw]*G[{yu}, yv^(-1)]*G[{1, yv^(-1)}, yw] + 
     G[{0}, yv^(-1)]*G[{1}, yw]*G[{yu}, yv^(-1)]*G[{1, yv^(-1)}, yw] - 
     G[{0}, yw]*G[{1}, yw]*G[{yu}, yv^(-1)]*G[{1, yv^(-1)}, yw] - 
     G[{1}, yu^(-1)]*G[{1}, yw]*G[{yu}, yv^(-1)]*G[{1, yv^(-1)}, yw] - 
     2*G[{1}, yv^(-1)]*G[{1}, yw]*G[{yu}, yv^(-1)]*G[{1, yv^(-1)}, yw] + 
     4*G[{0}, yu^(-1)]*G[{yu^(-1)}, yw]*G[{yu}, yv^(-1)]*
      G[{1, yv^(-1)}, yw] + 4*G[{0}, yv^(-1)]*G[{yu^(-1)}, yw]*
      G[{yu}, yv^(-1)]*G[{1, yv^(-1)}, yw] - 4*G[{0}, yw]*G[{yu^(-1)}, yw]*
      G[{yu}, yv^(-1)]*G[{1, yv^(-1)}, yw] - 3*G[{1}, yu^(-1)]*
      G[{yu^(-1)}, yw]*G[{yu}, yv^(-1)]*G[{1, yv^(-1)}, yw] - 
     3*G[{1}, yv^(-1)]*G[{yu^(-1)}, yw]*G[{yu}, yv^(-1)]*
      G[{1, yv^(-1)}, yw] + 6*G[{1}, yw]*G[{yu^(-1)}, yw]*G[{yu}, yv^(-1)]*
      G[{1, yv^(-1)}, yw] - G[{yu^(-1)}, yw]^2*G[{yu}, yv^(-1)]*
      G[{1, yv^(-1)}, yw] + G[{0}, yu^(-1)]*G[{yu}, yv^(-1)]^2*
      G[{1, yv^(-1)}, yw] + G[{0}, yv^(-1)]*G[{yu}, yv^(-1)]^2*
      G[{1, yv^(-1)}, yw] - G[{0}, yw]*G[{yu}, yv^(-1)]^2*
      G[{1, yv^(-1)}, yw] - G[{1}, yu^(-1)]*G[{yu}, yv^(-1)]^2*
      G[{1, yv^(-1)}, yw] + (G[{1}, yw]*G[{yu}, yv^(-1)]^2*
       G[{1, yv^(-1)}, yw])/2 - G[{yu^(-1)}, yw]*G[{yu}, yv^(-1)]^2*
      G[{1, yv^(-1)}, yw] - (G[{yu}, yv^(-1)]^3*G[{1, yv^(-1)}, yw])/3 + 
     (Pi^2*G[{yv^(-1)}, yw]*G[{1, yv^(-1)}, yw])/6 + 
     (G[{0}, yu^(-1)]^2*G[{yv^(-1)}, yw]*G[{1, yv^(-1)}, yw])/2 + 
     G[{0}, yu^(-1)]*G[{0}, yv^(-1)]*G[{yv^(-1)}, yw]*G[{1, yv^(-1)}, yw] + 
     (G[{0}, yv^(-1)]^2*G[{yv^(-1)}, yw]*G[{1, yv^(-1)}, yw])/2 - 
     G[{0}, yu^(-1)]*G[{0}, yw]*G[{yv^(-1)}, yw]*G[{1, yv^(-1)}, yw] - 
     G[{0}, yv^(-1)]*G[{0}, yw]*G[{yv^(-1)}, yw]*G[{1, yv^(-1)}, yw] + 
     (G[{0}, yw]^2*G[{yv^(-1)}, yw]*G[{1, yv^(-1)}, yw])/2 - 
     G[{0}, yu^(-1)]*G[{1}, yu^(-1)]*G[{yv^(-1)}, yw]*G[{1, yv^(-1)}, yw] - 
     G[{0}, yv^(-1)]*G[{1}, yu^(-1)]*G[{yv^(-1)}, yw]*G[{1, yv^(-1)}, yw] + 
     G[{0}, yw]*G[{1}, yu^(-1)]*G[{yv^(-1)}, yw]*G[{1, yv^(-1)}, yw] - 
     G[{0}, yu^(-1)]*G[{1}, yv^(-1)]*G[{yv^(-1)}, yw]*G[{1, yv^(-1)}, yw] - 
     G[{0}, yv^(-1)]*G[{1}, yv^(-1)]*G[{yv^(-1)}, yw]*G[{1, yv^(-1)}, yw] + 
     G[{0}, yw]*G[{1}, yv^(-1)]*G[{yv^(-1)}, yw]*G[{1, yv^(-1)}, yw] + 
     2*G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*G[{yv^(-1)}, yw]*G[{1, yv^(-1)}, yw] + 
     (G[{1}, yv^(-1)]^2*G[{yv^(-1)}, yw]*G[{1, yv^(-1)}, yw])/2 + 
     G[{0}, yu^(-1)]*G[{1}, yw]*G[{yv^(-1)}, yw]*G[{1, yv^(-1)}, yw] + 
     G[{0}, yv^(-1)]*G[{1}, yw]*G[{yv^(-1)}, yw]*G[{1, yv^(-1)}, yw] - 
     G[{0}, yw]*G[{1}, yw]*G[{yv^(-1)}, yw]*G[{1, yv^(-1)}, yw] - 
     2*G[{1}, yu^(-1)]*G[{1}, yw]*G[{yv^(-1)}, yw]*G[{1, yv^(-1)}, yw] - 
     G[{1}, yv^(-1)]*G[{1}, yw]*G[{yv^(-1)}, yw]*G[{1, yv^(-1)}, yw] - 
     (G[{1}, yw]^2*G[{yv^(-1)}, yw]*G[{1, yv^(-1)}, yw])/2 + 
     2*G[{0}, yu^(-1)]*G[{yu^(-1)}, yw]*G[{yv^(-1)}, yw]*
      G[{1, yv^(-1)}, yw] + 2*G[{0}, yv^(-1)]*G[{yu^(-1)}, yw]*
      G[{yv^(-1)}, yw]*G[{1, yv^(-1)}, yw] - 2*G[{0}, yw]*G[{yu^(-1)}, yw]*
      G[{yv^(-1)}, yw]*G[{1, yv^(-1)}, yw] + 3*G[{1}, yu^(-1)]*
      G[{yu^(-1)}, yw]*G[{yv^(-1)}, yw]*G[{1, yv^(-1)}, yw] - 
     2*G[{1}, yv^(-1)]*G[{yu^(-1)}, yw]*G[{yv^(-1)}, yw]*
      G[{1, yv^(-1)}, yw] + 5*G[{1}, yw]*G[{yu^(-1)}, yw]*G[{yv^(-1)}, yw]*
      G[{1, yv^(-1)}, yw] + G[{1}, yw]*G[{yu}, yv^(-1)]*G[{yv^(-1)}, yw]*
      G[{1, yv^(-1)}, yw] - 5*G[{yu^(-1)}, yw]*G[{yu}, yv^(-1)]*
      G[{yv^(-1)}, yw]*G[{1, yv^(-1)}, yw] + 
     (7*G[{0}, yu^(-1)]*G[{yv^(-1)}, yw]^2*G[{1, yv^(-1)}, yw])/2 + 
     (7*G[{0}, yv^(-1)]*G[{yv^(-1)}, yw]^2*G[{1, yv^(-1)}, yw])/2 - 
     (7*G[{0}, yw]*G[{yv^(-1)}, yw]^2*G[{1, yv^(-1)}, yw])/2 - 
     (7*G[{1}, yv^(-1)]*G[{yv^(-1)}, yw]^2*G[{1, yv^(-1)}, yw])/2 + 
     (7*G[{1}, yw]*G[{yv^(-1)}, yw]^2*G[{1, yv^(-1)}, yw])/2 - 
     (7*G[{yu}, yv^(-1)]*G[{yv^(-1)}, yw]^2*G[{1, yv^(-1)}, yw])/2 - 
     (Pi^2*G[{1/(yu*yv)}, yw]*G[{1, yv^(-1)}, yw])/6 - 
     (G[{0}, yu^(-1)]^2*G[{1/(yu*yv)}, yw]*G[{1, yv^(-1)}, yw])/2 - 
     G[{0}, yu^(-1)]*G[{0}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{1, yv^(-1)}, yw] - 
     (G[{0}, yv^(-1)]^2*G[{1/(yu*yv)}, yw]*G[{1, yv^(-1)}, yw])/2 + 
     G[{0}, yu^(-1)]*G[{0}, yw]*G[{1/(yu*yv)}, yw]*G[{1, yv^(-1)}, yw] + 
     G[{0}, yv^(-1)]*G[{0}, yw]*G[{1/(yu*yv)}, yw]*G[{1, yv^(-1)}, yw] - 
     (G[{0}, yw]^2*G[{1/(yu*yv)}, yw]*G[{1, yv^(-1)}, yw])/2 + 
     G[{0}, yu^(-1)]*G[{1}, yu^(-1)]*G[{1/(yu*yv)}, yw]*G[{1, yv^(-1)}, yw] + 
     G[{0}, yv^(-1)]*G[{1}, yu^(-1)]*G[{1/(yu*yv)}, yw]*G[{1, yv^(-1)}, yw] - 
     G[{0}, yw]*G[{1}, yu^(-1)]*G[{1/(yu*yv)}, yw]*G[{1, yv^(-1)}, yw] + 
     4*G[{0}, yu^(-1)]*G[{1}, yv^(-1)]*G[{1/(yu*yv)}, yw]*
      G[{1, yv^(-1)}, yw] + 4*G[{0}, yv^(-1)]*G[{1}, yv^(-1)]*
      G[{1/(yu*yv)}, yw]*G[{1, yv^(-1)}, yw] - 4*G[{0}, yw]*G[{1}, yv^(-1)]*
      G[{1/(yu*yv)}, yw]*G[{1, yv^(-1)}, yw] - 2*G[{1}, yu^(-1)]*
      G[{1}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{1, yv^(-1)}, yw] - 
     (7*G[{1}, yv^(-1)]^2*G[{1/(yu*yv)}, yw]*G[{1, yv^(-1)}, yw])/2 + 
     2*G[{0}, yu^(-1)]*G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{1, yv^(-1)}, yw] + 
     2*G[{0}, yv^(-1)]*G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{1, yv^(-1)}, yw] - 
     2*G[{0}, yw]*G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{1, yv^(-1)}, yw] + 
     2*G[{1}, yu^(-1)]*G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{1, yv^(-1)}, yw] + 
     G[{1}, yv^(-1)]*G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{1, yv^(-1)}, yw] + 
     (7*G[{1}, yw]^2*G[{1/(yu*yv)}, yw]*G[{1, yv^(-1)}, yw])/2 - 
     7*G[{0}, yu^(-1)]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*
      G[{1, yv^(-1)}, yw] - 7*G[{0}, yv^(-1)]*G[{yu^(-1)}, yw]*
      G[{1/(yu*yv)}, yw]*G[{1, yv^(-1)}, yw] + 7*G[{0}, yw]*G[{yu^(-1)}, yw]*
      G[{1/(yu*yv)}, yw]*G[{1, yv^(-1)}, yw] + G[{1}, yu^(-1)]*
      G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{1, yv^(-1)}, yw] + 
     7*G[{1}, yv^(-1)]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*
      G[{1, yv^(-1)}, yw] - 6*G[{1}, yw]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*
      G[{1, yv^(-1)}, yw] - 3*G[{0}, yu^(-1)]*G[{yu}, yv^(-1)]*
      G[{1/(yu*yv)}, yw]*G[{1, yv^(-1)}, yw] - 3*G[{0}, yv^(-1)]*
      G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{1, yv^(-1)}, yw] + 
     3*G[{0}, yw]*G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{1, yv^(-1)}, yw] - 
     7*G[{1}, yw]*G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{1, yv^(-1)}, yw] + 
     6*G[{yu^(-1)}, yw]*G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw]*
      G[{1, yv^(-1)}, yw] + 3*G[{yu}, yv^(-1)]^2*G[{1/(yu*yv)}, yw]*
      G[{1, yv^(-1)}, yw] - 7*G[{0}, yu^(-1)]*G[{yv^(-1)}, yw]*
      G[{1/(yu*yv)}, yw]*G[{1, yv^(-1)}, yw] - 7*G[{0}, yv^(-1)]*
      G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{1, yv^(-1)}, yw] + 
     7*G[{0}, yw]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{1, yv^(-1)}, yw] + 
     7*G[{1}, yv^(-1)]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*
      G[{1, yv^(-1)}, yw] - 7*G[{1}, yw]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*
      G[{1, yv^(-1)}, yw] + 7*G[{yu}, yv^(-1)]*G[{yv^(-1)}, yw]*
      G[{1/(yu*yv)}, yw]*G[{1, yv^(-1)}, yw] + 
     (5*G[{0}, yu^(-1)]*G[{1/(yu*yv)}, yw]^2*G[{1, yv^(-1)}, yw])/2 + 
     (5*G[{0}, yv^(-1)]*G[{1/(yu*yv)}, yw]^2*G[{1, yv^(-1)}, yw])/2 - 
     (5*G[{0}, yw]*G[{1/(yu*yv)}, yw]^2*G[{1, yv^(-1)}, yw])/2 - 
     (5*G[{1}, yv^(-1)]*G[{1/(yu*yv)}, yw]^2*G[{1, yv^(-1)}, yw])/2 + 
     (5*G[{1}, yw]*G[{1/(yu*yv)}, yw]^2*G[{1, yv^(-1)}, yw])/2 - 
     (G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2*G[{1, yv^(-1)}, yw])/2 - 
     (5*G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw]^2*G[{1, yv^(-1)}, yw])/2 + 
     G[{0}, yu^(-1)]*G[{0, 1}, yu^(-1)]*G[{1, yv^(-1)}, yw] + 
     G[{0}, yv^(-1)]*G[{0, 1}, yu^(-1)]*G[{1, yv^(-1)}, yw] - 
     G[{0}, yw]*G[{0, 1}, yu^(-1)]*G[{1, yv^(-1)}, yw] - 
     G[{1}, yu^(-1)]*G[{0, 1}, yu^(-1)]*G[{1, yv^(-1)}, yw] + 
     G[{1}, yv^(-1)]*G[{0, 1}, yu^(-1)]*G[{1, yv^(-1)}, yw] + 
     2*G[{yu^(-1)}, yw]*G[{0, 1}, yu^(-1)]*G[{1, yv^(-1)}, yw] - 
     2*G[{yu}, yv^(-1)]*G[{0, 1}, yu^(-1)]*G[{1, yv^(-1)}, yw] + 
     G[{yv^(-1)}, yw]*G[{0, 1}, yu^(-1)]*G[{1, yv^(-1)}, yw] - 
     G[{1/(yu*yv)}, yw]*G[{0, 1}, yu^(-1)]*G[{1, yv^(-1)}, yw] + 
     G[{0}, yu^(-1)]*G[{0, 1}, yv^(-1)]*G[{1, yv^(-1)}, yw] + 
     G[{0}, yv^(-1)]*G[{0, 1}, yv^(-1)]*G[{1, yv^(-1)}, yw] - 
     G[{0}, yw]*G[{0, 1}, yv^(-1)]*G[{1, yv^(-1)}, yw] - 
     G[{1}, yv^(-1)]*G[{0, 1}, yv^(-1)]*G[{1, yv^(-1)}, yw] + 
     G[{1}, yw]*G[{0, 1}, yv^(-1)]*G[{1, yv^(-1)}, yw] + 
     2*G[{yu^(-1)}, yw]*G[{0, 1}, yv^(-1)]*G[{1, yv^(-1)}, yw] - 
     G[{yu}, yv^(-1)]*G[{0, 1}, yv^(-1)]*G[{1, yv^(-1)}, yw] + 
     3*G[{0}, yu^(-1)]*G[{0, 1}, yw]*G[{1, yv^(-1)}, yw] + 
     3*G[{0}, yv^(-1)]*G[{0, 1}, yw]*G[{1, yv^(-1)}, yw] - 
     3*G[{0}, yw]*G[{0, 1}, yw]*G[{1, yv^(-1)}, yw] - 
     4*G[{1}, yu^(-1)]*G[{0, 1}, yw]*G[{1, yv^(-1)}, yw] - 
     3*G[{1}, yv^(-1)]*G[{0, 1}, yw]*G[{1, yv^(-1)}, yw] + 
     G[{1}, yw]*G[{0, 1}, yw]*G[{1, yv^(-1)}, yw] - 
     G[{yu^(-1)}, yw]*G[{0, 1}, yw]*G[{1, yv^(-1)}, yw] + 
     G[{yu}, yv^(-1)]*G[{0, 1}, yw]*G[{1, yv^(-1)}, yw] + 
     G[{yv^(-1)}, yw]*G[{0, 1}, yw]*G[{1, yv^(-1)}, yw] - 
     G[{1/(yu*yv)}, yw]*G[{0, 1}, yw]*G[{1, yv^(-1)}, yw] - 
     3*G[{0}, yu^(-1)]*G[{0, yu^(-1)}, yw]*G[{1, yv^(-1)}, yw] - 
     3*G[{0}, yv^(-1)]*G[{0, yu^(-1)}, yw]*G[{1, yv^(-1)}, yw] + 
     3*G[{0}, yw]*G[{0, yu^(-1)}, yw]*G[{1, yv^(-1)}, yw] + 
     4*G[{1}, yu^(-1)]*G[{0, yu^(-1)}, yw]*G[{1, yv^(-1)}, yw] + 
     3*G[{1}, yv^(-1)]*G[{0, yu^(-1)}, yw]*G[{1, yv^(-1)}, yw] - 
     G[{1}, yw]*G[{0, yu^(-1)}, yw]*G[{1, yv^(-1)}, yw] + 
     G[{yu^(-1)}, yw]*G[{0, yu^(-1)}, yw]*G[{1, yv^(-1)}, yw] - 
     G[{yu}, yv^(-1)]*G[{0, yu^(-1)}, yw]*G[{1, yv^(-1)}, yw] - 
     G[{yv^(-1)}, yw]*G[{0, yu^(-1)}, yw]*G[{1, yv^(-1)}, yw] + 
     G[{1/(yu*yv)}, yw]*G[{0, yu^(-1)}, yw]*G[{1, yv^(-1)}, yw] - 
     G[{0}, yu^(-1)]*G[{0, yu}, yv^(-1)]*G[{1, yv^(-1)}, yw] - 
     G[{0}, yv^(-1)]*G[{0, yu}, yv^(-1)]*G[{1, yv^(-1)}, yw] + 
     G[{0}, yw]*G[{0, yu}, yv^(-1)]*G[{1, yv^(-1)}, yw] + 
     G[{1}, yv^(-1)]*G[{0, yu}, yv^(-1)]*G[{1, yv^(-1)}, yw] - 
     G[{1}, yw]*G[{0, yu}, yv^(-1)]*G[{1, yv^(-1)}, yw] - 
     2*G[{yu^(-1)}, yw]*G[{0, yu}, yv^(-1)]*G[{1, yv^(-1)}, yw] + 
     G[{yu}, yv^(-1)]*G[{0, yu}, yv^(-1)]*G[{1, yv^(-1)}, yw] - 
     3*G[{0}, yu^(-1)]*G[{0, yv^(-1)}, yw]*G[{1, yv^(-1)}, yw] - 
     3*G[{0}, yv^(-1)]*G[{0, yv^(-1)}, yw]*G[{1, yv^(-1)}, yw] + 
     3*G[{0}, yw]*G[{0, yv^(-1)}, yw]*G[{1, yv^(-1)}, yw] + 
     4*G[{1}, yu^(-1)]*G[{0, yv^(-1)}, yw]*G[{1, yv^(-1)}, yw] + 
     3*G[{1}, yv^(-1)]*G[{0, yv^(-1)}, yw]*G[{1, yv^(-1)}, yw] - 
     G[{1}, yw]*G[{0, yv^(-1)}, yw]*G[{1, yv^(-1)}, yw] + 
     G[{yu^(-1)}, yw]*G[{0, yv^(-1)}, yw]*G[{1, yv^(-1)}, yw] - 
     G[{yu}, yv^(-1)]*G[{0, yv^(-1)}, yw]*G[{1, yv^(-1)}, yw] - 
     G[{yv^(-1)}, yw]*G[{0, yv^(-1)}, yw]*G[{1, yv^(-1)}, yw] + 
     G[{1/(yu*yv)}, yw]*G[{0, yv^(-1)}, yw]*G[{1, yv^(-1)}, yw] + 
     3*G[{0}, yu^(-1)]*G[{0, 1/(yu*yv)}, yw]*G[{1, yv^(-1)}, yw] + 
     3*G[{0}, yv^(-1)]*G[{0, 1/(yu*yv)}, yw]*G[{1, yv^(-1)}, yw] - 
     3*G[{0}, yw]*G[{0, 1/(yu*yv)}, yw]*G[{1, yv^(-1)}, yw] - 
     4*G[{1}, yu^(-1)]*G[{0, 1/(yu*yv)}, yw]*G[{1, yv^(-1)}, yw] - 
     3*G[{1}, yv^(-1)]*G[{0, 1/(yu*yv)}, yw]*G[{1, yv^(-1)}, yw] + 
     G[{1}, yw]*G[{0, 1/(yu*yv)}, yw]*G[{1, yv^(-1)}, yw] - 
     G[{yu^(-1)}, yw]*G[{0, 1/(yu*yv)}, yw]*G[{1, yv^(-1)}, yw] + 
     G[{yu}, yv^(-1)]*G[{0, 1/(yu*yv)}, yw]*G[{1, yv^(-1)}, yw] + 
     G[{yv^(-1)}, yw]*G[{0, 1/(yu*yv)}, yw]*G[{1, yv^(-1)}, yw] - 
     G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv)}, yw]*G[{1, yv^(-1)}, yw] + 
     4*G[{0}, yu^(-1)]*G[{1, yu^(-1)}, yw]*G[{1, yv^(-1)}, yw] + 
     4*G[{0}, yv^(-1)]*G[{1, yu^(-1)}, yw]*G[{1, yv^(-1)}, yw] - 
     4*G[{0}, yw]*G[{1, yu^(-1)}, yw]*G[{1, yv^(-1)}, yw] - 
     4*G[{1}, yu^(-1)]*G[{1, yu^(-1)}, yw]*G[{1, yv^(-1)}, yw] - 
     4*G[{1}, yv^(-1)]*G[{1, yu^(-1)}, yw]*G[{1, yv^(-1)}, yw] + 
     G[{yu^(-1)}, yw]*G[{1, yu^(-1)}, yw]*G[{1, yv^(-1)}, yw] + 
     G[{yv^(-1)}, yw]*G[{1, yu^(-1)}, yw]*G[{1, yv^(-1)}, yw] - 
     G[{1/(yu*yv)}, yw]*G[{1, yu^(-1)}, yw]*G[{1, yv^(-1)}, yw] + 
     4*G[{1}, yu^(-1)]*G[{1, yu}, yv^(-1)]*G[{1, yv^(-1)}, yw] + 
     G[{1}, yw]*G[{1, yu}, yv^(-1)]*G[{1, yv^(-1)}, yw] + 
     G[{yu}, yv^(-1)]*G[{1, yu}, yv^(-1)]*G[{1, yv^(-1)}, yw] - 
     G[{yv^(-1)}, yw]*G[{1, yu}, yv^(-1)]*G[{1, yv^(-1)}, yw] + 
     G[{1/(yu*yv)}, yw]*G[{1, yu}, yv^(-1)]*G[{1, yv^(-1)}, yw] + 
     2*G[{0}, yu^(-1)]*G[{1, yv^(-1)}, yw]^2 + 2*G[{0}, yv^(-1)]*
      G[{1, yv^(-1)}, yw]^2 - 2*G[{0}, yw]*G[{1, yv^(-1)}, yw]^2 - 
     4*G[{1}, yu^(-1)]*G[{1, yv^(-1)}, yw]^2 - 2*G[{1}, yv^(-1)]*
      G[{1, yv^(-1)}, yw]^2 - 2*G[{1}, yw]*G[{1, yv^(-1)}, yw]^2 + 
     (G[{yu^(-1)}, yw]*G[{1, yv^(-1)}, yw]^2)/2 + 2*G[{yu}, yv^(-1)]*
      G[{1, yv^(-1)}, yw]^2 + G[{yv^(-1)}, yw]*G[{1, yv^(-1)}, yw]^2 - 
     G[{1/(yu*yv)}, yw]*G[{1, yv^(-1)}, yw]^2 - 
     (Pi^2*G[{0}, yu^(-1)]*G[{1, 1/(yu*yv)}, yw])/3 - 
     (Pi^2*G[{0}, yv^(-1)]*G[{1, 1/(yu*yv)}, yw])/3 + 
     (Pi^2*G[{0}, yw]*G[{1, 1/(yu*yv)}, yw])/3 + 
     (5*Pi^2*G[{1}, yu^(-1)]*G[{1, 1/(yu*yv)}, yw])/6 + 
     (5*Pi^2*G[{1}, yv^(-1)]*G[{1, 1/(yu*yv)}, yw])/6 + 
     (G[{1}, yu^(-1)]^2*G[{1}, yv^(-1)]*G[{1, 1/(yu*yv)}, yw])/2 + 
     Pi^2*G[{1}, yw]*G[{1, 1/(yu*yv)}, yw] - G[{0}, yu^(-1)]^2*G[{1}, yw]*
      G[{1, 1/(yu*yv)}, yw] - 2*G[{0}, yu^(-1)]*G[{0}, yv^(-1)]*G[{1}, yw]*
      G[{1, 1/(yu*yv)}, yw] - G[{0}, yv^(-1)]^2*G[{1}, yw]*
      G[{1, 1/(yu*yv)}, yw] + 2*G[{0}, yu^(-1)]*G[{0}, yw]*G[{1}, yw]*
      G[{1, 1/(yu*yv)}, yw] + 2*G[{0}, yv^(-1)]*G[{0}, yw]*G[{1}, yw]*
      G[{1, 1/(yu*yv)}, yw] - G[{0}, yw]^2*G[{1}, yw]*G[{1, 1/(yu*yv)}, yw] + 
     3*G[{0}, yu^(-1)]*G[{1}, yu^(-1)]*G[{1}, yw]*G[{1, 1/(yu*yv)}, yw] + 
     3*G[{0}, yv^(-1)]*G[{1}, yu^(-1)]*G[{1}, yw]*G[{1, 1/(yu*yv)}, yw] - 
     3*G[{0}, yw]*G[{1}, yu^(-1)]*G[{1}, yw]*G[{1, 1/(yu*yv)}, yw] - 
     2*G[{1}, yu^(-1)]^2*G[{1}, yw]*G[{1, 1/(yu*yv)}, yw] + 
     3*G[{0}, yu^(-1)]*G[{1}, yv^(-1)]*G[{1}, yw]*G[{1, 1/(yu*yv)}, yw] + 
     3*G[{0}, yv^(-1)]*G[{1}, yv^(-1)]*G[{1}, yw]*G[{1, 1/(yu*yv)}, yw] - 
     3*G[{0}, yw]*G[{1}, yv^(-1)]*G[{1}, yw]*G[{1, 1/(yu*yv)}, yw] - 
     G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*G[{1}, yw]*G[{1, 1/(yu*yv)}, yw] - 
     2*G[{1}, yv^(-1)]^2*G[{1}, yw]*G[{1, 1/(yu*yv)}, yw] + 
     G[{0}, yu^(-1)]^2*G[{yu^(-1)}, yw]*G[{1, 1/(yu*yv)}, yw] + 
     2*G[{0}, yu^(-1)]*G[{0}, yv^(-1)]*G[{yu^(-1)}, yw]*
      G[{1, 1/(yu*yv)}, yw] + G[{0}, yv^(-1)]^2*G[{yu^(-1)}, yw]*
      G[{1, 1/(yu*yv)}, yw] - 2*G[{0}, yu^(-1)]*G[{0}, yw]*G[{yu^(-1)}, yw]*
      G[{1, 1/(yu*yv)}, yw] - 2*G[{0}, yv^(-1)]*G[{0}, yw]*G[{yu^(-1)}, yw]*
      G[{1, 1/(yu*yv)}, yw] + G[{0}, yw]^2*G[{yu^(-1)}, yw]*
      G[{1, 1/(yu*yv)}, yw] - G[{0}, yu^(-1)]*G[{1}, yu^(-1)]*
      G[{yu^(-1)}, yw]*G[{1, 1/(yu*yv)}, yw] - G[{0}, yv^(-1)]*
      G[{1}, yu^(-1)]*G[{yu^(-1)}, yw]*G[{1, 1/(yu*yv)}, yw] + 
     G[{0}, yw]*G[{1}, yu^(-1)]*G[{yu^(-1)}, yw]*G[{1, 1/(yu*yv)}, yw] - 
     G[{0}, yu^(-1)]*G[{1}, yv^(-1)]*G[{yu^(-1)}, yw]*G[{1, 1/(yu*yv)}, yw] - 
     G[{0}, yv^(-1)]*G[{1}, yv^(-1)]*G[{yu^(-1)}, yw]*G[{1, 1/(yu*yv)}, yw] + 
     G[{0}, yw]*G[{1}, yv^(-1)]*G[{yu^(-1)}, yw]*G[{1, 1/(yu*yv)}, yw] + 
     G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*G[{yu^(-1)}, yw]*G[{1, 1/(yu*yv)}, yw] + 
     (3*G[{1}, yv^(-1)]^2*G[{yu^(-1)}, yw]*G[{1, 1/(yu*yv)}, yw])/2 + 
     4*G[{0}, yu^(-1)]*G[{1}, yw]*G[{yu^(-1)}, yw]*G[{1, 1/(yu*yv)}, yw] + 
     4*G[{0}, yv^(-1)]*G[{1}, yw]*G[{yu^(-1)}, yw]*G[{1, 1/(yu*yv)}, yw] - 
     4*G[{0}, yw]*G[{1}, yw]*G[{yu^(-1)}, yw]*G[{1, 1/(yu*yv)}, yw] - 
     G[{1}, yu^(-1)]*G[{1}, yw]*G[{yu^(-1)}, yw]*G[{1, 1/(yu*yv)}, yw] + 
     2*G[{1}, yv^(-1)]*G[{1}, yw]*G[{yu^(-1)}, yw]*G[{1, 1/(yu*yv)}, yw] + 
     (9*G[{1}, yw]^2*G[{yu^(-1)}, yw]*G[{1, 1/(yu*yv)}, yw])/2 - 
     3*G[{0}, yu^(-1)]*G[{yu^(-1)}, yw]^2*G[{1, 1/(yu*yv)}, yw] - 
     3*G[{0}, yv^(-1)]*G[{yu^(-1)}, yw]^2*G[{1, 1/(yu*yv)}, yw] + 
     3*G[{0}, yw]*G[{yu^(-1)}, yw]^2*G[{1, 1/(yu*yv)}, yw] + 
     2*G[{1}, yu^(-1)]*G[{yu^(-1)}, yw]^2*G[{1, 1/(yu*yv)}, yw] + 
     (5*G[{1}, yv^(-1)]*G[{yu^(-1)}, yw]^2*G[{1, 1/(yu*yv)}, yw])/2 - 
     (3*G[{1}, yw]*G[{yu^(-1)}, yw]^2*G[{1, 1/(yu*yv)}, yw])/2 - 
     2*G[{yu^(-1)}, yw]^3*G[{1, 1/(yu*yv)}, yw] - Pi^2*G[{yu}, yv^(-1)]*
      G[{1, 1/(yu*yv)}, yw] - (G[{1}, yu^(-1)]^2*G[{yu}, yv^(-1)]*
       G[{1, 1/(yu*yv)}, yw])/2 - 3*G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*
      G[{yu}, yv^(-1)]*G[{1, 1/(yu*yv)}, yw] - 
     (G[{1}, yv^(-1)]^2*G[{yu}, yv^(-1)]*G[{1, 1/(yu*yv)}, yw])/2 - 
     2*G[{0}, yu^(-1)]*G[{1}, yw]*G[{yu}, yv^(-1)]*G[{1, 1/(yu*yv)}, yw] - 
     2*G[{0}, yv^(-1)]*G[{1}, yw]*G[{yu}, yv^(-1)]*G[{1, 1/(yu*yv)}, yw] + 
     2*G[{0}, yw]*G[{1}, yw]*G[{yu}, yv^(-1)]*G[{1, 1/(yu*yv)}, yw] - 
     G[{1}, yu^(-1)]*G[{1}, yw]*G[{yu}, yv^(-1)]*G[{1, 1/(yu*yv)}, yw] - 
     G[{1}, yv^(-1)]*G[{1}, yw]*G[{yu}, yv^(-1)]*G[{1, 1/(yu*yv)}, yw] - 
     2*G[{0}, yu^(-1)]*G[{yu^(-1)}, yw]*G[{yu}, yv^(-1)]*
      G[{1, 1/(yu*yv)}, yw] - 2*G[{0}, yv^(-1)]*G[{yu^(-1)}, yw]*
      G[{yu}, yv^(-1)]*G[{1, 1/(yu*yv)}, yw] + 2*G[{0}, yw]*G[{yu^(-1)}, yw]*
      G[{yu}, yv^(-1)]*G[{1, 1/(yu*yv)}, yw] + G[{1}, yu^(-1)]*
      G[{yu^(-1)}, yw]*G[{yu}, yv^(-1)]*G[{1, 1/(yu*yv)}, yw] - 
     G[{1}, yv^(-1)]*G[{yu^(-1)}, yw]*G[{yu}, yv^(-1)]*
      G[{1, 1/(yu*yv)}, yw] - 9*G[{1}, yw]*G[{yu^(-1)}, yw]*G[{yu}, yv^(-1)]*
      G[{1, 1/(yu*yv)}, yw] + (3*G[{yu^(-1)}, yw]^2*G[{yu}, yv^(-1)]*
       G[{1, 1/(yu*yv)}, yw])/2 + 2*G[{1}, yu^(-1)]*G[{yu}, yv^(-1)]^2*
      G[{1, 1/(yu*yv)}, yw] + 2*G[{1}, yv^(-1)]*G[{yu}, yv^(-1)]^2*
      G[{1, 1/(yu*yv)}, yw] + 3*G[{1}, yw]*G[{yu}, yv^(-1)]^2*
      G[{1, 1/(yu*yv)}, yw] + 2*G[{yu^(-1)}, yw]*G[{yu}, yv^(-1)]^2*
      G[{1, 1/(yu*yv)}, yw] - (4*G[{yu}, yv^(-1)]^3*G[{1, 1/(yu*yv)}, yw])/
      3 + G[{0}, yu^(-1)]^2*G[{yv^(-1)}, yw]*G[{1, 1/(yu*yv)}, yw] + 
     2*G[{0}, yu^(-1)]*G[{0}, yv^(-1)]*G[{yv^(-1)}, yw]*
      G[{1, 1/(yu*yv)}, yw] + G[{0}, yv^(-1)]^2*G[{yv^(-1)}, yw]*
      G[{1, 1/(yu*yv)}, yw] - 2*G[{0}, yu^(-1)]*G[{0}, yw]*G[{yv^(-1)}, yw]*
      G[{1, 1/(yu*yv)}, yw] - 2*G[{0}, yv^(-1)]*G[{0}, yw]*G[{yv^(-1)}, yw]*
      G[{1, 1/(yu*yv)}, yw] + G[{0}, yw]^2*G[{yv^(-1)}, yw]*
      G[{1, 1/(yu*yv)}, yw] - G[{0}, yu^(-1)]*G[{1}, yu^(-1)]*
      G[{yv^(-1)}, yw]*G[{1, 1/(yu*yv)}, yw] - G[{0}, yv^(-1)]*
      G[{1}, yu^(-1)]*G[{yv^(-1)}, yw]*G[{1, 1/(yu*yv)}, yw] + 
     G[{0}, yw]*G[{1}, yu^(-1)]*G[{yv^(-1)}, yw]*G[{1, 1/(yu*yv)}, yw] + 
     (3*G[{1}, yu^(-1)]^2*G[{yv^(-1)}, yw]*G[{1, 1/(yu*yv)}, yw])/2 - 
     G[{0}, yu^(-1)]*G[{1}, yv^(-1)]*G[{yv^(-1)}, yw]*G[{1, 1/(yu*yv)}, yw] - 
     G[{0}, yv^(-1)]*G[{1}, yv^(-1)]*G[{yv^(-1)}, yw]*G[{1, 1/(yu*yv)}, yw] + 
     G[{0}, yw]*G[{1}, yv^(-1)]*G[{yv^(-1)}, yw]*G[{1, 1/(yu*yv)}, yw] + 
     4*G[{0}, yu^(-1)]*G[{1}, yw]*G[{yv^(-1)}, yw]*G[{1, 1/(yu*yv)}, yw] + 
     4*G[{0}, yv^(-1)]*G[{1}, yw]*G[{yv^(-1)}, yw]*G[{1, 1/(yu*yv)}, yw] - 
     4*G[{0}, yw]*G[{1}, yw]*G[{yv^(-1)}, yw]*G[{1, 1/(yu*yv)}, yw] + 
     2*G[{1}, yu^(-1)]*G[{1}, yw]*G[{yv^(-1)}, yw]*G[{1, 1/(yu*yv)}, yw] - 
     G[{1}, yv^(-1)]*G[{1}, yw]*G[{yv^(-1)}, yw]*G[{1, 1/(yu*yv)}, yw] + 
     (9*G[{1}, yw]^2*G[{yv^(-1)}, yw]*G[{1, 1/(yu*yv)}, yw])/2 - 
     2*G[{0}, yu^(-1)]*G[{yu^(-1)}, yw]*G[{yv^(-1)}, yw]*
      G[{1, 1/(yu*yv)}, yw] - 2*G[{0}, yv^(-1)]*G[{yu^(-1)}, yw]*
      G[{yv^(-1)}, yw]*G[{1, 1/(yu*yv)}, yw] + 2*G[{0}, yw]*G[{yu^(-1)}, yw]*
      G[{yv^(-1)}, yw]*G[{1, 1/(yu*yv)}, yw] + G[{1}, yu^(-1)]*
      G[{yu^(-1)}, yw]*G[{yv^(-1)}, yw]*G[{1, 1/(yu*yv)}, yw] + 
     G[{1}, yv^(-1)]*G[{yu^(-1)}, yw]*G[{yv^(-1)}, yw]*
      G[{1, 1/(yu*yv)}, yw] - 2*G[{1}, yw]*G[{yu^(-1)}, yw]*G[{yv^(-1)}, yw]*
      G[{1, 1/(yu*yv)}, yw] - 3*G[{yu^(-1)}, yw]^2*G[{yv^(-1)}, yw]*
      G[{1, 1/(yu*yv)}, yw] - 2*G[{0}, yu^(-1)]*G[{yu}, yv^(-1)]*
      G[{yv^(-1)}, yw]*G[{1, 1/(yu*yv)}, yw] - 2*G[{0}, yv^(-1)]*
      G[{yu}, yv^(-1)]*G[{yv^(-1)}, yw]*G[{1, 1/(yu*yv)}, yw] + 
     2*G[{0}, yw]*G[{yu}, yv^(-1)]*G[{yv^(-1)}, yw]*G[{1, 1/(yu*yv)}, yw] - 
     G[{1}, yu^(-1)]*G[{yu}, yv^(-1)]*G[{yv^(-1)}, yw]*
      G[{1, 1/(yu*yv)}, yw] + G[{1}, yv^(-1)]*G[{yu}, yv^(-1)]*
      G[{yv^(-1)}, yw]*G[{1, 1/(yu*yv)}, yw] - 9*G[{1}, yw]*G[{yu}, yv^(-1)]*
      G[{yv^(-1)}, yw]*G[{1, 1/(yu*yv)}, yw] + 2*G[{yu^(-1)}, yw]*
      G[{yu}, yv^(-1)]*G[{yv^(-1)}, yw]*G[{1, 1/(yu*yv)}, yw] + 
     2*G[{yu}, yv^(-1)]^2*G[{yv^(-1)}, yw]*G[{1, 1/(yu*yv)}, yw] - 
     3*G[{0}, yu^(-1)]*G[{yv^(-1)}, yw]^2*G[{1, 1/(yu*yv)}, yw] - 
     3*G[{0}, yv^(-1)]*G[{yv^(-1)}, yw]^2*G[{1, 1/(yu*yv)}, yw] + 
     3*G[{0}, yw]*G[{yv^(-1)}, yw]^2*G[{1, 1/(yu*yv)}, yw] + 
     (5*G[{1}, yu^(-1)]*G[{yv^(-1)}, yw]^2*G[{1, 1/(yu*yv)}, yw])/2 + 
     2*G[{1}, yv^(-1)]*G[{yv^(-1)}, yw]^2*G[{1, 1/(yu*yv)}, yw] - 
     (3*G[{1}, yw]*G[{yv^(-1)}, yw]^2*G[{1, 1/(yu*yv)}, yw])/2 - 
     3*G[{yu^(-1)}, yw]*G[{yv^(-1)}, yw]^2*G[{1, 1/(yu*yv)}, yw] + 
     (3*G[{yu}, yv^(-1)]*G[{yv^(-1)}, yw]^2*G[{1, 1/(yu*yv)}, yw])/2 - 
     2*G[{yv^(-1)}, yw]^3*G[{1, 1/(yu*yv)}, yw] - 
     G[{0}, yu^(-1)]^2*G[{1/(yu*yv)}, yw]*G[{1, 1/(yu*yv)}, yw] - 
     2*G[{0}, yu^(-1)]*G[{0}, yv^(-1)]*G[{1/(yu*yv)}, yw]*
      G[{1, 1/(yu*yv)}, yw] - G[{0}, yv^(-1)]^2*G[{1/(yu*yv)}, yw]*
      G[{1, 1/(yu*yv)}, yw] + 2*G[{0}, yu^(-1)]*G[{0}, yw]*G[{1/(yu*yv)}, yw]*
      G[{1, 1/(yu*yv)}, yw] + 2*G[{0}, yv^(-1)]*G[{0}, yw]*G[{1/(yu*yv)}, yw]*
      G[{1, 1/(yu*yv)}, yw] - G[{0}, yw]^2*G[{1/(yu*yv)}, yw]*
      G[{1, 1/(yu*yv)}, yw] + G[{0}, yu^(-1)]*G[{1}, yu^(-1)]*
      G[{1/(yu*yv)}, yw]*G[{1, 1/(yu*yv)}, yw] + 
     G[{0}, yv^(-1)]*G[{1}, yu^(-1)]*G[{1/(yu*yv)}, yw]*
      G[{1, 1/(yu*yv)}, yw] - G[{0}, yw]*G[{1}, yu^(-1)]*G[{1/(yu*yv)}, yw]*
      G[{1, 1/(yu*yv)}, yw] - (3*G[{1}, yu^(-1)]^2*G[{1/(yu*yv)}, yw]*
       G[{1, 1/(yu*yv)}, yw])/2 + G[{0}, yu^(-1)]*G[{1}, yv^(-1)]*
      G[{1/(yu*yv)}, yw]*G[{1, 1/(yu*yv)}, yw] + 
     G[{0}, yv^(-1)]*G[{1}, yv^(-1)]*G[{1/(yu*yv)}, yw]*
      G[{1, 1/(yu*yv)}, yw] - G[{0}, yw]*G[{1}, yv^(-1)]*G[{1/(yu*yv)}, yw]*
      G[{1, 1/(yu*yv)}, yw] - G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*
      G[{1/(yu*yv)}, yw]*G[{1, 1/(yu*yv)}, yw] - 
     (3*G[{1}, yv^(-1)]^2*G[{1/(yu*yv)}, yw]*G[{1, 1/(yu*yv)}, yw])/2 - 
     6*G[{0}, yu^(-1)]*G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{1, 1/(yu*yv)}, yw] - 
     6*G[{0}, yv^(-1)]*G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{1, 1/(yu*yv)}, yw] + 
     6*G[{0}, yw]*G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{1, 1/(yu*yv)}, yw] - 
     3*G[{1}, yu^(-1)]*G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{1, 1/(yu*yv)}, yw] - 
     3*G[{1}, yv^(-1)]*G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{1, 1/(yu*yv)}, yw] - 
     9*G[{1}, yw]^2*G[{1/(yu*yv)}, yw]*G[{1, 1/(yu*yv)}, yw] + 
     6*G[{0}, yu^(-1)]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*
      G[{1, 1/(yu*yv)}, yw] + 6*G[{0}, yv^(-1)]*G[{yu^(-1)}, yw]*
      G[{1/(yu*yv)}, yw]*G[{1, 1/(yu*yv)}, yw] - 
     6*G[{0}, yw]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{1, 1/(yu*yv)}, yw] - 
     4*G[{1}, yu^(-1)]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*
      G[{1, 1/(yu*yv)}, yw] - 5*G[{1}, yv^(-1)]*G[{yu^(-1)}, yw]*
      G[{1/(yu*yv)}, yw]*G[{1, 1/(yu*yv)}, yw] + 
     3*G[{1}, yw]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{1, 1/(yu*yv)}, yw] + 
     6*G[{yu^(-1)}, yw]^2*G[{1/(yu*yv)}, yw]*G[{1, 1/(yu*yv)}, yw] + 
     2*G[{0}, yu^(-1)]*G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw]*
      G[{1, 1/(yu*yv)}, yw] + 2*G[{0}, yv^(-1)]*G[{yu}, yv^(-1)]*
      G[{1/(yu*yv)}, yw]*G[{1, 1/(yu*yv)}, yw] - 
     2*G[{0}, yw]*G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{1, 1/(yu*yv)}, yw] + 
     2*G[{1}, yu^(-1)]*G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw]*
      G[{1, 1/(yu*yv)}, yw] + 2*G[{1}, yv^(-1)]*G[{yu}, yv^(-1)]*
      G[{1/(yu*yv)}, yw]*G[{1, 1/(yu*yv)}, yw] + 
     18*G[{1}, yw]*G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw]*
      G[{1, 1/(yu*yv)}, yw] - 3*G[{yu^(-1)}, yw]*G[{yu}, yv^(-1)]*
      G[{1/(yu*yv)}, yw]*G[{1, 1/(yu*yv)}, yw] - 4*G[{yu}, yv^(-1)]^2*
      G[{1/(yu*yv)}, yw]*G[{1, 1/(yu*yv)}, yw] + 6*G[{0}, yu^(-1)]*
      G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{1, 1/(yu*yv)}, yw] + 
     6*G[{0}, yv^(-1)]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*
      G[{1, 1/(yu*yv)}, yw] - 6*G[{0}, yw]*G[{yv^(-1)}, yw]*
      G[{1/(yu*yv)}, yw]*G[{1, 1/(yu*yv)}, yw] - 5*G[{1}, yu^(-1)]*
      G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{1, 1/(yu*yv)}, yw] - 
     4*G[{1}, yv^(-1)]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*
      G[{1, 1/(yu*yv)}, yw] + 3*G[{1}, yw]*G[{yv^(-1)}, yw]*
      G[{1/(yu*yv)}, yw]*G[{1, 1/(yu*yv)}, yw] + 10*G[{yu^(-1)}, yw]*
      G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{1, 1/(yu*yv)}, yw] - 
     3*G[{yu}, yv^(-1)]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*
      G[{1, 1/(yu*yv)}, yw] + 6*G[{yv^(-1)}, yw]^2*G[{1/(yu*yv)}, yw]*
      G[{1, 1/(yu*yv)}, yw] - 2*G[{0}, yu^(-1)]*G[{1/(yu*yv)}, yw]^2*
      G[{1, 1/(yu*yv)}, yw] - 2*G[{0}, yv^(-1)]*G[{1/(yu*yv)}, yw]^2*
      G[{1, 1/(yu*yv)}, yw] + 2*G[{0}, yw]*G[{1/(yu*yv)}, yw]^2*
      G[{1, 1/(yu*yv)}, yw] + (3*G[{1}, yu^(-1)]*G[{1/(yu*yv)}, yw]^2*
       G[{1, 1/(yu*yv)}, yw])/2 + (3*G[{1}, yv^(-1)]*G[{1/(yu*yv)}, yw]^2*
       G[{1, 1/(yu*yv)}, yw])/2 - G[{1}, yw]*G[{1/(yu*yv)}, yw]^2*
      G[{1, 1/(yu*yv)}, yw] - (9*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2*
       G[{1, 1/(yu*yv)}, yw])/2 + G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw]^2*
      G[{1, 1/(yu*yv)}, yw] - (9*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2*
       G[{1, 1/(yu*yv)}, yw])/2 + (2*G[{1/(yu*yv)}, yw]^3*
       G[{1, 1/(yu*yv)}, yw])/3 - 2*G[{0}, yu^(-1)]*G[{0, 1}, yu^(-1)]*
      G[{1, 1/(yu*yv)}, yw] - 2*G[{0}, yv^(-1)]*G[{0, 1}, yu^(-1)]*
      G[{1, 1/(yu*yv)}, yw] + 2*G[{0}, yw]*G[{0, 1}, yu^(-1)]*
      G[{1, 1/(yu*yv)}, yw] + 4*G[{1}, yu^(-1)]*G[{0, 1}, yu^(-1)]*
      G[{1, 1/(yu*yv)}, yw] + G[{1}, yv^(-1)]*G[{0, 1}, yu^(-1)]*
      G[{1, 1/(yu*yv)}, yw] + 3*G[{1}, yw]*G[{0, 1}, yu^(-1)]*
      G[{1, 1/(yu*yv)}, yw] - 2*G[{yu^(-1)}, yw]*G[{0, 1}, yu^(-1)]*
      G[{1, 1/(yu*yv)}, yw] - G[{yu}, yv^(-1)]*G[{0, 1}, yu^(-1)]*
      G[{1, 1/(yu*yv)}, yw] - 3*G[{yv^(-1)}, yw]*G[{0, 1}, yu^(-1)]*
      G[{1, 1/(yu*yv)}, yw] + 5*G[{1/(yu*yv)}, yw]*G[{0, 1}, yu^(-1)]*
      G[{1, 1/(yu*yv)}, yw] - 2*G[{0}, yu^(-1)]*G[{0, 1}, yv^(-1)]*
      G[{1, 1/(yu*yv)}, yw] - 2*G[{0}, yv^(-1)]*G[{0, 1}, yv^(-1)]*
      G[{1, 1/(yu*yv)}, yw] + 2*G[{0}, yw]*G[{0, 1}, yv^(-1)]*
      G[{1, 1/(yu*yv)}, yw] + 3*G[{1}, yu^(-1)]*G[{0, 1}, yv^(-1)]*
      G[{1, 1/(yu*yv)}, yw] + 4*G[{1}, yv^(-1)]*G[{0, 1}, yv^(-1)]*
      G[{1, 1/(yu*yv)}, yw] + 3*G[{1}, yw]*G[{0, 1}, yv^(-1)]*
      G[{1, 1/(yu*yv)}, yw] - 3*G[{yu^(-1)}, yw]*G[{0, 1}, yv^(-1)]*
      G[{1, 1/(yu*yv)}, yw] - G[{yu}, yv^(-1)]*G[{0, 1}, yv^(-1)]*
      G[{1, 1/(yu*yv)}, yw] - 2*G[{yv^(-1)}, yw]*G[{0, 1}, yv^(-1)]*
      G[{1, 1/(yu*yv)}, yw] + 5*G[{1/(yu*yv)}, yw]*G[{0, 1}, yv^(-1)]*
      G[{1, 1/(yu*yv)}, yw] - 4*G[{0}, yu^(-1)]*G[{0, 1}, yw]*
      G[{1, 1/(yu*yv)}, yw] - 4*G[{0}, yv^(-1)]*G[{0, 1}, yw]*
      G[{1, 1/(yu*yv)}, yw] + 4*G[{0}, yw]*G[{0, 1}, yw]*
      G[{1, 1/(yu*yv)}, yw] + 3*G[{1}, yu^(-1)]*G[{0, 1}, yw]*
      G[{1, 1/(yu*yv)}, yw] + 3*G[{1}, yv^(-1)]*G[{0, 1}, yw]*
      G[{1, 1/(yu*yv)}, yw] - 2*G[{1}, yw]*G[{0, 1}, yw]*
      G[{1, 1/(yu*yv)}, yw] + 2*G[{yu^(-1)}, yw]*G[{0, 1}, yw]*
      G[{1, 1/(yu*yv)}, yw] + 2*G[{yu}, yv^(-1)]*G[{0, 1}, yw]*
      G[{1, 1/(yu*yv)}, yw] + 2*G[{yv^(-1)}, yw]*G[{0, 1}, yw]*
      G[{1, 1/(yu*yv)}, yw] - 4*G[{1/(yu*yv)}, yw]*G[{0, 1}, yw]*
      G[{1, 1/(yu*yv)}, yw] + 4*G[{0}, yu^(-1)]*G[{0, yu^(-1)}, yw]*
      G[{1, 1/(yu*yv)}, yw] + 4*G[{0}, yv^(-1)]*G[{0, yu^(-1)}, yw]*
      G[{1, 1/(yu*yv)}, yw] - 4*G[{0}, yw]*G[{0, yu^(-1)}, yw]*
      G[{1, 1/(yu*yv)}, yw] - 3*G[{1}, yu^(-1)]*G[{0, yu^(-1)}, yw]*
      G[{1, 1/(yu*yv)}, yw] - 3*G[{1}, yv^(-1)]*G[{0, yu^(-1)}, yw]*
      G[{1, 1/(yu*yv)}, yw] + 2*G[{1}, yw]*G[{0, yu^(-1)}, yw]*
      G[{1, 1/(yu*yv)}, yw] - 2*G[{yu^(-1)}, yw]*G[{0, yu^(-1)}, yw]*
      G[{1, 1/(yu*yv)}, yw] - 2*G[{yu}, yv^(-1)]*G[{0, yu^(-1)}, yw]*
      G[{1, 1/(yu*yv)}, yw] - 2*G[{yv^(-1)}, yw]*G[{0, yu^(-1)}, yw]*
      G[{1, 1/(yu*yv)}, yw] + 4*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1)}, yw]*
      G[{1, 1/(yu*yv)}, yw] + 2*G[{0}, yu^(-1)]*G[{0, yu}, yv^(-1)]*
      G[{1, 1/(yu*yv)}, yw] + 2*G[{0}, yv^(-1)]*G[{0, yu}, yv^(-1)]*
      G[{1, 1/(yu*yv)}, yw] - 2*G[{0}, yw]*G[{0, yu}, yv^(-1)]*
      G[{1, 1/(yu*yv)}, yw] - 3*G[{1}, yu^(-1)]*G[{0, yu}, yv^(-1)]*
      G[{1, 1/(yu*yv)}, yw] - 4*G[{1}, yv^(-1)]*G[{0, yu}, yv^(-1)]*
      G[{1, 1/(yu*yv)}, yw] - 3*G[{1}, yw]*G[{0, yu}, yv^(-1)]*
      G[{1, 1/(yu*yv)}, yw] + 3*G[{yu^(-1)}, yw]*G[{0, yu}, yv^(-1)]*
      G[{1, 1/(yu*yv)}, yw] + G[{yu}, yv^(-1)]*G[{0, yu}, yv^(-1)]*
      G[{1, 1/(yu*yv)}, yw] + 2*G[{yv^(-1)}, yw]*G[{0, yu}, yv^(-1)]*
      G[{1, 1/(yu*yv)}, yw] - 5*G[{1/(yu*yv)}, yw]*G[{0, yu}, yv^(-1)]*
      G[{1, 1/(yu*yv)}, yw] + 4*G[{0}, yu^(-1)]*G[{0, yv^(-1)}, yw]*
      G[{1, 1/(yu*yv)}, yw] + 4*G[{0}, yv^(-1)]*G[{0, yv^(-1)}, yw]*
      G[{1, 1/(yu*yv)}, yw] - 4*G[{0}, yw]*G[{0, yv^(-1)}, yw]*
      G[{1, 1/(yu*yv)}, yw] - 3*G[{1}, yu^(-1)]*G[{0, yv^(-1)}, yw]*
      G[{1, 1/(yu*yv)}, yw] - 3*G[{1}, yv^(-1)]*G[{0, yv^(-1)}, yw]*
      G[{1, 1/(yu*yv)}, yw] + 2*G[{1}, yw]*G[{0, yv^(-1)}, yw]*
      G[{1, 1/(yu*yv)}, yw] - 2*G[{yu^(-1)}, yw]*G[{0, yv^(-1)}, yw]*
      G[{1, 1/(yu*yv)}, yw] - 2*G[{yu}, yv^(-1)]*G[{0, yv^(-1)}, yw]*
      G[{1, 1/(yu*yv)}, yw] - 2*G[{yv^(-1)}, yw]*G[{0, yv^(-1)}, yw]*
      G[{1, 1/(yu*yv)}, yw] + 4*G[{1/(yu*yv)}, yw]*G[{0, yv^(-1)}, yw]*
      G[{1, 1/(yu*yv)}, yw] - 4*G[{0}, yu^(-1)]*G[{0, 1/(yu*yv)}, yw]*
      G[{1, 1/(yu*yv)}, yw] - 4*G[{0}, yv^(-1)]*G[{0, 1/(yu*yv)}, yw]*
      G[{1, 1/(yu*yv)}, yw] + 4*G[{0}, yw]*G[{0, 1/(yu*yv)}, yw]*
      G[{1, 1/(yu*yv)}, yw] + 3*G[{1}, yu^(-1)]*G[{0, 1/(yu*yv)}, yw]*
      G[{1, 1/(yu*yv)}, yw] + 3*G[{1}, yv^(-1)]*G[{0, 1/(yu*yv)}, yw]*
      G[{1, 1/(yu*yv)}, yw] - 2*G[{1}, yw]*G[{0, 1/(yu*yv)}, yw]*
      G[{1, 1/(yu*yv)}, yw] + 2*G[{yu^(-1)}, yw]*G[{0, 1/(yu*yv)}, yw]*
      G[{1, 1/(yu*yv)}, yw] + 2*G[{yu}, yv^(-1)]*G[{0, 1/(yu*yv)}, yw]*
      G[{1, 1/(yu*yv)}, yw] + 2*G[{yv^(-1)}, yw]*G[{0, 1/(yu*yv)}, yw]*
      G[{1, 1/(yu*yv)}, yw] - 4*G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv)}, yw]*
      G[{1, 1/(yu*yv)}, yw] - 6*G[{0}, yu^(-1)]*G[{1, yu^(-1)}, yw]*
      G[{1, 1/(yu*yv)}, yw] - 6*G[{0}, yv^(-1)]*G[{1, yu^(-1)}, yw]*
      G[{1, 1/(yu*yv)}, yw] + 6*G[{0}, yw]*G[{1, yu^(-1)}, yw]*
      G[{1, 1/(yu*yv)}, yw] + 6*G[{1}, yu^(-1)]*G[{1, yu^(-1)}, yw]*
      G[{1, 1/(yu*yv)}, yw] + 4*G[{1}, yv^(-1)]*G[{1, yu^(-1)}, yw]*
      G[{1, 1/(yu*yv)}, yw] - 2*G[{1}, yw]*G[{1, yu^(-1)}, yw]*
      G[{1, 1/(yu*yv)}, yw] - G[{yu^(-1)}, yw]*G[{1, yu^(-1)}, yw]*
      G[{1, 1/(yu*yv)}, yw] + 2*G[{yu}, yv^(-1)]*G[{1, yu^(-1)}, yw]*
      G[{1, 1/(yu*yv)}, yw] + G[{1/(yu*yv)}, yw]*G[{1, yu^(-1)}, yw]*
      G[{1, 1/(yu*yv)}, yw] + 2*G[{1}, yu^(-1)]*G[{1, yu}, yv^(-1)]*
      G[{1, 1/(yu*yv)}, yw] - 2*G[{1}, yv^(-1)]*G[{1, yu}, yv^(-1)]*
      G[{1, 1/(yu*yv)}, yw] - G[{yu^(-1)}, yw]*G[{1, yu}, yv^(-1)]*
      G[{1, 1/(yu*yv)}, yw] + G[{yv^(-1)}, yw]*G[{1, yu}, yv^(-1)]*
      G[{1, 1/(yu*yv)}, yw] - 6*G[{0}, yu^(-1)]*G[{1, yv^(-1)}, yw]*
      G[{1, 1/(yu*yv)}, yw] - 6*G[{0}, yv^(-1)]*G[{1, yv^(-1)}, yw]*
      G[{1, 1/(yu*yv)}, yw] + 6*G[{0}, yw]*G[{1, yv^(-1)}, yw]*
      G[{1, 1/(yu*yv)}, yw] + 4*G[{1}, yu^(-1)]*G[{1, yv^(-1)}, yw]*
      G[{1, 1/(yu*yv)}, yw] + 6*G[{1}, yv^(-1)]*G[{1, yv^(-1)}, yw]*
      G[{1, 1/(yu*yv)}, yw] - 2*G[{1}, yw]*G[{1, yv^(-1)}, yw]*
      G[{1, 1/(yu*yv)}, yw] + 2*G[{yu}, yv^(-1)]*G[{1, yv^(-1)}, yw]*
      G[{1, 1/(yu*yv)}, yw] - G[{yv^(-1)}, yw]*G[{1, yv^(-1)}, yw]*
      G[{1, 1/(yu*yv)}, yw] + G[{1/(yu*yv)}, yw]*G[{1, yv^(-1)}, yw]*
      G[{1, 1/(yu*yv)}, yw] + 2*G[{0}, yu^(-1)]*G[{1, 1/(yu*yv)}, yw]^2 + 
     2*G[{0}, yv^(-1)]*G[{1, 1/(yu*yv)}, yw]^2 - 
     2*G[{0}, yw]*G[{1, 1/(yu*yv)}, yw]^2 - 2*G[{1}, yu^(-1)]*
      G[{1, 1/(yu*yv)}, yw]^2 - 2*G[{1}, yv^(-1)]*G[{1, 1/(yu*yv)}, yw]^2 + 
     (5*G[{yu^(-1)}, yw]*G[{1, 1/(yu*yv)}, yw]^2)/2 + 
     (5*G[{yv^(-1)}, yw]*G[{1, 1/(yu*yv)}, yw]^2)/2 - 
     5*G[{1/(yu*yv)}, yw]*G[{1, 1/(yu*yv)}, yw]^2 + 
     (Pi^2*G[{0}, yu^(-1)]*G[{yu^(-1), 1/(yu*yv)}, yw])/3 + 
     (Pi^2*G[{0}, yv^(-1)]*G[{yu^(-1), 1/(yu*yv)}, yw])/3 - 
     (Pi^2*G[{0}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw])/3 - 
     (2*Pi^2*G[{1}, yu^(-1)]*G[{yu^(-1), 1/(yu*yv)}, yw])/3 - 
     (5*Pi^2*G[{1}, yv^(-1)]*G[{yu^(-1), 1/(yu*yv)}, yw])/6 - 
     G[{0}, yu^(-1)]*G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*
      G[{yu^(-1), 1/(yu*yv)}, yw] - G[{0}, yv^(-1)]*G[{1}, yu^(-1)]*
      G[{1}, yv^(-1)]*G[{yu^(-1), 1/(yu*yv)}, yw] + 
     G[{0}, yw]*G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*G[{yu^(-1), 1/(yu*yv)}, yw] + 
     2*G[{1}, yu^(-1)]^2*G[{1}, yv^(-1)]*G[{yu^(-1), 1/(yu*yv)}, yw] - 
     (7*Pi^2*G[{1}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw])/6 - 
     (G[{0}, yu^(-1)]^2*G[{1}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw])/2 - 
     G[{0}, yu^(-1)]*G[{0}, yv^(-1)]*G[{1}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw] - 
     (G[{0}, yv^(-1)]^2*G[{1}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw])/2 + 
     G[{0}, yu^(-1)]*G[{0}, yw]*G[{1}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw] + 
     G[{0}, yv^(-1)]*G[{0}, yw]*G[{1}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw] - 
     (G[{0}, yw]^2*G[{1}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw])/2 + 
     G[{0}, yu^(-1)]*G[{1}, yu^(-1)]*G[{1}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw] + 
     G[{0}, yv^(-1)]*G[{1}, yu^(-1)]*G[{1}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw] - 
     G[{0}, yw]*G[{1}, yu^(-1)]*G[{1}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw] - 
     (G[{1}, yu^(-1)]^2*G[{1}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw])/2 - 
     3*G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*G[{1}, yw]*G[{yu^(-1), 1/(yu*yv)}, 
       yw] + (G[{1}, yv^(-1)]^2*G[{1}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw])/2 + 
     (7*Pi^2*G[{yu^(-1)}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw])/6 + 
     (G[{0}, yu^(-1)]^2*G[{yu^(-1)}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw])/2 + 
     G[{0}, yu^(-1)]*G[{0}, yv^(-1)]*G[{yu^(-1)}, yw]*
      G[{yu^(-1), 1/(yu*yv)}, yw] + (G[{0}, yv^(-1)]^2*G[{yu^(-1)}, yw]*
       G[{yu^(-1), 1/(yu*yv)}, yw])/2 - G[{0}, yu^(-1)]*G[{0}, yw]*
      G[{yu^(-1)}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw] - 
     G[{0}, yv^(-1)]*G[{0}, yw]*G[{yu^(-1)}, yw]*G[{yu^(-1), 1/(yu*yv)}, 
       yw] + (G[{0}, yw]^2*G[{yu^(-1)}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw])/2 - 
     G[{0}, yu^(-1)]*G[{1}, yu^(-1)]*G[{yu^(-1)}, yw]*
      G[{yu^(-1), 1/(yu*yv)}, yw] - G[{0}, yv^(-1)]*G[{1}, yu^(-1)]*
      G[{yu^(-1)}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw] + 
     G[{0}, yw]*G[{1}, yu^(-1)]*G[{yu^(-1)}, yw]*G[{yu^(-1), 1/(yu*yv)}, 
       yw] + (G[{1}, yu^(-1)]^2*G[{yu^(-1)}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw])/
      2 - 3*G[{0}, yu^(-1)]*G[{1}, yv^(-1)]*G[{yu^(-1)}, yw]*
      G[{yu^(-1), 1/(yu*yv)}, yw] - 3*G[{0}, yv^(-1)]*G[{1}, yv^(-1)]*
      G[{yu^(-1)}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw] + 
     3*G[{0}, yw]*G[{1}, yv^(-1)]*G[{yu^(-1)}, yw]*G[{yu^(-1), 1/(yu*yv)}, 
       yw] + 5*G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*G[{yu^(-1)}, yw]*
      G[{yu^(-1), 1/(yu*yv)}, yw] + 3*G[{1}, yv^(-1)]^2*G[{yu^(-1)}, yw]*
      G[{yu^(-1), 1/(yu*yv)}, yw] - 3*G[{0}, yu^(-1)]*G[{1}, yw]*
      G[{yu^(-1)}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw] - 
     3*G[{0}, yv^(-1)]*G[{1}, yw]*G[{yu^(-1)}, yw]*G[{yu^(-1), 1/(yu*yv)}, 
       yw] + 3*G[{0}, yw]*G[{1}, yw]*G[{yu^(-1)}, yw]*
      G[{yu^(-1), 1/(yu*yv)}, yw] + 3*G[{1}, yu^(-1)]*G[{1}, yw]*
      G[{yu^(-1)}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw] + 
     4*G[{1}, yv^(-1)]*G[{1}, yw]*G[{yu^(-1)}, yw]*G[{yu^(-1), 1/(yu*yv)}, 
       yw] + (G[{1}, yw]^2*G[{yu^(-1)}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw])/2 + 
     2*G[{0}, yu^(-1)]*G[{yu^(-1)}, yw]^2*G[{yu^(-1), 1/(yu*yv)}, yw] + 
     2*G[{0}, yv^(-1)]*G[{yu^(-1)}, yw]^2*G[{yu^(-1), 1/(yu*yv)}, yw] - 
     2*G[{0}, yw]*G[{yu^(-1)}, yw]^2*G[{yu^(-1), 1/(yu*yv)}, yw] - 
     2*G[{1}, yu^(-1)]*G[{yu^(-1)}, yw]^2*G[{yu^(-1), 1/(yu*yv)}, yw] - 
     4*G[{1}, yv^(-1)]*G[{yu^(-1)}, yw]^2*G[{yu^(-1), 1/(yu*yv)}, yw] - 
     2*G[{1}, yw]*G[{yu^(-1)}, yw]^2*G[{yu^(-1), 1/(yu*yv)}, yw] + 
     (4*G[{yu^(-1)}, yw]^3*G[{yu^(-1), 1/(yu*yv)}, yw])/3 + 
     (5*Pi^2*G[{yu}, yv^(-1)]*G[{yu^(-1), 1/(yu*yv)}, yw])/6 + 
     G[{0}, yu^(-1)]*G[{1}, yu^(-1)]*G[{yu}, yv^(-1)]*
      G[{yu^(-1), 1/(yu*yv)}, yw] + G[{0}, yv^(-1)]*G[{1}, yu^(-1)]*
      G[{yu}, yv^(-1)]*G[{yu^(-1), 1/(yu*yv)}, yw] - 
     G[{0}, yw]*G[{1}, yu^(-1)]*G[{yu}, yv^(-1)]*G[{yu^(-1), 1/(yu*yv)}, 
       yw] - 2*G[{1}, yu^(-1)]^2*G[{yu}, yv^(-1)]*G[{yu^(-1), 1/(yu*yv)}, 
       yw] + G[{0}, yu^(-1)]*G[{1}, yv^(-1)]*G[{yu}, yv^(-1)]*
      G[{yu^(-1), 1/(yu*yv)}, yw] + G[{0}, yv^(-1)]*G[{1}, yv^(-1)]*
      G[{yu}, yv^(-1)]*G[{yu^(-1), 1/(yu*yv)}, yw] - 
     G[{0}, yw]*G[{1}, yv^(-1)]*G[{yu}, yv^(-1)]*G[{yu^(-1), 1/(yu*yv)}, 
       yw] + 4*G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*G[{yu}, yv^(-1)]*
      G[{yu^(-1), 1/(yu*yv)}, yw] - (G[{1}, yv^(-1)]^2*G[{yu}, yv^(-1)]*
       G[{yu^(-1), 1/(yu*yv)}, yw])/2 + G[{0}, yu^(-1)]*G[{1}, yw]*
      G[{yu}, yv^(-1)]*G[{yu^(-1), 1/(yu*yv)}, yw] + 
     G[{0}, yv^(-1)]*G[{1}, yw]*G[{yu}, yv^(-1)]*G[{yu^(-1), 1/(yu*yv)}, 
       yw] - G[{0}, yw]*G[{1}, yw]*G[{yu}, yv^(-1)]*G[{yu^(-1), 1/(yu*yv)}, 
       yw] + 2*G[{1}, yu^(-1)]*G[{1}, yw]*G[{yu}, yv^(-1)]*
      G[{yu^(-1), 1/(yu*yv)}, yw] + 3*G[{1}, yv^(-1)]*G[{1}, yw]*
      G[{yu}, yv^(-1)]*G[{yu^(-1), 1/(yu*yv)}, yw] + 
     2*G[{0}, yu^(-1)]*G[{yu^(-1)}, yw]*G[{yu}, yv^(-1)]*
      G[{yu^(-1), 1/(yu*yv)}, yw] + 2*G[{0}, yv^(-1)]*G[{yu^(-1)}, yw]*
      G[{yu}, yv^(-1)]*G[{yu^(-1), 1/(yu*yv)}, yw] - 
     2*G[{0}, yw]*G[{yu^(-1)}, yw]*G[{yu}, yv^(-1)]*G[{yu^(-1), 1/(yu*yv)}, 
       yw] - 4*G[{1}, yu^(-1)]*G[{yu^(-1)}, yw]*G[{yu}, yv^(-1)]*
      G[{yu^(-1), 1/(yu*yv)}, yw] - 4*G[{1}, yv^(-1)]*G[{yu^(-1)}, yw]*
      G[{yu}, yv^(-1)]*G[{yu^(-1), 1/(yu*yv)}, yw] - 
     G[{1}, yw]*G[{yu^(-1)}, yw]*G[{yu}, yv^(-1)]*G[{yu^(-1), 1/(yu*yv)}, 
       yw] + 2*G[{yu^(-1)}, yw]^2*G[{yu}, yv^(-1)]*G[{yu^(-1), 1/(yu*yv)}, 
       yw] - G[{0}, yu^(-1)]*G[{yu}, yv^(-1)]^2*G[{yu^(-1), 1/(yu*yv)}, yw] - 
     G[{0}, yv^(-1)]*G[{yu}, yv^(-1)]^2*G[{yu^(-1), 1/(yu*yv)}, yw] + 
     G[{0}, yw]*G[{yu}, yv^(-1)]^2*G[{yu^(-1), 1/(yu*yv)}, yw] - 
     G[{1}, yu^(-1)]*G[{yu}, yv^(-1)]^2*G[{yu^(-1), 1/(yu*yv)}, yw] - 
     2*G[{1}, yv^(-1)]*G[{yu}, yv^(-1)]^2*G[{yu^(-1), 1/(yu*yv)}, yw] - 
     (7*G[{1}, yw]*G[{yu}, yv^(-1)]^2*G[{yu^(-1), 1/(yu*yv)}, yw])/2 + 
     2*G[{yu^(-1)}, yw]*G[{yu}, yv^(-1)]^2*G[{yu^(-1), 1/(yu*yv)}, yw] + 
     (5*G[{yu}, yv^(-1)]^3*G[{yu^(-1), 1/(yu*yv)}, yw])/3 - 
     (Pi^2*G[{yv^(-1)}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw])/6 - 
     (3*G[{0}, yu^(-1)]^2*G[{yv^(-1)}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw])/2 - 
     3*G[{0}, yu^(-1)]*G[{0}, yv^(-1)]*G[{yv^(-1)}, yw]*
      G[{yu^(-1), 1/(yu*yv)}, yw] - (3*G[{0}, yv^(-1)]^2*G[{yv^(-1)}, yw]*
       G[{yu^(-1), 1/(yu*yv)}, yw])/2 + 3*G[{0}, yu^(-1)]*G[{0}, yw]*
      G[{yv^(-1)}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw] + 
     3*G[{0}, yv^(-1)]*G[{0}, yw]*G[{yv^(-1)}, yw]*G[{yu^(-1), 1/(yu*yv)}, 
       yw] - (3*G[{0}, yw]^2*G[{yv^(-1)}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw])/
      2 + 2*G[{0}, yu^(-1)]*G[{1}, yu^(-1)]*G[{yv^(-1)}, yw]*
      G[{yu^(-1), 1/(yu*yv)}, yw] + 2*G[{0}, yv^(-1)]*G[{1}, yu^(-1)]*
      G[{yv^(-1)}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw] - 
     2*G[{0}, yw]*G[{1}, yu^(-1)]*G[{yv^(-1)}, yw]*G[{yu^(-1), 1/(yu*yv)}, 
       yw] - (3*G[{1}, yu^(-1)]^2*G[{yv^(-1)}, yw]*G[{yu^(-1), 1/(yu*yv)}, 
        yw])/2 + 6*G[{0}, yu^(-1)]*G[{1}, yv^(-1)]*G[{yv^(-1)}, yw]*
      G[{yu^(-1), 1/(yu*yv)}, yw] + 6*G[{0}, yv^(-1)]*G[{1}, yv^(-1)]*
      G[{yv^(-1)}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw] - 
     6*G[{0}, yw]*G[{1}, yv^(-1)]*G[{yv^(-1)}, yw]*G[{yu^(-1), 1/(yu*yv)}, 
       yw] - 2*G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*G[{yv^(-1)}, yw]*
      G[{yu^(-1), 1/(yu*yv)}, yw] - (9*G[{1}, yv^(-1)]^2*G[{yv^(-1)}, yw]*
       G[{yu^(-1), 1/(yu*yv)}, yw])/2 - G[{0}, yu^(-1)]*G[{1}, yw]*
      G[{yv^(-1)}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw] - 
     G[{0}, yv^(-1)]*G[{1}, yw]*G[{yv^(-1)}, yw]*G[{yu^(-1), 1/(yu*yv)}, 
       yw] + G[{0}, yw]*G[{1}, yw]*G[{yv^(-1)}, yw]*G[{yu^(-1), 1/(yu*yv)}, 
       yw] + 2*G[{1}, yv^(-1)]*G[{1}, yw]*G[{yv^(-1)}, yw]*
      G[{yu^(-1), 1/(yu*yv)}, yw] - 3*G[{0}, yu^(-1)]*G[{yu^(-1)}, yw]*
      G[{yv^(-1)}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw] - 
     3*G[{0}, yv^(-1)]*G[{yu^(-1)}, yw]*G[{yv^(-1)}, yw]*
      G[{yu^(-1), 1/(yu*yv)}, yw] + 3*G[{0}, yw]*G[{yu^(-1)}, yw]*
      G[{yv^(-1)}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw] + 
     G[{1}, yu^(-1)]*G[{yu^(-1)}, yw]*G[{yv^(-1)}, yw]*
      G[{yu^(-1), 1/(yu*yv)}, yw] + 4*G[{1}, yv^(-1)]*G[{yu^(-1)}, yw]*
      G[{yv^(-1)}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw] - 
     G[{1}, yw]*G[{yu^(-1)}, yw]*G[{yv^(-1)}, yw]*G[{yu^(-1), 1/(yu*yv)}, 
       yw] - 2*G[{yu^(-1)}, yw]^2*G[{yv^(-1)}, yw]*G[{yu^(-1), 1/(yu*yv)}, 
       yw] - 2*G[{0}, yu^(-1)]*G[{yu}, yv^(-1)]*G[{yv^(-1)}, yw]*
      G[{yu^(-1), 1/(yu*yv)}, yw] - 2*G[{0}, yv^(-1)]*G[{yu}, yv^(-1)]*
      G[{yv^(-1)}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw] + 
     2*G[{0}, yw]*G[{yu}, yv^(-1)]*G[{yv^(-1)}, yw]*G[{yu^(-1), 1/(yu*yv)}, 
       yw] + G[{1}, yu^(-1)]*G[{yu}, yv^(-1)]*G[{yv^(-1)}, yw]*
      G[{yu^(-1), 1/(yu*yv)}, yw] - G[{1}, yv^(-1)]*G[{yu}, yv^(-1)]*
      G[{yv^(-1)}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw] + 
     G[{yu^(-1)}, yw]*G[{yu}, yv^(-1)]*G[{yv^(-1)}, yw]*
      G[{yu^(-1), 1/(yu*yv)}, yw] + 2*G[{yu}, yv^(-1)]^2*G[{yv^(-1)}, yw]*
      G[{yu^(-1), 1/(yu*yv)}, yw] - (G[{0}, yu^(-1)]*G[{yv^(-1)}, yw]^2*
       G[{yu^(-1), 1/(yu*yv)}, yw])/2 - (G[{0}, yv^(-1)]*G[{yv^(-1)}, yw]^2*
       G[{yu^(-1), 1/(yu*yv)}, yw])/2 + (G[{0}, yw]*G[{yv^(-1)}, yw]^2*
       G[{yu^(-1), 1/(yu*yv)}, yw])/2 - (5*G[{1}, yu^(-1)]*G[{yv^(-1)}, yw]^2*
       G[{yu^(-1), 1/(yu*yv)}, yw])/2 + (3*G[{1}, yv^(-1)]*G[{yv^(-1)}, yw]^2*
       G[{yu^(-1), 1/(yu*yv)}, yw])/2 - 2*G[{1}, yw]*G[{yv^(-1)}, yw]^2*
      G[{yu^(-1), 1/(yu*yv)}, yw] - (3*G[{yu^(-1)}, yw]*G[{yv^(-1)}, yw]^2*
       G[{yu^(-1), 1/(yu*yv)}, yw])/2 + 2*G[{yu}, yv^(-1)]*G[{yv^(-1)}, yw]^2*
      G[{yu^(-1), 1/(yu*yv)}, yw] + 2*G[{yv^(-1)}, yw]^3*
      G[{yu^(-1), 1/(yu*yv)}, yw] + (Pi^2*G[{1/(yu*yv)}, yw]*
       G[{yu^(-1), 1/(yu*yv)}, yw])/6 + 
     (3*G[{0}, yu^(-1)]^2*G[{1/(yu*yv)}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw])/2 + 
     3*G[{0}, yu^(-1)]*G[{0}, yv^(-1)]*G[{1/(yu*yv)}, yw]*
      G[{yu^(-1), 1/(yu*yv)}, yw] + (3*G[{0}, yv^(-1)]^2*G[{1/(yu*yv)}, yw]*
       G[{yu^(-1), 1/(yu*yv)}, yw])/2 - 3*G[{0}, yu^(-1)]*G[{0}, yw]*
      G[{1/(yu*yv)}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw] - 
     3*G[{0}, yv^(-1)]*G[{0}, yw]*G[{1/(yu*yv)}, yw]*
      G[{yu^(-1), 1/(yu*yv)}, yw] + (3*G[{0}, yw]^2*G[{1/(yu*yv)}, yw]*
       G[{yu^(-1), 1/(yu*yv)}, yw])/2 - 2*G[{0}, yu^(-1)]*G[{1}, yu^(-1)]*
      G[{1/(yu*yv)}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw] - 
     2*G[{0}, yv^(-1)]*G[{1}, yu^(-1)]*G[{1/(yu*yv)}, yw]*
      G[{yu^(-1), 1/(yu*yv)}, yw] + 2*G[{0}, yw]*G[{1}, yu^(-1)]*
      G[{1/(yu*yv)}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw] + 
     (3*G[{1}, yu^(-1)]^2*G[{1/(yu*yv)}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw])/2 - 
     9*G[{0}, yu^(-1)]*G[{1}, yv^(-1)]*G[{1/(yu*yv)}, yw]*
      G[{yu^(-1), 1/(yu*yv)}, yw] - 9*G[{0}, yv^(-1)]*G[{1}, yv^(-1)]*
      G[{1/(yu*yv)}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw] + 
     9*G[{0}, yw]*G[{1}, yv^(-1)]*G[{1/(yu*yv)}, yw]*
      G[{yu^(-1), 1/(yu*yv)}, yw] + 3*G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*
      G[{1/(yu*yv)}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw] + 
     9*G[{1}, yv^(-1)]^2*G[{1/(yu*yv)}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw] + 
     G[{1}, yu^(-1)]*G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{yu^(-1), 1/(yu*yv)}, 
       yw] + 2*G[{1}, yv^(-1)]*G[{1}, yw]*G[{1/(yu*yv)}, yw]*
      G[{yu^(-1), 1/(yu*yv)}, yw] + (3*G[{1}, yw]^2*G[{1/(yu*yv)}, yw]*
       G[{yu^(-1), 1/(yu*yv)}, yw])/2 + 4*G[{0}, yu^(-1)]*G[{yu^(-1)}, yw]*
      G[{1/(yu*yv)}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw] + 
     4*G[{0}, yv^(-1)]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*
      G[{yu^(-1), 1/(yu*yv)}, yw] - 4*G[{0}, yw]*G[{yu^(-1)}, yw]*
      G[{1/(yu*yv)}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw] - 
     2*G[{1}, yu^(-1)]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*
      G[{yu^(-1), 1/(yu*yv)}, yw] - 8*G[{1}, yv^(-1)]*G[{yu^(-1)}, yw]*
      G[{1/(yu*yv)}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw] - 
     2*G[{1}, yw]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*
      G[{yu^(-1), 1/(yu*yv)}, yw] + 4*G[{yu^(-1)}, yw]^2*G[{1/(yu*yv)}, yw]*
      G[{yu^(-1), 1/(yu*yv)}, yw] + 5*G[{0}, yu^(-1)]*G[{yu}, yv^(-1)]*
      G[{1/(yu*yv)}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw] + 
     5*G[{0}, yv^(-1)]*G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw]*
      G[{yu^(-1), 1/(yu*yv)}, yw] - 5*G[{0}, yw]*G[{yu}, yv^(-1)]*
      G[{1/(yu*yv)}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw] - 
     2*G[{1}, yu^(-1)]*G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw]*
      G[{yu^(-1), 1/(yu*yv)}, yw] - 2*G[{1}, yv^(-1)]*G[{yu}, yv^(-1)]*
      G[{1/(yu*yv)}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw] - 
     3*G[{1}, yw]*G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw]*
      G[{yu^(-1), 1/(yu*yv)}, yw] + 2*G[{yu^(-1)}, yw]*G[{yu}, yv^(-1)]*
      G[{1/(yu*yv)}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw] - 
     3*G[{yu}, yv^(-1)]^2*G[{1/(yu*yv)}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw] + 
     G[{0}, yu^(-1)]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*
      G[{yu^(-1), 1/(yu*yv)}, yw] + G[{0}, yv^(-1)]*G[{yv^(-1)}, yw]*
      G[{1/(yu*yv)}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw] - 
     G[{0}, yw]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{yu^(-1), 1/(yu*yv)}, 
       yw] + 5*G[{1}, yu^(-1)]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*
      G[{yu^(-1), 1/(yu*yv)}, yw] - 3*G[{1}, yv^(-1)]*G[{yv^(-1)}, yw]*
      G[{1/(yu*yv)}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw] + 
     4*G[{1}, yw]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*
      G[{yu^(-1), 1/(yu*yv)}, yw] + 3*G[{yu^(-1)}, yw]*G[{yv^(-1)}, yw]*
      G[{1/(yu*yv)}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw] - 
     4*G[{yu}, yv^(-1)]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*
      G[{yu^(-1), 1/(yu*yv)}, yw] - 6*G[{yv^(-1)}, yw]^2*G[{1/(yu*yv)}, yw]*
      G[{yu^(-1), 1/(yu*yv)}, yw] - (G[{0}, yu^(-1)]*G[{1/(yu*yv)}, yw]^2*
       G[{yu^(-1), 1/(yu*yv)}, yw])/2 - (G[{0}, yv^(-1)]*G[{1/(yu*yv)}, yw]^2*
       G[{yu^(-1), 1/(yu*yv)}, yw])/2 + (G[{0}, yw]*G[{1/(yu*yv)}, yw]^2*
       G[{yu^(-1), 1/(yu*yv)}, yw])/2 - 
     (3*G[{1}, yu^(-1)]*G[{1/(yu*yv)}, yw]^2*G[{yu^(-1), 1/(yu*yv)}, yw])/2 + 
     G[{1}, yv^(-1)]*G[{1/(yu*yv)}, yw]^2*G[{yu^(-1), 1/(yu*yv)}, yw] - 
     (3*G[{1}, yw]*G[{1/(yu*yv)}, yw]^2*G[{yu^(-1), 1/(yu*yv)}, yw])/2 - 
     G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2*G[{yu^(-1), 1/(yu*yv)}, yw] + 
     (3*G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw]^2*G[{yu^(-1), 1/(yu*yv)}, yw])/
      2 + (9*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2*G[{yu^(-1), 1/(yu*yv)}, 
        yw])/2 - (2*G[{1/(yu*yv)}, yw]^3*G[{yu^(-1), 1/(yu*yv)}, yw])/3 + 
     G[{0}, yu^(-1)]*G[{0, 1}, yu^(-1)]*G[{yu^(-1), 1/(yu*yv)}, yw] + 
     G[{0}, yv^(-1)]*G[{0, 1}, yu^(-1)]*G[{yu^(-1), 1/(yu*yv)}, yw] - 
     G[{0}, yw]*G[{0, 1}, yu^(-1)]*G[{yu^(-1), 1/(yu*yv)}, yw] - 
     3*G[{1}, yu^(-1)]*G[{0, 1}, yu^(-1)]*G[{yu^(-1), 1/(yu*yv)}, yw] - 
     2*G[{1}, yv^(-1)]*G[{0, 1}, yu^(-1)]*G[{yu^(-1), 1/(yu*yv)}, yw] - 
     3*G[{1}, yw]*G[{0, 1}, yu^(-1)]*G[{yu^(-1), 1/(yu*yv)}, yw] + 
     2*G[{yu^(-1)}, yw]*G[{0, 1}, yu^(-1)]*G[{yu^(-1), 1/(yu*yv)}, yw] + 
     3*G[{yu}, yv^(-1)]*G[{0, 1}, yu^(-1)]*G[{yu^(-1), 1/(yu*yv)}, yw] + 
     2*G[{yv^(-1)}, yw]*G[{0, 1}, yu^(-1)]*G[{yu^(-1), 1/(yu*yv)}, yw] - 
     4*G[{1/(yu*yv)}, yw]*G[{0, 1}, yu^(-1)]*G[{yu^(-1), 1/(yu*yv)}, yw] + 
     G[{0}, yu^(-1)]*G[{0, 1}, yv^(-1)]*G[{yu^(-1), 1/(yu*yv)}, yw] + 
     G[{0}, yv^(-1)]*G[{0, 1}, yv^(-1)]*G[{yu^(-1), 1/(yu*yv)}, yw] - 
     G[{0}, yw]*G[{0, 1}, yv^(-1)]*G[{yu^(-1), 1/(yu*yv)}, yw] - 
     3*G[{1}, yu^(-1)]*G[{0, 1}, yv^(-1)]*G[{yu^(-1), 1/(yu*yv)}, yw] - 
     3*G[{1}, yv^(-1)]*G[{0, 1}, yv^(-1)]*G[{yu^(-1), 1/(yu*yv)}, yw] - 
     4*G[{1}, yw]*G[{0, 1}, yv^(-1)]*G[{yu^(-1), 1/(yu*yv)}, yw] + 
     G[{yu^(-1)}, yw]*G[{0, 1}, yv^(-1)]*G[{yu^(-1), 1/(yu*yv)}, yw] + 
     2*G[{yu}, yv^(-1)]*G[{0, 1}, yv^(-1)]*G[{yu^(-1), 1/(yu*yv)}, yw] + 
     2*G[{yv^(-1)}, yw]*G[{0, 1}, yv^(-1)]*G[{yu^(-1), 1/(yu*yv)}, yw] - 
     5*G[{1/(yu*yv)}, yw]*G[{0, 1}, yv^(-1)]*G[{yu^(-1), 1/(yu*yv)}, yw] + 
     G[{0}, yu^(-1)]*G[{0, 1}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw] + 
     G[{0}, yv^(-1)]*G[{0, 1}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw] - 
     G[{0}, yw]*G[{0, 1}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw] + 
     G[{1}, yu^(-1)]*G[{0, 1}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw] + 
     G[{1}, yw]*G[{0, 1}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw] - 
     G[{yu^(-1)}, yw]*G[{0, 1}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw] - 
     3*G[{yu}, yv^(-1)]*G[{0, 1}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw] - 
     3*G[{yv^(-1)}, yw]*G[{0, 1}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw] + 
     5*G[{1/(yu*yv)}, yw]*G[{0, 1}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw] - 
     G[{0}, yu^(-1)]*G[{0, yu^(-1)}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw] - 
     G[{0}, yv^(-1)]*G[{0, yu^(-1)}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw] + 
     G[{0}, yw]*G[{0, yu^(-1)}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw] - 
     G[{1}, yu^(-1)]*G[{0, yu^(-1)}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw] - 
     G[{1}, yw]*G[{0, yu^(-1)}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw] + 
     G[{yu^(-1)}, yw]*G[{0, yu^(-1)}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw] + 
     3*G[{yu}, yv^(-1)]*G[{0, yu^(-1)}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw] + 
     3*G[{yv^(-1)}, yw]*G[{0, yu^(-1)}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw] - 
     5*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1)}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw] - 
     G[{0}, yu^(-1)]*G[{0, yu}, yv^(-1)]*G[{yu^(-1), 1/(yu*yv)}, yw] - 
     G[{0}, yv^(-1)]*G[{0, yu}, yv^(-1)]*G[{yu^(-1), 1/(yu*yv)}, yw] + 
     G[{0}, yw]*G[{0, yu}, yv^(-1)]*G[{yu^(-1), 1/(yu*yv)}, yw] + 
     3*G[{1}, yu^(-1)]*G[{0, yu}, yv^(-1)]*G[{yu^(-1), 1/(yu*yv)}, yw] + 
     3*G[{1}, yv^(-1)]*G[{0, yu}, yv^(-1)]*G[{yu^(-1), 1/(yu*yv)}, yw] + 
     4*G[{1}, yw]*G[{0, yu}, yv^(-1)]*G[{yu^(-1), 1/(yu*yv)}, yw] - 
     G[{yu^(-1)}, yw]*G[{0, yu}, yv^(-1)]*G[{yu^(-1), 1/(yu*yv)}, yw] - 
     2*G[{yu}, yv^(-1)]*G[{0, yu}, yv^(-1)]*G[{yu^(-1), 1/(yu*yv)}, yw] - 
     2*G[{yv^(-1)}, yw]*G[{0, yu}, yv^(-1)]*G[{yu^(-1), 1/(yu*yv)}, yw] + 
     5*G[{1/(yu*yv)}, yw]*G[{0, yu}, yv^(-1)]*G[{yu^(-1), 1/(yu*yv)}, yw] - 
     G[{0}, yu^(-1)]*G[{0, yv^(-1)}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw] - 
     G[{0}, yv^(-1)]*G[{0, yv^(-1)}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw] + 
     G[{0}, yw]*G[{0, yv^(-1)}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw] - 
     G[{1}, yu^(-1)]*G[{0, yv^(-1)}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw] - 
     G[{1}, yw]*G[{0, yv^(-1)}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw] + 
     G[{yu^(-1)}, yw]*G[{0, yv^(-1)}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw] + 
     3*G[{yu}, yv^(-1)]*G[{0, yv^(-1)}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw] + 
     3*G[{yv^(-1)}, yw]*G[{0, yv^(-1)}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw] - 
     5*G[{1/(yu*yv)}, yw]*G[{0, yv^(-1)}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw] + 
     G[{0}, yu^(-1)]*G[{0, 1/(yu*yv)}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw] + 
     G[{0}, yv^(-1)]*G[{0, 1/(yu*yv)}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw] - 
     G[{0}, yw]*G[{0, 1/(yu*yv)}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw] + 
     G[{1}, yu^(-1)]*G[{0, 1/(yu*yv)}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw] + 
     G[{1}, yw]*G[{0, 1/(yu*yv)}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw] - 
     G[{yu^(-1)}, yw]*G[{0, 1/(yu*yv)}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw] - 
     3*G[{yu}, yv^(-1)]*G[{0, 1/(yu*yv)}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw] - 
     3*G[{yv^(-1)}, yw]*G[{0, 1/(yu*yv)}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw] + 
     5*G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv)}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw] + 
     2*G[{0}, yu^(-1)]*G[{1, yu^(-1)}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw] + 
     2*G[{0}, yv^(-1)]*G[{1, yu^(-1)}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw] - 
     2*G[{0}, yw]*G[{1, yu^(-1)}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw] - 
     2*G[{1}, yu^(-1)]*G[{1, yu^(-1)}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw] + 
     2*G[{1}, yw]*G[{1, yu^(-1)}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw] - 
     2*G[{yu}, yv^(-1)]*G[{1, yu^(-1)}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw] - 
     G[{yv^(-1)}, yw]*G[{1, yu^(-1)}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw] - 
     6*G[{1}, yu^(-1)]*G[{1, yu}, yv^(-1)]*G[{yu^(-1), 1/(yu*yv)}, yw] + 
     2*G[{1}, yv^(-1)]*G[{1, yu}, yv^(-1)]*G[{yu^(-1), 1/(yu*yv)}, yw] - 
     G[{1}, yw]*G[{1, yu}, yv^(-1)]*G[{yu^(-1), 1/(yu*yv)}, yw] - 
     G[{yu^(-1)}, yw]*G[{1, yu}, yv^(-1)]*G[{yu^(-1), 1/(yu*yv)}, yw] - 
     G[{yu}, yv^(-1)]*G[{1, yu}, yv^(-1)]*G[{yu^(-1), 1/(yu*yv)}, yw] - 
     G[{1/(yu*yv)}, yw]*G[{1, yu}, yv^(-1)]*G[{yu^(-1), 1/(yu*yv)}, yw] + 
     2*G[{0}, yu^(-1)]*G[{1, yv^(-1)}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw] + 
     2*G[{0}, yv^(-1)]*G[{1, yv^(-1)}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw] - 
     2*G[{0}, yw]*G[{1, yv^(-1)}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw] + 
     4*G[{1}, yu^(-1)]*G[{1, yv^(-1)}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw] - 
     2*G[{1}, yv^(-1)]*G[{1, yv^(-1)}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw] + 
     6*G[{1}, yw]*G[{1, yv^(-1)}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw] + 
     G[{yu^(-1)}, yw]*G[{1, yv^(-1)}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw] - 
     6*G[{yu}, yv^(-1)]*G[{1, yv^(-1)}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw] - 
     G[{yv^(-1)}, yw]*G[{1, yv^(-1)}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw] + 
     G[{1/(yu*yv)}, yw]*G[{1, yv^(-1)}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw] - 
     2*G[{0}, yu^(-1)]*G[{1, 1/(yu*yv)}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw] - 
     2*G[{0}, yv^(-1)]*G[{1, 1/(yu*yv)}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw] + 
     2*G[{0}, yw]*G[{1, 1/(yu*yv)}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw] + 
     2*G[{1}, yv^(-1)]*G[{1, 1/(yu*yv)}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw] - 
     2*G[{1}, yw]*G[{1, 1/(yu*yv)}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw] - 
     3*G[{yu^(-1)}, yw]*G[{1, 1/(yu*yv)}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw] + 
     2*G[{yu}, yv^(-1)]*G[{1, 1/(yu*yv)}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw] - 
     4*G[{yv^(-1)}, yw]*G[{1, 1/(yu*yv)}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw] + 
     9*G[{1/(yu*yv)}, yw]*G[{1, 1/(yu*yv)}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw] - 
     2*G[{1}, yu^(-1)]*G[{yu^(-1), 1/(yu*yv)}, yw]^2 - 
     2*G[{1}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw]^2 + 2*G[{yu}, yv^(-1)]*
      G[{yu^(-1), 1/(yu*yv)}, yw]^2 + 
     (5*G[{yv^(-1)}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw]^2)/2 - 
     5*G[{1/(yu*yv)}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw]^2 + 
     (Pi^2*G[{0}, yu^(-1)]*G[{yv^(-1), 1/(yu*yv)}, yw])/3 + 
     (Pi^2*G[{0}, yv^(-1)]*G[{yv^(-1), 1/(yu*yv)}, yw])/3 - 
     (Pi^2*G[{0}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw])/3 - 
     (5*Pi^2*G[{1}, yu^(-1)]*G[{yv^(-1), 1/(yu*yv)}, yw])/6 - 
     (2*Pi^2*G[{1}, yv^(-1)]*G[{yv^(-1), 1/(yu*yv)}, yw])/3 - 
     G[{0}, yu^(-1)]*G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*
      G[{yv^(-1), 1/(yu*yv)}, yw] - G[{0}, yv^(-1)]*G[{1}, yu^(-1)]*
      G[{1}, yv^(-1)]*G[{yv^(-1), 1/(yu*yv)}, yw] + 
     G[{0}, yw]*G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*G[{yv^(-1), 1/(yu*yv)}, yw] + 
     (G[{1}, yu^(-1)]^2*G[{1}, yv^(-1)]*G[{yv^(-1), 1/(yu*yv)}, yw])/2 - 
     (7*Pi^2*G[{1}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw])/6 - 
     (G[{0}, yu^(-1)]^2*G[{1}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw])/2 - 
     G[{0}, yu^(-1)]*G[{0}, yv^(-1)]*G[{1}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw] - 
     (G[{0}, yv^(-1)]^2*G[{1}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw])/2 + 
     G[{0}, yu^(-1)]*G[{0}, yw]*G[{1}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw] + 
     G[{0}, yv^(-1)]*G[{0}, yw]*G[{1}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw] - 
     (G[{0}, yw]^2*G[{1}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw])/2 + 
     (G[{1}, yu^(-1)]^2*G[{1}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw])/2 + 
     G[{0}, yu^(-1)]*G[{1}, yv^(-1)]*G[{1}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw] + 
     G[{0}, yv^(-1)]*G[{1}, yv^(-1)]*G[{1}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw] - 
     G[{0}, yw]*G[{1}, yv^(-1)]*G[{1}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw] - 
     4*G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*G[{1}, yw]*G[{yv^(-1), 1/(yu*yv)}, 
       yw] - (G[{1}, yv^(-1)]^2*G[{1}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw])/2 + 
     Pi^2*G[{yu^(-1)}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw] + 
     (G[{0}, yu^(-1)]^2*G[{yu^(-1)}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw])/2 + 
     G[{0}, yu^(-1)]*G[{0}, yv^(-1)]*G[{yu^(-1)}, yw]*
      G[{yv^(-1), 1/(yu*yv)}, yw] + (G[{0}, yv^(-1)]^2*G[{yu^(-1)}, yw]*
       G[{yv^(-1), 1/(yu*yv)}, yw])/2 - G[{0}, yu^(-1)]*G[{0}, yw]*
      G[{yu^(-1)}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw] - 
     G[{0}, yv^(-1)]*G[{0}, yw]*G[{yu^(-1)}, yw]*G[{yv^(-1), 1/(yu*yv)}, 
       yw] + (G[{0}, yw]^2*G[{yu^(-1)}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw])/2 - 
     (G[{1}, yu^(-1)]^2*G[{yu^(-1)}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw])/2 - 
     4*G[{0}, yu^(-1)]*G[{1}, yv^(-1)]*G[{yu^(-1)}, yw]*
      G[{yv^(-1), 1/(yu*yv)}, yw] - 4*G[{0}, yv^(-1)]*G[{1}, yv^(-1)]*
      G[{yu^(-1)}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw] + 
     4*G[{0}, yw]*G[{1}, yv^(-1)]*G[{yu^(-1)}, yw]*G[{yv^(-1), 1/(yu*yv)}, 
       yw] + 5*G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*G[{yu^(-1)}, yw]*
      G[{yv^(-1), 1/(yu*yv)}, yw] + (5*G[{1}, yv^(-1)]^2*G[{yu^(-1)}, yw]*
       G[{yv^(-1), 1/(yu*yv)}, yw])/2 - 4*G[{0}, yu^(-1)]*G[{1}, yw]*
      G[{yu^(-1)}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw] - 
     4*G[{0}, yv^(-1)]*G[{1}, yw]*G[{yu^(-1)}, yw]*G[{yv^(-1), 1/(yu*yv)}, 
       yw] + 4*G[{0}, yw]*G[{1}, yw]*G[{yu^(-1)}, yw]*
      G[{yv^(-1), 1/(yu*yv)}, yw] + 3*G[{1}, yu^(-1)]*G[{1}, yw]*
      G[{yu^(-1)}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw] + 
     G[{1}, yv^(-1)]*G[{1}, yw]*G[{yu^(-1)}, yw]*G[{yv^(-1), 1/(yu*yv)}, 
       yw] - 2*G[{1}, yw]^2*G[{yu^(-1)}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw] + 
     3*G[{0}, yu^(-1)]*G[{yu^(-1)}, yw]^2*G[{yv^(-1), 1/(yu*yv)}, yw] + 
     3*G[{0}, yv^(-1)]*G[{yu^(-1)}, yw]^2*G[{yv^(-1), 1/(yu*yv)}, yw] - 
     3*G[{0}, yw]*G[{yu^(-1)}, yw]^2*G[{yv^(-1), 1/(yu*yv)}, yw] - 
     2*G[{1}, yu^(-1)]*G[{yu^(-1)}, yw]^2*G[{yv^(-1), 1/(yu*yv)}, yw] - 
     5*G[{1}, yv^(-1)]*G[{yu^(-1)}, yw]^2*G[{yv^(-1), 1/(yu*yv)}, yw] - 
     G[{1}, yw]*G[{yu^(-1)}, yw]^2*G[{yv^(-1), 1/(yu*yv)}, yw] + 
     (5*G[{yu^(-1)}, yw]^3*G[{yv^(-1), 1/(yu*yv)}, yw])/3 + 
     (5*Pi^2*G[{yu}, yv^(-1)]*G[{yv^(-1), 1/(yu*yv)}, yw])/6 + 
     G[{0}, yu^(-1)]*G[{1}, yu^(-1)]*G[{yu}, yv^(-1)]*
      G[{yv^(-1), 1/(yu*yv)}, yw] + G[{0}, yv^(-1)]*G[{1}, yu^(-1)]*
      G[{yu}, yv^(-1)]*G[{yv^(-1), 1/(yu*yv)}, yw] - 
     G[{0}, yw]*G[{1}, yu^(-1)]*G[{yu}, yv^(-1)]*G[{yv^(-1), 1/(yu*yv)}, 
       yw] - (G[{1}, yu^(-1)]^2*G[{yu}, yv^(-1)]*G[{yv^(-1), 1/(yu*yv)}, yw])/
      2 + G[{0}, yu^(-1)]*G[{1}, yv^(-1)]*G[{yu}, yv^(-1)]*
      G[{yv^(-1), 1/(yu*yv)}, yw] + G[{0}, yv^(-1)]*G[{1}, yv^(-1)]*
      G[{yu}, yv^(-1)]*G[{yv^(-1), 1/(yu*yv)}, yw] - 
     G[{0}, yw]*G[{1}, yv^(-1)]*G[{yu}, yv^(-1)]*G[{yv^(-1), 1/(yu*yv)}, 
       yw] + 3*G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*G[{yu}, yv^(-1)]*
      G[{yv^(-1), 1/(yu*yv)}, yw] - 2*G[{1}, yv^(-1)]^2*G[{yu}, yv^(-1)]*
      G[{yv^(-1), 1/(yu*yv)}, yw] + G[{0}, yu^(-1)]*G[{1}, yw]*
      G[{yu}, yv^(-1)]*G[{yv^(-1), 1/(yu*yv)}, yw] + 
     G[{0}, yv^(-1)]*G[{1}, yw]*G[{yu}, yv^(-1)]*G[{yv^(-1), 1/(yu*yv)}, 
       yw] - G[{0}, yw]*G[{1}, yw]*G[{yu}, yv^(-1)]*G[{yv^(-1), 1/(yu*yv)}, 
       yw] + 3*G[{1}, yu^(-1)]*G[{1}, yw]*G[{yu}, yv^(-1)]*
      G[{yv^(-1), 1/(yu*yv)}, yw] + 2*G[{1}, yv^(-1)]*G[{1}, yw]*
      G[{yu}, yv^(-1)]*G[{yv^(-1), 1/(yu*yv)}, yw] + 
     2*G[{0}, yu^(-1)]*G[{yu^(-1)}, yw]*G[{yu}, yv^(-1)]*
      G[{yv^(-1), 1/(yu*yv)}, yw] + 2*G[{0}, yv^(-1)]*G[{yu^(-1)}, yw]*
      G[{yu}, yv^(-1)]*G[{yv^(-1), 1/(yu*yv)}, yw] - 
     2*G[{0}, yw]*G[{yu^(-1)}, yw]*G[{yu}, yv^(-1)]*G[{yv^(-1), 1/(yu*yv)}, 
       yw] - 4*G[{1}, yu^(-1)]*G[{yu^(-1)}, yw]*G[{yu}, yv^(-1)]*
      G[{yv^(-1), 1/(yu*yv)}, yw] - 2*G[{1}, yv^(-1)]*G[{yu^(-1)}, yw]*
      G[{yu}, yv^(-1)]*G[{yv^(-1), 1/(yu*yv)}, yw] + 
     4*G[{1}, yw]*G[{yu^(-1)}, yw]*G[{yu}, yv^(-1)]*G[{yv^(-1), 1/(yu*yv)}, 
       yw] + G[{yu^(-1)}, yw]^2*G[{yu}, yv^(-1)]*G[{yv^(-1), 1/(yu*yv)}, 
       yw] - G[{0}, yu^(-1)]*G[{yu}, yv^(-1)]^2*G[{yv^(-1), 1/(yu*yv)}, yw] - 
     G[{0}, yv^(-1)]*G[{yu}, yv^(-1)]^2*G[{yv^(-1), 1/(yu*yv)}, yw] + 
     G[{0}, yw]*G[{yu}, yv^(-1)]^2*G[{yv^(-1), 1/(yu*yv)}, yw] - 
     2*G[{1}, yu^(-1)]*G[{yu}, yv^(-1)]^2*G[{yv^(-1), 1/(yu*yv)}, yw] - 
     G[{1}, yv^(-1)]*G[{yu}, yv^(-1)]^2*G[{yv^(-1), 1/(yu*yv)}, yw] - 
     (7*G[{1}, yw]*G[{yu}, yv^(-1)]^2*G[{yv^(-1), 1/(yu*yv)}, yw])/2 + 
     G[{yu^(-1)}, yw]*G[{yu}, yv^(-1)]^2*G[{yv^(-1), 1/(yu*yv)}, yw] + 
     (5*G[{yu}, yv^(-1)]^3*G[{yv^(-1), 1/(yu*yv)}, yw])/3 + 
     (7*Pi^2*G[{yv^(-1)}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw])/6 + 
     (G[{0}, yu^(-1)]^2*G[{yv^(-1)}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw])/2 + 
     G[{0}, yu^(-1)]*G[{0}, yv^(-1)]*G[{yv^(-1)}, yw]*
      G[{yv^(-1), 1/(yu*yv)}, yw] + (G[{0}, yv^(-1)]^2*G[{yv^(-1)}, yw]*
       G[{yv^(-1), 1/(yu*yv)}, yw])/2 - G[{0}, yu^(-1)]*G[{0}, yw]*
      G[{yv^(-1)}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw] - 
     G[{0}, yv^(-1)]*G[{0}, yw]*G[{yv^(-1)}, yw]*G[{yv^(-1), 1/(yu*yv)}, 
       yw] + (G[{0}, yw]^2*G[{yv^(-1)}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw])/2 - 
     3*G[{0}, yu^(-1)]*G[{1}, yu^(-1)]*G[{yv^(-1)}, yw]*
      G[{yv^(-1), 1/(yu*yv)}, yw] - 3*G[{0}, yv^(-1)]*G[{1}, yu^(-1)]*
      G[{yv^(-1)}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw] + 
     3*G[{0}, yw]*G[{1}, yu^(-1)]*G[{yv^(-1)}, yw]*G[{yv^(-1), 1/(yu*yv)}, 
       yw] + 3*G[{1}, yu^(-1)]^2*G[{yv^(-1)}, yw]*G[{yv^(-1), 1/(yu*yv)}, 
       yw] - G[{0}, yu^(-1)]*G[{1}, yv^(-1)]*G[{yv^(-1)}, yw]*
      G[{yv^(-1), 1/(yu*yv)}, yw] - G[{0}, yv^(-1)]*G[{1}, yv^(-1)]*
      G[{yv^(-1)}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw] + 
     G[{0}, yw]*G[{1}, yv^(-1)]*G[{yv^(-1)}, yw]*G[{yv^(-1), 1/(yu*yv)}, 
       yw] + 4*G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*G[{yv^(-1)}, yw]*
      G[{yv^(-1), 1/(yu*yv)}, yw] + (G[{1}, yv^(-1)]^2*G[{yv^(-1)}, yw]*
       G[{yv^(-1), 1/(yu*yv)}, yw])/2 - 3*G[{0}, yu^(-1)]*G[{1}, yw]*
      G[{yv^(-1)}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw] - 
     3*G[{0}, yv^(-1)]*G[{1}, yw]*G[{yv^(-1)}, yw]*G[{yv^(-1), 1/(yu*yv)}, 
       yw] + 3*G[{0}, yw]*G[{1}, yw]*G[{yv^(-1)}, yw]*
      G[{yv^(-1), 1/(yu*yv)}, yw] + 4*G[{1}, yu^(-1)]*G[{1}, yw]*
      G[{yv^(-1)}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw] + 
     3*G[{1}, yv^(-1)]*G[{1}, yw]*G[{yv^(-1)}, yw]*G[{yv^(-1), 1/(yu*yv)}, 
       yw] + (G[{1}, yw]^2*G[{yv^(-1)}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw])/2 + 
     2*G[{0}, yu^(-1)]*G[{yu^(-1)}, yw]*G[{yv^(-1)}, yw]*
      G[{yv^(-1), 1/(yu*yv)}, yw] + 2*G[{0}, yv^(-1)]*G[{yu^(-1)}, yw]*
      G[{yv^(-1)}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw] - 
     2*G[{0}, yw]*G[{yu^(-1)}, yw]*G[{yv^(-1)}, yw]*G[{yv^(-1), 1/(yu*yv)}, 
       yw] - 4*G[{1}, yu^(-1)]*G[{yu^(-1)}, yw]*G[{yv^(-1)}, yw]*
      G[{yv^(-1), 1/(yu*yv)}, yw] - 4*G[{1}, yv^(-1)]*G[{yu^(-1)}, yw]*
      G[{yv^(-1)}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw] - 
     4*G[{1}, yw]*G[{yu^(-1)}, yw]*G[{yv^(-1)}, yw]*G[{yv^(-1), 1/(yu*yv)}, 
       yw] + 2*G[{yu^(-1)}, yw]^2*G[{yv^(-1)}, yw]*G[{yv^(-1), 1/(yu*yv)}, 
       yw] + 2*G[{0}, yu^(-1)]*G[{yu}, yv^(-1)]*G[{yv^(-1)}, yw]*
      G[{yv^(-1), 1/(yu*yv)}, yw] + 2*G[{0}, yv^(-1)]*G[{yu}, yv^(-1)]*
      G[{yv^(-1)}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw] - 
     2*G[{0}, yw]*G[{yu}, yv^(-1)]*G[{yv^(-1)}, yw]*G[{yv^(-1), 1/(yu*yv)}, 
       yw] - 4*G[{1}, yu^(-1)]*G[{yu}, yv^(-1)]*G[{yv^(-1)}, yw]*
      G[{yv^(-1), 1/(yu*yv)}, yw] - 4*G[{1}, yv^(-1)]*G[{yu}, yv^(-1)]*
      G[{yv^(-1)}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw] - 
     G[{1}, yw]*G[{yu}, yv^(-1)]*G[{yv^(-1)}, yw]*G[{yv^(-1), 1/(yu*yv)}, 
       yw] + 4*G[{yu^(-1)}, yw]*G[{yu}, yv^(-1)]*G[{yv^(-1)}, yw]*
      G[{yv^(-1), 1/(yu*yv)}, yw] + 2*G[{yu}, yv^(-1)]^2*G[{yv^(-1)}, yw]*
      G[{yv^(-1), 1/(yu*yv)}, yw] + 2*G[{0}, yu^(-1)]*G[{yv^(-1)}, yw]^2*
      G[{yv^(-1), 1/(yu*yv)}, yw] + 2*G[{0}, yv^(-1)]*G[{yv^(-1)}, yw]^2*
      G[{yv^(-1), 1/(yu*yv)}, yw] - 2*G[{0}, yw]*G[{yv^(-1)}, yw]^2*
      G[{yv^(-1), 1/(yu*yv)}, yw] - 4*G[{1}, yu^(-1)]*G[{yv^(-1)}, yw]^2*
      G[{yv^(-1), 1/(yu*yv)}, yw] - 2*G[{1}, yv^(-1)]*G[{yv^(-1)}, yw]^2*
      G[{yv^(-1), 1/(yu*yv)}, yw] - 2*G[{1}, yw]*G[{yv^(-1)}, yw]^2*
      G[{yv^(-1), 1/(yu*yv)}, yw] + 2*G[{yu^(-1)}, yw]*G[{yv^(-1)}, yw]^2*
      G[{yv^(-1), 1/(yu*yv)}, yw] + 2*G[{yu}, yv^(-1)]*G[{yv^(-1)}, yw]^2*
      G[{yv^(-1), 1/(yu*yv)}, yw] + (4*G[{yv^(-1)}, yw]^3*
       G[{yv^(-1), 1/(yu*yv)}, yw])/3 + 
     (Pi^2*G[{1/(yu*yv)}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw])/6 + 
     (3*G[{0}, yu^(-1)]^2*G[{1/(yu*yv)}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw])/2 + 
     3*G[{0}, yu^(-1)]*G[{0}, yv^(-1)]*G[{1/(yu*yv)}, yw]*
      G[{yv^(-1), 1/(yu*yv)}, yw] + (3*G[{0}, yv^(-1)]^2*G[{1/(yu*yv)}, yw]*
       G[{yv^(-1), 1/(yu*yv)}, yw])/2 - 3*G[{0}, yu^(-1)]*G[{0}, yw]*
      G[{1/(yu*yv)}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw] - 
     3*G[{0}, yv^(-1)]*G[{0}, yw]*G[{1/(yu*yv)}, yw]*
      G[{yv^(-1), 1/(yu*yv)}, yw] + (3*G[{0}, yw]^2*G[{1/(yu*yv)}, yw]*
       G[{yv^(-1), 1/(yu*yv)}, yw])/2 - 9*G[{0}, yu^(-1)]*G[{1}, yu^(-1)]*
      G[{1/(yu*yv)}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw] - 
     9*G[{0}, yv^(-1)]*G[{1}, yu^(-1)]*G[{1/(yu*yv)}, yw]*
      G[{yv^(-1), 1/(yu*yv)}, yw] + 9*G[{0}, yw]*G[{1}, yu^(-1)]*
      G[{1/(yu*yv)}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw] + 
     9*G[{1}, yu^(-1)]^2*G[{1/(yu*yv)}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw] - 
     2*G[{0}, yu^(-1)]*G[{1}, yv^(-1)]*G[{1/(yu*yv)}, yw]*
      G[{yv^(-1), 1/(yu*yv)}, yw] - 2*G[{0}, yv^(-1)]*G[{1}, yv^(-1)]*
      G[{1/(yu*yv)}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw] + 
     2*G[{0}, yw]*G[{1}, yv^(-1)]*G[{1/(yu*yv)}, yw]*
      G[{yv^(-1), 1/(yu*yv)}, yw] + 2*G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*
      G[{1/(yu*yv)}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw] + 
     (3*G[{1}, yv^(-1)]^2*G[{1/(yu*yv)}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw])/2 + 
     2*G[{1}, yu^(-1)]*G[{1}, yw]*G[{1/(yu*yv)}, yw]*
      G[{yv^(-1), 1/(yu*yv)}, yw] + G[{1}, yv^(-1)]*G[{1}, yw]*
      G[{1/(yu*yv)}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw] + 
     (3*G[{1}, yw]^2*G[{1/(yu*yv)}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw])/2 - 
     3*G[{0}, yu^(-1)]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*
      G[{yv^(-1), 1/(yu*yv)}, yw] - 3*G[{0}, yv^(-1)]*G[{yu^(-1)}, yw]*
      G[{1/(yu*yv)}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw] + 
     3*G[{0}, yw]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*
      G[{yv^(-1), 1/(yu*yv)}, yw] - 2*G[{1}, yu^(-1)]*G[{yu^(-1)}, yw]*
      G[{1/(yu*yv)}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw] + 
     6*G[{1}, yv^(-1)]*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*
      G[{yv^(-1), 1/(yu*yv)}, yw] - 2*G[{1}, yw]*G[{yu^(-1)}, yw]*
      G[{1/(yu*yv)}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw] - 
     3*G[{yu^(-1)}, yw]^2*G[{1/(yu*yv)}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw] + 
     5*G[{0}, yu^(-1)]*G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw]*
      G[{yv^(-1), 1/(yu*yv)}, yw] + 5*G[{0}, yv^(-1)]*G[{yu}, yv^(-1)]*
      G[{1/(yu*yv)}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw] - 
     5*G[{0}, yw]*G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw]*
      G[{yv^(-1), 1/(yu*yv)}, yw] - 2*G[{1}, yu^(-1)]*G[{yu}, yv^(-1)]*
      G[{1/(yu*yv)}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw] - 
     2*G[{1}, yv^(-1)]*G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw]*
      G[{yv^(-1), 1/(yu*yv)}, yw] - 3*G[{1}, yw]*G[{yu}, yv^(-1)]*
      G[{1/(yu*yv)}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw] + 
     2*G[{yu^(-1)}, yw]*G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw]*
      G[{yv^(-1), 1/(yu*yv)}, yw] - 3*G[{yu}, yv^(-1)]^2*G[{1/(yu*yv)}, yw]*
      G[{yv^(-1), 1/(yu*yv)}, yw] + 4*G[{0}, yu^(-1)]*G[{yv^(-1)}, yw]*
      G[{1/(yu*yv)}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw] + 
     4*G[{0}, yv^(-1)]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*
      G[{yv^(-1), 1/(yu*yv)}, yw] - 4*G[{0}, yw]*G[{yv^(-1)}, yw]*
      G[{1/(yu*yv)}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw] - 
     8*G[{1}, yu^(-1)]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*
      G[{yv^(-1), 1/(yu*yv)}, yw] - 2*G[{1}, yv^(-1)]*G[{yv^(-1)}, yw]*
      G[{1/(yu*yv)}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw] - 
     2*G[{1}, yw]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*
      G[{yv^(-1), 1/(yu*yv)}, yw] + 2*G[{yu^(-1)}, yw]*G[{yv^(-1)}, yw]*
      G[{1/(yu*yv)}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw] + 
     2*G[{yu}, yv^(-1)]*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*
      G[{yv^(-1), 1/(yu*yv)}, yw] + 4*G[{yv^(-1)}, yw]^2*G[{1/(yu*yv)}, yw]*
      G[{yv^(-1), 1/(yu*yv)}, yw] - (G[{0}, yu^(-1)]*G[{1/(yu*yv)}, yw]^2*
       G[{yv^(-1), 1/(yu*yv)}, yw])/2 - (G[{0}, yv^(-1)]*G[{1/(yu*yv)}, yw]^2*
       G[{yv^(-1), 1/(yu*yv)}, yw])/2 + (G[{0}, yw]*G[{1/(yu*yv)}, yw]^2*
       G[{yv^(-1), 1/(yu*yv)}, yw])/2 + G[{1}, yu^(-1)]*G[{1/(yu*yv)}, yw]^2*
      G[{yv^(-1), 1/(yu*yv)}, yw] - (3*G[{1}, yv^(-1)]*G[{1/(yu*yv)}, yw]^2*
       G[{yv^(-1), 1/(yu*yv)}, yw])/2 - (3*G[{1}, yw]*G[{1/(yu*yv)}, yw]^2*
       G[{yv^(-1), 1/(yu*yv)}, yw])/2 + 
     (3*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2*G[{yv^(-1), 1/(yu*yv)}, yw])/
      2 + (3*G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw]^2*G[{yv^(-1), 1/(yu*yv)}, 
        yw])/2 - G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]^2*
      G[{yv^(-1), 1/(yu*yv)}, yw] - (2*G[{1/(yu*yv)}, yw]^3*
       G[{yv^(-1), 1/(yu*yv)}, yw])/3 + G[{0}, yu^(-1)]*G[{0, 1}, yu^(-1)]*
      G[{yv^(-1), 1/(yu*yv)}, yw] + G[{0}, yv^(-1)]*G[{0, 1}, yu^(-1)]*
      G[{yv^(-1), 1/(yu*yv)}, yw] - G[{0}, yw]*G[{0, 1}, yu^(-1)]*
      G[{yv^(-1), 1/(yu*yv)}, yw] - 3*G[{1}, yu^(-1)]*G[{0, 1}, yu^(-1)]*
      G[{yv^(-1), 1/(yu*yv)}, yw] - G[{1}, yv^(-1)]*G[{0, 1}, yu^(-1)]*
      G[{yv^(-1), 1/(yu*yv)}, yw] - 4*G[{1}, yw]*G[{0, 1}, yu^(-1)]*
      G[{yv^(-1), 1/(yu*yv)}, yw] + 3*G[{yu^(-1)}, yw]*G[{0, 1}, yu^(-1)]*
      G[{yv^(-1), 1/(yu*yv)}, yw] + 2*G[{yu}, yv^(-1)]*G[{0, 1}, yu^(-1)]*
      G[{yv^(-1), 1/(yu*yv)}, yw] + G[{yv^(-1)}, yw]*G[{0, 1}, yu^(-1)]*
      G[{yv^(-1), 1/(yu*yv)}, yw] - 5*G[{1/(yu*yv)}, yw]*G[{0, 1}, yu^(-1)]*
      G[{yv^(-1), 1/(yu*yv)}, yw] + G[{0}, yu^(-1)]*G[{0, 1}, yv^(-1)]*
      G[{yv^(-1), 1/(yu*yv)}, yw] + G[{0}, yv^(-1)]*G[{0, 1}, yv^(-1)]*
      G[{yv^(-1), 1/(yu*yv)}, yw] - G[{0}, yw]*G[{0, 1}, yv^(-1)]*
      G[{yv^(-1), 1/(yu*yv)}, yw] - 2*G[{1}, yu^(-1)]*G[{0, 1}, yv^(-1)]*
      G[{yv^(-1), 1/(yu*yv)}, yw] - 3*G[{1}, yv^(-1)]*G[{0, 1}, yv^(-1)]*
      G[{yv^(-1), 1/(yu*yv)}, yw] - 3*G[{1}, yw]*G[{0, 1}, yv^(-1)]*
      G[{yv^(-1), 1/(yu*yv)}, yw] + 3*G[{yu^(-1)}, yw]*G[{0, 1}, yv^(-1)]*
      G[{yv^(-1), 1/(yu*yv)}, yw] + 3*G[{yu}, yv^(-1)]*G[{0, 1}, yv^(-1)]*
      G[{yv^(-1), 1/(yu*yv)}, yw] + 2*G[{yv^(-1)}, yw]*G[{0, 1}, yv^(-1)]*
      G[{yv^(-1), 1/(yu*yv)}, yw] - 4*G[{1/(yu*yv)}, yw]*G[{0, 1}, yv^(-1)]*
      G[{yv^(-1), 1/(yu*yv)}, yw] + G[{0}, yu^(-1)]*G[{0, 1}, yw]*
      G[{yv^(-1), 1/(yu*yv)}, yw] + G[{0}, yv^(-1)]*G[{0, 1}, yw]*
      G[{yv^(-1), 1/(yu*yv)}, yw] - G[{0}, yw]*G[{0, 1}, yw]*
      G[{yv^(-1), 1/(yu*yv)}, yw] + G[{1}, yv^(-1)]*G[{0, 1}, yw]*
      G[{yv^(-1), 1/(yu*yv)}, yw] + G[{1}, yw]*G[{0, 1}, yw]*
      G[{yv^(-1), 1/(yu*yv)}, yw] - 2*G[{yu^(-1)}, yw]*G[{0, 1}, yw]*
      G[{yv^(-1), 1/(yu*yv)}, yw] - 3*G[{yu}, yv^(-1)]*G[{0, 1}, yw]*
      G[{yv^(-1), 1/(yu*yv)}, yw] - G[{yv^(-1)}, yw]*G[{0, 1}, yw]*
      G[{yv^(-1), 1/(yu*yv)}, yw] + 5*G[{1/(yu*yv)}, yw]*G[{0, 1}, yw]*
      G[{yv^(-1), 1/(yu*yv)}, yw] - G[{0}, yu^(-1)]*G[{0, yu^(-1)}, yw]*
      G[{yv^(-1), 1/(yu*yv)}, yw] - G[{0}, yv^(-1)]*G[{0, yu^(-1)}, yw]*
      G[{yv^(-1), 1/(yu*yv)}, yw] + G[{0}, yw]*G[{0, yu^(-1)}, yw]*
      G[{yv^(-1), 1/(yu*yv)}, yw] - G[{1}, yv^(-1)]*G[{0, yu^(-1)}, yw]*
      G[{yv^(-1), 1/(yu*yv)}, yw] - G[{1}, yw]*G[{0, yu^(-1)}, yw]*
      G[{yv^(-1), 1/(yu*yv)}, yw] + 2*G[{yu^(-1)}, yw]*G[{0, yu^(-1)}, yw]*
      G[{yv^(-1), 1/(yu*yv)}, yw] + 3*G[{yu}, yv^(-1)]*G[{0, yu^(-1)}, yw]*
      G[{yv^(-1), 1/(yu*yv)}, yw] + G[{yv^(-1)}, yw]*G[{0, yu^(-1)}, yw]*
      G[{yv^(-1), 1/(yu*yv)}, yw] - 5*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1)}, yw]*
      G[{yv^(-1), 1/(yu*yv)}, yw] - G[{0}, yu^(-1)]*G[{0, yu}, yv^(-1)]*
      G[{yv^(-1), 1/(yu*yv)}, yw] - G[{0}, yv^(-1)]*G[{0, yu}, yv^(-1)]*
      G[{yv^(-1), 1/(yu*yv)}, yw] + G[{0}, yw]*G[{0, yu}, yv^(-1)]*
      G[{yv^(-1), 1/(yu*yv)}, yw] + 2*G[{1}, yu^(-1)]*G[{0, yu}, yv^(-1)]*
      G[{yv^(-1), 1/(yu*yv)}, yw] + 3*G[{1}, yv^(-1)]*G[{0, yu}, yv^(-1)]*
      G[{yv^(-1), 1/(yu*yv)}, yw] + 3*G[{1}, yw]*G[{0, yu}, yv^(-1)]*
      G[{yv^(-1), 1/(yu*yv)}, yw] - 3*G[{yu^(-1)}, yw]*G[{0, yu}, yv^(-1)]*
      G[{yv^(-1), 1/(yu*yv)}, yw] - 3*G[{yu}, yv^(-1)]*G[{0, yu}, yv^(-1)]*
      G[{yv^(-1), 1/(yu*yv)}, yw] - 2*G[{yv^(-1)}, yw]*G[{0, yu}, yv^(-1)]*
      G[{yv^(-1), 1/(yu*yv)}, yw] + 4*G[{1/(yu*yv)}, yw]*G[{0, yu}, yv^(-1)]*
      G[{yv^(-1), 1/(yu*yv)}, yw] - G[{0}, yu^(-1)]*G[{0, yv^(-1)}, yw]*
      G[{yv^(-1), 1/(yu*yv)}, yw] - G[{0}, yv^(-1)]*G[{0, yv^(-1)}, yw]*
      G[{yv^(-1), 1/(yu*yv)}, yw] + G[{0}, yw]*G[{0, yv^(-1)}, yw]*
      G[{yv^(-1), 1/(yu*yv)}, yw] - G[{1}, yv^(-1)]*G[{0, yv^(-1)}, yw]*
      G[{yv^(-1), 1/(yu*yv)}, yw] - G[{1}, yw]*G[{0, yv^(-1)}, yw]*
      G[{yv^(-1), 1/(yu*yv)}, yw] + 2*G[{yu^(-1)}, yw]*G[{0, yv^(-1)}, yw]*
      G[{yv^(-1), 1/(yu*yv)}, yw] + 3*G[{yu}, yv^(-1)]*G[{0, yv^(-1)}, yw]*
      G[{yv^(-1), 1/(yu*yv)}, yw] + G[{yv^(-1)}, yw]*G[{0, yv^(-1)}, yw]*
      G[{yv^(-1), 1/(yu*yv)}, yw] - 5*G[{1/(yu*yv)}, yw]*G[{0, yv^(-1)}, yw]*
      G[{yv^(-1), 1/(yu*yv)}, yw] + G[{0}, yu^(-1)]*G[{0, 1/(yu*yv)}, yw]*
      G[{yv^(-1), 1/(yu*yv)}, yw] + G[{0}, yv^(-1)]*G[{0, 1/(yu*yv)}, yw]*
      G[{yv^(-1), 1/(yu*yv)}, yw] - G[{0}, yw]*G[{0, 1/(yu*yv)}, yw]*
      G[{yv^(-1), 1/(yu*yv)}, yw] + G[{1}, yv^(-1)]*G[{0, 1/(yu*yv)}, yw]*
      G[{yv^(-1), 1/(yu*yv)}, yw] + G[{1}, yw]*G[{0, 1/(yu*yv)}, yw]*
      G[{yv^(-1), 1/(yu*yv)}, yw] - 2*G[{yu^(-1)}, yw]*G[{0, 1/(yu*yv)}, yw]*
      G[{yv^(-1), 1/(yu*yv)}, yw] - 3*G[{yu}, yv^(-1)]*G[{0, 1/(yu*yv)}, yw]*
      G[{yv^(-1), 1/(yu*yv)}, yw] - G[{yv^(-1)}, yw]*G[{0, 1/(yu*yv)}, yw]*
      G[{yv^(-1), 1/(yu*yv)}, yw] + 5*G[{1/(yu*yv)}, yw]*
      G[{0, 1/(yu*yv)}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw] + 
     2*G[{0}, yu^(-1)]*G[{1, yu^(-1)}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw] + 
     2*G[{0}, yv^(-1)]*G[{1, yu^(-1)}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw] - 
     2*G[{0}, yw]*G[{1, yu^(-1)}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw] - 
     2*G[{1}, yu^(-1)]*G[{1, yu^(-1)}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw] + 
     4*G[{1}, yv^(-1)]*G[{1, yu^(-1)}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw] + 
     6*G[{1}, yw]*G[{1, yu^(-1)}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw] + 
     G[{yu^(-1)}, yw]*G[{1, yu^(-1)}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw] - 
     6*G[{yu}, yv^(-1)]*G[{1, yu^(-1)}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw] + 
     G[{yv^(-1)}, yw]*G[{1, yu^(-1)}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw] + 
     G[{1/(yu*yv)}, yw]*G[{1, yu^(-1)}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw] - 
     2*G[{1}, yu^(-1)]*G[{1, yu}, yv^(-1)]*G[{yv^(-1), 1/(yu*yv)}, yw] + 
     6*G[{1}, yv^(-1)]*G[{1, yu}, yv^(-1)]*G[{yv^(-1), 1/(yu*yv)}, yw] + 
     G[{1}, yw]*G[{1, yu}, yv^(-1)]*G[{yv^(-1), 1/(yu*yv)}, yw] + 
     G[{yu}, yv^(-1)]*G[{1, yu}, yv^(-1)]*G[{yv^(-1), 1/(yu*yv)}, yw] + 
     G[{yv^(-1)}, yw]*G[{1, yu}, yv^(-1)]*G[{yv^(-1), 1/(yu*yv)}, yw] + 
     G[{1/(yu*yv)}, yw]*G[{1, yu}, yv^(-1)]*G[{yv^(-1), 1/(yu*yv)}, yw] + 
     2*G[{0}, yu^(-1)]*G[{1, yv^(-1)}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw] + 
     2*G[{0}, yv^(-1)]*G[{1, yv^(-1)}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw] - 
     2*G[{0}, yw]*G[{1, yv^(-1)}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw] - 
     2*G[{1}, yv^(-1)]*G[{1, yv^(-1)}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw] + 
     2*G[{1}, yw]*G[{1, yv^(-1)}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw] + 
     G[{yu^(-1)}, yw]*G[{1, yv^(-1)}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw] - 
     2*G[{yu}, yv^(-1)]*G[{1, yv^(-1)}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw] - 
     2*G[{0}, yu^(-1)]*G[{1, 1/(yu*yv)}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw] - 
     2*G[{0}, yv^(-1)]*G[{1, 1/(yu*yv)}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw] + 
     2*G[{0}, yw]*G[{1, 1/(yu*yv)}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw] + 
     2*G[{1}, yu^(-1)]*G[{1, 1/(yu*yv)}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw] - 
     2*G[{1}, yw]*G[{1, 1/(yu*yv)}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw] - 
     6*G[{yu^(-1)}, yw]*G[{1, 1/(yu*yv)}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw] + 
     2*G[{yu}, yv^(-1)]*G[{1, 1/(yu*yv)}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw] - 
     3*G[{yv^(-1)}, yw]*G[{1, 1/(yu*yv)}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw] + 
     9*G[{1/(yu*yv)}, yw]*G[{1, 1/(yu*yv)}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw] - 
     2*G[{1}, yu^(-1)]*G[{yu^(-1), 1/(yu*yv)}, yw]*G[{yv^(-1), 1/(yu*yv)}, 
       yw] + 2*G[{1}, yv^(-1)]*G[{yu^(-1), 1/(yu*yv)}, yw]*
      G[{yv^(-1), 1/(yu*yv)}, yw] - 2*G[{yu^(-1)}, yw]*
      G[{yu^(-1), 1/(yu*yv)}, yw]*G[{yv^(-1), 1/(yu*yv)}, yw] + 
     3*G[{yv^(-1)}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw]*G[{yv^(-1), 1/(yu*yv)}, 
       yw] - 9*G[{1/(yu*yv)}, yw]*G[{yu^(-1), 1/(yu*yv)}, yw]*
      G[{yv^(-1), 1/(yu*yv)}, yw] - 2*G[{1}, yv^(-1)]*
      G[{yv^(-1), 1/(yu*yv)}, yw]^2 - 2*G[{1}, yw]*
      G[{yv^(-1), 1/(yu*yv)}, yw]^2 + 2*G[{yu^(-1)}, yw]*
      G[{yv^(-1), 1/(yu*yv)}, yw]^2 + 2*G[{yu}, yv^(-1)]*
      G[{yv^(-1), 1/(yu*yv)}, yw]^2 - 5*G[{1/(yu*yv)}, yw]*
      G[{yv^(-1), 1/(yu*yv)}, yw]^2 + (Pi^2*G[{0, 0, 1}, yu^(-1)])/3 + 
     2*G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*G[{0, 0, 1}, yu^(-1)] - 
     G[{1}, yv^(-1)]^2*G[{0, 0, 1}, yu^(-1)] - 2*G[{1}, yu^(-1)]*
      G[{yu}, yv^(-1)]*G[{0, 0, 1}, yu^(-1)] + 2*G[{1}, yv^(-1)]*
      G[{yu}, yv^(-1)]*G[{0, 0, 1}, yu^(-1)] - 2*G[{1}, yu^(-1)]*
      G[{yv^(-1)}, yw]*G[{0, 0, 1}, yu^(-1)] + 2*G[{1}, yv^(-1)]*
      G[{yv^(-1)}, yw]*G[{0, 0, 1}, yu^(-1)] - 2*G[{1}, yw]*G[{yv^(-1)}, yw]*
      G[{0, 0, 1}, yu^(-1)] + 2*G[{1}, yu^(-1)]*G[{1/(yu*yv)}, yw]*
      G[{0, 0, 1}, yu^(-1)] - 2*G[{1}, yv^(-1)]*G[{1/(yu*yv)}, yw]*
      G[{0, 0, 1}, yu^(-1)] + 2*G[{1}, yw]*G[{1/(yu*yv)}, yw]*
      G[{0, 0, 1}, yu^(-1)] - G[{1/(yu*yv)}, yw]^2*G[{0, 0, 1}, yu^(-1)] + 
     2*G[{0, 1}, yu^(-1)]*G[{0, 0, 1}, yu^(-1)] - 2*G[{1, yu}, yv^(-1)]*
      G[{0, 0, 1}, yu^(-1)] + 2*G[{1, yv^(-1)}, yw]*G[{0, 0, 1}, yu^(-1)] - 
     2*G[{1, 1/(yu*yv)}, yw]*G[{0, 0, 1}, yu^(-1)] + 
     2*G[{yv^(-1), 1/(yu*yv)}, yw]*G[{0, 0, 1}, yu^(-1)] + 
     (Pi^2*G[{0, 0, 1}, yv^(-1)])/3 - 2*G[{1}, yv^(-1)]*G[{yu^(-1)}, yw]*
      G[{0, 0, 1}, yv^(-1)] - 2*G[{1}, yw]*G[{yu^(-1)}, yw]*
      G[{0, 0, 1}, yv^(-1)] - 2*G[{1}, yv^(-1)]*G[{yu}, yv^(-1)]*
      G[{0, 0, 1}, yv^(-1)] + 2*G[{1}, yv^(-1)]*G[{1/(yu*yv)}, yw]*
      G[{0, 0, 1}, yv^(-1)] + 2*G[{1}, yw]*G[{1/(yu*yv)}, yw]*
      G[{0, 0, 1}, yv^(-1)] - G[{1/(yu*yv)}, yw]^2*G[{0, 0, 1}, yv^(-1)] + 
     2*G[{0, 1}, yv^(-1)]*G[{0, 0, 1}, yv^(-1)] - 2*G[{0, yu}, yv^(-1)]*
      G[{0, 0, 1}, yv^(-1)] + 2*G[{1, yu^(-1)}, yw]*G[{0, 0, 1}, yv^(-1)] + 
     2*G[{1, yu}, yv^(-1)]*G[{0, 0, 1}, yv^(-1)] - 2*G[{1, 1/(yu*yv)}, yw]*
      G[{0, 0, 1}, yv^(-1)] + 2*G[{yu^(-1), 1/(yu*yv)}, yw]*
      G[{0, 0, 1}, yv^(-1)] + G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*
      G[{0, 0, 1}, yw] - 4*G[{0}, yu^(-1)]*G[{1}, yw]*G[{0, 0, 1}, yw] - 
     4*G[{0}, yv^(-1)]*G[{1}, yw]*G[{0, 0, 1}, yw] + 
     4*G[{0}, yw]*G[{1}, yw]*G[{0, 0, 1}, yw] + 4*G[{1}, yu^(-1)]*G[{1}, yw]*
      G[{0, 0, 1}, yw] + 4*G[{1}, yv^(-1)]*G[{1}, yw]*G[{0, 0, 1}, yw] + 
     4*G[{0}, yu^(-1)]*G[{yu^(-1)}, yw]*G[{0, 0, 1}, yw] + 
     4*G[{0}, yv^(-1)]*G[{yu^(-1)}, yw]*G[{0, 0, 1}, yw] - 
     4*G[{0}, yw]*G[{yu^(-1)}, yw]*G[{0, 0, 1}, yw] - 
     4*G[{1}, yu^(-1)]*G[{yu^(-1)}, yw]*G[{0, 0, 1}, yw] - 
     5*G[{1}, yv^(-1)]*G[{yu^(-1)}, yw]*G[{0, 0, 1}, yw] - 
     5*G[{1}, yw]*G[{yu^(-1)}, yw]*G[{0, 0, 1}, yw] + 
     (7*G[{yu^(-1)}, yw]^2*G[{0, 0, 1}, yw])/2 - 
     G[{1}, yu^(-1)]*G[{yu}, yv^(-1)]*G[{0, 0, 1}, yw] - 
     G[{1}, yv^(-1)]*G[{yu}, yv^(-1)]*G[{0, 0, 1}, yw] + 
     G[{yu^(-1)}, yw]*G[{yu}, yv^(-1)]*G[{0, 0, 1}, yw] + 
     G[{yu}, yv^(-1)]^2*G[{0, 0, 1}, yw] + 4*G[{0}, yu^(-1)]*G[{yv^(-1)}, yw]*
      G[{0, 0, 1}, yw] + 4*G[{0}, yv^(-1)]*G[{yv^(-1)}, yw]*
      G[{0, 0, 1}, yw] - 4*G[{0}, yw]*G[{yv^(-1)}, yw]*G[{0, 0, 1}, yw] - 
     5*G[{1}, yu^(-1)]*G[{yv^(-1)}, yw]*G[{0, 0, 1}, yw] - 
     4*G[{1}, yv^(-1)]*G[{yv^(-1)}, yw]*G[{0, 0, 1}, yw] - 
     5*G[{1}, yw]*G[{yv^(-1)}, yw]*G[{0, 0, 1}, yw] + 
     2*G[{yu^(-1)}, yw]*G[{yv^(-1)}, yw]*G[{0, 0, 1}, yw] + 
     G[{yu}, yv^(-1)]*G[{yv^(-1)}, yw]*G[{0, 0, 1}, yw] + 
     (7*G[{yv^(-1)}, yw]^2*G[{0, 0, 1}, yw])/2 - 4*G[{0}, yu^(-1)]*
      G[{1/(yu*yv)}, yw]*G[{0, 0, 1}, yw] - 4*G[{0}, yv^(-1)]*
      G[{1/(yu*yv)}, yw]*G[{0, 0, 1}, yw] + 4*G[{0}, yw]*G[{1/(yu*yv)}, yw]*
      G[{0, 0, 1}, yw] + 5*G[{1}, yu^(-1)]*G[{1/(yu*yv)}, yw]*
      G[{0, 0, 1}, yw] + 5*G[{1}, yv^(-1)]*G[{1/(yu*yv)}, yw]*
      G[{0, 0, 1}, yw] + 10*G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 0, 1}, yw] - 
     7*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 0, 1}, yw] - 
     2*G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, 0, 1}, yw] - 
     7*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 0, 1}, yw] + 
     2*G[{1/(yu*yv)}, yw]^2*G[{0, 0, 1}, yw] + G[{0, 1}, yu^(-1)]*
      G[{0, 0, 1}, yw] + G[{0, 1}, yv^(-1)]*G[{0, 0, 1}, yw] + 
     2*G[{0, 1}, yw]*G[{0, 0, 1}, yw] - 2*G[{0, yu^(-1)}, yw]*
      G[{0, 0, 1}, yw] - G[{0, yu}, yv^(-1)]*G[{0, 0, 1}, yw] - 
     2*G[{0, yv^(-1)}, yw]*G[{0, 0, 1}, yw] + 2*G[{0, 1/(yu*yv)}, yw]*
      G[{0, 0, 1}, yw] + 3*G[{1, yu^(-1)}, yw]*G[{0, 0, 1}, yw] + 
     3*G[{1, yv^(-1)}, yw]*G[{0, 0, 1}, yw] - 6*G[{1, 1/(yu*yv)}, yw]*
      G[{0, 0, 1}, yw] + 3*G[{yu^(-1), 1/(yu*yv)}, yw]*G[{0, 0, 1}, yw] + 
     3*G[{yv^(-1), 1/(yu*yv)}, yw]*G[{0, 0, 1}, yw] - 
     G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*G[{0, 0, yu^(-1)}, yw] + 
     4*G[{0}, yu^(-1)]*G[{1}, yw]*G[{0, 0, yu^(-1)}, yw] + 
     4*G[{0}, yv^(-1)]*G[{1}, yw]*G[{0, 0, yu^(-1)}, yw] - 
     4*G[{0}, yw]*G[{1}, yw]*G[{0, 0, yu^(-1)}, yw] - 
     4*G[{1}, yu^(-1)]*G[{1}, yw]*G[{0, 0, yu^(-1)}, yw] - 
     8*G[{1}, yv^(-1)]*G[{1}, yw]*G[{0, 0, yu^(-1)}, yw] - 
     4*G[{0}, yu^(-1)]*G[{yu^(-1)}, yw]*G[{0, 0, yu^(-1)}, yw] - 
     4*G[{0}, yv^(-1)]*G[{yu^(-1)}, yw]*G[{0, 0, yu^(-1)}, yw] + 
     4*G[{0}, yw]*G[{yu^(-1)}, yw]*G[{0, 0, yu^(-1)}, yw] + 
     4*G[{1}, yu^(-1)]*G[{yu^(-1)}, yw]*G[{0, 0, yu^(-1)}, yw] + 
     9*G[{1}, yv^(-1)]*G[{yu^(-1)}, yw]*G[{0, 0, yu^(-1)}, yw] + 
     5*G[{1}, yw]*G[{yu^(-1)}, yw]*G[{0, 0, yu^(-1)}, yw] - 
     (7*G[{yu^(-1)}, yw]^2*G[{0, 0, yu^(-1)}, yw])/2 + 
     G[{1}, yu^(-1)]*G[{yu}, yv^(-1)]*G[{0, 0, yu^(-1)}, yw] + 
     G[{1}, yv^(-1)]*G[{yu}, yv^(-1)]*G[{0, 0, yu^(-1)}, yw] + 
     4*G[{1}, yw]*G[{yu}, yv^(-1)]*G[{0, 0, yu^(-1)}, yw] - 
     5*G[{yu^(-1)}, yw]*G[{yu}, yv^(-1)]*G[{0, 0, yu^(-1)}, yw] - 
     G[{yu}, yv^(-1)]^2*G[{0, 0, yu^(-1)}, yw] - 4*G[{0}, yu^(-1)]*
      G[{yv^(-1)}, yw]*G[{0, 0, yu^(-1)}, yw] - 4*G[{0}, yv^(-1)]*
      G[{yv^(-1)}, yw]*G[{0, 0, yu^(-1)}, yw] + 4*G[{0}, yw]*G[{yv^(-1)}, yw]*
      G[{0, 0, yu^(-1)}, yw] + 5*G[{1}, yu^(-1)]*G[{yv^(-1)}, yw]*
      G[{0, 0, yu^(-1)}, yw] + 8*G[{1}, yv^(-1)]*G[{yv^(-1)}, yw]*
      G[{0, 0, yu^(-1)}, yw] + 5*G[{1}, yw]*G[{yv^(-1)}, yw]*
      G[{0, 0, yu^(-1)}, yw] - 2*G[{yu^(-1)}, yw]*G[{yv^(-1)}, yw]*
      G[{0, 0, yu^(-1)}, yw] - 5*G[{yu}, yv^(-1)]*G[{yv^(-1)}, yw]*
      G[{0, 0, yu^(-1)}, yw] - (7*G[{yv^(-1)}, yw]^2*G[{0, 0, yu^(-1)}, yw])/
      2 + 4*G[{0}, yu^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, 0, yu^(-1)}, yw] + 
     4*G[{0}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, 0, yu^(-1)}, yw] - 
     4*G[{0}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 0, yu^(-1)}, yw] - 
     5*G[{1}, yu^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, 0, yu^(-1)}, yw] - 
     9*G[{1}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, 0, yu^(-1)}, yw] - 
     10*G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 0, yu^(-1)}, yw] + 
     7*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 0, yu^(-1)}, yw] + 
     6*G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, 0, yu^(-1)}, yw] + 
     7*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 0, yu^(-1)}, yw] - 
     2*G[{1/(yu*yv)}, yw]^2*G[{0, 0, yu^(-1)}, yw] - 
     G[{0, 1}, yu^(-1)]*G[{0, 0, yu^(-1)}, yw] - G[{0, 1}, yv^(-1)]*
      G[{0, 0, yu^(-1)}, yw] - 2*G[{0, 1}, yw]*G[{0, 0, yu^(-1)}, yw] + 
     2*G[{0, yu^(-1)}, yw]*G[{0, 0, yu^(-1)}, yw] + 
     G[{0, yu}, yv^(-1)]*G[{0, 0, yu^(-1)}, yw] + 2*G[{0, yv^(-1)}, yw]*
      G[{0, 0, yu^(-1)}, yw] - 2*G[{0, 1/(yu*yv)}, yw]*
      G[{0, 0, yu^(-1)}, yw] - 3*G[{1, yu^(-1)}, yw]*G[{0, 0, yu^(-1)}, yw] - 
     3*G[{1, yv^(-1)}, yw]*G[{0, 0, yu^(-1)}, yw] + 
     6*G[{1, 1/(yu*yv)}, yw]*G[{0, 0, yu^(-1)}, yw] - 
     3*G[{yu^(-1), 1/(yu*yv)}, yw]*G[{0, 0, yu^(-1)}, yw] - 
     3*G[{yv^(-1), 1/(yu*yv)}, yw]*G[{0, 0, yu^(-1)}, yw] - 
     (Pi^2*G[{0, 0, yu}, yv^(-1)])/3 + 2*G[{1}, yv^(-1)]*G[{yu^(-1)}, yw]*
      G[{0, 0, yu}, yv^(-1)] + 2*G[{1}, yw]*G[{yu^(-1)}, yw]*
      G[{0, 0, yu}, yv^(-1)] + 2*G[{1}, yv^(-1)]*G[{yu}, yv^(-1)]*
      G[{0, 0, yu}, yv^(-1)] - 2*G[{1}, yv^(-1)]*G[{1/(yu*yv)}, yw]*
      G[{0, 0, yu}, yv^(-1)] - 2*G[{1}, yw]*G[{1/(yu*yv)}, yw]*
      G[{0, 0, yu}, yv^(-1)] + G[{1/(yu*yv)}, yw]^2*G[{0, 0, yu}, yv^(-1)] - 
     2*G[{0, 1}, yv^(-1)]*G[{0, 0, yu}, yv^(-1)] + 2*G[{0, yu}, yv^(-1)]*
      G[{0, 0, yu}, yv^(-1)] - 2*G[{1, yu^(-1)}, yw]*G[{0, 0, yu}, yv^(-1)] - 
     2*G[{1, yu}, yv^(-1)]*G[{0, 0, yu}, yv^(-1)] + 
     2*G[{1, 1/(yu*yv)}, yw]*G[{0, 0, yu}, yv^(-1)] - 
     2*G[{yu^(-1), 1/(yu*yv)}, yw]*G[{0, 0, yu}, yv^(-1)] - 
     G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*G[{0, 0, yv^(-1)}, yw] + 
     4*G[{0}, yu^(-1)]*G[{1}, yw]*G[{0, 0, yv^(-1)}, yw] + 
     4*G[{0}, yv^(-1)]*G[{1}, yw]*G[{0, 0, yv^(-1)}, yw] - 
     4*G[{0}, yw]*G[{1}, yw]*G[{0, 0, yv^(-1)}, yw] - 
     8*G[{1}, yu^(-1)]*G[{1}, yw]*G[{0, 0, yv^(-1)}, yw] - 
     4*G[{1}, yv^(-1)]*G[{1}, yw]*G[{0, 0, yv^(-1)}, yw] - 
     4*G[{0}, yu^(-1)]*G[{yu^(-1)}, yw]*G[{0, 0, yv^(-1)}, yw] - 
     4*G[{0}, yv^(-1)]*G[{yu^(-1)}, yw]*G[{0, 0, yv^(-1)}, yw] + 
     4*G[{0}, yw]*G[{yu^(-1)}, yw]*G[{0, 0, yv^(-1)}, yw] + 
     8*G[{1}, yu^(-1)]*G[{yu^(-1)}, yw]*G[{0, 0, yv^(-1)}, yw] + 
     5*G[{1}, yv^(-1)]*G[{yu^(-1)}, yw]*G[{0, 0, yv^(-1)}, yw] + 
     5*G[{1}, yw]*G[{yu^(-1)}, yw]*G[{0, 0, yv^(-1)}, yw] - 
     (7*G[{yu^(-1)}, yw]^2*G[{0, 0, yv^(-1)}, yw])/2 + 
     G[{1}, yu^(-1)]*G[{yu}, yv^(-1)]*G[{0, 0, yv^(-1)}, yw] + 
     G[{1}, yv^(-1)]*G[{yu}, yv^(-1)]*G[{0, 0, yv^(-1)}, yw] + 
     4*G[{1}, yw]*G[{yu}, yv^(-1)]*G[{0, 0, yv^(-1)}, yw] - 
     5*G[{yu^(-1)}, yw]*G[{yu}, yv^(-1)]*G[{0, 0, yv^(-1)}, yw] - 
     G[{yu}, yv^(-1)]^2*G[{0, 0, yv^(-1)}, yw] - 4*G[{0}, yu^(-1)]*
      G[{yv^(-1)}, yw]*G[{0, 0, yv^(-1)}, yw] - 4*G[{0}, yv^(-1)]*
      G[{yv^(-1)}, yw]*G[{0, 0, yv^(-1)}, yw] + 4*G[{0}, yw]*G[{yv^(-1)}, yw]*
      G[{0, 0, yv^(-1)}, yw] + 9*G[{1}, yu^(-1)]*G[{yv^(-1)}, yw]*
      G[{0, 0, yv^(-1)}, yw] + 4*G[{1}, yv^(-1)]*G[{yv^(-1)}, yw]*
      G[{0, 0, yv^(-1)}, yw] + 5*G[{1}, yw]*G[{yv^(-1)}, yw]*
      G[{0, 0, yv^(-1)}, yw] - 2*G[{yu^(-1)}, yw]*G[{yv^(-1)}, yw]*
      G[{0, 0, yv^(-1)}, yw] - 5*G[{yu}, yv^(-1)]*G[{yv^(-1)}, yw]*
      G[{0, 0, yv^(-1)}, yw] - (7*G[{yv^(-1)}, yw]^2*G[{0, 0, yv^(-1)}, yw])/
      2 + 4*G[{0}, yu^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, 0, yv^(-1)}, yw] + 
     4*G[{0}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, 0, yv^(-1)}, yw] - 
     4*G[{0}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 0, yv^(-1)}, yw] - 
     9*G[{1}, yu^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, 0, yv^(-1)}, yw] - 
     5*G[{1}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, 0, yv^(-1)}, yw] - 
     10*G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 0, yv^(-1)}, yw] + 
     7*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 0, yv^(-1)}, yw] + 
     6*G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, 0, yv^(-1)}, yw] + 
     7*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 0, yv^(-1)}, yw] - 
     2*G[{1/(yu*yv)}, yw]^2*G[{0, 0, yv^(-1)}, yw] - 
     G[{0, 1}, yu^(-1)]*G[{0, 0, yv^(-1)}, yw] - G[{0, 1}, yv^(-1)]*
      G[{0, 0, yv^(-1)}, yw] - 2*G[{0, 1}, yw]*G[{0, 0, yv^(-1)}, yw] + 
     2*G[{0, yu^(-1)}, yw]*G[{0, 0, yv^(-1)}, yw] + 
     G[{0, yu}, yv^(-1)]*G[{0, 0, yv^(-1)}, yw] + 2*G[{0, yv^(-1)}, yw]*
      G[{0, 0, yv^(-1)}, yw] - 2*G[{0, 1/(yu*yv)}, yw]*
      G[{0, 0, yv^(-1)}, yw] - 3*G[{1, yu^(-1)}, yw]*G[{0, 0, yv^(-1)}, yw] - 
     3*G[{1, yv^(-1)}, yw]*G[{0, 0, yv^(-1)}, yw] + 
     6*G[{1, 1/(yu*yv)}, yw]*G[{0, 0, yv^(-1)}, yw] - 
     3*G[{yu^(-1), 1/(yu*yv)}, yw]*G[{0, 0, yv^(-1)}, yw] - 
     3*G[{yv^(-1), 1/(yu*yv)}, yw]*G[{0, 0, yv^(-1)}, yw] + 
     G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*G[{0, 0, 1/(yu*yv)}, yw] - 
     4*G[{0}, yu^(-1)]*G[{1}, yw]*G[{0, 0, 1/(yu*yv)}, yw] - 
     4*G[{0}, yv^(-1)]*G[{1}, yw]*G[{0, 0, 1/(yu*yv)}, yw] + 
     4*G[{0}, yw]*G[{1}, yw]*G[{0, 0, 1/(yu*yv)}, yw] + 
     8*G[{1}, yu^(-1)]*G[{1}, yw]*G[{0, 0, 1/(yu*yv)}, yw] + 
     8*G[{1}, yv^(-1)]*G[{1}, yw]*G[{0, 0, 1/(yu*yv)}, yw] + 
     4*G[{0}, yu^(-1)]*G[{yu^(-1)}, yw]*G[{0, 0, 1/(yu*yv)}, yw] + 
     4*G[{0}, yv^(-1)]*G[{yu^(-1)}, yw]*G[{0, 0, 1/(yu*yv)}, yw] - 
     4*G[{0}, yw]*G[{yu^(-1)}, yw]*G[{0, 0, 1/(yu*yv)}, yw] - 
     8*G[{1}, yu^(-1)]*G[{yu^(-1)}, yw]*G[{0, 0, 1/(yu*yv)}, yw] - 
     9*G[{1}, yv^(-1)]*G[{yu^(-1)}, yw]*G[{0, 0, 1/(yu*yv)}, yw] - 
     5*G[{1}, yw]*G[{yu^(-1)}, yw]*G[{0, 0, 1/(yu*yv)}, yw] + 
     (7*G[{yu^(-1)}, yw]^2*G[{0, 0, 1/(yu*yv)}, yw])/2 - 
     G[{1}, yu^(-1)]*G[{yu}, yv^(-1)]*G[{0, 0, 1/(yu*yv)}, yw] - 
     G[{1}, yv^(-1)]*G[{yu}, yv^(-1)]*G[{0, 0, 1/(yu*yv)}, yw] - 
     8*G[{1}, yw]*G[{yu}, yv^(-1)]*G[{0, 0, 1/(yu*yv)}, yw] + 
     9*G[{yu^(-1)}, yw]*G[{yu}, yv^(-1)]*G[{0, 0, 1/(yu*yv)}, yw] + 
     G[{yu}, yv^(-1)]^2*G[{0, 0, 1/(yu*yv)}, yw] + 
     4*G[{0}, yu^(-1)]*G[{yv^(-1)}, yw]*G[{0, 0, 1/(yu*yv)}, yw] + 
     4*G[{0}, yv^(-1)]*G[{yv^(-1)}, yw]*G[{0, 0, 1/(yu*yv)}, yw] - 
     4*G[{0}, yw]*G[{yv^(-1)}, yw]*G[{0, 0, 1/(yu*yv)}, yw] - 
     9*G[{1}, yu^(-1)]*G[{yv^(-1)}, yw]*G[{0, 0, 1/(yu*yv)}, yw] - 
     8*G[{1}, yv^(-1)]*G[{yv^(-1)}, yw]*G[{0, 0, 1/(yu*yv)}, yw] - 
     5*G[{1}, yw]*G[{yv^(-1)}, yw]*G[{0, 0, 1/(yu*yv)}, yw] + 
     2*G[{yu^(-1)}, yw]*G[{yv^(-1)}, yw]*G[{0, 0, 1/(yu*yv)}, yw] + 
     9*G[{yu}, yv^(-1)]*G[{yv^(-1)}, yw]*G[{0, 0, 1/(yu*yv)}, yw] + 
     (7*G[{yv^(-1)}, yw]^2*G[{0, 0, 1/(yu*yv)}, yw])/2 - 
     4*G[{0}, yu^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, 0, 1/(yu*yv)}, yw] - 
     4*G[{0}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, 0, 1/(yu*yv)}, yw] + 
     4*G[{0}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 0, 1/(yu*yv)}, yw] + 
     9*G[{1}, yu^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, 0, 1/(yu*yv)}, yw] + 
     9*G[{1}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, 0, 1/(yu*yv)}, yw] + 
     10*G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 0, 1/(yu*yv)}, yw] - 
     7*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 0, 1/(yu*yv)}, yw] - 
     10*G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, 0, 1/(yu*yv)}, yw] - 
     7*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 0, 1/(yu*yv)}, yw] + 
     2*G[{1/(yu*yv)}, yw]^2*G[{0, 0, 1/(yu*yv)}, yw] + 
     G[{0, 1}, yu^(-1)]*G[{0, 0, 1/(yu*yv)}, yw] + 
     G[{0, 1}, yv^(-1)]*G[{0, 0, 1/(yu*yv)}, yw] + 
     2*G[{0, 1}, yw]*G[{0, 0, 1/(yu*yv)}, yw] - 2*G[{0, yu^(-1)}, yw]*
      G[{0, 0, 1/(yu*yv)}, yw] - G[{0, yu}, yv^(-1)]*
      G[{0, 0, 1/(yu*yv)}, yw] - 2*G[{0, yv^(-1)}, yw]*
      G[{0, 0, 1/(yu*yv)}, yw] + 2*G[{0, 1/(yu*yv)}, yw]*
      G[{0, 0, 1/(yu*yv)}, yw] + 3*G[{1, yu^(-1)}, yw]*
      G[{0, 0, 1/(yu*yv)}, yw] + 3*G[{1, yv^(-1)}, yw]*
      G[{0, 0, 1/(yu*yv)}, yw] - 6*G[{1, 1/(yu*yv)}, yw]*
      G[{0, 0, 1/(yu*yv)}, yw] + 3*G[{yu^(-1), 1/(yu*yv)}, yw]*
      G[{0, 0, 1/(yu*yv)}, yw] + 3*G[{yv^(-1), 1/(yu*yv)}, yw]*
      G[{0, 0, 1/(yu*yv)}, yw] - (Pi^2*G[{0, 1, 1}, yu^(-1)])/2 + 
     2*G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*G[{0, 1, 1}, yu^(-1)] - 
     5*G[{0}, yu^(-1)]*G[{1}, yw]*G[{0, 1, 1}, yu^(-1)] - 
     5*G[{0}, yv^(-1)]*G[{1}, yw]*G[{0, 1, 1}, yu^(-1)] + 
     5*G[{0}, yw]*G[{1}, yw]*G[{0, 1, 1}, yu^(-1)] + 
     G[{1}, yu^(-1)]*G[{1}, yw]*G[{0, 1, 1}, yu^(-1)] + 
     5*G[{1}, yv^(-1)]*G[{1}, yw]*G[{0, 1, 1}, yu^(-1)] + 
     5*G[{0}, yu^(-1)]*G[{yu^(-1)}, yw]*G[{0, 1, 1}, yu^(-1)] + 
     5*G[{0}, yv^(-1)]*G[{yu^(-1)}, yw]*G[{0, 1, 1}, yu^(-1)] - 
     5*G[{0}, yw]*G[{yu^(-1)}, yw]*G[{0, 1, 1}, yu^(-1)] - 
     G[{1}, yu^(-1)]*G[{yu^(-1)}, yw]*G[{0, 1, 1}, yu^(-1)] - 
     10*G[{1}, yv^(-1)]*G[{yu^(-1)}, yw]*G[{0, 1, 1}, yu^(-1)] - 
     G[{1}, yw]*G[{yu^(-1)}, yw]*G[{0, 1, 1}, yu^(-1)] + 
     G[{yu^(-1)}, yw]^2*G[{0, 1, 1}, yu^(-1)] - 2*G[{1}, yu^(-1)]*
      G[{yu}, yv^(-1)]*G[{0, 1, 1}, yu^(-1)] - 5*G[{1}, yv^(-1)]*
      G[{yu}, yv^(-1)]*G[{0, 1, 1}, yu^(-1)] + 5*G[{yu^(-1)}, yw]*
      G[{yu}, yv^(-1)]*G[{0, 1, 1}, yu^(-1)] + 
     (7*G[{yu}, yv^(-1)]^2*G[{0, 1, 1}, yu^(-1)])/2 + 
     5*G[{0}, yu^(-1)]*G[{yv^(-1)}, yw]*G[{0, 1, 1}, yu^(-1)] + 
     5*G[{0}, yv^(-1)]*G[{yv^(-1)}, yw]*G[{0, 1, 1}, yu^(-1)] - 
     5*G[{0}, yw]*G[{yv^(-1)}, yw]*G[{0, 1, 1}, yu^(-1)] - 
     3*G[{1}, yu^(-1)]*G[{yv^(-1)}, yw]*G[{0, 1, 1}, yu^(-1)] - 
     5*G[{1}, yv^(-1)]*G[{yv^(-1)}, yw]*G[{0, 1, 1}, yu^(-1)] - 
     2*G[{1}, yw]*G[{yv^(-1)}, yw]*G[{0, 1, 1}, yu^(-1)] + 
     5*G[{yu^(-1)}, yw]*G[{yv^(-1)}, yw]*G[{0, 1, 1}, yu^(-1)] + 
     2*G[{yu}, yv^(-1)]*G[{yv^(-1)}, yw]*G[{0, 1, 1}, yu^(-1)] + 
     (7*G[{yv^(-1)}, yw]^2*G[{0, 1, 1}, yu^(-1)])/2 - 
     5*G[{0}, yu^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, 1, 1}, yu^(-1)] - 
     5*G[{0}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, 1, 1}, yu^(-1)] + 
     5*G[{0}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1, 1}, yu^(-1)] + 
     3*G[{1}, yu^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, 1, 1}, yu^(-1)] + 
     10*G[{1}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, 1, 1}, yu^(-1)] + 
     3*G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1, 1}, yu^(-1)] - 
     6*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1, 1}, yu^(-1)] - 
     7*G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, 1, 1}, yu^(-1)] - 
     7*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1, 1}, yu^(-1)] + 
     2*G[{1/(yu*yv)}, yw]^2*G[{0, 1, 1}, yu^(-1)] - 
     2*G[{0, 1}, yu^(-1)]*G[{0, 1, 1}, yu^(-1)] + 5*G[{0, 1}, yv^(-1)]*
      G[{0, 1, 1}, yu^(-1)] - 5*G[{0, 1}, yw]*G[{0, 1, 1}, yu^(-1)] + 
     5*G[{0, yu^(-1)}, yw]*G[{0, 1, 1}, yu^(-1)] - 5*G[{0, yu}, yv^(-1)]*
      G[{0, 1, 1}, yu^(-1)] + 5*G[{0, yv^(-1)}, yw]*G[{0, 1, 1}, yu^(-1)] - 
     5*G[{0, 1/(yu*yv)}, yw]*G[{0, 1, 1}, yu^(-1)] + 
     3*G[{1, yu}, yv^(-1)]*G[{0, 1, 1}, yu^(-1)] - 3*G[{1, yv^(-1)}, yw]*
      G[{0, 1, 1}, yu^(-1)] - 3*G[{1, 1/(yu*yv)}, yw]*G[{0, 1, 1}, yu^(-1)] + 
     6*G[{yu^(-1), 1/(yu*yv)}, yw]*G[{0, 1, 1}, yu^(-1)] + 
     3*G[{yv^(-1), 1/(yu*yv)}, yw]*G[{0, 1, 1}, yu^(-1)] - 
     (Pi^2*G[{0, 1, 1}, yv^(-1)])/2 - G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*
      G[{0, 1, 1}, yv^(-1)] - 5*G[{0}, yu^(-1)]*G[{1}, yw]*
      G[{0, 1, 1}, yv^(-1)] - 5*G[{0}, yv^(-1)]*G[{1}, yw]*
      G[{0, 1, 1}, yv^(-1)] + 5*G[{0}, yw]*G[{1}, yw]*G[{0, 1, 1}, yv^(-1)] + 
     3*G[{1}, yu^(-1)]*G[{1}, yw]*G[{0, 1, 1}, yv^(-1)] + 
     G[{1}, yv^(-1)]*G[{1}, yw]*G[{0, 1, 1}, yv^(-1)] + 
     5*G[{0}, yu^(-1)]*G[{yu^(-1)}, yw]*G[{0, 1, 1}, yv^(-1)] + 
     5*G[{0}, yv^(-1)]*G[{yu^(-1)}, yw]*G[{0, 1, 1}, yv^(-1)] - 
     5*G[{0}, yw]*G[{yu^(-1)}, yw]*G[{0, 1, 1}, yv^(-1)] - 
     7*G[{1}, yu^(-1)]*G[{yu^(-1)}, yw]*G[{0, 1, 1}, yv^(-1)] - 
     3*G[{1}, yv^(-1)]*G[{yu^(-1)}, yw]*G[{0, 1, 1}, yv^(-1)] - 
     2*G[{1}, yw]*G[{yu^(-1)}, yw]*G[{0, 1, 1}, yv^(-1)] + 
     (7*G[{yu^(-1)}, yw]^2*G[{0, 1, 1}, yv^(-1)])/2 - 
     3*G[{1}, yu^(-1)]*G[{yu}, yv^(-1)]*G[{0, 1, 1}, yv^(-1)] - 
     2*G[{1}, yv^(-1)]*G[{yu}, yv^(-1)]*G[{0, 1, 1}, yv^(-1)] + 
     2*G[{yu^(-1)}, yw]*G[{yu}, yv^(-1)]*G[{0, 1, 1}, yv^(-1)] + 
     (7*G[{yu}, yv^(-1)]^2*G[{0, 1, 1}, yv^(-1)])/2 + 
     5*G[{0}, yu^(-1)]*G[{yv^(-1)}, yw]*G[{0, 1, 1}, yv^(-1)] + 
     5*G[{0}, yv^(-1)]*G[{yv^(-1)}, yw]*G[{0, 1, 1}, yv^(-1)] - 
     5*G[{0}, yw]*G[{yv^(-1)}, yw]*G[{0, 1, 1}, yv^(-1)] - 
     2*G[{1}, yu^(-1)]*G[{yv^(-1)}, yw]*G[{0, 1, 1}, yv^(-1)] - 
     G[{1}, yv^(-1)]*G[{yv^(-1)}, yw]*G[{0, 1, 1}, yv^(-1)] - 
     G[{1}, yw]*G[{yv^(-1)}, yw]*G[{0, 1, 1}, yv^(-1)] + 
     5*G[{yu^(-1)}, yw]*G[{yv^(-1)}, yw]*G[{0, 1, 1}, yv^(-1)] + 
     5*G[{yu}, yv^(-1)]*G[{yv^(-1)}, yw]*G[{0, 1, 1}, yv^(-1)] + 
     G[{yv^(-1)}, yw]^2*G[{0, 1, 1}, yv^(-1)] - 5*G[{0}, yu^(-1)]*
      G[{1/(yu*yv)}, yw]*G[{0, 1, 1}, yv^(-1)] - 5*G[{0}, yv^(-1)]*
      G[{1/(yu*yv)}, yw]*G[{0, 1, 1}, yv^(-1)] + 
     5*G[{0}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1, 1}, yv^(-1)] + 
     6*G[{1}, yu^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, 1, 1}, yv^(-1)] + 
     3*G[{1}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, 1, 1}, yv^(-1)] + 
     3*G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1, 1}, yv^(-1)] - 
     7*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1, 1}, yv^(-1)] - 
     7*G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, 1, 1}, yv^(-1)] - 
     6*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1, 1}, yv^(-1)] + 
     2*G[{1/(yu*yv)}, yw]^2*G[{0, 1, 1}, yv^(-1)] - 
     G[{0, 1}, yu^(-1)]*G[{0, 1, 1}, yv^(-1)] - 2*G[{0, 1}, yv^(-1)]*
      G[{0, 1, 1}, yv^(-1)] - 5*G[{0, 1}, yw]*G[{0, 1, 1}, yv^(-1)] + 
     5*G[{0, yu^(-1)}, yw]*G[{0, 1, 1}, yv^(-1)] - 2*G[{0, yu}, yv^(-1)]*
      G[{0, 1, 1}, yv^(-1)] + 5*G[{0, yv^(-1)}, yw]*G[{0, 1, 1}, yv^(-1)] - 
     5*G[{0, 1/(yu*yv)}, yw]*G[{0, 1, 1}, yv^(-1)] - 
     3*G[{1, yu^(-1)}, yw]*G[{0, 1, 1}, yv^(-1)] - 3*G[{1, yu}, yv^(-1)]*
      G[{0, 1, 1}, yv^(-1)] - 3*G[{1, 1/(yu*yv)}, yw]*G[{0, 1, 1}, yv^(-1)] + 
     3*G[{yu^(-1), 1/(yu*yv)}, yw]*G[{0, 1, 1}, yv^(-1)] + 
     6*G[{yv^(-1), 1/(yu*yv)}, yw]*G[{0, 1, 1}, yv^(-1)] + 
     (3*Pi^2*G[{0, 1, 1}, yw])/2 + 2*G[{0}, yu^(-1)]^2*G[{0, 1, 1}, yw] + 
     4*G[{0}, yu^(-1)]*G[{0}, yv^(-1)]*G[{0, 1, 1}, yw] + 
     2*G[{0}, yv^(-1)]^2*G[{0, 1, 1}, yw] - 4*G[{0}, yu^(-1)]*G[{0}, yw]*
      G[{0, 1, 1}, yw] - 4*G[{0}, yv^(-1)]*G[{0}, yw]*G[{0, 1, 1}, yw] + 
     2*G[{0}, yw]^2*G[{0, 1, 1}, yw] - 4*G[{0}, yu^(-1)]*G[{1}, yu^(-1)]*
      G[{0, 1, 1}, yw] - 4*G[{0}, yv^(-1)]*G[{1}, yu^(-1)]*G[{0, 1, 1}, yw] + 
     4*G[{0}, yw]*G[{1}, yu^(-1)]*G[{0, 1, 1}, yw] + 
     2*G[{1}, yu^(-1)]^2*G[{0, 1, 1}, yw] - 4*G[{0}, yu^(-1)]*G[{1}, yv^(-1)]*
      G[{0, 1, 1}, yw] - 4*G[{0}, yv^(-1)]*G[{1}, yv^(-1)]*G[{0, 1, 1}, yw] + 
     4*G[{0}, yw]*G[{1}, yv^(-1)]*G[{0, 1, 1}, yw] + 
     8*G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*G[{0, 1, 1}, yw] + 
     2*G[{1}, yv^(-1)]^2*G[{0, 1, 1}, yw] - G[{1}, yw]^2*G[{0, 1, 1}, yw] + 
     4*G[{0}, yu^(-1)]*G[{yu^(-1)}, yw]*G[{0, 1, 1}, yw] + 
     4*G[{0}, yv^(-1)]*G[{yu^(-1)}, yw]*G[{0, 1, 1}, yw] - 
     4*G[{0}, yw]*G[{yu^(-1)}, yw]*G[{0, 1, 1}, yw] - 
     4*G[{1}, yu^(-1)]*G[{yu^(-1)}, yw]*G[{0, 1, 1}, yw] - 
     2*G[{1}, yv^(-1)]*G[{yu^(-1)}, yw]*G[{0, 1, 1}, yw] + 
     2*G[{1}, yw]*G[{yu^(-1)}, yw]*G[{0, 1, 1}, yw] - 
     4*G[{1}, yu^(-1)]*G[{yu}, yv^(-1)]*G[{0, 1, 1}, yw] - 
     4*G[{1}, yv^(-1)]*G[{yu}, yv^(-1)]*G[{0, 1, 1}, yw] - 
     2*G[{yu^(-1)}, yw]*G[{yu}, yv^(-1)]*G[{0, 1, 1}, yw] + 
     4*G[{yu}, yv^(-1)]^2*G[{0, 1, 1}, yw] + 4*G[{0}, yu^(-1)]*
      G[{yv^(-1)}, yw]*G[{0, 1, 1}, yw] + 4*G[{0}, yv^(-1)]*G[{yv^(-1)}, yw]*
      G[{0, 1, 1}, yw] - 4*G[{0}, yw]*G[{yv^(-1)}, yw]*G[{0, 1, 1}, yw] - 
     2*G[{1}, yu^(-1)]*G[{yv^(-1)}, yw]*G[{0, 1, 1}, yw] - 
     4*G[{1}, yv^(-1)]*G[{yv^(-1)}, yw]*G[{0, 1, 1}, yw] + 
     2*G[{1}, yw]*G[{yv^(-1)}, yw]*G[{0, 1, 1}, yw] - 
     2*G[{yu}, yv^(-1)]*G[{yv^(-1)}, yw]*G[{0, 1, 1}, yw] - 
     8*G[{0}, yu^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, 1, 1}, yw] - 
     8*G[{0}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, 1, 1}, yw] + 
     8*G[{0}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1, 1}, yw] + 
     6*G[{1}, yu^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, 1, 1}, yw] + 
     6*G[{1}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, 1, 1}, yw] - 
     2*G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1, 1}, yw] + 
     4*G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, 1, 1}, yw] - 
     G[{1/(yu*yv)}, yw]^2*G[{0, 1, 1}, yw] + 4*G[{0, 1}, yu^(-1)]*
      G[{0, 1, 1}, yw] + 4*G[{0, 1}, yv^(-1)]*G[{0, 1, 1}, yw] - 
     G[{0, 1}, yw]*G[{0, 1, 1}, yw] - 4*G[{0, yu}, yv^(-1)]*
      G[{0, 1, 1}, yw] - 2*G[{1, yu^(-1)}, yw]*G[{0, 1, 1}, yw] - 
     2*G[{1, yv^(-1)}, yw]*G[{0, 1, 1}, yw] + 2*G[{yu^(-1), 1/(yu*yv)}, yw]*
      G[{0, 1, 1}, yw] + 2*G[{yv^(-1), 1/(yu*yv)}, yw]*G[{0, 1, 1}, yw] - 
     (7*Pi^2*G[{0, 1, yu^(-1)}, yw])/6 - 2*G[{0}, yu^(-1)]^2*
      G[{0, 1, yu^(-1)}, yw] - 4*G[{0}, yu^(-1)]*G[{0}, yv^(-1)]*
      G[{0, 1, yu^(-1)}, yw] - 2*G[{0}, yv^(-1)]^2*G[{0, 1, yu^(-1)}, yw] + 
     4*G[{0}, yu^(-1)]*G[{0}, yw]*G[{0, 1, yu^(-1)}, yw] + 
     4*G[{0}, yv^(-1)]*G[{0}, yw]*G[{0, 1, yu^(-1)}, yw] - 
     2*G[{0}, yw]^2*G[{0, 1, yu^(-1)}, yw] + 4*G[{0}, yu^(-1)]*
      G[{1}, yu^(-1)]*G[{0, 1, yu^(-1)}, yw] + 4*G[{0}, yv^(-1)]*
      G[{1}, yu^(-1)]*G[{0, 1, yu^(-1)}, yw] - 4*G[{0}, yw]*G[{1}, yu^(-1)]*
      G[{0, 1, yu^(-1)}, yw] - 2*G[{1}, yu^(-1)]^2*G[{0, 1, yu^(-1)}, yw] + 
     6*G[{0}, yu^(-1)]*G[{1}, yv^(-1)]*G[{0, 1, yu^(-1)}, yw] + 
     6*G[{0}, yv^(-1)]*G[{1}, yv^(-1)]*G[{0, 1, yu^(-1)}, yw] - 
     6*G[{0}, yw]*G[{1}, yv^(-1)]*G[{0, 1, yu^(-1)}, yw] - 
     7*G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*G[{0, 1, yu^(-1)}, yw] - 
     4*G[{1}, yv^(-1)]^2*G[{0, 1, yu^(-1)}, yw] - 
     2*G[{0}, yu^(-1)]*G[{1}, yw]*G[{0, 1, yu^(-1)}, yw] - 
     2*G[{0}, yv^(-1)]*G[{1}, yw]*G[{0, 1, yu^(-1)}, yw] + 
     2*G[{0}, yw]*G[{1}, yw]*G[{0, 1, yu^(-1)}, yw] + 
     2*G[{1}, yu^(-1)]*G[{1}, yw]*G[{0, 1, yu^(-1)}, yw] + 
     6*G[{1}, yv^(-1)]*G[{1}, yw]*G[{0, 1, yu^(-1)}, yw] + 
     G[{1}, yw]^2*G[{0, 1, yu^(-1)}, yw] - 2*G[{0}, yu^(-1)]*G[{yu^(-1)}, yw]*
      G[{0, 1, yu^(-1)}, yw] - 2*G[{0}, yv^(-1)]*G[{yu^(-1)}, yw]*
      G[{0, 1, yu^(-1)}, yw] + 2*G[{0}, yw]*G[{yu^(-1)}, yw]*
      G[{0, 1, yu^(-1)}, yw] + 2*G[{1}, yu^(-1)]*G[{yu^(-1)}, yw]*
      G[{0, 1, yu^(-1)}, yw] - 3*G[{1}, yv^(-1)]*G[{yu^(-1)}, yw]*
      G[{0, 1, yu^(-1)}, yw] - 7*G[{1}, yw]*G[{yu^(-1)}, yw]*
      G[{0, 1, yu^(-1)}, yw] + (7*G[{yu^(-1)}, yw]^2*G[{0, 1, yu^(-1)}, yw])/
      2 - 2*G[{0}, yu^(-1)]*G[{yu}, yv^(-1)]*G[{0, 1, yu^(-1)}, yw] - 
     2*G[{0}, yv^(-1)]*G[{yu}, yv^(-1)]*G[{0, 1, yu^(-1)}, yw] + 
     2*G[{0}, yw]*G[{yu}, yv^(-1)]*G[{0, 1, yu^(-1)}, yw] + 
     3*G[{1}, yu^(-1)]*G[{yu}, yv^(-1)]*G[{0, 1, yu^(-1)}, yw] + 
     3*G[{1}, yv^(-1)]*G[{yu}, yv^(-1)]*G[{0, 1, yu^(-1)}, yw] - 
     4*G[{1}, yw]*G[{yu}, yv^(-1)]*G[{0, 1, yu^(-1)}, yw] + 
     5*G[{yu^(-1)}, yw]*G[{yu}, yv^(-1)]*G[{0, 1, yu^(-1)}, yw] - 
     G[{yu}, yv^(-1)]^2*G[{0, 1, yu^(-1)}, yw] - 3*G[{1}, yu^(-1)]*
      G[{yv^(-1)}, yw]*G[{0, 1, yu^(-1)}, yw] - 2*G[{1}, yv^(-1)]*
      G[{yv^(-1)}, yw]*G[{0, 1, yu^(-1)}, yw] - 7*G[{1}, yw]*G[{yv^(-1)}, yw]*
      G[{0, 1, yu^(-1)}, yw] + 2*G[{yu^(-1)}, yw]*G[{yv^(-1)}, yw]*
      G[{0, 1, yu^(-1)}, yw] + 5*G[{yu}, yv^(-1)]*G[{yv^(-1)}, yw]*
      G[{0, 1, yu^(-1)}, yw] + (7*G[{yv^(-1)}, yw]^2*G[{0, 1, yu^(-1)}, yw])/
      2 + 4*G[{0}, yu^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, 1, yu^(-1)}, yw] + 
     4*G[{0}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, 1, yu^(-1)}, yw] - 
     4*G[{0}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1, yu^(-1)}, yw] - 
     G[{1}, yu^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, 1, yu^(-1)}, yw] - 
     G[{1}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, 1, yu^(-1)}, yw] + 
     12*G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1, yu^(-1)}, yw] - 
     7*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1, yu^(-1)}, yw] - 
     6*G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, 1, yu^(-1)}, yw] - 
     7*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1, yu^(-1)}, yw] + 
     3*G[{1/(yu*yv)}, yw]^2*G[{0, 1, yu^(-1)}, yw] - 
     G[{0, 1}, yu^(-1)]*G[{0, 1, yu^(-1)}, yw] - G[{0, 1}, yv^(-1)]*
      G[{0, 1, yu^(-1)}, yw] - G[{0, 1}, yw]*G[{0, 1, yu^(-1)}, yw] - 
     2*G[{0, yu^(-1)}, yw]*G[{0, 1, yu^(-1)}, yw] + 
     G[{0, yu}, yv^(-1)]*G[{0, 1, yu^(-1)}, yw] - 2*G[{0, yv^(-1)}, yw]*
      G[{0, 1, yu^(-1)}, yw] + 2*G[{0, 1/(yu*yv)}, yw]*
      G[{0, 1, yu^(-1)}, yw] + 5*G[{1, yu^(-1)}, yw]*G[{0, 1, yu^(-1)}, yw] + 
     5*G[{1, yv^(-1)}, yw]*G[{0, 1, yu^(-1)}, yw] - 
     6*G[{1, 1/(yu*yv)}, yw]*G[{0, 1, yu^(-1)}, yw] + 
     G[{yu^(-1), 1/(yu*yv)}, yw]*G[{0, 1, yu^(-1)}, yw] + 
     G[{yv^(-1), 1/(yu*yv)}, yw]*G[{0, 1, yu^(-1)}, yw] + 
     (5*Pi^2*G[{0, 1, yu}, yv^(-1)])/6 - G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*
      G[{0, 1, yu}, yv^(-1)] + 3*G[{0}, yu^(-1)]*G[{1}, yw]*
      G[{0, 1, yu}, yv^(-1)] + 3*G[{0}, yv^(-1)]*G[{1}, yw]*
      G[{0, 1, yu}, yv^(-1)] - 3*G[{0}, yw]*G[{1}, yw]*
      G[{0, 1, yu}, yv^(-1)] - G[{1}, yu^(-1)]*G[{1}, yw]*
      G[{0, 1, yu}, yv^(-1)] - G[{1}, yv^(-1)]*G[{1}, yw]*
      G[{0, 1, yu}, yv^(-1)] - 3*G[{0}, yu^(-1)]*G[{yu^(-1)}, yw]*
      G[{0, 1, yu}, yv^(-1)] - 3*G[{0}, yv^(-1)]*G[{yu^(-1)}, yw]*
      G[{0, 1, yu}, yv^(-1)] + 3*G[{0}, yw]*G[{yu^(-1)}, yw]*
      G[{0, 1, yu}, yv^(-1)] + 5*G[{1}, yu^(-1)]*G[{yu^(-1)}, yw]*
      G[{0, 1, yu}, yv^(-1)] + G[{1}, yv^(-1)]*G[{yu^(-1)}, yw]*
      G[{0, 1, yu}, yv^(-1)] - (7*G[{yu^(-1)}, yw]^2*G[{0, 1, yu}, yv^(-1)])/
      2 + 5*G[{1}, yu^(-1)]*G[{yu}, yv^(-1)]*G[{0, 1, yu}, yv^(-1)] - 
     2*G[{yu^(-1)}, yw]*G[{yu}, yv^(-1)]*G[{0, 1, yu}, yv^(-1)] - 
     (7*G[{yu}, yv^(-1)]^2*G[{0, 1, yu}, yv^(-1)])/2 - 
     3*G[{0}, yu^(-1)]*G[{yv^(-1)}, yw]*G[{0, 1, yu}, yv^(-1)] - 
     3*G[{0}, yv^(-1)]*G[{yv^(-1)}, yw]*G[{0, 1, yu}, yv^(-1)] + 
     3*G[{0}, yw]*G[{yv^(-1)}, yw]*G[{0, 1, yu}, yv^(-1)] + 
     2*G[{1}, yu^(-1)]*G[{yv^(-1)}, yw]*G[{0, 1, yu}, yv^(-1)] + 
     G[{1}, yv^(-1)]*G[{yv^(-1)}, yw]*G[{0, 1, yu}, yv^(-1)] + 
     G[{1}, yw]*G[{yv^(-1)}, yw]*G[{0, 1, yu}, yv^(-1)] - 
     5*G[{yu^(-1)}, yw]*G[{yv^(-1)}, yw]*G[{0, 1, yu}, yv^(-1)] - 
     5*G[{yu}, yv^(-1)]*G[{yv^(-1)}, yw]*G[{0, 1, yu}, yv^(-1)] - 
     G[{yv^(-1)}, yw]^2*G[{0, 1, yu}, yv^(-1)] + 3*G[{0}, yu^(-1)]*
      G[{1/(yu*yv)}, yw]*G[{0, 1, yu}, yv^(-1)] + 
     3*G[{0}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, 1, yu}, yv^(-1)] - 
     3*G[{0}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1, yu}, yv^(-1)] - 
     6*G[{1}, yu^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, 1, yu}, yv^(-1)] - 
     G[{1}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, 1, yu}, yv^(-1)] - 
     G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1, yu}, yv^(-1)] + 
     7*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1, yu}, yv^(-1)] + 
     7*G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, 1, yu}, yv^(-1)] + 
     6*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1, yu}, yv^(-1)] - 
     3*G[{1/(yu*yv)}, yw]^2*G[{0, 1, yu}, yv^(-1)] + 
     G[{0, 1}, yu^(-1)]*G[{0, 1, yu}, yv^(-1)] - G[{0, 1}, yv^(-1)]*
      G[{0, 1, yu}, yv^(-1)] + 3*G[{0, 1}, yw]*G[{0, 1, yu}, yv^(-1)] - 
     3*G[{0, yu^(-1)}, yw]*G[{0, 1, yu}, yv^(-1)] - 
     2*G[{0, yu}, yv^(-1)]*G[{0, 1, yu}, yv^(-1)] - 
     3*G[{0, yv^(-1)}, yw]*G[{0, 1, yu}, yv^(-1)] + 
     3*G[{0, 1/(yu*yv)}, yw]*G[{0, 1, yu}, yv^(-1)] + 
     5*G[{1, yu^(-1)}, yw]*G[{0, 1, yu}, yv^(-1)] + 
     5*G[{1, yu}, yv^(-1)]*G[{0, 1, yu}, yv^(-1)] + 
     G[{1, 1/(yu*yv)}, yw]*G[{0, 1, yu}, yv^(-1)] - 
     G[{yu^(-1), 1/(yu*yv)}, yw]*G[{0, 1, yu}, yv^(-1)] - 
     6*G[{yv^(-1), 1/(yu*yv)}, yw]*G[{0, 1, yu}, yv^(-1)] - 
     (7*Pi^2*G[{0, 1, yv^(-1)}, yw])/6 - 2*G[{0}, yu^(-1)]^2*
      G[{0, 1, yv^(-1)}, yw] - 4*G[{0}, yu^(-1)]*G[{0}, yv^(-1)]*
      G[{0, 1, yv^(-1)}, yw] - 2*G[{0}, yv^(-1)]^2*G[{0, 1, yv^(-1)}, yw] + 
     4*G[{0}, yu^(-1)]*G[{0}, yw]*G[{0, 1, yv^(-1)}, yw] + 
     4*G[{0}, yv^(-1)]*G[{0}, yw]*G[{0, 1, yv^(-1)}, yw] - 
     2*G[{0}, yw]^2*G[{0, 1, yv^(-1)}, yw] + 6*G[{0}, yu^(-1)]*
      G[{1}, yu^(-1)]*G[{0, 1, yv^(-1)}, yw] + 6*G[{0}, yv^(-1)]*
      G[{1}, yu^(-1)]*G[{0, 1, yv^(-1)}, yw] - 6*G[{0}, yw]*G[{1}, yu^(-1)]*
      G[{0, 1, yv^(-1)}, yw] - 4*G[{1}, yu^(-1)]^2*G[{0, 1, yv^(-1)}, yw] + 
     4*G[{0}, yu^(-1)]*G[{1}, yv^(-1)]*G[{0, 1, yv^(-1)}, yw] + 
     4*G[{0}, yv^(-1)]*G[{1}, yv^(-1)]*G[{0, 1, yv^(-1)}, yw] - 
     4*G[{0}, yw]*G[{1}, yv^(-1)]*G[{0, 1, yv^(-1)}, yw] - 
     7*G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*G[{0, 1, yv^(-1)}, yw] - 
     2*G[{1}, yv^(-1)]^2*G[{0, 1, yv^(-1)}, yw] - 
     2*G[{0}, yu^(-1)]*G[{1}, yw]*G[{0, 1, yv^(-1)}, yw] - 
     2*G[{0}, yv^(-1)]*G[{1}, yw]*G[{0, 1, yv^(-1)}, yw] + 
     2*G[{0}, yw]*G[{1}, yw]*G[{0, 1, yv^(-1)}, yw] + 
     6*G[{1}, yu^(-1)]*G[{1}, yw]*G[{0, 1, yv^(-1)}, yw] + 
     2*G[{1}, yv^(-1)]*G[{1}, yw]*G[{0, 1, yv^(-1)}, yw] + 
     G[{1}, yw]^2*G[{0, 1, yv^(-1)}, yw] - 2*G[{1}, yu^(-1)]*G[{yu^(-1)}, yw]*
      G[{0, 1, yv^(-1)}, yw] - 3*G[{1}, yv^(-1)]*G[{yu^(-1)}, yw]*
      G[{0, 1, yv^(-1)}, yw] - 7*G[{1}, yw]*G[{yu^(-1)}, yw]*
      G[{0, 1, yv^(-1)}, yw] + (7*G[{yu^(-1)}, yw]^2*G[{0, 1, yv^(-1)}, yw])/
      2 - 2*G[{0}, yu^(-1)]*G[{yu}, yv^(-1)]*G[{0, 1, yv^(-1)}, yw] - 
     2*G[{0}, yv^(-1)]*G[{yu}, yv^(-1)]*G[{0, 1, yv^(-1)}, yw] + 
     2*G[{0}, yw]*G[{yu}, yv^(-1)]*G[{0, 1, yv^(-1)}, yw] + 
     3*G[{1}, yu^(-1)]*G[{yu}, yv^(-1)]*G[{0, 1, yv^(-1)}, yw] + 
     3*G[{1}, yv^(-1)]*G[{yu}, yv^(-1)]*G[{0, 1, yv^(-1)}, yw] - 
     4*G[{1}, yw]*G[{yu}, yv^(-1)]*G[{0, 1, yv^(-1)}, yw] + 
     5*G[{yu^(-1)}, yw]*G[{yu}, yv^(-1)]*G[{0, 1, yv^(-1)}, yw] - 
     G[{yu}, yv^(-1)]^2*G[{0, 1, yv^(-1)}, yw] - 2*G[{0}, yu^(-1)]*
      G[{yv^(-1)}, yw]*G[{0, 1, yv^(-1)}, yw] - 2*G[{0}, yv^(-1)]*
      G[{yv^(-1)}, yw]*G[{0, 1, yv^(-1)}, yw] + 2*G[{0}, yw]*G[{yv^(-1)}, yw]*
      G[{0, 1, yv^(-1)}, yw] - 3*G[{1}, yu^(-1)]*G[{yv^(-1)}, yw]*
      G[{0, 1, yv^(-1)}, yw] + 2*G[{1}, yv^(-1)]*G[{yv^(-1)}, yw]*
      G[{0, 1, yv^(-1)}, yw] - 7*G[{1}, yw]*G[{yv^(-1)}, yw]*
      G[{0, 1, yv^(-1)}, yw] + 2*G[{yu^(-1)}, yw]*G[{yv^(-1)}, yw]*
      G[{0, 1, yv^(-1)}, yw] + 5*G[{yu}, yv^(-1)]*G[{yv^(-1)}, yw]*
      G[{0, 1, yv^(-1)}, yw] + (7*G[{yv^(-1)}, yw]^2*G[{0, 1, yv^(-1)}, yw])/
      2 + 4*G[{0}, yu^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, 1, yv^(-1)}, yw] + 
     4*G[{0}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, 1, yv^(-1)}, yw] - 
     4*G[{0}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1, yv^(-1)}, yw] - 
     G[{1}, yu^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, 1, yv^(-1)}, yw] - 
     G[{1}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, 1, yv^(-1)}, yw] + 
     12*G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1, yv^(-1)}, yw] - 
     7*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1, yv^(-1)}, yw] - 
     6*G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, 1, yv^(-1)}, yw] - 
     7*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1, yv^(-1)}, yw] + 
     3*G[{1/(yu*yv)}, yw]^2*G[{0, 1, yv^(-1)}, yw] - 
     G[{0, 1}, yu^(-1)]*G[{0, 1, yv^(-1)}, yw] - G[{0, 1}, yv^(-1)]*
      G[{0, 1, yv^(-1)}, yw] - G[{0, 1}, yw]*G[{0, 1, yv^(-1)}, yw] + 
     G[{0, yu^(-1)}, yw]*G[{0, 1, yv^(-1)}, yw] + G[{0, yu}, yv^(-1)]*
      G[{0, 1, yv^(-1)}, yw] - 2*G[{0, yv^(-1)}, yw]*G[{0, 1, yv^(-1)}, yw] + 
     2*G[{0, 1/(yu*yv)}, yw]*G[{0, 1, yv^(-1)}, yw] + 
     5*G[{1, yu^(-1)}, yw]*G[{0, 1, yv^(-1)}, yw] + 
     5*G[{1, yv^(-1)}, yw]*G[{0, 1, yv^(-1)}, yw] - 
     6*G[{1, 1/(yu*yv)}, yw]*G[{0, 1, yv^(-1)}, yw] + 
     G[{yu^(-1), 1/(yu*yv)}, yw]*G[{0, 1, yv^(-1)}, yw] + 
     G[{yv^(-1), 1/(yu*yv)}, yw]*G[{0, 1, yv^(-1)}, yw] + 
     (Pi^2*G[{0, 1, 1/(yu*yv)}, yw])/2 + 2*G[{0}, yu^(-1)]^2*
      G[{0, 1, 1/(yu*yv)}, yw] + 4*G[{0}, yu^(-1)]*G[{0}, yv^(-1)]*
      G[{0, 1, 1/(yu*yv)}, yw] + 2*G[{0}, yv^(-1)]^2*
      G[{0, 1, 1/(yu*yv)}, yw] - 4*G[{0}, yu^(-1)]*G[{0}, yw]*
      G[{0, 1, 1/(yu*yv)}, yw] - 4*G[{0}, yv^(-1)]*G[{0}, yw]*
      G[{0, 1, 1/(yu*yv)}, yw] + 2*G[{0}, yw]^2*G[{0, 1, 1/(yu*yv)}, yw] - 
     6*G[{0}, yu^(-1)]*G[{1}, yu^(-1)]*G[{0, 1, 1/(yu*yv)}, yw] - 
     6*G[{0}, yv^(-1)]*G[{1}, yu^(-1)]*G[{0, 1, 1/(yu*yv)}, yw] + 
     6*G[{0}, yw]*G[{1}, yu^(-1)]*G[{0, 1, 1/(yu*yv)}, yw] + 
     4*G[{1}, yu^(-1)]^2*G[{0, 1, 1/(yu*yv)}, yw] - 
     6*G[{0}, yu^(-1)]*G[{1}, yv^(-1)]*G[{0, 1, 1/(yu*yv)}, yw] - 
     6*G[{0}, yv^(-1)]*G[{1}, yv^(-1)]*G[{0, 1, 1/(yu*yv)}, yw] + 
     6*G[{0}, yw]*G[{1}, yv^(-1)]*G[{0, 1, 1/(yu*yv)}, yw] + 
     8*G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*G[{0, 1, 1/(yu*yv)}, yw] + 
     4*G[{1}, yv^(-1)]^2*G[{0, 1, 1/(yu*yv)}, yw] - 
     2*G[{0}, yu^(-1)]*G[{1}, yw]*G[{0, 1, 1/(yu*yv)}, yw] - 
     2*G[{0}, yv^(-1)]*G[{1}, yw]*G[{0, 1, 1/(yu*yv)}, yw] + 
     2*G[{0}, yw]*G[{1}, yw]*G[{0, 1, 1/(yu*yv)}, yw] - 
     G[{1}, yw]^2*G[{0, 1, 1/(yu*yv)}, yw] + 4*G[{0}, yu^(-1)]*
      G[{yu^(-1)}, yw]*G[{0, 1, 1/(yu*yv)}, yw] + 
     4*G[{0}, yv^(-1)]*G[{yu^(-1)}, yw]*G[{0, 1, 1/(yu*yv)}, yw] - 
     4*G[{0}, yw]*G[{yu^(-1)}, yw]*G[{0, 1, 1/(yu*yv)}, yw] - 
     4*G[{1}, yu^(-1)]*G[{yu^(-1)}, yw]*G[{0, 1, 1/(yu*yv)}, yw] - 
     2*G[{1}, yv^(-1)]*G[{yu^(-1)}, yw]*G[{0, 1, 1/(yu*yv)}, yw] + 
     2*G[{1}, yw]*G[{yu^(-1)}, yw]*G[{0, 1, 1/(yu*yv)}, yw] + 
     4*G[{0}, yu^(-1)]*G[{yu}, yv^(-1)]*G[{0, 1, 1/(yu*yv)}, yw] + 
     4*G[{0}, yv^(-1)]*G[{yu}, yv^(-1)]*G[{0, 1, 1/(yu*yv)}, yw] - 
     4*G[{0}, yw]*G[{yu}, yv^(-1)]*G[{0, 1, 1/(yu*yv)}, yw] - 
     4*G[{1}, yu^(-1)]*G[{yu}, yv^(-1)]*G[{0, 1, 1/(yu*yv)}, yw] - 
     4*G[{1}, yv^(-1)]*G[{yu}, yv^(-1)]*G[{0, 1, 1/(yu*yv)}, yw] + 
     4*G[{1}, yw]*G[{yu}, yv^(-1)]*G[{0, 1, 1/(yu*yv)}, yw] - 
     2*G[{yu^(-1)}, yw]*G[{yu}, yv^(-1)]*G[{0, 1, 1/(yu*yv)}, yw] + 
     4*G[{0}, yu^(-1)]*G[{yv^(-1)}, yw]*G[{0, 1, 1/(yu*yv)}, yw] + 
     4*G[{0}, yv^(-1)]*G[{yv^(-1)}, yw]*G[{0, 1, 1/(yu*yv)}, yw] - 
     4*G[{0}, yw]*G[{yv^(-1)}, yw]*G[{0, 1, 1/(yu*yv)}, yw] - 
     2*G[{1}, yu^(-1)]*G[{yv^(-1)}, yw]*G[{0, 1, 1/(yu*yv)}, yw] - 
     4*G[{1}, yv^(-1)]*G[{yv^(-1)}, yw]*G[{0, 1, 1/(yu*yv)}, yw] + 
     2*G[{1}, yw]*G[{yv^(-1)}, yw]*G[{0, 1, 1/(yu*yv)}, yw] - 
     2*G[{yu}, yv^(-1)]*G[{yv^(-1)}, yw]*G[{0, 1, 1/(yu*yv)}, yw] - 
     6*G[{0}, yu^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, 1, 1/(yu*yv)}, yw] - 
     6*G[{0}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, 1, 1/(yu*yv)}, yw] + 
     6*G[{0}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1, 1/(yu*yv)}, yw] + 
     6*G[{1}, yu^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, 1, 1/(yu*yv)}, yw] + 
     6*G[{1}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, 1, 1/(yu*yv)}, yw] - 
     2*G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1, 1/(yu*yv)}, yw] - 
     G[{1/(yu*yv)}, yw]^2*G[{0, 1, 1/(yu*yv)}, yw] - 
     2*G[{0, 1}, yu^(-1)]*G[{0, 1, 1/(yu*yv)}, yw] - 
     2*G[{0, 1}, yv^(-1)]*G[{0, 1, 1/(yu*yv)}, yw] + 
     5*G[{0, 1}, yw]*G[{0, 1, 1/(yu*yv)}, yw] - G[{0, yu^(-1)}, yw]*
      G[{0, 1, 1/(yu*yv)}, yw] + 2*G[{0, yu}, yv^(-1)]*
      G[{0, 1, 1/(yu*yv)}, yw] - G[{0, yv^(-1)}, yw]*
      G[{0, 1, 1/(yu*yv)}, yw] - 2*G[{0, 1/(yu*yv)}, yw]*
      G[{0, 1, 1/(yu*yv)}, yw] - 2*G[{1, yu^(-1)}, yw]*
      G[{0, 1, 1/(yu*yv)}, yw] - 2*G[{1, yv^(-1)}, yw]*
      G[{0, 1, 1/(yu*yv)}, yw] + 2*G[{yu^(-1), 1/(yu*yv)}, yw]*
      G[{0, 1, 1/(yu*yv)}, yw] + 2*G[{yv^(-1), 1/(yu*yv)}, yw]*
      G[{0, 1, 1/(yu*yv)}, yw] - (7*Pi^2*G[{0, yu^(-1), 1}, yw])/6 - 
     2*G[{0}, yu^(-1)]^2*G[{0, yu^(-1), 1}, yw] - 
     4*G[{0}, yu^(-1)]*G[{0}, yv^(-1)]*G[{0, yu^(-1), 1}, yw] - 
     2*G[{0}, yv^(-1)]^2*G[{0, yu^(-1), 1}, yw] + 
     4*G[{0}, yu^(-1)]*G[{0}, yw]*G[{0, yu^(-1), 1}, yw] + 
     4*G[{0}, yv^(-1)]*G[{0}, yw]*G[{0, yu^(-1), 1}, yw] - 
     2*G[{0}, yw]^2*G[{0, yu^(-1), 1}, yw] + 4*G[{0}, yu^(-1)]*
      G[{1}, yu^(-1)]*G[{0, yu^(-1), 1}, yw] + 4*G[{0}, yv^(-1)]*
      G[{1}, yu^(-1)]*G[{0, yu^(-1), 1}, yw] - 4*G[{0}, yw]*G[{1}, yu^(-1)]*
      G[{0, yu^(-1), 1}, yw] - 2*G[{1}, yu^(-1)]^2*G[{0, yu^(-1), 1}, yw] + 
     6*G[{0}, yu^(-1)]*G[{1}, yv^(-1)]*G[{0, yu^(-1), 1}, yw] + 
     6*G[{0}, yv^(-1)]*G[{1}, yv^(-1)]*G[{0, yu^(-1), 1}, yw] - 
     6*G[{0}, yw]*G[{1}, yv^(-1)]*G[{0, yu^(-1), 1}, yw] - 
     8*G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*G[{0, yu^(-1), 1}, yw] - 
     4*G[{1}, yv^(-1)]^2*G[{0, yu^(-1), 1}, yw] + 
     G[{1}, yw]^2*G[{0, yu^(-1), 1}, yw] - 4*G[{0}, yu^(-1)]*G[{yu^(-1)}, yw]*
      G[{0, yu^(-1), 1}, yw] - 4*G[{0}, yv^(-1)]*G[{yu^(-1)}, yw]*
      G[{0, yu^(-1), 1}, yw] + 4*G[{0}, yw]*G[{yu^(-1)}, yw]*
      G[{0, yu^(-1), 1}, yw] + 4*G[{1}, yu^(-1)]*G[{yu^(-1)}, yw]*
      G[{0, yu^(-1), 1}, yw] + 2*G[{1}, yv^(-1)]*G[{yu^(-1)}, yw]*
      G[{0, yu^(-1), 1}, yw] - 2*G[{1}, yw]*G[{yu^(-1)}, yw]*
      G[{0, yu^(-1), 1}, yw] - 2*G[{0}, yu^(-1)]*G[{yu}, yv^(-1)]*
      G[{0, yu^(-1), 1}, yw] - 2*G[{0}, yv^(-1)]*G[{yu}, yv^(-1)]*
      G[{0, yu^(-1), 1}, yw] + 2*G[{0}, yw]*G[{yu}, yv^(-1)]*
      G[{0, yu^(-1), 1}, yw] + 4*G[{1}, yu^(-1)]*G[{yu}, yv^(-1)]*
      G[{0, yu^(-1), 1}, yw] + 4*G[{1}, yv^(-1)]*G[{yu}, yv^(-1)]*
      G[{0, yu^(-1), 1}, yw] + 2*G[{yu^(-1)}, yw]*G[{yu}, yv^(-1)]*
      G[{0, yu^(-1), 1}, yw] - 2*G[{yu}, yv^(-1)]^2*G[{0, yu^(-1), 1}, yw] - 
     2*G[{0}, yu^(-1)]*G[{yv^(-1)}, yw]*G[{0, yu^(-1), 1}, yw] - 
     2*G[{0}, yv^(-1)]*G[{yv^(-1)}, yw]*G[{0, yu^(-1), 1}, yw] + 
     2*G[{0}, yw]*G[{yv^(-1)}, yw]*G[{0, yu^(-1), 1}, yw] + 
     2*G[{1}, yu^(-1)]*G[{yv^(-1)}, yw]*G[{0, yu^(-1), 1}, yw] + 
     4*G[{1}, yv^(-1)]*G[{yv^(-1)}, yw]*G[{0, yu^(-1), 1}, yw] - 
     2*G[{1}, yw]*G[{yv^(-1)}, yw]*G[{0, yu^(-1), 1}, yw] - 
     2*G[{yu}, yv^(-1)]*G[{yv^(-1)}, yw]*G[{0, yu^(-1), 1}, yw] + 
     6*G[{0}, yu^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1), 1}, yw] + 
     6*G[{0}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1), 1}, yw] - 
     6*G[{0}, yw]*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1), 1}, yw] - 
     6*G[{1}, yu^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1), 1}, yw] - 
     6*G[{1}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1), 1}, yw] + 
     2*G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1), 1}, yw] + 
     G[{1/(yu*yv)}, yw]^2*G[{0, yu^(-1), 1}, yw] - 2*G[{0, 1}, yu^(-1)]*
      G[{0, yu^(-1), 1}, yw] - 2*G[{0, 1}, yv^(-1)]*G[{0, yu^(-1), 1}, yw] - 
     G[{0, 1}, yw]*G[{0, yu^(-1), 1}, yw] + G[{0, yu^(-1)}, yw]*
      G[{0, yu^(-1), 1}, yw] + 2*G[{0, yu}, yv^(-1)]*G[{0, yu^(-1), 1}, yw] - 
     2*G[{0, yv^(-1)}, yw]*G[{0, yu^(-1), 1}, yw] + 
     2*G[{0, 1/(yu*yv)}, yw]*G[{0, yu^(-1), 1}, yw] + 
     2*G[{1, yu^(-1)}, yw]*G[{0, yu^(-1), 1}, yw] + 
     2*G[{1, yv^(-1)}, yw]*G[{0, yu^(-1), 1}, yw] - 
     2*G[{yu^(-1), 1/(yu*yv)}, yw]*G[{0, yu^(-1), 1}, yw] - 
     2*G[{yv^(-1), 1/(yu*yv)}, yw]*G[{0, yu^(-1), 1}, yw] + 
     (5*Pi^2*G[{0, yu^(-1), yu^(-1)}, yw])/6 + 2*G[{0}, yu^(-1)]^2*
      G[{0, yu^(-1), yu^(-1)}, yw] + 4*G[{0}, yu^(-1)]*G[{0}, yv^(-1)]*
      G[{0, yu^(-1), yu^(-1)}, yw] + 2*G[{0}, yv^(-1)]^2*
      G[{0, yu^(-1), yu^(-1)}, yw] - 4*G[{0}, yu^(-1)]*G[{0}, yw]*
      G[{0, yu^(-1), yu^(-1)}, yw] - 4*G[{0}, yv^(-1)]*G[{0}, yw]*
      G[{0, yu^(-1), yu^(-1)}, yw] + 2*G[{0}, yw]^2*G[{0, yu^(-1), yu^(-1)}, 
       yw] - 4*G[{0}, yu^(-1)]*G[{1}, yu^(-1)]*G[{0, yu^(-1), yu^(-1)}, yw] - 
     4*G[{0}, yv^(-1)]*G[{1}, yu^(-1)]*G[{0, yu^(-1), yu^(-1)}, yw] + 
     4*G[{0}, yw]*G[{1}, yu^(-1)]*G[{0, yu^(-1), yu^(-1)}, yw] + 
     2*G[{1}, yu^(-1)]^2*G[{0, yu^(-1), yu^(-1)}, yw] - 
     8*G[{0}, yu^(-1)]*G[{1}, yv^(-1)]*G[{0, yu^(-1), yu^(-1)}, yw] - 
     8*G[{0}, yv^(-1)]*G[{1}, yv^(-1)]*G[{0, yu^(-1), yu^(-1)}, yw] + 
     8*G[{0}, yw]*G[{1}, yv^(-1)]*G[{0, yu^(-1), yu^(-1)}, yw] + 
     7*G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*G[{0, yu^(-1), yu^(-1)}, yw] + 
     6*G[{1}, yv^(-1)]^2*G[{0, yu^(-1), yu^(-1)}, yw] + 
     2*G[{0}, yu^(-1)]*G[{1}, yw]*G[{0, yu^(-1), yu^(-1)}, yw] + 
     2*G[{0}, yv^(-1)]*G[{1}, yw]*G[{0, yu^(-1), yu^(-1)}, yw] - 
     2*G[{0}, yw]*G[{1}, yw]*G[{0, yu^(-1), yu^(-1)}, yw] - 
     2*G[{1}, yu^(-1)]*G[{1}, yw]*G[{0, yu^(-1), yu^(-1)}, yw] - 
     6*G[{1}, yv^(-1)]*G[{1}, yw]*G[{0, yu^(-1), yu^(-1)}, yw] - 
     G[{1}, yw]^2*G[{0, yu^(-1), yu^(-1)}, yw] + 2*G[{0}, yu^(-1)]*
      G[{yu^(-1)}, yw]*G[{0, yu^(-1), yu^(-1)}, yw] + 
     2*G[{0}, yv^(-1)]*G[{yu^(-1)}, yw]*G[{0, yu^(-1), yu^(-1)}, yw] - 
     2*G[{0}, yw]*G[{yu^(-1)}, yw]*G[{0, yu^(-1), yu^(-1)}, yw] - 
     2*G[{1}, yu^(-1)]*G[{yu^(-1)}, yw]*G[{0, yu^(-1), yu^(-1)}, yw] + 
     3*G[{1}, yv^(-1)]*G[{yu^(-1)}, yw]*G[{0, yu^(-1), yu^(-1)}, yw] + 
     7*G[{1}, yw]*G[{yu^(-1)}, yw]*G[{0, yu^(-1), yu^(-1)}, yw] - 
     (7*G[{yu^(-1)}, yw]^2*G[{0, yu^(-1), yu^(-1)}, yw])/2 + 
     4*G[{0}, yu^(-1)]*G[{yu}, yv^(-1)]*G[{0, yu^(-1), yu^(-1)}, yw] + 
     4*G[{0}, yv^(-1)]*G[{yu}, yv^(-1)]*G[{0, yu^(-1), yu^(-1)}, yw] - 
     4*G[{0}, yw]*G[{yu}, yv^(-1)]*G[{0, yu^(-1), yu^(-1)}, yw] - 
     3*G[{1}, yu^(-1)]*G[{yu}, yv^(-1)]*G[{0, yu^(-1), yu^(-1)}, yw] - 
     3*G[{1}, yv^(-1)]*G[{yu}, yv^(-1)]*G[{0, yu^(-1), yu^(-1)}, yw] + 
     4*G[{1}, yw]*G[{yu}, yv^(-1)]*G[{0, yu^(-1), yu^(-1)}, yw] - 
     5*G[{yu^(-1)}, yw]*G[{yu}, yv^(-1)]*G[{0, yu^(-1), yu^(-1)}, yw] - 
     G[{yu}, yv^(-1)]^2*G[{0, yu^(-1), yu^(-1)}, yw] - 
     2*G[{0}, yu^(-1)]*G[{yv^(-1)}, yw]*G[{0, yu^(-1), yu^(-1)}, yw] - 
     2*G[{0}, yv^(-1)]*G[{yv^(-1)}, yw]*G[{0, yu^(-1), yu^(-1)}, yw] + 
     2*G[{0}, yw]*G[{yv^(-1)}, yw]*G[{0, yu^(-1), yu^(-1)}, yw] + 
     3*G[{1}, yu^(-1)]*G[{yv^(-1)}, yw]*G[{0, yu^(-1), yu^(-1)}, yw] + 
     6*G[{1}, yv^(-1)]*G[{yv^(-1)}, yw]*G[{0, yu^(-1), yu^(-1)}, yw] + 
     7*G[{1}, yw]*G[{yv^(-1)}, yw]*G[{0, yu^(-1), yu^(-1)}, yw] - 
     2*G[{yu^(-1)}, yw]*G[{yv^(-1)}, yw]*G[{0, yu^(-1), yu^(-1)}, yw] - 
     5*G[{yu}, yv^(-1)]*G[{yv^(-1)}, yw]*G[{0, yu^(-1), yu^(-1)}, yw] - 
     (7*G[{yv^(-1)}, yw]^2*G[{0, yu^(-1), yu^(-1)}, yw])/2 - 
     2*G[{0}, yu^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1), yu^(-1)}, yw] - 
     2*G[{0}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1), yu^(-1)}, yw] + 
     2*G[{0}, yw]*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1), yu^(-1)}, yw] + 
     G[{1}, yu^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1), yu^(-1)}, yw] - 
     3*G[{1}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1), yu^(-1)}, yw] - 
     12*G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1), yu^(-1)}, yw] + 
     7*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1), yu^(-1)}, yw] + 
     6*G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1), yu^(-1)}, yw] + 
     7*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1), yu^(-1)}, yw] - 
     3*G[{1/(yu*yv)}, yw]^2*G[{0, yu^(-1), yu^(-1)}, yw] - 
     G[{0, 1}, yu^(-1)]*G[{0, yu^(-1), yu^(-1)}, yw] - 
     G[{0, 1}, yv^(-1)]*G[{0, yu^(-1), yu^(-1)}, yw] + 
     3*G[{0, 1}, yw]*G[{0, yu^(-1), yu^(-1)}, yw] - 
     3*G[{0, yu^(-1)}, yw]*G[{0, yu^(-1), yu^(-1)}, yw] + 
     G[{0, yu}, yv^(-1)]*G[{0, yu^(-1), yu^(-1)}, yw] + 
     4*G[{0, yv^(-1)}, yw]*G[{0, yu^(-1), yu^(-1)}, yw] - 
     4*G[{0, 1/(yu*yv)}, yw]*G[{0, yu^(-1), yu^(-1)}, yw] - 
     5*G[{1, yu^(-1)}, yw]*G[{0, yu^(-1), yu^(-1)}, yw] - 
     5*G[{1, yv^(-1)}, yw]*G[{0, yu^(-1), yu^(-1)}, yw] + 
     6*G[{1, 1/(yu*yv)}, yw]*G[{0, yu^(-1), yu^(-1)}, yw] - 
     G[{yu^(-1), 1/(yu*yv)}, yw]*G[{0, yu^(-1), yu^(-1)}, yw] - 
     G[{yv^(-1), 1/(yu*yv)}, yw]*G[{0, yu^(-1), yu^(-1)}, yw] + 
     (7*Pi^2*G[{0, yu^(-1), yv^(-1)}, yw])/6 + 2*G[{0}, yu^(-1)]^2*
      G[{0, yu^(-1), yv^(-1)}, yw] + 4*G[{0}, yu^(-1)]*G[{0}, yv^(-1)]*
      G[{0, yu^(-1), yv^(-1)}, yw] + 2*G[{0}, yv^(-1)]^2*
      G[{0, yu^(-1), yv^(-1)}, yw] - 4*G[{0}, yu^(-1)]*G[{0}, yw]*
      G[{0, yu^(-1), yv^(-1)}, yw] - 4*G[{0}, yv^(-1)]*G[{0}, yw]*
      G[{0, yu^(-1), yv^(-1)}, yw] + 2*G[{0}, yw]^2*G[{0, yu^(-1), yv^(-1)}, 
       yw] - 6*G[{0}, yu^(-1)]*G[{1}, yu^(-1)]*G[{0, yu^(-1), yv^(-1)}, yw] - 
     6*G[{0}, yv^(-1)]*G[{1}, yu^(-1)]*G[{0, yu^(-1), yv^(-1)}, yw] + 
     6*G[{0}, yw]*G[{1}, yu^(-1)]*G[{0, yu^(-1), yv^(-1)}, yw] + 
     4*G[{1}, yu^(-1)]^2*G[{0, yu^(-1), yv^(-1)}, yw] - 
     6*G[{0}, yu^(-1)]*G[{1}, yv^(-1)]*G[{0, yu^(-1), yv^(-1)}, yw] - 
     6*G[{0}, yv^(-1)]*G[{1}, yv^(-1)]*G[{0, yu^(-1), yv^(-1)}, yw] + 
     6*G[{0}, yw]*G[{1}, yv^(-1)]*G[{0, yu^(-1), yv^(-1)}, yw] + 
     7*G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*G[{0, yu^(-1), yv^(-1)}, yw] + 
     4*G[{1}, yv^(-1)]^2*G[{0, yu^(-1), yv^(-1)}, yw] - 
     2*G[{1}, yu^(-1)]*G[{1}, yw]*G[{0, yu^(-1), yv^(-1)}, yw] - 
     2*G[{1}, yv^(-1)]*G[{1}, yw]*G[{0, yu^(-1), yv^(-1)}, yw] - 
     G[{1}, yw]^2*G[{0, yu^(-1), yv^(-1)}, yw] + 2*G[{0}, yu^(-1)]*
      G[{yu^(-1)}, yw]*G[{0, yu^(-1), yv^(-1)}, yw] + 
     2*G[{0}, yv^(-1)]*G[{yu^(-1)}, yw]*G[{0, yu^(-1), yv^(-1)}, yw] - 
     2*G[{0}, yw]*G[{yu^(-1)}, yw]*G[{0, yu^(-1), yv^(-1)}, yw] - 
     2*G[{1}, yu^(-1)]*G[{yu^(-1)}, yw]*G[{0, yu^(-1), yv^(-1)}, yw] + 
     3*G[{1}, yv^(-1)]*G[{yu^(-1)}, yw]*G[{0, yu^(-1), yv^(-1)}, yw] + 
     7*G[{1}, yw]*G[{yu^(-1)}, yw]*G[{0, yu^(-1), yv^(-1)}, yw] - 
     (7*G[{yu^(-1)}, yw]^2*G[{0, yu^(-1), yv^(-1)}, yw])/2 + 
     4*G[{0}, yu^(-1)]*G[{yu}, yv^(-1)]*G[{0, yu^(-1), yv^(-1)}, yw] + 
     4*G[{0}, yv^(-1)]*G[{yu}, yv^(-1)]*G[{0, yu^(-1), yv^(-1)}, yw] - 
     4*G[{0}, yw]*G[{yu}, yv^(-1)]*G[{0, yu^(-1), yv^(-1)}, yw] - 
     3*G[{1}, yu^(-1)]*G[{yu}, yv^(-1)]*G[{0, yu^(-1), yv^(-1)}, yw] - 
     3*G[{1}, yv^(-1)]*G[{yu}, yv^(-1)]*G[{0, yu^(-1), yv^(-1)}, yw] + 
     4*G[{1}, yw]*G[{yu}, yv^(-1)]*G[{0, yu^(-1), yv^(-1)}, yw] - 
     5*G[{yu^(-1)}, yw]*G[{yu}, yv^(-1)]*G[{0, yu^(-1), yv^(-1)}, yw] - 
     G[{yu}, yv^(-1)]^2*G[{0, yu^(-1), yv^(-1)}, yw] + 
     2*G[{0}, yu^(-1)]*G[{yv^(-1)}, yw]*G[{0, yu^(-1), yv^(-1)}, yw] + 
     2*G[{0}, yv^(-1)]*G[{yv^(-1)}, yw]*G[{0, yu^(-1), yv^(-1)}, yw] - 
     2*G[{0}, yw]*G[{yv^(-1)}, yw]*G[{0, yu^(-1), yv^(-1)}, yw] + 
     3*G[{1}, yu^(-1)]*G[{yv^(-1)}, yw]*G[{0, yu^(-1), yv^(-1)}, yw] - 
     2*G[{1}, yv^(-1)]*G[{yv^(-1)}, yw]*G[{0, yu^(-1), yv^(-1)}, yw] + 
     7*G[{1}, yw]*G[{yv^(-1)}, yw]*G[{0, yu^(-1), yv^(-1)}, yw] - 
     2*G[{yu^(-1)}, yw]*G[{yv^(-1)}, yw]*G[{0, yu^(-1), yv^(-1)}, yw] - 
     5*G[{yu}, yv^(-1)]*G[{yv^(-1)}, yw]*G[{0, yu^(-1), yv^(-1)}, yw] - 
     (7*G[{yv^(-1)}, yw]^2*G[{0, yu^(-1), yv^(-1)}, yw])/2 - 
     4*G[{0}, yu^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1), yv^(-1)}, yw] - 
     4*G[{0}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1), yv^(-1)}, yw] + 
     4*G[{0}, yw]*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1), yv^(-1)}, yw] + 
     G[{1}, yu^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1), yv^(-1)}, yw] + 
     G[{1}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1), yv^(-1)}, yw] - 
     12*G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1), yv^(-1)}, yw] + 
     7*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1), yv^(-1)}, yw] + 
     6*G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1), yv^(-1)}, yw] + 
     7*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1), yv^(-1)}, yw] - 
     3*G[{1/(yu*yv)}, yw]^2*G[{0, yu^(-1), yv^(-1)}, yw] + 
     G[{0, 1}, yu^(-1)]*G[{0, yu^(-1), yv^(-1)}, yw] + 
     G[{0, 1}, yv^(-1)]*G[{0, yu^(-1), yv^(-1)}, yw] + 
     G[{0, 1}, yw]*G[{0, yu^(-1), yv^(-1)}, yw] - G[{0, yu^(-1)}, yw]*
      G[{0, yu^(-1), yv^(-1)}, yw] - G[{0, yu}, yv^(-1)]*
      G[{0, yu^(-1), yv^(-1)}, yw] + 2*G[{0, yv^(-1)}, yw]*
      G[{0, yu^(-1), yv^(-1)}, yw] - 2*G[{0, 1/(yu*yv)}, yw]*
      G[{0, yu^(-1), yv^(-1)}, yw] - 5*G[{1, yu^(-1)}, yw]*
      G[{0, yu^(-1), yv^(-1)}, yw] - 5*G[{1, yv^(-1)}, yw]*
      G[{0, yu^(-1), yv^(-1)}, yw] + 6*G[{1, 1/(yu*yv)}, yw]*
      G[{0, yu^(-1), yv^(-1)}, yw] - G[{yu^(-1), 1/(yu*yv)}, yw]*
      G[{0, yu^(-1), yv^(-1)}, yw] - G[{yv^(-1), 1/(yu*yv)}, yw]*
      G[{0, yu^(-1), yv^(-1)}, yw] - (Pi^2*G[{0, yu^(-1), 1/(yu*yv)}, yw])/
      2 - 2*G[{0}, yu^(-1)]^2*G[{0, yu^(-1), 1/(yu*yv)}, yw] - 
     4*G[{0}, yu^(-1)]*G[{0}, yv^(-1)]*G[{0, yu^(-1), 1/(yu*yv)}, yw] - 
     2*G[{0}, yv^(-1)]^2*G[{0, yu^(-1), 1/(yu*yv)}, yw] + 
     4*G[{0}, yu^(-1)]*G[{0}, yw]*G[{0, yu^(-1), 1/(yu*yv)}, yw] + 
     4*G[{0}, yv^(-1)]*G[{0}, yw]*G[{0, yu^(-1), 1/(yu*yv)}, yw] - 
     2*G[{0}, yw]^2*G[{0, yu^(-1), 1/(yu*yv)}, yw] + 
     6*G[{0}, yu^(-1)]*G[{1}, yu^(-1)]*G[{0, yu^(-1), 1/(yu*yv)}, yw] + 
     6*G[{0}, yv^(-1)]*G[{1}, yu^(-1)]*G[{0, yu^(-1), 1/(yu*yv)}, yw] - 
     6*G[{0}, yw]*G[{1}, yu^(-1)]*G[{0, yu^(-1), 1/(yu*yv)}, yw] - 
     4*G[{1}, yu^(-1)]^2*G[{0, yu^(-1), 1/(yu*yv)}, yw] + 
     8*G[{0}, yu^(-1)]*G[{1}, yv^(-1)]*G[{0, yu^(-1), 1/(yu*yv)}, yw] + 
     8*G[{0}, yv^(-1)]*G[{1}, yv^(-1)]*G[{0, yu^(-1), 1/(yu*yv)}, yw] - 
     8*G[{0}, yw]*G[{1}, yv^(-1)]*G[{0, yu^(-1), 1/(yu*yv)}, yw] - 
     8*G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*G[{0, yu^(-1), 1/(yu*yv)}, yw] - 
     6*G[{1}, yv^(-1)]^2*G[{0, yu^(-1), 1/(yu*yv)}, yw] + 
     4*G[{0}, yu^(-1)]*G[{1}, yw]*G[{0, yu^(-1), 1/(yu*yv)}, yw] + 
     4*G[{0}, yv^(-1)]*G[{1}, yw]*G[{0, yu^(-1), 1/(yu*yv)}, yw] - 
     4*G[{0}, yw]*G[{1}, yw]*G[{0, yu^(-1), 1/(yu*yv)}, yw] - 
     4*G[{1}, yu^(-1)]*G[{1}, yw]*G[{0, yu^(-1), 1/(yu*yv)}, yw] - 
     4*G[{1}, yv^(-1)]*G[{1}, yw]*G[{0, yu^(-1), 1/(yu*yv)}, yw] + 
     G[{1}, yw]^2*G[{0, yu^(-1), 1/(yu*yv)}, yw] - 
     6*G[{0}, yu^(-1)]*G[{yu^(-1)}, yw]*G[{0, yu^(-1), 1/(yu*yv)}, yw] - 
     6*G[{0}, yv^(-1)]*G[{yu^(-1)}, yw]*G[{0, yu^(-1), 1/(yu*yv)}, yw] + 
     6*G[{0}, yw]*G[{yu^(-1)}, yw]*G[{0, yu^(-1), 1/(yu*yv)}, yw] + 
     8*G[{1}, yu^(-1)]*G[{yu^(-1)}, yw]*G[{0, yu^(-1), 1/(yu*yv)}, yw] + 
     6*G[{1}, yv^(-1)]*G[{yu^(-1)}, yw]*G[{0, yu^(-1), 1/(yu*yv)}, yw] - 
     2*G[{1}, yw]*G[{yu^(-1)}, yw]*G[{0, yu^(-1), 1/(yu*yv)}, yw] - 
     6*G[{0}, yu^(-1)]*G[{yu}, yv^(-1)]*G[{0, yu^(-1), 1/(yu*yv)}, yw] - 
     6*G[{0}, yv^(-1)]*G[{yu}, yv^(-1)]*G[{0, yu^(-1), 1/(yu*yv)}, yw] + 
     6*G[{0}, yw]*G[{yu}, yv^(-1)]*G[{0, yu^(-1), 1/(yu*yv)}, yw] + 
     4*G[{1}, yu^(-1)]*G[{yu}, yv^(-1)]*G[{0, yu^(-1), 1/(yu*yv)}, yw] + 
     4*G[{1}, yv^(-1)]*G[{yu}, yv^(-1)]*G[{0, yu^(-1), 1/(yu*yv)}, yw] - 
     2*G[{yu^(-1)}, yw]*G[{yu}, yv^(-1)]*G[{0, yu^(-1), 1/(yu*yv)}, yw] + 
     2*G[{yu}, yv^(-1)]^2*G[{0, yu^(-1), 1/(yu*yv)}, yw] - 
     4*G[{0}, yu^(-1)]*G[{yv^(-1)}, yw]*G[{0, yu^(-1), 1/(yu*yv)}, yw] - 
     4*G[{0}, yv^(-1)]*G[{yv^(-1)}, yw]*G[{0, yu^(-1), 1/(yu*yv)}, yw] + 
     4*G[{0}, yw]*G[{yv^(-1)}, yw]*G[{0, yu^(-1), 1/(yu*yv)}, yw] + 
     2*G[{1}, yu^(-1)]*G[{yv^(-1)}, yw]*G[{0, yu^(-1), 1/(yu*yv)}, yw] + 
     4*G[{1}, yv^(-1)]*G[{yv^(-1)}, yw]*G[{0, yu^(-1), 1/(yu*yv)}, yw] - 
     2*G[{1}, yw]*G[{yv^(-1)}, yw]*G[{0, yu^(-1), 1/(yu*yv)}, yw] + 
     2*G[{yu}, yv^(-1)]*G[{yv^(-1)}, yw]*G[{0, yu^(-1), 1/(yu*yv)}, yw] + 
     6*G[{0}, yu^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1), 1/(yu*yv)}, yw] + 
     6*G[{0}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1), 1/(yu*yv)}, yw] - 
     6*G[{0}, yw]*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1), 1/(yu*yv)}, yw] - 
     6*G[{1}, yu^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1), 1/(yu*yv)}, yw] - 
     6*G[{1}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1), 1/(yu*yv)}, yw] + 
     2*G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1), 1/(yu*yv)}, yw] + 
     G[{1/(yu*yv)}, yw]^2*G[{0, yu^(-1), 1/(yu*yv)}, yw] + 
     2*G[{0, 1}, yu^(-1)]*G[{0, yu^(-1), 1/(yu*yv)}, yw] + 
     2*G[{0, 1}, yv^(-1)]*G[{0, yu^(-1), 1/(yu*yv)}, yw] - 
     5*G[{0, 1}, yw]*G[{0, yu^(-1), 1/(yu*yv)}, yw] + 
     5*G[{0, yu^(-1)}, yw]*G[{0, yu^(-1), 1/(yu*yv)}, yw] - 
     2*G[{0, yu}, yv^(-1)]*G[{0, yu^(-1), 1/(yu*yv)}, yw] + 
     G[{0, yv^(-1)}, yw]*G[{0, yu^(-1), 1/(yu*yv)}, yw] + 
     2*G[{0, 1/(yu*yv)}, yw]*G[{0, yu^(-1), 1/(yu*yv)}, yw] + 
     2*G[{1, yu^(-1)}, yw]*G[{0, yu^(-1), 1/(yu*yv)}, yw] + 
     2*G[{1, yv^(-1)}, yw]*G[{0, yu^(-1), 1/(yu*yv)}, yw] - 
     2*G[{yu^(-1), 1/(yu*yv)}, yw]*G[{0, yu^(-1), 1/(yu*yv)}, yw] - 
     2*G[{yv^(-1), 1/(yu*yv)}, yw]*G[{0, yu^(-1), 1/(yu*yv)}, yw] + 
     (Pi^2*G[{0, yu, 1}, yv^(-1)])/6 + G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*
      G[{0, yu, 1}, yv^(-1)] + 3*G[{0}, yu^(-1)]*G[{1}, yw]*
      G[{0, yu, 1}, yv^(-1)] + 3*G[{0}, yv^(-1)]*G[{1}, yw]*
      G[{0, yu, 1}, yv^(-1)] - 3*G[{0}, yw]*G[{1}, yw]*
      G[{0, yu, 1}, yv^(-1)] - 3*G[{1}, yu^(-1)]*G[{1}, yw]*
      G[{0, yu, 1}, yv^(-1)] - G[{1}, yv^(-1)]*G[{1}, yw]*
      G[{0, yu, 1}, yv^(-1)] - 3*G[{0}, yu^(-1)]*G[{yu^(-1)}, yw]*
      G[{0, yu, 1}, yv^(-1)] - 3*G[{0}, yv^(-1)]*G[{yu^(-1)}, yw]*
      G[{0, yu, 1}, yv^(-1)] + 3*G[{0}, yw]*G[{yu^(-1)}, yw]*
      G[{0, yu, 1}, yv^(-1)] + 7*G[{1}, yu^(-1)]*G[{yu^(-1)}, yw]*
      G[{0, yu, 1}, yv^(-1)] + 3*G[{1}, yv^(-1)]*G[{yu^(-1)}, yw]*
      G[{0, yu, 1}, yv^(-1)] + 2*G[{1}, yw]*G[{yu^(-1)}, yw]*
      G[{0, yu, 1}, yv^(-1)] - (7*G[{yu^(-1)}, yw]^2*G[{0, yu, 1}, yv^(-1)])/
      2 + 3*G[{1}, yu^(-1)]*G[{yu}, yv^(-1)]*G[{0, yu, 1}, yv^(-1)] + 
     2*G[{1}, yv^(-1)]*G[{yu}, yv^(-1)]*G[{0, yu, 1}, yv^(-1)] - 
     2*G[{yu^(-1)}, yw]*G[{yu}, yv^(-1)]*G[{0, yu, 1}, yv^(-1)] - 
     (7*G[{yu}, yv^(-1)]^2*G[{0, yu, 1}, yv^(-1)])/2 - 
     3*G[{0}, yu^(-1)]*G[{yv^(-1)}, yw]*G[{0, yu, 1}, yv^(-1)] - 
     3*G[{0}, yv^(-1)]*G[{yv^(-1)}, yw]*G[{0, yu, 1}, yv^(-1)] + 
     3*G[{0}, yw]*G[{yv^(-1)}, yw]*G[{0, yu, 1}, yv^(-1)] + 
     2*G[{1}, yu^(-1)]*G[{yv^(-1)}, yw]*G[{0, yu, 1}, yv^(-1)] + 
     G[{1}, yv^(-1)]*G[{yv^(-1)}, yw]*G[{0, yu, 1}, yv^(-1)] + 
     G[{1}, yw]*G[{yv^(-1)}, yw]*G[{0, yu, 1}, yv^(-1)] - 
     5*G[{yu^(-1)}, yw]*G[{yv^(-1)}, yw]*G[{0, yu, 1}, yv^(-1)] - 
     5*G[{yu}, yv^(-1)]*G[{yv^(-1)}, yw]*G[{0, yu, 1}, yv^(-1)] - 
     G[{yv^(-1)}, yw]^2*G[{0, yu, 1}, yv^(-1)] + 3*G[{0}, yu^(-1)]*
      G[{1/(yu*yv)}, yw]*G[{0, yu, 1}, yv^(-1)] + 
     3*G[{0}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, yu, 1}, yv^(-1)] - 
     3*G[{0}, yw]*G[{1/(yu*yv)}, yw]*G[{0, yu, 1}, yv^(-1)] - 
     6*G[{1}, yu^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, yu, 1}, yv^(-1)] - 
     3*G[{1}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, yu, 1}, yv^(-1)] - 
     3*G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{0, yu, 1}, yv^(-1)] + 
     7*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{0, yu, 1}, yv^(-1)] + 
     7*G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, yu, 1}, yv^(-1)] + 
     6*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{0, yu, 1}, yv^(-1)] - 
     2*G[{1/(yu*yv)}, yw]^2*G[{0, yu, 1}, yv^(-1)] - 
     G[{0, 1}, yu^(-1)]*G[{0, yu, 1}, yv^(-1)] + 
     3*G[{0, 1}, yw]*G[{0, yu, 1}, yv^(-1)] - 3*G[{0, yu^(-1)}, yw]*
      G[{0, yu, 1}, yv^(-1)] - 3*G[{0, yv^(-1)}, yw]*G[{0, yu, 1}, yv^(-1)] + 
     3*G[{0, 1/(yu*yv)}, yw]*G[{0, yu, 1}, yv^(-1)] + 
     3*G[{1, yu^(-1)}, yw]*G[{0, yu, 1}, yv^(-1)] + 
     3*G[{1, yu}, yv^(-1)]*G[{0, yu, 1}, yv^(-1)] + 
     3*G[{1, 1/(yu*yv)}, yw]*G[{0, yu, 1}, yv^(-1)] - 
     3*G[{yu^(-1), 1/(yu*yv)}, yw]*G[{0, yu, 1}, yv^(-1)] - 
     6*G[{yv^(-1), 1/(yu*yv)}, yw]*G[{0, yu, 1}, yv^(-1)] - 
     (Pi^2*G[{0, yu, yu}, yv^(-1)])/2 + G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*
      G[{0, yu, yu}, yv^(-1)] - G[{0}, yu^(-1)]*G[{1}, yw]*
      G[{0, yu, yu}, yv^(-1)] - G[{0}, yv^(-1)]*G[{1}, yw]*
      G[{0, yu, yu}, yv^(-1)] + G[{0}, yw]*G[{1}, yw]*
      G[{0, yu, yu}, yv^(-1)] + G[{1}, yu^(-1)]*G[{1}, yw]*
      G[{0, yu, yu}, yv^(-1)] + G[{1}, yv^(-1)]*G[{1}, yw]*
      G[{0, yu, yu}, yv^(-1)] + G[{0}, yu^(-1)]*G[{yu^(-1)}, yw]*
      G[{0, yu, yu}, yv^(-1)] + G[{0}, yv^(-1)]*G[{yu^(-1)}, yw]*
      G[{0, yu, yu}, yv^(-1)] - G[{0}, yw]*G[{yu^(-1)}, yw]*
      G[{0, yu, yu}, yv^(-1)] - 5*G[{1}, yu^(-1)]*G[{yu^(-1)}, yw]*
      G[{0, yu, yu}, yv^(-1)] - G[{1}, yv^(-1)]*G[{yu^(-1)}, yw]*
      G[{0, yu, yu}, yv^(-1)] + (7*G[{yu^(-1)}, yw]^2*
       G[{0, yu, yu}, yv^(-1)])/2 - 5*G[{1}, yu^(-1)]*G[{yu}, yv^(-1)]*
      G[{0, yu, yu}, yv^(-1)] + 2*G[{yu^(-1)}, yw]*G[{yu}, yv^(-1)]*
      G[{0, yu, yu}, yv^(-1)] + (7*G[{yu}, yv^(-1)]^2*
       G[{0, yu, yu}, yv^(-1)])/2 + G[{0}, yu^(-1)]*G[{yv^(-1)}, yw]*
      G[{0, yu, yu}, yv^(-1)] + G[{0}, yv^(-1)]*G[{yv^(-1)}, yw]*
      G[{0, yu, yu}, yv^(-1)] - G[{0}, yw]*G[{yv^(-1)}, yw]*
      G[{0, yu, yu}, yv^(-1)] - 2*G[{1}, yu^(-1)]*G[{yv^(-1)}, yw]*
      G[{0, yu, yu}, yv^(-1)] - G[{1}, yv^(-1)]*G[{yv^(-1)}, yw]*
      G[{0, yu, yu}, yv^(-1)] - G[{1}, yw]*G[{yv^(-1)}, yw]*
      G[{0, yu, yu}, yv^(-1)] + 5*G[{yu^(-1)}, yw]*G[{yv^(-1)}, yw]*
      G[{0, yu, yu}, yv^(-1)] + 5*G[{yu}, yv^(-1)]*G[{yv^(-1)}, yw]*
      G[{0, yu, yu}, yv^(-1)] + G[{yv^(-1)}, yw]^2*G[{0, yu, yu}, yv^(-1)] - 
     G[{0}, yu^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, yu, yu}, yv^(-1)] - 
     G[{0}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, yu, yu}, yv^(-1)] + 
     G[{0}, yw]*G[{1/(yu*yv)}, yw]*G[{0, yu, yu}, yv^(-1)] + 
     6*G[{1}, yu^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, yu, yu}, yv^(-1)] + 
     G[{1}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, yu, yu}, yv^(-1)] + 
     G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{0, yu, yu}, yv^(-1)] - 
     7*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{0, yu, yu}, yv^(-1)] - 
     7*G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, yu, yu}, yv^(-1)] - 
     6*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{0, yu, yu}, yv^(-1)] + 
     3*G[{1/(yu*yv)}, yw]^2*G[{0, yu, yu}, yv^(-1)] + 
     G[{0, 1}, yu^(-1)]*G[{0, yu, yu}, yv^(-1)] + 3*G[{0, 1}, yv^(-1)]*
      G[{0, yu, yu}, yv^(-1)] - G[{0, 1}, yw]*G[{0, yu, yu}, yv^(-1)] + 
     G[{0, yu^(-1)}, yw]*G[{0, yu, yu}, yv^(-1)] - 3*G[{0, yu}, yv^(-1)]*
      G[{0, yu, yu}, yv^(-1)] + G[{0, yv^(-1)}, yw]*G[{0, yu, yu}, yv^(-1)] - 
     G[{0, 1/(yu*yv)}, yw]*G[{0, yu, yu}, yv^(-1)] - 
     5*G[{1, yu^(-1)}, yw]*G[{0, yu, yu}, yv^(-1)] - 
     5*G[{1, yu}, yv^(-1)]*G[{0, yu, yu}, yv^(-1)] - 
     G[{1, 1/(yu*yv)}, yw]*G[{0, yu, yu}, yv^(-1)] + 
     G[{yu^(-1), 1/(yu*yv)}, yw]*G[{0, yu, yu}, yv^(-1)] + 
     6*G[{yv^(-1), 1/(yu*yv)}, yw]*G[{0, yu, yu}, yv^(-1)] - 
     (7*Pi^2*G[{0, yv^(-1), 1}, yw])/6 - 2*G[{0}, yu^(-1)]^2*
      G[{0, yv^(-1), 1}, yw] - 4*G[{0}, yu^(-1)]*G[{0}, yv^(-1)]*
      G[{0, yv^(-1), 1}, yw] - 2*G[{0}, yv^(-1)]^2*G[{0, yv^(-1), 1}, yw] + 
     4*G[{0}, yu^(-1)]*G[{0}, yw]*G[{0, yv^(-1), 1}, yw] + 
     4*G[{0}, yv^(-1)]*G[{0}, yw]*G[{0, yv^(-1), 1}, yw] - 
     2*G[{0}, yw]^2*G[{0, yv^(-1), 1}, yw] + 6*G[{0}, yu^(-1)]*
      G[{1}, yu^(-1)]*G[{0, yv^(-1), 1}, yw] + 6*G[{0}, yv^(-1)]*
      G[{1}, yu^(-1)]*G[{0, yv^(-1), 1}, yw] - 6*G[{0}, yw]*G[{1}, yu^(-1)]*
      G[{0, yv^(-1), 1}, yw] - 4*G[{1}, yu^(-1)]^2*G[{0, yv^(-1), 1}, yw] + 
     4*G[{0}, yu^(-1)]*G[{1}, yv^(-1)]*G[{0, yv^(-1), 1}, yw] + 
     4*G[{0}, yv^(-1)]*G[{1}, yv^(-1)]*G[{0, yv^(-1), 1}, yw] - 
     4*G[{0}, yw]*G[{1}, yv^(-1)]*G[{0, yv^(-1), 1}, yw] - 
     8*G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*G[{0, yv^(-1), 1}, yw] - 
     2*G[{1}, yv^(-1)]^2*G[{0, yv^(-1), 1}, yw] + 
     G[{1}, yw]^2*G[{0, yv^(-1), 1}, yw] - 2*G[{0}, yu^(-1)]*G[{yu^(-1)}, yw]*
      G[{0, yv^(-1), 1}, yw] - 2*G[{0}, yv^(-1)]*G[{yu^(-1)}, yw]*
      G[{0, yv^(-1), 1}, yw] + 2*G[{0}, yw]*G[{yu^(-1)}, yw]*
      G[{0, yv^(-1), 1}, yw] + 4*G[{1}, yu^(-1)]*G[{yu^(-1)}, yw]*
      G[{0, yv^(-1), 1}, yw] + 2*G[{1}, yv^(-1)]*G[{yu^(-1)}, yw]*
      G[{0, yv^(-1), 1}, yw] - 2*G[{1}, yw]*G[{yu^(-1)}, yw]*
      G[{0, yv^(-1), 1}, yw] - 2*G[{0}, yu^(-1)]*G[{yu}, yv^(-1)]*
      G[{0, yv^(-1), 1}, yw] - 2*G[{0}, yv^(-1)]*G[{yu}, yv^(-1)]*
      G[{0, yv^(-1), 1}, yw] + 2*G[{0}, yw]*G[{yu}, yv^(-1)]*
      G[{0, yv^(-1), 1}, yw] + 4*G[{1}, yu^(-1)]*G[{yu}, yv^(-1)]*
      G[{0, yv^(-1), 1}, yw] + 4*G[{1}, yv^(-1)]*G[{yu}, yv^(-1)]*
      G[{0, yv^(-1), 1}, yw] - 2*G[{yu^(-1)}, yw]*G[{yu}, yv^(-1)]*
      G[{0, yv^(-1), 1}, yw] - 2*G[{yu}, yv^(-1)]^2*G[{0, yv^(-1), 1}, yw] - 
     4*G[{0}, yu^(-1)]*G[{yv^(-1)}, yw]*G[{0, yv^(-1), 1}, yw] - 
     4*G[{0}, yv^(-1)]*G[{yv^(-1)}, yw]*G[{0, yv^(-1), 1}, yw] + 
     4*G[{0}, yw]*G[{yv^(-1)}, yw]*G[{0, yv^(-1), 1}, yw] + 
     2*G[{1}, yu^(-1)]*G[{yv^(-1)}, yw]*G[{0, yv^(-1), 1}, yw] + 
     4*G[{1}, yv^(-1)]*G[{yv^(-1)}, yw]*G[{0, yv^(-1), 1}, yw] - 
     2*G[{1}, yw]*G[{yv^(-1)}, yw]*G[{0, yv^(-1), 1}, yw] + 
     2*G[{yu}, yv^(-1)]*G[{yv^(-1)}, yw]*G[{0, yv^(-1), 1}, yw] + 
     6*G[{0}, yu^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, yv^(-1), 1}, yw] + 
     6*G[{0}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, yv^(-1), 1}, yw] - 
     6*G[{0}, yw]*G[{1/(yu*yv)}, yw]*G[{0, yv^(-1), 1}, yw] - 
     6*G[{1}, yu^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, yv^(-1), 1}, yw] - 
     6*G[{1}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, yv^(-1), 1}, yw] + 
     2*G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{0, yv^(-1), 1}, yw] + 
     G[{1/(yu*yv)}, yw]^2*G[{0, yv^(-1), 1}, yw] - 2*G[{0, 1}, yu^(-1)]*
      G[{0, yv^(-1), 1}, yw] - 2*G[{0, 1}, yv^(-1)]*G[{0, yv^(-1), 1}, yw] - 
     G[{0, 1}, yw]*G[{0, yv^(-1), 1}, yw] + G[{0, yu^(-1)}, yw]*
      G[{0, yv^(-1), 1}, yw] + 2*G[{0, yu}, yv^(-1)]*G[{0, yv^(-1), 1}, yw] + 
     G[{0, yv^(-1)}, yw]*G[{0, yv^(-1), 1}, yw] + 2*G[{0, 1/(yu*yv)}, yw]*
      G[{0, yv^(-1), 1}, yw] + 2*G[{1, yu^(-1)}, yw]*G[{0, yv^(-1), 1}, yw] + 
     2*G[{1, yv^(-1)}, yw]*G[{0, yv^(-1), 1}, yw] - 
     2*G[{yu^(-1), 1/(yu*yv)}, yw]*G[{0, yv^(-1), 1}, yw] - 
     2*G[{yv^(-1), 1/(yu*yv)}, yw]*G[{0, yv^(-1), 1}, yw] + 
     (7*Pi^2*G[{0, yv^(-1), yu^(-1)}, yw])/6 + 2*G[{0}, yu^(-1)]^2*
      G[{0, yv^(-1), yu^(-1)}, yw] + 4*G[{0}, yu^(-1)]*G[{0}, yv^(-1)]*
      G[{0, yv^(-1), yu^(-1)}, yw] + 2*G[{0}, yv^(-1)]^2*
      G[{0, yv^(-1), yu^(-1)}, yw] - 4*G[{0}, yu^(-1)]*G[{0}, yw]*
      G[{0, yv^(-1), yu^(-1)}, yw] - 4*G[{0}, yv^(-1)]*G[{0}, yw]*
      G[{0, yv^(-1), yu^(-1)}, yw] + 2*G[{0}, yw]^2*G[{0, yv^(-1), yu^(-1)}, 
       yw] - 6*G[{0}, yu^(-1)]*G[{1}, yu^(-1)]*G[{0, yv^(-1), yu^(-1)}, yw] - 
     6*G[{0}, yv^(-1)]*G[{1}, yu^(-1)]*G[{0, yv^(-1), yu^(-1)}, yw] + 
     6*G[{0}, yw]*G[{1}, yu^(-1)]*G[{0, yv^(-1), yu^(-1)}, yw] + 
     4*G[{1}, yu^(-1)]^2*G[{0, yv^(-1), yu^(-1)}, yw] - 
     6*G[{0}, yu^(-1)]*G[{1}, yv^(-1)]*G[{0, yv^(-1), yu^(-1)}, yw] - 
     6*G[{0}, yv^(-1)]*G[{1}, yv^(-1)]*G[{0, yv^(-1), yu^(-1)}, yw] + 
     6*G[{0}, yw]*G[{1}, yv^(-1)]*G[{0, yv^(-1), yu^(-1)}, yw] + 
     7*G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*G[{0, yv^(-1), yu^(-1)}, yw] + 
     4*G[{1}, yv^(-1)]^2*G[{0, yv^(-1), yu^(-1)}, yw] - 
     2*G[{1}, yu^(-1)]*G[{1}, yw]*G[{0, yv^(-1), yu^(-1)}, yw] - 
     2*G[{1}, yv^(-1)]*G[{1}, yw]*G[{0, yv^(-1), yu^(-1)}, yw] - 
     G[{1}, yw]^2*G[{0, yv^(-1), yu^(-1)}, yw] + 2*G[{0}, yu^(-1)]*
      G[{yu^(-1)}, yw]*G[{0, yv^(-1), yu^(-1)}, yw] + 
     2*G[{0}, yv^(-1)]*G[{yu^(-1)}, yw]*G[{0, yv^(-1), yu^(-1)}, yw] - 
     2*G[{0}, yw]*G[{yu^(-1)}, yw]*G[{0, yv^(-1), yu^(-1)}, yw] - 
     2*G[{1}, yu^(-1)]*G[{yu^(-1)}, yw]*G[{0, yv^(-1), yu^(-1)}, yw] + 
     3*G[{1}, yv^(-1)]*G[{yu^(-1)}, yw]*G[{0, yv^(-1), yu^(-1)}, yw] + 
     7*G[{1}, yw]*G[{yu^(-1)}, yw]*G[{0, yv^(-1), yu^(-1)}, yw] - 
     (7*G[{yu^(-1)}, yw]^2*G[{0, yv^(-1), yu^(-1)}, yw])/2 + 
     4*G[{0}, yu^(-1)]*G[{yu}, yv^(-1)]*G[{0, yv^(-1), yu^(-1)}, yw] + 
     4*G[{0}, yv^(-1)]*G[{yu}, yv^(-1)]*G[{0, yv^(-1), yu^(-1)}, yw] - 
     4*G[{0}, yw]*G[{yu}, yv^(-1)]*G[{0, yv^(-1), yu^(-1)}, yw] - 
     3*G[{1}, yu^(-1)]*G[{yu}, yv^(-1)]*G[{0, yv^(-1), yu^(-1)}, yw] - 
     3*G[{1}, yv^(-1)]*G[{yu}, yv^(-1)]*G[{0, yv^(-1), yu^(-1)}, yw] + 
     4*G[{1}, yw]*G[{yu}, yv^(-1)]*G[{0, yv^(-1), yu^(-1)}, yw] - 
     5*G[{yu^(-1)}, yw]*G[{yu}, yv^(-1)]*G[{0, yv^(-1), yu^(-1)}, yw] - 
     G[{yu}, yv^(-1)]^2*G[{0, yv^(-1), yu^(-1)}, yw] + 
     2*G[{0}, yu^(-1)]*G[{yv^(-1)}, yw]*G[{0, yv^(-1), yu^(-1)}, yw] + 
     2*G[{0}, yv^(-1)]*G[{yv^(-1)}, yw]*G[{0, yv^(-1), yu^(-1)}, yw] - 
     2*G[{0}, yw]*G[{yv^(-1)}, yw]*G[{0, yv^(-1), yu^(-1)}, yw] + 
     3*G[{1}, yu^(-1)]*G[{yv^(-1)}, yw]*G[{0, yv^(-1), yu^(-1)}, yw] - 
     2*G[{1}, yv^(-1)]*G[{yv^(-1)}, yw]*G[{0, yv^(-1), yu^(-1)}, yw] + 
     7*G[{1}, yw]*G[{yv^(-1)}, yw]*G[{0, yv^(-1), yu^(-1)}, yw] - 
     2*G[{yu^(-1)}, yw]*G[{yv^(-1)}, yw]*G[{0, yv^(-1), yu^(-1)}, yw] - 
     5*G[{yu}, yv^(-1)]*G[{yv^(-1)}, yw]*G[{0, yv^(-1), yu^(-1)}, yw] - 
     (7*G[{yv^(-1)}, yw]^2*G[{0, yv^(-1), yu^(-1)}, yw])/2 - 
     4*G[{0}, yu^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, yv^(-1), yu^(-1)}, yw] - 
     4*G[{0}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, yv^(-1), yu^(-1)}, yw] + 
     4*G[{0}, yw]*G[{1/(yu*yv)}, yw]*G[{0, yv^(-1), yu^(-1)}, yw] + 
     G[{1}, yu^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, yv^(-1), yu^(-1)}, yw] + 
     G[{1}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, yv^(-1), yu^(-1)}, yw] - 
     12*G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{0, yv^(-1), yu^(-1)}, yw] + 
     7*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{0, yv^(-1), yu^(-1)}, yw] + 
     6*G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, yv^(-1), yu^(-1)}, yw] + 
     7*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{0, yv^(-1), yu^(-1)}, yw] - 
     3*G[{1/(yu*yv)}, yw]^2*G[{0, yv^(-1), yu^(-1)}, yw] + 
     G[{0, 1}, yu^(-1)]*G[{0, yv^(-1), yu^(-1)}, yw] + 
     G[{0, 1}, yv^(-1)]*G[{0, yv^(-1), yu^(-1)}, yw] + 
     G[{0, 1}, yw]*G[{0, yv^(-1), yu^(-1)}, yw] - G[{0, yu^(-1)}, yw]*
      G[{0, yv^(-1), yu^(-1)}, yw] - G[{0, yu}, yv^(-1)]*
      G[{0, yv^(-1), yu^(-1)}, yw] - G[{0, yv^(-1)}, yw]*
      G[{0, yv^(-1), yu^(-1)}, yw] - 2*G[{0, 1/(yu*yv)}, yw]*
      G[{0, yv^(-1), yu^(-1)}, yw] - 5*G[{1, yu^(-1)}, yw]*
      G[{0, yv^(-1), yu^(-1)}, yw] - 5*G[{1, yv^(-1)}, yw]*
      G[{0, yv^(-1), yu^(-1)}, yw] + 6*G[{1, 1/(yu*yv)}, yw]*
      G[{0, yv^(-1), yu^(-1)}, yw] - G[{yu^(-1), 1/(yu*yv)}, yw]*
      G[{0, yv^(-1), yu^(-1)}, yw] - G[{yv^(-1), 1/(yu*yv)}, yw]*
      G[{0, yv^(-1), yu^(-1)}, yw] + (5*Pi^2*G[{0, yv^(-1), yv^(-1)}, yw])/
      6 + 2*G[{0}, yu^(-1)]^2*G[{0, yv^(-1), yv^(-1)}, yw] + 
     4*G[{0}, yu^(-1)]*G[{0}, yv^(-1)]*G[{0, yv^(-1), yv^(-1)}, yw] + 
     2*G[{0}, yv^(-1)]^2*G[{0, yv^(-1), yv^(-1)}, yw] - 
     4*G[{0}, yu^(-1)]*G[{0}, yw]*G[{0, yv^(-1), yv^(-1)}, yw] - 
     4*G[{0}, yv^(-1)]*G[{0}, yw]*G[{0, yv^(-1), yv^(-1)}, yw] + 
     2*G[{0}, yw]^2*G[{0, yv^(-1), yv^(-1)}, yw] - 
     8*G[{0}, yu^(-1)]*G[{1}, yu^(-1)]*G[{0, yv^(-1), yv^(-1)}, yw] - 
     8*G[{0}, yv^(-1)]*G[{1}, yu^(-1)]*G[{0, yv^(-1), yv^(-1)}, yw] + 
     8*G[{0}, yw]*G[{1}, yu^(-1)]*G[{0, yv^(-1), yv^(-1)}, yw] + 
     6*G[{1}, yu^(-1)]^2*G[{0, yv^(-1), yv^(-1)}, yw] - 
     4*G[{0}, yu^(-1)]*G[{1}, yv^(-1)]*G[{0, yv^(-1), yv^(-1)}, yw] - 
     4*G[{0}, yv^(-1)]*G[{1}, yv^(-1)]*G[{0, yv^(-1), yv^(-1)}, yw] + 
     4*G[{0}, yw]*G[{1}, yv^(-1)]*G[{0, yv^(-1), yv^(-1)}, yw] + 
     7*G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*G[{0, yv^(-1), yv^(-1)}, yw] + 
     2*G[{1}, yv^(-1)]^2*G[{0, yv^(-1), yv^(-1)}, yw] + 
     2*G[{0}, yu^(-1)]*G[{1}, yw]*G[{0, yv^(-1), yv^(-1)}, yw] + 
     2*G[{0}, yv^(-1)]*G[{1}, yw]*G[{0, yv^(-1), yv^(-1)}, yw] - 
     2*G[{0}, yw]*G[{1}, yw]*G[{0, yv^(-1), yv^(-1)}, yw] - 
     6*G[{1}, yu^(-1)]*G[{1}, yw]*G[{0, yv^(-1), yv^(-1)}, yw] - 
     2*G[{1}, yv^(-1)]*G[{1}, yw]*G[{0, yv^(-1), yv^(-1)}, yw] - 
     G[{1}, yw]^2*G[{0, yv^(-1), yv^(-1)}, yw] - 2*G[{0}, yu^(-1)]*
      G[{yu^(-1)}, yw]*G[{0, yv^(-1), yv^(-1)}, yw] - 
     2*G[{0}, yv^(-1)]*G[{yu^(-1)}, yw]*G[{0, yv^(-1), yv^(-1)}, yw] + 
     2*G[{0}, yw]*G[{yu^(-1)}, yw]*G[{0, yv^(-1), yv^(-1)}, yw] + 
     6*G[{1}, yu^(-1)]*G[{yu^(-1)}, yw]*G[{0, yv^(-1), yv^(-1)}, yw] + 
     3*G[{1}, yv^(-1)]*G[{yu^(-1)}, yw]*G[{0, yv^(-1), yv^(-1)}, yw] + 
     7*G[{1}, yw]*G[{yu^(-1)}, yw]*G[{0, yv^(-1), yv^(-1)}, yw] - 
     (7*G[{yu^(-1)}, yw]^2*G[{0, yv^(-1), yv^(-1)}, yw])/2 + 
     4*G[{0}, yu^(-1)]*G[{yu}, yv^(-1)]*G[{0, yv^(-1), yv^(-1)}, yw] + 
     4*G[{0}, yv^(-1)]*G[{yu}, yv^(-1)]*G[{0, yv^(-1), yv^(-1)}, yw] - 
     4*G[{0}, yw]*G[{yu}, yv^(-1)]*G[{0, yv^(-1), yv^(-1)}, yw] - 
     3*G[{1}, yu^(-1)]*G[{yu}, yv^(-1)]*G[{0, yv^(-1), yv^(-1)}, yw] - 
     3*G[{1}, yv^(-1)]*G[{yu}, yv^(-1)]*G[{0, yv^(-1), yv^(-1)}, yw] + 
     4*G[{1}, yw]*G[{yu}, yv^(-1)]*G[{0, yv^(-1), yv^(-1)}, yw] - 
     5*G[{yu^(-1)}, yw]*G[{yu}, yv^(-1)]*G[{0, yv^(-1), yv^(-1)}, yw] - 
     G[{yu}, yv^(-1)]^2*G[{0, yv^(-1), yv^(-1)}, yw] + 
     2*G[{0}, yu^(-1)]*G[{yv^(-1)}, yw]*G[{0, yv^(-1), yv^(-1)}, yw] + 
     2*G[{0}, yv^(-1)]*G[{yv^(-1)}, yw]*G[{0, yv^(-1), yv^(-1)}, yw] - 
     2*G[{0}, yw]*G[{yv^(-1)}, yw]*G[{0, yv^(-1), yv^(-1)}, yw] + 
     3*G[{1}, yu^(-1)]*G[{yv^(-1)}, yw]*G[{0, yv^(-1), yv^(-1)}, yw] - 
     2*G[{1}, yv^(-1)]*G[{yv^(-1)}, yw]*G[{0, yv^(-1), yv^(-1)}, yw] + 
     7*G[{1}, yw]*G[{yv^(-1)}, yw]*G[{0, yv^(-1), yv^(-1)}, yw] - 
     2*G[{yu^(-1)}, yw]*G[{yv^(-1)}, yw]*G[{0, yv^(-1), yv^(-1)}, yw] - 
     5*G[{yu}, yv^(-1)]*G[{yv^(-1)}, yw]*G[{0, yv^(-1), yv^(-1)}, yw] - 
     (7*G[{yv^(-1)}, yw]^2*G[{0, yv^(-1), yv^(-1)}, yw])/2 - 
     2*G[{0}, yu^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, yv^(-1), yv^(-1)}, yw] - 
     2*G[{0}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, yv^(-1), yv^(-1)}, yw] + 
     2*G[{0}, yw]*G[{1/(yu*yv)}, yw]*G[{0, yv^(-1), yv^(-1)}, yw] - 
     3*G[{1}, yu^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, yv^(-1), yv^(-1)}, yw] + 
     G[{1}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, yv^(-1), yv^(-1)}, yw] - 
     12*G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{0, yv^(-1), yv^(-1)}, yw] + 
     7*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{0, yv^(-1), yv^(-1)}, yw] + 
     6*G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, yv^(-1), yv^(-1)}, yw] + 
     7*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{0, yv^(-1), yv^(-1)}, yw] - 
     3*G[{1/(yu*yv)}, yw]^2*G[{0, yv^(-1), yv^(-1)}, yw] - 
     G[{0, 1}, yu^(-1)]*G[{0, yv^(-1), yv^(-1)}, yw] - 
     G[{0, 1}, yv^(-1)]*G[{0, yv^(-1), yv^(-1)}, yw] + 
     3*G[{0, 1}, yw]*G[{0, yv^(-1), yv^(-1)}, yw] - 
     3*G[{0, yu^(-1)}, yw]*G[{0, yv^(-1), yv^(-1)}, yw] + 
     G[{0, yu}, yv^(-1)]*G[{0, yv^(-1), yv^(-1)}, yw] - 
     3*G[{0, yv^(-1)}, yw]*G[{0, yv^(-1), yv^(-1)}, yw] - 
     4*G[{0, 1/(yu*yv)}, yw]*G[{0, yv^(-1), yv^(-1)}, yw] - 
     5*G[{1, yu^(-1)}, yw]*G[{0, yv^(-1), yv^(-1)}, yw] - 
     5*G[{1, yv^(-1)}, yw]*G[{0, yv^(-1), yv^(-1)}, yw] + 
     6*G[{1, 1/(yu*yv)}, yw]*G[{0, yv^(-1), yv^(-1)}, yw] - 
     G[{yu^(-1), 1/(yu*yv)}, yw]*G[{0, yv^(-1), yv^(-1)}, yw] - 
     G[{yv^(-1), 1/(yu*yv)}, yw]*G[{0, yv^(-1), yv^(-1)}, yw] - 
     (Pi^2*G[{0, yv^(-1), 1/(yu*yv)}, yw])/2 - 2*G[{0}, yu^(-1)]^2*
      G[{0, yv^(-1), 1/(yu*yv)}, yw] - 4*G[{0}, yu^(-1)]*G[{0}, yv^(-1)]*
      G[{0, yv^(-1), 1/(yu*yv)}, yw] - 2*G[{0}, yv^(-1)]^2*
      G[{0, yv^(-1), 1/(yu*yv)}, yw] + 4*G[{0}, yu^(-1)]*G[{0}, yw]*
      G[{0, yv^(-1), 1/(yu*yv)}, yw] + 4*G[{0}, yv^(-1)]*G[{0}, yw]*
      G[{0, yv^(-1), 1/(yu*yv)}, yw] - 2*G[{0}, yw]^2*
      G[{0, yv^(-1), 1/(yu*yv)}, yw] + 8*G[{0}, yu^(-1)]*G[{1}, yu^(-1)]*
      G[{0, yv^(-1), 1/(yu*yv)}, yw] + 8*G[{0}, yv^(-1)]*G[{1}, yu^(-1)]*
      G[{0, yv^(-1), 1/(yu*yv)}, yw] - 8*G[{0}, yw]*G[{1}, yu^(-1)]*
      G[{0, yv^(-1), 1/(yu*yv)}, yw] - 6*G[{1}, yu^(-1)]^2*
      G[{0, yv^(-1), 1/(yu*yv)}, yw] + 6*G[{0}, yu^(-1)]*G[{1}, yv^(-1)]*
      G[{0, yv^(-1), 1/(yu*yv)}, yw] + 6*G[{0}, yv^(-1)]*G[{1}, yv^(-1)]*
      G[{0, yv^(-1), 1/(yu*yv)}, yw] - 6*G[{0}, yw]*G[{1}, yv^(-1)]*
      G[{0, yv^(-1), 1/(yu*yv)}, yw] - 8*G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*
      G[{0, yv^(-1), 1/(yu*yv)}, yw] - 4*G[{1}, yv^(-1)]^2*
      G[{0, yv^(-1), 1/(yu*yv)}, yw] + 4*G[{0}, yu^(-1)]*G[{1}, yw]*
      G[{0, yv^(-1), 1/(yu*yv)}, yw] + 4*G[{0}, yv^(-1)]*G[{1}, yw]*
      G[{0, yv^(-1), 1/(yu*yv)}, yw] - 4*G[{0}, yw]*G[{1}, yw]*
      G[{0, yv^(-1), 1/(yu*yv)}, yw] - 4*G[{1}, yu^(-1)]*G[{1}, yw]*
      G[{0, yv^(-1), 1/(yu*yv)}, yw] - 4*G[{1}, yv^(-1)]*G[{1}, yw]*
      G[{0, yv^(-1), 1/(yu*yv)}, yw] + G[{1}, yw]^2*
      G[{0, yv^(-1), 1/(yu*yv)}, yw] - 4*G[{0}, yu^(-1)]*G[{yu^(-1)}, yw]*
      G[{0, yv^(-1), 1/(yu*yv)}, yw] - 4*G[{0}, yv^(-1)]*G[{yu^(-1)}, yw]*
      G[{0, yv^(-1), 1/(yu*yv)}, yw] + 4*G[{0}, yw]*G[{yu^(-1)}, yw]*
      G[{0, yv^(-1), 1/(yu*yv)}, yw] + 4*G[{1}, yu^(-1)]*G[{yu^(-1)}, yw]*
      G[{0, yv^(-1), 1/(yu*yv)}, yw] + 2*G[{1}, yv^(-1)]*G[{yu^(-1)}, yw]*
      G[{0, yv^(-1), 1/(yu*yv)}, yw] - 2*G[{1}, yw]*G[{yu^(-1)}, yw]*
      G[{0, yv^(-1), 1/(yu*yv)}, yw] - 6*G[{0}, yu^(-1)]*G[{yu}, yv^(-1)]*
      G[{0, yv^(-1), 1/(yu*yv)}, yw] - 6*G[{0}, yv^(-1)]*G[{yu}, yv^(-1)]*
      G[{0, yv^(-1), 1/(yu*yv)}, yw] + 6*G[{0}, yw]*G[{yu}, yv^(-1)]*
      G[{0, yv^(-1), 1/(yu*yv)}, yw] + 4*G[{1}, yu^(-1)]*G[{yu}, yv^(-1)]*
      G[{0, yv^(-1), 1/(yu*yv)}, yw] + 4*G[{1}, yv^(-1)]*G[{yu}, yv^(-1)]*
      G[{0, yv^(-1), 1/(yu*yv)}, yw] + 2*G[{yu^(-1)}, yw]*G[{yu}, yv^(-1)]*
      G[{0, yv^(-1), 1/(yu*yv)}, yw] + 2*G[{yu}, yv^(-1)]^2*
      G[{0, yv^(-1), 1/(yu*yv)}, yw] - 6*G[{0}, yu^(-1)]*G[{yv^(-1)}, yw]*
      G[{0, yv^(-1), 1/(yu*yv)}, yw] - 6*G[{0}, yv^(-1)]*G[{yv^(-1)}, yw]*
      G[{0, yv^(-1), 1/(yu*yv)}, yw] + 6*G[{0}, yw]*G[{yv^(-1)}, yw]*
      G[{0, yv^(-1), 1/(yu*yv)}, yw] + 6*G[{1}, yu^(-1)]*G[{yv^(-1)}, yw]*
      G[{0, yv^(-1), 1/(yu*yv)}, yw] + 8*G[{1}, yv^(-1)]*G[{yv^(-1)}, yw]*
      G[{0, yv^(-1), 1/(yu*yv)}, yw] - 2*G[{1}, yw]*G[{yv^(-1)}, yw]*
      G[{0, yv^(-1), 1/(yu*yv)}, yw] - 2*G[{yu}, yv^(-1)]*G[{yv^(-1)}, yw]*
      G[{0, yv^(-1), 1/(yu*yv)}, yw] + 6*G[{0}, yu^(-1)]*G[{1/(yu*yv)}, yw]*
      G[{0, yv^(-1), 1/(yu*yv)}, yw] + 6*G[{0}, yv^(-1)]*G[{1/(yu*yv)}, yw]*
      G[{0, yv^(-1), 1/(yu*yv)}, yw] - 6*G[{0}, yw]*G[{1/(yu*yv)}, yw]*
      G[{0, yv^(-1), 1/(yu*yv)}, yw] - 6*G[{1}, yu^(-1)]*G[{1/(yu*yv)}, yw]*
      G[{0, yv^(-1), 1/(yu*yv)}, yw] - 6*G[{1}, yv^(-1)]*G[{1/(yu*yv)}, yw]*
      G[{0, yv^(-1), 1/(yu*yv)}, yw] + 2*G[{1}, yw]*G[{1/(yu*yv)}, yw]*
      G[{0, yv^(-1), 1/(yu*yv)}, yw] + G[{1/(yu*yv)}, yw]^2*
      G[{0, yv^(-1), 1/(yu*yv)}, yw] + 2*G[{0, 1}, yu^(-1)]*
      G[{0, yv^(-1), 1/(yu*yv)}, yw] + 2*G[{0, 1}, yv^(-1)]*
      G[{0, yv^(-1), 1/(yu*yv)}, yw] - 5*G[{0, 1}, yw]*
      G[{0, yv^(-1), 1/(yu*yv)}, yw] + 5*G[{0, yu^(-1)}, yw]*
      G[{0, yv^(-1), 1/(yu*yv)}, yw] - 2*G[{0, yu}, yv^(-1)]*
      G[{0, yv^(-1), 1/(yu*yv)}, yw] + 5*G[{0, yv^(-1)}, yw]*
      G[{0, yv^(-1), 1/(yu*yv)}, yw] + 2*G[{0, 1/(yu*yv)}, yw]*
      G[{0, yv^(-1), 1/(yu*yv)}, yw] + 2*G[{1, yu^(-1)}, yw]*
      G[{0, yv^(-1), 1/(yu*yv)}, yw] + 2*G[{1, yv^(-1)}, yw]*
      G[{0, yv^(-1), 1/(yu*yv)}, yw] - 2*G[{yu^(-1), 1/(yu*yv)}, yw]*
      G[{0, yv^(-1), 1/(yu*yv)}, yw] - 2*G[{yv^(-1), 1/(yu*yv)}, yw]*
      G[{0, yv^(-1), 1/(yu*yv)}, yw] + (5*Pi^2*G[{0, 1/(yu*yv), 1}, yw])/6 + 
     2*G[{0}, yu^(-1)]^2*G[{0, 1/(yu*yv), 1}, yw] + 
     4*G[{0}, yu^(-1)]*G[{0}, yv^(-1)]*G[{0, 1/(yu*yv), 1}, yw] + 
     2*G[{0}, yv^(-1)]^2*G[{0, 1/(yu*yv), 1}, yw] - 
     4*G[{0}, yu^(-1)]*G[{0}, yw]*G[{0, 1/(yu*yv), 1}, yw] - 
     4*G[{0}, yv^(-1)]*G[{0}, yw]*G[{0, 1/(yu*yv), 1}, yw] + 
     2*G[{0}, yw]^2*G[{0, 1/(yu*yv), 1}, yw] - 6*G[{0}, yu^(-1)]*
      G[{1}, yu^(-1)]*G[{0, 1/(yu*yv), 1}, yw] - 6*G[{0}, yv^(-1)]*
      G[{1}, yu^(-1)]*G[{0, 1/(yu*yv), 1}, yw] + 6*G[{0}, yw]*G[{1}, yu^(-1)]*
      G[{0, 1/(yu*yv), 1}, yw] + 4*G[{1}, yu^(-1)]^2*
      G[{0, 1/(yu*yv), 1}, yw] - 6*G[{0}, yu^(-1)]*G[{1}, yv^(-1)]*
      G[{0, 1/(yu*yv), 1}, yw] - 6*G[{0}, yv^(-1)]*G[{1}, yv^(-1)]*
      G[{0, 1/(yu*yv), 1}, yw] + 6*G[{0}, yw]*G[{1}, yv^(-1)]*
      G[{0, 1/(yu*yv), 1}, yw] + 8*G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*
      G[{0, 1/(yu*yv), 1}, yw] + 4*G[{1}, yv^(-1)]^2*
      G[{0, 1/(yu*yv), 1}, yw] - G[{1}, yw]^2*G[{0, 1/(yu*yv), 1}, yw] + 
     2*G[{0}, yu^(-1)]*G[{yu^(-1)}, yw]*G[{0, 1/(yu*yv), 1}, yw] + 
     2*G[{0}, yv^(-1)]*G[{yu^(-1)}, yw]*G[{0, 1/(yu*yv), 1}, yw] - 
     2*G[{0}, yw]*G[{yu^(-1)}, yw]*G[{0, 1/(yu*yv), 1}, yw] - 
     4*G[{1}, yu^(-1)]*G[{yu^(-1)}, yw]*G[{0, 1/(yu*yv), 1}, yw] - 
     2*G[{1}, yv^(-1)]*G[{yu^(-1)}, yw]*G[{0, 1/(yu*yv), 1}, yw] + 
     2*G[{1}, yw]*G[{yu^(-1)}, yw]*G[{0, 1/(yu*yv), 1}, yw] + 
     4*G[{0}, yu^(-1)]*G[{yu}, yv^(-1)]*G[{0, 1/(yu*yv), 1}, yw] + 
     4*G[{0}, yv^(-1)]*G[{yu}, yv^(-1)]*G[{0, 1/(yu*yv), 1}, yw] - 
     4*G[{0}, yw]*G[{yu}, yv^(-1)]*G[{0, 1/(yu*yv), 1}, yw] - 
     4*G[{1}, yu^(-1)]*G[{yu}, yv^(-1)]*G[{0, 1/(yu*yv), 1}, yw] - 
     4*G[{1}, yv^(-1)]*G[{yu}, yv^(-1)]*G[{0, 1/(yu*yv), 1}, yw] + 
     2*G[{yu^(-1)}, yw]*G[{yu}, yv^(-1)]*G[{0, 1/(yu*yv), 1}, yw] + 
     2*G[{0}, yu^(-1)]*G[{yv^(-1)}, yw]*G[{0, 1/(yu*yv), 1}, yw] + 
     2*G[{0}, yv^(-1)]*G[{yv^(-1)}, yw]*G[{0, 1/(yu*yv), 1}, yw] - 
     2*G[{0}, yw]*G[{yv^(-1)}, yw]*G[{0, 1/(yu*yv), 1}, yw] - 
     2*G[{1}, yu^(-1)]*G[{yv^(-1)}, yw]*G[{0, 1/(yu*yv), 1}, yw] - 
     4*G[{1}, yv^(-1)]*G[{yv^(-1)}, yw]*G[{0, 1/(yu*yv), 1}, yw] + 
     2*G[{1}, yw]*G[{yv^(-1)}, yw]*G[{0, 1/(yu*yv), 1}, yw] + 
     2*G[{yu}, yv^(-1)]*G[{yv^(-1)}, yw]*G[{0, 1/(yu*yv), 1}, yw] - 
     4*G[{0}, yu^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv), 1}, yw] - 
     4*G[{0}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv), 1}, yw] + 
     4*G[{0}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv), 1}, yw] + 
     6*G[{1}, yu^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv), 1}, yw] + 
     6*G[{1}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv), 1}, yw] - 
     2*G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv), 1}, yw] - 
     4*G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv), 1}, yw] - 
     G[{1/(yu*yv)}, yw]^2*G[{0, 1/(yu*yv), 1}, yw] + 
     3*G[{0, 1}, yw]*G[{0, 1/(yu*yv), 1}, yw] - 3*G[{0, yu^(-1)}, yw]*
      G[{0, 1/(yu*yv), 1}, yw] - 3*G[{0, yv^(-1)}, yw]*
      G[{0, 1/(yu*yv), 1}, yw] + 3*G[{0, 1/(yu*yv)}, yw]*
      G[{0, 1/(yu*yv), 1}, yw] - 2*G[{1, yu^(-1)}, yw]*
      G[{0, 1/(yu*yv), 1}, yw] - 2*G[{1, yv^(-1)}, yw]*
      G[{0, 1/(yu*yv), 1}, yw] + 2*G[{yu^(-1), 1/(yu*yv)}, yw]*
      G[{0, 1/(yu*yv), 1}, yw] + 2*G[{yv^(-1), 1/(yu*yv)}, yw]*
      G[{0, 1/(yu*yv), 1}, yw] - (5*Pi^2*G[{0, 1/(yu*yv), yu^(-1)}, yw])/6 - 
     2*G[{0}, yu^(-1)]^2*G[{0, 1/(yu*yv), yu^(-1)}, yw] - 
     4*G[{0}, yu^(-1)]*G[{0}, yv^(-1)]*G[{0, 1/(yu*yv), yu^(-1)}, yw] - 
     2*G[{0}, yv^(-1)]^2*G[{0, 1/(yu*yv), yu^(-1)}, yw] + 
     4*G[{0}, yu^(-1)]*G[{0}, yw]*G[{0, 1/(yu*yv), yu^(-1)}, yw] + 
     4*G[{0}, yv^(-1)]*G[{0}, yw]*G[{0, 1/(yu*yv), yu^(-1)}, yw] - 
     2*G[{0}, yw]^2*G[{0, 1/(yu*yv), yu^(-1)}, yw] + 
     6*G[{0}, yu^(-1)]*G[{1}, yu^(-1)]*G[{0, 1/(yu*yv), yu^(-1)}, yw] + 
     6*G[{0}, yv^(-1)]*G[{1}, yu^(-1)]*G[{0, 1/(yu*yv), yu^(-1)}, yw] - 
     6*G[{0}, yw]*G[{1}, yu^(-1)]*G[{0, 1/(yu*yv), yu^(-1)}, yw] - 
     4*G[{1}, yu^(-1)]^2*G[{0, 1/(yu*yv), yu^(-1)}, yw] + 
     8*G[{0}, yu^(-1)]*G[{1}, yv^(-1)]*G[{0, 1/(yu*yv), yu^(-1)}, yw] + 
     8*G[{0}, yv^(-1)]*G[{1}, yv^(-1)]*G[{0, 1/(yu*yv), yu^(-1)}, yw] - 
     8*G[{0}, yw]*G[{1}, yv^(-1)]*G[{0, 1/(yu*yv), yu^(-1)}, yw] - 
     7*G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*G[{0, 1/(yu*yv), yu^(-1)}, yw] - 
     6*G[{1}, yv^(-1)]^2*G[{0, 1/(yu*yv), yu^(-1)}, yw] + 
     2*G[{1}, yu^(-1)]*G[{1}, yw]*G[{0, 1/(yu*yv), yu^(-1)}, yw] + 
     2*G[{1}, yv^(-1)]*G[{1}, yw]*G[{0, 1/(yu*yv), yu^(-1)}, yw] + 
     G[{1}, yw]^2*G[{0, 1/(yu*yv), yu^(-1)}, yw] - 
     2*G[{0}, yu^(-1)]*G[{yu^(-1)}, yw]*G[{0, 1/(yu*yv), yu^(-1)}, yw] - 
     2*G[{0}, yv^(-1)]*G[{yu^(-1)}, yw]*G[{0, 1/(yu*yv), yu^(-1)}, yw] + 
     2*G[{0}, yw]*G[{yu^(-1)}, yw]*G[{0, 1/(yu*yv), yu^(-1)}, yw] + 
     2*G[{1}, yu^(-1)]*G[{yu^(-1)}, yw]*G[{0, 1/(yu*yv), yu^(-1)}, yw] - 
     3*G[{1}, yv^(-1)]*G[{yu^(-1)}, yw]*G[{0, 1/(yu*yv), yu^(-1)}, yw] - 
     7*G[{1}, yw]*G[{yu^(-1)}, yw]*G[{0, 1/(yu*yv), yu^(-1)}, yw] + 
     (7*G[{yu^(-1)}, yw]^2*G[{0, 1/(yu*yv), yu^(-1)}, yw])/2 - 
     6*G[{0}, yu^(-1)]*G[{yu}, yv^(-1)]*G[{0, 1/(yu*yv), yu^(-1)}, yw] - 
     6*G[{0}, yv^(-1)]*G[{yu}, yv^(-1)]*G[{0, 1/(yu*yv), yu^(-1)}, yw] + 
     6*G[{0}, yw]*G[{yu}, yv^(-1)]*G[{0, 1/(yu*yv), yu^(-1)}, yw] + 
     3*G[{1}, yu^(-1)]*G[{yu}, yv^(-1)]*G[{0, 1/(yu*yv), yu^(-1)}, yw] + 
     3*G[{1}, yv^(-1)]*G[{yu}, yv^(-1)]*G[{0, 1/(yu*yv), yu^(-1)}, yw] - 
     4*G[{1}, yw]*G[{yu}, yv^(-1)]*G[{0, 1/(yu*yv), yu^(-1)}, yw] + 
     5*G[{yu^(-1)}, yw]*G[{yu}, yv^(-1)]*G[{0, 1/(yu*yv), yu^(-1)}, yw] + 
     3*G[{yu}, yv^(-1)]^2*G[{0, 1/(yu*yv), yu^(-1)}, yw] - 
     3*G[{1}, yu^(-1)]*G[{yv^(-1)}, yw]*G[{0, 1/(yu*yv), yu^(-1)}, yw] - 
     2*G[{1}, yv^(-1)]*G[{yv^(-1)}, yw]*G[{0, 1/(yu*yv), yu^(-1)}, yw] - 
     7*G[{1}, yw]*G[{yv^(-1)}, yw]*G[{0, 1/(yu*yv), yu^(-1)}, yw] + 
     2*G[{yu^(-1)}, yw]*G[{yv^(-1)}, yw]*G[{0, 1/(yu*yv), yu^(-1)}, yw] + 
     5*G[{yu}, yv^(-1)]*G[{yv^(-1)}, yw]*G[{0, 1/(yu*yv), yu^(-1)}, yw] + 
     (7*G[{yv^(-1)}, yw]^2*G[{0, 1/(yu*yv), yu^(-1)}, yw])/2 + 
     2*G[{0}, yu^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv), yu^(-1)}, yw] + 
     2*G[{0}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv), yu^(-1)}, yw] - 
     2*G[{0}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv), yu^(-1)}, yw] - 
     G[{1}, yu^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv), yu^(-1)}, yw] + 
     3*G[{1}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv), yu^(-1)}, yw] + 
     12*G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv), yu^(-1)}, yw] - 
     7*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv), yu^(-1)}, yw] - 
     6*G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv), yu^(-1)}, yw] - 
     7*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv), yu^(-1)}, yw] + 
     3*G[{1/(yu*yv)}, yw]^2*G[{0, 1/(yu*yv), yu^(-1)}, yw] + 
     G[{0, 1}, yu^(-1)]*G[{0, 1/(yu*yv), yu^(-1)}, yw] + 
     G[{0, 1}, yv^(-1)]*G[{0, 1/(yu*yv), yu^(-1)}, yw] - 
     3*G[{0, 1}, yw]*G[{0, 1/(yu*yv), yu^(-1)}, yw] + 
     3*G[{0, yu^(-1)}, yw]*G[{0, 1/(yu*yv), yu^(-1)}, yw] - 
     G[{0, yu}, yv^(-1)]*G[{0, 1/(yu*yv), yu^(-1)}, yw] + 
     3*G[{0, yv^(-1)}, yw]*G[{0, 1/(yu*yv), yu^(-1)}, yw] - 
     3*G[{0, 1/(yu*yv)}, yw]*G[{0, 1/(yu*yv), yu^(-1)}, yw] + 
     5*G[{1, yu^(-1)}, yw]*G[{0, 1/(yu*yv), yu^(-1)}, yw] + 
     5*G[{1, yv^(-1)}, yw]*G[{0, 1/(yu*yv), yu^(-1)}, yw] - 
     6*G[{1, 1/(yu*yv)}, yw]*G[{0, 1/(yu*yv), yu^(-1)}, yw] + 
     G[{yu^(-1), 1/(yu*yv)}, yw]*G[{0, 1/(yu*yv), yu^(-1)}, yw] + 
     G[{yv^(-1), 1/(yu*yv)}, yw]*G[{0, 1/(yu*yv), yu^(-1)}, yw] - 
     (5*Pi^2*G[{0, 1/(yu*yv), yv^(-1)}, yw])/6 - 2*G[{0}, yu^(-1)]^2*
      G[{0, 1/(yu*yv), yv^(-1)}, yw] - 4*G[{0}, yu^(-1)]*G[{0}, yv^(-1)]*
      G[{0, 1/(yu*yv), yv^(-1)}, yw] - 2*G[{0}, yv^(-1)]^2*
      G[{0, 1/(yu*yv), yv^(-1)}, yw] + 4*G[{0}, yu^(-1)]*G[{0}, yw]*
      G[{0, 1/(yu*yv), yv^(-1)}, yw] + 4*G[{0}, yv^(-1)]*G[{0}, yw]*
      G[{0, 1/(yu*yv), yv^(-1)}, yw] - 2*G[{0}, yw]^2*
      G[{0, 1/(yu*yv), yv^(-1)}, yw] + 8*G[{0}, yu^(-1)]*G[{1}, yu^(-1)]*
      G[{0, 1/(yu*yv), yv^(-1)}, yw] + 8*G[{0}, yv^(-1)]*G[{1}, yu^(-1)]*
      G[{0, 1/(yu*yv), yv^(-1)}, yw] - 8*G[{0}, yw]*G[{1}, yu^(-1)]*
      G[{0, 1/(yu*yv), yv^(-1)}, yw] - 6*G[{1}, yu^(-1)]^2*
      G[{0, 1/(yu*yv), yv^(-1)}, yw] + 6*G[{0}, yu^(-1)]*G[{1}, yv^(-1)]*
      G[{0, 1/(yu*yv), yv^(-1)}, yw] + 6*G[{0}, yv^(-1)]*G[{1}, yv^(-1)]*
      G[{0, 1/(yu*yv), yv^(-1)}, yw] - 6*G[{0}, yw]*G[{1}, yv^(-1)]*
      G[{0, 1/(yu*yv), yv^(-1)}, yw] - 7*G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*
      G[{0, 1/(yu*yv), yv^(-1)}, yw] - 4*G[{1}, yv^(-1)]^2*
      G[{0, 1/(yu*yv), yv^(-1)}, yw] + 2*G[{1}, yu^(-1)]*G[{1}, yw]*
      G[{0, 1/(yu*yv), yv^(-1)}, yw] + 2*G[{1}, yv^(-1)]*G[{1}, yw]*
      G[{0, 1/(yu*yv), yv^(-1)}, yw] + G[{1}, yw]^2*
      G[{0, 1/(yu*yv), yv^(-1)}, yw] - 2*G[{1}, yu^(-1)]*G[{yu^(-1)}, yw]*
      G[{0, 1/(yu*yv), yv^(-1)}, yw] - 3*G[{1}, yv^(-1)]*G[{yu^(-1)}, yw]*
      G[{0, 1/(yu*yv), yv^(-1)}, yw] - 7*G[{1}, yw]*G[{yu^(-1)}, yw]*
      G[{0, 1/(yu*yv), yv^(-1)}, yw] + 
     (7*G[{yu^(-1)}, yw]^2*G[{0, 1/(yu*yv), yv^(-1)}, yw])/2 - 
     6*G[{0}, yu^(-1)]*G[{yu}, yv^(-1)]*G[{0, 1/(yu*yv), yv^(-1)}, yw] - 
     6*G[{0}, yv^(-1)]*G[{yu}, yv^(-1)]*G[{0, 1/(yu*yv), yv^(-1)}, yw] + 
     6*G[{0}, yw]*G[{yu}, yv^(-1)]*G[{0, 1/(yu*yv), yv^(-1)}, yw] + 
     3*G[{1}, yu^(-1)]*G[{yu}, yv^(-1)]*G[{0, 1/(yu*yv), yv^(-1)}, yw] + 
     3*G[{1}, yv^(-1)]*G[{yu}, yv^(-1)]*G[{0, 1/(yu*yv), yv^(-1)}, yw] - 
     4*G[{1}, yw]*G[{yu}, yv^(-1)]*G[{0, 1/(yu*yv), yv^(-1)}, yw] + 
     5*G[{yu^(-1)}, yw]*G[{yu}, yv^(-1)]*G[{0, 1/(yu*yv), yv^(-1)}, yw] + 
     3*G[{yu}, yv^(-1)]^2*G[{0, 1/(yu*yv), yv^(-1)}, yw] - 
     2*G[{0}, yu^(-1)]*G[{yv^(-1)}, yw]*G[{0, 1/(yu*yv), yv^(-1)}, yw] - 
     2*G[{0}, yv^(-1)]*G[{yv^(-1)}, yw]*G[{0, 1/(yu*yv), yv^(-1)}, yw] + 
     2*G[{0}, yw]*G[{yv^(-1)}, yw]*G[{0, 1/(yu*yv), yv^(-1)}, yw] - 
     3*G[{1}, yu^(-1)]*G[{yv^(-1)}, yw]*G[{0, 1/(yu*yv), yv^(-1)}, yw] + 
     2*G[{1}, yv^(-1)]*G[{yv^(-1)}, yw]*G[{0, 1/(yu*yv), yv^(-1)}, yw] - 
     7*G[{1}, yw]*G[{yv^(-1)}, yw]*G[{0, 1/(yu*yv), yv^(-1)}, yw] + 
     2*G[{yu^(-1)}, yw]*G[{yv^(-1)}, yw]*G[{0, 1/(yu*yv), yv^(-1)}, yw] + 
     5*G[{yu}, yv^(-1)]*G[{yv^(-1)}, yw]*G[{0, 1/(yu*yv), yv^(-1)}, yw] + 
     (7*G[{yv^(-1)}, yw]^2*G[{0, 1/(yu*yv), yv^(-1)}, yw])/2 + 
     2*G[{0}, yu^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv), yv^(-1)}, yw] + 
     2*G[{0}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv), yv^(-1)}, yw] - 
     2*G[{0}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv), yv^(-1)}, yw] + 
     3*G[{1}, yu^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv), yv^(-1)}, yw] - 
     G[{1}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv), yv^(-1)}, yw] + 
     12*G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv), yv^(-1)}, yw] - 
     7*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv), yv^(-1)}, yw] - 
     6*G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv), yv^(-1)}, yw] - 
     7*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv), yv^(-1)}, yw] + 
     3*G[{1/(yu*yv)}, yw]^2*G[{0, 1/(yu*yv), yv^(-1)}, yw] + 
     G[{0, 1}, yu^(-1)]*G[{0, 1/(yu*yv), yv^(-1)}, yw] + 
     G[{0, 1}, yv^(-1)]*G[{0, 1/(yu*yv), yv^(-1)}, yw] - 
     3*G[{0, 1}, yw]*G[{0, 1/(yu*yv), yv^(-1)}, yw] + 
     3*G[{0, yu^(-1)}, yw]*G[{0, 1/(yu*yv), yv^(-1)}, yw] - 
     G[{0, yu}, yv^(-1)]*G[{0, 1/(yu*yv), yv^(-1)}, yw] + 
     3*G[{0, yv^(-1)}, yw]*G[{0, 1/(yu*yv), yv^(-1)}, yw] - 
     3*G[{0, 1/(yu*yv)}, yw]*G[{0, 1/(yu*yv), yv^(-1)}, yw] + 
     5*G[{1, yu^(-1)}, yw]*G[{0, 1/(yu*yv), yv^(-1)}, yw] + 
     5*G[{1, yv^(-1)}, yw]*G[{0, 1/(yu*yv), yv^(-1)}, yw] - 
     6*G[{1, 1/(yu*yv)}, yw]*G[{0, 1/(yu*yv), yv^(-1)}, yw] + 
     G[{yu^(-1), 1/(yu*yv)}, yw]*G[{0, 1/(yu*yv), yv^(-1)}, yw] + 
     G[{yv^(-1), 1/(yu*yv)}, yw]*G[{0, 1/(yu*yv), yv^(-1)}, yw] + 
     (Pi^2*G[{0, 1/(yu*yv), 1/(yu*yv)}, yw])/2 + 2*G[{0}, yu^(-1)]^2*
      G[{0, 1/(yu*yv), 1/(yu*yv)}, yw] + 4*G[{0}, yu^(-1)]*G[{0}, yv^(-1)]*
      G[{0, 1/(yu*yv), 1/(yu*yv)}, yw] + 2*G[{0}, yv^(-1)]^2*
      G[{0, 1/(yu*yv), 1/(yu*yv)}, yw] - 4*G[{0}, yu^(-1)]*G[{0}, yw]*
      G[{0, 1/(yu*yv), 1/(yu*yv)}, yw] - 4*G[{0}, yv^(-1)]*G[{0}, yw]*
      G[{0, 1/(yu*yv), 1/(yu*yv)}, yw] + 2*G[{0}, yw]^2*
      G[{0, 1/(yu*yv), 1/(yu*yv)}, yw] - 8*G[{0}, yu^(-1)]*G[{1}, yu^(-1)]*
      G[{0, 1/(yu*yv), 1/(yu*yv)}, yw] - 8*G[{0}, yv^(-1)]*G[{1}, yu^(-1)]*
      G[{0, 1/(yu*yv), 1/(yu*yv)}, yw] + 8*G[{0}, yw]*G[{1}, yu^(-1)]*
      G[{0, 1/(yu*yv), 1/(yu*yv)}, yw] + 6*G[{1}, yu^(-1)]^2*
      G[{0, 1/(yu*yv), 1/(yu*yv)}, yw] - 8*G[{0}, yu^(-1)]*G[{1}, yv^(-1)]*
      G[{0, 1/(yu*yv), 1/(yu*yv)}, yw] - 8*G[{0}, yv^(-1)]*G[{1}, yv^(-1)]*
      G[{0, 1/(yu*yv), 1/(yu*yv)}, yw] + 8*G[{0}, yw]*G[{1}, yv^(-1)]*
      G[{0, 1/(yu*yv), 1/(yu*yv)}, yw] + 8*G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*
      G[{0, 1/(yu*yv), 1/(yu*yv)}, yw] + 6*G[{1}, yv^(-1)]^2*
      G[{0, 1/(yu*yv), 1/(yu*yv)}, yw] - 6*G[{0}, yu^(-1)]*G[{1}, yw]*
      G[{0, 1/(yu*yv), 1/(yu*yv)}, yw] - 6*G[{0}, yv^(-1)]*G[{1}, yw]*
      G[{0, 1/(yu*yv), 1/(yu*yv)}, yw] + 6*G[{0}, yw]*G[{1}, yw]*
      G[{0, 1/(yu*yv), 1/(yu*yv)}, yw] + 8*G[{1}, yu^(-1)]*G[{1}, yw]*
      G[{0, 1/(yu*yv), 1/(yu*yv)}, yw] + 8*G[{1}, yv^(-1)]*G[{1}, yw]*
      G[{0, 1/(yu*yv), 1/(yu*yv)}, yw] - G[{1}, yw]^2*
      G[{0, 1/(yu*yv), 1/(yu*yv)}, yw] + 6*G[{0}, yu^(-1)]*G[{yu^(-1)}, yw]*
      G[{0, 1/(yu*yv), 1/(yu*yv)}, yw] + 6*G[{0}, yv^(-1)]*G[{yu^(-1)}, yw]*
      G[{0, 1/(yu*yv), 1/(yu*yv)}, yw] - 6*G[{0}, yw]*G[{yu^(-1)}, yw]*
      G[{0, 1/(yu*yv), 1/(yu*yv)}, yw] - 8*G[{1}, yu^(-1)]*G[{yu^(-1)}, yw]*
      G[{0, 1/(yu*yv), 1/(yu*yv)}, yw] - 6*G[{1}, yv^(-1)]*G[{yu^(-1)}, yw]*
      G[{0, 1/(yu*yv), 1/(yu*yv)}, yw] + 2*G[{1}, yw]*G[{yu^(-1)}, yw]*
      G[{0, 1/(yu*yv), 1/(yu*yv)}, yw] + 8*G[{0}, yu^(-1)]*G[{yu}, yv^(-1)]*
      G[{0, 1/(yu*yv), 1/(yu*yv)}, yw] + 8*G[{0}, yv^(-1)]*G[{yu}, yv^(-1)]*
      G[{0, 1/(yu*yv), 1/(yu*yv)}, yw] - 8*G[{0}, yw]*G[{yu}, yv^(-1)]*
      G[{0, 1/(yu*yv), 1/(yu*yv)}, yw] - 4*G[{1}, yu^(-1)]*G[{yu}, yv^(-1)]*
      G[{0, 1/(yu*yv), 1/(yu*yv)}, yw] - 4*G[{1}, yv^(-1)]*G[{yu}, yv^(-1)]*
      G[{0, 1/(yu*yv), 1/(yu*yv)}, yw] - 4*G[{1}, yw]*G[{yu}, yv^(-1)]*
      G[{0, 1/(yu*yv), 1/(yu*yv)}, yw] + 2*G[{yu^(-1)}, yw]*G[{yu}, yv^(-1)]*
      G[{0, 1/(yu*yv), 1/(yu*yv)}, yw] - 4*G[{yu}, yv^(-1)]^2*
      G[{0, 1/(yu*yv), 1/(yu*yv)}, yw] + 6*G[{0}, yu^(-1)]*G[{yv^(-1)}, yw]*
      G[{0, 1/(yu*yv), 1/(yu*yv)}, yw] + 6*G[{0}, yv^(-1)]*G[{yv^(-1)}, yw]*
      G[{0, 1/(yu*yv), 1/(yu*yv)}, yw] - 6*G[{0}, yw]*G[{yv^(-1)}, yw]*
      G[{0, 1/(yu*yv), 1/(yu*yv)}, yw] - 6*G[{1}, yu^(-1)]*G[{yv^(-1)}, yw]*
      G[{0, 1/(yu*yv), 1/(yu*yv)}, yw] - 8*G[{1}, yv^(-1)]*G[{yv^(-1)}, yw]*
      G[{0, 1/(yu*yv), 1/(yu*yv)}, yw] + 2*G[{1}, yw]*G[{yv^(-1)}, yw]*
      G[{0, 1/(yu*yv), 1/(yu*yv)}, yw] + 2*G[{yu}, yv^(-1)]*G[{yv^(-1)}, yw]*
      G[{0, 1/(yu*yv), 1/(yu*yv)}, yw] - 6*G[{0}, yu^(-1)]*G[{1/(yu*yv)}, yw]*
      G[{0, 1/(yu*yv), 1/(yu*yv)}, yw] - 6*G[{0}, yv^(-1)]*G[{1/(yu*yv)}, yw]*
      G[{0, 1/(yu*yv), 1/(yu*yv)}, yw] + 6*G[{0}, yw]*G[{1/(yu*yv)}, yw]*
      G[{0, 1/(yu*yv), 1/(yu*yv)}, yw] + 6*G[{1}, yu^(-1)]*G[{1/(yu*yv)}, yw]*
      G[{0, 1/(yu*yv), 1/(yu*yv)}, yw] + 6*G[{1}, yv^(-1)]*G[{1/(yu*yv)}, yw]*
      G[{0, 1/(yu*yv), 1/(yu*yv)}, yw] - 2*G[{1}, yw]*G[{1/(yu*yv)}, yw]*
      G[{0, 1/(yu*yv), 1/(yu*yv)}, yw] - G[{1/(yu*yv)}, yw]^2*
      G[{0, 1/(yu*yv), 1/(yu*yv)}, yw] - 2*G[{0, 1}, yu^(-1)]*
      G[{0, 1/(yu*yv), 1/(yu*yv)}, yw] - 2*G[{0, 1}, yv^(-1)]*
      G[{0, 1/(yu*yv), 1/(yu*yv)}, yw] + 5*G[{0, 1}, yw]*
      G[{0, 1/(yu*yv), 1/(yu*yv)}, yw] - 5*G[{0, yu^(-1)}, yw]*
      G[{0, 1/(yu*yv), 1/(yu*yv)}, yw] + 2*G[{0, yu}, yv^(-1)]*
      G[{0, 1/(yu*yv), 1/(yu*yv)}, yw] - 5*G[{0, yv^(-1)}, yw]*
      G[{0, 1/(yu*yv), 1/(yu*yv)}, yw] + 5*G[{0, 1/(yu*yv)}, yw]*
      G[{0, 1/(yu*yv), 1/(yu*yv)}, yw] - 2*G[{1, yu^(-1)}, yw]*
      G[{0, 1/(yu*yv), 1/(yu*yv)}, yw] - 2*G[{1, yv^(-1)}, yw]*
      G[{0, 1/(yu*yv), 1/(yu*yv)}, yw] + 2*G[{yu^(-1), 1/(yu*yv)}, yw]*
      G[{0, 1/(yu*yv), 1/(yu*yv)}, yw] + 2*G[{yv^(-1), 1/(yu*yv)}, yw]*
      G[{0, 1/(yu*yv), 1/(yu*yv)}, yw] - Pi^2*G[{1, 1, yu^(-1)}, yw] - 
     2*G[{0}, yu^(-1)]^2*G[{1, 1, yu^(-1)}, yw] - 
     4*G[{0}, yu^(-1)]*G[{0}, yv^(-1)]*G[{1, 1, yu^(-1)}, yw] - 
     2*G[{0}, yv^(-1)]^2*G[{1, 1, yu^(-1)}, yw] + 
     4*G[{0}, yu^(-1)]*G[{0}, yw]*G[{1, 1, yu^(-1)}, yw] + 
     4*G[{0}, yv^(-1)]*G[{0}, yw]*G[{1, 1, yu^(-1)}, yw] - 
     2*G[{0}, yw]^2*G[{1, 1, yu^(-1)}, yw] + 4*G[{0}, yu^(-1)]*
      G[{1}, yu^(-1)]*G[{1, 1, yu^(-1)}, yw] + 4*G[{0}, yv^(-1)]*
      G[{1}, yu^(-1)]*G[{1, 1, yu^(-1)}, yw] - 4*G[{0}, yw]*G[{1}, yu^(-1)]*
      G[{1, 1, yu^(-1)}, yw] - 2*G[{1}, yu^(-1)]^2*G[{1, 1, yu^(-1)}, yw] + 
     6*G[{0}, yu^(-1)]*G[{1}, yv^(-1)]*G[{1, 1, yu^(-1)}, yw] + 
     6*G[{0}, yv^(-1)]*G[{1}, yv^(-1)]*G[{1, 1, yu^(-1)}, yw] - 
     6*G[{0}, yw]*G[{1}, yv^(-1)]*G[{1, 1, yu^(-1)}, yw] - 
     9*G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*G[{1, 1, yu^(-1)}, yw] - 
     4*G[{1}, yv^(-1)]^2*G[{1, 1, yu^(-1)}, yw] + 
     2*G[{0}, yu^(-1)]*G[{1}, yw]*G[{1, 1, yu^(-1)}, yw] + 
     2*G[{0}, yv^(-1)]*G[{1}, yw]*G[{1, 1, yu^(-1)}, yw] - 
     2*G[{0}, yw]*G[{1}, yw]*G[{1, 1, yu^(-1)}, yw] - 
     2*G[{1}, yu^(-1)]*G[{1}, yw]*G[{1, 1, yu^(-1)}, yw] - 
     2*G[{1}, yv^(-1)]*G[{1}, yw]*G[{1, 1, yu^(-1)}, yw] - 
     7*G[{0}, yu^(-1)]*G[{yu^(-1)}, yw]*G[{1, 1, yu^(-1)}, yw] - 
     7*G[{0}, yv^(-1)]*G[{yu^(-1)}, yw]*G[{1, 1, yu^(-1)}, yw] + 
     7*G[{0}, yw]*G[{yu^(-1)}, yw]*G[{1, 1, yu^(-1)}, yw] + 
     7*G[{1}, yu^(-1)]*G[{yu^(-1)}, yw]*G[{1, 1, yu^(-1)}, yw] + 
     7*G[{1}, yv^(-1)]*G[{yu^(-1)}, yw]*G[{1, 1, yu^(-1)}, yw] - 
     (7*G[{yu^(-1)}, yw]^2*G[{1, 1, yu^(-1)}, yw])/2 - 
     2*G[{0}, yu^(-1)]*G[{yu}, yv^(-1)]*G[{1, 1, yu^(-1)}, yw] - 
     2*G[{0}, yv^(-1)]*G[{yu}, yv^(-1)]*G[{1, 1, yu^(-1)}, yw] + 
     2*G[{0}, yw]*G[{yu}, yv^(-1)]*G[{1, 1, yu^(-1)}, yw] + 
     5*G[{1}, yu^(-1)]*G[{yu}, yv^(-1)]*G[{1, 1, yu^(-1)}, yw] + 
     4*G[{1}, yv^(-1)]*G[{yu}, yv^(-1)]*G[{1, 1, yu^(-1)}, yw] - 
     (5*G[{yu}, yv^(-1)]^2*G[{1, 1, yu^(-1)}, yw])/2 - 
     G[{0}, yu^(-1)]*G[{yv^(-1)}, yw]*G[{1, 1, yu^(-1)}, yw] - 
     G[{0}, yv^(-1)]*G[{yv^(-1)}, yw]*G[{1, 1, yu^(-1)}, yw] + 
     G[{0}, yw]*G[{yv^(-1)}, yw]*G[{1, 1, yu^(-1)}, yw] + 
     4*G[{1}, yu^(-1)]*G[{yv^(-1)}, yw]*G[{1, 1, yu^(-1)}, yw] + 
     3*G[{1}, yv^(-1)]*G[{yv^(-1)}, yw]*G[{1, 1, yu^(-1)}, yw] + 
     5*G[{1}, yw]*G[{yv^(-1)}, yw]*G[{1, 1, yu^(-1)}, yw] - 
     5*G[{yu^(-1)}, yw]*G[{yv^(-1)}, yw]*G[{1, 1, yu^(-1)}, yw] - 
     5*G[{yu}, yv^(-1)]*G[{yv^(-1)}, yw]*G[{1, 1, yu^(-1)}, yw] - 
     G[{yv^(-1)}, yw]^2*G[{1, 1, yu^(-1)}, yw] + 9*G[{0}, yu^(-1)]*
      G[{1/(yu*yv)}, yw]*G[{1, 1, yu^(-1)}, yw] + 
     9*G[{0}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{1, 1, yu^(-1)}, yw] - 
     9*G[{0}, yw]*G[{1/(yu*yv)}, yw]*G[{1, 1, yu^(-1)}, yw] - 
     12*G[{1}, yu^(-1)]*G[{1/(yu*yv)}, yw]*G[{1, 1, yu^(-1)}, yw] - 
     11*G[{1}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{1, 1, yu^(-1)}, yw] - 
     5*G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{1, 1, yu^(-1)}, yw] + 
     7*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{1, 1, yu^(-1)}, yw] + 
     5*G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{1, 1, yu^(-1)}, yw] + 
     6*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{1, 1, yu^(-1)}, yw] - 
     G[{1/(yu*yv)}, yw]^2*G[{1, 1, yu^(-1)}, yw] - 3*G[{0, 1}, yu^(-1)]*
      G[{1, 1, yu^(-1)}, yw] - 2*G[{0, 1}, yv^(-1)]*G[{1, 1, yu^(-1)}, yw] + 
     2*G[{0, yu}, yv^(-1)]*G[{1, 1, yu^(-1)}, yw] + 
     5*G[{1, yu^(-1)}, yw]*G[{1, 1, yu^(-1)}, yw] + 
     G[{1, yu}, yv^(-1)]*G[{1, 1, yu^(-1)}, yw] + 2*G[{1, yv^(-1)}, yw]*
      G[{1, 1, yu^(-1)}, yw] + 3*G[{1, 1/(yu*yv)}, yw]*
      G[{1, 1, yu^(-1)}, yw] - 5*G[{yu^(-1), 1/(yu*yv)}, yw]*
      G[{1, 1, yu^(-1)}, yw] - 8*G[{yv^(-1), 1/(yu*yv)}, yw]*
      G[{1, 1, yu^(-1)}, yw] - (Pi^2*G[{1, 1, yu}, yv^(-1)])/2 - 
     2*G[{1}, yu^(-1)]^2*G[{1, 1, yu}, yv^(-1)] - 
     2*G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*G[{1, 1, yu}, yv^(-1)] + 
     3*G[{0}, yu^(-1)]*G[{1}, yw]*G[{1, 1, yu}, yv^(-1)] + 
     3*G[{0}, yv^(-1)]*G[{1}, yw]*G[{1, 1, yu}, yv^(-1)] - 
     3*G[{0}, yw]*G[{1}, yw]*G[{1, 1, yu}, yv^(-1)] - 
     5*G[{1}, yu^(-1)]*G[{1}, yw]*G[{1, 1, yu}, yv^(-1)] - 
     5*G[{1}, yv^(-1)]*G[{1}, yw]*G[{1, 1, yu}, yv^(-1)] - 
     3*G[{0}, yu^(-1)]*G[{yu^(-1)}, yw]*G[{1, 1, yu}, yv^(-1)] - 
     3*G[{0}, yv^(-1)]*G[{yu^(-1)}, yw]*G[{1, 1, yu}, yv^(-1)] + 
     3*G[{0}, yw]*G[{yu^(-1)}, yw]*G[{1, 1, yu}, yv^(-1)] + 
     13*G[{1}, yu^(-1)]*G[{yu^(-1)}, yw]*G[{1, 1, yu}, yv^(-1)] + 
     5*G[{1}, yv^(-1)]*G[{yu^(-1)}, yw]*G[{1, 1, yu}, yv^(-1)] + 
     2*G[{1}, yw]*G[{yu^(-1)}, yw]*G[{1, 1, yu}, yv^(-1)] - 
     (7*G[{yu^(-1)}, yw]^2*G[{1, 1, yu}, yv^(-1)])/2 + 
     7*G[{1}, yu^(-1)]*G[{yu}, yv^(-1)]*G[{1, 1, yu}, yv^(-1)] - 
     2*G[{yu^(-1)}, yw]*G[{yu}, yv^(-1)]*G[{1, 1, yu}, yv^(-1)] - 
     (7*G[{yu}, yv^(-1)]^2*G[{1, 1, yu}, yv^(-1)])/2 - 
     3*G[{0}, yu^(-1)]*G[{yv^(-1)}, yw]*G[{1, 1, yu}, yv^(-1)] - 
     3*G[{0}, yv^(-1)]*G[{yv^(-1)}, yw]*G[{1, 1, yu}, yv^(-1)] + 
     3*G[{0}, yw]*G[{yv^(-1)}, yw]*G[{1, 1, yu}, yv^(-1)] + 
     4*G[{1}, yu^(-1)]*G[{yv^(-1)}, yw]*G[{1, 1, yu}, yv^(-1)] + 
     5*G[{1}, yv^(-1)]*G[{yv^(-1)}, yw]*G[{1, 1, yu}, yv^(-1)] + 
     3*G[{1}, yw]*G[{yv^(-1)}, yw]*G[{1, 1, yu}, yv^(-1)] - 
     5*G[{yu^(-1)}, yw]*G[{yv^(-1)}, yw]*G[{1, 1, yu}, yv^(-1)] - 
     5*G[{yu}, yv^(-1)]*G[{yv^(-1)}, yw]*G[{1, 1, yu}, yv^(-1)] - 
     G[{yv^(-1)}, yw]^2*G[{1, 1, yu}, yv^(-1)] + 3*G[{0}, yu^(-1)]*
      G[{1/(yu*yv)}, yw]*G[{1, 1, yu}, yv^(-1)] + 
     3*G[{0}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{1, 1, yu}, yv^(-1)] - 
     3*G[{0}, yw]*G[{1/(yu*yv)}, yw]*G[{1, 1, yu}, yv^(-1)] - 
     12*G[{1}, yu^(-1)]*G[{1/(yu*yv)}, yw]*G[{1, 1, yu}, yv^(-1)] - 
     5*G[{1}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{1, 1, yu}, yv^(-1)] - 
     5*G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{1, 1, yu}, yv^(-1)] + 
     7*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{1, 1, yu}, yv^(-1)] + 
     7*G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{1, 1, yu}, yv^(-1)] + 
     6*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{1, 1, yu}, yv^(-1)] - 
     G[{1/(yu*yv)}, yw]^2*G[{1, 1, yu}, yv^(-1)] - 2*G[{0, 1}, yv^(-1)]*
      G[{1, 1, yu}, yv^(-1)] + 3*G[{0, 1}, yw]*G[{1, 1, yu}, yv^(-1)] - 
     3*G[{0, yu^(-1)}, yw]*G[{1, 1, yu}, yv^(-1)] + 
     2*G[{0, yu}, yv^(-1)]*G[{1, 1, yu}, yv^(-1)] - 
     3*G[{0, yv^(-1)}, yw]*G[{1, 1, yu}, yv^(-1)] + 
     3*G[{0, 1/(yu*yv)}, yw]*G[{1, 1, yu}, yv^(-1)] + 
     3*G[{1, yu^(-1)}, yw]*G[{1, 1, yu}, yv^(-1)] + 
     5*G[{1, yu}, yv^(-1)]*G[{1, 1, yu}, yv^(-1)] - 
     2*G[{1, yv^(-1)}, yw]*G[{1, 1, yu}, yv^(-1)] + 
     5*G[{1, 1/(yu*yv)}, yw]*G[{1, 1, yu}, yv^(-1)] - 
     3*G[{yu^(-1), 1/(yu*yv)}, yw]*G[{1, 1, yu}, yv^(-1)] - 
     8*G[{yv^(-1), 1/(yu*yv)}, yw]*G[{1, 1, yu}, yv^(-1)] - 
     Pi^2*G[{1, 1, yv^(-1)}, yw] - 2*G[{0}, yu^(-1)]^2*
      G[{1, 1, yv^(-1)}, yw] - 4*G[{0}, yu^(-1)]*G[{0}, yv^(-1)]*
      G[{1, 1, yv^(-1)}, yw] - 2*G[{0}, yv^(-1)]^2*G[{1, 1, yv^(-1)}, yw] + 
     4*G[{0}, yu^(-1)]*G[{0}, yw]*G[{1, 1, yv^(-1)}, yw] + 
     4*G[{0}, yv^(-1)]*G[{0}, yw]*G[{1, 1, yv^(-1)}, yw] - 
     2*G[{0}, yw]^2*G[{1, 1, yv^(-1)}, yw] + 6*G[{0}, yu^(-1)]*
      G[{1}, yu^(-1)]*G[{1, 1, yv^(-1)}, yw] + 6*G[{0}, yv^(-1)]*
      G[{1}, yu^(-1)]*G[{1, 1, yv^(-1)}, yw] - 6*G[{0}, yw]*G[{1}, yu^(-1)]*
      G[{1, 1, yv^(-1)}, yw] - 4*G[{1}, yu^(-1)]^2*G[{1, 1, yv^(-1)}, yw] + 
     4*G[{0}, yu^(-1)]*G[{1}, yv^(-1)]*G[{1, 1, yv^(-1)}, yw] + 
     4*G[{0}, yv^(-1)]*G[{1}, yv^(-1)]*G[{1, 1, yv^(-1)}, yw] - 
     4*G[{0}, yw]*G[{1}, yv^(-1)]*G[{1, 1, yv^(-1)}, yw] - 
     8*G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*G[{1, 1, yv^(-1)}, yw] - 
     2*G[{1}, yv^(-1)]^2*G[{1, 1, yv^(-1)}, yw] + 
     2*G[{0}, yu^(-1)]*G[{1}, yw]*G[{1, 1, yv^(-1)}, yw] + 
     2*G[{0}, yv^(-1)]*G[{1}, yw]*G[{1, 1, yv^(-1)}, yw] - 
     2*G[{0}, yw]*G[{1}, yw]*G[{1, 1, yv^(-1)}, yw] - 
     2*G[{1}, yu^(-1)]*G[{1}, yw]*G[{1, 1, yv^(-1)}, yw] - 
     2*G[{1}, yv^(-1)]*G[{1}, yw]*G[{1, 1, yv^(-1)}, yw] - 
     G[{0}, yu^(-1)]*G[{yu^(-1)}, yw]*G[{1, 1, yv^(-1)}, yw] - 
     G[{0}, yv^(-1)]*G[{yu^(-1)}, yw]*G[{1, 1, yv^(-1)}, yw] + 
     G[{0}, yw]*G[{yu^(-1)}, yw]*G[{1, 1, yv^(-1)}, yw] + 
     3*G[{1}, yu^(-1)]*G[{yu^(-1)}, yw]*G[{1, 1, yv^(-1)}, yw] + 
     4*G[{1}, yv^(-1)]*G[{yu^(-1)}, yw]*G[{1, 1, yv^(-1)}, yw] + 
     5*G[{1}, yw]*G[{yu^(-1)}, yw]*G[{1, 1, yv^(-1)}, yw] - 
     G[{yu^(-1)}, yw]^2*G[{1, 1, yv^(-1)}, yw] - 2*G[{0}, yu^(-1)]*
      G[{yu}, yv^(-1)]*G[{1, 1, yv^(-1)}, yw] - 2*G[{0}, yv^(-1)]*
      G[{yu}, yv^(-1)]*G[{1, 1, yv^(-1)}, yw] + 2*G[{0}, yw]*G[{yu}, yv^(-1)]*
      G[{1, 1, yv^(-1)}, yw] + 4*G[{1}, yu^(-1)]*G[{yu}, yv^(-1)]*
      G[{1, 1, yv^(-1)}, yw] + 5*G[{1}, yv^(-1)]*G[{yu}, yv^(-1)]*
      G[{1, 1, yv^(-1)}, yw] - 5*G[{yu^(-1)}, yw]*G[{yu}, yv^(-1)]*
      G[{1, 1, yv^(-1)}, yw] - (5*G[{yu}, yv^(-1)]^2*G[{1, 1, yv^(-1)}, yw])/
      2 - 7*G[{0}, yu^(-1)]*G[{yv^(-1)}, yw]*G[{1, 1, yv^(-1)}, yw] - 
     7*G[{0}, yv^(-1)]*G[{yv^(-1)}, yw]*G[{1, 1, yv^(-1)}, yw] + 
     7*G[{0}, yw]*G[{yv^(-1)}, yw]*G[{1, 1, yv^(-1)}, yw] + 
     7*G[{1}, yu^(-1)]*G[{yv^(-1)}, yw]*G[{1, 1, yv^(-1)}, yw] + 
     7*G[{1}, yv^(-1)]*G[{yv^(-1)}, yw]*G[{1, 1, yv^(-1)}, yw] - 
     5*G[{yu^(-1)}, yw]*G[{yv^(-1)}, yw]*G[{1, 1, yv^(-1)}, yw] - 
     (7*G[{yv^(-1)}, yw]^2*G[{1, 1, yv^(-1)}, yw])/2 + 
     9*G[{0}, yu^(-1)]*G[{1/(yu*yv)}, yw]*G[{1, 1, yv^(-1)}, yw] + 
     9*G[{0}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{1, 1, yv^(-1)}, yw] - 
     9*G[{0}, yw]*G[{1/(yu*yv)}, yw]*G[{1, 1, yv^(-1)}, yw] - 
     11*G[{1}, yu^(-1)]*G[{1/(yu*yv)}, yw]*G[{1, 1, yv^(-1)}, yw] - 
     12*G[{1}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{1, 1, yv^(-1)}, yw] - 
     5*G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{1, 1, yv^(-1)}, yw] + 
     6*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{1, 1, yv^(-1)}, yw] + 
     5*G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{1, 1, yv^(-1)}, yw] + 
     7*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{1, 1, yv^(-1)}, yw] - 
     G[{1/(yu*yv)}, yw]^2*G[{1, 1, yv^(-1)}, yw] - 2*G[{0, 1}, yu^(-1)]*
      G[{1, 1, yv^(-1)}, yw] - 3*G[{0, 1}, yv^(-1)]*G[{1, 1, yv^(-1)}, yw] + 
     3*G[{0, yu}, yv^(-1)]*G[{1, 1, yv^(-1)}, yw] + 
     2*G[{1, yu^(-1)}, yw]*G[{1, 1, yv^(-1)}, yw] - 
     G[{1, yu}, yv^(-1)]*G[{1, 1, yv^(-1)}, yw] + 5*G[{1, yv^(-1)}, yw]*
      G[{1, 1, yv^(-1)}, yw] + 3*G[{1, 1/(yu*yv)}, yw]*
      G[{1, 1, yv^(-1)}, yw] - 8*G[{yu^(-1), 1/(yu*yv)}, yw]*
      G[{1, 1, yv^(-1)}, yw] - 5*G[{yv^(-1), 1/(yu*yv)}, yw]*
      G[{1, 1, yv^(-1)}, yw] - Pi^2*G[{1, 1, 1/(yu*yv)}, yw] - 
     2*G[{0}, yu^(-1)]*G[{1}, yu^(-1)]*G[{1, 1, 1/(yu*yv)}, yw] - 
     2*G[{0}, yv^(-1)]*G[{1}, yu^(-1)]*G[{1, 1, 1/(yu*yv)}, yw] + 
     2*G[{0}, yw]*G[{1}, yu^(-1)]*G[{1, 1, 1/(yu*yv)}, yw] + 
     2*G[{1}, yu^(-1)]^2*G[{1, 1, 1/(yu*yv)}, yw] - 
     2*G[{0}, yu^(-1)]*G[{1}, yv^(-1)]*G[{1, 1, 1/(yu*yv)}, yw] - 
     2*G[{0}, yv^(-1)]*G[{1}, yv^(-1)]*G[{1, 1, 1/(yu*yv)}, yw] + 
     2*G[{0}, yw]*G[{1}, yv^(-1)]*G[{1, 1, 1/(yu*yv)}, yw] + 
     G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*G[{1, 1, 1/(yu*yv)}, yw] + 
     2*G[{1}, yv^(-1)]^2*G[{1, 1, 1/(yu*yv)}, yw] - 
     2*G[{0}, yu^(-1)]*G[{1}, yw]*G[{1, 1, 1/(yu*yv)}, yw] - 
     2*G[{0}, yv^(-1)]*G[{1}, yw]*G[{1, 1, 1/(yu*yv)}, yw] + 
     2*G[{0}, yw]*G[{1}, yw]*G[{1, 1, 1/(yu*yv)}, yw] + 
     2*G[{1}, yu^(-1)]*G[{1}, yw]*G[{1, 1, 1/(yu*yv)}, yw] + 
     2*G[{1}, yv^(-1)]*G[{1}, yw]*G[{1, 1, 1/(yu*yv)}, yw] - 
     2*G[{1}, yu^(-1)]*G[{yu^(-1)}, yw]*G[{1, 1, 1/(yu*yv)}, yw] - 
     7*G[{1}, yv^(-1)]*G[{yu^(-1)}, yw]*G[{1, 1, 1/(yu*yv)}, yw] - 
     9*G[{1}, yw]*G[{yu^(-1)}, yw]*G[{1, 1, 1/(yu*yv)}, yw] + 
     (9*G[{yu^(-1)}, yw]^2*G[{1, 1, 1/(yu*yv)}, yw])/2 + 
     4*G[{0}, yu^(-1)]*G[{yu}, yv^(-1)]*G[{1, 1, 1/(yu*yv)}, yw] + 
     4*G[{0}, yv^(-1)]*G[{yu}, yv^(-1)]*G[{1, 1, 1/(yu*yv)}, yw] - 
     4*G[{0}, yw]*G[{yu}, yv^(-1)]*G[{1, 1, 1/(yu*yv)}, yw] - 
     G[{1}, yu^(-1)]*G[{yu}, yv^(-1)]*G[{1, 1, 1/(yu*yv)}, yw] - 
     G[{1}, yv^(-1)]*G[{yu}, yv^(-1)]*G[{1, 1, 1/(yu*yv)}, yw] + 
     9*G[{yu^(-1)}, yw]*G[{yu}, yv^(-1)]*G[{1, 1, 1/(yu*yv)}, yw] - 
     3*G[{yu}, yv^(-1)]^2*G[{1, 1, 1/(yu*yv)}, yw] - 
     7*G[{1}, yu^(-1)]*G[{yv^(-1)}, yw]*G[{1, 1, 1/(yu*yv)}, yw] - 
     2*G[{1}, yv^(-1)]*G[{yv^(-1)}, yw]*G[{1, 1, 1/(yu*yv)}, yw] - 
     9*G[{1}, yw]*G[{yv^(-1)}, yw]*G[{1, 1, 1/(yu*yv)}, yw] + 
     10*G[{yu^(-1)}, yw]*G[{yv^(-1)}, yw]*G[{1, 1, 1/(yu*yv)}, yw] + 
     9*G[{yu}, yv^(-1)]*G[{yv^(-1)}, yw]*G[{1, 1, 1/(yu*yv)}, yw] + 
     (9*G[{yv^(-1)}, yw]^2*G[{1, 1, 1/(yu*yv)}, yw])/2 - 
     2*G[{0}, yu^(-1)]*G[{1/(yu*yv)}, yw]*G[{1, 1, 1/(yu*yv)}, yw] - 
     2*G[{0}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{1, 1, 1/(yu*yv)}, yw] + 
     2*G[{0}, yw]*G[{1/(yu*yv)}, yw]*G[{1, 1, 1/(yu*yv)}, yw] + 
     11*G[{1}, yu^(-1)]*G[{1/(yu*yv)}, yw]*G[{1, 1, 1/(yu*yv)}, yw] + 
     11*G[{1}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{1, 1, 1/(yu*yv)}, yw] + 
     18*G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{1, 1, 1/(yu*yv)}, yw] - 
     13*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{1, 1, 1/(yu*yv)}, yw] - 
     18*G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{1, 1, 1/(yu*yv)}, yw] - 
     13*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{1, 1, 1/(yu*yv)}, yw] + 
     4*G[{1/(yu*yv)}, yw]^2*G[{1, 1, 1/(yu*yv)}, yw] - 
     3*G[{0, 1}, yu^(-1)]*G[{1, 1, 1/(yu*yv)}, yw] - 
     3*G[{0, 1}, yv^(-1)]*G[{1, 1, 1/(yu*yv)}, yw] + 
     2*G[{0, 1}, yw]*G[{1, 1, 1/(yu*yv)}, yw] - 2*G[{0, yu^(-1)}, yw]*
      G[{1, 1, 1/(yu*yv)}, yw] + 3*G[{0, yu}, yv^(-1)]*
      G[{1, 1, 1/(yu*yv)}, yw] - 2*G[{0, yv^(-1)}, yw]*
      G[{1, 1, 1/(yu*yv)}, yw] + 2*G[{0, 1/(yu*yv)}, yw]*
      G[{1, 1, 1/(yu*yv)}, yw] - 3*G[{1, yu^(-1)}, yw]*
      G[{1, 1, 1/(yu*yv)}, yw] - 3*G[{1, yv^(-1)}, yw]*
      G[{1, 1, 1/(yu*yv)}, yw] - 6*G[{1, 1/(yu*yv)}, yw]*
      G[{1, 1, 1/(yu*yv)}, yw] + 9*G[{yu^(-1), 1/(yu*yv)}, yw]*
      G[{1, 1, 1/(yu*yv)}, yw] + 9*G[{yv^(-1), 1/(yu*yv)}, yw]*
      G[{1, 1, 1/(yu*yv)}, yw] - (Pi^2*G[{1, yu^(-1), yu^(-1)}, yw])/3 - 
     2*G[{0}, yu^(-1)]^2*G[{1, yu^(-1), yu^(-1)}, yw] - 
     4*G[{0}, yu^(-1)]*G[{0}, yv^(-1)]*G[{1, yu^(-1), yu^(-1)}, yw] - 
     2*G[{0}, yv^(-1)]^2*G[{1, yu^(-1), yu^(-1)}, yw] + 
     4*G[{0}, yu^(-1)]*G[{0}, yw]*G[{1, yu^(-1), yu^(-1)}, yw] + 
     4*G[{0}, yv^(-1)]*G[{0}, yw]*G[{1, yu^(-1), yu^(-1)}, yw] - 
     2*G[{0}, yw]^2*G[{1, yu^(-1), yu^(-1)}, yw] + 
     4*G[{0}, yu^(-1)]*G[{1}, yu^(-1)]*G[{1, yu^(-1), yu^(-1)}, yw] + 
     4*G[{0}, yv^(-1)]*G[{1}, yu^(-1)]*G[{1, yu^(-1), yu^(-1)}, yw] - 
     4*G[{0}, yw]*G[{1}, yu^(-1)]*G[{1, yu^(-1), yu^(-1)}, yw] - 
     2*G[{1}, yu^(-1)]^2*G[{1, yu^(-1), yu^(-1)}, yw] + 
     4*G[{0}, yu^(-1)]*G[{1}, yv^(-1)]*G[{1, yu^(-1), yu^(-1)}, yw] + 
     4*G[{0}, yv^(-1)]*G[{1}, yv^(-1)]*G[{1, yu^(-1), yu^(-1)}, yw] - 
     4*G[{0}, yw]*G[{1}, yv^(-1)]*G[{1, yu^(-1), yu^(-1)}, yw] - 
     4*G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*G[{1, yu^(-1), yu^(-1)}, yw] - 
     2*G[{0}, yu^(-1)]*G[{1}, yw]*G[{1, yu^(-1), yu^(-1)}, yw] - 
     2*G[{0}, yv^(-1)]*G[{1}, yw]*G[{1, yu^(-1), yu^(-1)}, yw] + 
     2*G[{0}, yw]*G[{1}, yw]*G[{1, yu^(-1), yu^(-1)}, yw] + 
     2*G[{1}, yu^(-1)]*G[{1}, yw]*G[{1, yu^(-1), yu^(-1)}, yw] + 
     6*G[{1}, yv^(-1)]*G[{1}, yw]*G[{1, yu^(-1), yu^(-1)}, yw] + 
     2*G[{1}, yw]^2*G[{1, yu^(-1), yu^(-1)}, yw] - 
     7*G[{0}, yu^(-1)]*G[{yu^(-1)}, yw]*G[{1, yu^(-1), yu^(-1)}, yw] - 
     7*G[{0}, yv^(-1)]*G[{yu^(-1)}, yw]*G[{1, yu^(-1), yu^(-1)}, yw] + 
     7*G[{0}, yw]*G[{yu^(-1)}, yw]*G[{1, yu^(-1), yu^(-1)}, yw] + 
     7*G[{1}, yu^(-1)]*G[{yu^(-1)}, yw]*G[{1, yu^(-1), yu^(-1)}, yw] - 
     7*G[{1}, yw]*G[{yu^(-1)}, yw]*G[{1, yu^(-1), yu^(-1)}, yw] - 
     2*G[{1}, yv^(-1)]*G[{yu}, yv^(-1)]*G[{1, yu^(-1), yu^(-1)}, yw] - 
     4*G[{1}, yw]*G[{yu}, yv^(-1)]*G[{1, yu^(-1), yu^(-1)}, yw] + 
     7*G[{yu^(-1)}, yw]*G[{yu}, yv^(-1)]*G[{1, yu^(-1), yu^(-1)}, yw] + 
     G[{yu}, yv^(-1)]^2*G[{1, yu^(-1), yu^(-1)}, yw] + 
     G[{0}, yu^(-1)]*G[{yv^(-1)}, yw]*G[{1, yu^(-1), yu^(-1)}, yw] + 
     G[{0}, yv^(-1)]*G[{yv^(-1)}, yw]*G[{1, yu^(-1), yu^(-1)}, yw] - 
     G[{0}, yw]*G[{yv^(-1)}, yw]*G[{1, yu^(-1), yu^(-1)}, yw] - 
     G[{1}, yu^(-1)]*G[{yv^(-1)}, yw]*G[{1, yu^(-1), yu^(-1)}, yw] - 
     9*G[{1}, yv^(-1)]*G[{yv^(-1)}, yw]*G[{1, yu^(-1), yu^(-1)}, yw] - 
     8*G[{1}, yw]*G[{yv^(-1)}, yw]*G[{1, yu^(-1), yu^(-1)}, yw] - 
     3*G[{yu^(-1)}, yw]*G[{yv^(-1)}, yw]*G[{1, yu^(-1), yu^(-1)}, yw] + 
     8*G[{yu}, yv^(-1)]*G[{yv^(-1)}, yw]*G[{1, yu^(-1), yu^(-1)}, yw] + 
     (5*G[{yv^(-1)}, yw]^2*G[{1, yu^(-1), yu^(-1)}, yw])/2 + 
     7*G[{0}, yu^(-1)]*G[{1/(yu*yv)}, yw]*G[{1, yu^(-1), yu^(-1)}, yw] + 
     7*G[{0}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{1, yu^(-1), yu^(-1)}, yw] - 
     7*G[{0}, yw]*G[{1/(yu*yv)}, yw]*G[{1, yu^(-1), yu^(-1)}, yw] - 
     7*G[{1}, yu^(-1)]*G[{1/(yu*yv)}, yw]*G[{1, yu^(-1), yu^(-1)}, yw] + 
     7*G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{1, yu^(-1), yu^(-1)}, yw] - 
     7*G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{1, yu^(-1), yu^(-1)}, yw] - 
     G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{1, yu^(-1), yu^(-1)}, yw] - 
     2*G[{0, 1}, yv^(-1)]*G[{1, yu^(-1), yu^(-1)}, yw] - 
     2*G[{0, 1}, yw]*G[{1, yu^(-1), yu^(-1)}, yw] + 
     2*G[{0, yu^(-1)}, yw]*G[{1, yu^(-1), yu^(-1)}, yw] + 
     2*G[{0, yu}, yv^(-1)]*G[{1, yu^(-1), yu^(-1)}, yw] + 
     2*G[{0, yv^(-1)}, yw]*G[{1, yu^(-1), yu^(-1)}, yw] - 
     2*G[{0, 1/(yu*yv)}, yw]*G[{1, yu^(-1), yu^(-1)}, yw] - 
     4*G[{1, yu^(-1)}, yw]*G[{1, yu^(-1), yu^(-1)}, yw] - 
     2*G[{1, yu}, yv^(-1)]*G[{1, yu^(-1), yu^(-1)}, yw] + 
     5*G[{1, yv^(-1)}, yw]*G[{1, yu^(-1), yu^(-1)}, yw] - 
     5*G[{1, 1/(yu*yv)}, yw]*G[{1, yu^(-1), yu^(-1)}, yw] - 
     5*G[{yv^(-1), 1/(yu*yv)}, yw]*G[{1, yu^(-1), yu^(-1)}, yw] - 
     (7*Pi^2*G[{1, yu^(-1), yv^(-1)}, yw])/6 - 2*G[{0}, yu^(-1)]^2*
      G[{1, yu^(-1), yv^(-1)}, yw] - 4*G[{0}, yu^(-1)]*G[{0}, yv^(-1)]*
      G[{1, yu^(-1), yv^(-1)}, yw] - 2*G[{0}, yv^(-1)]^2*
      G[{1, yu^(-1), yv^(-1)}, yw] + 4*G[{0}, yu^(-1)]*G[{0}, yw]*
      G[{1, yu^(-1), yv^(-1)}, yw] + 4*G[{0}, yv^(-1)]*G[{0}, yw]*
      G[{1, yu^(-1), yv^(-1)}, yw] - 2*G[{0}, yw]^2*G[{1, yu^(-1), yv^(-1)}, 
       yw] + 6*G[{0}, yu^(-1)]*G[{1}, yu^(-1)]*G[{1, yu^(-1), yv^(-1)}, yw] + 
     6*G[{0}, yv^(-1)]*G[{1}, yu^(-1)]*G[{1, yu^(-1), yv^(-1)}, yw] - 
     6*G[{0}, yw]*G[{1}, yu^(-1)]*G[{1, yu^(-1), yv^(-1)}, yw] - 
     4*G[{1}, yu^(-1)]^2*G[{1, yu^(-1), yv^(-1)}, yw] + 
     6*G[{0}, yu^(-1)]*G[{1}, yv^(-1)]*G[{1, yu^(-1), yv^(-1)}, yw] + 
     6*G[{0}, yv^(-1)]*G[{1}, yv^(-1)]*G[{1, yu^(-1), yv^(-1)}, yw] - 
     6*G[{0}, yw]*G[{1}, yv^(-1)]*G[{1, yu^(-1), yv^(-1)}, yw] - 
     7*G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*G[{1, yu^(-1), yv^(-1)}, yw] - 
     4*G[{1}, yv^(-1)]^2*G[{1, yu^(-1), yv^(-1)}, yw] + 
     3*G[{0}, yu^(-1)]*G[{1}, yw]*G[{1, yu^(-1), yv^(-1)}, yw] + 
     3*G[{0}, yv^(-1)]*G[{1}, yw]*G[{1, yu^(-1), yv^(-1)}, yw] - 
     3*G[{0}, yw]*G[{1}, yw]*G[{1, yu^(-1), yv^(-1)}, yw] - 
     G[{1}, yu^(-1)]*G[{1}, yw]*G[{1, yu^(-1), yv^(-1)}, yw] - 
     G[{1}, yv^(-1)]*G[{1}, yw]*G[{1, yu^(-1), yv^(-1)}, yw] + 
     2*G[{1}, yw]^2*G[{1, yu^(-1), yv^(-1)}, yw] - 
     2*G[{0}, yu^(-1)]*G[{yu^(-1)}, yw]*G[{1, yu^(-1), yv^(-1)}, yw] - 
     2*G[{0}, yv^(-1)]*G[{yu^(-1)}, yw]*G[{1, yu^(-1), yv^(-1)}, yw] + 
     2*G[{0}, yw]*G[{yu^(-1)}, yw]*G[{1, yu^(-1), yv^(-1)}, yw] + 
     2*G[{1}, yu^(-1)]*G[{yu^(-1)}, yw]*G[{1, yu^(-1), yv^(-1)}, yw] - 
     3*G[{1}, yv^(-1)]*G[{yu^(-1)}, yw]*G[{1, yu^(-1), yv^(-1)}, yw] - 
     5*G[{1}, yw]*G[{yu^(-1)}, yw]*G[{1, yu^(-1), yv^(-1)}, yw] + 
     (7*G[{yu^(-1)}, yw]^2*G[{1, yu^(-1), yv^(-1)}, yw])/2 - 
     4*G[{0}, yu^(-1)]*G[{yu}, yv^(-1)]*G[{1, yu^(-1), yv^(-1)}, yw] - 
     4*G[{0}, yv^(-1)]*G[{yu}, yv^(-1)]*G[{1, yu^(-1), yv^(-1)}, yw] + 
     4*G[{0}, yw]*G[{yu}, yv^(-1)]*G[{1, yu^(-1), yv^(-1)}, yw] + 
     3*G[{1}, yu^(-1)]*G[{yu}, yv^(-1)]*G[{1, yu^(-1), yv^(-1)}, yw] + 
     3*G[{1}, yv^(-1)]*G[{yu}, yv^(-1)]*G[{1, yu^(-1), yv^(-1)}, yw] - 
     4*G[{1}, yw]*G[{yu}, yv^(-1)]*G[{1, yu^(-1), yv^(-1)}, yw] + 
     5*G[{yu^(-1)}, yw]*G[{yu}, yv^(-1)]*G[{1, yu^(-1), yv^(-1)}, yw] + 
     G[{yu}, yv^(-1)]^2*G[{1, yu^(-1), yv^(-1)}, yw] - 
     2*G[{0}, yu^(-1)]*G[{yv^(-1)}, yw]*G[{1, yu^(-1), yv^(-1)}, yw] - 
     2*G[{0}, yv^(-1)]*G[{yv^(-1)}, yw]*G[{1, yu^(-1), yv^(-1)}, yw] + 
     2*G[{0}, yw]*G[{yv^(-1)}, yw]*G[{1, yu^(-1), yv^(-1)}, yw] - 
     3*G[{1}, yu^(-1)]*G[{yv^(-1)}, yw]*G[{1, yu^(-1), yv^(-1)}, yw] + 
     2*G[{1}, yv^(-1)]*G[{yv^(-1)}, yw]*G[{1, yu^(-1), yv^(-1)}, yw] - 
     5*G[{1}, yw]*G[{yv^(-1)}, yw]*G[{1, yu^(-1), yv^(-1)}, yw] + 
     2*G[{yu^(-1)}, yw]*G[{yv^(-1)}, yw]*G[{1, yu^(-1), yv^(-1)}, yw] + 
     5*G[{yu}, yv^(-1)]*G[{yv^(-1)}, yw]*G[{1, yu^(-1), yv^(-1)}, yw] + 
     (7*G[{yv^(-1)}, yw]^2*G[{1, yu^(-1), yv^(-1)}, yw])/2 + 
     4*G[{0}, yu^(-1)]*G[{1/(yu*yv)}, yw]*G[{1, yu^(-1), yv^(-1)}, yw] + 
     4*G[{0}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{1, yu^(-1), yv^(-1)}, yw] - 
     4*G[{0}, yw]*G[{1/(yu*yv)}, yw]*G[{1, yu^(-1), yv^(-1)}, yw] - 
     G[{1}, yu^(-1)]*G[{1/(yu*yv)}, yw]*G[{1, yu^(-1), yv^(-1)}, yw] - 
     G[{1}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{1, yu^(-1), yv^(-1)}, yw] + 
     6*G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{1, yu^(-1), yv^(-1)}, yw] - 
     7*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{1, yu^(-1), yv^(-1)}, yw] - 
     6*G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{1, yu^(-1), yv^(-1)}, yw] - 
     7*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{1, yu^(-1), yv^(-1)}, yw] + 
     3*G[{1/(yu*yv)}, yw]^2*G[{1, yu^(-1), yv^(-1)}, yw] - 
     G[{0, 1}, yu^(-1)]*G[{1, yu^(-1), yv^(-1)}, yw] - 
     G[{0, 1}, yv^(-1)]*G[{1, yu^(-1), yv^(-1)}, yw] - 
     G[{0, 1}, yw]*G[{1, yu^(-1), yv^(-1)}, yw] + G[{0, yu^(-1)}, yw]*
      G[{1, yu^(-1), yv^(-1)}, yw] + G[{0, yu}, yv^(-1)]*
      G[{1, yu^(-1), yv^(-1)}, yw] + G[{0, yv^(-1)}, yw]*
      G[{1, yu^(-1), yv^(-1)}, yw] - G[{0, 1/(yu*yv)}, yw]*
      G[{1, yu^(-1), yv^(-1)}, yw] - 2*G[{1, yu^(-1)}, yw]*
      G[{1, yu^(-1), yv^(-1)}, yw] + 5*G[{1, yv^(-1)}, yw]*
      G[{1, yu^(-1), yv^(-1)}, yw] - 6*G[{1, 1/(yu*yv)}, yw]*
      G[{1, yu^(-1), yv^(-1)}, yw] + G[{yu^(-1), 1/(yu*yv)}, yw]*
      G[{1, yu^(-1), yv^(-1)}, yw] + G[{yv^(-1), 1/(yu*yv)}, yw]*
      G[{1, yu^(-1), yv^(-1)}, yw] + (Pi^2*G[{1, yu^(-1), 1/(yu*yv)}, yw])/
      2 + 2*G[{0}, yu^(-1)]^2*G[{1, yu^(-1), 1/(yu*yv)}, yw] + 
     4*G[{0}, yu^(-1)]*G[{0}, yv^(-1)]*G[{1, yu^(-1), 1/(yu*yv)}, yw] + 
     2*G[{0}, yv^(-1)]^2*G[{1, yu^(-1), 1/(yu*yv)}, yw] - 
     4*G[{0}, yu^(-1)]*G[{0}, yw]*G[{1, yu^(-1), 1/(yu*yv)}, yw] - 
     4*G[{0}, yv^(-1)]*G[{0}, yw]*G[{1, yu^(-1), 1/(yu*yv)}, yw] + 
     2*G[{0}, yw]^2*G[{1, yu^(-1), 1/(yu*yv)}, yw] - 
     6*G[{0}, yu^(-1)]*G[{1}, yu^(-1)]*G[{1, yu^(-1), 1/(yu*yv)}, yw] - 
     6*G[{0}, yv^(-1)]*G[{1}, yu^(-1)]*G[{1, yu^(-1), 1/(yu*yv)}, yw] + 
     6*G[{0}, yw]*G[{1}, yu^(-1)]*G[{1, yu^(-1), 1/(yu*yv)}, yw] + 
     4*G[{1}, yu^(-1)]^2*G[{1, yu^(-1), 1/(yu*yv)}, yw] - 
     4*G[{0}, yu^(-1)]*G[{1}, yv^(-1)]*G[{1, yu^(-1), 1/(yu*yv)}, yw] - 
     4*G[{0}, yv^(-1)]*G[{1}, yv^(-1)]*G[{1, yu^(-1), 1/(yu*yv)}, yw] + 
     4*G[{0}, yw]*G[{1}, yv^(-1)]*G[{1, yu^(-1), 1/(yu*yv)}, yw] + 
     4*G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*G[{1, yu^(-1), 1/(yu*yv)}, yw] + 
     G[{0}, yu^(-1)]*G[{1}, yw]*G[{1, yu^(-1), 1/(yu*yv)}, yw] + 
     G[{0}, yv^(-1)]*G[{1}, yw]*G[{1, yu^(-1), 1/(yu*yv)}, yw] - 
     G[{0}, yw]*G[{1}, yw]*G[{1, yu^(-1), 1/(yu*yv)}, yw] - 
     3*G[{1}, yu^(-1)]*G[{1}, yw]*G[{1, yu^(-1), 1/(yu*yv)}, yw] - 
     7*G[{1}, yv^(-1)]*G[{1}, yw]*G[{1, yu^(-1), 1/(yu*yv)}, yw] - 
     4*G[{1}, yw]^2*G[{1, yu^(-1), 1/(yu*yv)}, yw] + 
     6*G[{0}, yu^(-1)]*G[{yu^(-1)}, yw]*G[{1, yu^(-1), 1/(yu*yv)}, yw] + 
     6*G[{0}, yv^(-1)]*G[{yu^(-1)}, yw]*G[{1, yu^(-1), 1/(yu*yv)}, yw] - 
     6*G[{0}, yw]*G[{yu^(-1)}, yw]*G[{1, yu^(-1), 1/(yu*yv)}, yw] - 
     6*G[{1}, yu^(-1)]*G[{yu^(-1)}, yw]*G[{1, yu^(-1), 1/(yu*yv)}, yw] + 
     6*G[{1}, yw]*G[{yu^(-1)}, yw]*G[{1, yu^(-1), 1/(yu*yv)}, yw] + 
     2*G[{0}, yu^(-1)]*G[{yu}, yv^(-1)]*G[{1, yu^(-1), 1/(yu*yv)}, yw] + 
     2*G[{0}, yv^(-1)]*G[{yu}, yv^(-1)]*G[{1, yu^(-1), 1/(yu*yv)}, yw] - 
     2*G[{0}, yw]*G[{yu}, yv^(-1)]*G[{1, yu^(-1), 1/(yu*yv)}, yw] + 
     G[{1}, yv^(-1)]*G[{yu}, yv^(-1)]*G[{1, yu^(-1), 1/(yu*yv)}, yw] + 
     8*G[{1}, yw]*G[{yu}, yv^(-1)]*G[{1, yu^(-1), 1/(yu*yv)}, yw] - 
     6*G[{yu^(-1)}, yw]*G[{yu}, yv^(-1)]*G[{1, yu^(-1), 1/(yu*yv)}, yw] - 
     (5*G[{yu}, yv^(-1)]^2*G[{1, yu^(-1), 1/(yu*yv)}, yw])/2 + 
     4*G[{0}, yu^(-1)]*G[{yv^(-1)}, yw]*G[{1, yu^(-1), 1/(yu*yv)}, yw] + 
     4*G[{0}, yv^(-1)]*G[{yv^(-1)}, yw]*G[{1, yu^(-1), 1/(yu*yv)}, yw] - 
     4*G[{0}, yw]*G[{yv^(-1)}, yw]*G[{1, yu^(-1), 1/(yu*yv)}, yw] - 
     2*G[{1}, yu^(-1)]*G[{yv^(-1)}, yw]*G[{1, yu^(-1), 1/(yu*yv)}, yw] - 
     2*G[{1}, yv^(-1)]*G[{yv^(-1)}, yw]*G[{1, yu^(-1), 1/(yu*yv)}, yw] + 
     4*G[{1}, yw]*G[{yv^(-1)}, yw]*G[{1, yu^(-1), 1/(yu*yv)}, yw] - 
     4*G[{yu}, yv^(-1)]*G[{yv^(-1)}, yw]*G[{1, yu^(-1), 1/(yu*yv)}, yw] - 
     6*G[{0}, yu^(-1)]*G[{1/(yu*yv)}, yw]*G[{1, yu^(-1), 1/(yu*yv)}, yw] - 
     6*G[{0}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{1, yu^(-1), 1/(yu*yv)}, yw] + 
     6*G[{0}, yw]*G[{1/(yu*yv)}, yw]*G[{1, yu^(-1), 1/(yu*yv)}, yw] + 
     6*G[{1}, yu^(-1)]*G[{1/(yu*yv)}, yw]*G[{1, yu^(-1), 1/(yu*yv)}, yw] - 
     6*G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{1, yu^(-1), 1/(yu*yv)}, yw] + 
     6*G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{1, yu^(-1), 1/(yu*yv)}, yw] + 
     3*G[{0, 1}, yv^(-1)]*G[{1, yu^(-1), 1/(yu*yv)}, yw] + 
     3*G[{0, 1}, yw]*G[{1, yu^(-1), 1/(yu*yv)}, yw] - 
     3*G[{0, yu^(-1)}, yw]*G[{1, yu^(-1), 1/(yu*yv)}, yw] - 
     3*G[{0, yu}, yv^(-1)]*G[{1, yu^(-1), 1/(yu*yv)}, yw] - 
     3*G[{0, yv^(-1)}, yw]*G[{1, yu^(-1), 1/(yu*yv)}, yw] + 
     3*G[{0, 1/(yu*yv)}, yw]*G[{1, yu^(-1), 1/(yu*yv)}, yw] + 
     6*G[{1, yu^(-1)}, yw]*G[{1, yu^(-1), 1/(yu*yv)}, yw] + 
     3*G[{1, yu}, yv^(-1)]*G[{1, yu^(-1), 1/(yu*yv)}, yw] + 
     6*G[{1, yv^(-1)}, yw]*G[{1, yu^(-1), 1/(yu*yv)}, yw] + 
     2*G[{1, 1/(yu*yv)}, yw]*G[{1, yu^(-1), 1/(yu*yv)}, yw] + 
     2*G[{yv^(-1), 1/(yu*yv)}, yw]*G[{1, yu^(-1), 1/(yu*yv)}, yw] - 
     2*G[{1}, yu^(-1)]^2*G[{1, yu, yu}, yv^(-1)] + 
     2*G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*G[{1, yu, yu}, yv^(-1)] + 
     2*G[{1}, yv^(-1)]^2*G[{1, yu, yu}, yv^(-1)] + 
     8*G[{1}, yu^(-1)]*G[{yu^(-1)}, yw]*G[{1, yu, yu}, yv^(-1)] + 
     G[{1}, yv^(-1)]*G[{yu^(-1)}, yw]*G[{1, yu, yu}, yv^(-1)] - 
     G[{1}, yw]*G[{yu^(-1)}, yw]*G[{1, yu, yu}, yv^(-1)] - 
     (5*G[{yu^(-1)}, yw]^2*G[{1, yu, yu}, yv^(-1)])/2 + 
     7*G[{1}, yu^(-1)]*G[{yu}, yv^(-1)]*G[{1, yu, yu}, yv^(-1)] - 
     7*G[{1}, yv^(-1)]*G[{yu}, yv^(-1)]*G[{1, yu, yu}, yv^(-1)] + 
     3*G[{yu^(-1)}, yw]*G[{yu}, yv^(-1)]*G[{1, yu, yu}, yv^(-1)] - 
     G[{1}, yu^(-1)]*G[{yv^(-1)}, yw]*G[{1, yu, yu}, yv^(-1)] - 
     8*G[{1}, yv^(-1)]*G[{yv^(-1)}, yw]*G[{1, yu, yu}, yv^(-1)] + 
     G[{1}, yw]*G[{yv^(-1)}, yw]*G[{1, yu, yu}, yv^(-1)] - 
     3*G[{yu}, yv^(-1)]*G[{yv^(-1)}, yw]*G[{1, yu, yu}, yv^(-1)] + 
     (5*G[{yv^(-1)}, yw]^2*G[{1, yu, yu}, yv^(-1)])/2 - 
     7*G[{1}, yu^(-1)]*G[{1/(yu*yv)}, yw]*G[{1, yu, yu}, yv^(-1)] + 
     7*G[{1}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{1, yu, yu}, yv^(-1)] + 
     G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{1, yu, yu}, yv^(-1)] - 
     G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{1, yu, yu}, yv^(-1)] + 
     2*G[{0, 1}, yu^(-1)]*G[{1, yu, yu}, yv^(-1)] - 
     2*G[{0, 1}, yv^(-1)]*G[{1, yu, yu}, yv^(-1)] + 
     2*G[{0, yu}, yv^(-1)]*G[{1, yu, yu}, yv^(-1)] + 
     5*G[{1, yu^(-1)}, yw]*G[{1, yu, yu}, yv^(-1)] - 
     4*G[{1, yu}, yv^(-1)]*G[{1, yu, yu}, yv^(-1)] - 
     5*G[{1, yv^(-1)}, yw]*G[{1, yu, yu}, yv^(-1)] + 
     5*G[{yu^(-1), 1/(yu*yv)}, yw]*G[{1, yu, yu}, yv^(-1)] - 
     5*G[{yv^(-1), 1/(yu*yv)}, yw]*G[{1, yu, yu}, yv^(-1)] - 
     (7*Pi^2*G[{1, yv^(-1), yu^(-1)}, yw])/6 - 2*G[{0}, yu^(-1)]^2*
      G[{1, yv^(-1), yu^(-1)}, yw] - 4*G[{0}, yu^(-1)]*G[{0}, yv^(-1)]*
      G[{1, yv^(-1), yu^(-1)}, yw] - 2*G[{0}, yv^(-1)]^2*
      G[{1, yv^(-1), yu^(-1)}, yw] + 4*G[{0}, yu^(-1)]*G[{0}, yw]*
      G[{1, yv^(-1), yu^(-1)}, yw] + 4*G[{0}, yv^(-1)]*G[{0}, yw]*
      G[{1, yv^(-1), yu^(-1)}, yw] - 2*G[{0}, yw]^2*G[{1, yv^(-1), yu^(-1)}, 
       yw] + 6*G[{0}, yu^(-1)]*G[{1}, yu^(-1)]*G[{1, yv^(-1), yu^(-1)}, yw] + 
     6*G[{0}, yv^(-1)]*G[{1}, yu^(-1)]*G[{1, yv^(-1), yu^(-1)}, yw] - 
     6*G[{0}, yw]*G[{1}, yu^(-1)]*G[{1, yv^(-1), yu^(-1)}, yw] - 
     4*G[{1}, yu^(-1)]^2*G[{1, yv^(-1), yu^(-1)}, yw] + 
     6*G[{0}, yu^(-1)]*G[{1}, yv^(-1)]*G[{1, yv^(-1), yu^(-1)}, yw] + 
     6*G[{0}, yv^(-1)]*G[{1}, yv^(-1)]*G[{1, yv^(-1), yu^(-1)}, yw] - 
     6*G[{0}, yw]*G[{1}, yv^(-1)]*G[{1, yv^(-1), yu^(-1)}, yw] - 
     7*G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*G[{1, yv^(-1), yu^(-1)}, yw] - 
     4*G[{1}, yv^(-1)]^2*G[{1, yv^(-1), yu^(-1)}, yw] + 
     3*G[{0}, yu^(-1)]*G[{1}, yw]*G[{1, yv^(-1), yu^(-1)}, yw] + 
     3*G[{0}, yv^(-1)]*G[{1}, yw]*G[{1, yv^(-1), yu^(-1)}, yw] - 
     3*G[{0}, yw]*G[{1}, yw]*G[{1, yv^(-1), yu^(-1)}, yw] - 
     G[{1}, yu^(-1)]*G[{1}, yw]*G[{1, yv^(-1), yu^(-1)}, yw] - 
     G[{1}, yv^(-1)]*G[{1}, yw]*G[{1, yv^(-1), yu^(-1)}, yw] + 
     2*G[{1}, yw]^2*G[{1, yv^(-1), yu^(-1)}, yw] - 
     2*G[{0}, yu^(-1)]*G[{yu^(-1)}, yw]*G[{1, yv^(-1), yu^(-1)}, yw] - 
     2*G[{0}, yv^(-1)]*G[{yu^(-1)}, yw]*G[{1, yv^(-1), yu^(-1)}, yw] + 
     2*G[{0}, yw]*G[{yu^(-1)}, yw]*G[{1, yv^(-1), yu^(-1)}, yw] + 
     2*G[{1}, yu^(-1)]*G[{yu^(-1)}, yw]*G[{1, yv^(-1), yu^(-1)}, yw] - 
     3*G[{1}, yv^(-1)]*G[{yu^(-1)}, yw]*G[{1, yv^(-1), yu^(-1)}, yw] - 
     5*G[{1}, yw]*G[{yu^(-1)}, yw]*G[{1, yv^(-1), yu^(-1)}, yw] + 
     (7*G[{yu^(-1)}, yw]^2*G[{1, yv^(-1), yu^(-1)}, yw])/2 - 
     4*G[{0}, yu^(-1)]*G[{yu}, yv^(-1)]*G[{1, yv^(-1), yu^(-1)}, yw] - 
     4*G[{0}, yv^(-1)]*G[{yu}, yv^(-1)]*G[{1, yv^(-1), yu^(-1)}, yw] + 
     4*G[{0}, yw]*G[{yu}, yv^(-1)]*G[{1, yv^(-1), yu^(-1)}, yw] + 
     3*G[{1}, yu^(-1)]*G[{yu}, yv^(-1)]*G[{1, yv^(-1), yu^(-1)}, yw] + 
     3*G[{1}, yv^(-1)]*G[{yu}, yv^(-1)]*G[{1, yv^(-1), yu^(-1)}, yw] - 
     4*G[{1}, yw]*G[{yu}, yv^(-1)]*G[{1, yv^(-1), yu^(-1)}, yw] + 
     5*G[{yu^(-1)}, yw]*G[{yu}, yv^(-1)]*G[{1, yv^(-1), yu^(-1)}, yw] + 
     G[{yu}, yv^(-1)]^2*G[{1, yv^(-1), yu^(-1)}, yw] - 
     2*G[{0}, yu^(-1)]*G[{yv^(-1)}, yw]*G[{1, yv^(-1), yu^(-1)}, yw] - 
     2*G[{0}, yv^(-1)]*G[{yv^(-1)}, yw]*G[{1, yv^(-1), yu^(-1)}, yw] + 
     2*G[{0}, yw]*G[{yv^(-1)}, yw]*G[{1, yv^(-1), yu^(-1)}, yw] - 
     3*G[{1}, yu^(-1)]*G[{yv^(-1)}, yw]*G[{1, yv^(-1), yu^(-1)}, yw] + 
     2*G[{1}, yv^(-1)]*G[{yv^(-1)}, yw]*G[{1, yv^(-1), yu^(-1)}, yw] - 
     5*G[{1}, yw]*G[{yv^(-1)}, yw]*G[{1, yv^(-1), yu^(-1)}, yw] + 
     2*G[{yu^(-1)}, yw]*G[{yv^(-1)}, yw]*G[{1, yv^(-1), yu^(-1)}, yw] + 
     5*G[{yu}, yv^(-1)]*G[{yv^(-1)}, yw]*G[{1, yv^(-1), yu^(-1)}, yw] + 
     (7*G[{yv^(-1)}, yw]^2*G[{1, yv^(-1), yu^(-1)}, yw])/2 + 
     4*G[{0}, yu^(-1)]*G[{1/(yu*yv)}, yw]*G[{1, yv^(-1), yu^(-1)}, yw] + 
     4*G[{0}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{1, yv^(-1), yu^(-1)}, yw] - 
     4*G[{0}, yw]*G[{1/(yu*yv)}, yw]*G[{1, yv^(-1), yu^(-1)}, yw] - 
     G[{1}, yu^(-1)]*G[{1/(yu*yv)}, yw]*G[{1, yv^(-1), yu^(-1)}, yw] - 
     G[{1}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{1, yv^(-1), yu^(-1)}, yw] + 
     6*G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{1, yv^(-1), yu^(-1)}, yw] - 
     7*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{1, yv^(-1), yu^(-1)}, yw] - 
     6*G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{1, yv^(-1), yu^(-1)}, yw] - 
     7*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{1, yv^(-1), yu^(-1)}, yw] + 
     3*G[{1/(yu*yv)}, yw]^2*G[{1, yv^(-1), yu^(-1)}, yw] - 
     G[{0, 1}, yu^(-1)]*G[{1, yv^(-1), yu^(-1)}, yw] - 
     G[{0, 1}, yv^(-1)]*G[{1, yv^(-1), yu^(-1)}, yw] - 
     G[{0, 1}, yw]*G[{1, yv^(-1), yu^(-1)}, yw] + G[{0, yu^(-1)}, yw]*
      G[{1, yv^(-1), yu^(-1)}, yw] + G[{0, yu}, yv^(-1)]*
      G[{1, yv^(-1), yu^(-1)}, yw] + G[{0, yv^(-1)}, yw]*
      G[{1, yv^(-1), yu^(-1)}, yw] - G[{0, 1/(yu*yv)}, yw]*
      G[{1, yv^(-1), yu^(-1)}, yw] - 2*G[{1, yu^(-1)}, yw]*
      G[{1, yv^(-1), yu^(-1)}, yw] - 2*G[{1, yv^(-1)}, yw]*
      G[{1, yv^(-1), yu^(-1)}, yw] - 6*G[{1, 1/(yu*yv)}, yw]*
      G[{1, yv^(-1), yu^(-1)}, yw] + G[{yu^(-1), 1/(yu*yv)}, yw]*
      G[{1, yv^(-1), yu^(-1)}, yw] + G[{yv^(-1), 1/(yu*yv)}, yw]*
      G[{1, yv^(-1), yu^(-1)}, yw] - (Pi^2*G[{1, yv^(-1), yv^(-1)}, yw])/3 - 
     2*G[{0}, yu^(-1)]^2*G[{1, yv^(-1), yv^(-1)}, yw] - 
     4*G[{0}, yu^(-1)]*G[{0}, yv^(-1)]*G[{1, yv^(-1), yv^(-1)}, yw] - 
     2*G[{0}, yv^(-1)]^2*G[{1, yv^(-1), yv^(-1)}, yw] + 
     4*G[{0}, yu^(-1)]*G[{0}, yw]*G[{1, yv^(-1), yv^(-1)}, yw] + 
     4*G[{0}, yv^(-1)]*G[{0}, yw]*G[{1, yv^(-1), yv^(-1)}, yw] - 
     2*G[{0}, yw]^2*G[{1, yv^(-1), yv^(-1)}, yw] + 
     4*G[{0}, yu^(-1)]*G[{1}, yu^(-1)]*G[{1, yv^(-1), yv^(-1)}, yw] + 
     4*G[{0}, yv^(-1)]*G[{1}, yu^(-1)]*G[{1, yv^(-1), yv^(-1)}, yw] - 
     4*G[{0}, yw]*G[{1}, yu^(-1)]*G[{1, yv^(-1), yv^(-1)}, yw] + 
     4*G[{0}, yu^(-1)]*G[{1}, yv^(-1)]*G[{1, yv^(-1), yv^(-1)}, yw] + 
     4*G[{0}, yv^(-1)]*G[{1}, yv^(-1)]*G[{1, yv^(-1), yv^(-1)}, yw] - 
     4*G[{0}, yw]*G[{1}, yv^(-1)]*G[{1, yv^(-1), yv^(-1)}, yw] - 
     6*G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*G[{1, yv^(-1), yv^(-1)}, yw] - 
     2*G[{1}, yv^(-1)]^2*G[{1, yv^(-1), yv^(-1)}, yw] - 
     2*G[{0}, yu^(-1)]*G[{1}, yw]*G[{1, yv^(-1), yv^(-1)}, yw] - 
     2*G[{0}, yv^(-1)]*G[{1}, yw]*G[{1, yv^(-1), yv^(-1)}, yw] + 
     2*G[{0}, yw]*G[{1}, yw]*G[{1, yv^(-1), yv^(-1)}, yw] + 
     6*G[{1}, yu^(-1)]*G[{1}, yw]*G[{1, yv^(-1), yv^(-1)}, yw] + 
     2*G[{1}, yv^(-1)]*G[{1}, yw]*G[{1, yv^(-1), yv^(-1)}, yw] + 
     2*G[{1}, yw]^2*G[{1, yv^(-1), yv^(-1)}, yw] + 
     G[{0}, yu^(-1)]*G[{yu^(-1)}, yw]*G[{1, yv^(-1), yv^(-1)}, yw] + 
     G[{0}, yv^(-1)]*G[{yu^(-1)}, yw]*G[{1, yv^(-1), yv^(-1)}, yw] - 
     G[{0}, yw]*G[{yu^(-1)}, yw]*G[{1, yv^(-1), yv^(-1)}, yw] - 
     9*G[{1}, yu^(-1)]*G[{yu^(-1)}, yw]*G[{1, yv^(-1), yv^(-1)}, yw] - 
     G[{1}, yv^(-1)]*G[{yu^(-1)}, yw]*G[{1, yv^(-1), yv^(-1)}, yw] - 
     8*G[{1}, yw]*G[{yu^(-1)}, yw]*G[{1, yv^(-1), yv^(-1)}, yw] + 
     (5*G[{yu^(-1)}, yw]^2*G[{1, yv^(-1), yv^(-1)}, yw])/2 - 
     2*G[{1}, yu^(-1)]*G[{yu}, yv^(-1)]*G[{1, yv^(-1), yv^(-1)}, yw] - 
     4*G[{1}, yw]*G[{yu}, yv^(-1)]*G[{1, yv^(-1), yv^(-1)}, yw] + 
     8*G[{yu^(-1)}, yw]*G[{yu}, yv^(-1)]*G[{1, yv^(-1), yv^(-1)}, yw] + 
     G[{yu}, yv^(-1)]^2*G[{1, yv^(-1), yv^(-1)}, yw] - 
     7*G[{0}, yu^(-1)]*G[{yv^(-1)}, yw]*G[{1, yv^(-1), yv^(-1)}, yw] - 
     7*G[{0}, yv^(-1)]*G[{yv^(-1)}, yw]*G[{1, yv^(-1), yv^(-1)}, yw] + 
     7*G[{0}, yw]*G[{yv^(-1)}, yw]*G[{1, yv^(-1), yv^(-1)}, yw] + 
     7*G[{1}, yv^(-1)]*G[{yv^(-1)}, yw]*G[{1, yv^(-1), yv^(-1)}, yw] - 
     7*G[{1}, yw]*G[{yv^(-1)}, yw]*G[{1, yv^(-1), yv^(-1)}, yw] - 
     3*G[{yu^(-1)}, yw]*G[{yv^(-1)}, yw]*G[{1, yv^(-1), yv^(-1)}, yw] + 
     7*G[{yu}, yv^(-1)]*G[{yv^(-1)}, yw]*G[{1, yv^(-1), yv^(-1)}, yw] + 
     7*G[{0}, yu^(-1)]*G[{1/(yu*yv)}, yw]*G[{1, yv^(-1), yv^(-1)}, yw] + 
     7*G[{0}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{1, yv^(-1), yv^(-1)}, yw] - 
     7*G[{0}, yw]*G[{1/(yu*yv)}, yw]*G[{1, yv^(-1), yv^(-1)}, yw] - 
     7*G[{1}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{1, yv^(-1), yv^(-1)}, yw] + 
     7*G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{1, yv^(-1), yv^(-1)}, yw] - 
     G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{1, yv^(-1), yv^(-1)}, yw] - 
     7*G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{1, yv^(-1), yv^(-1)}, yw] - 
     2*G[{0, 1}, yu^(-1)]*G[{1, yv^(-1), yv^(-1)}, yw] - 
     2*G[{0, 1}, yw]*G[{1, yv^(-1), yv^(-1)}, yw] + 
     2*G[{0, yu^(-1)}, yw]*G[{1, yv^(-1), yv^(-1)}, yw] + 
     2*G[{0, yv^(-1)}, yw]*G[{1, yv^(-1), yv^(-1)}, yw] - 
     2*G[{0, 1/(yu*yv)}, yw]*G[{1, yv^(-1), yv^(-1)}, yw] - 
     2*G[{1, yu^(-1)}, yw]*G[{1, yv^(-1), yv^(-1)}, yw] + 
     2*G[{1, yu}, yv^(-1)]*G[{1, yv^(-1), yv^(-1)}, yw] - 
     4*G[{1, yv^(-1)}, yw]*G[{1, yv^(-1), yv^(-1)}, yw] - 
     5*G[{1, 1/(yu*yv)}, yw]*G[{1, yv^(-1), yv^(-1)}, yw] - 
     5*G[{yu^(-1), 1/(yu*yv)}, yw]*G[{1, yv^(-1), yv^(-1)}, yw] + 
     (Pi^2*G[{1, yv^(-1), 1/(yu*yv)}, yw])/2 + 2*G[{0}, yu^(-1)]^2*
      G[{1, yv^(-1), 1/(yu*yv)}, yw] + 4*G[{0}, yu^(-1)]*G[{0}, yv^(-1)]*
      G[{1, yv^(-1), 1/(yu*yv)}, yw] + 2*G[{0}, yv^(-1)]^2*
      G[{1, yv^(-1), 1/(yu*yv)}, yw] - 4*G[{0}, yu^(-1)]*G[{0}, yw]*
      G[{1, yv^(-1), 1/(yu*yv)}, yw] - 4*G[{0}, yv^(-1)]*G[{0}, yw]*
      G[{1, yv^(-1), 1/(yu*yv)}, yw] + 2*G[{0}, yw]^2*
      G[{1, yv^(-1), 1/(yu*yv)}, yw] - 4*G[{0}, yu^(-1)]*G[{1}, yu^(-1)]*
      G[{1, yv^(-1), 1/(yu*yv)}, yw] - 4*G[{0}, yv^(-1)]*G[{1}, yu^(-1)]*
      G[{1, yv^(-1), 1/(yu*yv)}, yw] + 4*G[{0}, yw]*G[{1}, yu^(-1)]*
      G[{1, yv^(-1), 1/(yu*yv)}, yw] - 6*G[{0}, yu^(-1)]*G[{1}, yv^(-1)]*
      G[{1, yv^(-1), 1/(yu*yv)}, yw] - 6*G[{0}, yv^(-1)]*G[{1}, yv^(-1)]*
      G[{1, yv^(-1), 1/(yu*yv)}, yw] + 6*G[{0}, yw]*G[{1}, yv^(-1)]*
      G[{1, yv^(-1), 1/(yu*yv)}, yw] + 7*G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*
      G[{1, yv^(-1), 1/(yu*yv)}, yw] + 4*G[{1}, yv^(-1)]^2*
      G[{1, yv^(-1), 1/(yu*yv)}, yw] + G[{0}, yu^(-1)]*G[{1}, yw]*
      G[{1, yv^(-1), 1/(yu*yv)}, yw] + G[{0}, yv^(-1)]*G[{1}, yw]*
      G[{1, yv^(-1), 1/(yu*yv)}, yw] - G[{0}, yw]*G[{1}, yw]*
      G[{1, yv^(-1), 1/(yu*yv)}, yw] - 7*G[{1}, yu^(-1)]*G[{1}, yw]*
      G[{1, yv^(-1), 1/(yu*yv)}, yw] - 3*G[{1}, yv^(-1)]*G[{1}, yw]*
      G[{1, yv^(-1), 1/(yu*yv)}, yw] - 4*G[{1}, yw]^2*
      G[{1, yv^(-1), 1/(yu*yv)}, yw] + 4*G[{0}, yu^(-1)]*G[{yu^(-1)}, yw]*
      G[{1, yv^(-1), 1/(yu*yv)}, yw] + 4*G[{0}, yv^(-1)]*G[{yu^(-1)}, yw]*
      G[{1, yv^(-1), 1/(yu*yv)}, yw] - 4*G[{0}, yw]*G[{yu^(-1)}, yw]*
      G[{1, yv^(-1), 1/(yu*yv)}, yw] - 2*G[{1}, yu^(-1)]*G[{yu^(-1)}, yw]*
      G[{1, yv^(-1), 1/(yu*yv)}, yw] - 2*G[{1}, yv^(-1)]*G[{yu^(-1)}, yw]*
      G[{1, yv^(-1), 1/(yu*yv)}, yw] + 4*G[{1}, yw]*G[{yu^(-1)}, yw]*
      G[{1, yv^(-1), 1/(yu*yv)}, yw] + 2*G[{0}, yu^(-1)]*G[{yu}, yv^(-1)]*
      G[{1, yv^(-1), 1/(yu*yv)}, yw] + 2*G[{0}, yv^(-1)]*G[{yu}, yv^(-1)]*
      G[{1, yv^(-1), 1/(yu*yv)}, yw] - 2*G[{0}, yw]*G[{yu}, yv^(-1)]*
      G[{1, yv^(-1), 1/(yu*yv)}, yw] + G[{1}, yu^(-1)]*G[{yu}, yv^(-1)]*
      G[{1, yv^(-1), 1/(yu*yv)}, yw] + 8*G[{1}, yw]*G[{yu}, yv^(-1)]*
      G[{1, yv^(-1), 1/(yu*yv)}, yw] - 4*G[{yu^(-1)}, yw]*G[{yu}, yv^(-1)]*
      G[{1, yv^(-1), 1/(yu*yv)}, yw] - 
     (5*G[{yu}, yv^(-1)]^2*G[{1, yv^(-1), 1/(yu*yv)}, yw])/2 + 
     6*G[{0}, yu^(-1)]*G[{yv^(-1)}, yw]*G[{1, yv^(-1), 1/(yu*yv)}, yw] + 
     6*G[{0}, yv^(-1)]*G[{yv^(-1)}, yw]*G[{1, yv^(-1), 1/(yu*yv)}, yw] - 
     6*G[{0}, yw]*G[{yv^(-1)}, yw]*G[{1, yv^(-1), 1/(yu*yv)}, yw] - 
     6*G[{1}, yv^(-1)]*G[{yv^(-1)}, yw]*G[{1, yv^(-1), 1/(yu*yv)}, yw] + 
     6*G[{1}, yw]*G[{yv^(-1)}, yw]*G[{1, yv^(-1), 1/(yu*yv)}, yw] - 
     6*G[{yu}, yv^(-1)]*G[{yv^(-1)}, yw]*G[{1, yv^(-1), 1/(yu*yv)}, yw] - 
     6*G[{0}, yu^(-1)]*G[{1/(yu*yv)}, yw]*G[{1, yv^(-1), 1/(yu*yv)}, yw] - 
     6*G[{0}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{1, yv^(-1), 1/(yu*yv)}, yw] + 
     6*G[{0}, yw]*G[{1/(yu*yv)}, yw]*G[{1, yv^(-1), 1/(yu*yv)}, yw] + 
     6*G[{1}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{1, yv^(-1), 1/(yu*yv)}, yw] - 
     6*G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{1, yv^(-1), 1/(yu*yv)}, yw] + 
     6*G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{1, yv^(-1), 1/(yu*yv)}, yw] + 
     3*G[{0, 1}, yu^(-1)]*G[{1, yv^(-1), 1/(yu*yv)}, yw] + 
     3*G[{0, 1}, yw]*G[{1, yv^(-1), 1/(yu*yv)}, yw] - 
     3*G[{0, yu^(-1)}, yw]*G[{1, yv^(-1), 1/(yu*yv)}, yw] - 
     3*G[{0, yv^(-1)}, yw]*G[{1, yv^(-1), 1/(yu*yv)}, yw] + 
     3*G[{0, 1/(yu*yv)}, yw]*G[{1, yv^(-1), 1/(yu*yv)}, yw] + 
     3*G[{1, yu^(-1)}, yw]*G[{1, yv^(-1), 1/(yu*yv)}, yw] - 
     3*G[{1, yu}, yv^(-1)]*G[{1, yv^(-1), 1/(yu*yv)}, yw] + 
     6*G[{1, yv^(-1)}, yw]*G[{1, yv^(-1), 1/(yu*yv)}, yw] + 
     2*G[{1, 1/(yu*yv)}, yw]*G[{1, yv^(-1), 1/(yu*yv)}, yw] + 
     2*G[{yu^(-1), 1/(yu*yv)}, yw]*G[{1, yv^(-1), 1/(yu*yv)}, yw] - 
     (5*Pi^2*G[{1, 1/(yu*yv), yu^(-1)}, yw])/6 - 2*G[{0}, yu^(-1)]*
      G[{1}, yu^(-1)]*G[{1, 1/(yu*yv), yu^(-1)}, yw] - 
     2*G[{0}, yv^(-1)]*G[{1}, yu^(-1)]*G[{1, 1/(yu*yv), yu^(-1)}, yw] + 
     2*G[{0}, yw]*G[{1}, yu^(-1)]*G[{1, 1/(yu*yv), yu^(-1)}, yw] + 
     2*G[{1}, yu^(-1)]^2*G[{1, 1/(yu*yv), yu^(-1)}, yw] + 
     2*G[{0}, yu^(-1)]*G[{1}, yv^(-1)]*G[{1, 1/(yu*yv), yu^(-1)}, yw] + 
     2*G[{0}, yv^(-1)]*G[{1}, yv^(-1)]*G[{1, 1/(yu*yv), yu^(-1)}, yw] - 
     2*G[{0}, yw]*G[{1}, yv^(-1)]*G[{1, 1/(yu*yv), yu^(-1)}, yw] - 
     3*G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*G[{1, 1/(yu*yv), yu^(-1)}, yw] - 
     4*G[{1}, yv^(-1)]^2*G[{1, 1/(yu*yv), yu^(-1)}, yw] + 
     G[{0}, yu^(-1)]*G[{1}, yw]*G[{1, 1/(yu*yv), yu^(-1)}, yw] + 
     G[{0}, yv^(-1)]*G[{1}, yw]*G[{1, 1/(yu*yv), yu^(-1)}, yw] - 
     G[{0}, yw]*G[{1}, yw]*G[{1, 1/(yu*yv), yu^(-1)}, yw] - 
     3*G[{1}, yu^(-1)]*G[{1}, yw]*G[{1, 1/(yu*yv), yu^(-1)}, yw] - 
     7*G[{1}, yv^(-1)]*G[{1}, yw]*G[{1, 1/(yu*yv), yu^(-1)}, yw] - 
     4*G[{1}, yw]^2*G[{1, 1/(yu*yv), yu^(-1)}, yw] + 
     5*G[{0}, yu^(-1)]*G[{yu^(-1)}, yw]*G[{1, 1/(yu*yv), yu^(-1)}, yw] + 
     5*G[{0}, yv^(-1)]*G[{yu^(-1)}, yw]*G[{1, 1/(yu*yv), yu^(-1)}, yw] - 
     5*G[{0}, yw]*G[{yu^(-1)}, yw]*G[{1, 1/(yu*yv), yu^(-1)}, yw] - 
     5*G[{1}, yu^(-1)]*G[{yu^(-1)}, yw]*G[{1, 1/(yu*yv), yu^(-1)}, yw] - 
     3*G[{1}, yv^(-1)]*G[{yu^(-1)}, yw]*G[{1, 1/(yu*yv), yu^(-1)}, yw] + 
     2*G[{1}, yw]*G[{yu^(-1)}, yw]*G[{1, 1/(yu*yv), yu^(-1)}, yw] + 
     (7*G[{yu^(-1)}, yw]^2*G[{1, 1/(yu*yv), yu^(-1)}, yw])/2 + 
     3*G[{1}, yu^(-1)]*G[{yu}, yv^(-1)]*G[{1, 1/(yu*yv), yu^(-1)}, yw] + 
     5*G[{1}, yv^(-1)]*G[{yu}, yv^(-1)]*G[{1, 1/(yu*yv), yu^(-1)}, yw] + 
     8*G[{1}, yw]*G[{yu}, yv^(-1)]*G[{1, 1/(yu*yv), yu^(-1)}, yw] - 
     2*G[{yu^(-1)}, yw]*G[{yu}, yv^(-1)]*G[{1, 1/(yu*yv), yu^(-1)}, yw] - 
     4*G[{yu}, yv^(-1)]^2*G[{1, 1/(yu*yv), yu^(-1)}, yw] + 
     G[{0}, yu^(-1)]*G[{yv^(-1)}, yw]*G[{1, 1/(yu*yv), yu^(-1)}, yw] + 
     G[{0}, yv^(-1)]*G[{yv^(-1)}, yw]*G[{1, 1/(yu*yv), yu^(-1)}, yw] - 
     G[{0}, yw]*G[{yv^(-1)}, yw]*G[{1, 1/(yu*yv), yu^(-1)}, yw] - 
     2*G[{1}, yu^(-1)]*G[{yv^(-1)}, yw]*G[{1, 1/(yu*yv), yu^(-1)}, yw] + 
     3*G[{1}, yv^(-1)]*G[{yv^(-1)}, yw]*G[{1, 1/(yu*yv), yu^(-1)}, yw] + 
     3*G[{1}, yw]*G[{yv^(-1)}, yw]*G[{1, 1/(yu*yv), yu^(-1)}, yw] + 
     5*G[{yu^(-1)}, yw]*G[{yv^(-1)}, yw]*G[{1, 1/(yu*yv), yu^(-1)}, yw] - 
     3*G[{yu}, yv^(-1)]*G[{yv^(-1)}, yw]*G[{1, 1/(yu*yv), yu^(-1)}, yw] + 
     G[{yv^(-1)}, yw]^2*G[{1, 1/(yu*yv), yu^(-1)}, yw] - 
     3*G[{0}, yu^(-1)]*G[{1/(yu*yv)}, yw]*G[{1, 1/(yu*yv), yu^(-1)}, yw] - 
     3*G[{0}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{1, 1/(yu*yv), yu^(-1)}, yw] + 
     3*G[{0}, yw]*G[{1/(yu*yv)}, yw]*G[{1, 1/(yu*yv), yu^(-1)}, yw] + 
     6*G[{1}, yu^(-1)]*G[{1/(yu*yv)}, yw]*G[{1, 1/(yu*yv), yu^(-1)}, yw] - 
     G[{1}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{1, 1/(yu*yv), yu^(-1)}, yw] - 
     G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{1, 1/(yu*yv), yu^(-1)}, yw] - 
     7*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{1, 1/(yu*yv), yu^(-1)}, yw] + 
     G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{1, 1/(yu*yv), yu^(-1)}, yw] - 
     6*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{1, 1/(yu*yv), yu^(-1)}, yw] + 
     3*G[{1/(yu*yv)}, yw]^2*G[{1, 1/(yu*yv), yu^(-1)}, yw] - 
     G[{0, 1}, yu^(-1)]*G[{1, 1/(yu*yv), yu^(-1)}, yw] + 
     G[{0, 1}, yv^(-1)]*G[{1, 1/(yu*yv), yu^(-1)}, yw] + 
     G[{0, 1}, yw]*G[{1, 1/(yu*yv), yu^(-1)}, yw] - 
     G[{0, yu^(-1)}, yw]*G[{1, 1/(yu*yv), yu^(-1)}, yw] - 
     G[{0, yu}, yv^(-1)]*G[{1, 1/(yu*yv), yu^(-1)}, yw] - 
     G[{0, yv^(-1)}, yw]*G[{1, 1/(yu*yv), yu^(-1)}, yw] + 
     G[{0, 1/(yu*yv)}, yw]*G[{1, 1/(yu*yv), yu^(-1)}, yw] + 
     2*G[{1, yu^(-1)}, yw]*G[{1, 1/(yu*yv), yu^(-1)}, yw] + 
     2*G[{1, yu}, yv^(-1)]*G[{1, 1/(yu*yv), yu^(-1)}, yw] + 
     G[{yu^(-1), 1/(yu*yv)}, yw]*G[{1, 1/(yu*yv), yu^(-1)}, yw] + 
     6*G[{yv^(-1), 1/(yu*yv)}, yw]*G[{1, 1/(yu*yv), yu^(-1)}, yw] - 
     (5*Pi^2*G[{1, 1/(yu*yv), yv^(-1)}, yw])/6 + 2*G[{0}, yu^(-1)]*
      G[{1}, yu^(-1)]*G[{1, 1/(yu*yv), yv^(-1)}, yw] + 
     2*G[{0}, yv^(-1)]*G[{1}, yu^(-1)]*G[{1, 1/(yu*yv), yv^(-1)}, yw] - 
     2*G[{0}, yw]*G[{1}, yu^(-1)]*G[{1, 1/(yu*yv), yv^(-1)}, yw] - 
     4*G[{1}, yu^(-1)]^2*G[{1, 1/(yu*yv), yv^(-1)}, yw] - 
     2*G[{0}, yu^(-1)]*G[{1}, yv^(-1)]*G[{1, 1/(yu*yv), yv^(-1)}, yw] - 
     2*G[{0}, yv^(-1)]*G[{1}, yv^(-1)]*G[{1, 1/(yu*yv), yv^(-1)}, yw] + 
     2*G[{0}, yw]*G[{1}, yv^(-1)]*G[{1, 1/(yu*yv), yv^(-1)}, yw] - 
     G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*G[{1, 1/(yu*yv), yv^(-1)}, yw] + 
     2*G[{1}, yv^(-1)]^2*G[{1, 1/(yu*yv), yv^(-1)}, yw] + 
     G[{0}, yu^(-1)]*G[{1}, yw]*G[{1, 1/(yu*yv), yv^(-1)}, yw] + 
     G[{0}, yv^(-1)]*G[{1}, yw]*G[{1, 1/(yu*yv), yv^(-1)}, yw] - 
     G[{0}, yw]*G[{1}, yw]*G[{1, 1/(yu*yv), yv^(-1)}, yw] - 
     7*G[{1}, yu^(-1)]*G[{1}, yw]*G[{1, 1/(yu*yv), yv^(-1)}, yw] - 
     3*G[{1}, yv^(-1)]*G[{1}, yw]*G[{1, 1/(yu*yv), yv^(-1)}, yw] - 
     4*G[{1}, yw]^2*G[{1, 1/(yu*yv), yv^(-1)}, yw] + 
     G[{0}, yu^(-1)]*G[{yu^(-1)}, yw]*G[{1, 1/(yu*yv), yv^(-1)}, yw] + 
     G[{0}, yv^(-1)]*G[{yu^(-1)}, yw]*G[{1, 1/(yu*yv), yv^(-1)}, yw] - 
     G[{0}, yw]*G[{yu^(-1)}, yw]*G[{1, 1/(yu*yv), yv^(-1)}, yw] + 
     3*G[{1}, yu^(-1)]*G[{yu^(-1)}, yw]*G[{1, 1/(yu*yv), yv^(-1)}, yw] - 
     2*G[{1}, yv^(-1)]*G[{yu^(-1)}, yw]*G[{1, 1/(yu*yv), yv^(-1)}, yw] + 
     3*G[{1}, yw]*G[{yu^(-1)}, yw]*G[{1, 1/(yu*yv), yv^(-1)}, yw] + 
     G[{yu^(-1)}, yw]^2*G[{1, 1/(yu*yv), yv^(-1)}, yw] + 
     5*G[{1}, yu^(-1)]*G[{yu}, yv^(-1)]*G[{1, 1/(yu*yv), yv^(-1)}, yw] + 
     3*G[{1}, yv^(-1)]*G[{yu}, yv^(-1)]*G[{1, 1/(yu*yv), yv^(-1)}, yw] + 
     8*G[{1}, yw]*G[{yu}, yv^(-1)]*G[{1, 1/(yu*yv), yv^(-1)}, yw] - 
     3*G[{yu^(-1)}, yw]*G[{yu}, yv^(-1)]*G[{1, 1/(yu*yv), yv^(-1)}, yw] - 
     4*G[{yu}, yv^(-1)]^2*G[{1, 1/(yu*yv), yv^(-1)}, yw] + 
     5*G[{0}, yu^(-1)]*G[{yv^(-1)}, yw]*G[{1, 1/(yu*yv), yv^(-1)}, yw] + 
     5*G[{0}, yv^(-1)]*G[{yv^(-1)}, yw]*G[{1, 1/(yu*yv), yv^(-1)}, yw] - 
     5*G[{0}, yw]*G[{yv^(-1)}, yw]*G[{1, 1/(yu*yv), yv^(-1)}, yw] - 
     3*G[{1}, yu^(-1)]*G[{yv^(-1)}, yw]*G[{1, 1/(yu*yv), yv^(-1)}, yw] - 
     5*G[{1}, yv^(-1)]*G[{yv^(-1)}, yw]*G[{1, 1/(yu*yv), yv^(-1)}, yw] + 
     2*G[{1}, yw]*G[{yv^(-1)}, yw]*G[{1, 1/(yu*yv), yv^(-1)}, yw] + 
     5*G[{yu^(-1)}, yw]*G[{yv^(-1)}, yw]*G[{1, 1/(yu*yv), yv^(-1)}, yw] - 
     2*G[{yu}, yv^(-1)]*G[{yv^(-1)}, yw]*G[{1, 1/(yu*yv), yv^(-1)}, yw] + 
     (7*G[{yv^(-1)}, yw]^2*G[{1, 1/(yu*yv), yv^(-1)}, yw])/2 - 
     3*G[{0}, yu^(-1)]*G[{1/(yu*yv)}, yw]*G[{1, 1/(yu*yv), yv^(-1)}, yw] - 
     3*G[{0}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{1, 1/(yu*yv), yv^(-1)}, yw] + 
     3*G[{0}, yw]*G[{1/(yu*yv)}, yw]*G[{1, 1/(yu*yv), yv^(-1)}, yw] - 
     G[{1}, yu^(-1)]*G[{1/(yu*yv)}, yw]*G[{1, 1/(yu*yv), yv^(-1)}, yw] + 
     6*G[{1}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{1, 1/(yu*yv), yv^(-1)}, yw] - 
     G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{1, 1/(yu*yv), yv^(-1)}, yw] - 
     6*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{1, 1/(yu*yv), yv^(-1)}, yw] + 
     G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{1, 1/(yu*yv), yv^(-1)}, yw] - 
     7*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{1, 1/(yu*yv), yv^(-1)}, yw] + 
     3*G[{1/(yu*yv)}, yw]^2*G[{1, 1/(yu*yv), yv^(-1)}, yw] + 
     G[{0, 1}, yu^(-1)]*G[{1, 1/(yu*yv), yv^(-1)}, yw] - 
     G[{0, 1}, yv^(-1)]*G[{1, 1/(yu*yv), yv^(-1)}, yw] + 
     G[{0, 1}, yw]*G[{1, 1/(yu*yv), yv^(-1)}, yw] - 
     G[{0, yu^(-1)}, yw]*G[{1, 1/(yu*yv), yv^(-1)}, yw] + 
     G[{0, yu}, yv^(-1)]*G[{1, 1/(yu*yv), yv^(-1)}, yw] - 
     G[{0, yv^(-1)}, yw]*G[{1, 1/(yu*yv), yv^(-1)}, yw] + 
     G[{0, 1/(yu*yv)}, yw]*G[{1, 1/(yu*yv), yv^(-1)}, yw] - 
     2*G[{1, yu}, yv^(-1)]*G[{1, 1/(yu*yv), yv^(-1)}, yw] + 
     2*G[{1, yv^(-1)}, yw]*G[{1, 1/(yu*yv), yv^(-1)}, yw] + 
     6*G[{yu^(-1), 1/(yu*yv)}, yw]*G[{1, 1/(yu*yv), yv^(-1)}, yw] + 
     G[{yv^(-1), 1/(yu*yv)}, yw]*G[{1, 1/(yu*yv), yv^(-1)}, yw] - 
     2*G[{0}, yu^(-1)]*G[{1}, yu^(-1)]*G[{1, 1/(yu*yv), 1/(yu*yv)}, yw] - 
     2*G[{0}, yv^(-1)]*G[{1}, yu^(-1)]*G[{1, 1/(yu*yv), 1/(yu*yv)}, yw] + 
     2*G[{0}, yw]*G[{1}, yu^(-1)]*G[{1, 1/(yu*yv), 1/(yu*yv)}, yw] + 
     4*G[{1}, yu^(-1)]^2*G[{1, 1/(yu*yv), 1/(yu*yv)}, yw] - 
     2*G[{0}, yu^(-1)]*G[{1}, yv^(-1)]*G[{1, 1/(yu*yv), 1/(yu*yv)}, yw] - 
     2*G[{0}, yv^(-1)]*G[{1}, yv^(-1)]*G[{1, 1/(yu*yv), 1/(yu*yv)}, yw] + 
     2*G[{0}, yw]*G[{1}, yv^(-1)]*G[{1, 1/(yu*yv), 1/(yu*yv)}, yw] + 
     5*G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*G[{1, 1/(yu*yv), 1/(yu*yv)}, yw] + 
     4*G[{1}, yv^(-1)]^2*G[{1, 1/(yu*yv), 1/(yu*yv)}, yw] + 
     12*G[{1}, yu^(-1)]*G[{1}, yw]*G[{1, 1/(yu*yv), 1/(yu*yv)}, yw] + 
     12*G[{1}, yv^(-1)]*G[{1}, yw]*G[{1, 1/(yu*yv), 1/(yu*yv)}, yw] + 
     12*G[{1}, yw]^2*G[{1, 1/(yu*yv), 1/(yu*yv)}, yw] - 
     2*G[{0}, yu^(-1)]*G[{yu^(-1)}, yw]*G[{1, 1/(yu*yv), 1/(yu*yv)}, yw] - 
     2*G[{0}, yv^(-1)]*G[{yu^(-1)}, yw]*G[{1, 1/(yu*yv), 1/(yu*yv)}, yw] + 
     2*G[{0}, yw]*G[{yu^(-1)}, yw]*G[{1, 1/(yu*yv), 1/(yu*yv)}, yw] - 
     2*G[{1}, yv^(-1)]*G[{yu^(-1)}, yw]*G[{1, 1/(yu*yv), 1/(yu*yv)}, yw] - 
     6*G[{1}, yw]*G[{yu^(-1)}, yw]*G[{1, 1/(yu*yv), 1/(yu*yv)}, yw] + 
     4*G[{0}, yu^(-1)]*G[{yu}, yv^(-1)]*G[{1, 1/(yu*yv), 1/(yu*yv)}, yw] + 
     4*G[{0}, yv^(-1)]*G[{yu}, yv^(-1)]*G[{1, 1/(yu*yv), 1/(yu*yv)}, yw] - 
     4*G[{0}, yw]*G[{yu}, yv^(-1)]*G[{1, 1/(yu*yv), 1/(yu*yv)}, yw] - 
     9*G[{1}, yu^(-1)]*G[{yu}, yv^(-1)]*G[{1, 1/(yu*yv), 1/(yu*yv)}, yw] - 
     9*G[{1}, yv^(-1)]*G[{yu}, yv^(-1)]*G[{1, 1/(yu*yv), 1/(yu*yv)}, yw] - 
     24*G[{1}, yw]*G[{yu}, yv^(-1)]*G[{1, 1/(yu*yv), 1/(yu*yv)}, yw] + 
     6*G[{yu^(-1)}, yw]*G[{yu}, yv^(-1)]*G[{1, 1/(yu*yv), 1/(yu*yv)}, yw] + 
     5*G[{yu}, yv^(-1)]^2*G[{1, 1/(yu*yv), 1/(yu*yv)}, yw] - 
     2*G[{0}, yu^(-1)]*G[{yv^(-1)}, yw]*G[{1, 1/(yu*yv), 1/(yu*yv)}, yw] - 
     2*G[{0}, yv^(-1)]*G[{yv^(-1)}, yw]*G[{1, 1/(yu*yv), 1/(yu*yv)}, yw] + 
     2*G[{0}, yw]*G[{yv^(-1)}, yw]*G[{1, 1/(yu*yv), 1/(yu*yv)}, yw] - 
     2*G[{1}, yu^(-1)]*G[{yv^(-1)}, yw]*G[{1, 1/(yu*yv), 1/(yu*yv)}, yw] - 
     6*G[{1}, yw]*G[{yv^(-1)}, yw]*G[{1, 1/(yu*yv), 1/(yu*yv)}, yw] + 
     6*G[{yu}, yv^(-1)]*G[{yv^(-1)}, yw]*G[{1, 1/(yu*yv), 1/(yu*yv)}, yw] + 
     6*G[{1}, yu^(-1)]*G[{1/(yu*yv)}, yw]*G[{1, 1/(yu*yv), 1/(yu*yv)}, yw] + 
     6*G[{1}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{1, 1/(yu*yv), 1/(yu*yv)}, yw] + 
     12*G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{1, 1/(yu*yv), 1/(yu*yv)}, yw] - 
     12*G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{1, 1/(yu*yv), 1/(yu*yv)}, 
       yw] - 2*G[{1/(yu*yv)}, yw]^2*G[{1, 1/(yu*yv), 1/(yu*yv)}, yw] - 
     7*G[{0, 1}, yu^(-1)]*G[{1, 1/(yu*yv), 1/(yu*yv)}, yw] - 
     7*G[{0, 1}, yv^(-1)]*G[{1, 1/(yu*yv), 1/(yu*yv)}, yw] + 
     4*G[{0, 1}, yw]*G[{1, 1/(yu*yv), 1/(yu*yv)}, yw] - 
     4*G[{0, yu^(-1)}, yw]*G[{1, 1/(yu*yv), 1/(yu*yv)}, yw] + 
     7*G[{0, yu}, yv^(-1)]*G[{1, 1/(yu*yv), 1/(yu*yv)}, yw] - 
     4*G[{0, yv^(-1)}, yw]*G[{1, 1/(yu*yv), 1/(yu*yv)}, yw] + 
     4*G[{0, 1/(yu*yv)}, yw]*G[{1, 1/(yu*yv), 1/(yu*yv)}, yw] - 
     3*G[{1, yu^(-1)}, yw]*G[{1, 1/(yu*yv), 1/(yu*yv)}, yw] - 
     3*G[{1, yv^(-1)}, yw]*G[{1, 1/(yu*yv), 1/(yu*yv)}, yw] + 
     14*G[{1, 1/(yu*yv)}, yw]*G[{1, 1/(yu*yv), 1/(yu*yv)}, yw] + 
     2*G[{yu^(-1), 1/(yu*yv)}, yw]*G[{1, 1/(yu*yv), 1/(yu*yv)}, yw] + 
     2*G[{yv^(-1), 1/(yu*yv)}, yw]*G[{1, 1/(yu*yv), 1/(yu*yv)}, yw] - 
     (4*Pi^2*G[{yu^(-1), yu^(-1), 1/(yu*yv)}, yw])/3 - 
     2*G[{0}, yu^(-1)]^2*G[{yu^(-1), yu^(-1), 1/(yu*yv)}, yw] - 
     4*G[{0}, yu^(-1)]*G[{0}, yv^(-1)]*G[{yu^(-1), yu^(-1), 1/(yu*yv)}, yw] - 
     2*G[{0}, yv^(-1)]^2*G[{yu^(-1), yu^(-1), 1/(yu*yv)}, yw] + 
     4*G[{0}, yu^(-1)]*G[{0}, yw]*G[{yu^(-1), yu^(-1), 1/(yu*yv)}, yw] + 
     4*G[{0}, yv^(-1)]*G[{0}, yw]*G[{yu^(-1), yu^(-1), 1/(yu*yv)}, yw] - 
     2*G[{0}, yw]^2*G[{yu^(-1), yu^(-1), 1/(yu*yv)}, yw] + 
     4*G[{0}, yu^(-1)]*G[{1}, yu^(-1)]*G[{yu^(-1), yu^(-1), 1/(yu*yv)}, yw] + 
     4*G[{0}, yv^(-1)]*G[{1}, yu^(-1)]*G[{yu^(-1), yu^(-1), 1/(yu*yv)}, yw] - 
     4*G[{0}, yw]*G[{1}, yu^(-1)]*G[{yu^(-1), yu^(-1), 1/(yu*yv)}, yw] - 
     2*G[{1}, yu^(-1)]^2*G[{yu^(-1), yu^(-1), 1/(yu*yv)}, yw] + 
     12*G[{0}, yu^(-1)]*G[{1}, yv^(-1)]*G[{yu^(-1), yu^(-1), 1/(yu*yv)}, 
       yw] + 12*G[{0}, yv^(-1)]*G[{1}, yv^(-1)]*
      G[{yu^(-1), yu^(-1), 1/(yu*yv)}, yw] - 12*G[{0}, yw]*G[{1}, yv^(-1)]*
      G[{yu^(-1), yu^(-1), 1/(yu*yv)}, yw] - 10*G[{1}, yu^(-1)]*
      G[{1}, yv^(-1)]*G[{yu^(-1), yu^(-1), 1/(yu*yv)}, yw] - 
     12*G[{1}, yv^(-1)]^2*G[{yu^(-1), yu^(-1), 1/(yu*yv)}, yw] + 
     4*G[{0}, yu^(-1)]*G[{1}, yw]*G[{yu^(-1), yu^(-1), 1/(yu*yv)}, yw] + 
     4*G[{0}, yv^(-1)]*G[{1}, yw]*G[{yu^(-1), yu^(-1), 1/(yu*yv)}, yw] - 
     4*G[{0}, yw]*G[{1}, yw]*G[{yu^(-1), yu^(-1), 1/(yu*yv)}, yw] - 
     4*G[{1}, yu^(-1)]*G[{1}, yw]*G[{yu^(-1), yu^(-1), 1/(yu*yv)}, yw] - 
     8*G[{1}, yv^(-1)]*G[{1}, yw]*G[{yu^(-1), yu^(-1), 1/(yu*yv)}, yw] - 
     2*G[{1}, yw]^2*G[{yu^(-1), yu^(-1), 1/(yu*yv)}, yw] - 
     8*G[{0}, yu^(-1)]*G[{yu^(-1)}, yw]*G[{yu^(-1), yu^(-1), 1/(yu*yv)}, 
       yw] - 8*G[{0}, yv^(-1)]*G[{yu^(-1)}, yw]*
      G[{yu^(-1), yu^(-1), 1/(yu*yv)}, yw] + 8*G[{0}, yw]*G[{yu^(-1)}, yw]*
      G[{yu^(-1), yu^(-1), 1/(yu*yv)}, yw] + 8*G[{1}, yu^(-1)]*
      G[{yu^(-1)}, yw]*G[{yu^(-1), yu^(-1), 1/(yu*yv)}, yw] + 
     16*G[{1}, yv^(-1)]*G[{yu^(-1)}, yw]*G[{yu^(-1), yu^(-1), 1/(yu*yv)}, 
       yw] + 8*G[{1}, yw]*G[{yu^(-1)}, yw]*G[{yu^(-1), yu^(-1), 1/(yu*yv)}, 
       yw] - 8*G[{yu^(-1)}, yw]^2*G[{yu^(-1), yu^(-1), 1/(yu*yv)}, yw] - 
     8*G[{0}, yu^(-1)]*G[{yu}, yv^(-1)]*G[{yu^(-1), yu^(-1), 1/(yu*yv)}, 
       yw] - 8*G[{0}, yv^(-1)]*G[{yu}, yv^(-1)]*
      G[{yu^(-1), yu^(-1), 1/(yu*yv)}, yw] + 8*G[{0}, yw]*G[{yu}, yv^(-1)]*
      G[{yu^(-1), yu^(-1), 1/(yu*yv)}, yw] + 6*G[{1}, yu^(-1)]*
      G[{yu}, yv^(-1)]*G[{yu^(-1), yu^(-1), 1/(yu*yv)}, yw] + 
     8*G[{1}, yv^(-1)]*G[{yu}, yv^(-1)]*G[{yu^(-1), yu^(-1), 1/(yu*yv)}, 
       yw] + 4*G[{1}, yw]*G[{yu}, yv^(-1)]*G[{yu^(-1), yu^(-1), 1/(yu*yv)}, 
       yw] - 8*G[{yu^(-1)}, yw]*G[{yu}, yv^(-1)]*
      G[{yu^(-1), yu^(-1), 1/(yu*yv)}, yw] + G[{yu}, yv^(-1)]^2*
      G[{yu^(-1), yu^(-1), 1/(yu*yv)}, yw] + 3*G[{0}, yu^(-1)]*
      G[{yv^(-1)}, yw]*G[{yu^(-1), yu^(-1), 1/(yu*yv)}, yw] + 
     3*G[{0}, yv^(-1)]*G[{yv^(-1)}, yw]*G[{yu^(-1), yu^(-1), 1/(yu*yv)}, 
       yw] - 3*G[{0}, yw]*G[{yv^(-1)}, yw]*G[{yu^(-1), yu^(-1), 1/(yu*yv)}, 
       yw] - 5*G[{1}, yu^(-1)]*G[{yv^(-1)}, yw]*
      G[{yu^(-1), yu^(-1), 1/(yu*yv)}, yw] - 3*G[{1}, yv^(-1)]*
      G[{yv^(-1)}, yw]*G[{yu^(-1), yu^(-1), 1/(yu*yv)}, yw] - 
     2*G[{1}, yw]*G[{yv^(-1)}, yw]*G[{yu^(-1), yu^(-1), 1/(yu*yv)}, yw] + 
     3*G[{yu^(-1)}, yw]*G[{yv^(-1)}, yw]*G[{yu^(-1), yu^(-1), 1/(yu*yv)}, 
       yw] + 2*G[{yu}, yv^(-1)]*G[{yv^(-1)}, yw]*
      G[{yu^(-1), yu^(-1), 1/(yu*yv)}, yw] + 
     (9*G[{yv^(-1)}, yw]^2*G[{yu^(-1), yu^(-1), 1/(yu*yv)}, yw])/2 - 
     3*G[{0}, yu^(-1)]*G[{1/(yu*yv)}, yw]*G[{yu^(-1), yu^(-1), 1/(yu*yv)}, 
       yw] - 3*G[{0}, yv^(-1)]*G[{1/(yu*yv)}, yw]*
      G[{yu^(-1), yu^(-1), 1/(yu*yv)}, yw] + 3*G[{0}, yw]*G[{1/(yu*yv)}, yw]*
      G[{yu^(-1), yu^(-1), 1/(yu*yv)}, yw] + 5*G[{1}, yu^(-1)]*
      G[{1/(yu*yv)}, yw]*G[{yu^(-1), yu^(-1), 1/(yu*yv)}, yw] + 
     6*G[{1}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{yu^(-1), yu^(-1), 1/(yu*yv)}, 
       yw] + 5*G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{yu^(-1), yu^(-1), 1/(yu*yv)}, 
       yw] - 6*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*
      G[{yu^(-1), yu^(-1), 1/(yu*yv)}, yw] - 5*G[{yu}, yv^(-1)]*
      G[{1/(yu*yv)}, yw]*G[{yu^(-1), yu^(-1), 1/(yu*yv)}, yw] - 
     13*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{yu^(-1), yu^(-1), 1/(yu*yv)}, 
       yw] + 6*G[{1/(yu*yv)}, yw]^2*G[{yu^(-1), yu^(-1), 1/(yu*yv)}, yw] + 
     2*G[{0, 1}, yu^(-1)]*G[{yu^(-1), yu^(-1), 1/(yu*yv)}, yw] + 
     4*G[{0, 1}, yv^(-1)]*G[{yu^(-1), yu^(-1), 1/(yu*yv)}, yw] - 
     4*G[{0, 1}, yw]*G[{yu^(-1), yu^(-1), 1/(yu*yv)}, yw] + 
     4*G[{0, yu^(-1)}, yw]*G[{yu^(-1), yu^(-1), 1/(yu*yv)}, yw] - 
     4*G[{0, yu}, yv^(-1)]*G[{yu^(-1), yu^(-1), 1/(yu*yv)}, yw] + 
     4*G[{0, yv^(-1)}, yw]*G[{yu^(-1), yu^(-1), 1/(yu*yv)}, yw] - 
     4*G[{0, 1/(yu*yv)}, yw]*G[{yu^(-1), yu^(-1), 1/(yu*yv)}, yw] + 
     2*G[{1, yu}, yv^(-1)]*G[{yu^(-1), yu^(-1), 1/(yu*yv)}, yw] - 
     2*G[{1, yv^(-1)}, yw]*G[{yu^(-1), yu^(-1), 1/(yu*yv)}, yw] - 
     6*G[{1, 1/(yu*yv)}, yw]*G[{yu^(-1), yu^(-1), 1/(yu*yv)}, yw] + 
     2*G[{yu^(-1), 1/(yu*yv)}, yw]*G[{yu^(-1), yu^(-1), 1/(yu*yv)}, yw] + 
     7*G[{yv^(-1), 1/(yu*yv)}, yw]*G[{yu^(-1), yu^(-1), 1/(yu*yv)}, yw] + 
     (7*Pi^2*G[{yu^(-1), 1/(yu*yv), yv^(-1)}, yw])/6 + 
     2*G[{0}, yu^(-1)]^2*G[{yu^(-1), 1/(yu*yv), yv^(-1)}, yw] + 
     4*G[{0}, yu^(-1)]*G[{0}, yv^(-1)]*G[{yu^(-1), 1/(yu*yv), yv^(-1)}, yw] + 
     2*G[{0}, yv^(-1)]^2*G[{yu^(-1), 1/(yu*yv), yv^(-1)}, yw] - 
     4*G[{0}, yu^(-1)]*G[{0}, yw]*G[{yu^(-1), 1/(yu*yv), yv^(-1)}, yw] - 
     4*G[{0}, yv^(-1)]*G[{0}, yw]*G[{yu^(-1), 1/(yu*yv), yv^(-1)}, yw] + 
     2*G[{0}, yw]^2*G[{yu^(-1), 1/(yu*yv), yv^(-1)}, yw] - 
     6*G[{0}, yu^(-1)]*G[{1}, yu^(-1)]*G[{yu^(-1), 1/(yu*yv), yv^(-1)}, yw] - 
     6*G[{0}, yv^(-1)]*G[{1}, yu^(-1)]*G[{yu^(-1), 1/(yu*yv), yv^(-1)}, yw] + 
     6*G[{0}, yw]*G[{1}, yu^(-1)]*G[{yu^(-1), 1/(yu*yv), yv^(-1)}, yw] + 
     4*G[{1}, yu^(-1)]^2*G[{yu^(-1), 1/(yu*yv), yv^(-1)}, yw] - 
     6*G[{0}, yu^(-1)]*G[{1}, yv^(-1)]*G[{yu^(-1), 1/(yu*yv), yv^(-1)}, yw] - 
     6*G[{0}, yv^(-1)]*G[{1}, yv^(-1)]*G[{yu^(-1), 1/(yu*yv), yv^(-1)}, yw] + 
     6*G[{0}, yw]*G[{1}, yv^(-1)]*G[{yu^(-1), 1/(yu*yv), yv^(-1)}, yw] + 
     7*G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*G[{yu^(-1), 1/(yu*yv), yv^(-1)}, yw] + 
     4*G[{1}, yv^(-1)]^2*G[{yu^(-1), 1/(yu*yv), yv^(-1)}, yw] - 
     3*G[{0}, yu^(-1)]*G[{1}, yw]*G[{yu^(-1), 1/(yu*yv), yv^(-1)}, yw] - 
     3*G[{0}, yv^(-1)]*G[{1}, yw]*G[{yu^(-1), 1/(yu*yv), yv^(-1)}, yw] + 
     3*G[{0}, yw]*G[{1}, yw]*G[{yu^(-1), 1/(yu*yv), yv^(-1)}, yw] + 
     G[{1}, yu^(-1)]*G[{1}, yw]*G[{yu^(-1), 1/(yu*yv), yv^(-1)}, yw] + 
     G[{1}, yv^(-1)]*G[{1}, yw]*G[{yu^(-1), 1/(yu*yv), yv^(-1)}, yw] - 
     2*G[{1}, yw]^2*G[{yu^(-1), 1/(yu*yv), yv^(-1)}, yw] + 
     5*G[{0}, yu^(-1)]*G[{yu^(-1)}, yw]*G[{yu^(-1), 1/(yu*yv), yv^(-1)}, 
       yw] + 5*G[{0}, yv^(-1)]*G[{yu^(-1)}, yw]*
      G[{yu^(-1), 1/(yu*yv), yv^(-1)}, yw] - 5*G[{0}, yw]*G[{yu^(-1)}, yw]*
      G[{yu^(-1), 1/(yu*yv), yv^(-1)}, yw] - 5*G[{1}, yu^(-1)]*
      G[{yu^(-1)}, yw]*G[{yu^(-1), 1/(yu*yv), yv^(-1)}, yw] - 
     8*G[{1}, yv^(-1)]*G[{yu^(-1)}, yw]*G[{yu^(-1), 1/(yu*yv), yv^(-1)}, 
       yw] - 3*G[{1}, yw]*G[{yu^(-1)}, yw]*G[{yu^(-1), 1/(yu*yv), yv^(-1)}, 
       yw] + 4*G[{yu^(-1)}, yw]^2*G[{yu^(-1), 1/(yu*yv), yv^(-1)}, yw] + 
     4*G[{0}, yu^(-1)]*G[{yu}, yv^(-1)]*G[{yu^(-1), 1/(yu*yv), yv^(-1)}, 
       yw] + 4*G[{0}, yv^(-1)]*G[{yu}, yv^(-1)]*
      G[{yu^(-1), 1/(yu*yv), yv^(-1)}, yw] - 4*G[{0}, yw]*G[{yu}, yv^(-1)]*
      G[{yu^(-1), 1/(yu*yv), yv^(-1)}, yw] - 3*G[{1}, yu^(-1)]*
      G[{yu}, yv^(-1)]*G[{yu^(-1), 1/(yu*yv), yv^(-1)}, yw] - 
     3*G[{1}, yv^(-1)]*G[{yu}, yv^(-1)]*G[{yu^(-1), 1/(yu*yv), yv^(-1)}, 
       yw] + 4*G[{1}, yw]*G[{yu}, yv^(-1)]*G[{yu^(-1), 1/(yu*yv), yv^(-1)}, 
       yw] + 3*G[{yu^(-1)}, yw]*G[{yu}, yv^(-1)]*
      G[{yu^(-1), 1/(yu*yv), yv^(-1)}, yw] - G[{yu}, yv^(-1)]^2*
      G[{yu^(-1), 1/(yu*yv), yv^(-1)}, yw] + 2*G[{0}, yu^(-1)]*
      G[{yv^(-1)}, yw]*G[{yu^(-1), 1/(yu*yv), yv^(-1)}, yw] + 
     2*G[{0}, yv^(-1)]*G[{yv^(-1)}, yw]*G[{yu^(-1), 1/(yu*yv), yv^(-1)}, 
       yw] - 2*G[{0}, yw]*G[{yv^(-1)}, yw]*G[{yu^(-1), 1/(yu*yv), yv^(-1)}, 
       yw] + 3*G[{1}, yu^(-1)]*G[{yv^(-1)}, yw]*
      G[{yu^(-1), 1/(yu*yv), yv^(-1)}, yw] - 2*G[{1}, yv^(-1)]*
      G[{yv^(-1)}, yw]*G[{yu^(-1), 1/(yu*yv), yv^(-1)}, yw] + 
     5*G[{1}, yw]*G[{yv^(-1)}, yw]*G[{yu^(-1), 1/(yu*yv), yv^(-1)}, yw] + 
     2*G[{yu^(-1)}, yw]*G[{yv^(-1)}, yw]*G[{yu^(-1), 1/(yu*yv), yv^(-1)}, 
       yw] - 5*G[{yu}, yv^(-1)]*G[{yv^(-1)}, yw]*
      G[{yu^(-1), 1/(yu*yv), yv^(-1)}, yw] - 
     (7*G[{yv^(-1)}, yw]^2*G[{yu^(-1), 1/(yu*yv), yv^(-1)}, yw])/2 - 
     4*G[{0}, yu^(-1)]*G[{1/(yu*yv)}, yw]*G[{yu^(-1), 1/(yu*yv), yv^(-1)}, 
       yw] - 4*G[{0}, yv^(-1)]*G[{1/(yu*yv)}, yw]*
      G[{yu^(-1), 1/(yu*yv), yv^(-1)}, yw] + 4*G[{0}, yw]*G[{1/(yu*yv)}, yw]*
      G[{yu^(-1), 1/(yu*yv), yv^(-1)}, yw] + G[{1}, yu^(-1)]*
      G[{1/(yu*yv)}, yw]*G[{yu^(-1), 1/(yu*yv), yv^(-1)}, yw] + 
     G[{1}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{yu^(-1), 1/(yu*yv), yv^(-1)}, 
       yw] - 6*G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{yu^(-1), 1/(yu*yv), yv^(-1)}, 
       yw] - G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*
      G[{yu^(-1), 1/(yu*yv), yv^(-1)}, yw] + 6*G[{yu}, yv^(-1)]*
      G[{1/(yu*yv)}, yw]*G[{yu^(-1), 1/(yu*yv), yv^(-1)}, yw] + 
     7*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{yu^(-1), 1/(yu*yv), yv^(-1)}, 
       yw] - 3*G[{1/(yu*yv)}, yw]^2*G[{yu^(-1), 1/(yu*yv), yv^(-1)}, yw] + 
     G[{0, 1}, yu^(-1)]*G[{yu^(-1), 1/(yu*yv), yv^(-1)}, yw] + 
     G[{0, 1}, yv^(-1)]*G[{yu^(-1), 1/(yu*yv), yv^(-1)}, yw] + 
     G[{0, 1}, yw]*G[{yu^(-1), 1/(yu*yv), yv^(-1)}, yw] - 
     G[{0, yu^(-1)}, yw]*G[{yu^(-1), 1/(yu*yv), yv^(-1)}, yw] - 
     G[{0, yu}, yv^(-1)]*G[{yu^(-1), 1/(yu*yv), yv^(-1)}, yw] - 
     G[{0, yv^(-1)}, yw]*G[{yu^(-1), 1/(yu*yv), yv^(-1)}, yw] + 
     G[{0, 1/(yu*yv)}, yw]*G[{yu^(-1), 1/(yu*yv), yv^(-1)}, yw] + 
     2*G[{1, yu^(-1)}, yw]*G[{yu^(-1), 1/(yu*yv), yv^(-1)}, yw] + 
     2*G[{1, yv^(-1)}, yw]*G[{yu^(-1), 1/(yu*yv), yv^(-1)}, yw] - 
     2*G[{1, 1/(yu*yv)}, yw]*G[{yu^(-1), 1/(yu*yv), yv^(-1)}, yw] - 
     G[{yv^(-1), 1/(yu*yv)}, yw]*G[{yu^(-1), 1/(yu*yv), yv^(-1)}, yw] - 
     (Pi^2*G[{yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/2 - 
     2*G[{0}, yu^(-1)]^2*G[{yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] - 
     4*G[{0}, yu^(-1)]*G[{0}, yv^(-1)]*G[{yu^(-1), 1/(yu*yv), 1/(yu*yv)}, 
       yw] - 2*G[{0}, yv^(-1)]^2*G[{yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] + 
     4*G[{0}, yu^(-1)]*G[{0}, yw]*G[{yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] + 
     4*G[{0}, yv^(-1)]*G[{0}, yw]*G[{yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] - 
     2*G[{0}, yw]^2*G[{yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] + 
     6*G[{0}, yu^(-1)]*G[{1}, yu^(-1)]*G[{yu^(-1), 1/(yu*yv), 1/(yu*yv)}, 
       yw] + 6*G[{0}, yv^(-1)]*G[{1}, yu^(-1)]*
      G[{yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] - 6*G[{0}, yw]*G[{1}, yu^(-1)]*
      G[{yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] - 4*G[{1}, yu^(-1)]^2*
      G[{yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] + 12*G[{0}, yu^(-1)]*
      G[{1}, yv^(-1)]*G[{yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] + 
     12*G[{0}, yv^(-1)]*G[{1}, yv^(-1)]*G[{yu^(-1), 1/(yu*yv), 1/(yu*yv)}, 
       yw] - 12*G[{0}, yw]*G[{1}, yv^(-1)]*G[{yu^(-1), 1/(yu*yv), 1/(yu*yv)}, 
       yw] - 12*G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*
      G[{yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] - 12*G[{1}, yv^(-1)]^2*
      G[{yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] + 3*G[{0}, yu^(-1)]*G[{1}, yw]*
      G[{yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] + 3*G[{0}, yv^(-1)]*G[{1}, yw]*
      G[{yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] - 3*G[{0}, yw]*G[{1}, yw]*
      G[{yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] - 5*G[{1}, yu^(-1)]*G[{1}, yw]*
      G[{yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] - 9*G[{1}, yv^(-1)]*G[{1}, yw]*
      G[{yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] - 4*G[{1}, yw]^2*
      G[{yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] - 5*G[{0}, yu^(-1)]*
      G[{yu^(-1)}, yw]*G[{yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] - 
     5*G[{0}, yv^(-1)]*G[{yu^(-1)}, yw]*G[{yu^(-1), 1/(yu*yv), 1/(yu*yv)}, 
       yw] + 5*G[{0}, yw]*G[{yu^(-1)}, yw]*G[{yu^(-1), 1/(yu*yv), 1/(yu*yv)}, 
       yw] + 9*G[{1}, yu^(-1)]*G[{yu^(-1)}, yw]*
      G[{yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] + 10*G[{1}, yv^(-1)]*
      G[{yu^(-1)}, yw]*G[{yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] + 
     9*G[{1}, yw]*G[{yu^(-1)}, yw]*G[{yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] - 
     5*G[{yu^(-1)}, yw]^2*G[{yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] - 
     10*G[{0}, yu^(-1)]*G[{yu}, yv^(-1)]*G[{yu^(-1), 1/(yu*yv), 1/(yu*yv)}, 
       yw] - 10*G[{0}, yv^(-1)]*G[{yu}, yv^(-1)]*
      G[{yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] + 10*G[{0}, yw]*G[{yu}, yv^(-1)]*
      G[{yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] + 8*G[{1}, yu^(-1)]*
      G[{yu}, yv^(-1)]*G[{yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] + 
     9*G[{1}, yv^(-1)]*G[{yu}, yv^(-1)]*G[{yu^(-1), 1/(yu*yv), 1/(yu*yv)}, 
       yw] + 8*G[{1}, yw]*G[{yu}, yv^(-1)]*G[{yu^(-1), 1/(yu*yv), 1/(yu*yv)}, 
       yw] - 9*G[{yu^(-1)}, yw]*G[{yu}, yv^(-1)]*
      G[{yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] + 
     (3*G[{yu}, yv^(-1)]^2*G[{yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/2 - 
     4*G[{0}, yu^(-1)]*G[{yv^(-1)}, yw]*G[{yu^(-1), 1/(yu*yv), 1/(yu*yv)}, 
       yw] - 4*G[{0}, yv^(-1)]*G[{yv^(-1)}, yw]*
      G[{yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] + 4*G[{0}, yw]*G[{yv^(-1)}, yw]*
      G[{yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] + 2*G[{1}, yu^(-1)]*
      G[{yv^(-1)}, yw]*G[{yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] + 
     6*G[{1}, yv^(-1)]*G[{yv^(-1)}, yw]*G[{yu^(-1), 1/(yu*yv), 1/(yu*yv)}, 
       yw] - 6*G[{yu^(-1)}, yw]*G[{yv^(-1)}, yw]*
      G[{yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] + 6*G[{0}, yu^(-1)]*
      G[{1/(yu*yv)}, yw]*G[{yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] + 
     6*G[{0}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{yu^(-1), 1/(yu*yv), 1/(yu*yv)}, 
       yw] - 6*G[{0}, yw]*G[{1/(yu*yv)}, yw]*
      G[{yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] - 6*G[{1}, yu^(-1)]*
      G[{1/(yu*yv)}, yw]*G[{yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] - 
     12*G[{1}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{yu^(-1), 1/(yu*yv), 1/(yu*yv)}, 
       yw] - 6*G[{1}, yw]*G[{1/(yu*yv)}, yw]*
      G[{yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] + 12*G[{yu^(-1)}, yw]*
      G[{1/(yu*yv)}, yw]*G[{yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] + 
     6*G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{yu^(-1), 1/(yu*yv), 1/(yu*yv)}, 
       yw] + 2*G[{1/(yu*yv)}, yw]^2*G[{yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] + 
     4*G[{0, 1}, yu^(-1)]*G[{yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] + 
     7*G[{0, 1}, yv^(-1)]*G[{yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] - 
     7*G[{0, 1}, yw]*G[{yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] + 
     7*G[{0, yu^(-1)}, yw]*G[{yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] - 
     7*G[{0, yu}, yv^(-1)]*G[{yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] + 
     7*G[{0, yv^(-1)}, yw]*G[{yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] - 
     7*G[{0, 1/(yu*yv)}, yw]*G[{yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] + 
     3*G[{1, yu}, yv^(-1)]*G[{yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] - 
     3*G[{1, yv^(-1)}, yw]*G[{yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] - 
     11*G[{1, 1/(yu*yv)}, yw]*G[{yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] + 
     14*G[{yu^(-1), 1/(yu*yv)}, yw]*G[{yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] - 
     2*G[{yv^(-1), 1/(yu*yv)}, yw]*G[{yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] - 
     (4*Pi^2*G[{yv^(-1), yv^(-1), 1/(yu*yv)}, yw])/3 - 
     2*G[{0}, yu^(-1)]^2*G[{yv^(-1), yv^(-1), 1/(yu*yv)}, yw] - 
     4*G[{0}, yu^(-1)]*G[{0}, yv^(-1)]*G[{yv^(-1), yv^(-1), 1/(yu*yv)}, yw] - 
     2*G[{0}, yv^(-1)]^2*G[{yv^(-1), yv^(-1), 1/(yu*yv)}, yw] + 
     4*G[{0}, yu^(-1)]*G[{0}, yw]*G[{yv^(-1), yv^(-1), 1/(yu*yv)}, yw] + 
     4*G[{0}, yv^(-1)]*G[{0}, yw]*G[{yv^(-1), yv^(-1), 1/(yu*yv)}, yw] - 
     2*G[{0}, yw]^2*G[{yv^(-1), yv^(-1), 1/(yu*yv)}, yw] + 
     12*G[{0}, yu^(-1)]*G[{1}, yu^(-1)]*G[{yv^(-1), yv^(-1), 1/(yu*yv)}, 
       yw] + 12*G[{0}, yv^(-1)]*G[{1}, yu^(-1)]*
      G[{yv^(-1), yv^(-1), 1/(yu*yv)}, yw] - 12*G[{0}, yw]*G[{1}, yu^(-1)]*
      G[{yv^(-1), yv^(-1), 1/(yu*yv)}, yw] - 12*G[{1}, yu^(-1)]^2*
      G[{yv^(-1), yv^(-1), 1/(yu*yv)}, yw] + 4*G[{0}, yu^(-1)]*
      G[{1}, yv^(-1)]*G[{yv^(-1), yv^(-1), 1/(yu*yv)}, yw] + 
     4*G[{0}, yv^(-1)]*G[{1}, yv^(-1)]*G[{yv^(-1), yv^(-1), 1/(yu*yv)}, yw] - 
     4*G[{0}, yw]*G[{1}, yv^(-1)]*G[{yv^(-1), yv^(-1), 1/(yu*yv)}, yw] - 
     8*G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*G[{yv^(-1), yv^(-1), 1/(yu*yv)}, yw] - 
     2*G[{1}, yv^(-1)]^2*G[{yv^(-1), yv^(-1), 1/(yu*yv)}, yw] + 
     4*G[{0}, yu^(-1)]*G[{1}, yw]*G[{yv^(-1), yv^(-1), 1/(yu*yv)}, yw] + 
     4*G[{0}, yv^(-1)]*G[{1}, yw]*G[{yv^(-1), yv^(-1), 1/(yu*yv)}, yw] - 
     4*G[{0}, yw]*G[{1}, yw]*G[{yv^(-1), yv^(-1), 1/(yu*yv)}, yw] - 
     8*G[{1}, yu^(-1)]*G[{1}, yw]*G[{yv^(-1), yv^(-1), 1/(yu*yv)}, yw] - 
     4*G[{1}, yv^(-1)]*G[{1}, yw]*G[{yv^(-1), yv^(-1), 1/(yu*yv)}, yw] - 
     2*G[{1}, yw]^2*G[{yv^(-1), yv^(-1), 1/(yu*yv)}, yw] + 
     8*G[{1}, yu^(-1)]*G[{yu^(-1)}, yw]*G[{yv^(-1), yv^(-1), 1/(yu*yv)}, 
       yw] - 2*G[{1}, yv^(-1)]*G[{yu^(-1)}, yw]*
      G[{yv^(-1), yv^(-1), 1/(yu*yv)}, yw] + 6*G[{1}, yw]*G[{yu^(-1)}, yw]*
      G[{yv^(-1), yv^(-1), 1/(yu*yv)}, yw] + G[{yu^(-1)}, yw]^2*
      G[{yv^(-1), yv^(-1), 1/(yu*yv)}, yw] - 8*G[{0}, yu^(-1)]*
      G[{yu}, yv^(-1)]*G[{yv^(-1), yv^(-1), 1/(yu*yv)}, yw] - 
     8*G[{0}, yv^(-1)]*G[{yu}, yv^(-1)]*G[{yv^(-1), yv^(-1), 1/(yu*yv)}, 
       yw] + 8*G[{0}, yw]*G[{yu}, yv^(-1)]*G[{yv^(-1), yv^(-1), 1/(yu*yv)}, 
       yw] + 8*G[{1}, yu^(-1)]*G[{yu}, yv^(-1)]*
      G[{yv^(-1), yv^(-1), 1/(yu*yv)}, yw] + 6*G[{1}, yv^(-1)]*
      G[{yu}, yv^(-1)]*G[{yv^(-1), yv^(-1), 1/(yu*yv)}, yw] + 
     4*G[{1}, yw]*G[{yu}, yv^(-1)]*G[{yv^(-1), yv^(-1), 1/(yu*yv)}, yw] - 
     6*G[{yu^(-1)}, yw]*G[{yu}, yv^(-1)]*G[{yv^(-1), yv^(-1), 1/(yu*yv)}, 
       yw] + G[{yu}, yv^(-1)]^2*G[{yv^(-1), yv^(-1), 1/(yu*yv)}, yw] - 
     8*G[{0}, yu^(-1)]*G[{yv^(-1)}, yw]*G[{yv^(-1), yv^(-1), 1/(yu*yv)}, 
       yw] - 8*G[{0}, yv^(-1)]*G[{yv^(-1)}, yw]*
      G[{yv^(-1), yv^(-1), 1/(yu*yv)}, yw] + 8*G[{0}, yw]*G[{yv^(-1)}, yw]*
      G[{yv^(-1), yv^(-1), 1/(yu*yv)}, yw] + 16*G[{1}, yu^(-1)]*
      G[{yv^(-1)}, yw]*G[{yv^(-1), yv^(-1), 1/(yu*yv)}, yw] + 
     8*G[{1}, yv^(-1)]*G[{yv^(-1)}, yw]*G[{yv^(-1), yv^(-1), 1/(yu*yv)}, 
       yw] + 8*G[{1}, yw]*G[{yv^(-1)}, yw]*G[{yv^(-1), yv^(-1), 1/(yu*yv)}, 
       yw] - 8*G[{yu^(-1)}, yw]*G[{yv^(-1)}, yw]*
      G[{yv^(-1), yv^(-1), 1/(yu*yv)}, yw] - 8*G[{yu}, yv^(-1)]*
      G[{yv^(-1)}, yw]*G[{yv^(-1), yv^(-1), 1/(yu*yv)}, yw] - 
     8*G[{yv^(-1)}, yw]^2*G[{yv^(-1), yv^(-1), 1/(yu*yv)}, yw] - 
     3*G[{0}, yu^(-1)]*G[{1/(yu*yv)}, yw]*G[{yv^(-1), yv^(-1), 1/(yu*yv)}, 
       yw] - 3*G[{0}, yv^(-1)]*G[{1/(yu*yv)}, yw]*
      G[{yv^(-1), yv^(-1), 1/(yu*yv)}, yw] + 3*G[{0}, yw]*G[{1/(yu*yv)}, yw]*
      G[{yv^(-1), yv^(-1), 1/(yu*yv)}, yw] + 6*G[{1}, yu^(-1)]*
      G[{1/(yu*yv)}, yw]*G[{yv^(-1), yv^(-1), 1/(yu*yv)}, yw] + 
     5*G[{1}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{yv^(-1), yv^(-1), 1/(yu*yv)}, 
       yw] + 5*G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{yv^(-1), yv^(-1), 1/(yu*yv)}, 
       yw] - 5*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*
      G[{yv^(-1), yv^(-1), 1/(yu*yv)}, yw] - 5*G[{yu}, yv^(-1)]*
      G[{1/(yu*yv)}, yw]*G[{yv^(-1), yv^(-1), 1/(yu*yv)}, yw] - 
     6*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{yv^(-1), yv^(-1), 1/(yu*yv)}, 
       yw] + 6*G[{1/(yu*yv)}, yw]^2*G[{yv^(-1), yv^(-1), 1/(yu*yv)}, yw] + 
     4*G[{0, 1}, yu^(-1)]*G[{yv^(-1), yv^(-1), 1/(yu*yv)}, yw] + 
     2*G[{0, 1}, yv^(-1)]*G[{yv^(-1), yv^(-1), 1/(yu*yv)}, yw] - 
     4*G[{0, 1}, yw]*G[{yv^(-1), yv^(-1), 1/(yu*yv)}, yw] + 
     4*G[{0, yu^(-1)}, yw]*G[{yv^(-1), yv^(-1), 1/(yu*yv)}, yw] - 
     2*G[{0, yu}, yv^(-1)]*G[{yv^(-1), yv^(-1), 1/(yu*yv)}, yw] + 
     4*G[{0, yv^(-1)}, yw]*G[{yv^(-1), yv^(-1), 1/(yu*yv)}, yw] - 
     4*G[{0, 1/(yu*yv)}, yw]*G[{yv^(-1), yv^(-1), 1/(yu*yv)}, yw] - 
     2*G[{1, yu^(-1)}, yw]*G[{yv^(-1), yv^(-1), 1/(yu*yv)}, yw] - 
     2*G[{1, yu}, yv^(-1)]*G[{yv^(-1), yv^(-1), 1/(yu*yv)}, yw] - 
     6*G[{1, 1/(yu*yv)}, yw]*G[{yv^(-1), yv^(-1), 1/(yu*yv)}, yw] + 
     6*G[{yu^(-1), 1/(yu*yv)}, yw]*G[{yv^(-1), yv^(-1), 1/(yu*yv)}, yw] + 
     2*G[{yv^(-1), 1/(yu*yv)}, yw]*G[{yv^(-1), yv^(-1), 1/(yu*yv)}, yw] - 
     (Pi^2*G[{yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/2 - 
     2*G[{0}, yu^(-1)]^2*G[{yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] - 
     4*G[{0}, yu^(-1)]*G[{0}, yv^(-1)]*G[{yv^(-1), 1/(yu*yv), 1/(yu*yv)}, 
       yw] - 2*G[{0}, yv^(-1)]^2*G[{yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] + 
     4*G[{0}, yu^(-1)]*G[{0}, yw]*G[{yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] + 
     4*G[{0}, yv^(-1)]*G[{0}, yw]*G[{yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] - 
     2*G[{0}, yw]^2*G[{yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] + 
     12*G[{0}, yu^(-1)]*G[{1}, yu^(-1)]*G[{yv^(-1), 1/(yu*yv), 1/(yu*yv)}, 
       yw] + 12*G[{0}, yv^(-1)]*G[{1}, yu^(-1)]*
      G[{yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] - 12*G[{0}, yw]*G[{1}, yu^(-1)]*
      G[{yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] - 12*G[{1}, yu^(-1)]^2*
      G[{yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] + 6*G[{0}, yu^(-1)]*
      G[{1}, yv^(-1)]*G[{yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] + 
     6*G[{0}, yv^(-1)]*G[{1}, yv^(-1)]*G[{yv^(-1), 1/(yu*yv), 1/(yu*yv)}, 
       yw] - 6*G[{0}, yw]*G[{1}, yv^(-1)]*G[{yv^(-1), 1/(yu*yv), 1/(yu*yv)}, 
       yw] - 9*G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*
      G[{yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] - 4*G[{1}, yv^(-1)]^2*
      G[{yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] + 3*G[{0}, yu^(-1)]*G[{1}, yw]*
      G[{yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] + 3*G[{0}, yv^(-1)]*G[{1}, yw]*
      G[{yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] - 3*G[{0}, yw]*G[{1}, yw]*
      G[{yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] - 9*G[{1}, yu^(-1)]*G[{1}, yw]*
      G[{yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] - 5*G[{1}, yv^(-1)]*G[{1}, yw]*
      G[{yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] - 4*G[{1}, yw]^2*
      G[{yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] + G[{0}, yu^(-1)]*
      G[{yu^(-1)}, yw]*G[{yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] + 
     G[{0}, yv^(-1)]*G[{yu^(-1)}, yw]*G[{yv^(-1), 1/(yu*yv), 1/(yu*yv)}, 
       yw] - G[{0}, yw]*G[{yu^(-1)}, yw]*G[{yv^(-1), 1/(yu*yv), 1/(yu*yv)}, 
       yw] + 9*G[{1}, yu^(-1)]*G[{yu^(-1)}, yw]*
      G[{yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] - 3*G[{1}, yv^(-1)]*
      G[{yu^(-1)}, yw]*G[{yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] + 
     8*G[{1}, yw]*G[{yu^(-1)}, yw]*G[{yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] + 
     (3*G[{yu^(-1)}, yw]^2*G[{yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/2 - 
     10*G[{0}, yu^(-1)]*G[{yu}, yv^(-1)]*G[{yv^(-1), 1/(yu*yv), 1/(yu*yv)}, 
       yw] - 10*G[{0}, yv^(-1)]*G[{yu}, yv^(-1)]*
      G[{yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] + 10*G[{0}, yw]*G[{yu}, yv^(-1)]*
      G[{yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] + 9*G[{1}, yu^(-1)]*
      G[{yu}, yv^(-1)]*G[{yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] + 
     8*G[{1}, yv^(-1)]*G[{yu}, yv^(-1)]*G[{yv^(-1), 1/(yu*yv), 1/(yu*yv)}, 
       yw] + 8*G[{1}, yw]*G[{yu}, yv^(-1)]*G[{yv^(-1), 1/(yu*yv), 1/(yu*yv)}, 
       yw] - 8*G[{yu^(-1)}, yw]*G[{yu}, yv^(-1)]*
      G[{yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] + 
     (3*G[{yu}, yv^(-1)]^2*G[{yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw])/2 - 
     5*G[{0}, yu^(-1)]*G[{yv^(-1)}, yw]*G[{yv^(-1), 1/(yu*yv), 1/(yu*yv)}, 
       yw] - 5*G[{0}, yv^(-1)]*G[{yv^(-1)}, yw]*
      G[{yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] + 5*G[{0}, yw]*G[{yv^(-1)}, yw]*
      G[{yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] + 10*G[{1}, yu^(-1)]*
      G[{yv^(-1)}, yw]*G[{yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] + 
     9*G[{1}, yv^(-1)]*G[{yv^(-1)}, yw]*G[{yv^(-1), 1/(yu*yv), 1/(yu*yv)}, 
       yw] + 9*G[{1}, yw]*G[{yv^(-1)}, yw]*G[{yv^(-1), 1/(yu*yv), 1/(yu*yv)}, 
       yw] - 9*G[{yu^(-1)}, yw]*G[{yv^(-1)}, yw]*
      G[{yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] - 9*G[{yu}, yv^(-1)]*
      G[{yv^(-1)}, yw]*G[{yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] - 
     5*G[{yv^(-1)}, yw]^2*G[{yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] + 
     6*G[{0}, yu^(-1)]*G[{1/(yu*yv)}, yw]*G[{yv^(-1), 1/(yu*yv), 1/(yu*yv)}, 
       yw] + 6*G[{0}, yv^(-1)]*G[{1/(yu*yv)}, yw]*
      G[{yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] - 
     6*G[{0}, yw]*G[{1/(yu*yv)}, yw]*G[{yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] - 
     12*G[{1}, yu^(-1)]*G[{1/(yu*yv)}, yw]*G[{yv^(-1), 1/(yu*yv), 1/(yu*yv)}, 
       yw] - 6*G[{1}, yv^(-1)]*G[{1/(yu*yv)}, yw]*
      G[{yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] - 
     6*G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] + 
     6*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*G[{yv^(-1), 1/(yu*yv), 1/(yu*yv)}, 
       yw] + 6*G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw]*
      G[{yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] + 12*G[{yv^(-1)}, yw]*
      G[{1/(yu*yv)}, yw]*G[{yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] + 
     2*G[{1/(yu*yv)}, yw]^2*G[{yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] + 
     7*G[{0, 1}, yu^(-1)]*G[{yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] + 
     4*G[{0, 1}, yv^(-1)]*G[{yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] - 
     7*G[{0, 1}, yw]*G[{yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] + 
     7*G[{0, yu^(-1)}, yw]*G[{yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] - 
     4*G[{0, yu}, yv^(-1)]*G[{yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] + 
     7*G[{0, yv^(-1)}, yw]*G[{yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] - 
     7*G[{0, 1/(yu*yv)}, yw]*G[{yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] - 
     3*G[{1, yu^(-1)}, yw]*G[{yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] - 
     3*G[{1, yu}, yv^(-1)]*G[{yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] - 
     11*G[{1, 1/(yu*yv)}, yw]*G[{yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] + 
     11*G[{yu^(-1), 1/(yu*yv)}, yw]*G[{yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] + 
     14*G[{yv^(-1), 1/(yu*yv)}, yw]*G[{yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] - 
     2*G[{1}, yv^(-1)]*G[{0, 0, 0, 1}, yu^(-1)] + 2*G[{yu}, yv^(-1)]*
      G[{0, 0, 0, 1}, yu^(-1)] + 2*G[{yv^(-1)}, yw]*
      G[{0, 0, 0, 1}, yu^(-1)] - 2*G[{1/(yu*yv)}, yw]*
      G[{0, 0, 0, 1}, yu^(-1)] + 2*G[{yu^(-1)}, yw]*
      G[{0, 0, 0, 1}, yv^(-1)] + 2*G[{yu}, yv^(-1)]*
      G[{0, 0, 0, 1}, yv^(-1)] - 2*G[{1/(yu*yv)}, yw]*
      G[{0, 0, 0, 1}, yv^(-1)] - 6*G[{1}, yw]*G[{0, 0, 0, 1}, yw] + 
     6*G[{yu^(-1)}, yw]*G[{0, 0, 0, 1}, yw] + 6*G[{yv^(-1)}, yw]*
      G[{0, 0, 0, 1}, yw] - 6*G[{1/(yu*yv)}, yw]*G[{0, 0, 0, 1}, yw] + 
     6*G[{1}, yw]*G[{0, 0, 0, yu^(-1)}, yw] - 6*G[{yu^(-1)}, yw]*
      G[{0, 0, 0, yu^(-1)}, yw] - 6*G[{yv^(-1)}, yw]*
      G[{0, 0, 0, yu^(-1)}, yw] + 6*G[{1/(yu*yv)}, yw]*
      G[{0, 0, 0, yu^(-1)}, yw] - 2*G[{yu^(-1)}, yw]*
      G[{0, 0, 0, yu}, yv^(-1)] - 2*G[{yu}, yv^(-1)]*
      G[{0, 0, 0, yu}, yv^(-1)] + 2*G[{1/(yu*yv)}, yw]*
      G[{0, 0, 0, yu}, yv^(-1)] + 6*G[{1}, yw]*G[{0, 0, 0, yv^(-1)}, yw] - 
     6*G[{yu^(-1)}, yw]*G[{0, 0, 0, yv^(-1)}, yw] - 
     6*G[{yv^(-1)}, yw]*G[{0, 0, 0, yv^(-1)}, yw] + 
     6*G[{1/(yu*yv)}, yw]*G[{0, 0, 0, yv^(-1)}, yw] - 
     6*G[{1}, yw]*G[{0, 0, 0, 1/(yu*yv)}, yw] + 6*G[{yu^(-1)}, yw]*
      G[{0, 0, 0, 1/(yu*yv)}, yw] + 6*G[{yv^(-1)}, yw]*
      G[{0, 0, 0, 1/(yu*yv)}, yw] - 6*G[{1/(yu*yv)}, yw]*
      G[{0, 0, 0, 1/(yu*yv)}, yw] + 4*G[{1}, yw]*G[{0, 0, 1, 1}, yu^(-1)] - 
     4*G[{yu^(-1)}, yw]*G[{0, 0, 1, 1}, yu^(-1)] - 
     4*G[{yv^(-1)}, yw]*G[{0, 0, 1, 1}, yu^(-1)] + 4*G[{1/(yu*yv)}, yw]*
      G[{0, 0, 1, 1}, yu^(-1)] + 4*G[{1}, yu^(-1)]*G[{0, 0, 1, 1}, yv^(-1)] + 
     4*G[{1}, yw]*G[{0, 0, 1, 1}, yv^(-1)] - 4*G[{yu^(-1)}, yw]*
      G[{0, 0, 1, 1}, yv^(-1)] - 4*G[{yv^(-1)}, yw]*
      G[{0, 0, 1, 1}, yv^(-1)] + 4*G[{1/(yu*yv)}, yw]*
      G[{0, 0, 1, 1}, yv^(-1)] + 4*G[{0}, yu^(-1)]*G[{0, 0, 1, 1}, yw] + 
     4*G[{0}, yv^(-1)]*G[{0, 0, 1, 1}, yw] - 4*G[{0}, yw]*
      G[{0, 0, 1, 1}, yw] - 4*G[{1}, yu^(-1)]*G[{0, 0, 1, 1}, yw] - 
     4*G[{1}, yv^(-1)]*G[{0, 0, 1, 1}, yw] + 4*G[{yu^(-1)}, yw]*
      G[{0, 0, 1, 1}, yw] + 4*G[{yv^(-1)}, yw]*G[{0, 0, 1, 1}, yw] - 
     8*G[{1/(yu*yv)}, yw]*G[{0, 0, 1, 1}, yw] - 4*G[{0}, yu^(-1)]*
      G[{0, 0, 1, yu^(-1)}, yw] - 4*G[{0}, yv^(-1)]*G[{0, 0, 1, yu^(-1)}, 
       yw] + 4*G[{0}, yw]*G[{0, 0, 1, yu^(-1)}, yw] + 
     4*G[{1}, yu^(-1)]*G[{0, 0, 1, yu^(-1)}, yw] + 
     8*G[{1}, yv^(-1)]*G[{0, 0, 1, yu^(-1)}, yw] - 
     6*G[{1}, yw]*G[{0, 0, 1, yu^(-1)}, yw] + 2*G[{yu^(-1)}, yw]*
      G[{0, 0, 1, yu^(-1)}, yw] - 4*G[{yu}, yv^(-1)]*
      G[{0, 0, 1, yu^(-1)}, yw] + 2*G[{yv^(-1)}, yw]*
      G[{0, 0, 1, yu^(-1)}, yw] + 2*G[{1/(yu*yv)}, yw]*
      G[{0, 0, 1, yu^(-1)}, yw] - 4*G[{1}, yu^(-1)]*
      G[{0, 0, 1, yu}, yv^(-1)] - 4*G[{1}, yv^(-1)]*
      G[{0, 0, 1, yu}, yv^(-1)] + 2*G[{yu^(-1)}, yw]*
      G[{0, 0, 1, yu}, yv^(-1)] + 6*G[{yu}, yv^(-1)]*
      G[{0, 0, 1, yu}, yv^(-1)] + 4*G[{yv^(-1)}, yw]*
      G[{0, 0, 1, yu}, yv^(-1)] - 6*G[{1/(yu*yv)}, yw]*
      G[{0, 0, 1, yu}, yv^(-1)] - 4*G[{0}, yu^(-1)]*G[{0, 0, 1, yv^(-1)}, 
       yw] - 4*G[{0}, yv^(-1)]*G[{0, 0, 1, yv^(-1)}, yw] + 
     4*G[{0}, yw]*G[{0, 0, 1, yv^(-1)}, yw] + 8*G[{1}, yu^(-1)]*
      G[{0, 0, 1, yv^(-1)}, yw] + 4*G[{1}, yv^(-1)]*G[{0, 0, 1, yv^(-1)}, 
       yw] - 6*G[{1}, yw]*G[{0, 0, 1, yv^(-1)}, yw] + 
     2*G[{yu^(-1)}, yw]*G[{0, 0, 1, yv^(-1)}, yw] - 
     4*G[{yu}, yv^(-1)]*G[{0, 0, 1, yv^(-1)}, yw] + 
     2*G[{yv^(-1)}, yw]*G[{0, 0, 1, yv^(-1)}, yw] + 
     2*G[{1/(yu*yv)}, yw]*G[{0, 0, 1, yv^(-1)}, yw] + 
     4*G[{0}, yu^(-1)]*G[{0, 0, 1, 1/(yu*yv)}, yw] + 
     4*G[{0}, yv^(-1)]*G[{0, 0, 1, 1/(yu*yv)}, yw] - 
     4*G[{0}, yw]*G[{0, 0, 1, 1/(yu*yv)}, yw] - 8*G[{1}, yu^(-1)]*
      G[{0, 0, 1, 1/(yu*yv)}, yw] - 8*G[{1}, yv^(-1)]*
      G[{0, 0, 1, 1/(yu*yv)}, yw] + 4*G[{1}, yw]*G[{0, 0, 1, 1/(yu*yv)}, 
       yw] + 8*G[{yu}, yv^(-1)]*G[{0, 0, 1, 1/(yu*yv)}, yw] - 
     4*G[{1/(yu*yv)}, yw]*G[{0, 0, 1, 1/(yu*yv)}, yw] - 
     4*G[{0}, yu^(-1)]*G[{0, 0, yu^(-1), 1}, yw] - 
     4*G[{0}, yv^(-1)]*G[{0, 0, yu^(-1), 1}, yw] + 
     4*G[{0}, yw]*G[{0, 0, yu^(-1), 1}, yw] + 4*G[{1}, yu^(-1)]*
      G[{0, 0, yu^(-1), 1}, yw] + 8*G[{1}, yv^(-1)]*G[{0, 0, yu^(-1), 1}, 
       yw] - 4*G[{1}, yw]*G[{0, 0, yu^(-1), 1}, yw] - 
     4*G[{yu}, yv^(-1)]*G[{0, 0, yu^(-1), 1}, yw] + 
     4*G[{1/(yu*yv)}, yw]*G[{0, 0, yu^(-1), 1}, yw] + 
     4*G[{0}, yu^(-1)]*G[{0, 0, yu^(-1), yu^(-1)}, yw] + 
     4*G[{0}, yv^(-1)]*G[{0, 0, yu^(-1), yu^(-1)}, yw] - 
     4*G[{0}, yw]*G[{0, 0, yu^(-1), yu^(-1)}, yw] - 
     4*G[{1}, yu^(-1)]*G[{0, 0, yu^(-1), yu^(-1)}, yw] - 
     8*G[{1}, yv^(-1)]*G[{0, 0, yu^(-1), yu^(-1)}, yw] + 
     6*G[{1}, yw]*G[{0, 0, yu^(-1), yu^(-1)}, yw] - 
     2*G[{yu^(-1)}, yw]*G[{0, 0, yu^(-1), yu^(-1)}, yw] + 
     4*G[{yu}, yv^(-1)]*G[{0, 0, yu^(-1), yu^(-1)}, yw] - 
     6*G[{yv^(-1)}, yw]*G[{0, 0, yu^(-1), yu^(-1)}, yw] + 
     2*G[{1/(yu*yv)}, yw]*G[{0, 0, yu^(-1), yu^(-1)}, yw] + 
     4*G[{0}, yu^(-1)]*G[{0, 0, yu^(-1), yv^(-1)}, yw] + 
     4*G[{0}, yv^(-1)]*G[{0, 0, yu^(-1), yv^(-1)}, yw] - 
     4*G[{0}, yw]*G[{0, 0, yu^(-1), yv^(-1)}, yw] - 
     8*G[{1}, yu^(-1)]*G[{0, 0, yu^(-1), yv^(-1)}, yw] - 
     4*G[{1}, yv^(-1)]*G[{0, 0, yu^(-1), yv^(-1)}, yw] + 
     2*G[{1}, yw]*G[{0, 0, yu^(-1), yv^(-1)}, yw] + 
     2*G[{yu^(-1)}, yw]*G[{0, 0, yu^(-1), yv^(-1)}, yw] + 
     4*G[{yu}, yv^(-1)]*G[{0, 0, yu^(-1), yv^(-1)}, yw] - 
     2*G[{yv^(-1)}, yw]*G[{0, 0, yu^(-1), yv^(-1)}, yw] - 
     2*G[{1/(yu*yv)}, yw]*G[{0, 0, yu^(-1), yv^(-1)}, yw] - 
     4*G[{0}, yu^(-1)]*G[{0, 0, yu^(-1), 1/(yu*yv)}, yw] - 
     4*G[{0}, yv^(-1)]*G[{0, 0, yu^(-1), 1/(yu*yv)}, yw] + 
     4*G[{0}, yw]*G[{0, 0, yu^(-1), 1/(yu*yv)}, yw] + 
     8*G[{1}, yu^(-1)]*G[{0, 0, yu^(-1), 1/(yu*yv)}, yw] + 
     8*G[{1}, yv^(-1)]*G[{0, 0, yu^(-1), 1/(yu*yv)}, yw] - 
     4*G[{yu^(-1)}, yw]*G[{0, 0, yu^(-1), 1/(yu*yv)}, yw] - 
     8*G[{yu}, yv^(-1)]*G[{0, 0, yu^(-1), 1/(yu*yv)}, yw] + 
     4*G[{1/(yu*yv)}, yw]*G[{0, 0, yu^(-1), 1/(yu*yv)}, yw] - 
     4*G[{1}, yu^(-1)]*G[{0, 0, yu, 1}, yv^(-1)] - 
     4*G[{1}, yv^(-1)]*G[{0, 0, yu, 1}, yv^(-1)] + 
     4*G[{yu}, yv^(-1)]*G[{0, 0, yu, 1}, yv^(-1)] + 
     4*G[{yv^(-1)}, yw]*G[{0, 0, yu, 1}, yv^(-1)] - 
     4*G[{1/(yu*yv)}, yw]*G[{0, 0, yu, 1}, yv^(-1)] + 
     4*G[{1}, yu^(-1)]*G[{0, 0, yu, yu}, yv^(-1)] + 
     4*G[{1}, yv^(-1)]*G[{0, 0, yu, yu}, yv^(-1)] - 
     2*G[{yu^(-1)}, yw]*G[{0, 0, yu, yu}, yv^(-1)] - 
     6*G[{yu}, yv^(-1)]*G[{0, 0, yu, yu}, yv^(-1)] - 
     4*G[{yv^(-1)}, yw]*G[{0, 0, yu, yu}, yv^(-1)] + 
     6*G[{1/(yu*yv)}, yw]*G[{0, 0, yu, yu}, yv^(-1)] - 
     4*G[{0}, yu^(-1)]*G[{0, 0, yv^(-1), 1}, yw] - 
     4*G[{0}, yv^(-1)]*G[{0, 0, yv^(-1), 1}, yw] + 
     4*G[{0}, yw]*G[{0, 0, yv^(-1), 1}, yw] + 8*G[{1}, yu^(-1)]*
      G[{0, 0, yv^(-1), 1}, yw] + 4*G[{1}, yv^(-1)]*G[{0, 0, yv^(-1), 1}, 
       yw] - 4*G[{1}, yw]*G[{0, 0, yv^(-1), 1}, yw] - 
     4*G[{yu}, yv^(-1)]*G[{0, 0, yv^(-1), 1}, yw] + 
     4*G[{1/(yu*yv)}, yw]*G[{0, 0, yv^(-1), 1}, yw] + 
     4*G[{0}, yu^(-1)]*G[{0, 0, yv^(-1), yu^(-1)}, yw] + 
     4*G[{0}, yv^(-1)]*G[{0, 0, yv^(-1), yu^(-1)}, yw] - 
     4*G[{0}, yw]*G[{0, 0, yv^(-1), yu^(-1)}, yw] - 
     8*G[{1}, yu^(-1)]*G[{0, 0, yv^(-1), yu^(-1)}, yw] - 
     4*G[{1}, yv^(-1)]*G[{0, 0, yv^(-1), yu^(-1)}, yw] + 
     2*G[{1}, yw]*G[{0, 0, yv^(-1), yu^(-1)}, yw] + 
     2*G[{yu^(-1)}, yw]*G[{0, 0, yv^(-1), yu^(-1)}, yw] + 
     4*G[{yu}, yv^(-1)]*G[{0, 0, yv^(-1), yu^(-1)}, yw] - 
     2*G[{yv^(-1)}, yw]*G[{0, 0, yv^(-1), yu^(-1)}, yw] - 
     2*G[{1/(yu*yv)}, yw]*G[{0, 0, yv^(-1), yu^(-1)}, yw] + 
     4*G[{0}, yu^(-1)]*G[{0, 0, yv^(-1), yv^(-1)}, yw] + 
     4*G[{0}, yv^(-1)]*G[{0, 0, yv^(-1), yv^(-1)}, yw] - 
     4*G[{0}, yw]*G[{0, 0, yv^(-1), yv^(-1)}, yw] - 
     8*G[{1}, yu^(-1)]*G[{0, 0, yv^(-1), yv^(-1)}, yw] - 
     4*G[{1}, yv^(-1)]*G[{0, 0, yv^(-1), yv^(-1)}, yw] + 
     6*G[{1}, yw]*G[{0, 0, yv^(-1), yv^(-1)}, yw] - 
     6*G[{yu^(-1)}, yw]*G[{0, 0, yv^(-1), yv^(-1)}, yw] + 
     4*G[{yu}, yv^(-1)]*G[{0, 0, yv^(-1), yv^(-1)}, yw] - 
     2*G[{yv^(-1)}, yw]*G[{0, 0, yv^(-1), yv^(-1)}, yw] + 
     2*G[{1/(yu*yv)}, yw]*G[{0, 0, yv^(-1), yv^(-1)}, yw] - 
     4*G[{0}, yu^(-1)]*G[{0, 0, yv^(-1), 1/(yu*yv)}, yw] - 
     4*G[{0}, yv^(-1)]*G[{0, 0, yv^(-1), 1/(yu*yv)}, yw] + 
     4*G[{0}, yw]*G[{0, 0, yv^(-1), 1/(yu*yv)}, yw] + 
     8*G[{1}, yu^(-1)]*G[{0, 0, yv^(-1), 1/(yu*yv)}, yw] + 
     8*G[{1}, yv^(-1)]*G[{0, 0, yv^(-1), 1/(yu*yv)}, yw] - 
     8*G[{yu}, yv^(-1)]*G[{0, 0, yv^(-1), 1/(yu*yv)}, yw] - 
     4*G[{yv^(-1)}, yw]*G[{0, 0, yv^(-1), 1/(yu*yv)}, yw] + 
     4*G[{1/(yu*yv)}, yw]*G[{0, 0, yv^(-1), 1/(yu*yv)}, yw] + 
     4*G[{0}, yu^(-1)]*G[{0, 0, 1/(yu*yv), 1}, yw] + 
     4*G[{0}, yv^(-1)]*G[{0, 0, 1/(yu*yv), 1}, yw] - 
     4*G[{0}, yw]*G[{0, 0, 1/(yu*yv), 1}, yw] - 8*G[{1}, yu^(-1)]*
      G[{0, 0, 1/(yu*yv), 1}, yw] - 8*G[{1}, yv^(-1)]*
      G[{0, 0, 1/(yu*yv), 1}, yw] + 8*G[{1}, yw]*G[{0, 0, 1/(yu*yv), 1}, 
       yw] - 4*G[{yu^(-1)}, yw]*G[{0, 0, 1/(yu*yv), 1}, yw] + 
     8*G[{yu}, yv^(-1)]*G[{0, 0, 1/(yu*yv), 1}, yw] - 
     4*G[{yv^(-1)}, yw]*G[{0, 0, 1/(yu*yv), 1}, yw] - 
     4*G[{0}, yu^(-1)]*G[{0, 0, 1/(yu*yv), yu^(-1)}, yw] - 
     4*G[{0}, yv^(-1)]*G[{0, 0, 1/(yu*yv), yu^(-1)}, yw] + 
     4*G[{0}, yw]*G[{0, 0, 1/(yu*yv), yu^(-1)}, yw] + 
     8*G[{1}, yu^(-1)]*G[{0, 0, 1/(yu*yv), yu^(-1)}, yw] + 
     8*G[{1}, yv^(-1)]*G[{0, 0, 1/(yu*yv), yu^(-1)}, yw] - 
     6*G[{1}, yw]*G[{0, 0, 1/(yu*yv), yu^(-1)}, yw] + 
     2*G[{yu^(-1)}, yw]*G[{0, 0, 1/(yu*yv), yu^(-1)}, yw] - 
     8*G[{yu}, yv^(-1)]*G[{0, 0, 1/(yu*yv), yu^(-1)}, yw] + 
     6*G[{yv^(-1)}, yw]*G[{0, 0, 1/(yu*yv), yu^(-1)}, yw] - 
     2*G[{1/(yu*yv)}, yw]*G[{0, 0, 1/(yu*yv), yu^(-1)}, yw] - 
     4*G[{0}, yu^(-1)]*G[{0, 0, 1/(yu*yv), yv^(-1)}, yw] - 
     4*G[{0}, yv^(-1)]*G[{0, 0, 1/(yu*yv), yv^(-1)}, yw] + 
     4*G[{0}, yw]*G[{0, 0, 1/(yu*yv), yv^(-1)}, yw] + 
     8*G[{1}, yu^(-1)]*G[{0, 0, 1/(yu*yv), yv^(-1)}, yw] + 
     8*G[{1}, yv^(-1)]*G[{0, 0, 1/(yu*yv), yv^(-1)}, yw] - 
     6*G[{1}, yw]*G[{0, 0, 1/(yu*yv), yv^(-1)}, yw] + 
     6*G[{yu^(-1)}, yw]*G[{0, 0, 1/(yu*yv), yv^(-1)}, yw] - 
     8*G[{yu}, yv^(-1)]*G[{0, 0, 1/(yu*yv), yv^(-1)}, yw] + 
     2*G[{yv^(-1)}, yw]*G[{0, 0, 1/(yu*yv), yv^(-1)}, yw] - 
     2*G[{1/(yu*yv)}, yw]*G[{0, 0, 1/(yu*yv), yv^(-1)}, yw] + 
     4*G[{0}, yu^(-1)]*G[{0, 0, 1/(yu*yv), 1/(yu*yv)}, yw] + 
     4*G[{0}, yv^(-1)]*G[{0, 0, 1/(yu*yv), 1/(yu*yv)}, yw] - 
     4*G[{0}, yw]*G[{0, 0, 1/(yu*yv), 1/(yu*yv)}, yw] - 
     8*G[{1}, yu^(-1)]*G[{0, 0, 1/(yu*yv), 1/(yu*yv)}, yw] - 
     8*G[{1}, yv^(-1)]*G[{0, 0, 1/(yu*yv), 1/(yu*yv)}, yw] - 
     4*G[{1}, yw]*G[{0, 0, 1/(yu*yv), 1/(yu*yv)}, yw] + 
     4*G[{yu^(-1)}, yw]*G[{0, 0, 1/(yu*yv), 1/(yu*yv)}, yw] + 
     8*G[{yu}, yv^(-1)]*G[{0, 0, 1/(yu*yv), 1/(yu*yv)}, yw] + 
     4*G[{yv^(-1)}, yw]*G[{0, 0, 1/(yu*yv), 1/(yu*yv)}, yw] - 
     4*G[{1/(yu*yv)}, yw]*G[{0, 0, 1/(yu*yv), 1/(yu*yv)}, yw] + 
     2*G[{1}, yv^(-1)]*G[{0, 1, 0, yu^(-1)}, yw] - 
     2*G[{1}, yw]*G[{0, 1, 0, yu^(-1)}, yw] + 2*G[{yu^(-1)}, yw]*
      G[{0, 1, 0, yu^(-1)}, yw] - 2*G[{yu}, yv^(-1)]*
      G[{0, 1, 0, yu^(-1)}, yw] - 2*G[{1}, yv^(-1)]*
      G[{0, 1, 0, yu}, yv^(-1)] + 2*G[{1}, yw]*G[{0, 1, 0, yu}, yv^(-1)] - 
     2*G[{yu^(-1)}, yw]*G[{0, 1, 0, yu}, yv^(-1)] + 
     2*G[{yu}, yv^(-1)]*G[{0, 1, 0, yu}, yv^(-1)] + 
     2*G[{1}, yu^(-1)]*G[{0, 1, 0, yv^(-1)}, yw] - 
     2*G[{1}, yw]*G[{0, 1, 0, yv^(-1)}, yw] - 2*G[{yu}, yv^(-1)]*
      G[{0, 1, 0, yv^(-1)}, yw] + 2*G[{yv^(-1)}, yw]*
      G[{0, 1, 0, yv^(-1)}, yw] - 2*G[{1}, yu^(-1)]*G[{0, 1, 0, 1/(yu*yv)}, 
       yw] - 2*G[{1}, yv^(-1)]*G[{0, 1, 0, 1/(yu*yv)}, yw] + 
     4*G[{1}, yw]*G[{0, 1, 0, 1/(yu*yv)}, yw] - 2*G[{yu^(-1)}, yw]*
      G[{0, 1, 0, 1/(yu*yv)}, yw] + 4*G[{yu}, yv^(-1)]*
      G[{0, 1, 0, 1/(yu*yv)}, yw] - 2*G[{yv^(-1)}, yw]*
      G[{0, 1, 0, 1/(yu*yv)}, yw] + 6*G[{1}, yw]*G[{0, 1, 1, 1}, yu^(-1)] - 
     6*G[{yu^(-1)}, yw]*G[{0, 1, 1, 1}, yu^(-1)] - 
     6*G[{yv^(-1)}, yw]*G[{0, 1, 1, 1}, yu^(-1)] + 6*G[{1/(yu*yv)}, yw]*
      G[{0, 1, 1, 1}, yu^(-1)] + 2*G[{1}, yu^(-1)]*G[{0, 1, 1, 1}, yv^(-1)] + 
     6*G[{1}, yw]*G[{0, 1, 1, 1}, yv^(-1)] - 6*G[{yu^(-1)}, yw]*
      G[{0, 1, 1, 1}, yv^(-1)] - 6*G[{yv^(-1)}, yw]*
      G[{0, 1, 1, 1}, yv^(-1)] + 6*G[{1/(yu*yv)}, yw]*
      G[{0, 1, 1, 1}, yv^(-1)] - G[{0}, yu^(-1)]*G[{0, 1, 1, 1}, yw] - 
     G[{0}, yv^(-1)]*G[{0, 1, 1, 1}, yw] + G[{0}, yw]*G[{0, 1, 1, 1}, yw] + 
     G[{1}, yu^(-1)]*G[{0, 1, 1, 1}, yw] + G[{1}, yv^(-1)]*
      G[{0, 1, 1, 1}, yw] + 2*G[{1}, yw]*G[{0, 1, 1, 1}, yw] - 
     2*G[{1/(yu*yv)}, yw]*G[{0, 1, 1, 1}, yw] + G[{0}, yu^(-1)]*
      G[{0, 1, 1, yu^(-1)}, yw] + G[{0}, yv^(-1)]*G[{0, 1, 1, yu^(-1)}, yw] - 
     G[{0}, yw]*G[{0, 1, 1, yu^(-1)}, yw] - G[{1}, yu^(-1)]*
      G[{0, 1, 1, yu^(-1)}, yw] - 7*G[{1}, yv^(-1)]*G[{0, 1, 1, yu^(-1)}, 
       yw] + 2*G[{yu^(-1)}, yw]*G[{0, 1, 1, yu^(-1)}, yw] + 
     6*G[{yu}, yv^(-1)]*G[{0, 1, 1, yu^(-1)}, yw] + 
     4*G[{yv^(-1)}, yw]*G[{0, 1, 1, yu^(-1)}, yw] - 
     6*G[{1/(yu*yv)}, yw]*G[{0, 1, 1, yu^(-1)}, yw] + 
     2*G[{1}, yu^(-1)]*G[{0, 1, 1, yu}, yv^(-1)] + 
     6*G[{1}, yv^(-1)]*G[{0, 1, 1, yu}, yv^(-1)] + 
     4*G[{yu^(-1)}, yw]*G[{0, 1, 1, yu}, yv^(-1)] - 
     2*G[{yu}, yv^(-1)]*G[{0, 1, 1, yu}, yv^(-1)] - 
     6*G[{yv^(-1)}, yw]*G[{0, 1, 1, yu}, yv^(-1)] + 
     2*G[{1/(yu*yv)}, yw]*G[{0, 1, 1, yu}, yv^(-1)] + 
     G[{0}, yu^(-1)]*G[{0, 1, 1, yv^(-1)}, yw] + 
     G[{0}, yv^(-1)]*G[{0, 1, 1, yv^(-1)}, yw] - 
     G[{0}, yw]*G[{0, 1, 1, yv^(-1)}, yw] - 7*G[{1}, yu^(-1)]*
      G[{0, 1, 1, yv^(-1)}, yw] - G[{1}, yv^(-1)]*G[{0, 1, 1, yv^(-1)}, yw] + 
     4*G[{yu^(-1)}, yw]*G[{0, 1, 1, yv^(-1)}, yw] + 
     6*G[{yu}, yv^(-1)]*G[{0, 1, 1, yv^(-1)}, yw] + 
     2*G[{yv^(-1)}, yw]*G[{0, 1, 1, yv^(-1)}, yw] - 
     6*G[{1/(yu*yv)}, yw]*G[{0, 1, 1, yv^(-1)}, yw] + 
     7*G[{0}, yu^(-1)]*G[{0, 1, 1, 1/(yu*yv)}, yw] + 
     7*G[{0}, yv^(-1)]*G[{0, 1, 1, 1/(yu*yv)}, yw] - 
     7*G[{0}, yw]*G[{0, 1, 1, 1/(yu*yv)}, yw] - G[{1}, yu^(-1)]*
      G[{0, 1, 1, 1/(yu*yv)}, yw] - G[{1}, yv^(-1)]*G[{0, 1, 1, 1/(yu*yv)}, 
       yw] + 2*G[{1}, yw]*G[{0, 1, 1, 1/(yu*yv)}, yw] - 
     2*G[{yu^(-1)}, yw]*G[{0, 1, 1, 1/(yu*yv)}, yw] - 
     12*G[{yu}, yv^(-1)]*G[{0, 1, 1, 1/(yu*yv)}, yw] - 
     2*G[{yv^(-1)}, yw]*G[{0, 1, 1, 1/(yu*yv)}, yw] + 
     2*G[{1/(yu*yv)}, yw]*G[{0, 1, 1, 1/(yu*yv)}, yw] + 
     3*G[{0}, yu^(-1)]*G[{0, 1, yu^(-1), 1}, yw] + 
     3*G[{0}, yv^(-1)]*G[{0, 1, yu^(-1), 1}, yw] - 
     3*G[{0}, yw]*G[{0, 1, yu^(-1), 1}, yw] - 3*G[{1}, yu^(-1)]*
      G[{0, 1, yu^(-1), 1}, yw] - 7*G[{1}, yv^(-1)]*G[{0, 1, yu^(-1), 1}, 
       yw] + 2*G[{1}, yw]*G[{0, 1, yu^(-1), 1}, yw] + 
     2*G[{yu^(-1)}, yw]*G[{0, 1, yu^(-1), 1}, yw] + 
     4*G[{yu}, yv^(-1)]*G[{0, 1, yu^(-1), 1}, yw] + 
     2*G[{yv^(-1)}, yw]*G[{0, 1, yu^(-1), 1}, yw] - 
     6*G[{1/(yu*yv)}, yw]*G[{0, 1, yu^(-1), 1}, yw] - 
     3*G[{0}, yu^(-1)]*G[{0, 1, yu^(-1), yu^(-1)}, yw] - 
     3*G[{0}, yv^(-1)]*G[{0, 1, yu^(-1), yu^(-1)}, yw] + 
     3*G[{0}, yw]*G[{0, 1, yu^(-1), yu^(-1)}, yw] + 
     3*G[{1}, yu^(-1)]*G[{0, 1, yu^(-1), yu^(-1)}, yw] + 
     11*G[{1}, yv^(-1)]*G[{0, 1, yu^(-1), yu^(-1)}, yw] - 
     4*G[{1}, yw]*G[{0, 1, yu^(-1), yu^(-1)}, yw] - 
     4*G[{yu^(-1)}, yw]*G[{0, 1, yu^(-1), yu^(-1)}, yw] - 
     8*G[{yu}, yv^(-1)]*G[{0, 1, yu^(-1), yu^(-1)}, yw] + 
     8*G[{1/(yu*yv)}, yw]*G[{0, 1, yu^(-1), yu^(-1)}, yw] - 
     3*G[{0}, yu^(-1)]*G[{0, 1, yu^(-1), yv^(-1)}, yw] - 
     3*G[{0}, yv^(-1)]*G[{0, 1, yu^(-1), yv^(-1)}, yw] + 
     3*G[{0}, yw]*G[{0, 1, yu^(-1), yv^(-1)}, yw] + 
     7*G[{1}, yu^(-1)]*G[{0, 1, yu^(-1), yv^(-1)}, yw] + 
     7*G[{1}, yv^(-1)]*G[{0, 1, yu^(-1), yv^(-1)}, yw] - 
     4*G[{yu^(-1)}, yw]*G[{0, 1, yu^(-1), yv^(-1)}, yw] - 
     8*G[{yu}, yv^(-1)]*G[{0, 1, yu^(-1), yv^(-1)}, yw] - 
     4*G[{yv^(-1)}, yw]*G[{0, 1, yu^(-1), yv^(-1)}, yw] + 
     8*G[{1/(yu*yv)}, yw]*G[{0, 1, yu^(-1), yv^(-1)}, yw] - 
     5*G[{0}, yu^(-1)]*G[{0, 1, yu^(-1), 1/(yu*yv)}, yw] - 
     5*G[{0}, yv^(-1)]*G[{0, 1, yu^(-1), 1/(yu*yv)}, yw] + 
     5*G[{0}, yw]*G[{0, 1, yu^(-1), 1/(yu*yv)}, yw] + 
     G[{1}, yu^(-1)]*G[{0, 1, yu^(-1), 1/(yu*yv)}, yw] + 
     G[{1}, yv^(-1)]*G[{0, 1, yu^(-1), 1/(yu*yv)}, yw] - 
     6*G[{1}, yw]*G[{0, 1, yu^(-1), 1/(yu*yv)}, yw] + 
     6*G[{yu^(-1)}, yw]*G[{0, 1, yu^(-1), 1/(yu*yv)}, yw] + 
     8*G[{yu}, yv^(-1)]*G[{0, 1, yu^(-1), 1/(yu*yv)}, yw] + 
     6*G[{yv^(-1)}, yw]*G[{0, 1, yu^(-1), 1/(yu*yv)}, yw] - 
     6*G[{1/(yu*yv)}, yw]*G[{0, 1, yu^(-1), 1/(yu*yv)}, yw] + 
     4*G[{1}, yu^(-1)]*G[{0, 1, yu, 1}, yv^(-1)] + 
     4*G[{1}, yv^(-1)]*G[{0, 1, yu, 1}, yv^(-1)] + 
     2*G[{yu^(-1)}, yw]*G[{0, 1, yu, 1}, yv^(-1)] - 
     2*G[{yu}, yv^(-1)]*G[{0, 1, yu, 1}, yv^(-1)] - 
     4*G[{yv^(-1)}, yw]*G[{0, 1, yu, 1}, yv^(-1)] + 
     2*G[{1/(yu*yv)}, yw]*G[{0, 1, yu, 1}, yv^(-1)] - 
     8*G[{1}, yu^(-1)]*G[{0, 1, yu, yu}, yv^(-1)] - 
     8*G[{1}, yv^(-1)]*G[{0, 1, yu, yu}, yv^(-1)] - 
     4*G[{1}, yw]*G[{0, 1, yu, yu}, yv^(-1)] + 4*G[{yu}, yv^(-1)]*
      G[{0, 1, yu, yu}, yv^(-1)] + 12*G[{yv^(-1)}, yw]*
      G[{0, 1, yu, yu}, yv^(-1)] - 8*G[{1/(yu*yv)}, yw]*
      G[{0, 1, yu, yu}, yv^(-1)] + 3*G[{0}, yu^(-1)]*
      G[{0, 1, yv^(-1), 1}, yw] + 3*G[{0}, yv^(-1)]*G[{0, 1, yv^(-1), 1}, 
       yw] - 3*G[{0}, yw]*G[{0, 1, yv^(-1), 1}, yw] - 
     7*G[{1}, yu^(-1)]*G[{0, 1, yv^(-1), 1}, yw] - 
     3*G[{1}, yv^(-1)]*G[{0, 1, yv^(-1), 1}, yw] + 
     2*G[{1}, yw]*G[{0, 1, yv^(-1), 1}, yw] + 2*G[{yu^(-1)}, yw]*
      G[{0, 1, yv^(-1), 1}, yw] + 4*G[{yu}, yv^(-1)]*
      G[{0, 1, yv^(-1), 1}, yw] + 2*G[{yv^(-1)}, yw]*
      G[{0, 1, yv^(-1), 1}, yw] - 6*G[{1/(yu*yv)}, yw]*
      G[{0, 1, yv^(-1), 1}, yw] - 3*G[{0}, yu^(-1)]*
      G[{0, 1, yv^(-1), yu^(-1)}, yw] - 3*G[{0}, yv^(-1)]*
      G[{0, 1, yv^(-1), yu^(-1)}, yw] + 3*G[{0}, yw]*
      G[{0, 1, yv^(-1), yu^(-1)}, yw] + 7*G[{1}, yu^(-1)]*
      G[{0, 1, yv^(-1), yu^(-1)}, yw] + 7*G[{1}, yv^(-1)]*
      G[{0, 1, yv^(-1), yu^(-1)}, yw] - 4*G[{yu^(-1)}, yw]*
      G[{0, 1, yv^(-1), yu^(-1)}, yw] - 8*G[{yu}, yv^(-1)]*
      G[{0, 1, yv^(-1), yu^(-1)}, yw] - 4*G[{yv^(-1)}, yw]*
      G[{0, 1, yv^(-1), yu^(-1)}, yw] + 8*G[{1/(yu*yv)}, yw]*
      G[{0, 1, yv^(-1), yu^(-1)}, yw] - 3*G[{0}, yu^(-1)]*
      G[{0, 1, yv^(-1), yv^(-1)}, yw] - 3*G[{0}, yv^(-1)]*
      G[{0, 1, yv^(-1), yv^(-1)}, yw] + 3*G[{0}, yw]*
      G[{0, 1, yv^(-1), yv^(-1)}, yw] + 11*G[{1}, yu^(-1)]*
      G[{0, 1, yv^(-1), yv^(-1)}, yw] + 3*G[{1}, yv^(-1)]*
      G[{0, 1, yv^(-1), yv^(-1)}, yw] - 4*G[{1}, yw]*
      G[{0, 1, yv^(-1), yv^(-1)}, yw] - 8*G[{yu}, yv^(-1)]*
      G[{0, 1, yv^(-1), yv^(-1)}, yw] - 4*G[{yv^(-1)}, yw]*
      G[{0, 1, yv^(-1), yv^(-1)}, yw] + 8*G[{1/(yu*yv)}, yw]*
      G[{0, 1, yv^(-1), yv^(-1)}, yw] - 5*G[{0}, yu^(-1)]*
      G[{0, 1, yv^(-1), 1/(yu*yv)}, yw] - 5*G[{0}, yv^(-1)]*
      G[{0, 1, yv^(-1), 1/(yu*yv)}, yw] + 5*G[{0}, yw]*
      G[{0, 1, yv^(-1), 1/(yu*yv)}, yw] + G[{1}, yu^(-1)]*
      G[{0, 1, yv^(-1), 1/(yu*yv)}, yw] + G[{1}, yv^(-1)]*
      G[{0, 1, yv^(-1), 1/(yu*yv)}, yw] - 6*G[{1}, yw]*
      G[{0, 1, yv^(-1), 1/(yu*yv)}, yw] + 6*G[{yu^(-1)}, yw]*
      G[{0, 1, yv^(-1), 1/(yu*yv)}, yw] + 8*G[{yu}, yv^(-1)]*
      G[{0, 1, yv^(-1), 1/(yu*yv)}, yw] + 6*G[{yv^(-1)}, yw]*
      G[{0, 1, yv^(-1), 1/(yu*yv)}, yw] - 6*G[{1/(yu*yv)}, yw]*
      G[{0, 1, yv^(-1), 1/(yu*yv)}, yw] + 3*G[{0}, yu^(-1)]*
      G[{0, 1, 1/(yu*yv), 1}, yw] + 3*G[{0}, yv^(-1)]*
      G[{0, 1, 1/(yu*yv), 1}, yw] - 3*G[{0}, yw]*G[{0, 1, 1/(yu*yv), 1}, 
       yw] + G[{1}, yu^(-1)]*G[{0, 1, 1/(yu*yv), 1}, yw] + 
     G[{1}, yv^(-1)]*G[{0, 1, 1/(yu*yv), 1}, yw] - 
     2*G[{1}, yw]*G[{0, 1, 1/(yu*yv), 1}, yw] - 8*G[{yu}, yv^(-1)]*
      G[{0, 1, 1/(yu*yv), 1}, yw] + 2*G[{1/(yu*yv)}, yw]*
      G[{0, 1, 1/(yu*yv), 1}, yw] - 3*G[{0}, yu^(-1)]*
      G[{0, 1, 1/(yu*yv), yu^(-1)}, yw] - 3*G[{0}, yv^(-1)]*
      G[{0, 1, 1/(yu*yv), yu^(-1)}, yw] + 3*G[{0}, yw]*
      G[{0, 1, 1/(yu*yv), yu^(-1)}, yw] - G[{1}, yu^(-1)]*
      G[{0, 1, 1/(yu*yv), yu^(-1)}, yw] + G[{1}, yv^(-1)]*
      G[{0, 1, 1/(yu*yv), yu^(-1)}, yw] + 2*G[{yu^(-1)}, yw]*
      G[{0, 1, 1/(yu*yv), yu^(-1)}, yw] + 6*G[{yu}, yv^(-1)]*
      G[{0, 1, 1/(yu*yv), yu^(-1)}, yw] + 4*G[{yv^(-1)}, yw]*
      G[{0, 1, 1/(yu*yv), yu^(-1)}, yw] - 6*G[{1/(yu*yv)}, yw]*
      G[{0, 1, 1/(yu*yv), yu^(-1)}, yw] - 3*G[{0}, yu^(-1)]*
      G[{0, 1, 1/(yu*yv), yv^(-1)}, yw] - 3*G[{0}, yv^(-1)]*
      G[{0, 1, 1/(yu*yv), yv^(-1)}, yw] + 3*G[{0}, yw]*
      G[{0, 1, 1/(yu*yv), yv^(-1)}, yw] + G[{1}, yu^(-1)]*
      G[{0, 1, 1/(yu*yv), yv^(-1)}, yw] - G[{1}, yv^(-1)]*
      G[{0, 1, 1/(yu*yv), yv^(-1)}, yw] + 4*G[{yu^(-1)}, yw]*
      G[{0, 1, 1/(yu*yv), yv^(-1)}, yw] + 6*G[{yu}, yv^(-1)]*
      G[{0, 1, 1/(yu*yv), yv^(-1)}, yw] + 2*G[{yv^(-1)}, yw]*
      G[{0, 1, 1/(yu*yv), yv^(-1)}, yw] - 6*G[{1/(yu*yv)}, yw]*
      G[{0, 1, 1/(yu*yv), yv^(-1)}, yw] + 11*G[{0}, yu^(-1)]*
      G[{0, 1, 1/(yu*yv), 1/(yu*yv)}, yw] + 11*G[{0}, yv^(-1)]*
      G[{0, 1, 1/(yu*yv), 1/(yu*yv)}, yw] - 11*G[{0}, yw]*
      G[{0, 1, 1/(yu*yv), 1/(yu*yv)}, yw] - 13*G[{1}, yu^(-1)]*
      G[{0, 1, 1/(yu*yv), 1/(yu*yv)}, yw] - 13*G[{1}, yv^(-1)]*
      G[{0, 1, 1/(yu*yv), 1/(yu*yv)}, yw] + 2*G[{1}, yw]*
      G[{0, 1, 1/(yu*yv), 1/(yu*yv)}, yw] - 2*G[{yu^(-1)}, yw]*
      G[{0, 1, 1/(yu*yv), 1/(yu*yv)}, yw] + 4*G[{yu}, yv^(-1)]*
      G[{0, 1, 1/(yu*yv), 1/(yu*yv)}, yw] - 2*G[{yv^(-1)}, yw]*
      G[{0, 1, 1/(yu*yv), 1/(yu*yv)}, yw] + 2*G[{1/(yu*yv)}, yw]*
      G[{0, 1, 1/(yu*yv), 1/(yu*yv)}, yw] - 2*G[{1}, yu^(-1)]*
      G[{0, yu^(-1), 0, yv^(-1)}, yw] + 2*G[{1}, yv^(-1)]*
      G[{0, yu^(-1), 0, yv^(-1)}, yw] + 2*G[{yu^(-1)}, yw]*
      G[{0, yu^(-1), 0, yv^(-1)}, yw] - 2*G[{yv^(-1)}, yw]*
      G[{0, yu^(-1), 0, yv^(-1)}, yw] + 2*G[{1}, yu^(-1)]*
      G[{0, yu^(-1), 0, 1/(yu*yv)}, yw] - 2*G[{1}, yw]*
      G[{0, yu^(-1), 0, 1/(yu*yv)}, yw] - 2*G[{yu}, yv^(-1)]*
      G[{0, yu^(-1), 0, 1/(yu*yv)}, yw] + 2*G[{yv^(-1)}, yw]*
      G[{0, yu^(-1), 0, 1/(yu*yv)}, yw] + G[{0}, yu^(-1)]*
      G[{0, yu^(-1), 1, 1}, yw] + G[{0}, yv^(-1)]*G[{0, yu^(-1), 1, 1}, yw] - 
     G[{0}, yw]*G[{0, yu^(-1), 1, 1}, yw] - G[{1}, yu^(-1)]*
      G[{0, yu^(-1), 1, 1}, yw] - G[{1}, yv^(-1)]*G[{0, yu^(-1), 1, 1}, yw] - 
     2*G[{1}, yw]*G[{0, yu^(-1), 1, 1}, yw] + 4*G[{yv^(-1)}, yw]*
      G[{0, yu^(-1), 1, 1}, yw] - 2*G[{1/(yu*yv)}, yw]*
      G[{0, yu^(-1), 1, 1}, yw] - G[{0}, yu^(-1)]*G[{0, yu^(-1), 1, yu^(-1)}, 
       yw] - G[{0}, yv^(-1)]*G[{0, yu^(-1), 1, yu^(-1)}, yw] + 
     G[{0}, yw]*G[{0, yu^(-1), 1, yu^(-1)}, yw] + 
     G[{1}, yu^(-1)]*G[{0, yu^(-1), 1, yu^(-1)}, yw] + 
     7*G[{1}, yv^(-1)]*G[{0, yu^(-1), 1, yu^(-1)}, yw] - 
     2*G[{yu^(-1)}, yw]*G[{0, yu^(-1), 1, yu^(-1)}, yw] - 
     6*G[{yu}, yv^(-1)]*G[{0, yu^(-1), 1, yu^(-1)}, yw] - 
     4*G[{yv^(-1)}, yw]*G[{0, yu^(-1), 1, yu^(-1)}, yw] + 
     6*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1), 1, yu^(-1)}, yw] - 
     G[{0}, yu^(-1)]*G[{0, yu^(-1), 1, yv^(-1)}, yw] - 
     G[{0}, yv^(-1)]*G[{0, yu^(-1), 1, yv^(-1)}, yw] + 
     G[{0}, yw]*G[{0, yu^(-1), 1, yv^(-1)}, yw] + 
     3*G[{1}, yu^(-1)]*G[{0, yu^(-1), 1, yv^(-1)}, yw] + 
     G[{1}, yv^(-1)]*G[{0, yu^(-1), 1, yv^(-1)}, yw] - 
     4*G[{yu^(-1)}, yw]*G[{0, yu^(-1), 1, yv^(-1)}, yw] - 
     2*G[{yu}, yv^(-1)]*G[{0, yu^(-1), 1, yv^(-1)}, yw] - 
     2*G[{yv^(-1)}, yw]*G[{0, yu^(-1), 1, yv^(-1)}, yw] + 
     6*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1), 1, yv^(-1)}, yw] - 
     7*G[{0}, yu^(-1)]*G[{0, yu^(-1), 1, 1/(yu*yv)}, yw] - 
     7*G[{0}, yv^(-1)]*G[{0, yu^(-1), 1, 1/(yu*yv)}, yw] + 
     7*G[{0}, yw]*G[{0, yu^(-1), 1, 1/(yu*yv)}, yw] + 
     5*G[{1}, yu^(-1)]*G[{0, yu^(-1), 1, 1/(yu*yv)}, yw] + 
     5*G[{1}, yv^(-1)]*G[{0, yu^(-1), 1, 1/(yu*yv)}, yw] - 
     2*G[{1}, yw]*G[{0, yu^(-1), 1, 1/(yu*yv)}, yw] + 
     2*G[{yu^(-1)}, yw]*G[{0, yu^(-1), 1, 1/(yu*yv)}, yw] + 
     4*G[{yu}, yv^(-1)]*G[{0, yu^(-1), 1, 1/(yu*yv)}, yw] + 
     2*G[{yv^(-1)}, yw]*G[{0, yu^(-1), 1, 1/(yu*yv)}, yw] - 
     2*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1), 1, 1/(yu*yv)}, yw] - 
     3*G[{0}, yu^(-1)]*G[{0, yu^(-1), yu^(-1), 1}, yw] - 
     3*G[{0}, yv^(-1)]*G[{0, yu^(-1), yu^(-1), 1}, yw] + 
     3*G[{0}, yw]*G[{0, yu^(-1), yu^(-1), 1}, yw] + 
     3*G[{1}, yu^(-1)]*G[{0, yu^(-1), yu^(-1), 1}, yw] + 
     7*G[{1}, yv^(-1)]*G[{0, yu^(-1), yu^(-1), 1}, yw] - 
     2*G[{1}, yw]*G[{0, yu^(-1), yu^(-1), 1}, yw] - 
     2*G[{yu^(-1)}, yw]*G[{0, yu^(-1), yu^(-1), 1}, yw] - 
     4*G[{yu}, yv^(-1)]*G[{0, yu^(-1), yu^(-1), 1}, yw] - 
     2*G[{yv^(-1)}, yw]*G[{0, yu^(-1), yu^(-1), 1}, yw] + 
     6*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1), yu^(-1), 1}, yw] + 
     3*G[{0}, yu^(-1)]*G[{0, yu^(-1), yu^(-1), yu^(-1)}, yw] + 
     3*G[{0}, yv^(-1)]*G[{0, yu^(-1), yu^(-1), yu^(-1)}, yw] - 
     3*G[{0}, yw]*G[{0, yu^(-1), yu^(-1), yu^(-1)}, yw] - 
     3*G[{1}, yu^(-1)]*G[{0, yu^(-1), yu^(-1), yu^(-1)}, yw] - 
     11*G[{1}, yv^(-1)]*G[{0, yu^(-1), yu^(-1), yu^(-1)}, yw] + 
     4*G[{1}, yw]*G[{0, yu^(-1), yu^(-1), yu^(-1)}, yw] + 
     4*G[{yu^(-1)}, yw]*G[{0, yu^(-1), yu^(-1), yu^(-1)}, yw] + 
     8*G[{yu}, yv^(-1)]*G[{0, yu^(-1), yu^(-1), yu^(-1)}, yw] - 
     4*G[{yv^(-1)}, yw]*G[{0, yu^(-1), yu^(-1), yu^(-1)}, yw] - 
     4*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1), yu^(-1), yu^(-1)}, yw] + 
     3*G[{0}, yu^(-1)]*G[{0, yu^(-1), yu^(-1), yv^(-1)}, yw] + 
     3*G[{0}, yv^(-1)]*G[{0, yu^(-1), yu^(-1), yv^(-1)}, yw] - 
     3*G[{0}, yw]*G[{0, yu^(-1), yu^(-1), yv^(-1)}, yw] - 
     3*G[{1}, yu^(-1)]*G[{0, yu^(-1), yu^(-1), yv^(-1)}, yw] - 
     11*G[{1}, yv^(-1)]*G[{0, yu^(-1), yu^(-1), yv^(-1)}, yw] + 
     4*G[{yu^(-1)}, yw]*G[{0, yu^(-1), yu^(-1), yv^(-1)}, yw] + 
     8*G[{yu}, yv^(-1)]*G[{0, yu^(-1), yu^(-1), yv^(-1)}, yw] + 
     4*G[{yv^(-1)}, yw]*G[{0, yu^(-1), yu^(-1), yv^(-1)}, yw] - 
     8*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1), yu^(-1), yv^(-1)}, yw] + 
     5*G[{0}, yu^(-1)]*G[{0, yu^(-1), yu^(-1), 1/(yu*yv)}, yw] + 
     5*G[{0}, yv^(-1)]*G[{0, yu^(-1), yu^(-1), 1/(yu*yv)}, yw] - 
     5*G[{0}, yw]*G[{0, yu^(-1), yu^(-1), 1/(yu*yv)}, yw] - 
     5*G[{1}, yu^(-1)]*G[{0, yu^(-1), yu^(-1), 1/(yu*yv)}, yw] - 
     G[{1}, yv^(-1)]*G[{0, yu^(-1), yu^(-1), 1/(yu*yv)}, yw] + 
     6*G[{1}, yw]*G[{0, yu^(-1), yu^(-1), 1/(yu*yv)}, yw] - 
     6*G[{yu^(-1)}, yw]*G[{0, yu^(-1), yu^(-1), 1/(yu*yv)}, yw] - 
     4*G[{yu}, yv^(-1)]*G[{0, yu^(-1), yu^(-1), 1/(yu*yv)}, yw] - 
     6*G[{yv^(-1)}, yw]*G[{0, yu^(-1), yu^(-1), 1/(yu*yv)}, yw] + 
     6*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1), yu^(-1), 1/(yu*yv)}, yw] - 
     3*G[{0}, yu^(-1)]*G[{0, yu^(-1), yv^(-1), 1}, yw] - 
     3*G[{0}, yv^(-1)]*G[{0, yu^(-1), yv^(-1), 1}, yw] + 
     3*G[{0}, yw]*G[{0, yu^(-1), yv^(-1), 1}, yw] + 
     3*G[{1}, yu^(-1)]*G[{0, yu^(-1), yv^(-1), 1}, yw] + 
     3*G[{1}, yv^(-1)]*G[{0, yu^(-1), yv^(-1), 1}, yw] - 
     2*G[{1}, yw]*G[{0, yu^(-1), yv^(-1), 1}, yw] - 
     2*G[{yu^(-1)}, yw]*G[{0, yu^(-1), yv^(-1), 1}, yw] - 
     2*G[{yv^(-1)}, yw]*G[{0, yu^(-1), yv^(-1), 1}, yw] + 
     6*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1), yv^(-1), 1}, yw] + 
     3*G[{0}, yu^(-1)]*G[{0, yu^(-1), yv^(-1), yu^(-1)}, yw] + 
     3*G[{0}, yv^(-1)]*G[{0, yu^(-1), yv^(-1), yu^(-1)}, yw] - 
     3*G[{0}, yw]*G[{0, yu^(-1), yv^(-1), yu^(-1)}, yw] - 
     3*G[{1}, yu^(-1)]*G[{0, yu^(-1), yv^(-1), yu^(-1)}, yw] - 
     11*G[{1}, yv^(-1)]*G[{0, yu^(-1), yv^(-1), yu^(-1)}, yw] + 
     4*G[{yu^(-1)}, yw]*G[{0, yu^(-1), yv^(-1), yu^(-1)}, yw] + 
     8*G[{yu}, yv^(-1)]*G[{0, yu^(-1), yv^(-1), yu^(-1)}, yw] + 
     4*G[{yv^(-1)}, yw]*G[{0, yu^(-1), yv^(-1), yu^(-1)}, yw] - 
     8*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1), yv^(-1), yu^(-1)}, yw] + 
     3*G[{0}, yu^(-1)]*G[{0, yu^(-1), yv^(-1), yv^(-1)}, yw] + 
     3*G[{0}, yv^(-1)]*G[{0, yu^(-1), yv^(-1), yv^(-1)}, yw] - 
     3*G[{0}, yw]*G[{0, yu^(-1), yv^(-1), yv^(-1)}, yw] - 
     11*G[{1}, yu^(-1)]*G[{0, yu^(-1), yv^(-1), yv^(-1)}, yw] - 
     3*G[{1}, yv^(-1)]*G[{0, yu^(-1), yv^(-1), yv^(-1)}, yw] + 
     4*G[{yu^(-1)}, yw]*G[{0, yu^(-1), yv^(-1), yv^(-1)}, yw] + 
     8*G[{yu}, yv^(-1)]*G[{0, yu^(-1), yv^(-1), yv^(-1)}, yw] + 
     4*G[{yv^(-1)}, yw]*G[{0, yu^(-1), yv^(-1), yv^(-1)}, yw] - 
     8*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1), yv^(-1), yv^(-1)}, yw] + 
     5*G[{0}, yu^(-1)]*G[{0, yu^(-1), yv^(-1), 1/(yu*yv)}, yw] + 
     5*G[{0}, yv^(-1)]*G[{0, yu^(-1), yv^(-1), 1/(yu*yv)}, yw] - 
     5*G[{0}, yw]*G[{0, yu^(-1), yv^(-1), 1/(yu*yv)}, yw] - 
     G[{1}, yu^(-1)]*G[{0, yu^(-1), yv^(-1), 1/(yu*yv)}, yw] - 
     G[{1}, yv^(-1)]*G[{0, yu^(-1), yv^(-1), 1/(yu*yv)}, yw] + 
     6*G[{1}, yw]*G[{0, yu^(-1), yv^(-1), 1/(yu*yv)}, yw] - 
     6*G[{yu^(-1)}, yw]*G[{0, yu^(-1), yv^(-1), 1/(yu*yv)}, yw] - 
     8*G[{yu}, yv^(-1)]*G[{0, yu^(-1), yv^(-1), 1/(yu*yv)}, yw] - 
     6*G[{yv^(-1)}, yw]*G[{0, yu^(-1), yv^(-1), 1/(yu*yv)}, yw] + 
     6*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1), yv^(-1), 1/(yu*yv)}, yw] - 
     3*G[{0}, yu^(-1)]*G[{0, yu^(-1), 1/(yu*yv), 1}, yw] - 
     3*G[{0}, yv^(-1)]*G[{0, yu^(-1), 1/(yu*yv), 1}, yw] + 
     3*G[{0}, yw]*G[{0, yu^(-1), 1/(yu*yv), 1}, yw] + 
     3*G[{1}, yu^(-1)]*G[{0, yu^(-1), 1/(yu*yv), 1}, yw] + 
     3*G[{1}, yv^(-1)]*G[{0, yu^(-1), 1/(yu*yv), 1}, yw] - 
     2*G[{1}, yw]*G[{0, yu^(-1), 1/(yu*yv), 1}, yw] + 
     4*G[{yu^(-1)}, yw]*G[{0, yu^(-1), 1/(yu*yv), 1}, yw] - 
     2*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1), 1/(yu*yv), 1}, yw] + 
     3*G[{0}, yu^(-1)]*G[{0, yu^(-1), 1/(yu*yv), yu^(-1)}, yw] + 
     3*G[{0}, yv^(-1)]*G[{0, yu^(-1), 1/(yu*yv), yu^(-1)}, yw] - 
     3*G[{0}, yw]*G[{0, yu^(-1), 1/(yu*yv), yu^(-1)}, yw] - 
     3*G[{1}, yu^(-1)]*G[{0, yu^(-1), 1/(yu*yv), yu^(-1)}, yw] - 
     G[{1}, yv^(-1)]*G[{0, yu^(-1), 1/(yu*yv), yu^(-1)}, yw] + 
     4*G[{1}, yw]*G[{0, yu^(-1), 1/(yu*yv), yu^(-1)}, yw] - 
     6*G[{yu^(-1)}, yw]*G[{0, yu^(-1), 1/(yu*yv), yu^(-1)}, yw] - 
     2*G[{yu}, yv^(-1)]*G[{0, yu^(-1), 1/(yu*yv), yu^(-1)}, yw] - 
     4*G[{yv^(-1)}, yw]*G[{0, yu^(-1), 1/(yu*yv), yu^(-1)}, yw] + 
     6*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1), 1/(yu*yv), yu^(-1)}, yw] + 
     3*G[{0}, yu^(-1)]*G[{0, yu^(-1), 1/(yu*yv), yv^(-1)}, yw] + 
     3*G[{0}, yv^(-1)]*G[{0, yu^(-1), 1/(yu*yv), yv^(-1)}, yw] - 
     3*G[{0}, yw]*G[{0, yu^(-1), 1/(yu*yv), yv^(-1)}, yw] - 
     G[{1}, yu^(-1)]*G[{0, yu^(-1), 1/(yu*yv), yv^(-1)}, yw] + 
     G[{1}, yv^(-1)]*G[{0, yu^(-1), 1/(yu*yv), yv^(-1)}, yw] + 
     4*G[{1}, yw]*G[{0, yu^(-1), 1/(yu*yv), yv^(-1)}, yw] - 
     8*G[{yu^(-1)}, yw]*G[{0, yu^(-1), 1/(yu*yv), yv^(-1)}, yw] - 
     6*G[{yu}, yv^(-1)]*G[{0, yu^(-1), 1/(yu*yv), yv^(-1)}, yw] - 
     2*G[{yv^(-1)}, yw]*G[{0, yu^(-1), 1/(yu*yv), yv^(-1)}, yw] + 
     6*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1), 1/(yu*yv), yv^(-1)}, yw] - 
     11*G[{0}, yu^(-1)]*G[{0, yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] - 
     11*G[{0}, yv^(-1)]*G[{0, yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] + 
     11*G[{0}, yw]*G[{0, yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] + 
     13*G[{1}, yu^(-1)]*G[{0, yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] + 
     13*G[{1}, yv^(-1)]*G[{0, yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] - 
     2*G[{1}, yw]*G[{0, yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] + 
     2*G[{yu^(-1)}, yw]*G[{0, yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] - 
     4*G[{yu}, yv^(-1)]*G[{0, yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] + 
     2*G[{yv^(-1)}, yw]*G[{0, yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] - 
     2*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] - 
     2*G[{1}, yu^(-1)]*G[{0, yu, 1, 1}, yv^(-1)] - 
     2*G[{1}, yw]*G[{0, yu, 1, 1}, yv^(-1)] + 2*G[{yu^(-1)}, yw]*
      G[{0, yu, 1, 1}, yv^(-1)] + 2*G[{yv^(-1)}, yw]*
      G[{0, yu, 1, 1}, yv^(-1)] - 2*G[{1/(yu*yv)}, yw]*
      G[{0, yu, 1, 1}, yv^(-1)] - 2*G[{1}, yu^(-1)]*
      G[{0, yu, 1, yu}, yv^(-1)] - 6*G[{1}, yv^(-1)]*
      G[{0, yu, 1, yu}, yv^(-1)] - 4*G[{yu^(-1)}, yw]*
      G[{0, yu, 1, yu}, yv^(-1)] + 2*G[{yu}, yv^(-1)]*
      G[{0, yu, 1, yu}, yv^(-1)] + 6*G[{yv^(-1)}, yw]*
      G[{0, yu, 1, yu}, yv^(-1)] - 2*G[{1/(yu*yv)}, yw]*
      G[{0, yu, 1, yu}, yv^(-1)] - 4*G[{1}, yu^(-1)]*
      G[{0, yu, yu, 1}, yv^(-1)] - 4*G[{1}, yv^(-1)]*
      G[{0, yu, yu, 1}, yv^(-1)] - 2*G[{yu^(-1)}, yw]*
      G[{0, yu, yu, 1}, yv^(-1)] + 2*G[{yu}, yv^(-1)]*
      G[{0, yu, yu, 1}, yv^(-1)] + 4*G[{yv^(-1)}, yw]*
      G[{0, yu, yu, 1}, yv^(-1)] - 2*G[{1/(yu*yv)}, yw]*
      G[{0, yu, yu, 1}, yv^(-1)] + 8*G[{1}, yu^(-1)]*
      G[{0, yu, yu, yu}, yv^(-1)] + 8*G[{1}, yv^(-1)]*
      G[{0, yu, yu, yu}, yv^(-1)] + 4*G[{yu^(-1)}, yw]*
      G[{0, yu, yu, yu}, yv^(-1)] - 4*G[{yu}, yv^(-1)]*
      G[{0, yu, yu, yu}, yv^(-1)] - 8*G[{yv^(-1)}, yw]*
      G[{0, yu, yu, yu}, yv^(-1)] + 4*G[{1/(yu*yv)}, yw]*
      G[{0, yu, yu, yu}, yv^(-1)] + 2*G[{1}, yv^(-1)]*
      G[{0, yv^(-1), 0, 1/(yu*yv)}, yw] - 2*G[{1}, yw]*
      G[{0, yv^(-1), 0, 1/(yu*yv)}, yw] + 2*G[{yu^(-1)}, yw]*
      G[{0, yv^(-1), 0, 1/(yu*yv)}, yw] - 2*G[{yu}, yv^(-1)]*
      G[{0, yv^(-1), 0, 1/(yu*yv)}, yw] + G[{0}, yu^(-1)]*
      G[{0, yv^(-1), 1, 1}, yw] + G[{0}, yv^(-1)]*G[{0, yv^(-1), 1, 1}, yw] - 
     G[{0}, yw]*G[{0, yv^(-1), 1, 1}, yw] - G[{1}, yu^(-1)]*
      G[{0, yv^(-1), 1, 1}, yw] - G[{1}, yv^(-1)]*G[{0, yv^(-1), 1, 1}, yw] - 
     2*G[{1}, yw]*G[{0, yv^(-1), 1, 1}, yw] + 4*G[{yu^(-1)}, yw]*
      G[{0, yv^(-1), 1, 1}, yw] - 2*G[{1/(yu*yv)}, yw]*
      G[{0, yv^(-1), 1, 1}, yw] - G[{0}, yu^(-1)]*G[{0, yv^(-1), 1, yu^(-1)}, 
       yw] - G[{0}, yv^(-1)]*G[{0, yv^(-1), 1, yu^(-1)}, yw] + 
     G[{0}, yw]*G[{0, yv^(-1), 1, yu^(-1)}, yw] + 
     G[{1}, yu^(-1)]*G[{0, yv^(-1), 1, yu^(-1)}, yw] + 
     3*G[{1}, yv^(-1)]*G[{0, yv^(-1), 1, yu^(-1)}, yw] - 
     2*G[{yu^(-1)}, yw]*G[{0, yv^(-1), 1, yu^(-1)}, yw] - 
     2*G[{yu}, yv^(-1)]*G[{0, yv^(-1), 1, yu^(-1)}, yw] - 
     4*G[{yv^(-1)}, yw]*G[{0, yv^(-1), 1, yu^(-1)}, yw] + 
     6*G[{1/(yu*yv)}, yw]*G[{0, yv^(-1), 1, yu^(-1)}, yw] - 
     G[{0}, yu^(-1)]*G[{0, yv^(-1), 1, yv^(-1)}, yw] - 
     G[{0}, yv^(-1)]*G[{0, yv^(-1), 1, yv^(-1)}, yw] + 
     G[{0}, yw]*G[{0, yv^(-1), 1, yv^(-1)}, yw] + 
     7*G[{1}, yu^(-1)]*G[{0, yv^(-1), 1, yv^(-1)}, yw] + 
     G[{1}, yv^(-1)]*G[{0, yv^(-1), 1, yv^(-1)}, yw] - 
     4*G[{yu^(-1)}, yw]*G[{0, yv^(-1), 1, yv^(-1)}, yw] - 
     6*G[{yu}, yv^(-1)]*G[{0, yv^(-1), 1, yv^(-1)}, yw] - 
     2*G[{yv^(-1)}, yw]*G[{0, yv^(-1), 1, yv^(-1)}, yw] + 
     6*G[{1/(yu*yv)}, yw]*G[{0, yv^(-1), 1, yv^(-1)}, yw] - 
     7*G[{0}, yu^(-1)]*G[{0, yv^(-1), 1, 1/(yu*yv)}, yw] - 
     7*G[{0}, yv^(-1)]*G[{0, yv^(-1), 1, 1/(yu*yv)}, yw] + 
     7*G[{0}, yw]*G[{0, yv^(-1), 1, 1/(yu*yv)}, yw] + 
     5*G[{1}, yu^(-1)]*G[{0, yv^(-1), 1, 1/(yu*yv)}, yw] + 
     5*G[{1}, yv^(-1)]*G[{0, yv^(-1), 1, 1/(yu*yv)}, yw] - 
     2*G[{1}, yw]*G[{0, yv^(-1), 1, 1/(yu*yv)}, yw] + 
     2*G[{yu^(-1)}, yw]*G[{0, yv^(-1), 1, 1/(yu*yv)}, yw] + 
     4*G[{yu}, yv^(-1)]*G[{0, yv^(-1), 1, 1/(yu*yv)}, yw] + 
     2*G[{yv^(-1)}, yw]*G[{0, yv^(-1), 1, 1/(yu*yv)}, yw] - 
     2*G[{1/(yu*yv)}, yw]*G[{0, yv^(-1), 1, 1/(yu*yv)}, yw] - 
     3*G[{0}, yu^(-1)]*G[{0, yv^(-1), yu^(-1), 1}, yw] - 
     3*G[{0}, yv^(-1)]*G[{0, yv^(-1), yu^(-1), 1}, yw] + 
     3*G[{0}, yw]*G[{0, yv^(-1), yu^(-1), 1}, yw] + 
     3*G[{1}, yu^(-1)]*G[{0, yv^(-1), yu^(-1), 1}, yw] + 
     3*G[{1}, yv^(-1)]*G[{0, yv^(-1), yu^(-1), 1}, yw] - 
     2*G[{1}, yw]*G[{0, yv^(-1), yu^(-1), 1}, yw] - 
     2*G[{yu^(-1)}, yw]*G[{0, yv^(-1), yu^(-1), 1}, yw] - 
     2*G[{yv^(-1)}, yw]*G[{0, yv^(-1), yu^(-1), 1}, yw] + 
     6*G[{1/(yu*yv)}, yw]*G[{0, yv^(-1), yu^(-1), 1}, yw] + 
     3*G[{0}, yu^(-1)]*G[{0, yv^(-1), yu^(-1), yu^(-1)}, yw] + 
     3*G[{0}, yv^(-1)]*G[{0, yv^(-1), yu^(-1), yu^(-1)}, yw] - 
     3*G[{0}, yw]*G[{0, yv^(-1), yu^(-1), yu^(-1)}, yw] - 
     3*G[{1}, yu^(-1)]*G[{0, yv^(-1), yu^(-1), yu^(-1)}, yw] - 
     11*G[{1}, yv^(-1)]*G[{0, yv^(-1), yu^(-1), yu^(-1)}, yw] + 
     4*G[{yu^(-1)}, yw]*G[{0, yv^(-1), yu^(-1), yu^(-1)}, yw] + 
     8*G[{yu}, yv^(-1)]*G[{0, yv^(-1), yu^(-1), yu^(-1)}, yw] + 
     4*G[{yv^(-1)}, yw]*G[{0, yv^(-1), yu^(-1), yu^(-1)}, yw] - 
     8*G[{1/(yu*yv)}, yw]*G[{0, yv^(-1), yu^(-1), yu^(-1)}, yw] + 
     3*G[{0}, yu^(-1)]*G[{0, yv^(-1), yu^(-1), yv^(-1)}, yw] + 
     3*G[{0}, yv^(-1)]*G[{0, yv^(-1), yu^(-1), yv^(-1)}, yw] - 
     3*G[{0}, yw]*G[{0, yv^(-1), yu^(-1), yv^(-1)}, yw] - 
     11*G[{1}, yu^(-1)]*G[{0, yv^(-1), yu^(-1), yv^(-1)}, yw] - 
     3*G[{1}, yv^(-1)]*G[{0, yv^(-1), yu^(-1), yv^(-1)}, yw] + 
     4*G[{yu^(-1)}, yw]*G[{0, yv^(-1), yu^(-1), yv^(-1)}, yw] + 
     8*G[{yu}, yv^(-1)]*G[{0, yv^(-1), yu^(-1), yv^(-1)}, yw] + 
     4*G[{yv^(-1)}, yw]*G[{0, yv^(-1), yu^(-1), yv^(-1)}, yw] - 
     8*G[{1/(yu*yv)}, yw]*G[{0, yv^(-1), yu^(-1), yv^(-1)}, yw] + 
     5*G[{0}, yu^(-1)]*G[{0, yv^(-1), yu^(-1), 1/(yu*yv)}, yw] + 
     5*G[{0}, yv^(-1)]*G[{0, yv^(-1), yu^(-1), 1/(yu*yv)}, yw] - 
     5*G[{0}, yw]*G[{0, yv^(-1), yu^(-1), 1/(yu*yv)}, yw] - 
     G[{1}, yu^(-1)]*G[{0, yv^(-1), yu^(-1), 1/(yu*yv)}, yw] - 
     G[{1}, yv^(-1)]*G[{0, yv^(-1), yu^(-1), 1/(yu*yv)}, yw] + 
     6*G[{1}, yw]*G[{0, yv^(-1), yu^(-1), 1/(yu*yv)}, yw] - 
     6*G[{yu^(-1)}, yw]*G[{0, yv^(-1), yu^(-1), 1/(yu*yv)}, yw] - 
     8*G[{yu}, yv^(-1)]*G[{0, yv^(-1), yu^(-1), 1/(yu*yv)}, yw] - 
     6*G[{yv^(-1)}, yw]*G[{0, yv^(-1), yu^(-1), 1/(yu*yv)}, yw] + 
     6*G[{1/(yu*yv)}, yw]*G[{0, yv^(-1), yu^(-1), 1/(yu*yv)}, yw] - 
     3*G[{0}, yu^(-1)]*G[{0, yv^(-1), yv^(-1), 1}, yw] - 
     3*G[{0}, yv^(-1)]*G[{0, yv^(-1), yv^(-1), 1}, yw] + 
     3*G[{0}, yw]*G[{0, yv^(-1), yv^(-1), 1}, yw] + 
     7*G[{1}, yu^(-1)]*G[{0, yv^(-1), yv^(-1), 1}, yw] + 
     3*G[{1}, yv^(-1)]*G[{0, yv^(-1), yv^(-1), 1}, yw] - 
     2*G[{1}, yw]*G[{0, yv^(-1), yv^(-1), 1}, yw] - 
     2*G[{yu^(-1)}, yw]*G[{0, yv^(-1), yv^(-1), 1}, yw] - 
     4*G[{yu}, yv^(-1)]*G[{0, yv^(-1), yv^(-1), 1}, yw] - 
     2*G[{yv^(-1)}, yw]*G[{0, yv^(-1), yv^(-1), 1}, yw] + 
     6*G[{1/(yu*yv)}, yw]*G[{0, yv^(-1), yv^(-1), 1}, yw] + 
     3*G[{0}, yu^(-1)]*G[{0, yv^(-1), yv^(-1), yu^(-1)}, yw] + 
     3*G[{0}, yv^(-1)]*G[{0, yv^(-1), yv^(-1), yu^(-1)}, yw] - 
     3*G[{0}, yw]*G[{0, yv^(-1), yv^(-1), yu^(-1)}, yw] - 
     11*G[{1}, yu^(-1)]*G[{0, yv^(-1), yv^(-1), yu^(-1)}, yw] - 
     3*G[{1}, yv^(-1)]*G[{0, yv^(-1), yv^(-1), yu^(-1)}, yw] + 
     4*G[{yu^(-1)}, yw]*G[{0, yv^(-1), yv^(-1), yu^(-1)}, yw] + 
     8*G[{yu}, yv^(-1)]*G[{0, yv^(-1), yv^(-1), yu^(-1)}, yw] + 
     4*G[{yv^(-1)}, yw]*G[{0, yv^(-1), yv^(-1), yu^(-1)}, yw] - 
     8*G[{1/(yu*yv)}, yw]*G[{0, yv^(-1), yv^(-1), yu^(-1)}, yw] + 
     3*G[{0}, yu^(-1)]*G[{0, yv^(-1), yv^(-1), yv^(-1)}, yw] + 
     3*G[{0}, yv^(-1)]*G[{0, yv^(-1), yv^(-1), yv^(-1)}, yw] - 
     3*G[{0}, yw]*G[{0, yv^(-1), yv^(-1), yv^(-1)}, yw] - 
     11*G[{1}, yu^(-1)]*G[{0, yv^(-1), yv^(-1), yv^(-1)}, yw] - 
     3*G[{1}, yv^(-1)]*G[{0, yv^(-1), yv^(-1), yv^(-1)}, yw] + 
     4*G[{1}, yw]*G[{0, yv^(-1), yv^(-1), yv^(-1)}, yw] - 
     4*G[{yu^(-1)}, yw]*G[{0, yv^(-1), yv^(-1), yv^(-1)}, yw] + 
     8*G[{yu}, yv^(-1)]*G[{0, yv^(-1), yv^(-1), yv^(-1)}, yw] + 
     4*G[{yv^(-1)}, yw]*G[{0, yv^(-1), yv^(-1), yv^(-1)}, yw] - 
     4*G[{1/(yu*yv)}, yw]*G[{0, yv^(-1), yv^(-1), yv^(-1)}, yw] + 
     5*G[{0}, yu^(-1)]*G[{0, yv^(-1), yv^(-1), 1/(yu*yv)}, yw] + 
     5*G[{0}, yv^(-1)]*G[{0, yv^(-1), yv^(-1), 1/(yu*yv)}, yw] - 
     5*G[{0}, yw]*G[{0, yv^(-1), yv^(-1), 1/(yu*yv)}, yw] - 
     G[{1}, yu^(-1)]*G[{0, yv^(-1), yv^(-1), 1/(yu*yv)}, yw] - 
     5*G[{1}, yv^(-1)]*G[{0, yv^(-1), yv^(-1), 1/(yu*yv)}, yw] + 
     6*G[{1}, yw]*G[{0, yv^(-1), yv^(-1), 1/(yu*yv)}, yw] - 
     6*G[{yu^(-1)}, yw]*G[{0, yv^(-1), yv^(-1), 1/(yu*yv)}, yw] - 
     4*G[{yu}, yv^(-1)]*G[{0, yv^(-1), yv^(-1), 1/(yu*yv)}, yw] - 
     6*G[{yv^(-1)}, yw]*G[{0, yv^(-1), yv^(-1), 1/(yu*yv)}, yw] + 
     6*G[{1/(yu*yv)}, yw]*G[{0, yv^(-1), yv^(-1), 1/(yu*yv)}, yw] - 
     3*G[{0}, yu^(-1)]*G[{0, yv^(-1), 1/(yu*yv), 1}, yw] - 
     3*G[{0}, yv^(-1)]*G[{0, yv^(-1), 1/(yu*yv), 1}, yw] + 
     3*G[{0}, yw]*G[{0, yv^(-1), 1/(yu*yv), 1}, yw] + 
     3*G[{1}, yu^(-1)]*G[{0, yv^(-1), 1/(yu*yv), 1}, yw] + 
     3*G[{1}, yv^(-1)]*G[{0, yv^(-1), 1/(yu*yv), 1}, yw] - 
     2*G[{1}, yw]*G[{0, yv^(-1), 1/(yu*yv), 1}, yw] + 
     4*G[{yv^(-1)}, yw]*G[{0, yv^(-1), 1/(yu*yv), 1}, yw] - 
     2*G[{1/(yu*yv)}, yw]*G[{0, yv^(-1), 1/(yu*yv), 1}, yw] + 
     3*G[{0}, yu^(-1)]*G[{0, yv^(-1), 1/(yu*yv), yu^(-1)}, yw] + 
     3*G[{0}, yv^(-1)]*G[{0, yv^(-1), 1/(yu*yv), yu^(-1)}, yw] - 
     3*G[{0}, yw]*G[{0, yv^(-1), 1/(yu*yv), yu^(-1)}, yw] + 
     G[{1}, yu^(-1)]*G[{0, yv^(-1), 1/(yu*yv), yu^(-1)}, yw] - 
     G[{1}, yv^(-1)]*G[{0, yv^(-1), 1/(yu*yv), yu^(-1)}, yw] + 
     4*G[{1}, yw]*G[{0, yv^(-1), 1/(yu*yv), yu^(-1)}, yw] - 
     2*G[{yu^(-1)}, yw]*G[{0, yv^(-1), 1/(yu*yv), yu^(-1)}, yw] - 
     6*G[{yu}, yv^(-1)]*G[{0, yv^(-1), 1/(yu*yv), yu^(-1)}, yw] - 
     8*G[{yv^(-1)}, yw]*G[{0, yv^(-1), 1/(yu*yv), yu^(-1)}, yw] + 
     6*G[{1/(yu*yv)}, yw]*G[{0, yv^(-1), 1/(yu*yv), yu^(-1)}, yw] + 
     3*G[{0}, yu^(-1)]*G[{0, yv^(-1), 1/(yu*yv), yv^(-1)}, yw] + 
     3*G[{0}, yv^(-1)]*G[{0, yv^(-1), 1/(yu*yv), yv^(-1)}, yw] - 
     3*G[{0}, yw]*G[{0, yv^(-1), 1/(yu*yv), yv^(-1)}, yw] - 
     G[{1}, yu^(-1)]*G[{0, yv^(-1), 1/(yu*yv), yv^(-1)}, yw] - 
     3*G[{1}, yv^(-1)]*G[{0, yv^(-1), 1/(yu*yv), yv^(-1)}, yw] + 
     4*G[{1}, yw]*G[{0, yv^(-1), 1/(yu*yv), yv^(-1)}, yw] - 
     4*G[{yu^(-1)}, yw]*G[{0, yv^(-1), 1/(yu*yv), yv^(-1)}, yw] - 
     2*G[{yu}, yv^(-1)]*G[{0, yv^(-1), 1/(yu*yv), yv^(-1)}, yw] - 
     6*G[{yv^(-1)}, yw]*G[{0, yv^(-1), 1/(yu*yv), yv^(-1)}, yw] + 
     6*G[{1/(yu*yv)}, yw]*G[{0, yv^(-1), 1/(yu*yv), yv^(-1)}, yw] - 
     11*G[{0}, yu^(-1)]*G[{0, yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] - 
     11*G[{0}, yv^(-1)]*G[{0, yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] + 
     11*G[{0}, yw]*G[{0, yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] + 
     13*G[{1}, yu^(-1)]*G[{0, yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] + 
     13*G[{1}, yv^(-1)]*G[{0, yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] - 
     2*G[{1}, yw]*G[{0, yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] + 
     2*G[{yu^(-1)}, yw]*G[{0, yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] - 
     4*G[{yu}, yv^(-1)]*G[{0, yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] + 
     2*G[{yv^(-1)}, yw]*G[{0, yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] - 
     2*G[{1/(yu*yv)}, yw]*G[{0, yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] - 
     G[{0}, yu^(-1)]*G[{0, 1/(yu*yv), 1, 1}, yw] - 
     G[{0}, yv^(-1)]*G[{0, 1/(yu*yv), 1, 1}, yw] + 
     G[{0}, yw]*G[{0, 1/(yu*yv), 1, 1}, yw] + G[{1}, yu^(-1)]*
      G[{0, 1/(yu*yv), 1, 1}, yw] + G[{1}, yv^(-1)]*G[{0, 1/(yu*yv), 1, 1}, 
       yw] + 2*G[{1}, yw]*G[{0, 1/(yu*yv), 1, 1}, yw] - 
     4*G[{yu^(-1)}, yw]*G[{0, 1/(yu*yv), 1, 1}, yw] - 
     4*G[{yv^(-1)}, yw]*G[{0, 1/(yu*yv), 1, 1}, yw] + 
     6*G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv), 1, 1}, yw] + 
     G[{0}, yu^(-1)]*G[{0, 1/(yu*yv), 1, yu^(-1)}, yw] + 
     G[{0}, yv^(-1)]*G[{0, 1/(yu*yv), 1, yu^(-1)}, yw] - 
     G[{0}, yw]*G[{0, 1/(yu*yv), 1, yu^(-1)}, yw] - 
     G[{1}, yu^(-1)]*G[{0, 1/(yu*yv), 1, yu^(-1)}, yw] - 
     3*G[{1}, yv^(-1)]*G[{0, 1/(yu*yv), 1, yu^(-1)}, yw] + 
     2*G[{yu^(-1)}, yw]*G[{0, 1/(yu*yv), 1, yu^(-1)}, yw] + 
     2*G[{yu}, yv^(-1)]*G[{0, 1/(yu*yv), 1, yu^(-1)}, yw] + 
     4*G[{yv^(-1)}, yw]*G[{0, 1/(yu*yv), 1, yu^(-1)}, yw] - 
     6*G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv), 1, yu^(-1)}, yw] + 
     G[{0}, yu^(-1)]*G[{0, 1/(yu*yv), 1, yv^(-1)}, yw] + 
     G[{0}, yv^(-1)]*G[{0, 1/(yu*yv), 1, yv^(-1)}, yw] - 
     G[{0}, yw]*G[{0, 1/(yu*yv), 1, yv^(-1)}, yw] - 
     3*G[{1}, yu^(-1)]*G[{0, 1/(yu*yv), 1, yv^(-1)}, yw] - 
     G[{1}, yv^(-1)]*G[{0, 1/(yu*yv), 1, yv^(-1)}, yw] + 
     4*G[{yu^(-1)}, yw]*G[{0, 1/(yu*yv), 1, yv^(-1)}, yw] + 
     2*G[{yu}, yv^(-1)]*G[{0, 1/(yu*yv), 1, yv^(-1)}, yw] + 
     2*G[{yv^(-1)}, yw]*G[{0, 1/(yu*yv), 1, yv^(-1)}, yw] - 
     6*G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv), 1, yv^(-1)}, yw] + 
     7*G[{0}, yu^(-1)]*G[{0, 1/(yu*yv), 1, 1/(yu*yv)}, yw] + 
     7*G[{0}, yv^(-1)]*G[{0, 1/(yu*yv), 1, 1/(yu*yv)}, yw] - 
     7*G[{0}, yw]*G[{0, 1/(yu*yv), 1, 1/(yu*yv)}, yw] - 
     9*G[{1}, yu^(-1)]*G[{0, 1/(yu*yv), 1, 1/(yu*yv)}, yw] - 
     9*G[{1}, yv^(-1)]*G[{0, 1/(yu*yv), 1, 1/(yu*yv)}, yw] + 
     2*G[{1}, yw]*G[{0, 1/(yu*yv), 1, 1/(yu*yv)}, yw] - 
     2*G[{yu^(-1)}, yw]*G[{0, 1/(yu*yv), 1, 1/(yu*yv)}, yw] + 
     4*G[{yu}, yv^(-1)]*G[{0, 1/(yu*yv), 1, 1/(yu*yv)}, yw] - 
     2*G[{yv^(-1)}, yw]*G[{0, 1/(yu*yv), 1, 1/(yu*yv)}, yw] + 
     2*G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv), 1, 1/(yu*yv)}, yw] + 
     3*G[{0}, yu^(-1)]*G[{0, 1/(yu*yv), yu^(-1), 1}, yw] + 
     3*G[{0}, yv^(-1)]*G[{0, 1/(yu*yv), yu^(-1), 1}, yw] - 
     3*G[{0}, yw]*G[{0, 1/(yu*yv), yu^(-1), 1}, yw] - 
     3*G[{1}, yu^(-1)]*G[{0, 1/(yu*yv), yu^(-1), 1}, yw] - 
     3*G[{1}, yv^(-1)]*G[{0, 1/(yu*yv), yu^(-1), 1}, yw] + 
     2*G[{1}, yw]*G[{0, 1/(yu*yv), yu^(-1), 1}, yw] + 
     2*G[{yu^(-1)}, yw]*G[{0, 1/(yu*yv), yu^(-1), 1}, yw] + 
     2*G[{yv^(-1)}, yw]*G[{0, 1/(yu*yv), yu^(-1), 1}, yw] - 
     6*G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv), yu^(-1), 1}, yw] - 
     3*G[{0}, yu^(-1)]*G[{0, 1/(yu*yv), yu^(-1), yu^(-1)}, yw] - 
     3*G[{0}, yv^(-1)]*G[{0, 1/(yu*yv), yu^(-1), yu^(-1)}, yw] + 
     3*G[{0}, yw]*G[{0, 1/(yu*yv), yu^(-1), yu^(-1)}, yw] + 
     3*G[{1}, yu^(-1)]*G[{0, 1/(yu*yv), yu^(-1), yu^(-1)}, yw] + 
     11*G[{1}, yv^(-1)]*G[{0, 1/(yu*yv), yu^(-1), yu^(-1)}, yw] - 
     4*G[{yu^(-1)}, yw]*G[{0, 1/(yu*yv), yu^(-1), yu^(-1)}, yw] - 
     8*G[{yu}, yv^(-1)]*G[{0, 1/(yu*yv), yu^(-1), yu^(-1)}, yw] + 
     4*G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv), yu^(-1), yu^(-1)}, yw] - 
     3*G[{0}, yu^(-1)]*G[{0, 1/(yu*yv), yu^(-1), yv^(-1)}, yw] - 
     3*G[{0}, yv^(-1)]*G[{0, 1/(yu*yv), yu^(-1), yv^(-1)}, yw] + 
     3*G[{0}, yw]*G[{0, 1/(yu*yv), yu^(-1), yv^(-1)}, yw] + 
     7*G[{1}, yu^(-1)]*G[{0, 1/(yu*yv), yu^(-1), yv^(-1)}, yw] + 
     7*G[{1}, yv^(-1)]*G[{0, 1/(yu*yv), yu^(-1), yv^(-1)}, yw] - 
     4*G[{yu^(-1)}, yw]*G[{0, 1/(yu*yv), yu^(-1), yv^(-1)}, yw] - 
     8*G[{yu}, yv^(-1)]*G[{0, 1/(yu*yv), yu^(-1), yv^(-1)}, yw] - 
     4*G[{yv^(-1)}, yw]*G[{0, 1/(yu*yv), yu^(-1), yv^(-1)}, yw] + 
     8*G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv), yu^(-1), yv^(-1)}, yw] - 
     5*G[{0}, yu^(-1)]*G[{0, 1/(yu*yv), yu^(-1), 1/(yu*yv)}, yw] - 
     5*G[{0}, yv^(-1)]*G[{0, 1/(yu*yv), yu^(-1), 1/(yu*yv)}, yw] + 
     5*G[{0}, yw]*G[{0, 1/(yu*yv), yu^(-1), 1/(yu*yv)}, yw] + 
     5*G[{1}, yu^(-1)]*G[{0, 1/(yu*yv), yu^(-1), 1/(yu*yv)}, yw] + 
     G[{1}, yv^(-1)]*G[{0, 1/(yu*yv), yu^(-1), 1/(yu*yv)}, yw] - 
     6*G[{1}, yw]*G[{0, 1/(yu*yv), yu^(-1), 1/(yu*yv)}, yw] + 
     6*G[{yu^(-1)}, yw]*G[{0, 1/(yu*yv), yu^(-1), 1/(yu*yv)}, yw] + 
     4*G[{yu}, yv^(-1)]*G[{0, 1/(yu*yv), yu^(-1), 1/(yu*yv)}, yw] + 
     6*G[{yv^(-1)}, yw]*G[{0, 1/(yu*yv), yu^(-1), 1/(yu*yv)}, yw] - 
     6*G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv), yu^(-1), 1/(yu*yv)}, yw] + 
     3*G[{0}, yu^(-1)]*G[{0, 1/(yu*yv), yv^(-1), 1}, yw] + 
     3*G[{0}, yv^(-1)]*G[{0, 1/(yu*yv), yv^(-1), 1}, yw] - 
     3*G[{0}, yw]*G[{0, 1/(yu*yv), yv^(-1), 1}, yw] - 
     3*G[{1}, yu^(-1)]*G[{0, 1/(yu*yv), yv^(-1), 1}, yw] - 
     3*G[{1}, yv^(-1)]*G[{0, 1/(yu*yv), yv^(-1), 1}, yw] + 
     2*G[{1}, yw]*G[{0, 1/(yu*yv), yv^(-1), 1}, yw] + 
     2*G[{yu^(-1)}, yw]*G[{0, 1/(yu*yv), yv^(-1), 1}, yw] + 
     2*G[{yv^(-1)}, yw]*G[{0, 1/(yu*yv), yv^(-1), 1}, yw] - 
     6*G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv), yv^(-1), 1}, yw] - 
     3*G[{0}, yu^(-1)]*G[{0, 1/(yu*yv), yv^(-1), yu^(-1)}, yw] - 
     3*G[{0}, yv^(-1)]*G[{0, 1/(yu*yv), yv^(-1), yu^(-1)}, yw] + 
     3*G[{0}, yw]*G[{0, 1/(yu*yv), yv^(-1), yu^(-1)}, yw] + 
     7*G[{1}, yu^(-1)]*G[{0, 1/(yu*yv), yv^(-1), yu^(-1)}, yw] + 
     7*G[{1}, yv^(-1)]*G[{0, 1/(yu*yv), yv^(-1), yu^(-1)}, yw] - 
     4*G[{yu^(-1)}, yw]*G[{0, 1/(yu*yv), yv^(-1), yu^(-1)}, yw] - 
     8*G[{yu}, yv^(-1)]*G[{0, 1/(yu*yv), yv^(-1), yu^(-1)}, yw] - 
     4*G[{yv^(-1)}, yw]*G[{0, 1/(yu*yv), yv^(-1), yu^(-1)}, yw] + 
     8*G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv), yv^(-1), yu^(-1)}, yw] - 
     3*G[{0}, yu^(-1)]*G[{0, 1/(yu*yv), yv^(-1), yv^(-1)}, yw] - 
     3*G[{0}, yv^(-1)]*G[{0, 1/(yu*yv), yv^(-1), yv^(-1)}, yw] + 
     3*G[{0}, yw]*G[{0, 1/(yu*yv), yv^(-1), yv^(-1)}, yw] + 
     11*G[{1}, yu^(-1)]*G[{0, 1/(yu*yv), yv^(-1), yv^(-1)}, yw] + 
     3*G[{1}, yv^(-1)]*G[{0, 1/(yu*yv), yv^(-1), yv^(-1)}, yw] - 
     8*G[{yu}, yv^(-1)]*G[{0, 1/(yu*yv), yv^(-1), yv^(-1)}, yw] - 
     4*G[{yv^(-1)}, yw]*G[{0, 1/(yu*yv), yv^(-1), yv^(-1)}, yw] + 
     4*G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv), yv^(-1), yv^(-1)}, yw] - 
     5*G[{0}, yu^(-1)]*G[{0, 1/(yu*yv), yv^(-1), 1/(yu*yv)}, yw] - 
     5*G[{0}, yv^(-1)]*G[{0, 1/(yu*yv), yv^(-1), 1/(yu*yv)}, yw] + 
     5*G[{0}, yw]*G[{0, 1/(yu*yv), yv^(-1), 1/(yu*yv)}, yw] + 
     G[{1}, yu^(-1)]*G[{0, 1/(yu*yv), yv^(-1), 1/(yu*yv)}, yw] + 
     5*G[{1}, yv^(-1)]*G[{0, 1/(yu*yv), yv^(-1), 1/(yu*yv)}, yw] - 
     6*G[{1}, yw]*G[{0, 1/(yu*yv), yv^(-1), 1/(yu*yv)}, yw] + 
     6*G[{yu^(-1)}, yw]*G[{0, 1/(yu*yv), yv^(-1), 1/(yu*yv)}, yw] + 
     4*G[{yu}, yv^(-1)]*G[{0, 1/(yu*yv), yv^(-1), 1/(yu*yv)}, yw] + 
     6*G[{yv^(-1)}, yw]*G[{0, 1/(yu*yv), yv^(-1), 1/(yu*yv)}, yw] - 
     6*G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv), yv^(-1), 1/(yu*yv)}, yw] + 
     3*G[{0}, yu^(-1)]*G[{0, 1/(yu*yv), 1/(yu*yv), 1}, yw] + 
     3*G[{0}, yv^(-1)]*G[{0, 1/(yu*yv), 1/(yu*yv), 1}, yw] - 
     3*G[{0}, yw]*G[{0, 1/(yu*yv), 1/(yu*yv), 1}, yw] - 
     7*G[{1}, yu^(-1)]*G[{0, 1/(yu*yv), 1/(yu*yv), 1}, yw] - 
     7*G[{1}, yv^(-1)]*G[{0, 1/(yu*yv), 1/(yu*yv), 1}, yw] + 
     6*G[{1}, yw]*G[{0, 1/(yu*yv), 1/(yu*yv), 1}, yw] - 
     4*G[{yu^(-1)}, yw]*G[{0, 1/(yu*yv), 1/(yu*yv), 1}, yw] + 
     8*G[{yu}, yv^(-1)]*G[{0, 1/(yu*yv), 1/(yu*yv), 1}, yw] - 
     4*G[{yv^(-1)}, yw]*G[{0, 1/(yu*yv), 1/(yu*yv), 1}, yw] + 
     2*G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv), 1/(yu*yv), 1}, yw] - 
     3*G[{0}, yu^(-1)]*G[{0, 1/(yu*yv), 1/(yu*yv), yu^(-1)}, yw] - 
     3*G[{0}, yv^(-1)]*G[{0, 1/(yu*yv), 1/(yu*yv), yu^(-1)}, yw] + 
     3*G[{0}, yw]*G[{0, 1/(yu*yv), 1/(yu*yv), yu^(-1)}, yw] + 
     3*G[{1}, yu^(-1)]*G[{0, 1/(yu*yv), 1/(yu*yv), yu^(-1)}, yw] + 
     G[{1}, yv^(-1)]*G[{0, 1/(yu*yv), 1/(yu*yv), yu^(-1)}, yw] - 
     8*G[{1}, yw]*G[{0, 1/(yu*yv), 1/(yu*yv), yu^(-1)}, yw] + 
     6*G[{yu^(-1)}, yw]*G[{0, 1/(yu*yv), 1/(yu*yv), yu^(-1)}, yw] + 
     2*G[{yu}, yv^(-1)]*G[{0, 1/(yu*yv), 1/(yu*yv), yu^(-1)}, yw] + 
     8*G[{yv^(-1)}, yw]*G[{0, 1/(yu*yv), 1/(yu*yv), yu^(-1)}, yw] - 
     6*G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv), 1/(yu*yv), yu^(-1)}, yw] - 
     3*G[{0}, yu^(-1)]*G[{0, 1/(yu*yv), 1/(yu*yv), yv^(-1)}, yw] - 
     3*G[{0}, yv^(-1)]*G[{0, 1/(yu*yv), 1/(yu*yv), yv^(-1)}, yw] + 
     3*G[{0}, yw]*G[{0, 1/(yu*yv), 1/(yu*yv), yv^(-1)}, yw] + 
     G[{1}, yu^(-1)]*G[{0, 1/(yu*yv), 1/(yu*yv), yv^(-1)}, yw] + 
     3*G[{1}, yv^(-1)]*G[{0, 1/(yu*yv), 1/(yu*yv), yv^(-1)}, yw] - 
     8*G[{1}, yw]*G[{0, 1/(yu*yv), 1/(yu*yv), yv^(-1)}, yw] + 
     8*G[{yu^(-1)}, yw]*G[{0, 1/(yu*yv), 1/(yu*yv), yv^(-1)}, yw] + 
     2*G[{yu}, yv^(-1)]*G[{0, 1/(yu*yv), 1/(yu*yv), yv^(-1)}, yw] + 
     6*G[{yv^(-1)}, yw]*G[{0, 1/(yu*yv), 1/(yu*yv), yv^(-1)}, yw] - 
     6*G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv), 1/(yu*yv), yv^(-1)}, yw] + 
     11*G[{0}, yu^(-1)]*G[{0, 1/(yu*yv), 1/(yu*yv), 1/(yu*yv)}, yw] + 
     11*G[{0}, yv^(-1)]*G[{0, 1/(yu*yv), 1/(yu*yv), 1/(yu*yv)}, yw] - 
     11*G[{0}, yw]*G[{0, 1/(yu*yv), 1/(yu*yv), 1/(yu*yv)}, yw] - 
     13*G[{1}, yu^(-1)]*G[{0, 1/(yu*yv), 1/(yu*yv), 1/(yu*yv)}, yw] - 
     13*G[{1}, yv^(-1)]*G[{0, 1/(yu*yv), 1/(yu*yv), 1/(yu*yv)}, yw] + 
     2*G[{1}, yw]*G[{0, 1/(yu*yv), 1/(yu*yv), 1/(yu*yv)}, yw] - 
     2*G[{yu^(-1)}, yw]*G[{0, 1/(yu*yv), 1/(yu*yv), 1/(yu*yv)}, yw] + 
     4*G[{yu}, yv^(-1)]*G[{0, 1/(yu*yv), 1/(yu*yv), 1/(yu*yv)}, yw] - 
     2*G[{yv^(-1)}, yw]*G[{0, 1/(yu*yv), 1/(yu*yv), 1/(yu*yv)}, yw] + 
     2*G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv), 1/(yu*yv), 1/(yu*yv)}, yw] - 
     3*G[{0}, yu^(-1)]*G[{1, 1, 1, yu^(-1)}, yw] - 
     3*G[{0}, yv^(-1)]*G[{1, 1, 1, yu^(-1)}, yw] + 
     3*G[{0}, yw]*G[{1, 1, 1, yu^(-1)}, yw] + 3*G[{1}, yu^(-1)]*
      G[{1, 1, 1, yu^(-1)}, yw] + 3*G[{1}, yv^(-1)]*G[{1, 1, 1, yu^(-1)}, 
       yw] - 6*G[{yv^(-1)}, yw]*G[{1, 1, 1, yu^(-1)}, yw] + 
     4*G[{1/(yu*yv)}, yw]*G[{1, 1, 1, yu^(-1)}, yw] + 
     3*G[{1}, yu^(-1)]*G[{1, 1, 1, yu}, yv^(-1)] + 
     4*G[{1}, yw]*G[{1, 1, 1, yu}, yv^(-1)] - 2*G[{yu^(-1)}, yw]*
      G[{1, 1, 1, yu}, yv^(-1)] - 6*G[{yv^(-1)}, yw]*
      G[{1, 1, 1, yu}, yv^(-1)] + 4*G[{1/(yu*yv)}, yw]*
      G[{1, 1, 1, yu}, yv^(-1)] - 3*G[{0}, yu^(-1)]*G[{1, 1, 1, yv^(-1)}, 
       yw] - 3*G[{0}, yv^(-1)]*G[{1, 1, 1, yv^(-1)}, yw] + 
     3*G[{0}, yw]*G[{1, 1, 1, yv^(-1)}, yw] + 3*G[{1}, yu^(-1)]*
      G[{1, 1, 1, yv^(-1)}, yw] + 3*G[{1}, yv^(-1)]*G[{1, 1, 1, yv^(-1)}, 
       yw] - 6*G[{yu^(-1)}, yw]*G[{1, 1, 1, yv^(-1)}, yw] + 
     4*G[{1/(yu*yv)}, yw]*G[{1, 1, 1, yv^(-1)}, yw] + 
     4*G[{0}, yu^(-1)]*G[{1, 1, 1, 1/(yu*yv)}, yw] + 
     4*G[{0}, yv^(-1)]*G[{1, 1, 1, 1/(yu*yv)}, yw] - 
     4*G[{0}, yw]*G[{1, 1, 1, 1/(yu*yv)}, yw] - 4*G[{1}, yu^(-1)]*
      G[{1, 1, 1, 1/(yu*yv)}, yw] - 4*G[{1}, yv^(-1)]*
      G[{1, 1, 1, 1/(yu*yv)}, yw] + 6*G[{yu^(-1)}, yw]*
      G[{1, 1, 1, 1/(yu*yv)}, yw] + 6*G[{yv^(-1)}, yw]*
      G[{1, 1, 1, 1/(yu*yv)}, yw] - 12*G[{1/(yu*yv)}, yw]*
      G[{1, 1, 1, 1/(yu*yv)}, yw] + G[{0}, yu^(-1)]*
      G[{1, 1, yu^(-1), yu^(-1)}, yw] + G[{0}, yv^(-1)]*
      G[{1, 1, yu^(-1), yu^(-1)}, yw] - G[{0}, yw]*
      G[{1, 1, yu^(-1), yu^(-1)}, yw] - G[{1}, yu^(-1)]*
      G[{1, 1, yu^(-1), yu^(-1)}, yw] + 3*G[{1}, yv^(-1)]*
      G[{1, 1, yu^(-1), yu^(-1)}, yw] + 4*G[{1}, yw]*
      G[{1, 1, yu^(-1), yu^(-1)}, yw] - 4*G[{yu}, yv^(-1)]*
      G[{1, 1, yu^(-1), yu^(-1)}, yw] + 2*G[{yv^(-1)}, yw]*
      G[{1, 1, yu^(-1), yu^(-1)}, yw] + 4*G[{1/(yu*yv)}, yw]*
      G[{1, 1, yu^(-1), yu^(-1)}, yw] - 3*G[{0}, yu^(-1)]*
      G[{1, 1, yu^(-1), yv^(-1)}, yw] - 3*G[{0}, yv^(-1)]*
      G[{1, 1, yu^(-1), yv^(-1)}, yw] + 3*G[{0}, yw]*
      G[{1, 1, yu^(-1), yv^(-1)}, yw] + 3*G[{1}, yu^(-1)]*
      G[{1, 1, yu^(-1), yv^(-1)}, yw] + 3*G[{1}, yv^(-1)]*
      G[{1, 1, yu^(-1), yv^(-1)}, yw] - 2*G[{yu^(-1)}, yw]*
      G[{1, 1, yu^(-1), yv^(-1)}, yw] - 2*G[{yv^(-1)}, yw]*
      G[{1, 1, yu^(-1), yv^(-1)}, yw] + 6*G[{1/(yu*yv)}, yw]*
      G[{1, 1, yu^(-1), yv^(-1)}, yw] - G[{0}, yu^(-1)]*
      G[{1, 1, yu^(-1), 1/(yu*yv)}, yw] - G[{0}, yv^(-1)]*
      G[{1, 1, yu^(-1), 1/(yu*yv)}, yw] + 
     G[{0}, yw]*G[{1, 1, yu^(-1), 1/(yu*yv)}, yw] + 
     G[{1}, yu^(-1)]*G[{1, 1, yu^(-1), 1/(yu*yv)}, yw] + 
     9*G[{1}, yv^(-1)]*G[{1, 1, yu^(-1), 1/(yu*yv)}, yw] + 
     8*G[{1}, yw]*G[{1, 1, yu^(-1), 1/(yu*yv)}, yw] - 
     2*G[{yu^(-1)}, yw]*G[{1, 1, yu^(-1), 1/(yu*yv)}, yw] - 
     8*G[{yu}, yv^(-1)]*G[{1, 1, yu^(-1), 1/(yu*yv)}, yw] - 
     6*G[{yv^(-1)}, yw]*G[{1, 1, yu^(-1), 1/(yu*yv)}, yw] + 
     2*G[{1/(yu*yv)}, yw]*G[{1, 1, yu^(-1), 1/(yu*yv)}, yw] - 
     G[{1}, yu^(-1)]*G[{1, 1, yu, yu}, yv^(-1)] + 
     4*G[{1}, yv^(-1)]*G[{1, 1, yu, yu}, yv^(-1)] + 
     4*G[{1}, yw]*G[{1, 1, yu, yu}, yv^(-1)] - 10*G[{yu^(-1)}, yw]*
      G[{1, 1, yu, yu}, yv^(-1)] + 2*G[{yv^(-1)}, yw]*
      G[{1, 1, yu, yu}, yv^(-1)] + 4*G[{1/(yu*yv)}, yw]*
      G[{1, 1, yu, yu}, yv^(-1)] - 3*G[{0}, yu^(-1)]*
      G[{1, 1, yv^(-1), yu^(-1)}, yw] - 3*G[{0}, yv^(-1)]*
      G[{1, 1, yv^(-1), yu^(-1)}, yw] + 3*G[{0}, yw]*
      G[{1, 1, yv^(-1), yu^(-1)}, yw] + 3*G[{1}, yu^(-1)]*
      G[{1, 1, yv^(-1), yu^(-1)}, yw] + 3*G[{1}, yv^(-1)]*
      G[{1, 1, yv^(-1), yu^(-1)}, yw] - 2*G[{yu^(-1)}, yw]*
      G[{1, 1, yv^(-1), yu^(-1)}, yw] - 2*G[{yv^(-1)}, yw]*
      G[{1, 1, yv^(-1), yu^(-1)}, yw] + 6*G[{1/(yu*yv)}, yw]*
      G[{1, 1, yv^(-1), yu^(-1)}, yw] + G[{0}, yu^(-1)]*
      G[{1, 1, yv^(-1), yv^(-1)}, yw] + G[{0}, yv^(-1)]*
      G[{1, 1, yv^(-1), yv^(-1)}, yw] - G[{0}, yw]*
      G[{1, 1, yv^(-1), yv^(-1)}, yw] + 3*G[{1}, yu^(-1)]*
      G[{1, 1, yv^(-1), yv^(-1)}, yw] - G[{1}, yv^(-1)]*
      G[{1, 1, yv^(-1), yv^(-1)}, yw] + 4*G[{1}, yw]*
      G[{1, 1, yv^(-1), yv^(-1)}, yw] + 2*G[{yu^(-1)}, yw]*
      G[{1, 1, yv^(-1), yv^(-1)}, yw] - 4*G[{yu}, yv^(-1)]*
      G[{1, 1, yv^(-1), yv^(-1)}, yw] + 4*G[{1/(yu*yv)}, yw]*
      G[{1, 1, yv^(-1), yv^(-1)}, yw] - G[{0}, yu^(-1)]*
      G[{1, 1, yv^(-1), 1/(yu*yv)}, yw] - G[{0}, yv^(-1)]*
      G[{1, 1, yv^(-1), 1/(yu*yv)}, yw] + 
     G[{0}, yw]*G[{1, 1, yv^(-1), 1/(yu*yv)}, yw] + 
     9*G[{1}, yu^(-1)]*G[{1, 1, yv^(-1), 1/(yu*yv)}, yw] + 
     G[{1}, yv^(-1)]*G[{1, 1, yv^(-1), 1/(yu*yv)}, yw] + 
     8*G[{1}, yw]*G[{1, 1, yv^(-1), 1/(yu*yv)}, yw] - 
     6*G[{yu^(-1)}, yw]*G[{1, 1, yv^(-1), 1/(yu*yv)}, yw] - 
     8*G[{yu}, yv^(-1)]*G[{1, 1, yv^(-1), 1/(yu*yv)}, yw] - 
     2*G[{yv^(-1)}, yw]*G[{1, 1, yv^(-1), 1/(yu*yv)}, yw] + 
     2*G[{1/(yu*yv)}, yw]*G[{1, 1, yv^(-1), 1/(yu*yv)}, yw] + 
     8*G[{1}, yv^(-1)]*G[{1, 1, 1/(yu*yv), yu^(-1)}, yw] + 
     8*G[{1}, yw]*G[{1, 1, 1/(yu*yv), yu^(-1)}, yw] - 
     2*G[{yu^(-1)}, yw]*G[{1, 1, 1/(yu*yv), yu^(-1)}, yw] - 
     8*G[{yu}, yv^(-1)]*G[{1, 1, 1/(yu*yv), yu^(-1)}, yw] - 
     8*G[{yv^(-1)}, yw]*G[{1, 1, 1/(yu*yv), yu^(-1)}, yw] + 
     2*G[{1/(yu*yv)}, yw]*G[{1, 1, 1/(yu*yv), yu^(-1)}, yw] + 
     8*G[{1}, yu^(-1)]*G[{1, 1, 1/(yu*yv), yv^(-1)}, yw] + 
     8*G[{1}, yw]*G[{1, 1, 1/(yu*yv), yv^(-1)}, yw] - 
     8*G[{yu^(-1)}, yw]*G[{1, 1, 1/(yu*yv), yv^(-1)}, yw] - 
     8*G[{yu}, yv^(-1)]*G[{1, 1, 1/(yu*yv), yv^(-1)}, yw] - 
     2*G[{yv^(-1)}, yw]*G[{1, 1, 1/(yu*yv), yv^(-1)}, yw] + 
     2*G[{1/(yu*yv)}, yw]*G[{1, 1, 1/(yu*yv), yv^(-1)}, yw] + 
     4*G[{0}, yu^(-1)]*G[{1, 1, 1/(yu*yv), 1/(yu*yv)}, yw] + 
     4*G[{0}, yv^(-1)]*G[{1, 1, 1/(yu*yv), 1/(yu*yv)}, yw] - 
     4*G[{0}, yw]*G[{1, 1, 1/(yu*yv), 1/(yu*yv)}, yw] - 
     16*G[{1}, yu^(-1)]*G[{1, 1, 1/(yu*yv), 1/(yu*yv)}, yw] - 
     16*G[{1}, yv^(-1)]*G[{1, 1, 1/(yu*yv), 1/(yu*yv)}, yw] - 
     24*G[{1}, yw]*G[{1, 1, 1/(yu*yv), 1/(yu*yv)}, yw] + 
     4*G[{yu^(-1)}, yw]*G[{1, 1, 1/(yu*yv), 1/(yu*yv)}, yw] + 
     24*G[{yu}, yv^(-1)]*G[{1, 1, 1/(yu*yv), 1/(yu*yv)}, yw] + 
     4*G[{yv^(-1)}, yw]*G[{1, 1, 1/(yu*yv), 1/(yu*yv)}, yw] - 
     8*G[{1/(yu*yv)}, yw]*G[{1, 1, 1/(yu*yv), 1/(yu*yv)}, yw] + 
     4*G[{0}, yu^(-1)]*G[{1, yu^(-1), 1, 1/(yu*yv)}, yw] + 
     4*G[{0}, yv^(-1)]*G[{1, yu^(-1), 1, 1/(yu*yv)}, yw] - 
     4*G[{0}, yw]*G[{1, yu^(-1), 1, 1/(yu*yv)}, yw] - 
     4*G[{1}, yu^(-1)]*G[{1, yu^(-1), 1, 1/(yu*yv)}, yw] + 
     4*G[{1}, yw]*G[{1, yu^(-1), 1, 1/(yu*yv)}, yw] - 
     4*G[{yu}, yv^(-1)]*G[{1, yu^(-1), 1, 1/(yu*yv)}, yw] - 
     4*G[{yv^(-1)}, yw]*G[{1, yu^(-1), 1, 1/(yu*yv)}, yw] + 
     5*G[{0}, yu^(-1)]*G[{1, yu^(-1), yu^(-1), yu^(-1)}, yw] + 
     5*G[{0}, yv^(-1)]*G[{1, yu^(-1), yu^(-1), yu^(-1)}, yw] - 
     5*G[{0}, yw]*G[{1, yu^(-1), yu^(-1), yu^(-1)}, yw] - 
     5*G[{1}, yu^(-1)]*G[{1, yu^(-1), yu^(-1), yu^(-1)}, yw] + 
     5*G[{1}, yw]*G[{1, yu^(-1), yu^(-1), yu^(-1)}, yw] - 
     5*G[{yu}, yv^(-1)]*G[{1, yu^(-1), yu^(-1), yu^(-1)}, yw] + 
     12*G[{yv^(-1)}, yw]*G[{1, yu^(-1), yu^(-1), yu^(-1)}, yw] - 
     3*G[{0}, yu^(-1)]*G[{1, yu^(-1), yu^(-1), yv^(-1)}, yw] - 
     3*G[{0}, yv^(-1)]*G[{1, yu^(-1), yu^(-1), yv^(-1)}, yw] + 
     3*G[{0}, yw]*G[{1, yu^(-1), yu^(-1), yv^(-1)}, yw] + 
     3*G[{1}, yu^(-1)]*G[{1, yu^(-1), yu^(-1), yv^(-1)}, yw] + 
     11*G[{1}, yv^(-1)]*G[{1, yu^(-1), yu^(-1), yv^(-1)}, yw] + 
     8*G[{1}, yw]*G[{1, yu^(-1), yu^(-1), yv^(-1)}, yw] - 
     4*G[{yu^(-1)}, yw]*G[{1, yu^(-1), yu^(-1), yv^(-1)}, yw] - 
     8*G[{yu}, yv^(-1)]*G[{1, yu^(-1), yu^(-1), yv^(-1)}, yw] - 
     4*G[{yv^(-1)}, yw]*G[{1, yu^(-1), yu^(-1), yv^(-1)}, yw] + 
     8*G[{1/(yu*yv)}, yw]*G[{1, yu^(-1), yu^(-1), yv^(-1)}, yw] - 
     9*G[{0}, yu^(-1)]*G[{1, yu^(-1), yu^(-1), 1/(yu*yv)}, yw] - 
     9*G[{0}, yv^(-1)]*G[{1, yu^(-1), yu^(-1), 1/(yu*yv)}, yw] + 
     9*G[{0}, yw]*G[{1, yu^(-1), yu^(-1), 1/(yu*yv)}, yw] + 
     9*G[{1}, yu^(-1)]*G[{1, yu^(-1), yu^(-1), 1/(yu*yv)}, yw] - 
     9*G[{1}, yw]*G[{1, yu^(-1), yu^(-1), 1/(yu*yv)}, yw] + 
     9*G[{yu}, yv^(-1)]*G[{1, yu^(-1), yu^(-1), 1/(yu*yv)}, yw] + 
     6*G[{yv^(-1)}, yw]*G[{1, yu^(-1), yu^(-1), 1/(yu*yv)}, yw] - 
     3*G[{0}, yu^(-1)]*G[{1, yu^(-1), yv^(-1), yu^(-1)}, yw] - 
     3*G[{0}, yv^(-1)]*G[{1, yu^(-1), yv^(-1), yu^(-1)}, yw] + 
     3*G[{0}, yw]*G[{1, yu^(-1), yv^(-1), yu^(-1)}, yw] + 
     3*G[{1}, yu^(-1)]*G[{1, yu^(-1), yv^(-1), yu^(-1)}, yw] + 
     11*G[{1}, yv^(-1)]*G[{1, yu^(-1), yv^(-1), yu^(-1)}, yw] + 
     8*G[{1}, yw]*G[{1, yu^(-1), yv^(-1), yu^(-1)}, yw] - 
     4*G[{yu^(-1)}, yw]*G[{1, yu^(-1), yv^(-1), yu^(-1)}, yw] - 
     8*G[{yu}, yv^(-1)]*G[{1, yu^(-1), yv^(-1), yu^(-1)}, yw] - 
     4*G[{yv^(-1)}, yw]*G[{1, yu^(-1), yv^(-1), yu^(-1)}, yw] + 
     8*G[{1/(yu*yv)}, yw]*G[{1, yu^(-1), yv^(-1), yu^(-1)}, yw] - 
     3*G[{0}, yu^(-1)]*G[{1, yu^(-1), yv^(-1), yv^(-1)}, yw] - 
     3*G[{0}, yv^(-1)]*G[{1, yu^(-1), yv^(-1), yv^(-1)}, yw] + 
     3*G[{0}, yw]*G[{1, yu^(-1), yv^(-1), yv^(-1)}, yw] + 
     11*G[{1}, yu^(-1)]*G[{1, yu^(-1), yv^(-1), yv^(-1)}, yw] + 
     3*G[{1}, yv^(-1)]*G[{1, yu^(-1), yv^(-1), yv^(-1)}, yw] + 
     8*G[{1}, yw]*G[{1, yu^(-1), yv^(-1), yv^(-1)}, yw] - 
     4*G[{yu^(-1)}, yw]*G[{1, yu^(-1), yv^(-1), yv^(-1)}, yw] - 
     8*G[{yu}, yv^(-1)]*G[{1, yu^(-1), yv^(-1), yv^(-1)}, yw] - 
     4*G[{yv^(-1)}, yw]*G[{1, yu^(-1), yv^(-1), yv^(-1)}, yw] + 
     8*G[{1/(yu*yv)}, yw]*G[{1, yu^(-1), yv^(-1), yv^(-1)}, yw] - 
     5*G[{0}, yu^(-1)]*G[{1, yu^(-1), yv^(-1), 1/(yu*yv)}, yw] - 
     5*G[{0}, yv^(-1)]*G[{1, yu^(-1), yv^(-1), 1/(yu*yv)}, yw] + 
     5*G[{0}, yw]*G[{1, yu^(-1), yv^(-1), 1/(yu*yv)}, yw] + 
     G[{1}, yu^(-1)]*G[{1, yu^(-1), yv^(-1), 1/(yu*yv)}, yw] + 
     G[{1}, yv^(-1)]*G[{1, yu^(-1), yv^(-1), 1/(yu*yv)}, yw] - 
     8*G[{1}, yw]*G[{1, yu^(-1), yv^(-1), 1/(yu*yv)}, yw] + 
     6*G[{yu^(-1)}, yw]*G[{1, yu^(-1), yv^(-1), 1/(yu*yv)}, yw] + 
     8*G[{yu}, yv^(-1)]*G[{1, yu^(-1), yv^(-1), 1/(yu*yv)}, yw] + 
     6*G[{yv^(-1)}, yw]*G[{1, yu^(-1), yv^(-1), 1/(yu*yv)}, yw] - 
     6*G[{1/(yu*yv)}, yw]*G[{1, yu^(-1), yv^(-1), 1/(yu*yv)}, yw] - 
     5*G[{0}, yu^(-1)]*G[{1, yu^(-1), 1/(yu*yv), yu^(-1)}, yw] - 
     5*G[{0}, yv^(-1)]*G[{1, yu^(-1), 1/(yu*yv), yu^(-1)}, yw] + 
     5*G[{0}, yw]*G[{1, yu^(-1), 1/(yu*yv), yu^(-1)}, yw] + 
     5*G[{1}, yu^(-1)]*G[{1, yu^(-1), 1/(yu*yv), yu^(-1)}, yw] - 
     5*G[{1}, yw]*G[{1, yu^(-1), 1/(yu*yv), yu^(-1)}, yw] + 
     5*G[{yu}, yv^(-1)]*G[{1, yu^(-1), 1/(yu*yv), yu^(-1)}, yw] + 
     2*G[{yv^(-1)}, yw]*G[{1, yu^(-1), 1/(yu*yv), yu^(-1)}, yw] - 
     G[{0}, yu^(-1)]*G[{1, yu^(-1), 1/(yu*yv), yv^(-1)}, yw] - 
     G[{0}, yv^(-1)]*G[{1, yu^(-1), 1/(yu*yv), yv^(-1)}, yw] + 
     G[{0}, yw]*G[{1, yu^(-1), 1/(yu*yv), yv^(-1)}, yw] - 
     3*G[{1}, yu^(-1)]*G[{1, yu^(-1), 1/(yu*yv), yv^(-1)}, yw] + 
     G[{1}, yv^(-1)]*G[{1, yu^(-1), 1/(yu*yv), yv^(-1)}, yw] - 
     4*G[{1}, yw]*G[{1, yu^(-1), 1/(yu*yv), yv^(-1)}, yw] + 
     6*G[{yu^(-1)}, yw]*G[{1, yu^(-1), 1/(yu*yv), yv^(-1)}, yw] + 
     4*G[{yu}, yv^(-1)]*G[{1, yu^(-1), 1/(yu*yv), yv^(-1)}, yw] + 
     2*G[{yv^(-1)}, yw]*G[{1, yu^(-1), 1/(yu*yv), yv^(-1)}, yw] - 
     6*G[{1/(yu*yv)}, yw]*G[{1, yu^(-1), 1/(yu*yv), yv^(-1)}, yw] + 
     9*G[{0}, yu^(-1)]*G[{1, yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] + 
     9*G[{0}, yv^(-1)]*G[{1, yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] - 
     9*G[{0}, yw]*G[{1, yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] - 
     9*G[{1}, yu^(-1)]*G[{1, yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] + 
     9*G[{1}, yw]*G[{1, yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] - 
     9*G[{yu}, yv^(-1)]*G[{1, yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] - 
     2*G[{yv^(-1)}, yw]*G[{1, yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] - 
     5*G[{1}, yu^(-1)]*G[{1, yu, yu, yu}, yv^(-1)] + 
     5*G[{1}, yv^(-1)]*G[{1, yu, yu, yu}, yv^(-1)] - 
     12*G[{yu^(-1)}, yw]*G[{1, yu, yu, yu}, yv^(-1)] + 
     12*G[{yv^(-1)}, yw]*G[{1, yu, yu, yu}, yv^(-1)] + 
     4*G[{0}, yu^(-1)]*G[{1, yv^(-1), 1, 1/(yu*yv)}, yw] + 
     4*G[{0}, yv^(-1)]*G[{1, yv^(-1), 1, 1/(yu*yv)}, yw] - 
     4*G[{0}, yw]*G[{1, yv^(-1), 1, 1/(yu*yv)}, yw] - 
     4*G[{1}, yv^(-1)]*G[{1, yv^(-1), 1, 1/(yu*yv)}, yw] + 
     4*G[{1}, yw]*G[{1, yv^(-1), 1, 1/(yu*yv)}, yw] - 
     4*G[{yu^(-1)}, yw]*G[{1, yv^(-1), 1, 1/(yu*yv)}, yw] - 
     4*G[{yu}, yv^(-1)]*G[{1, yv^(-1), 1, 1/(yu*yv)}, yw] - 
     3*G[{0}, yu^(-1)]*G[{1, yv^(-1), yu^(-1), yu^(-1)}, yw] - 
     3*G[{0}, yv^(-1)]*G[{1, yv^(-1), yu^(-1), yu^(-1)}, yw] + 
     3*G[{0}, yw]*G[{1, yv^(-1), yu^(-1), yu^(-1)}, yw] + 
     3*G[{1}, yu^(-1)]*G[{1, yv^(-1), yu^(-1), yu^(-1)}, yw] + 
     11*G[{1}, yv^(-1)]*G[{1, yv^(-1), yu^(-1), yu^(-1)}, yw] + 
     8*G[{1}, yw]*G[{1, yv^(-1), yu^(-1), yu^(-1)}, yw] - 
     4*G[{yu^(-1)}, yw]*G[{1, yv^(-1), yu^(-1), yu^(-1)}, yw] - 
     8*G[{yu}, yv^(-1)]*G[{1, yv^(-1), yu^(-1), yu^(-1)}, yw] - 
     4*G[{yv^(-1)}, yw]*G[{1, yv^(-1), yu^(-1), yu^(-1)}, yw] + 
     8*G[{1/(yu*yv)}, yw]*G[{1, yv^(-1), yu^(-1), yu^(-1)}, yw] - 
     3*G[{0}, yu^(-1)]*G[{1, yv^(-1), yu^(-1), yv^(-1)}, yw] - 
     3*G[{0}, yv^(-1)]*G[{1, yv^(-1), yu^(-1), yv^(-1)}, yw] + 
     3*G[{0}, yw]*G[{1, yv^(-1), yu^(-1), yv^(-1)}, yw] + 
     11*G[{1}, yu^(-1)]*G[{1, yv^(-1), yu^(-1), yv^(-1)}, yw] + 
     3*G[{1}, yv^(-1)]*G[{1, yv^(-1), yu^(-1), yv^(-1)}, yw] + 
     8*G[{1}, yw]*G[{1, yv^(-1), yu^(-1), yv^(-1)}, yw] - 
     4*G[{yu^(-1)}, yw]*G[{1, yv^(-1), yu^(-1), yv^(-1)}, yw] - 
     8*G[{yu}, yv^(-1)]*G[{1, yv^(-1), yu^(-1), yv^(-1)}, yw] - 
     4*G[{yv^(-1)}, yw]*G[{1, yv^(-1), yu^(-1), yv^(-1)}, yw] + 
     8*G[{1/(yu*yv)}, yw]*G[{1, yv^(-1), yu^(-1), yv^(-1)}, yw] - 
     5*G[{0}, yu^(-1)]*G[{1, yv^(-1), yu^(-1), 1/(yu*yv)}, yw] - 
     5*G[{0}, yv^(-1)]*G[{1, yv^(-1), yu^(-1), 1/(yu*yv)}, yw] + 
     5*G[{0}, yw]*G[{1, yv^(-1), yu^(-1), 1/(yu*yv)}, yw] + 
     G[{1}, yu^(-1)]*G[{1, yv^(-1), yu^(-1), 1/(yu*yv)}, yw] + 
     G[{1}, yv^(-1)]*G[{1, yv^(-1), yu^(-1), 1/(yu*yv)}, yw] - 
     8*G[{1}, yw]*G[{1, yv^(-1), yu^(-1), 1/(yu*yv)}, yw] + 
     6*G[{yu^(-1)}, yw]*G[{1, yv^(-1), yu^(-1), 1/(yu*yv)}, yw] + 
     8*G[{yu}, yv^(-1)]*G[{1, yv^(-1), yu^(-1), 1/(yu*yv)}, yw] + 
     6*G[{yv^(-1)}, yw]*G[{1, yv^(-1), yu^(-1), 1/(yu*yv)}, yw] - 
     6*G[{1/(yu*yv)}, yw]*G[{1, yv^(-1), yu^(-1), 1/(yu*yv)}, yw] - 
     3*G[{0}, yu^(-1)]*G[{1, yv^(-1), yv^(-1), yu^(-1)}, yw] - 
     3*G[{0}, yv^(-1)]*G[{1, yv^(-1), yv^(-1), yu^(-1)}, yw] + 
     3*G[{0}, yw]*G[{1, yv^(-1), yv^(-1), yu^(-1)}, yw] + 
     11*G[{1}, yu^(-1)]*G[{1, yv^(-1), yv^(-1), yu^(-1)}, yw] + 
     3*G[{1}, yv^(-1)]*G[{1, yv^(-1), yv^(-1), yu^(-1)}, yw] + 
     8*G[{1}, yw]*G[{1, yv^(-1), yv^(-1), yu^(-1)}, yw] - 
     4*G[{yu^(-1)}, yw]*G[{1, yv^(-1), yv^(-1), yu^(-1)}, yw] - 
     8*G[{yu}, yv^(-1)]*G[{1, yv^(-1), yv^(-1), yu^(-1)}, yw] - 
     4*G[{yv^(-1)}, yw]*G[{1, yv^(-1), yv^(-1), yu^(-1)}, yw] + 
     8*G[{1/(yu*yv)}, yw]*G[{1, yv^(-1), yv^(-1), yu^(-1)}, yw] + 
     5*G[{0}, yu^(-1)]*G[{1, yv^(-1), yv^(-1), yv^(-1)}, yw] + 
     5*G[{0}, yv^(-1)]*G[{1, yv^(-1), yv^(-1), yv^(-1)}, yw] - 
     5*G[{0}, yw]*G[{1, yv^(-1), yv^(-1), yv^(-1)}, yw] - 
     5*G[{1}, yv^(-1)]*G[{1, yv^(-1), yv^(-1), yv^(-1)}, yw] + 
     5*G[{1}, yw]*G[{1, yv^(-1), yv^(-1), yv^(-1)}, yw] + 
     12*G[{yu^(-1)}, yw]*G[{1, yv^(-1), yv^(-1), yv^(-1)}, yw] - 
     5*G[{yu}, yv^(-1)]*G[{1, yv^(-1), yv^(-1), yv^(-1)}, yw] - 
     9*G[{0}, yu^(-1)]*G[{1, yv^(-1), yv^(-1), 1/(yu*yv)}, yw] - 
     9*G[{0}, yv^(-1)]*G[{1, yv^(-1), yv^(-1), 1/(yu*yv)}, yw] + 
     9*G[{0}, yw]*G[{1, yv^(-1), yv^(-1), 1/(yu*yv)}, yw] + 
     9*G[{1}, yv^(-1)]*G[{1, yv^(-1), yv^(-1), 1/(yu*yv)}, yw] - 
     9*G[{1}, yw]*G[{1, yv^(-1), yv^(-1), 1/(yu*yv)}, yw] + 
     6*G[{yu^(-1)}, yw]*G[{1, yv^(-1), yv^(-1), 1/(yu*yv)}, yw] + 
     9*G[{yu}, yv^(-1)]*G[{1, yv^(-1), yv^(-1), 1/(yu*yv)}, yw] - 
     G[{0}, yu^(-1)]*G[{1, yv^(-1), 1/(yu*yv), yu^(-1)}, yw] - 
     G[{0}, yv^(-1)]*G[{1, yv^(-1), 1/(yu*yv), yu^(-1)}, yw] + 
     G[{0}, yw]*G[{1, yv^(-1), 1/(yu*yv), yu^(-1)}, yw] + 
     G[{1}, yu^(-1)]*G[{1, yv^(-1), 1/(yu*yv), yu^(-1)}, yw] - 
     3*G[{1}, yv^(-1)]*G[{1, yv^(-1), 1/(yu*yv), yu^(-1)}, yw] - 
     4*G[{1}, yw]*G[{1, yv^(-1), 1/(yu*yv), yu^(-1)}, yw] + 
     2*G[{yu^(-1)}, yw]*G[{1, yv^(-1), 1/(yu*yv), yu^(-1)}, yw] + 
     4*G[{yu}, yv^(-1)]*G[{1, yv^(-1), 1/(yu*yv), yu^(-1)}, yw] + 
     6*G[{yv^(-1)}, yw]*G[{1, yv^(-1), 1/(yu*yv), yu^(-1)}, yw] - 
     6*G[{1/(yu*yv)}, yw]*G[{1, yv^(-1), 1/(yu*yv), yu^(-1)}, yw] - 
     5*G[{0}, yu^(-1)]*G[{1, yv^(-1), 1/(yu*yv), yv^(-1)}, yw] - 
     5*G[{0}, yv^(-1)]*G[{1, yv^(-1), 1/(yu*yv), yv^(-1)}, yw] + 
     5*G[{0}, yw]*G[{1, yv^(-1), 1/(yu*yv), yv^(-1)}, yw] + 
     5*G[{1}, yv^(-1)]*G[{1, yv^(-1), 1/(yu*yv), yv^(-1)}, yw] - 
     5*G[{1}, yw]*G[{1, yv^(-1), 1/(yu*yv), yv^(-1)}, yw] + 
     2*G[{yu^(-1)}, yw]*G[{1, yv^(-1), 1/(yu*yv), yv^(-1)}, yw] + 
     5*G[{yu}, yv^(-1)]*G[{1, yv^(-1), 1/(yu*yv), yv^(-1)}, yw] + 
     9*G[{0}, yu^(-1)]*G[{1, yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] + 
     9*G[{0}, yv^(-1)]*G[{1, yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] - 
     9*G[{0}, yw]*G[{1, yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] - 
     9*G[{1}, yv^(-1)]*G[{1, yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] + 
     9*G[{1}, yw]*G[{1, yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] - 
     2*G[{yu^(-1)}, yw]*G[{1, yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] - 
     9*G[{yu}, yv^(-1)]*G[{1, yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] - 
     8*G[{0}, yu^(-1)]*G[{1, 1/(yu*yv), yu^(-1), yu^(-1)}, yw] - 
     8*G[{0}, yv^(-1)]*G[{1, 1/(yu*yv), yu^(-1), yu^(-1)}, yw] + 
     8*G[{0}, yw]*G[{1, 1/(yu*yv), yu^(-1), yu^(-1)}, yw] + 
     8*G[{1}, yu^(-1)]*G[{1, 1/(yu*yv), yu^(-1), yu^(-1)}, yw] + 
     11*G[{1}, yv^(-1)]*G[{1, 1/(yu*yv), yu^(-1), yu^(-1)}, yw] + 
     3*G[{1}, yw]*G[{1, 1/(yu*yv), yu^(-1), yu^(-1)}, yw] - 
     4*G[{yu^(-1)}, yw]*G[{1, 1/(yu*yv), yu^(-1), yu^(-1)}, yw] - 
     3*G[{yu}, yv^(-1)]*G[{1, 1/(yu*yv), yu^(-1), yu^(-1)}, yw] - 
     8*G[{yv^(-1)}, yw]*G[{1, 1/(yu*yv), yu^(-1), yu^(-1)}, yw] + 
     8*G[{1/(yu*yv)}, yw]*G[{1, 1/(yu*yv), yu^(-1), yu^(-1)}, yw] + 
     4*G[{0}, yu^(-1)]*G[{1, 1/(yu*yv), yu^(-1), 1/(yu*yv)}, yw] + 
     4*G[{0}, yv^(-1)]*G[{1, 1/(yu*yv), yu^(-1), 1/(yu*yv)}, yw] - 
     4*G[{0}, yw]*G[{1, 1/(yu*yv), yu^(-1), 1/(yu*yv)}, yw] - 
     8*G[{1}, yu^(-1)]*G[{1, 1/(yu*yv), yu^(-1), 1/(yu*yv)}, yw] + 
     G[{1}, yv^(-1)]*G[{1, 1/(yu*yv), yu^(-1), 1/(yu*yv)}, yw] + 
     G[{1}, yw]*G[{1, 1/(yu*yv), yu^(-1), 1/(yu*yv)}, yw] + 
     6*G[{yu^(-1)}, yw]*G[{1, 1/(yu*yv), yu^(-1), 1/(yu*yv)}, yw] - 
     G[{yu}, yv^(-1)]*G[{1, 1/(yu*yv), yu^(-1), 1/(yu*yv)}, yw] - 
     6*G[{1/(yu*yv)}, yw]*G[{1, 1/(yu*yv), yu^(-1), 1/(yu*yv)}, yw] - 
     8*G[{0}, yu^(-1)]*G[{1, 1/(yu*yv), yv^(-1), yv^(-1)}, yw] - 
     8*G[{0}, yv^(-1)]*G[{1, 1/(yu*yv), yv^(-1), yv^(-1)}, yw] + 
     8*G[{0}, yw]*G[{1, 1/(yu*yv), yv^(-1), yv^(-1)}, yw] + 
     11*G[{1}, yu^(-1)]*G[{1, 1/(yu*yv), yv^(-1), yv^(-1)}, yw] + 
     8*G[{1}, yv^(-1)]*G[{1, 1/(yu*yv), yv^(-1), yv^(-1)}, yw] + 
     3*G[{1}, yw]*G[{1, 1/(yu*yv), yv^(-1), yv^(-1)}, yw] - 
     8*G[{yu^(-1)}, yw]*G[{1, 1/(yu*yv), yv^(-1), yv^(-1)}, yw] - 
     3*G[{yu}, yv^(-1)]*G[{1, 1/(yu*yv), yv^(-1), yv^(-1)}, yw] - 
     4*G[{yv^(-1)}, yw]*G[{1, 1/(yu*yv), yv^(-1), yv^(-1)}, yw] + 
     8*G[{1/(yu*yv)}, yw]*G[{1, 1/(yu*yv), yv^(-1), yv^(-1)}, yw] + 
     4*G[{0}, yu^(-1)]*G[{1, 1/(yu*yv), yv^(-1), 1/(yu*yv)}, yw] + 
     4*G[{0}, yv^(-1)]*G[{1, 1/(yu*yv), yv^(-1), 1/(yu*yv)}, yw] - 
     4*G[{0}, yw]*G[{1, 1/(yu*yv), yv^(-1), 1/(yu*yv)}, yw] + 
     G[{1}, yu^(-1)]*G[{1, 1/(yu*yv), yv^(-1), 1/(yu*yv)}, yw] - 
     8*G[{1}, yv^(-1)]*G[{1, 1/(yu*yv), yv^(-1), 1/(yu*yv)}, yw] + 
     G[{1}, yw]*G[{1, 1/(yu*yv), yv^(-1), 1/(yu*yv)}, yw] - 
     G[{yu}, yv^(-1)]*G[{1, 1/(yu*yv), yv^(-1), 1/(yu*yv)}, yw] + 
     6*G[{yv^(-1)}, yw]*G[{1, 1/(yu*yv), yv^(-1), 1/(yu*yv)}, yw] - 
     6*G[{1/(yu*yv)}, yw]*G[{1, 1/(yu*yv), yv^(-1), 1/(yu*yv)}, yw] - 
     8*G[{1}, yu^(-1)]*G[{1, 1/(yu*yv), 1/(yu*yv), yu^(-1)}, yw] + 
     5*G[{1}, yv^(-1)]*G[{1, 1/(yu*yv), 1/(yu*yv), yu^(-1)}, yw] - 
     3*G[{1}, yw]*G[{1, 1/(yu*yv), 1/(yu*yv), yu^(-1)}, yw] + 
     2*G[{yu^(-1)}, yw]*G[{1, 1/(yu*yv), 1/(yu*yv), yu^(-1)}, yw] + 
     3*G[{yu}, yv^(-1)]*G[{1, 1/(yu*yv), 1/(yu*yv), yu^(-1)}, yw] - 
     6*G[{1/(yu*yv)}, yw]*G[{1, 1/(yu*yv), 1/(yu*yv), yu^(-1)}, yw] + 
     5*G[{1}, yu^(-1)]*G[{1, 1/(yu*yv), 1/(yu*yv), yv^(-1)}, yw] - 
     8*G[{1}, yv^(-1)]*G[{1, 1/(yu*yv), 1/(yu*yv), yv^(-1)}, yw] - 
     3*G[{1}, yw]*G[{1, 1/(yu*yv), 1/(yu*yv), yv^(-1)}, yw] + 
     3*G[{yu}, yv^(-1)]*G[{1, 1/(yu*yv), 1/(yu*yv), yv^(-1)}, yw] + 
     2*G[{yv^(-1)}, yw]*G[{1, 1/(yu*yv), 1/(yu*yv), yv^(-1)}, yw] - 
     6*G[{1/(yu*yv)}, yw]*G[{1, 1/(yu*yv), 1/(yu*yv), yv^(-1)}, yw] + 
     4*G[{0}, yu^(-1)]*G[{1, 1/(yu*yv), 1/(yu*yv), 1/(yu*yv)}, yw] + 
     4*G[{0}, yv^(-1)]*G[{1, 1/(yu*yv), 1/(yu*yv), 1/(yu*yv)}, yw] - 
     4*G[{0}, yw]*G[{1, 1/(yu*yv), 1/(yu*yv), 1/(yu*yv)}, yw] - 
     17*G[{1}, yu^(-1)]*G[{1, 1/(yu*yv), 1/(yu*yv), 1/(yu*yv)}, yw] - 
     17*G[{1}, yv^(-1)]*G[{1, 1/(yu*yv), 1/(yu*yv), 1/(yu*yv)}, yw] - 
     26*G[{1}, yw]*G[{1, 1/(yu*yv), 1/(yu*yv), 1/(yu*yv)}, yw] - 
     2*G[{yu^(-1)}, yw]*G[{1, 1/(yu*yv), 1/(yu*yv), 1/(yu*yv)}, yw] + 
     26*G[{yu}, yv^(-1)]*G[{1, 1/(yu*yv), 1/(yu*yv), 1/(yu*yv)}, yw] - 
     2*G[{yv^(-1)}, yw]*G[{1, 1/(yu*yv), 1/(yu*yv), 1/(yu*yv)}, yw] + 
     4*G[{1/(yu*yv)}, yw]*G[{1, 1/(yu*yv), 1/(yu*yv), 1/(yu*yv)}, yw] + 
     11*G[{0}, yu^(-1)]*G[{yu^(-1), yu^(-1), yu^(-1), 1/(yu*yv)}, yw] + 
     11*G[{0}, yv^(-1)]*G[{yu^(-1), yu^(-1), yu^(-1), 1/(yu*yv)}, yw] - 
     11*G[{0}, yw]*G[{yu^(-1), yu^(-1), yu^(-1), 1/(yu*yv)}, yw] - 
     11*G[{1}, yu^(-1)]*G[{yu^(-1), yu^(-1), yu^(-1), 1/(yu*yv)}, yw] - 
     22*G[{1}, yv^(-1)]*G[{yu^(-1), yu^(-1), yu^(-1), 1/(yu*yv)}, yw] - 
     11*G[{1}, yw]*G[{yu^(-1), yu^(-1), yu^(-1), 1/(yu*yv)}, yw] + 
     22*G[{yu^(-1)}, yw]*G[{yu^(-1), yu^(-1), yu^(-1), 1/(yu*yv)}, yw] + 
     11*G[{yu}, yv^(-1)]*G[{yu^(-1), yu^(-1), yu^(-1), 1/(yu*yv)}, yw] + 
     4*G[{yv^(-1)}, yw]*G[{yu^(-1), yu^(-1), yu^(-1), 1/(yu*yv)}, yw] - 
     8*G[{1/(yu*yv)}, yw]*G[{yu^(-1), yu^(-1), yu^(-1), 1/(yu*yv)}, yw] - 
     3*G[{0}, yu^(-1)]*G[{yu^(-1), yu^(-1), 1/(yu*yv), yv^(-1)}, yw] - 
     3*G[{0}, yv^(-1)]*G[{yu^(-1), yu^(-1), 1/(yu*yv), yv^(-1)}, yw] + 
     3*G[{0}, yw]*G[{yu^(-1), yu^(-1), 1/(yu*yv), yv^(-1)}, yw] + 
     3*G[{1}, yu^(-1)]*G[{yu^(-1), yu^(-1), 1/(yu*yv), yv^(-1)}, yw] + 
     11*G[{1}, yv^(-1)]*G[{yu^(-1), yu^(-1), 1/(yu*yv), yv^(-1)}, yw] + 
     8*G[{1}, yw]*G[{yu^(-1), yu^(-1), 1/(yu*yv), yv^(-1)}, yw] - 
     11*G[{yu^(-1)}, yw]*G[{yu^(-1), yu^(-1), 1/(yu*yv), yv^(-1)}, yw] - 
     8*G[{yu}, yv^(-1)]*G[{yu^(-1), yu^(-1), 1/(yu*yv), yv^(-1)}, yw] - 
     4*G[{yv^(-1)}, yw]*G[{yu^(-1), yu^(-1), 1/(yu*yv), yv^(-1)}, yw] + 
     8*G[{1/(yu*yv)}, yw]*G[{yu^(-1), yu^(-1), 1/(yu*yv), yv^(-1)}, yw] - 
     G[{0}, yu^(-1)]*G[{yu^(-1), yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] - 
     G[{0}, yv^(-1)]*G[{yu^(-1), yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] + 
     G[{0}, yw]*G[{yu^(-1), yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] + 
     G[{1}, yu^(-1)]*G[{yu^(-1), yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] + 
     2*G[{1}, yv^(-1)]*G[{yu^(-1), yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] + 
     G[{1}, yw]*G[{yu^(-1), yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] - 
     2*G[{yu^(-1)}, yw]*G[{yu^(-1), yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] - 
     G[{yu}, yv^(-1)]*G[{yu^(-1), yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] + 
     6*G[{yv^(-1)}, yw]*G[{yu^(-1), yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] - 
     12*G[{1/(yu*yv)}, yw]*G[{yu^(-1), yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] + 
     3*G[{0}, yu^(-1)]*G[{yu^(-1), 1/(yu*yv), yv^(-1), yv^(-1)}, yw] + 
     3*G[{0}, yv^(-1)]*G[{yu^(-1), 1/(yu*yv), yv^(-1), yv^(-1)}, yw] - 
     3*G[{0}, yw]*G[{yu^(-1), 1/(yu*yv), yv^(-1), yv^(-1)}, yw] - 
     11*G[{1}, yu^(-1)]*G[{yu^(-1), 1/(yu*yv), yv^(-1), yv^(-1)}, yw] - 
     3*G[{1}, yv^(-1)]*G[{yu^(-1), 1/(yu*yv), yv^(-1), yv^(-1)}, yw] - 
     8*G[{1}, yw]*G[{yu^(-1), 1/(yu*yv), yv^(-1), yv^(-1)}, yw] + 
     3*G[{yu^(-1)}, yw]*G[{yu^(-1), 1/(yu*yv), yv^(-1), yv^(-1)}, yw] + 
     8*G[{yu}, yv^(-1)]*G[{yu^(-1), 1/(yu*yv), yv^(-1), yv^(-1)}, yw] + 
     4*G[{yv^(-1)}, yw]*G[{yu^(-1), 1/(yu*yv), yv^(-1), yv^(-1)}, yw] - 
     8*G[{1/(yu*yv)}, yw]*G[{yu^(-1), 1/(yu*yv), yv^(-1), yv^(-1)}, yw] + 
     5*G[{0}, yu^(-1)]*G[{yu^(-1), 1/(yu*yv), yv^(-1), 1/(yu*yv)}, yw] + 
     5*G[{0}, yv^(-1)]*G[{yu^(-1), 1/(yu*yv), yv^(-1), 1/(yu*yv)}, yw] - 
     5*G[{0}, yw]*G[{yu^(-1), 1/(yu*yv), yv^(-1), 1/(yu*yv)}, yw] - 
     G[{1}, yu^(-1)]*G[{yu^(-1), 1/(yu*yv), yv^(-1), 1/(yu*yv)}, yw] - 
     G[{1}, yv^(-1)]*G[{yu^(-1), 1/(yu*yv), yv^(-1), 1/(yu*yv)}, yw] + 
     8*G[{1}, yw]*G[{yu^(-1), 1/(yu*yv), yv^(-1), 1/(yu*yv)}, yw] + 
     G[{yu^(-1)}, yw]*G[{yu^(-1), 1/(yu*yv), yv^(-1), 1/(yu*yv)}, yw] - 
     8*G[{yu}, yv^(-1)]*G[{yu^(-1), 1/(yu*yv), yv^(-1), 1/(yu*yv)}, yw] - 
     6*G[{yv^(-1)}, yw]*G[{yu^(-1), 1/(yu*yv), yv^(-1), 1/(yu*yv)}, yw] + 
     6*G[{1/(yu*yv)}, yw]*G[{yu^(-1), 1/(yu*yv), yv^(-1), 1/(yu*yv)}, yw] + 
     5*G[{0}, yu^(-1)]*G[{yu^(-1), 1/(yu*yv), 1/(yu*yv), yv^(-1)}, yw] + 
     5*G[{0}, yv^(-1)]*G[{yu^(-1), 1/(yu*yv), 1/(yu*yv), yv^(-1)}, yw] - 
     5*G[{0}, yw]*G[{yu^(-1), 1/(yu*yv), 1/(yu*yv), yv^(-1)}, yw] - 
     5*G[{1}, yu^(-1)]*G[{yu^(-1), 1/(yu*yv), 1/(yu*yv), yv^(-1)}, yw] + 
     3*G[{1}, yv^(-1)]*G[{yu^(-1), 1/(yu*yv), 1/(yu*yv), yv^(-1)}, yw] + 
     8*G[{1}, yw]*G[{yu^(-1), 1/(yu*yv), 1/(yu*yv), yv^(-1)}, yw] - 
     3*G[{yu^(-1)}, yw]*G[{yu^(-1), 1/(yu*yv), 1/(yu*yv), yv^(-1)}, yw] - 
     8*G[{yu}, yv^(-1)]*G[{yu^(-1), 1/(yu*yv), 1/(yu*yv), yv^(-1)}, yw] - 
     2*G[{yv^(-1)}, yw]*G[{yu^(-1), 1/(yu*yv), 1/(yu*yv), yv^(-1)}, yw] + 
     6*G[{1/(yu*yv)}, yw]*G[{yu^(-1), 1/(yu*yv), 1/(yu*yv), yv^(-1)}, yw] - 
     13*G[{0}, yu^(-1)]*G[{yu^(-1), 1/(yu*yv), 1/(yu*yv), 1/(yu*yv)}, yw] - 
     13*G[{0}, yv^(-1)]*G[{yu^(-1), 1/(yu*yv), 1/(yu*yv), 1/(yu*yv)}, yw] + 
     13*G[{0}, yw]*G[{yu^(-1), 1/(yu*yv), 1/(yu*yv), 1/(yu*yv)}, yw] + 
     17*G[{1}, yu^(-1)]*G[{yu^(-1), 1/(yu*yv), 1/(yu*yv), 1/(yu*yv)}, yw] + 
     26*G[{1}, yv^(-1)]*G[{yu^(-1), 1/(yu*yv), 1/(yu*yv), 1/(yu*yv)}, yw] + 
     17*G[{1}, yw]*G[{yu^(-1), 1/(yu*yv), 1/(yu*yv), 1/(yu*yv)}, yw] - 
     26*G[{yu^(-1)}, yw]*G[{yu^(-1), 1/(yu*yv), 1/(yu*yv), 1/(yu*yv)}, yw] - 
     17*G[{yu}, yv^(-1)]*G[{yu^(-1), 1/(yu*yv), 1/(yu*yv), 1/(yu*yv)}, yw] + 
     2*G[{yv^(-1)}, yw]*G[{yu^(-1), 1/(yu*yv), 1/(yu*yv), 1/(yu*yv)}, yw] - 
     4*G[{1/(yu*yv)}, yw]*G[{yu^(-1), 1/(yu*yv), 1/(yu*yv), 1/(yu*yv)}, yw] + 
     11*G[{0}, yu^(-1)]*G[{yv^(-1), yv^(-1), yv^(-1), 1/(yu*yv)}, yw] + 
     11*G[{0}, yv^(-1)]*G[{yv^(-1), yv^(-1), yv^(-1), 1/(yu*yv)}, yw] - 
     11*G[{0}, yw]*G[{yv^(-1), yv^(-1), yv^(-1), 1/(yu*yv)}, yw] - 
     22*G[{1}, yu^(-1)]*G[{yv^(-1), yv^(-1), yv^(-1), 1/(yu*yv)}, yw] - 
     11*G[{1}, yv^(-1)]*G[{yv^(-1), yv^(-1), yv^(-1), 1/(yu*yv)}, yw] - 
     11*G[{1}, yw]*G[{yv^(-1), yv^(-1), yv^(-1), 1/(yu*yv)}, yw] + 
     11*G[{yu^(-1)}, yw]*G[{yv^(-1), yv^(-1), yv^(-1), 1/(yu*yv)}, yw] + 
     11*G[{yu}, yv^(-1)]*G[{yv^(-1), yv^(-1), yv^(-1), 1/(yu*yv)}, yw] + 
     22*G[{yv^(-1)}, yw]*G[{yv^(-1), yv^(-1), yv^(-1), 1/(yu*yv)}, yw] - 
     8*G[{1/(yu*yv)}, yw]*G[{yv^(-1), yv^(-1), yv^(-1), 1/(yu*yv)}, yw] - 
     G[{0}, yu^(-1)]*G[{yv^(-1), yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] - 
     G[{0}, yv^(-1)]*G[{yv^(-1), yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] + 
     G[{0}, yw]*G[{yv^(-1), yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] + 
     2*G[{1}, yu^(-1)]*G[{yv^(-1), yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] + 
     G[{1}, yv^(-1)]*G[{yv^(-1), yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] + 
     G[{1}, yw]*G[{yv^(-1), yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] - 
     G[{yu^(-1)}, yw]*G[{yv^(-1), yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] - 
     G[{yu}, yv^(-1)]*G[{yv^(-1), yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] - 
     2*G[{yv^(-1)}, yw]*G[{yv^(-1), yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] - 
     12*G[{1/(yu*yv)}, yw]*G[{yv^(-1), yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] - 
     13*G[{0}, yu^(-1)]*G[{yv^(-1), 1/(yu*yv), 1/(yu*yv), 1/(yu*yv)}, yw] - 
     13*G[{0}, yv^(-1)]*G[{yv^(-1), 1/(yu*yv), 1/(yu*yv), 1/(yu*yv)}, yw] + 
     13*G[{0}, yw]*G[{yv^(-1), 1/(yu*yv), 1/(yu*yv), 1/(yu*yv)}, yw] + 
     26*G[{1}, yu^(-1)]*G[{yv^(-1), 1/(yu*yv), 1/(yu*yv), 1/(yu*yv)}, yw] + 
     17*G[{1}, yv^(-1)]*G[{yv^(-1), 1/(yu*yv), 1/(yu*yv), 1/(yu*yv)}, yw] + 
     17*G[{1}, yw]*G[{yv^(-1), 1/(yu*yv), 1/(yu*yv), 1/(yu*yv)}, yw] - 
     17*G[{yu^(-1)}, yw]*G[{yv^(-1), 1/(yu*yv), 1/(yu*yv), 1/(yu*yv)}, yw] - 
     17*G[{yu}, yv^(-1)]*G[{yv^(-1), 1/(yu*yv), 1/(yu*yv), 1/(yu*yv)}, yw] - 
     26*G[{yv^(-1)}, yw]*G[{yv^(-1), 1/(yu*yv), 1/(yu*yv), 1/(yu*yv)}, yw] - 
     4*G[{1/(yu*yv)}, yw]*G[{yv^(-1), 1/(yu*yv), 1/(yu*yv), 1/(yu*yv)}, yw] - 
     2*G[{0, 0, 0, 0, 1}, yu^(-1)] - 2*G[{0, 0, 0, 0, 1}, yv^(-1)] + 
     2*G[{0, 0, 0, 0, yu}, yv^(-1)] - 10*G[{0, 0, 0, 1, 1}, yu^(-1)] - 
     10*G[{0, 0, 0, 1, 1}, yv^(-1)] + 8*G[{0, 0, 0, 1, yu}, yv^(-1)] + 
     10*G[{0, 0, 0, yu, 1}, yv^(-1)] - 8*G[{0, 0, 0, yu, yu}, yv^(-1)] - 
     5*G[{0, 0, 1, 0, 1}, yu^(-1)] - 5*G[{0, 0, 1, 0, 1}, yv^(-1)] - 
     2*G[{0, 0, 1, 0, 1}, yw] + 2*G[{0, 0, 1, 0, yu^(-1)}, yw] + 
     5*G[{0, 0, 1, 0, yu}, yv^(-1)] + 2*G[{0, 0, 1, 0, yv^(-1)}, yw] - 
     2*G[{0, 0, 1, 0, 1/(yu*yv)}, yw] + 12*G[{0, 0, 1, 1, 1}, yu^(-1)] + 
     12*G[{0, 0, 1, 1, 1}, yv^(-1)] + 2*G[{0, 0, 1, 1, 1}, yw] + 
     8*G[{0, 0, 1, 1, yu^(-1)}, yw] + 6*G[{0, 0, 1, 1, yu}, yv^(-1)] + 
     8*G[{0, 0, 1, 1, yv^(-1)}, yw] - 8*G[{0, 0, 1, 1, 1/(yu*yv)}, yw] + 
     10*G[{0, 0, 1, yu^(-1), 1}, yw] - 4*G[{0, 0, 1, yu^(-1), yu^(-1)}, yw] - 
     6*G[{0, 0, 1, yu^(-1), yv^(-1)}, yw] - 
     2*G[{0, 0, 1, yu^(-1), 1/(yu*yv)}, yw] + 
     5*G[{0, 0, 1, yu, 1}, yv^(-1)] + 3*G[{0, 0, 1, yu, yu}, yv^(-1)] + 
     10*G[{0, 0, 1, yv^(-1), 1}, yw] - 6*G[{0, 0, 1, yv^(-1), yu^(-1)}, yw] - 
     4*G[{0, 0, 1, yv^(-1), yv^(-1)}, yw] - 
     2*G[{0, 0, 1, yv^(-1), 1/(yu*yv)}, yw] - 
     12*G[{0, 0, 1, 1/(yu*yv), 1}, yw] + 
     18*G[{0, 0, 1, 1/(yu*yv), 1/(yu*yv)}, yw] + 
     2*G[{0, 0, yu^(-1), 0, 1}, yw] - 2*G[{0, 0, yu^(-1), 0, yu^(-1)}, yw] - 
     2*G[{0, 0, yu^(-1), 0, yv^(-1)}, yw] + 
     2*G[{0, 0, yu^(-1), 0, 1/(yu*yv)}, yw] + 
     8*G[{0, 0, yu^(-1), 1, 1}, yw] - 8*G[{0, 0, yu^(-1), 1, yu^(-1)}, yw] - 
     4*G[{0, 0, yu^(-1), 1, yv^(-1)}, yw] - 
     4*G[{0, 0, yu^(-1), 1, 1/(yu*yv)}, yw] - 
     16*G[{0, 0, yu^(-1), yu^(-1), 1}, yw] + 
     24*G[{0, 0, yu^(-1), yu^(-1), yu^(-1)}, yw] + 
     2*G[{0, 0, yu^(-1), yu^(-1), yv^(-1)}, yw] - 
     2*G[{0, 0, yu^(-1), yu^(-1), 1/(yu*yv)}, yw] - 
     6*G[{0, 0, yu^(-1), yv^(-1), 1}, yw] + 
     2*G[{0, 0, yu^(-1), yv^(-1), yu^(-1)}, yw] + 
     4*G[{0, 0, yu^(-1), yv^(-1), yv^(-1)}, yw] + 
     2*G[{0, 0, yu^(-1), yv^(-1), 1/(yu*yv)}, yw] + 
     8*G[{0, 0, yu^(-1), 1/(yu*yv), 1}, yw] - 
     4*G[{0, 0, yu^(-1), 1/(yu*yv), yu^(-1)}, yw] - 
     18*G[{0, 0, yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] + 
     5*G[{0, 0, yu, 0, 1}, yv^(-1)] - 5*G[{0, 0, yu, 0, yu}, yv^(-1)] + 
     4*G[{0, 0, yu, 1, 1}, yv^(-1)] - 5*G[{0, 0, yu, yu, 1}, yv^(-1)] + 
     17*G[{0, 0, yu, yu, yu}, yv^(-1)] + 2*G[{0, 0, yv^(-1), 0, 1}, yw] - 
     2*G[{0, 0, yv^(-1), 0, yu^(-1)}, yw] - 
     2*G[{0, 0, yv^(-1), 0, yv^(-1)}, yw] + 
     2*G[{0, 0, yv^(-1), 0, 1/(yu*yv)}, yw] + 
     8*G[{0, 0, yv^(-1), 1, 1}, yw] - 4*G[{0, 0, yv^(-1), 1, yu^(-1)}, yw] - 
     8*G[{0, 0, yv^(-1), 1, yv^(-1)}, yw] - 
     4*G[{0, 0, yv^(-1), 1, 1/(yu*yv)}, yw] - 
     6*G[{0, 0, yv^(-1), yu^(-1), 1}, yw] + 
     2*G[{0, 0, yv^(-1), yu^(-1), yu^(-1)}, yw] + 
     10*G[{0, 0, yv^(-1), yu^(-1), yv^(-1)}, yw] + 
     2*G[{0, 0, yv^(-1), yu^(-1), 1/(yu*yv)}, yw] - 
     16*G[{0, 0, yv^(-1), yv^(-1), 1}, yw] + 
     16*G[{0, 0, yv^(-1), yv^(-1), yu^(-1)}, yw] + 
     24*G[{0, 0, yv^(-1), yv^(-1), yv^(-1)}, yw] - 
     2*G[{0, 0, yv^(-1), yv^(-1), 1/(yu*yv)}, yw] + 
     8*G[{0, 0, yv^(-1), 1/(yu*yv), 1}, yw] - 
     8*G[{0, 0, yv^(-1), 1/(yu*yv), yu^(-1)}, yw] - 
     4*G[{0, 0, yv^(-1), 1/(yu*yv), yv^(-1)}, yw] - 
     18*G[{0, 0, yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] - 
     2*G[{0, 0, 1/(yu*yv), 0, 1}, yw] + 2*G[{0, 0, 1/(yu*yv), 0, yu^(-1)}, 
       yw] + 2*G[{0, 0, 1/(yu*yv), 0, yv^(-1)}, yw] - 
     2*G[{0, 0, 1/(yu*yv), 0, 1/(yu*yv)}, yw] - 
     16*G[{0, 0, 1/(yu*yv), 1, 1}, yw] + 12*G[{0, 0, 1/(yu*yv), 1, yu^(-1)}, 
       yw] + 12*G[{0, 0, 1/(yu*yv), 1, yv^(-1)}, yw] + 
     14*G[{0, 0, 1/(yu*yv), yu^(-1), 1}, yw] - 
     10*G[{0, 0, 1/(yu*yv), yu^(-1), yu^(-1)}, yw] - 
     14*G[{0, 0, 1/(yu*yv), yu^(-1), yv^(-1)}, yw] + 
     2*G[{0, 0, 1/(yu*yv), yu^(-1), 1/(yu*yv)}, yw] + 
     14*G[{0, 0, 1/(yu*yv), yv^(-1), 1}, yw] - 
     14*G[{0, 0, 1/(yu*yv), yv^(-1), yu^(-1)}, yw] - 
     10*G[{0, 0, 1/(yu*yv), yv^(-1), yv^(-1)}, yw] + 
     2*G[{0, 0, 1/(yu*yv), yv^(-1), 1/(yu*yv)}, yw] - 
     18*G[{0, 0, 1/(yu*yv), 1/(yu*yv), 1}, yw] + 
     18*G[{0, 0, 1/(yu*yv), 1/(yu*yv), yu^(-1)}, yw] + 
     18*G[{0, 0, 1/(yu*yv), 1/(yu*yv), yv^(-1)}, yw] - 
     10*G[{0, 0, 1/(yu*yv), 1/(yu*yv), 1/(yu*yv)}, yw] + 
     4*G[{0, 1, 0, 1, 1}, yu^(-1)] + 4*G[{0, 1, 0, 1, 1}, yv^(-1)] + 
     G[{0, 1, 0, 1, 1}, yw] + 4*G[{0, 1, 0, 1, yu^(-1)}, yw] + 
     7*G[{0, 1, 0, 1, yu}, yv^(-1)] + 4*G[{0, 1, 0, 1, yv^(-1)}, yw] - 
     8*G[{0, 1, 0, 1, 1/(yu*yv)}, yw] + 4*G[{0, 1, 0, yu^(-1), 1}, yw] - 
     G[{0, 1, 0, yu^(-1), yu^(-1)}, yw] + 4*G[{0, 1, 0, yu, 1}, yv^(-1)] - 
     G[{0, 1, 0, yu, yu}, yv^(-1)] + 4*G[{0, 1, 0, yv^(-1), 1}, yw] - 
     G[{0, 1, 0, yv^(-1), yv^(-1)}, yw] - 8*G[{0, 1, 0, 1/(yu*yv), 1}, yw] + 
     7*G[{0, 1, 0, 1/(yu*yv), 1/(yu*yv)}, yw] + G[{0, 1, 1, 0, yu^(-1)}, 
      yw] + 4*G[{0, 1, 1, 0, yu}, yv^(-1)] + G[{0, 1, 1, 0, yv^(-1)}, yw] - 
     G[{0, 1, 1, 0, 1/(yu*yv)}, yw] - 2*G[{0, 1, 1, 1, 1}, yw] - 
     G[{0, 1, 1, 1, yu^(-1)}, yw] - 2*G[{0, 1, 1, 1, yu}, yv^(-1)] - 
     G[{0, 1, 1, 1, yv^(-1)}, yw] + 2*G[{0, 1, 1, 1, 1/(yu*yv)}, yw] - 
     6*G[{0, 1, 1, yu^(-1), 1}, yw] + 5*G[{0, 1, 1, yu^(-1), yu^(-1)}, yw] - 
     3*G[{0, 1, 1, yu^(-1), yv^(-1)}, yw] + 
     6*G[{0, 1, 1, yu^(-1), 1/(yu*yv)}, yw] - 
     4*G[{0, 1, 1, yu, 1}, yv^(-1)] - 2*G[{0, 1, 1, yu, yu}, yv^(-1)] - 
     6*G[{0, 1, 1, yv^(-1), 1}, yw] - 3*G[{0, 1, 1, yv^(-1), yu^(-1)}, yw] + 
     5*G[{0, 1, 1, yv^(-1), yv^(-1)}, yw] + 
     6*G[{0, 1, 1, yv^(-1), 1/(yu*yv)}, yw] + 
     10*G[{0, 1, 1, 1/(yu*yv), 1}, yw] + 3*G[{0, 1, 1, 1/(yu*yv), yu^(-1)}, 
       yw] + 3*G[{0, 1, 1, 1/(yu*yv), yv^(-1)}, yw] - 
     2*G[{0, 1, 1, 1/(yu*yv), 1/(yu*yv)}, yw] + 
     3*G[{0, 1, yu^(-1), 0, yu^(-1)}, yw] + 
     3*G[{0, 1, yu^(-1), 0, yv^(-1)}, yw] - 
     3*G[{0, 1, yu^(-1), 0, 1/(yu*yv)}, yw] - 
     6*G[{0, 1, yu^(-1), 1, 1}, yw] + 5*G[{0, 1, yu^(-1), 1, yu^(-1)}, yw] + 
     G[{0, 1, yu^(-1), 1, yv^(-1)}, yw] + 
     6*G[{0, 1, yu^(-1), 1, 1/(yu*yv)}, yw] + 
     12*G[{0, 1, yu^(-1), yu^(-1), 1}, yw] - 
     7*G[{0, 1, yu^(-1), yu^(-1), yu^(-1)}, yw] - 
     3*G[{0, 1, yu^(-1), yu^(-1), yv^(-1)}, yw] - 
     8*G[{0, 1, yu^(-1), yu^(-1), 1/(yu*yv)}, yw] + 
     8*G[{0, 1, yu^(-1), yv^(-1), 1}, yw] - 
     3*G[{0, 1, yu^(-1), yv^(-1), yu^(-1)}, yw] - 
     3*G[{0, 1, yu^(-1), yv^(-1), yv^(-1)}, yw] - 
     8*G[{0, 1, yu^(-1), yv^(-1), 1/(yu*yv)}, yw] - 
     2*G[{0, 1, yu^(-1), 1/(yu*yv), 1}, yw] - 
     7*G[{0, 1, yu^(-1), 1/(yu*yv), yu^(-1)}, yw] - 
     7*G[{0, 1, yu^(-1), 1/(yu*yv), yv^(-1)}, yw] + 
     6*G[{0, 1, yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] + 
     3*G[{0, 1, yu, 0, yu}, yv^(-1)] - 4*G[{0, 1, yu, 1, 1}, yv^(-1)] - 
     2*G[{0, 1, yu, 1, yu}, yv^(-1)] + 5*G[{0, 1, yu, yu, 1}, yv^(-1)] + 
     7*G[{0, 1, yu, yu, yu}, yv^(-1)] + 3*G[{0, 1, yv^(-1), 0, yv^(-1)}, 
       yw] - 3*G[{0, 1, yv^(-1), 0, 1/(yu*yv)}, yw] - 
     6*G[{0, 1, yv^(-1), 1, 1}, yw] + G[{0, 1, yv^(-1), 1, yu^(-1)}, yw] + 
     5*G[{0, 1, yv^(-1), 1, yv^(-1)}, yw] + 
     6*G[{0, 1, yv^(-1), 1, 1/(yu*yv)}, yw] + 
     8*G[{0, 1, yv^(-1), yu^(-1), 1}, yw] - 
     3*G[{0, 1, yv^(-1), yu^(-1), yu^(-1)}, yw] - 
     3*G[{0, 1, yv^(-1), yu^(-1), yv^(-1)}, yw] - 
     8*G[{0, 1, yv^(-1), yu^(-1), 1/(yu*yv)}, yw] + 
     12*G[{0, 1, yv^(-1), yv^(-1), 1}, yw] - 
     3*G[{0, 1, yv^(-1), yv^(-1), yu^(-1)}, yw] - 
     7*G[{0, 1, yv^(-1), yv^(-1), yv^(-1)}, yw] - 
     8*G[{0, 1, yv^(-1), yv^(-1), 1/(yu*yv)}, yw] - 
     2*G[{0, 1, yv^(-1), 1/(yu*yv), 1}, yw] - 
     7*G[{0, 1, yv^(-1), 1/(yu*yv), yu^(-1)}, yw] - 
     7*G[{0, 1, yv^(-1), 1/(yu*yv), yv^(-1)}, yw] + 
     6*G[{0, 1, yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] - 
     4*G[{0, 1, 1/(yu*yv), 0, yu^(-1)}, yw] - 
     4*G[{0, 1, 1/(yu*yv), 0, yv^(-1)}, yw] + 
     7*G[{0, 1, 1/(yu*yv), 0, 1/(yu*yv)}, yw] + 
     10*G[{0, 1, 1/(yu*yv), 1, 1}, yw] - G[{0, 1, 1/(yu*yv), 1, yu^(-1)}, 
      yw] - G[{0, 1, 1/(yu*yv), 1, yv^(-1)}, yw] - 
     2*G[{0, 1, 1/(yu*yv), 1, 1/(yu*yv)}, yw] - 
     6*G[{0, 1, 1/(yu*yv), yu^(-1), 1}, yw] - 
     3*G[{0, 1, 1/(yu*yv), yu^(-1), yu^(-1)}, yw] - 
     3*G[{0, 1, 1/(yu*yv), yu^(-1), yv^(-1)}, yw] + 
     6*G[{0, 1, 1/(yu*yv), yu^(-1), 1/(yu*yv)}, yw] - 
     6*G[{0, 1, 1/(yu*yv), yv^(-1), 1}, yw] - 
     3*G[{0, 1, 1/(yu*yv), yv^(-1), yu^(-1)}, yw] - 
     3*G[{0, 1, 1/(yu*yv), yv^(-1), yv^(-1)}, yw] + 
     6*G[{0, 1, 1/(yu*yv), yv^(-1), 1/(yu*yv)}, yw] - 
     6*G[{0, 1, 1/(yu*yv), 1/(yu*yv), 1}, yw] + 
     15*G[{0, 1, 1/(yu*yv), 1/(yu*yv), yu^(-1)}, yw] + 
     15*G[{0, 1, 1/(yu*yv), 1/(yu*yv), yv^(-1)}, yw] - 
     2*G[{0, 1, 1/(yu*yv), 1/(yu*yv), 1/(yu*yv)}, yw] - 
     3*G[{0, yu^(-1), 0, yu^(-1), 1}, yw] + 
     7*G[{0, yu^(-1), 0, yu^(-1), yu^(-1)}, yw] - 
     4*G[{0, yu^(-1), 0, yu^(-1), yv^(-1)}, yw] - 
     4*G[{0, yu^(-1), 0, yv^(-1), yu^(-1)}, yw] + 
     G[{0, yu^(-1), 0, yv^(-1), yv^(-1)}, yw] + 
     4*G[{0, yu^(-1), 0, 1/(yu*yv), 1}, yw] - 
     7*G[{0, yu^(-1), 0, 1/(yu*yv), 1/(yu*yv)}, yw] + 
     3*G[{0, yu^(-1), 1, 0, yv^(-1)}, yw] - 
     3*G[{0, yu^(-1), 1, 0, 1/(yu*yv)}, yw] + 
     2*G[{0, yu^(-1), 1, 1, 1}, yw] + G[{0, yu^(-1), 1, 1, yu^(-1)}, yw] - 
     3*G[{0, yu^(-1), 1, 1, yv^(-1)}, yw] + 
     2*G[{0, yu^(-1), 1, 1, 1/(yu*yv)}, yw] + 
     6*G[{0, yu^(-1), 1, yu^(-1), 1}, yw] - 
     5*G[{0, yu^(-1), 1, yu^(-1), yu^(-1)}, yw] + 
     3*G[{0, yu^(-1), 1, yu^(-1), yv^(-1)}, yw] - 
     6*G[{0, yu^(-1), 1, yu^(-1), 1/(yu*yv)}, yw] + 
     2*G[{0, yu^(-1), 1, yv^(-1), 1}, yw] + 
     3*G[{0, yu^(-1), 1, yv^(-1), yu^(-1)}, yw] - 
     G[{0, yu^(-1), 1, yv^(-1), yv^(-1)}, yw] - 
     6*G[{0, yu^(-1), 1, yv^(-1), 1/(yu*yv)}, yw] - 
     2*G[{0, yu^(-1), 1, 1/(yu*yv), 1}, yw] - 
     7*G[{0, yu^(-1), 1, 1/(yu*yv), yu^(-1)}, yw] - 
     7*G[{0, yu^(-1), 1, 1/(yu*yv), yv^(-1)}, yw] + 
     2*G[{0, yu^(-1), 1, 1/(yu*yv), 1/(yu*yv)}, yw] - 
     7*G[{0, yu^(-1), yu^(-1), 0, yv^(-1)}, yw] + 
     7*G[{0, yu^(-1), yu^(-1), 0, 1/(yu*yv)}, yw] + 
     6*G[{0, yu^(-1), yu^(-1), 1, 1}, yw] - 
     5*G[{0, yu^(-1), yu^(-1), 1, yu^(-1)}, yw] - 
     G[{0, yu^(-1), yu^(-1), 1, yv^(-1)}, yw] - 
     6*G[{0, yu^(-1), yu^(-1), 1, 1/(yu*yv)}, yw] - 
     12*G[{0, yu^(-1), yu^(-1), yu^(-1), 1}, yw] + 
     7*G[{0, yu^(-1), yu^(-1), yu^(-1), yu^(-1)}, yw] + 
     7*G[{0, yu^(-1), yu^(-1), yu^(-1), yv^(-1)}, yw] + 
     4*G[{0, yu^(-1), yu^(-1), yu^(-1), 1/(yu*yv)}, yw] - 
     8*G[{0, yu^(-1), yu^(-1), yv^(-1), 1}, yw] + 
     7*G[{0, yu^(-1), yu^(-1), yv^(-1), yu^(-1)}, yw] - 
     G[{0, yu^(-1), yu^(-1), yv^(-1), yv^(-1)}, yw] + 
     8*G[{0, yu^(-1), yu^(-1), yv^(-1), 1/(yu*yv)}, yw] - 
     2*G[{0, yu^(-1), yu^(-1), 1/(yu*yv), 1}, yw] + 
     7*G[{0, yu^(-1), yu^(-1), 1/(yu*yv), yu^(-1)}, yw] + 
     11*G[{0, yu^(-1), yu^(-1), 1/(yu*yv), yv^(-1)}, yw] - 
     6*G[{0, yu^(-1), yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] - 
     3*G[{0, yu^(-1), yv^(-1), 0, yv^(-1)}, yw] + 
     3*G[{0, yu^(-1), yv^(-1), 0, 1/(yu*yv)}, yw] + 
     2*G[{0, yu^(-1), yv^(-1), 1, 1}, yw] - 
     G[{0, yu^(-1), yv^(-1), 1, yu^(-1)}, yw] - 
     G[{0, yu^(-1), yv^(-1), 1, yv^(-1)}, yw] - 
     6*G[{0, yu^(-1), yv^(-1), 1, 1/(yu*yv)}, yw] - 
     8*G[{0, yu^(-1), yv^(-1), yu^(-1), 1}, yw] + 
     7*G[{0, yu^(-1), yv^(-1), yu^(-1), yu^(-1)}, yw] - 
     G[{0, yu^(-1), yv^(-1), yu^(-1), yv^(-1)}, yw] + 
     8*G[{0, yu^(-1), yv^(-1), yu^(-1), 1/(yu*yv)}, yw] - 
     8*G[{0, yu^(-1), yv^(-1), yv^(-1), 1}, yw] - 
     G[{0, yu^(-1), yv^(-1), yv^(-1), yu^(-1)}, yw] + 
     7*G[{0, yu^(-1), yv^(-1), yv^(-1), yv^(-1)}, yw] + 
     8*G[{0, yu^(-1), yv^(-1), yv^(-1), 1/(yu*yv)}, yw] + 
     2*G[{0, yu^(-1), yv^(-1), 1/(yu*yv), 1}, yw] + 
     7*G[{0, yu^(-1), yv^(-1), 1/(yu*yv), yu^(-1)}, yw] + 
     7*G[{0, yu^(-1), yv^(-1), 1/(yu*yv), yv^(-1)}, yw] - 
     6*G[{0, yu^(-1), yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] + 
     4*G[{0, yu^(-1), 1/(yu*yv), 0, yv^(-1)}, yw] - 
     7*G[{0, yu^(-1), 1/(yu*yv), 0, 1/(yu*yv)}, yw] + 
     2*G[{0, yu^(-1), 1/(yu*yv), 1, 1}, yw] - 
     7*G[{0, yu^(-1), 1/(yu*yv), 1, yu^(-1)}, yw] - 
     3*G[{0, yu^(-1), 1/(yu*yv), 1, yv^(-1)}, yw] + 
     2*G[{0, yu^(-1), 1/(yu*yv), 1, 1/(yu*yv)}, yw] - 
     2*G[{0, yu^(-1), 1/(yu*yv), yu^(-1), 1}, yw] + 
     7*G[{0, yu^(-1), 1/(yu*yv), yu^(-1), yu^(-1)}, yw] + 
     7*G[{0, yu^(-1), 1/(yu*yv), yu^(-1), yv^(-1)}, yw] - 
     6*G[{0, yu^(-1), 1/(yu*yv), yu^(-1), 1/(yu*yv)}, yw] + 
     2*G[{0, yu^(-1), 1/(yu*yv), yv^(-1), 1}, yw] + 
     7*G[{0, yu^(-1), 1/(yu*yv), yv^(-1), yu^(-1)}, yw] + 
     3*G[{0, yu^(-1), 1/(yu*yv), yv^(-1), yv^(-1)}, yw] - 
     6*G[{0, yu^(-1), 1/(yu*yv), yv^(-1), 1/(yu*yv)}, yw] + 
     6*G[{0, yu^(-1), 1/(yu*yv), 1/(yu*yv), 1}, yw] - 
     15*G[{0, yu^(-1), 1/(yu*yv), 1/(yu*yv), yu^(-1)}, yw] - 
     15*G[{0, yu^(-1), 1/(yu*yv), 1/(yu*yv), yv^(-1)}, yw] + 
     2*G[{0, yu^(-1), 1/(yu*yv), 1/(yu*yv), 1/(yu*yv)}, yw] + 
     7*G[{0, yu, 0, yu, yu}, yv^(-1)] + 2*G[{0, yu, 1, 1, yu}, yv^(-1)] + 
     4*G[{0, yu, 1, yu, 1}, yv^(-1)] + 2*G[{0, yu, 1, yu, yu}, yv^(-1)] + 
     4*G[{0, yu, yu, 1, 1}, yv^(-1)] + 2*G[{0, yu, yu, 1, yu}, yv^(-1)] - 
     5*G[{0, yu, yu, yu, 1}, yv^(-1)] - 7*G[{0, yu, yu, yu, yu}, yv^(-1)] - 
     3*G[{0, yv^(-1), 0, yv^(-1), 1}, yw] + 
     3*G[{0, yv^(-1), 0, yv^(-1), yu^(-1)}, yw] + 
     7*G[{0, yv^(-1), 0, yv^(-1), yv^(-1)}, yw] + 
     4*G[{0, yv^(-1), 0, 1/(yu*yv), 1}, yw] - 
     4*G[{0, yv^(-1), 0, 1/(yu*yv), yu^(-1)}, yw] - 
     7*G[{0, yv^(-1), 0, 1/(yu*yv), 1/(yu*yv)}, yw] - 
     3*G[{0, yv^(-1), 1, 0, 1/(yu*yv)}, yw] + 
     2*G[{0, yv^(-1), 1, 1, 1}, yw] - 3*G[{0, yv^(-1), 1, 1, yu^(-1)}, yw] + 
     G[{0, yv^(-1), 1, 1, yv^(-1)}, yw] + 
     2*G[{0, yv^(-1), 1, 1, 1/(yu*yv)}, yw] + 
     2*G[{0, yv^(-1), 1, yu^(-1), 1}, yw] - 
     G[{0, yv^(-1), 1, yu^(-1), yu^(-1)}, yw] + 
     3*G[{0, yv^(-1), 1, yu^(-1), yv^(-1)}, yw] - 
     6*G[{0, yv^(-1), 1, yu^(-1), 1/(yu*yv)}, yw] + 
     6*G[{0, yv^(-1), 1, yv^(-1), 1}, yw] + 
     3*G[{0, yv^(-1), 1, yv^(-1), yu^(-1)}, yw] - 
     5*G[{0, yv^(-1), 1, yv^(-1), yv^(-1)}, yw] - 
     6*G[{0, yv^(-1), 1, yv^(-1), 1/(yu*yv)}, yw] - 
     2*G[{0, yv^(-1), 1, 1/(yu*yv), 1}, yw] - 
     7*G[{0, yv^(-1), 1, 1/(yu*yv), yu^(-1)}, yw] - 
     7*G[{0, yv^(-1), 1, 1/(yu*yv), yv^(-1)}, yw] + 
     2*G[{0, yv^(-1), 1, 1/(yu*yv), 1/(yu*yv)}, yw] + 
     3*G[{0, yv^(-1), yu^(-1), 0, 1/(yu*yv)}, yw] + 
     2*G[{0, yv^(-1), yu^(-1), 1, 1}, yw] - 
     G[{0, yv^(-1), yu^(-1), 1, yu^(-1)}, yw] - 
     G[{0, yv^(-1), yu^(-1), 1, yv^(-1)}, yw] - 
     6*G[{0, yv^(-1), yu^(-1), 1, 1/(yu*yv)}, yw] - 
     8*G[{0, yv^(-1), yu^(-1), yu^(-1), 1}, yw] + 
     7*G[{0, yv^(-1), yu^(-1), yu^(-1), yu^(-1)}, yw] - 
     G[{0, yv^(-1), yu^(-1), yu^(-1), yv^(-1)}, yw] + 
     8*G[{0, yv^(-1), yu^(-1), yu^(-1), 1/(yu*yv)}, yw] - 
     8*G[{0, yv^(-1), yu^(-1), yv^(-1), 1}, yw] - 
     G[{0, yv^(-1), yu^(-1), yv^(-1), yu^(-1)}, yw] + 
     7*G[{0, yv^(-1), yu^(-1), yv^(-1), yv^(-1)}, yw] + 
     8*G[{0, yv^(-1), yu^(-1), yv^(-1), 1/(yu*yv)}, yw] + 
     2*G[{0, yv^(-1), yu^(-1), 1/(yu*yv), 1}, yw] + 
     7*G[{0, yv^(-1), yu^(-1), 1/(yu*yv), yu^(-1)}, yw] + 
     7*G[{0, yv^(-1), yu^(-1), 1/(yu*yv), yv^(-1)}, yw] - 
     6*G[{0, yv^(-1), yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] + 
     7*G[{0, yv^(-1), yv^(-1), 0, 1/(yu*yv)}, yw] + 
     6*G[{0, yv^(-1), yv^(-1), 1, 1}, yw] - 
     G[{0, yv^(-1), yv^(-1), 1, yu^(-1)}, yw] - 
     5*G[{0, yv^(-1), yv^(-1), 1, yv^(-1)}, yw] - 
     6*G[{0, yv^(-1), yv^(-1), 1, 1/(yu*yv)}, yw] - 
     8*G[{0, yv^(-1), yv^(-1), yu^(-1), 1}, yw] - 
     G[{0, yv^(-1), yv^(-1), yu^(-1), yu^(-1)}, yw] + 
     7*G[{0, yv^(-1), yv^(-1), yu^(-1), yv^(-1)}, yw] + 
     8*G[{0, yv^(-1), yv^(-1), yu^(-1), 1/(yu*yv)}, yw] - 
     12*G[{0, yv^(-1), yv^(-1), yv^(-1), 1}, yw] + 
     7*G[{0, yv^(-1), yv^(-1), yv^(-1), yu^(-1)}, yw] + 
     7*G[{0, yv^(-1), yv^(-1), yv^(-1), yv^(-1)}, yw] + 
     4*G[{0, yv^(-1), yv^(-1), yv^(-1), 1/(yu*yv)}, yw] - 
     2*G[{0, yv^(-1), yv^(-1), 1/(yu*yv), 1}, yw] + 
     11*G[{0, yv^(-1), yv^(-1), 1/(yu*yv), yu^(-1)}, yw] + 
     7*G[{0, yv^(-1), yv^(-1), 1/(yu*yv), yv^(-1)}, yw] - 
     6*G[{0, yv^(-1), yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] - 
     7*G[{0, yv^(-1), 1/(yu*yv), 0, 1/(yu*yv)}, yw] + 
     2*G[{0, yv^(-1), 1/(yu*yv), 1, 1}, yw] - 
     3*G[{0, yv^(-1), 1/(yu*yv), 1, yu^(-1)}, yw] - 
     7*G[{0, yv^(-1), 1/(yu*yv), 1, yv^(-1)}, yw] + 
     2*G[{0, yv^(-1), 1/(yu*yv), 1, 1/(yu*yv)}, yw] + 
     2*G[{0, yv^(-1), 1/(yu*yv), yu^(-1), 1}, yw] + 
     3*G[{0, yv^(-1), 1/(yu*yv), yu^(-1), yu^(-1)}, yw] + 
     7*G[{0, yv^(-1), 1/(yu*yv), yu^(-1), yv^(-1)}, yw] - 
     6*G[{0, yv^(-1), 1/(yu*yv), yu^(-1), 1/(yu*yv)}, yw] - 
     2*G[{0, yv^(-1), 1/(yu*yv), yv^(-1), 1}, yw] + 
     7*G[{0, yv^(-1), 1/(yu*yv), yv^(-1), yu^(-1)}, yw] + 
     7*G[{0, yv^(-1), 1/(yu*yv), yv^(-1), yv^(-1)}, yw] - 
     6*G[{0, yv^(-1), 1/(yu*yv), yv^(-1), 1/(yu*yv)}, yw] + 
     6*G[{0, yv^(-1), 1/(yu*yv), 1/(yu*yv), 1}, yw] - 
     15*G[{0, yv^(-1), 1/(yu*yv), 1/(yu*yv), yu^(-1)}, yw] - 
     15*G[{0, yv^(-1), 1/(yu*yv), 1/(yu*yv), yv^(-1)}, yw] + 
     2*G[{0, yv^(-1), 1/(yu*yv), 1/(yu*yv), 1/(yu*yv)}, yw] - 
     7*G[{0, 1/(yu*yv), 0, 1/(yu*yv), 1}, yw] + 
     7*G[{0, 1/(yu*yv), 0, 1/(yu*yv), yu^(-1)}, yw] + 
     7*G[{0, 1/(yu*yv), 0, 1/(yu*yv), yv^(-1)}, yw] - 
     7*G[{0, 1/(yu*yv), 0, 1/(yu*yv), 1/(yu*yv)}, yw] - 
     2*G[{0, 1/(yu*yv), 1, 1, 1}, yw] + 3*G[{0, 1/(yu*yv), 1, 1, yu^(-1)}, 
       yw] + 3*G[{0, 1/(yu*yv), 1, 1, yv^(-1)}, yw] - 
     6*G[{0, 1/(yu*yv), 1, 1, 1/(yu*yv)}, yw] - 
     2*G[{0, 1/(yu*yv), 1, yu^(-1), 1}, yw] + 
     G[{0, 1/(yu*yv), 1, yu^(-1), yu^(-1)}, yw] - 
     3*G[{0, 1/(yu*yv), 1, yu^(-1), yv^(-1)}, yw] + 
     6*G[{0, 1/(yu*yv), 1, yu^(-1), 1/(yu*yv)}, yw] - 
     2*G[{0, 1/(yu*yv), 1, yv^(-1), 1}, yw] - 
     3*G[{0, 1/(yu*yv), 1, yv^(-1), yu^(-1)}, yw] + 
     G[{0, 1/(yu*yv), 1, yv^(-1), yv^(-1)}, yw] + 
     6*G[{0, 1/(yu*yv), 1, yv^(-1), 1/(yu*yv)}, yw] - 
     6*G[{0, 1/(yu*yv), 1, 1/(yu*yv), 1}, yw] + 
     11*G[{0, 1/(yu*yv), 1, 1/(yu*yv), yu^(-1)}, yw] + 
     11*G[{0, 1/(yu*yv), 1, 1/(yu*yv), yv^(-1)}, yw] - 
     2*G[{0, 1/(yu*yv), 1, 1/(yu*yv), 1/(yu*yv)}, yw] - 
     2*G[{0, 1/(yu*yv), yu^(-1), 1, 1}, yw] + 
     G[{0, 1/(yu*yv), yu^(-1), 1, yu^(-1)}, yw] + 
     G[{0, 1/(yu*yv), yu^(-1), 1, yv^(-1)}, yw] + 
     6*G[{0, 1/(yu*yv), yu^(-1), 1, 1/(yu*yv)}, yw] + 
     8*G[{0, 1/(yu*yv), yu^(-1), yu^(-1), 1}, yw] - 
     7*G[{0, 1/(yu*yv), yu^(-1), yu^(-1), yu^(-1)}, yw] - 
     3*G[{0, 1/(yu*yv), yu^(-1), yu^(-1), yv^(-1)}, yw] - 
     4*G[{0, 1/(yu*yv), yu^(-1), yu^(-1), 1/(yu*yv)}, yw] + 
     8*G[{0, 1/(yu*yv), yu^(-1), yv^(-1), 1}, yw] - 
     3*G[{0, 1/(yu*yv), yu^(-1), yv^(-1), yu^(-1)}, yw] - 
     3*G[{0, 1/(yu*yv), yu^(-1), yv^(-1), yv^(-1)}, yw] - 
     8*G[{0, 1/(yu*yv), yu^(-1), yv^(-1), 1/(yu*yv)}, yw] + 
     2*G[{0, 1/(yu*yv), yu^(-1), 1/(yu*yv), 1}, yw] - 
     7*G[{0, 1/(yu*yv), yu^(-1), 1/(yu*yv), yu^(-1)}, yw] - 
     11*G[{0, 1/(yu*yv), yu^(-1), 1/(yu*yv), yv^(-1)}, yw] + 
     6*G[{0, 1/(yu*yv), yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] - 
     2*G[{0, 1/(yu*yv), yv^(-1), 1, 1}, yw] + 
     G[{0, 1/(yu*yv), yv^(-1), 1, yu^(-1)}, yw] + 
     G[{0, 1/(yu*yv), yv^(-1), 1, yv^(-1)}, yw] + 
     6*G[{0, 1/(yu*yv), yv^(-1), 1, 1/(yu*yv)}, yw] + 
     8*G[{0, 1/(yu*yv), yv^(-1), yu^(-1), 1}, yw] - 
     3*G[{0, 1/(yu*yv), yv^(-1), yu^(-1), yu^(-1)}, yw] - 
     3*G[{0, 1/(yu*yv), yv^(-1), yu^(-1), yv^(-1)}, yw] - 
     8*G[{0, 1/(yu*yv), yv^(-1), yu^(-1), 1/(yu*yv)}, yw] + 
     8*G[{0, 1/(yu*yv), yv^(-1), yv^(-1), 1}, yw] - 
     3*G[{0, 1/(yu*yv), yv^(-1), yv^(-1), yu^(-1)}, yw] - 
     7*G[{0, 1/(yu*yv), yv^(-1), yv^(-1), yv^(-1)}, yw] - 
     4*G[{0, 1/(yu*yv), yv^(-1), yv^(-1), 1/(yu*yv)}, yw] + 
     2*G[{0, 1/(yu*yv), yv^(-1), 1/(yu*yv), 1}, yw] - 
     11*G[{0, 1/(yu*yv), yv^(-1), 1/(yu*yv), yu^(-1)}, yw] - 
     7*G[{0, 1/(yu*yv), yv^(-1), 1/(yu*yv), yv^(-1)}, yw] + 
     6*G[{0, 1/(yu*yv), yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] - 
     14*G[{0, 1/(yu*yv), 1/(yu*yv), 1, 1}, yw] + 
     11*G[{0, 1/(yu*yv), 1/(yu*yv), 1, yu^(-1)}, yw] + 
     11*G[{0, 1/(yu*yv), 1/(yu*yv), 1, yv^(-1)}, yw] - 
     2*G[{0, 1/(yu*yv), 1/(yu*yv), 1, 1/(yu*yv)}, yw] + 
     6*G[{0, 1/(yu*yv), 1/(yu*yv), yu^(-1), 1}, yw] - 
     7*G[{0, 1/(yu*yv), 1/(yu*yv), yu^(-1), yu^(-1)}, yw] - 
     11*G[{0, 1/(yu*yv), 1/(yu*yv), yu^(-1), yv^(-1)}, yw] + 
     6*G[{0, 1/(yu*yv), 1/(yu*yv), yu^(-1), 1/(yu*yv)}, yw] + 
     6*G[{0, 1/(yu*yv), 1/(yu*yv), yv^(-1), 1}, yw] - 
     11*G[{0, 1/(yu*yv), 1/(yu*yv), yv^(-1), yu^(-1)}, yw] - 
     7*G[{0, 1/(yu*yv), 1/(yu*yv), yv^(-1), yv^(-1)}, yw] + 
     6*G[{0, 1/(yu*yv), 1/(yu*yv), yv^(-1), 1/(yu*yv)}, yw] - 
     6*G[{0, 1/(yu*yv), 1/(yu*yv), 1/(yu*yv), 1}, yw] + 
     15*G[{0, 1/(yu*yv), 1/(yu*yv), 1/(yu*yv), yu^(-1)}, yw] + 
     15*G[{0, 1/(yu*yv), 1/(yu*yv), 1/(yu*yv), yv^(-1)}, yw] - 
     2*G[{0, 1/(yu*yv), 1/(yu*yv), 1/(yu*yv), 1/(yu*yv)}, yw] + 
     2*G[{1, 1, 1, 1, yu^(-1)}, yw] + 2*G[{1, 1, 1, 1, yu}, yv^(-1)] + 
     2*G[{1, 1, 1, 1, yv^(-1)}, yw] - 24*G[{1, 1, 1, yu^(-1), yu^(-1)}, yw] - 
     12*G[{1, 1, 1, yu^(-1), yv^(-1)}, yw] + 
     2*G[{1, 1, 1, yu^(-1), 1/(yu*yv)}, yw] - 
     24*G[{1, 1, 1, yu, yu}, yv^(-1)] - 12*G[{1, 1, 1, yv^(-1), yu^(-1)}, 
       yw] - 24*G[{1, 1, 1, yv^(-1), yv^(-1)}, yw] + 
     2*G[{1, 1, 1, yv^(-1), 1/(yu*yv)}, yw] + 
     4*G[{1, 1, 1, 1/(yu*yv), yu^(-1)}, yw] + 
     4*G[{1, 1, 1, 1/(yu*yv), yv^(-1)}, yw] + 
     48*G[{1, 1, 1, 1/(yu*yv), 1/(yu*yv)}, yw] - 
     7*G[{1, 1, yu^(-1), 1, yu^(-1)}, yw] - 
     5*G[{1, 1, yu^(-1), 1, yv^(-1)}, yw] + 
     2*G[{1, 1, yu^(-1), 1, 1/(yu*yv)}, yw] + 
     25*G[{1, 1, yu^(-1), yu^(-1), yu^(-1)}, yw] - 
     G[{1, 1, yu^(-1), yu^(-1), yv^(-1)}, yw] - 
     10*G[{1, 1, yu^(-1), yu^(-1), 1/(yu*yv)}, yw] - 
     G[{1, 1, yu^(-1), yv^(-1), yu^(-1)}, yw] - 
     15*G[{1, 1, yu^(-1), yv^(-1), yv^(-1)}, yw] - 
     6*G[{1, 1, yu^(-1), yv^(-1), 1/(yu*yv)}, yw] - 
     7*G[{1, 1, yu^(-1), 1/(yu*yv), yu^(-1)}, yw] - 
     G[{1, 1, yu^(-1), 1/(yu*yv), yv^(-1)}, yw] - 
     12*G[{1, 1, yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] - 
     7*G[{1, 1, yu, 1, yu}, yv^(-1)] + 25*G[{1, 1, yu, yu, yu}, yv^(-1)] - 
     5*G[{1, 1, yv^(-1), 1, yu^(-1)}, yw] - 
     7*G[{1, 1, yv^(-1), 1, yv^(-1)}, yw] + 
     2*G[{1, 1, yv^(-1), 1, 1/(yu*yv)}, yw] - 
     G[{1, 1, yv^(-1), yu^(-1), yu^(-1)}, yw] - 
     G[{1, 1, yv^(-1), yu^(-1), yv^(-1)}, yw] - 
     6*G[{1, 1, yv^(-1), yu^(-1), 1/(yu*yv)}, yw] + 
     13*G[{1, 1, yv^(-1), yv^(-1), yu^(-1)}, yw] + 
     25*G[{1, 1, yv^(-1), yv^(-1), yv^(-1)}, yw] - 
     10*G[{1, 1, yv^(-1), yv^(-1), 1/(yu*yv)}, yw] + 
     5*G[{1, 1, yv^(-1), 1/(yu*yv), yu^(-1)}, yw] - 
     7*G[{1, 1, yv^(-1), 1/(yu*yv), yv^(-1)}, yw] - 
     12*G[{1, 1, yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] + 
     2*G[{1, 1, 1/(yu*yv), 1, yu^(-1)}, yw] + 
     2*G[{1, 1, 1/(yu*yv), 1, yv^(-1)}, yw] + 
     12*G[{1, 1, 1/(yu*yv), 1, 1/(yu*yv)}, yw] - 
     6*G[{1, 1, 1/(yu*yv), yu^(-1), yu^(-1)}, yw] + 
     8*G[{1, 1, 1/(yu*yv), yu^(-1), yv^(-1)}, yw] - 
     2*G[{1, 1, 1/(yu*yv), yu^(-1), 1/(yu*yv)}, yw] + 
     8*G[{1, 1, 1/(yu*yv), yv^(-1), yu^(-1)}, yw] - 
     6*G[{1, 1, 1/(yu*yv), yv^(-1), yv^(-1)}, yw] - 
     2*G[{1, 1, 1/(yu*yv), yv^(-1), 1/(yu*yv)}, yw] + 
     10*G[{1, 1, 1/(yu*yv), 1/(yu*yv), yu^(-1)}, yw] + 
     10*G[{1, 1, 1/(yu*yv), 1/(yu*yv), yv^(-1)}, yw] - 
     28*G[{1, 1, 1/(yu*yv), 1/(yu*yv), 1/(yu*yv)}, yw] + 
     14*G[{1, yu^(-1), 1, yu^(-1), yu^(-1)}, yw] - 
     3*G[{1, yu^(-1), 1, yu^(-1), 1/(yu*yv)}, yw] - 
     7*G[{1, yu^(-1), 1, yv^(-1), yv^(-1)}, yw] + 
     5*G[{1, yu^(-1), 1, 1/(yu*yv), yv^(-1)}, yw] - 
     5*G[{1, yu^(-1), 1, 1/(yu*yv), 1/(yu*yv)}, yw] - 
     7*G[{1, yu^(-1), yu^(-1), 1, yv^(-1)}, yw] + 
     7*G[{1, yu^(-1), yu^(-1), 1, 1/(yu*yv)}, yw] - 
     7*G[{1, yu^(-1), yu^(-1), yu^(-1), yv^(-1)}, yw] - 
     7*G[{1, yu^(-1), yu^(-1), yv^(-1), yu^(-1)}, yw] + 
     G[{1, yu^(-1), yu^(-1), yv^(-1), yv^(-1)}, yw] - 
     8*G[{1, yu^(-1), yu^(-1), yv^(-1), 1/(yu*yv)}, yw] - 
     15*G[{1, yu^(-1), yu^(-1), 1/(yu*yv), yv^(-1)}, yw] - 
     7*G[{1, yu^(-1), yv^(-1), 1, yv^(-1)}, yw] + 
     8*G[{1, yu^(-1), yv^(-1), 1, 1/(yu*yv)}, yw] - 
     7*G[{1, yu^(-1), yv^(-1), yu^(-1), yu^(-1)}, yw] + 
     G[{1, yu^(-1), yv^(-1), yu^(-1), yv^(-1)}, yw] - 
     8*G[{1, yu^(-1), yv^(-1), yu^(-1), 1/(yu*yv)}, yw] + 
     G[{1, yu^(-1), yv^(-1), yv^(-1), yu^(-1)}, yw] - 
     7*G[{1, yu^(-1), yv^(-1), yv^(-1), yv^(-1)}, yw] - 
     8*G[{1, yu^(-1), yv^(-1), yv^(-1), 1/(yu*yv)}, yw] - 
     7*G[{1, yu^(-1), yv^(-1), 1/(yu*yv), yu^(-1)}, yw] - 
     7*G[{1, yu^(-1), yv^(-1), 1/(yu*yv), yv^(-1)}, yw] + 
     6*G[{1, yu^(-1), yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] - 
     3*G[{1, yu^(-1), 1/(yu*yv), 1, yv^(-1)}, yw] - 
     5*G[{1, yu^(-1), 1/(yu*yv), 1, 1/(yu*yv)}, yw] - 
     7*G[{1, yu^(-1), 1/(yu*yv), yu^(-1), yv^(-1)}, yw] - 
     7*G[{1, yu^(-1), 1/(yu*yv), yv^(-1), yu^(-1)}, yw] + 
     G[{1, yu^(-1), 1/(yu*yv), yv^(-1), yv^(-1)}, yw] + 
     6*G[{1, yu^(-1), 1/(yu*yv), yv^(-1), 1/(yu*yv)}, yw] + 
     11*G[{1, yu^(-1), 1/(yu*yv), 1/(yu*yv), yv^(-1)}, yw] + 
     14*G[{1, yu, 1, yu, yu}, yv^(-1)] + 
     7*G[{1, yv^(-1), 1, yv^(-1), yu^(-1)}, yw] + 
     14*G[{1, yv^(-1), 1, yv^(-1), yv^(-1)}, yw] - 
     3*G[{1, yv^(-1), 1, yv^(-1), 1/(yu*yv)}, yw] + 
     8*G[{1, yv^(-1), 1, 1/(yu*yv), yu^(-1)}, yw] - 
     5*G[{1, yv^(-1), 1, 1/(yu*yv), 1/(yu*yv)}, yw] + 
     8*G[{1, yv^(-1), yu^(-1), 1, 1/(yu*yv)}, yw] - 
     7*G[{1, yv^(-1), yu^(-1), yu^(-1), yu^(-1)}, yw] + 
     G[{1, yv^(-1), yu^(-1), yu^(-1), yv^(-1)}, yw] - 
     8*G[{1, yv^(-1), yu^(-1), yu^(-1), 1/(yu*yv)}, yw] + 
     G[{1, yv^(-1), yu^(-1), yv^(-1), yu^(-1)}, yw] - 
     7*G[{1, yv^(-1), yu^(-1), yv^(-1), yv^(-1)}, yw] - 
     8*G[{1, yv^(-1), yu^(-1), yv^(-1), 1/(yu*yv)}, yw] - 
     7*G[{1, yv^(-1), yu^(-1), 1/(yu*yv), yu^(-1)}, yw] - 
     7*G[{1, yv^(-1), yu^(-1), 1/(yu*yv), yv^(-1)}, yw] + 
     6*G[{1, yv^(-1), yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] + 
     7*G[{1, yv^(-1), yv^(-1), 1, 1/(yu*yv)}, yw] + 
     G[{1, yv^(-1), yv^(-1), yu^(-1), yu^(-1)}, yw] - 
     7*G[{1, yv^(-1), yv^(-1), yu^(-1), yv^(-1)}, yw] - 
     8*G[{1, yv^(-1), yv^(-1), yu^(-1), 1/(yu*yv)}, yw] - 
     7*G[{1, yv^(-1), yv^(-1), yv^(-1), yu^(-1)}, yw] - 
     15*G[{1, yv^(-1), yv^(-1), 1/(yu*yv), yu^(-1)}, yw] - 
     5*G[{1, yv^(-1), 1/(yu*yv), 1, 1/(yu*yv)}, yw] + 
     G[{1, yv^(-1), 1/(yu*yv), yu^(-1), yu^(-1)}, yw] - 
     7*G[{1, yv^(-1), 1/(yu*yv), yu^(-1), yv^(-1)}, yw] + 
     6*G[{1, yv^(-1), 1/(yu*yv), yu^(-1), 1/(yu*yv)}, yw] - 
     7*G[{1, yv^(-1), 1/(yu*yv), yv^(-1), yu^(-1)}, yw] + 
     11*G[{1, yv^(-1), 1/(yu*yv), 1/(yu*yv), yu^(-1)}, yw] - 
     G[{1, 1/(yu*yv), 1, 1/(yu*yv), yu^(-1)}, yw] - 
     G[{1, 1/(yu*yv), 1, 1/(yu*yv), yv^(-1)}, yw] - 
     18*G[{1, 1/(yu*yv), 1, 1/(yu*yv), 1/(yu*yv)}, yw] - 
     7*G[{1, 1/(yu*yv), yu^(-1), yu^(-1), yu^(-1)}, yw] - 
     8*G[{1, 1/(yu*yv), yu^(-1), yu^(-1), 1/(yu*yv)}, yw] - 
     7*G[{1, 1/(yu*yv), yu^(-1), 1/(yu*yv), yu^(-1)}, yw] + 
     8*G[{1, 1/(yu*yv), yu^(-1), 1/(yu*yv), yv^(-1)}, yw] + 
     6*G[{1, 1/(yu*yv), yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] - 
     7*G[{1, 1/(yu*yv), yv^(-1), yv^(-1), yv^(-1)}, yw] - 
     8*G[{1, 1/(yu*yv), yv^(-1), yv^(-1), 1/(yu*yv)}, yw] + 
     8*G[{1, 1/(yu*yv), yv^(-1), 1/(yu*yv), yu^(-1)}, yw] - 
     7*G[{1, 1/(yu*yv), yv^(-1), 1/(yu*yv), yv^(-1)}, yw] + 
     6*G[{1, 1/(yu*yv), yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] - 
     7*G[{1, 1/(yu*yv), 1/(yu*yv), yu^(-1), yu^(-1)}, yw] + 
     8*G[{1, 1/(yu*yv), 1/(yu*yv), yu^(-1), yv^(-1)}, yw] + 
     6*G[{1, 1/(yu*yv), 1/(yu*yv), yu^(-1), 1/(yu*yv)}, yw] + 
     8*G[{1, 1/(yu*yv), 1/(yu*yv), yv^(-1), yu^(-1)}, yw] - 
     7*G[{1, 1/(yu*yv), 1/(yu*yv), yv^(-1), yv^(-1)}, yw] + 
     6*G[{1, 1/(yu*yv), 1/(yu*yv), yv^(-1), 1/(yu*yv)}, yw] + 
     19*G[{1, 1/(yu*yv), 1/(yu*yv), 1/(yu*yv), yu^(-1)}, yw] + 
     19*G[{1, 1/(yu*yv), 1/(yu*yv), 1/(yu*yv), yv^(-1)}, yw] - 
     4*G[{1, 1/(yu*yv), 1/(yu*yv), 1/(yu*yv), 1/(yu*yv)}, yw] - 
     14*G[{yu^(-1), yu^(-1), yu^(-1), yu^(-1), 1/(yu*yv)}, yw] + 
     7*G[{yu^(-1), yu^(-1), yu^(-1), 1/(yu*yv), yv^(-1)}, yw] + 
     26*G[{yu^(-1), yu^(-1), yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] + 
     6*G[{yu^(-1), yu^(-1), 1/(yu*yv), yu^(-1), 1/(yu*yv)}, yw] + 
     G[{yu^(-1), yu^(-1), 1/(yu*yv), yv^(-1), yv^(-1)}, yw] - 
     8*G[{yu^(-1), yu^(-1), 1/(yu*yv), yv^(-1), 1/(yu*yv)}, yw] - 
     9*G[{yu^(-1), yu^(-1), 1/(yu*yv), 1/(yu*yv), yv^(-1)}, yw] - 
     24*G[{yu^(-1), yu^(-1), 1/(yu*yv), 1/(yu*yv), 1/(yu*yv)}, yw] - 
     G[{yu^(-1), 1/(yu*yv), yu^(-1), 1/(yu*yv), yv^(-1)}, yw] - 
     18*G[{yu^(-1), 1/(yu*yv), yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] + 
     7*G[{yu^(-1), 1/(yu*yv), yv^(-1), yv^(-1), yv^(-1)}, yw] + 
     8*G[{yu^(-1), 1/(yu*yv), yv^(-1), yv^(-1), 1/(yu*yv)}, yw] + 
     7*G[{yu^(-1), 1/(yu*yv), yv^(-1), 1/(yu*yv), yv^(-1)}, yw] - 
     6*G[{yu^(-1), 1/(yu*yv), yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] + 
     7*G[{yu^(-1), 1/(yu*yv), 1/(yu*yv), yv^(-1), yv^(-1)}, yw] - 
     6*G[{yu^(-1), 1/(yu*yv), 1/(yu*yv), yv^(-1), 1/(yu*yv)}, yw] - 
     19*G[{yu^(-1), 1/(yu*yv), 1/(yu*yv), 1/(yu*yv), yv^(-1)}, yw] + 
     4*G[{yu^(-1), 1/(yu*yv), 1/(yu*yv), 1/(yu*yv), 1/(yu*yv)}, yw] - 
     14*G[{yv^(-1), yv^(-1), yv^(-1), yv^(-1), 1/(yu*yv)}, yw] + 
     26*G[{yv^(-1), yv^(-1), yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] + 
     6*G[{yv^(-1), yv^(-1), 1/(yu*yv), yv^(-1), 1/(yu*yv)}, yw] - 
     24*G[{yv^(-1), yv^(-1), 1/(yu*yv), 1/(yu*yv), 1/(yu*yv)}, yw] - 
     18*G[{yv^(-1), 1/(yu*yv), yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] + 
     4*G[{yv^(-1), 1/(yu*yv), 1/(yu*yv), 1/(yu*yv), 1/(yu*yv)}, yw] - 
     (Pi^2*Zeta[3])/6 + G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*Zeta[3] + 
     4*G[{0}, yu^(-1)]*G[{1}, yw]*Zeta[3] + 4*G[{0}, yv^(-1)]*G[{1}, yw]*
      Zeta[3] - 4*G[{0}, yw]*G[{1}, yw]*Zeta[3] + G[{1}, yw]^2*Zeta[3] - 
     4*G[{0}, yu^(-1)]*G[{yu^(-1)}, yw]*Zeta[3] - 
     4*G[{0}, yv^(-1)]*G[{yu^(-1)}, yw]*Zeta[3] + 
     4*G[{0}, yw]*G[{yu^(-1)}, yw]*Zeta[3] - G[{1}, yv^(-1)]*G[{yu^(-1)}, yw]*
      Zeta[3] - 7*G[{1}, yw]*G[{yu^(-1)}, yw]*Zeta[3] + 
     (7*G[{yu^(-1)}, yw]^2*Zeta[3])/2 - G[{1}, yu^(-1)]*G[{yu}, yv^(-1)]*
      Zeta[3] - G[{1}, yv^(-1)]*G[{yu}, yv^(-1)]*Zeta[3] - 
     4*G[{1}, yw]*G[{yu}, yv^(-1)]*Zeta[3] + 5*G[{yu^(-1)}, yw]*
      G[{yu}, yv^(-1)]*Zeta[3] + G[{yu}, yv^(-1)]^2*Zeta[3] - 
     4*G[{0}, yu^(-1)]*G[{yv^(-1)}, yw]*Zeta[3] - 
     4*G[{0}, yv^(-1)]*G[{yv^(-1)}, yw]*Zeta[3] + 
     4*G[{0}, yw]*G[{yv^(-1)}, yw]*Zeta[3] - G[{1}, yu^(-1)]*G[{yv^(-1)}, yw]*
      Zeta[3] - 7*G[{1}, yw]*G[{yv^(-1)}, yw]*Zeta[3] + 
     2*G[{yu^(-1)}, yw]*G[{yv^(-1)}, yw]*Zeta[3] + 
     5*G[{yu}, yv^(-1)]*G[{yv^(-1)}, yw]*Zeta[3] + 
     (7*G[{yv^(-1)}, yw]^2*Zeta[3])/2 + 4*G[{0}, yu^(-1)]*G[{1/(yu*yv)}, yw]*
      Zeta[3] + 4*G[{0}, yv^(-1)]*G[{1/(yu*yv)}, yw]*Zeta[3] - 
     4*G[{0}, yw]*G[{1/(yu*yv)}, yw]*Zeta[3] + G[{1}, yu^(-1)]*
      G[{1/(yu*yv)}, yw]*Zeta[3] + G[{1}, yv^(-1)]*G[{1/(yu*yv)}, yw]*
      Zeta[3] + 12*G[{1}, yw]*G[{1/(yu*yv)}, yw]*Zeta[3] - 
     7*G[{yu^(-1)}, yw]*G[{1/(yu*yv)}, yw]*Zeta[3] - 
     6*G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw]*Zeta[3] - 
     7*G[{yv^(-1)}, yw]*G[{1/(yu*yv)}, yw]*Zeta[3] + 
     3*G[{1/(yu*yv)}, yw]^2*Zeta[3] + G[{0, 1}, yu^(-1)]*Zeta[3] + 
     G[{0, 1}, yv^(-1)]*Zeta[3] + 4*G[{0, 1}, yw]*Zeta[3] - 
     4*G[{0, yu^(-1)}, yw]*Zeta[3] - G[{0, yu}, yv^(-1)]*Zeta[3] - 
     4*G[{0, yv^(-1)}, yw]*Zeta[3] + 4*G[{0, 1/(yu*yv)}, yw]*Zeta[3] + 
     5*G[{1, yu^(-1)}, yw]*Zeta[3] + 5*G[{1, yv^(-1)}, yw]*Zeta[3] - 
     6*G[{1, 1/(yu*yv)}, yw]*Zeta[3] + G[{yu^(-1), 1/(yu*yv)}, yw]*Zeta[3] + 
     G[{yv^(-1), 1/(yu*yv)}, yw]*Zeta[3] + (19*Zeta[5])/2
 
GuvwRegII = (13*Pi^4*G[{0}, yu^(-1)])/360 + (13*Pi^4*G[{0}, yv^(-1)])/360 - 
     (13*Pi^4*G[{0}, yw])/360 + (Pi^2*G[{0}, yu^(-1)]*G[{0, 1}, yu^(-1)])/6 + 
     (Pi^2*G[{0}, yv^(-1)]*G[{0, 1}, yu^(-1)])/6 - 
     (Pi^2*G[{0}, yw]*G[{0, 1}, yu^(-1)])/6 - 
     (G[{0}, yu^(-1)]*G[{0, 1}, yu^(-1)]^2)/2 - 
     (G[{0}, yv^(-1)]*G[{0, 1}, yu^(-1)]^2)/2 + 
     (G[{0}, yw]*G[{0, 1}, yu^(-1)]^2)/2 + 
     (Pi^2*G[{0}, yu^(-1)]*G[{0, 1}, yv^(-1)])/6 + 
     (Pi^2*G[{0}, yv^(-1)]*G[{0, 1}, yv^(-1)])/6 - 
     (Pi^2*G[{0}, yw]*G[{0, 1}, yv^(-1)])/6 - G[{0}, yu^(-1)]*
      G[{0, 1}, yu^(-1)]*G[{0, 1}, yv^(-1)] - G[{0}, yv^(-1)]*
      G[{0, 1}, yu^(-1)]*G[{0, 1}, yv^(-1)] + G[{0}, yw]*G[{0, 1}, yu^(-1)]*
      G[{0, 1}, yv^(-1)] - (G[{0}, yu^(-1)]*G[{0, 1}, yv^(-1)]^2)/2 - 
     (G[{0}, yv^(-1)]*G[{0, 1}, yv^(-1)]^2)/2 + 
     (G[{0}, yw]*G[{0, 1}, yv^(-1)]^2)/2 + 
     (Pi^2*G[{0}, yu^(-1)]*G[{0, 1}, yw])/6 + 
     (Pi^2*G[{0}, yv^(-1)]*G[{0, 1}, yw])/6 - (Pi^2*G[{0}, yw]*G[{0, 1}, yw])/
      6 - G[{1}, yu^(-1)]*G[{1}, yv^(-1)]^2*G[{0, 1}, yw] - 
     (Pi^2*G[{yu}, yv^(-1)]*G[{0, 1}, yw])/3 + 4*G[{1}, yu^(-1)]*
      G[{1}, yv^(-1)]*G[{yu}, yv^(-1)]*G[{0, 1}, yw] - 
     2*G[{1}, yu^(-1)]*G[{yu}, yv^(-1)]^2*G[{0, 1}, yw] - 
     2*G[{1}, yv^(-1)]*G[{yu}, yv^(-1)]^2*G[{0, 1}, yw] + 
     (4*G[{yu}, yv^(-1)]^3*G[{0, 1}, yw])/3 - G[{0}, yu^(-1)]*
      G[{0, 1}, yu^(-1)]*G[{0, 1}, yw] - G[{0}, yv^(-1)]*G[{0, 1}, yu^(-1)]*
      G[{0, 1}, yw] + G[{0}, yw]*G[{0, 1}, yu^(-1)]*G[{0, 1}, yw] + 
     2*G[{yu}, yv^(-1)]*G[{0, 1}, yu^(-1)]*G[{0, 1}, yw] - 
     G[{0}, yu^(-1)]*G[{0, 1}, yv^(-1)]*G[{0, 1}, yw] - 
     G[{0}, yv^(-1)]*G[{0, 1}, yv^(-1)]*G[{0, 1}, yw] + 
     G[{0}, yw]*G[{0, 1}, yv^(-1)]*G[{0, 1}, yw] + 
     2*G[{yu}, yv^(-1)]*G[{0, 1}, yv^(-1)]*G[{0, 1}, yw] - 
     (G[{0}, yu^(-1)]*G[{0, 1}, yw]^2)/2 - (G[{0}, yv^(-1)]*G[{0, 1}, yw]^2)/
      2 + (G[{0}, yw]*G[{0, 1}, yw]^2)/2 + G[{1}, yu^(-1)]*G[{0, 1}, yw]^2 + 
     G[{1}, yv^(-1)]*G[{0, 1}, yw]^2 - G[{yu}, yv^(-1)]*G[{0, 1}, yw]^2 - 
     (Pi^2*G[{0}, yu^(-1)]*G[{0, yu^(-1)}, yw])/6 - 
     (Pi^2*G[{0}, yv^(-1)]*G[{0, yu^(-1)}, yw])/6 + 
     (Pi^2*G[{0}, yw]*G[{0, yu^(-1)}, yw])/6 + 
     (Pi^2*G[{1}, yv^(-1)]*G[{0, yu^(-1)}, yw])/3 - 
     G[{1}, yu^(-1)]*G[{1}, yv^(-1)]^2*G[{0, yu^(-1)}, yw] + 
     G[{0}, yu^(-1)]*G[{0, 1}, yu^(-1)]*G[{0, yu^(-1)}, yw] + 
     G[{0}, yv^(-1)]*G[{0, 1}, yu^(-1)]*G[{0, yu^(-1)}, yw] - 
     G[{0}, yw]*G[{0, 1}, yu^(-1)]*G[{0, yu^(-1)}, yw] - 
     2*G[{1}, yv^(-1)]*G[{0, 1}, yu^(-1)]*G[{0, yu^(-1)}, yw] + 
     G[{0}, yu^(-1)]*G[{0, 1}, yv^(-1)]*G[{0, yu^(-1)}, yw] + 
     G[{0}, yv^(-1)]*G[{0, 1}, yv^(-1)]*G[{0, yu^(-1)}, yw] - 
     G[{0}, yw]*G[{0, 1}, yv^(-1)]*G[{0, yu^(-1)}, yw] - 
     2*G[{1}, yv^(-1)]*G[{0, 1}, yv^(-1)]*G[{0, yu^(-1)}, yw] + 
     G[{0}, yu^(-1)]*G[{0, 1}, yw]*G[{0, yu^(-1)}, yw] + 
     G[{0}, yv^(-1)]*G[{0, 1}, yw]*G[{0, yu^(-1)}, yw] - 
     G[{0}, yw]*G[{0, 1}, yw]*G[{0, yu^(-1)}, yw] - 
     2*G[{1}, yu^(-1)]*G[{0, 1}, yw]*G[{0, yu^(-1)}, yw] - 
     (G[{0}, yu^(-1)]*G[{0, yu^(-1)}, yw]^2)/2 - 
     (G[{0}, yv^(-1)]*G[{0, yu^(-1)}, yw]^2)/2 + 
     (G[{0}, yw]*G[{0, yu^(-1)}, yw]^2)/2 + G[{1}, yu^(-1)]*
      G[{0, yu^(-1)}, yw]^2 - (Pi^2*G[{0}, yu^(-1)]*G[{0, yu}, yv^(-1)])/6 - 
     (Pi^2*G[{0}, yv^(-1)]*G[{0, yu}, yv^(-1)])/6 + 
     (Pi^2*G[{0}, yw]*G[{0, yu}, yv^(-1)])/6 + G[{0}, yu^(-1)]*
      G[{0, 1}, yu^(-1)]*G[{0, yu}, yv^(-1)] + G[{0}, yv^(-1)]*
      G[{0, 1}, yu^(-1)]*G[{0, yu}, yv^(-1)] - G[{0}, yw]*G[{0, 1}, yu^(-1)]*
      G[{0, yu}, yv^(-1)] + G[{0}, yu^(-1)]*G[{0, 1}, yv^(-1)]*
      G[{0, yu}, yv^(-1)] + G[{0}, yv^(-1)]*G[{0, 1}, yv^(-1)]*
      G[{0, yu}, yv^(-1)] - G[{0}, yw]*G[{0, 1}, yv^(-1)]*
      G[{0, yu}, yv^(-1)] + G[{0}, yu^(-1)]*G[{0, 1}, yw]*
      G[{0, yu}, yv^(-1)] + G[{0}, yv^(-1)]*G[{0, 1}, yw]*
      G[{0, yu}, yv^(-1)] - G[{0}, yw]*G[{0, 1}, yw]*G[{0, yu}, yv^(-1)] - 
     2*G[{yu}, yv^(-1)]*G[{0, 1}, yw]*G[{0, yu}, yv^(-1)] - 
     G[{0}, yu^(-1)]*G[{0, yu^(-1)}, yw]*G[{0, yu}, yv^(-1)] - 
     G[{0}, yv^(-1)]*G[{0, yu^(-1)}, yw]*G[{0, yu}, yv^(-1)] + 
     G[{0}, yw]*G[{0, yu^(-1)}, yw]*G[{0, yu}, yv^(-1)] + 
     2*G[{1}, yv^(-1)]*G[{0, yu^(-1)}, yw]*G[{0, yu}, yv^(-1)] - 
     (G[{0}, yu^(-1)]*G[{0, yu}, yv^(-1)]^2)/2 - 
     (G[{0}, yv^(-1)]*G[{0, yu}, yv^(-1)]^2)/2 + 
     (G[{0}, yw]*G[{0, yu}, yv^(-1)]^2)/2 - 
     (Pi^2*G[{0}, yu^(-1)]*G[{0, yv^(-1)}, yw])/6 - 
     (Pi^2*G[{0}, yv^(-1)]*G[{0, yv^(-1)}, yw])/6 + 
     (Pi^2*G[{0}, yw]*G[{0, yv^(-1)}, yw])/6 + 
     (Pi^2*G[{1}, yu^(-1)]*G[{0, yv^(-1)}, yw])/3 + 
     G[{1}, yu^(-1)]*G[{1}, yv^(-1)]^2*G[{0, yv^(-1)}, yw] + 
     G[{0}, yu^(-1)]*G[{0, 1}, yu^(-1)]*G[{0, yv^(-1)}, yw] + 
     G[{0}, yv^(-1)]*G[{0, 1}, yu^(-1)]*G[{0, yv^(-1)}, yw] - 
     G[{0}, yw]*G[{0, 1}, yu^(-1)]*G[{0, yv^(-1)}, yw] - 
     2*G[{1}, yu^(-1)]*G[{0, 1}, yu^(-1)]*G[{0, yv^(-1)}, yw] + 
     G[{0}, yu^(-1)]*G[{0, 1}, yv^(-1)]*G[{0, yv^(-1)}, yw] + 
     G[{0}, yv^(-1)]*G[{0, 1}, yv^(-1)]*G[{0, yv^(-1)}, yw] - 
     G[{0}, yw]*G[{0, 1}, yv^(-1)]*G[{0, yv^(-1)}, yw] - 
     2*G[{1}, yu^(-1)]*G[{0, 1}, yv^(-1)]*G[{0, yv^(-1)}, yw] + 
     G[{0}, yu^(-1)]*G[{0, 1}, yw]*G[{0, yv^(-1)}, yw] + 
     G[{0}, yv^(-1)]*G[{0, 1}, yw]*G[{0, yv^(-1)}, yw] - 
     G[{0}, yw]*G[{0, 1}, yw]*G[{0, yv^(-1)}, yw] - 
     2*G[{1}, yv^(-1)]*G[{0, 1}, yw]*G[{0, yv^(-1)}, yw] - 
     G[{0}, yu^(-1)]*G[{0, yu^(-1)}, yw]*G[{0, yv^(-1)}, yw] - 
     G[{0}, yv^(-1)]*G[{0, yu^(-1)}, yw]*G[{0, yv^(-1)}, yw] + 
     G[{0}, yw]*G[{0, yu^(-1)}, yw]*G[{0, yv^(-1)}, yw] + 
     2*G[{1}, yv^(-1)]*G[{0, yu^(-1)}, yw]*G[{0, yv^(-1)}, yw] - 
     G[{0}, yu^(-1)]*G[{0, yu}, yv^(-1)]*G[{0, yv^(-1)}, yw] - 
     G[{0}, yv^(-1)]*G[{0, yu}, yv^(-1)]*G[{0, yv^(-1)}, yw] + 
     G[{0}, yw]*G[{0, yu}, yv^(-1)]*G[{0, yv^(-1)}, yw] + 
     2*G[{1}, yu^(-1)]*G[{0, yu}, yv^(-1)]*G[{0, yv^(-1)}, yw] - 
     (G[{0}, yu^(-1)]*G[{0, yv^(-1)}, yw]^2)/2 - 
     (G[{0}, yv^(-1)]*G[{0, yv^(-1)}, yw]^2)/2 + 
     (G[{0}, yw]*G[{0, yv^(-1)}, yw]^2)/2 + G[{1}, yv^(-1)]*
      G[{0, yv^(-1)}, yw]^2 + (Pi^2*G[{0}, yu^(-1)]*G[{0, 1/(yu*yv)}, yw])/
      6 + (Pi^2*G[{0}, yv^(-1)]*G[{0, 1/(yu*yv)}, yw])/6 - 
     (Pi^2*G[{0}, yw]*G[{0, 1/(yu*yv)}, yw])/6 - 
     (Pi^2*G[{1}, yu^(-1)]*G[{0, 1/(yu*yv)}, yw])/3 - 
     (Pi^2*G[{1}, yv^(-1)]*G[{0, 1/(yu*yv)}, yw])/3 + 
     G[{1}, yu^(-1)]*G[{1}, yv^(-1)]^2*G[{0, 1/(yu*yv)}, yw] + 
     (Pi^2*G[{yu}, yv^(-1)]*G[{0, 1/(yu*yv)}, yw])/3 - 
     4*G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*G[{yu}, yv^(-1)]*
      G[{0, 1/(yu*yv)}, yw] + 2*G[{1}, yu^(-1)]*G[{yu}, yv^(-1)]^2*
      G[{0, 1/(yu*yv)}, yw] + 2*G[{1}, yv^(-1)]*G[{yu}, yv^(-1)]^2*
      G[{0, 1/(yu*yv)}, yw] - (4*G[{yu}, yv^(-1)]^3*G[{0, 1/(yu*yv)}, yw])/
      3 - G[{0}, yu^(-1)]*G[{0, 1}, yu^(-1)]*G[{0, 1/(yu*yv)}, yw] - 
     G[{0}, yv^(-1)]*G[{0, 1}, yu^(-1)]*G[{0, 1/(yu*yv)}, yw] + 
     G[{0}, yw]*G[{0, 1}, yu^(-1)]*G[{0, 1/(yu*yv)}, yw] + 
     2*G[{1}, yu^(-1)]*G[{0, 1}, yu^(-1)]*G[{0, 1/(yu*yv)}, yw] + 
     2*G[{1}, yv^(-1)]*G[{0, 1}, yu^(-1)]*G[{0, 1/(yu*yv)}, yw] - 
     2*G[{yu}, yv^(-1)]*G[{0, 1}, yu^(-1)]*G[{0, 1/(yu*yv)}, yw] - 
     G[{0}, yu^(-1)]*G[{0, 1}, yv^(-1)]*G[{0, 1/(yu*yv)}, yw] - 
     G[{0}, yv^(-1)]*G[{0, 1}, yv^(-1)]*G[{0, 1/(yu*yv)}, yw] + 
     G[{0}, yw]*G[{0, 1}, yv^(-1)]*G[{0, 1/(yu*yv)}, yw] + 
     2*G[{1}, yu^(-1)]*G[{0, 1}, yv^(-1)]*G[{0, 1/(yu*yv)}, yw] + 
     2*G[{1}, yv^(-1)]*G[{0, 1}, yv^(-1)]*G[{0, 1/(yu*yv)}, yw] - 
     2*G[{yu}, yv^(-1)]*G[{0, 1}, yv^(-1)]*G[{0, 1/(yu*yv)}, yw] - 
     G[{0}, yu^(-1)]*G[{0, 1}, yw]*G[{0, 1/(yu*yv)}, yw] - 
     G[{0}, yv^(-1)]*G[{0, 1}, yw]*G[{0, 1/(yu*yv)}, yw] + 
     G[{0}, yw]*G[{0, 1}, yw]*G[{0, 1/(yu*yv)}, yw] + 
     2*G[{yu}, yv^(-1)]*G[{0, 1}, yw]*G[{0, 1/(yu*yv)}, yw] + 
     G[{0}, yu^(-1)]*G[{0, yu^(-1)}, yw]*G[{0, 1/(yu*yv)}, yw] + 
     G[{0}, yv^(-1)]*G[{0, yu^(-1)}, yw]*G[{0, 1/(yu*yv)}, yw] - 
     G[{0}, yw]*G[{0, yu^(-1)}, yw]*G[{0, 1/(yu*yv)}, yw] - 
     2*G[{yu}, yv^(-1)]*G[{0, yu^(-1)}, yw]*G[{0, 1/(yu*yv)}, yw] + 
     G[{0}, yu^(-1)]*G[{0, yu}, yv^(-1)]*G[{0, 1/(yu*yv)}, yw] + 
     G[{0}, yv^(-1)]*G[{0, yu}, yv^(-1)]*G[{0, 1/(yu*yv)}, yw] - 
     G[{0}, yw]*G[{0, yu}, yv^(-1)]*G[{0, 1/(yu*yv)}, yw] - 
     2*G[{1}, yu^(-1)]*G[{0, yu}, yv^(-1)]*G[{0, 1/(yu*yv)}, yw] - 
     2*G[{1}, yv^(-1)]*G[{0, yu}, yv^(-1)]*G[{0, 1/(yu*yv)}, yw] + 
     2*G[{yu}, yv^(-1)]*G[{0, yu}, yv^(-1)]*G[{0, 1/(yu*yv)}, yw] + 
     G[{0}, yu^(-1)]*G[{0, yv^(-1)}, yw]*G[{0, 1/(yu*yv)}, yw] + 
     G[{0}, yv^(-1)]*G[{0, yv^(-1)}, yw]*G[{0, 1/(yu*yv)}, yw] - 
     G[{0}, yw]*G[{0, yv^(-1)}, yw]*G[{0, 1/(yu*yv)}, yw] - 
     2*G[{yu}, yv^(-1)]*G[{0, yv^(-1)}, yw]*G[{0, 1/(yu*yv)}, yw] - 
     (G[{0}, yu^(-1)]*G[{0, 1/(yu*yv)}, yw]^2)/2 - 
     (G[{0}, yv^(-1)]*G[{0, 1/(yu*yv)}, yw]^2)/2 + 
     (G[{0}, yw]*G[{0, 1/(yu*yv)}, yw]^2)/2 + G[{yu}, yv^(-1)]*
      G[{0, 1/(yu*yv)}, yw]^2 - 2*G[{1}, yu^(-1)]*G[{0, 1}, yw]*
      G[{1, yu}, yv^(-1)] + 2*G[{1}, yv^(-1)]*G[{0, 1}, yw]*
      G[{1, yu}, yv^(-1)] + 2*G[{1}, yu^(-1)]*G[{0, yu^(-1)}, yw]*
      G[{1, yu}, yv^(-1)] + 2*G[{1}, yv^(-1)]*G[{0, yu^(-1)}, yw]*
      G[{1, yu}, yv^(-1)] - 2*G[{1}, yu^(-1)]*G[{0, yv^(-1)}, yw]*
      G[{1, yu}, yv^(-1)] - 2*G[{1}, yv^(-1)]*G[{0, yv^(-1)}, yw]*
      G[{1, yu}, yv^(-1)] + 2*G[{1}, yu^(-1)]*G[{0, 1/(yu*yv)}, yw]*
      G[{1, yu}, yv^(-1)] - 2*G[{1}, yv^(-1)]*G[{0, 1/(yu*yv)}, yw]*
      G[{1, yu}, yv^(-1)] + (Pi^2*G[{0, 0, 1}, yw])/3 - 
     2*G[{0, 1}, yu^(-1)]*G[{0, 0, 1}, yw] - 2*G[{0, 1}, yv^(-1)]*
      G[{0, 0, 1}, yw] - 2*G[{0, 1}, yw]*G[{0, 0, 1}, yw] + 
     2*G[{0, yu^(-1)}, yw]*G[{0, 0, 1}, yw] + 2*G[{0, yu}, yv^(-1)]*
      G[{0, 0, 1}, yw] + 2*G[{0, yv^(-1)}, yw]*G[{0, 0, 1}, yw] - 
     2*G[{0, 1/(yu*yv)}, yw]*G[{0, 0, 1}, yw] - (Pi^2*G[{0, 0, yu^(-1)}, yw])/
      3 + 2*G[{0, 1}, yu^(-1)]*G[{0, 0, yu^(-1)}, yw] + 
     2*G[{0, 1}, yv^(-1)]*G[{0, 0, yu^(-1)}, yw] + 
     2*G[{0, 1}, yw]*G[{0, 0, yu^(-1)}, yw] - 2*G[{0, yu^(-1)}, yw]*
      G[{0, 0, yu^(-1)}, yw] - 2*G[{0, yu}, yv^(-1)]*G[{0, 0, yu^(-1)}, yw] - 
     2*G[{0, yv^(-1)}, yw]*G[{0, 0, yu^(-1)}, yw] + 
     2*G[{0, 1/(yu*yv)}, yw]*G[{0, 0, yu^(-1)}, yw] - 
     (Pi^2*G[{0, 0, yv^(-1)}, yw])/3 + 2*G[{0, 1}, yu^(-1)]*
      G[{0, 0, yv^(-1)}, yw] + 2*G[{0, 1}, yv^(-1)]*G[{0, 0, yv^(-1)}, yw] + 
     2*G[{0, 1}, yw]*G[{0, 0, yv^(-1)}, yw] - 2*G[{0, yu^(-1)}, yw]*
      G[{0, 0, yv^(-1)}, yw] - 2*G[{0, yu}, yv^(-1)]*G[{0, 0, yv^(-1)}, yw] - 
     2*G[{0, yv^(-1)}, yw]*G[{0, 0, yv^(-1)}, yw] + 
     2*G[{0, 1/(yu*yv)}, yw]*G[{0, 0, yv^(-1)}, yw] + 
     (Pi^2*G[{0, 0, 1/(yu*yv)}, yw])/3 - 2*G[{0, 1}, yu^(-1)]*
      G[{0, 0, 1/(yu*yv)}, yw] - 2*G[{0, 1}, yv^(-1)]*
      G[{0, 0, 1/(yu*yv)}, yw] - 2*G[{0, 1}, yw]*G[{0, 0, 1/(yu*yv)}, yw] + 
     2*G[{0, yu^(-1)}, yw]*G[{0, 0, 1/(yu*yv)}, yw] + 
     2*G[{0, yu}, yv^(-1)]*G[{0, 0, 1/(yu*yv)}, yw] + 
     2*G[{0, yv^(-1)}, yw]*G[{0, 0, 1/(yu*yv)}, yw] - 
     2*G[{0, 1/(yu*yv)}, yw]*G[{0, 0, 1/(yu*yv)}, yw] - 
     (Pi^2*G[{0, 1, 1}, yu^(-1)])/3 + 2*G[{0, 1}, yu^(-1)]*
      G[{0, 1, 1}, yu^(-1)] + 2*G[{0, 1}, yv^(-1)]*G[{0, 1, 1}, yu^(-1)] + 
     2*G[{0, 1}, yw]*G[{0, 1, 1}, yu^(-1)] - 2*G[{0, yu^(-1)}, yw]*
      G[{0, 1, 1}, yu^(-1)] - 2*G[{0, yu}, yv^(-1)]*G[{0, 1, 1}, yu^(-1)] + 
     2*G[{0, yv^(-1)}, yw]*G[{0, 1, 1}, yu^(-1)] - 2*G[{0, 1/(yu*yv)}, yw]*
      G[{0, 1, 1}, yu^(-1)] - (Pi^2*G[{0, 1, 1}, yv^(-1)])/3 - 
     2*G[{0}, yu^(-1)]*G[{1}, yu^(-1)]*G[{0, 1, 1}, yv^(-1)] - 
     2*G[{0}, yv^(-1)]*G[{1}, yu^(-1)]*G[{0, 1, 1}, yv^(-1)] + 
     2*G[{0}, yw]*G[{1}, yu^(-1)]*G[{0, 1, 1}, yv^(-1)] + 
     2*G[{1}, yu^(-1)]^2*G[{0, 1, 1}, yv^(-1)] + 2*G[{0, 1}, yu^(-1)]*
      G[{0, 1, 1}, yv^(-1)] + 2*G[{0, 1}, yv^(-1)]*G[{0, 1, 1}, yv^(-1)] + 
     2*G[{0, 1}, yw]*G[{0, 1, 1}, yv^(-1)] + 2*G[{0, yu^(-1)}, yw]*
      G[{0, 1, 1}, yv^(-1)] - 2*G[{0, yu}, yv^(-1)]*G[{0, 1, 1}, yv^(-1)] - 
     2*G[{0, yv^(-1)}, yw]*G[{0, 1, 1}, yv^(-1)] - 2*G[{0, 1/(yu*yv)}, yw]*
      G[{0, 1, 1}, yv^(-1)] + (Pi^2*G[{0, 1, 1}, yw])/3 + 
     2*G[{0}, yu^(-1)]*G[{1}, yu^(-1)]*G[{0, 1, 1}, yw] + 
     2*G[{0}, yv^(-1)]*G[{1}, yu^(-1)]*G[{0, 1, 1}, yw] - 
     2*G[{0}, yw]*G[{1}, yu^(-1)]*G[{0, 1, 1}, yw] - 
     2*G[{1}, yu^(-1)]^2*G[{0, 1, 1}, yw] + 2*G[{0}, yu^(-1)]*G[{1}, yv^(-1)]*
      G[{0, 1, 1}, yw] + 2*G[{0}, yv^(-1)]*G[{1}, yv^(-1)]*G[{0, 1, 1}, yw] - 
     2*G[{0}, yw]*G[{1}, yv^(-1)]*G[{0, 1, 1}, yw] - 
     6*G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*G[{0, 1, 1}, yw] - 
     2*G[{1}, yv^(-1)]^2*G[{0, 1, 1}, yw] - 4*G[{0}, yu^(-1)]*
      G[{yu}, yv^(-1)]*G[{0, 1, 1}, yw] - 4*G[{0}, yv^(-1)]*G[{yu}, yv^(-1)]*
      G[{0, 1, 1}, yw] + 4*G[{0}, yw]*G[{yu}, yv^(-1)]*G[{0, 1, 1}, yw] + 
     6*G[{1}, yu^(-1)]*G[{yu}, yv^(-1)]*G[{0, 1, 1}, yw] + 
     6*G[{1}, yv^(-1)]*G[{yu}, yv^(-1)]*G[{0, 1, 1}, yw] - 
     2*G[{yu}, yv^(-1)]^2*G[{0, 1, 1}, yw] - 2*G[{0, 1}, yu^(-1)]*
      G[{0, 1, 1}, yw] - 2*G[{0, 1}, yv^(-1)]*G[{0, 1, 1}, yw] + 
     2*G[{0, 1}, yw]*G[{0, 1, 1}, yw] + 2*G[{0, yu}, yv^(-1)]*
      G[{0, 1, 1}, yw] - 2*G[{0}, yu^(-1)]*G[{1}, yu^(-1)]*
      G[{0, 1, yu^(-1)}, yw] - 2*G[{0}, yv^(-1)]*G[{1}, yu^(-1)]*
      G[{0, 1, yu^(-1)}, yw] + 2*G[{0}, yw]*G[{1}, yu^(-1)]*
      G[{0, 1, yu^(-1)}, yw] + 2*G[{1}, yu^(-1)]^2*G[{0, 1, yu^(-1)}, yw] + 
     4*G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*G[{0, 1, yu^(-1)}, yw] + 
     2*G[{0}, yu^(-1)]*G[{yu}, yv^(-1)]*G[{0, 1, yu^(-1)}, yw] + 
     2*G[{0}, yv^(-1)]*G[{yu}, yv^(-1)]*G[{0, 1, yu^(-1)}, yw] - 
     2*G[{0}, yw]*G[{yu}, yv^(-1)]*G[{0, 1, yu^(-1)}, yw] - 
     4*G[{1}, yu^(-1)]*G[{yu}, yv^(-1)]*G[{0, 1, yu^(-1)}, yw] - 
     4*G[{1}, yv^(-1)]*G[{yu}, yv^(-1)]*G[{0, 1, yu^(-1)}, yw] + 
     2*G[{yu}, yv^(-1)]^2*G[{0, 1, yu^(-1)}, yw] + 2*G[{0, yu^(-1)}, yw]*
      G[{0, 1, yu^(-1)}, yw] + 2*G[{0, yv^(-1)}, yw]*G[{0, 1, yu^(-1)}, yw] - 
     2*G[{0, 1/(yu*yv)}, yw]*G[{0, 1, yu^(-1)}, yw] + 
     2*G[{0}, yu^(-1)]*G[{1}, yu^(-1)]*G[{0, 1, yu}, yv^(-1)] + 
     2*G[{0}, yv^(-1)]*G[{1}, yu^(-1)]*G[{0, 1, yu}, yv^(-1)] - 
     2*G[{0}, yw]*G[{1}, yu^(-1)]*G[{0, 1, yu}, yv^(-1)] - 
     2*G[{1}, yu^(-1)]^2*G[{0, 1, yu}, yv^(-1)] - 
     2*G[{0, 1}, yw]*G[{0, 1, yu}, yv^(-1)] - 2*G[{0, yu^(-1)}, yw]*
      G[{0, 1, yu}, yv^(-1)] + 2*G[{0, yu}, yv^(-1)]*G[{0, 1, yu}, yv^(-1)] + 
     2*G[{0, yv^(-1)}, yw]*G[{0, 1, yu}, yv^(-1)] + 
     2*G[{0, 1/(yu*yv)}, yw]*G[{0, 1, yu}, yv^(-1)] - 
     2*G[{0}, yu^(-1)]*G[{1}, yv^(-1)]*G[{0, 1, yv^(-1)}, yw] - 
     2*G[{0}, yv^(-1)]*G[{1}, yv^(-1)]*G[{0, 1, yv^(-1)}, yw] + 
     2*G[{0}, yw]*G[{1}, yv^(-1)]*G[{0, 1, yv^(-1)}, yw] + 
     4*G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*G[{0, 1, yv^(-1)}, yw] + 
     2*G[{1}, yv^(-1)]^2*G[{0, 1, yv^(-1)}, yw] + 
     2*G[{0}, yu^(-1)]*G[{yu}, yv^(-1)]*G[{0, 1, yv^(-1)}, yw] + 
     2*G[{0}, yv^(-1)]*G[{yu}, yv^(-1)]*G[{0, 1, yv^(-1)}, yw] - 
     2*G[{0}, yw]*G[{yu}, yv^(-1)]*G[{0, 1, yv^(-1)}, yw] - 
     4*G[{1}, yu^(-1)]*G[{yu}, yv^(-1)]*G[{0, 1, yv^(-1)}, yw] - 
     4*G[{1}, yv^(-1)]*G[{yu}, yv^(-1)]*G[{0, 1, yv^(-1)}, yw] + 
     2*G[{yu}, yv^(-1)]^2*G[{0, 1, yv^(-1)}, yw] + 2*G[{0, yu^(-1)}, yw]*
      G[{0, 1, yv^(-1)}, yw] + 2*G[{0, yv^(-1)}, yw]*G[{0, 1, yv^(-1)}, yw] - 
     2*G[{0, 1/(yu*yv)}, yw]*G[{0, 1, yv^(-1)}, yw] - 
     2*G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*G[{0, 1, 1/(yu*yv)}, yw] + 
     2*G[{1}, yu^(-1)]*G[{yu}, yv^(-1)]*G[{0, 1, 1/(yu*yv)}, yw] + 
     2*G[{1}, yv^(-1)]*G[{yu}, yv^(-1)]*G[{0, 1, 1/(yu*yv)}, yw] - 
     2*G[{yu}, yv^(-1)]^2*G[{0, 1, 1/(yu*yv)}, yw] - 
     2*G[{0}, yu^(-1)]*G[{1}, yu^(-1)]*G[{0, yu^(-1), 1}, yw] - 
     2*G[{0}, yv^(-1)]*G[{1}, yu^(-1)]*G[{0, yu^(-1), 1}, yw] + 
     2*G[{0}, yw]*G[{1}, yu^(-1)]*G[{0, yu^(-1), 1}, yw] + 
     2*G[{1}, yu^(-1)]^2*G[{0, yu^(-1), 1}, yw] + 
     2*G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*G[{0, yu^(-1), 1}, yw] + 
     2*G[{0}, yu^(-1)]*G[{yu}, yv^(-1)]*G[{0, yu^(-1), 1}, yw] + 
     2*G[{0}, yv^(-1)]*G[{yu}, yv^(-1)]*G[{0, yu^(-1), 1}, yw] - 
     2*G[{0}, yw]*G[{yu}, yv^(-1)]*G[{0, yu^(-1), 1}, yw] - 
     2*G[{1}, yu^(-1)]*G[{yu}, yv^(-1)]*G[{0, yu^(-1), 1}, yw] - 
     2*G[{1}, yv^(-1)]*G[{yu}, yv^(-1)]*G[{0, yu^(-1), 1}, yw] - 
     (Pi^2*G[{0, yu^(-1), yu^(-1)}, yw])/3 + 2*G[{0}, yu^(-1)]*
      G[{1}, yu^(-1)]*G[{0, yu^(-1), yu^(-1)}, yw] + 
     2*G[{0}, yv^(-1)]*G[{1}, yu^(-1)]*G[{0, yu^(-1), yu^(-1)}, yw] - 
     2*G[{0}, yw]*G[{1}, yu^(-1)]*G[{0, yu^(-1), yu^(-1)}, yw] - 
     2*G[{1}, yu^(-1)]^2*G[{0, yu^(-1), yu^(-1)}, yw] - 
     2*G[{0}, yu^(-1)]*G[{1}, yv^(-1)]*G[{0, yu^(-1), yu^(-1)}, yw] - 
     2*G[{0}, yv^(-1)]*G[{1}, yv^(-1)]*G[{0, yu^(-1), yu^(-1)}, yw] + 
     2*G[{0}, yw]*G[{1}, yv^(-1)]*G[{0, yu^(-1), yu^(-1)}, yw] + 
     2*G[{1}, yv^(-1)]^2*G[{0, yu^(-1), yu^(-1)}, yw] + 
     2*G[{0, 1}, yu^(-1)]*G[{0, yu^(-1), yu^(-1)}, yw] + 
     2*G[{0, 1}, yv^(-1)]*G[{0, yu^(-1), yu^(-1)}, yw] - 
     2*G[{0, 1}, yw]*G[{0, yu^(-1), yu^(-1)}, yw] + 
     2*G[{0, yu^(-1)}, yw]*G[{0, yu^(-1), yu^(-1)}, yw] - 
     2*G[{0, yu}, yv^(-1)]*G[{0, yu^(-1), yu^(-1)}, yw] - 
     2*G[{0, yv^(-1)}, yw]*G[{0, yu^(-1), yu^(-1)}, yw] + 
     2*G[{0, 1/(yu*yv)}, yw]*G[{0, yu^(-1), yu^(-1)}, yw] - 
     2*G[{0, yv^(-1)}, yw]*G[{0, yu^(-1), yv^(-1)}, yw] + 
     2*G[{0, 1/(yu*yv)}, yw]*G[{0, yu^(-1), yv^(-1)}, yw] + 
     2*G[{0}, yu^(-1)]*G[{1}, yv^(-1)]*G[{0, yu^(-1), 1/(yu*yv)}, yw] + 
     2*G[{0}, yv^(-1)]*G[{1}, yv^(-1)]*G[{0, yu^(-1), 1/(yu*yv)}, yw] - 
     2*G[{0}, yw]*G[{1}, yv^(-1)]*G[{0, yu^(-1), 1/(yu*yv)}, yw] - 
     2*G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*G[{0, yu^(-1), 1/(yu*yv)}, yw] - 
     2*G[{1}, yv^(-1)]^2*G[{0, yu^(-1), 1/(yu*yv)}, yw] - 
     2*G[{0}, yu^(-1)]*G[{yu}, yv^(-1)]*G[{0, yu^(-1), 1/(yu*yv)}, yw] - 
     2*G[{0}, yv^(-1)]*G[{yu}, yv^(-1)]*G[{0, yu^(-1), 1/(yu*yv)}, yw] + 
     2*G[{0}, yw]*G[{yu}, yv^(-1)]*G[{0, yu^(-1), 1/(yu*yv)}, yw] + 
     2*G[{1}, yu^(-1)]*G[{yu}, yv^(-1)]*G[{0, yu^(-1), 1/(yu*yv)}, yw] + 
     2*G[{1}, yv^(-1)]*G[{yu}, yv^(-1)]*G[{0, yu^(-1), 1/(yu*yv)}, yw] - 
     2*G[{0, yv^(-1)}, yw]*G[{0, yu^(-1), 1/(yu*yv)}, yw] + 
     2*G[{0}, yu^(-1)]*G[{1}, yu^(-1)]*G[{0, yu, 1}, yv^(-1)] + 
     2*G[{0}, yv^(-1)]*G[{1}, yu^(-1)]*G[{0, yu, 1}, yv^(-1)] - 
     2*G[{0}, yw]*G[{1}, yu^(-1)]*G[{0, yu, 1}, yv^(-1)] - 
     2*G[{1}, yu^(-1)]^2*G[{0, yu, 1}, yv^(-1)] - 
     2*G[{0, 1}, yw]*G[{0, yu, 1}, yv^(-1)] - 2*G[{0, yu^(-1)}, yw]*
      G[{0, yu, 1}, yv^(-1)] + 2*G[{0, yv^(-1)}, yw]*G[{0, yu, 1}, yv^(-1)] + 
     2*G[{0, 1/(yu*yv)}, yw]*G[{0, yu, 1}, yv^(-1)] + 
     (Pi^2*G[{0, yu, yu}, yv^(-1)])/3 - 2*G[{0}, yu^(-1)]*G[{1}, yu^(-1)]*
      G[{0, yu, yu}, yv^(-1)] - 2*G[{0}, yv^(-1)]*G[{1}, yu^(-1)]*
      G[{0, yu, yu}, yv^(-1)] + 2*G[{0}, yw]*G[{1}, yu^(-1)]*
      G[{0, yu, yu}, yv^(-1)] + 2*G[{1}, yu^(-1)]^2*G[{0, yu, yu}, yv^(-1)] - 
     2*G[{0, 1}, yu^(-1)]*G[{0, yu, yu}, yv^(-1)] - 
     2*G[{0, 1}, yv^(-1)]*G[{0, yu, yu}, yv^(-1)] + 
     2*G[{0, 1}, yw]*G[{0, yu, yu}, yv^(-1)] + 2*G[{0, yu^(-1)}, yw]*
      G[{0, yu, yu}, yv^(-1)] + 2*G[{0, yu}, yv^(-1)]*
      G[{0, yu, yu}, yv^(-1)] - 2*G[{0, yv^(-1)}, yw]*
      G[{0, yu, yu}, yv^(-1)] - 2*G[{0, 1/(yu*yv)}, yw]*
      G[{0, yu, yu}, yv^(-1)] - 2*G[{0}, yu^(-1)]*G[{1}, yv^(-1)]*
      G[{0, yv^(-1), 1}, yw] - 2*G[{0}, yv^(-1)]*G[{1}, yv^(-1)]*
      G[{0, yv^(-1), 1}, yw] + 2*G[{0}, yw]*G[{1}, yv^(-1)]*
      G[{0, yv^(-1), 1}, yw] + 2*G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*
      G[{0, yv^(-1), 1}, yw] + 2*G[{1}, yv^(-1)]^2*G[{0, yv^(-1), 1}, yw] + 
     2*G[{0}, yu^(-1)]*G[{yu}, yv^(-1)]*G[{0, yv^(-1), 1}, yw] + 
     2*G[{0}, yv^(-1)]*G[{yu}, yv^(-1)]*G[{0, yv^(-1), 1}, yw] - 
     2*G[{0}, yw]*G[{yu}, yv^(-1)]*G[{0, yv^(-1), 1}, yw] - 
     2*G[{1}, yu^(-1)]*G[{yu}, yv^(-1)]*G[{0, yv^(-1), 1}, yw] - 
     2*G[{1}, yv^(-1)]*G[{yu}, yv^(-1)]*G[{0, yv^(-1), 1}, yw] + 
     2*G[{0, 1/(yu*yv)}, yw]*G[{0, yv^(-1), yu^(-1)}, yw] - 
     (Pi^2*G[{0, yv^(-1), yv^(-1)}, yw])/3 - 2*G[{0}, yu^(-1)]*
      G[{1}, yu^(-1)]*G[{0, yv^(-1), yv^(-1)}, yw] - 
     2*G[{0}, yv^(-1)]*G[{1}, yu^(-1)]*G[{0, yv^(-1), yv^(-1)}, yw] + 
     2*G[{0}, yw]*G[{1}, yu^(-1)]*G[{0, yv^(-1), yv^(-1)}, yw] + 
     2*G[{1}, yu^(-1)]^2*G[{0, yv^(-1), yv^(-1)}, yw] + 
     2*G[{0}, yu^(-1)]*G[{1}, yv^(-1)]*G[{0, yv^(-1), yv^(-1)}, yw] + 
     2*G[{0}, yv^(-1)]*G[{1}, yv^(-1)]*G[{0, yv^(-1), yv^(-1)}, yw] - 
     2*G[{0}, yw]*G[{1}, yv^(-1)]*G[{0, yv^(-1), yv^(-1)}, yw] - 
     2*G[{1}, yv^(-1)]^2*G[{0, yv^(-1), yv^(-1)}, yw] + 
     2*G[{0, 1}, yu^(-1)]*G[{0, yv^(-1), yv^(-1)}, yw] + 
     2*G[{0, 1}, yv^(-1)]*G[{0, yv^(-1), yv^(-1)}, yw] - 
     2*G[{0, 1}, yw]*G[{0, yv^(-1), yv^(-1)}, yw] + 
     2*G[{0, yu^(-1)}, yw]*G[{0, yv^(-1), yv^(-1)}, yw] - 
     2*G[{0, yu}, yv^(-1)]*G[{0, yv^(-1), yv^(-1)}, yw] + 
     2*G[{0, yv^(-1)}, yw]*G[{0, yv^(-1), yv^(-1)}, yw] + 
     2*G[{0, 1/(yu*yv)}, yw]*G[{0, yv^(-1), yv^(-1)}, yw] + 
     2*G[{0}, yu^(-1)]*G[{1}, yu^(-1)]*G[{0, yv^(-1), 1/(yu*yv)}, yw] + 
     2*G[{0}, yv^(-1)]*G[{1}, yu^(-1)]*G[{0, yv^(-1), 1/(yu*yv)}, yw] - 
     2*G[{0}, yw]*G[{1}, yu^(-1)]*G[{0, yv^(-1), 1/(yu*yv)}, yw] - 
     2*G[{1}, yu^(-1)]^2*G[{0, yv^(-1), 1/(yu*yv)}, yw] - 
     2*G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*G[{0, yv^(-1), 1/(yu*yv)}, yw] - 
     2*G[{0}, yu^(-1)]*G[{yu}, yv^(-1)]*G[{0, yv^(-1), 1/(yu*yv)}, yw] - 
     2*G[{0}, yv^(-1)]*G[{yu}, yv^(-1)]*G[{0, yv^(-1), 1/(yu*yv)}, yw] + 
     2*G[{0}, yw]*G[{yu}, yv^(-1)]*G[{0, yv^(-1), 1/(yu*yv)}, yw] + 
     2*G[{1}, yu^(-1)]*G[{yu}, yv^(-1)]*G[{0, yv^(-1), 1/(yu*yv)}, yw] + 
     2*G[{1}, yv^(-1)]*G[{yu}, yv^(-1)]*G[{0, yv^(-1), 1/(yu*yv)}, yw] - 
     (Pi^2*G[{0, 1/(yu*yv), 1}, yw])/3 + 2*G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*
      G[{0, 1/(yu*yv), 1}, yw] - 2*G[{1}, yu^(-1)]*G[{yu}, yv^(-1)]*
      G[{0, 1/(yu*yv), 1}, yw] - 2*G[{1}, yv^(-1)]*G[{yu}, yv^(-1)]*
      G[{0, 1/(yu*yv), 1}, yw] + 2*G[{yu}, yv^(-1)]^2*
      G[{0, 1/(yu*yv), 1}, yw] + 2*G[{0, 1}, yu^(-1)]*
      G[{0, 1/(yu*yv), 1}, yw] + 2*G[{0, 1}, yv^(-1)]*
      G[{0, 1/(yu*yv), 1}, yw] - 2*G[{0, 1}, yw]*G[{0, 1/(yu*yv), 1}, yw] + 
     2*G[{0, yu^(-1)}, yw]*G[{0, 1/(yu*yv), 1}, yw] - 
     2*G[{0, yu}, yv^(-1)]*G[{0, 1/(yu*yv), 1}, yw] + 
     2*G[{0, yv^(-1)}, yw]*G[{0, 1/(yu*yv), 1}, yw] - 
     2*G[{0, 1/(yu*yv)}, yw]*G[{0, 1/(yu*yv), 1}, yw] + 
     (Pi^2*G[{0, 1/(yu*yv), yu^(-1)}, yw])/3 + 2*G[{0}, yu^(-1)]*
      G[{1}, yv^(-1)]*G[{0, 1/(yu*yv), yu^(-1)}, yw] + 
     2*G[{0}, yv^(-1)]*G[{1}, yv^(-1)]*G[{0, 1/(yu*yv), yu^(-1)}, yw] - 
     2*G[{0}, yw]*G[{1}, yv^(-1)]*G[{0, 1/(yu*yv), yu^(-1)}, yw] - 
     4*G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*G[{0, 1/(yu*yv), yu^(-1)}, yw] - 
     2*G[{1}, yv^(-1)]^2*G[{0, 1/(yu*yv), yu^(-1)}, yw] - 
     2*G[{0}, yu^(-1)]*G[{yu}, yv^(-1)]*G[{0, 1/(yu*yv), yu^(-1)}, yw] - 
     2*G[{0}, yv^(-1)]*G[{yu}, yv^(-1)]*G[{0, 1/(yu*yv), yu^(-1)}, yw] + 
     2*G[{0}, yw]*G[{yu}, yv^(-1)]*G[{0, 1/(yu*yv), yu^(-1)}, yw] + 
     4*G[{1}, yu^(-1)]*G[{yu}, yv^(-1)]*G[{0, 1/(yu*yv), yu^(-1)}, yw] + 
     4*G[{1}, yv^(-1)]*G[{yu}, yv^(-1)]*G[{0, 1/(yu*yv), yu^(-1)}, yw] - 
     2*G[{yu}, yv^(-1)]^2*G[{0, 1/(yu*yv), yu^(-1)}, yw] - 
     2*G[{0, 1}, yu^(-1)]*G[{0, 1/(yu*yv), yu^(-1)}, yw] - 
     2*G[{0, 1}, yv^(-1)]*G[{0, 1/(yu*yv), yu^(-1)}, yw] + 
     2*G[{0, 1}, yw]*G[{0, 1/(yu*yv), yu^(-1)}, yw] - 
     2*G[{0, yu^(-1)}, yw]*G[{0, 1/(yu*yv), yu^(-1)}, yw] + 
     2*G[{0, yu}, yv^(-1)]*G[{0, 1/(yu*yv), yu^(-1)}, yw] - 
     2*G[{0, yv^(-1)}, yw]*G[{0, 1/(yu*yv), yu^(-1)}, yw] + 
     2*G[{0, 1/(yu*yv)}, yw]*G[{0, 1/(yu*yv), yu^(-1)}, yw] + 
     (Pi^2*G[{0, 1/(yu*yv), yv^(-1)}, yw])/3 + 2*G[{0}, yu^(-1)]*
      G[{1}, yu^(-1)]*G[{0, 1/(yu*yv), yv^(-1)}, yw] + 
     2*G[{0}, yv^(-1)]*G[{1}, yu^(-1)]*G[{0, 1/(yu*yv), yv^(-1)}, yw] - 
     2*G[{0}, yw]*G[{1}, yu^(-1)]*G[{0, 1/(yu*yv), yv^(-1)}, yw] - 
     2*G[{1}, yu^(-1)]^2*G[{0, 1/(yu*yv), yv^(-1)}, yw] - 
     4*G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*G[{0, 1/(yu*yv), yv^(-1)}, yw] - 
     2*G[{0}, yu^(-1)]*G[{yu}, yv^(-1)]*G[{0, 1/(yu*yv), yv^(-1)}, yw] - 
     2*G[{0}, yv^(-1)]*G[{yu}, yv^(-1)]*G[{0, 1/(yu*yv), yv^(-1)}, yw] + 
     2*G[{0}, yw]*G[{yu}, yv^(-1)]*G[{0, 1/(yu*yv), yv^(-1)}, yw] + 
     4*G[{1}, yu^(-1)]*G[{yu}, yv^(-1)]*G[{0, 1/(yu*yv), yv^(-1)}, yw] + 
     4*G[{1}, yv^(-1)]*G[{yu}, yv^(-1)]*G[{0, 1/(yu*yv), yv^(-1)}, yw] - 
     2*G[{yu}, yv^(-1)]^2*G[{0, 1/(yu*yv), yv^(-1)}, yw] - 
     2*G[{0, 1}, yu^(-1)]*G[{0, 1/(yu*yv), yv^(-1)}, yw] - 
     2*G[{0, 1}, yv^(-1)]*G[{0, 1/(yu*yv), yv^(-1)}, yw] + 
     2*G[{0, 1}, yw]*G[{0, 1/(yu*yv), yv^(-1)}, yw] - 
     2*G[{0, yu^(-1)}, yw]*G[{0, 1/(yu*yv), yv^(-1)}, yw] + 
     2*G[{0, yu}, yv^(-1)]*G[{0, 1/(yu*yv), yv^(-1)}, yw] - 
     2*G[{0, yv^(-1)}, yw]*G[{0, 1/(yu*yv), yv^(-1)}, yw] + 
     2*G[{0, 1/(yu*yv)}, yw]*G[{0, 1/(yu*yv), yv^(-1)}, yw] - 
     2*G[{0}, yu^(-1)]*G[{1}, yu^(-1)]*G[{0, 1/(yu*yv), 1/(yu*yv)}, yw] - 
     2*G[{0}, yv^(-1)]*G[{1}, yu^(-1)]*G[{0, 1/(yu*yv), 1/(yu*yv)}, yw] + 
     2*G[{0}, yw]*G[{1}, yu^(-1)]*G[{0, 1/(yu*yv), 1/(yu*yv)}, yw] + 
     2*G[{1}, yu^(-1)]^2*G[{0, 1/(yu*yv), 1/(yu*yv)}, yw] - 
     2*G[{0}, yu^(-1)]*G[{1}, yv^(-1)]*G[{0, 1/(yu*yv), 1/(yu*yv)}, yw] - 
     2*G[{0}, yv^(-1)]*G[{1}, yv^(-1)]*G[{0, 1/(yu*yv), 1/(yu*yv)}, yw] + 
     2*G[{0}, yw]*G[{1}, yv^(-1)]*G[{0, 1/(yu*yv), 1/(yu*yv)}, yw] + 
     6*G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*G[{0, 1/(yu*yv), 1/(yu*yv)}, yw] + 
     2*G[{1}, yv^(-1)]^2*G[{0, 1/(yu*yv), 1/(yu*yv)}, yw] + 
     4*G[{0}, yu^(-1)]*G[{yu}, yv^(-1)]*G[{0, 1/(yu*yv), 1/(yu*yv)}, yw] + 
     4*G[{0}, yv^(-1)]*G[{yu}, yv^(-1)]*G[{0, 1/(yu*yv), 1/(yu*yv)}, yw] - 
     4*G[{0}, yw]*G[{yu}, yv^(-1)]*G[{0, 1/(yu*yv), 1/(yu*yv)}, yw] - 
     6*G[{1}, yu^(-1)]*G[{yu}, yv^(-1)]*G[{0, 1/(yu*yv), 1/(yu*yv)}, yw] - 
     6*G[{1}, yv^(-1)]*G[{yu}, yv^(-1)]*G[{0, 1/(yu*yv), 1/(yu*yv)}, yw] + 
     2*G[{yu}, yv^(-1)]^2*G[{0, 1/(yu*yv), 1/(yu*yv)}, yw] - 
     2*G[{0, 1}, yw]*G[{1, 1, yu}, yv^(-1)] - 2*G[{0, yu^(-1)}, yw]*
      G[{1, 1, yu}, yv^(-1)] + 2*G[{0, yv^(-1)}, yw]*G[{1, 1, yu}, yv^(-1)] + 
     2*G[{0, 1/(yu*yv)}, yw]*G[{1, 1, yu}, yv^(-1)] - 
     4*G[{0, yu^(-1)}, yw]*G[{1, yu, yu}, yv^(-1)] + 
     4*G[{0, yv^(-1)}, yw]*G[{1, yu, yu}, yv^(-1)] + 
     2*G[{0}, yu^(-1)]*G[{0, 0, 1, 1}, yu^(-1)] + 
     2*G[{0}, yv^(-1)]*G[{0, 0, 1, 1}, yu^(-1)] - 
     2*G[{0}, yw]*G[{0, 0, 1, 1}, yu^(-1)] + 2*G[{0}, yu^(-1)]*
      G[{0, 0, 1, 1}, yv^(-1)] + 2*G[{0}, yv^(-1)]*G[{0, 0, 1, 1}, yv^(-1)] - 
     2*G[{0}, yw]*G[{0, 0, 1, 1}, yv^(-1)] + 2*G[{0}, yu^(-1)]*
      G[{0, 0, 1, 1}, yw] + 2*G[{0}, yv^(-1)]*G[{0, 0, 1, 1}, yw] - 
     2*G[{0}, yw]*G[{0, 0, 1, 1}, yw] - 4*G[{yu}, yv^(-1)]*
      G[{0, 0, 1, 1}, yw] - 2*G[{0}, yu^(-1)]*G[{0, 0, 1, yu^(-1)}, yw] - 
     2*G[{0}, yv^(-1)]*G[{0, 0, 1, yu^(-1)}, yw] + 
     2*G[{0}, yw]*G[{0, 0, 1, yu^(-1)}, yw] + 4*G[{yu}, yv^(-1)]*
      G[{0, 0, 1, yu^(-1)}, yw] - 2*G[{0}, yu^(-1)]*
      G[{0, 0, 1, yu}, yv^(-1)] - 2*G[{0}, yv^(-1)]*
      G[{0, 0, 1, yu}, yv^(-1)] + 2*G[{0}, yw]*G[{0, 0, 1, yu}, yv^(-1)] - 
     2*G[{0}, yu^(-1)]*G[{0, 0, 1, yv^(-1)}, yw] - 
     2*G[{0}, yv^(-1)]*G[{0, 0, 1, yv^(-1)}, yw] + 
     2*G[{0}, yw]*G[{0, 0, 1, yv^(-1)}, yw] + 4*G[{yu}, yv^(-1)]*
      G[{0, 0, 1, yv^(-1)}, yw] + 2*G[{0}, yu^(-1)]*G[{0, 0, 1, 1/(yu*yv)}, 
       yw] + 2*G[{0}, yv^(-1)]*G[{0, 0, 1, 1/(yu*yv)}, yw] - 
     2*G[{0}, yw]*G[{0, 0, 1, 1/(yu*yv)}, yw] - 4*G[{yu}, yv^(-1)]*
      G[{0, 0, 1, 1/(yu*yv)}, yw] - 2*G[{0}, yu^(-1)]*
      G[{0, 0, yu^(-1), 1}, yw] - 2*G[{0}, yv^(-1)]*G[{0, 0, yu^(-1), 1}, 
       yw] + 2*G[{0}, yw]*G[{0, 0, yu^(-1), 1}, yw] + 
     4*G[{yu}, yv^(-1)]*G[{0, 0, yu^(-1), 1}, yw] + 
     2*G[{0}, yu^(-1)]*G[{0, 0, yu^(-1), yu^(-1)}, yw] + 
     2*G[{0}, yv^(-1)]*G[{0, 0, yu^(-1), yu^(-1)}, yw] - 
     2*G[{0}, yw]*G[{0, 0, yu^(-1), yu^(-1)}, yw] - 
     4*G[{1}, yv^(-1)]*G[{0, 0, yu^(-1), yu^(-1)}, yw] + 
     2*G[{0}, yu^(-1)]*G[{0, 0, yu^(-1), yv^(-1)}, yw] + 
     2*G[{0}, yv^(-1)]*G[{0, 0, yu^(-1), yv^(-1)}, yw] - 
     2*G[{0}, yw]*G[{0, 0, yu^(-1), yv^(-1)}, yw] - 
     4*G[{1}, yv^(-1)]*G[{0, 0, yu^(-1), yv^(-1)}, yw] - 
     2*G[{0}, yu^(-1)]*G[{0, 0, yu^(-1), 1/(yu*yv)}, yw] - 
     2*G[{0}, yv^(-1)]*G[{0, 0, yu^(-1), 1/(yu*yv)}, yw] + 
     2*G[{0}, yw]*G[{0, 0, yu^(-1), 1/(yu*yv)}, yw] + 
     4*G[{1}, yv^(-1)]*G[{0, 0, yu^(-1), 1/(yu*yv)}, yw] - 
     2*G[{0}, yu^(-1)]*G[{0, 0, yu, 1}, yv^(-1)] - 
     2*G[{0}, yv^(-1)]*G[{0, 0, yu, 1}, yv^(-1)] + 
     2*G[{0}, yw]*G[{0, 0, yu, 1}, yv^(-1)] + 2*G[{0}, yu^(-1)]*
      G[{0, 0, yu, yu}, yv^(-1)] + 2*G[{0}, yv^(-1)]*
      G[{0, 0, yu, yu}, yv^(-1)] - 2*G[{0}, yw]*G[{0, 0, yu, yu}, yv^(-1)] - 
     2*G[{0}, yu^(-1)]*G[{0, 0, yv^(-1), 1}, yw] - 
     2*G[{0}, yv^(-1)]*G[{0, 0, yv^(-1), 1}, yw] + 
     2*G[{0}, yw]*G[{0, 0, yv^(-1), 1}, yw] + 4*G[{yu}, yv^(-1)]*
      G[{0, 0, yv^(-1), 1}, yw] + 2*G[{0}, yu^(-1)]*
      G[{0, 0, yv^(-1), yu^(-1)}, yw] + 2*G[{0}, yv^(-1)]*
      G[{0, 0, yv^(-1), yu^(-1)}, yw] - 2*G[{0}, yw]*
      G[{0, 0, yv^(-1), yu^(-1)}, yw] - 4*G[{1}, yv^(-1)]*
      G[{0, 0, yv^(-1), yu^(-1)}, yw] + 2*G[{0}, yu^(-1)]*
      G[{0, 0, yv^(-1), yv^(-1)}, yw] + 2*G[{0}, yv^(-1)]*
      G[{0, 0, yv^(-1), yv^(-1)}, yw] - 2*G[{0}, yw]*
      G[{0, 0, yv^(-1), yv^(-1)}, yw] - 4*G[{1}, yu^(-1)]*
      G[{0, 0, yv^(-1), yv^(-1)}, yw] - 2*G[{0}, yu^(-1)]*
      G[{0, 0, yv^(-1), 1/(yu*yv)}, yw] - 2*G[{0}, yv^(-1)]*
      G[{0, 0, yv^(-1), 1/(yu*yv)}, yw] + 2*G[{0}, yw]*
      G[{0, 0, yv^(-1), 1/(yu*yv)}, yw] + 4*G[{1}, yu^(-1)]*
      G[{0, 0, yv^(-1), 1/(yu*yv)}, yw] + 2*G[{0}, yu^(-1)]*
      G[{0, 0, 1/(yu*yv), 1}, yw] + 2*G[{0}, yv^(-1)]*
      G[{0, 0, 1/(yu*yv), 1}, yw] - 2*G[{0}, yw]*G[{0, 0, 1/(yu*yv), 1}, 
       yw] - 4*G[{yu}, yv^(-1)]*G[{0, 0, 1/(yu*yv), 1}, yw] - 
     2*G[{0}, yu^(-1)]*G[{0, 0, 1/(yu*yv), yu^(-1)}, yw] - 
     2*G[{0}, yv^(-1)]*G[{0, 0, 1/(yu*yv), yu^(-1)}, yw] + 
     2*G[{0}, yw]*G[{0, 0, 1/(yu*yv), yu^(-1)}, yw] + 
     4*G[{1}, yv^(-1)]*G[{0, 0, 1/(yu*yv), yu^(-1)}, yw] - 
     2*G[{0}, yu^(-1)]*G[{0, 0, 1/(yu*yv), yv^(-1)}, yw] - 
     2*G[{0}, yv^(-1)]*G[{0, 0, 1/(yu*yv), yv^(-1)}, yw] + 
     2*G[{0}, yw]*G[{0, 0, 1/(yu*yv), yv^(-1)}, yw] + 
     4*G[{1}, yu^(-1)]*G[{0, 0, 1/(yu*yv), yv^(-1)}, yw] + 
     2*G[{0}, yu^(-1)]*G[{0, 0, 1/(yu*yv), 1/(yu*yv)}, yw] + 
     2*G[{0}, yv^(-1)]*G[{0, 0, 1/(yu*yv), 1/(yu*yv)}, yw] - 
     2*G[{0}, yw]*G[{0, 0, 1/(yu*yv), 1/(yu*yv)}, yw] - 
     4*G[{1}, yu^(-1)]*G[{0, 0, 1/(yu*yv), 1/(yu*yv)}, yw] - 
     4*G[{1}, yv^(-1)]*G[{0, 0, 1/(yu*yv), 1/(yu*yv)}, yw] + 
     4*G[{yu}, yv^(-1)]*G[{0, 0, 1/(yu*yv), 1/(yu*yv)}, yw] - 
     2*G[{1}, yv^(-1)]*G[{0, 1, 0, yu^(-1)}, yw] + 
     2*G[{yu}, yv^(-1)]*G[{0, 1, 0, yu^(-1)}, yw] - 
     2*G[{1}, yu^(-1)]*G[{0, 1, 0, yv^(-1)}, yw] + 
     2*G[{yu}, yv^(-1)]*G[{0, 1, 0, yv^(-1)}, yw] + 
     2*G[{1}, yu^(-1)]*G[{0, 1, 0, 1/(yu*yv)}, yw] + 
     2*G[{1}, yv^(-1)]*G[{0, 1, 0, 1/(yu*yv)}, yw] - 
     4*G[{yu}, yv^(-1)]*G[{0, 1, 0, 1/(yu*yv)}, yw] + 
     6*G[{1}, yu^(-1)]*G[{0, 1, 1, 1}, yv^(-1)] + 
     6*G[{0}, yu^(-1)]*G[{0, 1, 1, 1}, yw] + 6*G[{0}, yv^(-1)]*
      G[{0, 1, 1, 1}, yw] - 6*G[{0}, yw]*G[{0, 1, 1, 1}, yw] - 
     6*G[{1}, yu^(-1)]*G[{0, 1, 1, 1}, yw] - 6*G[{1}, yv^(-1)]*
      G[{0, 1, 1, 1}, yw] - 4*G[{0}, yu^(-1)]*G[{0, 1, 1, yu^(-1)}, yw] - 
     4*G[{0}, yv^(-1)]*G[{0, 1, 1, yu^(-1)}, yw] + 
     4*G[{0}, yw]*G[{0, 1, 1, yu^(-1)}, yw] + 6*G[{1}, yu^(-1)]*
      G[{0, 1, 1, yu^(-1)}, yw] + 8*G[{1}, yv^(-1)]*G[{0, 1, 1, yu^(-1)}, 
       yw] - 6*G[{yu}, yv^(-1)]*G[{0, 1, 1, yu^(-1)}, yw] + 
     2*G[{0}, yu^(-1)]*G[{0, 1, 1, yu}, yv^(-1)] + 
     2*G[{0}, yv^(-1)]*G[{0, 1, 1, yu}, yv^(-1)] - 
     2*G[{0}, yw]*G[{0, 1, 1, yu}, yv^(-1)] - 6*G[{1}, yu^(-1)]*
      G[{0, 1, 1, yu}, yv^(-1)] - 4*G[{0}, yu^(-1)]*G[{0, 1, 1, yv^(-1)}, 
       yw] - 4*G[{0}, yv^(-1)]*G[{0, 1, 1, yv^(-1)}, yw] + 
     4*G[{0}, yw]*G[{0, 1, 1, yv^(-1)}, yw] + 8*G[{1}, yu^(-1)]*
      G[{0, 1, 1, yv^(-1)}, yw] + 6*G[{1}, yv^(-1)]*G[{0, 1, 1, yv^(-1)}, 
       yw] - 6*G[{yu}, yv^(-1)]*G[{0, 1, 1, yv^(-1)}, yw] + 
     2*G[{0}, yu^(-1)]*G[{0, 1, 1, 1/(yu*yv)}, yw] + 
     2*G[{0}, yv^(-1)]*G[{0, 1, 1, 1/(yu*yv)}, yw] - 
     2*G[{0}, yw]*G[{0, 1, 1, 1/(yu*yv)}, yw] - 4*G[{1}, yu^(-1)]*
      G[{0, 1, 1, 1/(yu*yv)}, yw] - 4*G[{1}, yv^(-1)]*
      G[{0, 1, 1, 1/(yu*yv)}, yw] + 4*G[{yu}, yv^(-1)]*
      G[{0, 1, 1, 1/(yu*yv)}, yw] - 2*G[{0}, yu^(-1)]*
      G[{0, 1, yu^(-1), 1}, yw] - 2*G[{0}, yv^(-1)]*G[{0, 1, yu^(-1), 1}, 
       yw] + 2*G[{0}, yw]*G[{0, 1, yu^(-1), 1}, yw] + 
     4*G[{1}, yu^(-1)]*G[{0, 1, yu^(-1), 1}, yw] + 
     4*G[{1}, yv^(-1)]*G[{0, 1, yu^(-1), 1}, yw] - 
     4*G[{yu}, yv^(-1)]*G[{0, 1, yu^(-1), 1}, yw] - 
     4*G[{1}, yu^(-1)]*G[{0, 1, yu^(-1), yu^(-1)}, yw] + 
     4*G[{yu}, yv^(-1)]*G[{0, 1, yu^(-1), yu^(-1)}, yw] + 
     2*G[{0}, yu^(-1)]*G[{0, 1, yu^(-1), yv^(-1)}, yw] + 
     2*G[{0}, yv^(-1)]*G[{0, 1, yu^(-1), yv^(-1)}, yw] - 
     2*G[{0}, yw]*G[{0, 1, yu^(-1), yv^(-1)}, yw] - 
     4*G[{1}, yu^(-1)]*G[{0, 1, yu^(-1), yv^(-1)}, yw] - 
     4*G[{1}, yv^(-1)]*G[{0, 1, yu^(-1), yv^(-1)}, yw] + 
     4*G[{yu}, yv^(-1)]*G[{0, 1, yu^(-1), yv^(-1)}, yw] + 
     2*G[{0}, yu^(-1)]*G[{0, 1, yu, 1}, yv^(-1)] + 
     2*G[{0}, yv^(-1)]*G[{0, 1, yu, 1}, yv^(-1)] - 
     2*G[{0}, yw]*G[{0, 1, yu, 1}, yv^(-1)] - 4*G[{1}, yu^(-1)]*
      G[{0, 1, yu, 1}, yv^(-1)] - 4*G[{0}, yu^(-1)]*
      G[{0, 1, yu, yu}, yv^(-1)] - 4*G[{0}, yv^(-1)]*
      G[{0, 1, yu, yu}, yv^(-1)] + 4*G[{0}, yw]*G[{0, 1, yu, yu}, yv^(-1)] + 
     4*G[{1}, yu^(-1)]*G[{0, 1, yu, yu}, yv^(-1)] - 
     2*G[{0}, yu^(-1)]*G[{0, 1, yv^(-1), 1}, yw] - 
     2*G[{0}, yv^(-1)]*G[{0, 1, yv^(-1), 1}, yw] + 
     2*G[{0}, yw]*G[{0, 1, yv^(-1), 1}, yw] + 4*G[{1}, yu^(-1)]*
      G[{0, 1, yv^(-1), 1}, yw] + 4*G[{1}, yv^(-1)]*G[{0, 1, yv^(-1), 1}, 
       yw] - 4*G[{yu}, yv^(-1)]*G[{0, 1, yv^(-1), 1}, yw] + 
     2*G[{0}, yu^(-1)]*G[{0, 1, yv^(-1), yu^(-1)}, yw] + 
     2*G[{0}, yv^(-1)]*G[{0, 1, yv^(-1), yu^(-1)}, yw] - 
     2*G[{0}, yw]*G[{0, 1, yv^(-1), yu^(-1)}, yw] - 
     4*G[{1}, yu^(-1)]*G[{0, 1, yv^(-1), yu^(-1)}, yw] - 
     4*G[{1}, yv^(-1)]*G[{0, 1, yv^(-1), yu^(-1)}, yw] + 
     4*G[{yu}, yv^(-1)]*G[{0, 1, yv^(-1), yu^(-1)}, yw] - 
     4*G[{1}, yv^(-1)]*G[{0, 1, yv^(-1), yv^(-1)}, yw] + 
     4*G[{yu}, yv^(-1)]*G[{0, 1, yv^(-1), yv^(-1)}, yw] - 
     2*G[{1}, yu^(-1)]*G[{0, 1, 1/(yu*yv), 1}, yw] - 
     2*G[{1}, yv^(-1)]*G[{0, 1, 1/(yu*yv), 1}, yw] + 
     4*G[{yu}, yv^(-1)]*G[{0, 1, 1/(yu*yv), 1}, yw] + 
     2*G[{1}, yu^(-1)]*G[{0, 1, 1/(yu*yv), yu^(-1)}, yw] - 
     2*G[{yu}, yv^(-1)]*G[{0, 1, 1/(yu*yv), yu^(-1)}, yw] + 
     2*G[{1}, yv^(-1)]*G[{0, 1, 1/(yu*yv), yv^(-1)}, yw] - 
     2*G[{yu}, yv^(-1)]*G[{0, 1, 1/(yu*yv), yv^(-1)}, yw] + 
     2*G[{1}, yu^(-1)]*G[{0, yu^(-1), 0, yv^(-1)}, yw] - 
     2*G[{1}, yv^(-1)]*G[{0, yu^(-1), 0, yv^(-1)}, yw] - 
     2*G[{1}, yu^(-1)]*G[{0, yu^(-1), 0, 1/(yu*yv)}, yw] + 
     2*G[{yu}, yv^(-1)]*G[{0, yu^(-1), 0, 1/(yu*yv)}, yw] - 
     2*G[{0}, yu^(-1)]*G[{0, yu^(-1), 1, 1}, yw] - 
     2*G[{0}, yv^(-1)]*G[{0, yu^(-1), 1, 1}, yw] + 
     2*G[{0}, yw]*G[{0, yu^(-1), 1, 1}, yw] + 2*G[{1}, yu^(-1)]*
      G[{0, yu^(-1), 1, 1}, yw] + 2*G[{1}, yv^(-1)]*G[{0, yu^(-1), 1, 1}, 
       yw] - 2*G[{1}, yu^(-1)]*G[{0, yu^(-1), 1, yu^(-1)}, yw] + 
     2*G[{yu}, yv^(-1)]*G[{0, yu^(-1), 1, yu^(-1)}, yw] + 
     2*G[{0}, yu^(-1)]*G[{0, yu^(-1), 1, yv^(-1)}, yw] + 
     2*G[{0}, yv^(-1)]*G[{0, yu^(-1), 1, yv^(-1)}, yw] - 
     2*G[{0}, yw]*G[{0, yu^(-1), 1, yv^(-1)}, yw] - 
     4*G[{1}, yu^(-1)]*G[{0, yu^(-1), 1, yv^(-1)}, yw] - 
     2*G[{1}, yv^(-1)]*G[{0, yu^(-1), 1, yv^(-1)}, yw] + 
     2*G[{yu}, yv^(-1)]*G[{0, yu^(-1), 1, yv^(-1)}, yw] - 
     2*G[{0}, yu^(-1)]*G[{0, yu^(-1), yu^(-1), 1}, yw] - 
     2*G[{0}, yv^(-1)]*G[{0, yu^(-1), yu^(-1), 1}, yw] + 
     2*G[{0}, yw]*G[{0, yu^(-1), yu^(-1), 1}, yw] + 
     4*G[{yu}, yv^(-1)]*G[{0, yu^(-1), yu^(-1), 1}, yw] + 
     4*G[{0}, yu^(-1)]*G[{0, yu^(-1), yu^(-1), yu^(-1)}, yw] + 
     4*G[{0}, yv^(-1)]*G[{0, yu^(-1), yu^(-1), yu^(-1)}, yw] - 
     4*G[{0}, yw]*G[{0, yu^(-1), yu^(-1), yu^(-1)}, yw] - 
     8*G[{1}, yv^(-1)]*G[{0, yu^(-1), yu^(-1), yu^(-1)}, yw] - 
     2*G[{0}, yu^(-1)]*G[{0, yu^(-1), yu^(-1), 1/(yu*yv)}, yw] - 
     2*G[{0}, yv^(-1)]*G[{0, yu^(-1), yu^(-1), 1/(yu*yv)}, yw] + 
     2*G[{0}, yw]*G[{0, yu^(-1), yu^(-1), 1/(yu*yv)}, yw] + 
     4*G[{1}, yu^(-1)]*G[{0, yu^(-1), yu^(-1), 1/(yu*yv)}, yw] + 
     4*G[{1}, yv^(-1)]*G[{0, yu^(-1), yu^(-1), 1/(yu*yv)}, yw] - 
     4*G[{yu}, yv^(-1)]*G[{0, yu^(-1), yu^(-1), 1/(yu*yv)}, yw] + 
     2*G[{0}, yu^(-1)]*G[{0, yu^(-1), 1/(yu*yv), 1}, yw] + 
     2*G[{0}, yv^(-1)]*G[{0, yu^(-1), 1/(yu*yv), 1}, yw] - 
     2*G[{0}, yw]*G[{0, yu^(-1), 1/(yu*yv), 1}, yw] - 
     2*G[{1}, yu^(-1)]*G[{0, yu^(-1), 1/(yu*yv), 1}, yw] - 
     2*G[{1}, yv^(-1)]*G[{0, yu^(-1), 1/(yu*yv), 1}, yw] - 
     2*G[{0}, yu^(-1)]*G[{0, yu^(-1), 1/(yu*yv), yu^(-1)}, yw] - 
     2*G[{0}, yv^(-1)]*G[{0, yu^(-1), 1/(yu*yv), yu^(-1)}, yw] + 
     2*G[{0}, yw]*G[{0, yu^(-1), 1/(yu*yv), yu^(-1)}, yw] + 
     2*G[{1}, yu^(-1)]*G[{0, yu^(-1), 1/(yu*yv), yu^(-1)}, yw] + 
     4*G[{1}, yv^(-1)]*G[{0, yu^(-1), 1/(yu*yv), yu^(-1)}, yw] - 
     2*G[{yu}, yv^(-1)]*G[{0, yu^(-1), 1/(yu*yv), yu^(-1)}, yw] + 
     2*G[{1}, yv^(-1)]*G[{0, yu^(-1), 1/(yu*yv), yv^(-1)}, yw] - 
     2*G[{yu}, yv^(-1)]*G[{0, yu^(-1), 1/(yu*yv), yv^(-1)}, yw] - 
     2*G[{1}, yu^(-1)]*G[{0, yu, 1, 1}, yv^(-1)] - 
     2*G[{0}, yu^(-1)]*G[{0, yu, 1, yu}, yv^(-1)] - 
     2*G[{0}, yv^(-1)]*G[{0, yu, 1, yu}, yv^(-1)] + 
     2*G[{0}, yw]*G[{0, yu, 1, yu}, yv^(-1)] + 2*G[{1}, yu^(-1)]*
      G[{0, yu, 1, yu}, yv^(-1)] - 2*G[{0}, yu^(-1)]*
      G[{0, yu, yu, 1}, yv^(-1)] - 2*G[{0}, yv^(-1)]*
      G[{0, yu, yu, 1}, yv^(-1)] + 2*G[{0}, yw]*G[{0, yu, yu, 1}, yv^(-1)] + 
     4*G[{0}, yu^(-1)]*G[{0, yu, yu, yu}, yv^(-1)] + 
     4*G[{0}, yv^(-1)]*G[{0, yu, yu, yu}, yv^(-1)] - 
     4*G[{0}, yw]*G[{0, yu, yu, yu}, yv^(-1)] - 2*G[{1}, yv^(-1)]*
      G[{0, yv^(-1), 0, 1/(yu*yv)}, yw] + 2*G[{yu}, yv^(-1)]*
      G[{0, yv^(-1), 0, 1/(yu*yv)}, yw] - 2*G[{0}, yu^(-1)]*
      G[{0, yv^(-1), 1, 1}, yw] - 2*G[{0}, yv^(-1)]*G[{0, yv^(-1), 1, 1}, 
       yw] + 2*G[{0}, yw]*G[{0, yv^(-1), 1, 1}, yw] + 
     2*G[{1}, yu^(-1)]*G[{0, yv^(-1), 1, 1}, yw] + 
     2*G[{1}, yv^(-1)]*G[{0, yv^(-1), 1, 1}, yw] + 
     2*G[{0}, yu^(-1)]*G[{0, yv^(-1), 1, yu^(-1)}, yw] + 
     2*G[{0}, yv^(-1)]*G[{0, yv^(-1), 1, yu^(-1)}, yw] - 
     2*G[{0}, yw]*G[{0, yv^(-1), 1, yu^(-1)}, yw] - 
     2*G[{1}, yu^(-1)]*G[{0, yv^(-1), 1, yu^(-1)}, yw] - 
     4*G[{1}, yv^(-1)]*G[{0, yv^(-1), 1, yu^(-1)}, yw] + 
     2*G[{yu}, yv^(-1)]*G[{0, yv^(-1), 1, yu^(-1)}, yw] - 
     2*G[{1}, yv^(-1)]*G[{0, yv^(-1), 1, yv^(-1)}, yw] + 
     2*G[{yu}, yv^(-1)]*G[{0, yv^(-1), 1, yv^(-1)}, yw] - 
     2*G[{0}, yu^(-1)]*G[{0, yv^(-1), yv^(-1), 1}, yw] - 
     2*G[{0}, yv^(-1)]*G[{0, yv^(-1), yv^(-1), 1}, yw] + 
     2*G[{0}, yw]*G[{0, yv^(-1), yv^(-1), 1}, yw] + 
     4*G[{yu}, yv^(-1)]*G[{0, yv^(-1), yv^(-1), 1}, yw] + 
     4*G[{0}, yu^(-1)]*G[{0, yv^(-1), yv^(-1), yv^(-1)}, yw] + 
     4*G[{0}, yv^(-1)]*G[{0, yv^(-1), yv^(-1), yv^(-1)}, yw] - 
     4*G[{0}, yw]*G[{0, yv^(-1), yv^(-1), yv^(-1)}, yw] - 
     8*G[{1}, yu^(-1)]*G[{0, yv^(-1), yv^(-1), yv^(-1)}, yw] - 
     2*G[{0}, yu^(-1)]*G[{0, yv^(-1), yv^(-1), 1/(yu*yv)}, yw] - 
     2*G[{0}, yv^(-1)]*G[{0, yv^(-1), yv^(-1), 1/(yu*yv)}, yw] + 
     2*G[{0}, yw]*G[{0, yv^(-1), yv^(-1), 1/(yu*yv)}, yw] + 
     4*G[{1}, yu^(-1)]*G[{0, yv^(-1), yv^(-1), 1/(yu*yv)}, yw] + 
     4*G[{1}, yv^(-1)]*G[{0, yv^(-1), yv^(-1), 1/(yu*yv)}, yw] - 
     4*G[{yu}, yv^(-1)]*G[{0, yv^(-1), yv^(-1), 1/(yu*yv)}, yw] + 
     2*G[{0}, yu^(-1)]*G[{0, yv^(-1), 1/(yu*yv), 1}, yw] + 
     2*G[{0}, yv^(-1)]*G[{0, yv^(-1), 1/(yu*yv), 1}, yw] - 
     2*G[{0}, yw]*G[{0, yv^(-1), 1/(yu*yv), 1}, yw] - 
     2*G[{1}, yu^(-1)]*G[{0, yv^(-1), 1/(yu*yv), 1}, yw] - 
     2*G[{1}, yv^(-1)]*G[{0, yv^(-1), 1/(yu*yv), 1}, yw] + 
     2*G[{1}, yu^(-1)]*G[{0, yv^(-1), 1/(yu*yv), yu^(-1)}, yw] - 
     2*G[{yu}, yv^(-1)]*G[{0, yv^(-1), 1/(yu*yv), yu^(-1)}, yw] - 
     2*G[{0}, yu^(-1)]*G[{0, yv^(-1), 1/(yu*yv), yv^(-1)}, yw] - 
     2*G[{0}, yv^(-1)]*G[{0, yv^(-1), 1/(yu*yv), yv^(-1)}, yw] + 
     2*G[{0}, yw]*G[{0, yv^(-1), 1/(yu*yv), yv^(-1)}, yw] + 
     4*G[{1}, yu^(-1)]*G[{0, yv^(-1), 1/(yu*yv), yv^(-1)}, yw] + 
     2*G[{1}, yv^(-1)]*G[{0, yv^(-1), 1/(yu*yv), yv^(-1)}, yw] - 
     2*G[{yu}, yv^(-1)]*G[{0, yv^(-1), 1/(yu*yv), yv^(-1)}, yw] - 
     2*G[{0}, yu^(-1)]*G[{0, 1/(yu*yv), 1, 1}, yw] - 
     2*G[{0}, yv^(-1)]*G[{0, 1/(yu*yv), 1, 1}, yw] + 
     2*G[{0}, yw]*G[{0, 1/(yu*yv), 1, 1}, yw] + 2*G[{1}, yu^(-1)]*
      G[{0, 1/(yu*yv), 1, 1}, yw] + 2*G[{1}, yv^(-1)]*
      G[{0, 1/(yu*yv), 1, 1}, yw] + 2*G[{0}, yu^(-1)]*
      G[{0, 1/(yu*yv), 1, yu^(-1)}, yw] + 2*G[{0}, yv^(-1)]*
      G[{0, 1/(yu*yv), 1, yu^(-1)}, yw] - 2*G[{0}, yw]*
      G[{0, 1/(yu*yv), 1, yu^(-1)}, yw] - 2*G[{1}, yu^(-1)]*
      G[{0, 1/(yu*yv), 1, yu^(-1)}, yw] - 4*G[{1}, yv^(-1)]*
      G[{0, 1/(yu*yv), 1, yu^(-1)}, yw] + 2*G[{yu}, yv^(-1)]*
      G[{0, 1/(yu*yv), 1, yu^(-1)}, yw] + 2*G[{0}, yu^(-1)]*
      G[{0, 1/(yu*yv), 1, yv^(-1)}, yw] + 2*G[{0}, yv^(-1)]*
      G[{0, 1/(yu*yv), 1, yv^(-1)}, yw] - 2*G[{0}, yw]*
      G[{0, 1/(yu*yv), 1, yv^(-1)}, yw] - 4*G[{1}, yu^(-1)]*
      G[{0, 1/(yu*yv), 1, yv^(-1)}, yw] - 2*G[{1}, yv^(-1)]*
      G[{0, 1/(yu*yv), 1, yv^(-1)}, yw] + 2*G[{yu}, yv^(-1)]*
      G[{0, 1/(yu*yv), 1, yv^(-1)}, yw] - 2*G[{0}, yu^(-1)]*
      G[{0, 1/(yu*yv), 1, 1/(yu*yv)}, yw] - 2*G[{0}, yv^(-1)]*
      G[{0, 1/(yu*yv), 1, 1/(yu*yv)}, yw] + 2*G[{0}, yw]*
      G[{0, 1/(yu*yv), 1, 1/(yu*yv)}, yw] + 4*G[{1}, yu^(-1)]*
      G[{0, 1/(yu*yv), 1, 1/(yu*yv)}, yw] + 4*G[{1}, yv^(-1)]*
      G[{0, 1/(yu*yv), 1, 1/(yu*yv)}, yw] - 4*G[{yu}, yv^(-1)]*
      G[{0, 1/(yu*yv), 1, 1/(yu*yv)}, yw] + 4*G[{0}, yu^(-1)]*
      G[{0, 1/(yu*yv), yu^(-1), 1}, yw] + 4*G[{0}, yv^(-1)]*
      G[{0, 1/(yu*yv), yu^(-1), 1}, yw] - 4*G[{0}, yw]*
      G[{0, 1/(yu*yv), yu^(-1), 1}, yw] - 4*G[{1}, yu^(-1)]*
      G[{0, 1/(yu*yv), yu^(-1), 1}, yw] - 4*G[{1}, yv^(-1)]*
      G[{0, 1/(yu*yv), yu^(-1), 1}, yw] - 4*G[{0}, yu^(-1)]*
      G[{0, 1/(yu*yv), yu^(-1), yu^(-1)}, yw] - 4*G[{0}, yv^(-1)]*
      G[{0, 1/(yu*yv), yu^(-1), yu^(-1)}, yw] + 
     4*G[{0}, yw]*G[{0, 1/(yu*yv), yu^(-1), yu^(-1)}, yw] + 
     4*G[{1}, yu^(-1)]*G[{0, 1/(yu*yv), yu^(-1), yu^(-1)}, yw] + 
     8*G[{1}, yv^(-1)]*G[{0, 1/(yu*yv), yu^(-1), yu^(-1)}, yw] - 
     4*G[{yu}, yv^(-1)]*G[{0, 1/(yu*yv), yu^(-1), yu^(-1)}, yw] - 
     2*G[{0}, yu^(-1)]*G[{0, 1/(yu*yv), yu^(-1), yv^(-1)}, yw] - 
     2*G[{0}, yv^(-1)]*G[{0, 1/(yu*yv), yu^(-1), yv^(-1)}, yw] + 
     2*G[{0}, yw]*G[{0, 1/(yu*yv), yu^(-1), yv^(-1)}, yw] + 
     4*G[{1}, yu^(-1)]*G[{0, 1/(yu*yv), yu^(-1), yv^(-1)}, yw] + 
     4*G[{1}, yv^(-1)]*G[{0, 1/(yu*yv), yu^(-1), yv^(-1)}, yw] - 
     4*G[{yu}, yv^(-1)]*G[{0, 1/(yu*yv), yu^(-1), yv^(-1)}, yw] + 
     2*G[{0}, yu^(-1)]*G[{0, 1/(yu*yv), yu^(-1), 1/(yu*yv)}, yw] + 
     2*G[{0}, yv^(-1)]*G[{0, 1/(yu*yv), yu^(-1), 1/(yu*yv)}, yw] - 
     2*G[{0}, yw]*G[{0, 1/(yu*yv), yu^(-1), 1/(yu*yv)}, yw] - 
     4*G[{1}, yu^(-1)]*G[{0, 1/(yu*yv), yu^(-1), 1/(yu*yv)}, yw] - 
     4*G[{1}, yv^(-1)]*G[{0, 1/(yu*yv), yu^(-1), 1/(yu*yv)}, yw] + 
     4*G[{yu}, yv^(-1)]*G[{0, 1/(yu*yv), yu^(-1), 1/(yu*yv)}, yw] + 
     4*G[{0}, yu^(-1)]*G[{0, 1/(yu*yv), yv^(-1), 1}, yw] + 
     4*G[{0}, yv^(-1)]*G[{0, 1/(yu*yv), yv^(-1), 1}, yw] - 
     4*G[{0}, yw]*G[{0, 1/(yu*yv), yv^(-1), 1}, yw] - 
     4*G[{1}, yu^(-1)]*G[{0, 1/(yu*yv), yv^(-1), 1}, yw] - 
     4*G[{1}, yv^(-1)]*G[{0, 1/(yu*yv), yv^(-1), 1}, yw] - 
     2*G[{0}, yu^(-1)]*G[{0, 1/(yu*yv), yv^(-1), yu^(-1)}, yw] - 
     2*G[{0}, yv^(-1)]*G[{0, 1/(yu*yv), yv^(-1), yu^(-1)}, yw] + 
     2*G[{0}, yw]*G[{0, 1/(yu*yv), yv^(-1), yu^(-1)}, yw] + 
     4*G[{1}, yu^(-1)]*G[{0, 1/(yu*yv), yv^(-1), yu^(-1)}, yw] + 
     4*G[{1}, yv^(-1)]*G[{0, 1/(yu*yv), yv^(-1), yu^(-1)}, yw] - 
     4*G[{yu}, yv^(-1)]*G[{0, 1/(yu*yv), yv^(-1), yu^(-1)}, yw] - 
     4*G[{0}, yu^(-1)]*G[{0, 1/(yu*yv), yv^(-1), yv^(-1)}, yw] - 
     4*G[{0}, yv^(-1)]*G[{0, 1/(yu*yv), yv^(-1), yv^(-1)}, yw] + 
     4*G[{0}, yw]*G[{0, 1/(yu*yv), yv^(-1), yv^(-1)}, yw] + 
     8*G[{1}, yu^(-1)]*G[{0, 1/(yu*yv), yv^(-1), yv^(-1)}, yw] + 
     4*G[{1}, yv^(-1)]*G[{0, 1/(yu*yv), yv^(-1), yv^(-1)}, yw] - 
     4*G[{yu}, yv^(-1)]*G[{0, 1/(yu*yv), yv^(-1), yv^(-1)}, yw] + 
     2*G[{0}, yu^(-1)]*G[{0, 1/(yu*yv), yv^(-1), 1/(yu*yv)}, yw] + 
     2*G[{0}, yv^(-1)]*G[{0, 1/(yu*yv), yv^(-1), 1/(yu*yv)}, yw] - 
     2*G[{0}, yw]*G[{0, 1/(yu*yv), yv^(-1), 1/(yu*yv)}, yw] - 
     4*G[{1}, yu^(-1)]*G[{0, 1/(yu*yv), yv^(-1), 1/(yu*yv)}, yw] - 
     4*G[{1}, yv^(-1)]*G[{0, 1/(yu*yv), yv^(-1), 1/(yu*yv)}, yw] + 
     4*G[{yu}, yv^(-1)]*G[{0, 1/(yu*yv), yv^(-1), 1/(yu*yv)}, yw] - 
     4*G[{0}, yu^(-1)]*G[{0, 1/(yu*yv), 1/(yu*yv), 1}, yw] - 
     4*G[{0}, yv^(-1)]*G[{0, 1/(yu*yv), 1/(yu*yv), 1}, yw] + 
     4*G[{0}, yw]*G[{0, 1/(yu*yv), 1/(yu*yv), 1}, yw] + 
     6*G[{1}, yu^(-1)]*G[{0, 1/(yu*yv), 1/(yu*yv), 1}, yw] + 
     6*G[{1}, yv^(-1)]*G[{0, 1/(yu*yv), 1/(yu*yv), 1}, yw] - 
     4*G[{yu}, yv^(-1)]*G[{0, 1/(yu*yv), 1/(yu*yv), 1}, yw] + 
     2*G[{0}, yu^(-1)]*G[{0, 1/(yu*yv), 1/(yu*yv), yu^(-1)}, yw] + 
     2*G[{0}, yv^(-1)]*G[{0, 1/(yu*yv), 1/(yu*yv), yu^(-1)}, yw] - 
     2*G[{0}, yw]*G[{0, 1/(yu*yv), 1/(yu*yv), yu^(-1)}, yw] - 
     6*G[{1}, yu^(-1)]*G[{0, 1/(yu*yv), 1/(yu*yv), yu^(-1)}, yw] - 
     4*G[{1}, yv^(-1)]*G[{0, 1/(yu*yv), 1/(yu*yv), yu^(-1)}, yw] + 
     6*G[{yu}, yv^(-1)]*G[{0, 1/(yu*yv), 1/(yu*yv), yu^(-1)}, yw] + 
     2*G[{0}, yu^(-1)]*G[{0, 1/(yu*yv), 1/(yu*yv), yv^(-1)}, yw] + 
     2*G[{0}, yv^(-1)]*G[{0, 1/(yu*yv), 1/(yu*yv), yv^(-1)}, yw] - 
     2*G[{0}, yw]*G[{0, 1/(yu*yv), 1/(yu*yv), yv^(-1)}, yw] - 
     4*G[{1}, yu^(-1)]*G[{0, 1/(yu*yv), 1/(yu*yv), yv^(-1)}, yw] - 
     6*G[{1}, yv^(-1)]*G[{0, 1/(yu*yv), 1/(yu*yv), yv^(-1)}, yw] + 
     6*G[{yu}, yv^(-1)]*G[{0, 1/(yu*yv), 1/(yu*yv), yv^(-1)}, yw] + 
     12*G[{0, 0, 0, 1, 1}, yw] - 12*G[{0, 0, 0, 1, yu^(-1)}, yw] - 
     12*G[{0, 0, 0, 1, yv^(-1)}, yw] + 12*G[{0, 0, 0, 1, 1/(yu*yv)}, yw] - 
     12*G[{0, 0, 0, yu^(-1), 1}, yw] + 12*G[{0, 0, 0, yu^(-1), yu^(-1)}, 
       yw] + 12*G[{0, 0, 0, yu^(-1), yv^(-1)}, yw] - 
     12*G[{0, 0, 0, yu^(-1), 1/(yu*yv)}, yw] - 
     12*G[{0, 0, 0, yv^(-1), 1}, yw] + 12*G[{0, 0, 0, yv^(-1), yu^(-1)}, 
       yw] + 12*G[{0, 0, 0, yv^(-1), yv^(-1)}, yw] - 
     12*G[{0, 0, 0, yv^(-1), 1/(yu*yv)}, yw] + 
     12*G[{0, 0, 0, 1/(yu*yv), 1}, yw] - 12*G[{0, 0, 0, 1/(yu*yv), yu^(-1)}, 
       yw] - 12*G[{0, 0, 0, 1/(yu*yv), yv^(-1)}, yw] + 
     12*G[{0, 0, 0, 1/(yu*yv), 1/(yu*yv)}, yw] + 4*G[{0, 0, 1, 0, 1}, yw] - 
     4*G[{0, 0, 1, 0, yu^(-1)}, yw] - 4*G[{0, 0, 1, 0, yv^(-1)}, yw] + 
     4*G[{0, 0, 1, 0, 1/(yu*yv)}, yw] - 12*G[{0, 0, 1, 1, 1}, yu^(-1)] - 
     12*G[{0, 0, 1, 1, 1}, yv^(-1)] - 8*G[{0, 0, 1, 1, yu^(-1)}, yw] + 
     4*G[{0, 0, 1, 1, yu}, yv^(-1)] - 8*G[{0, 0, 1, 1, yv^(-1)}, yw] + 
     4*G[{0, 0, 1, 1, 1/(yu*yv)}, yw] - 4*G[{0, 0, 1, yu^(-1), 1}, yw] - 
     4*G[{0, 0, 1, yu^(-1), yu^(-1)}, yw] - 
     4*G[{0, 0, 1, yu^(-1), yv^(-1)}, yw] + 
     4*G[{0, 0, 1, yu^(-1), 1/(yu*yv)}, yw] + 
     4*G[{0, 0, 1, yu, 1}, yv^(-1)] - 4*G[{0, 0, 1, yu, yu}, yv^(-1)] - 
     4*G[{0, 0, 1, yv^(-1), 1}, yw] - 4*G[{0, 0, 1, yv^(-1), yu^(-1)}, yw] - 
     4*G[{0, 0, 1, yv^(-1), yv^(-1)}, yw] + 
     4*G[{0, 0, 1, yv^(-1), 1/(yu*yv)}, yw] + 
     4*G[{0, 0, 1, 1/(yu*yv), 1}, yw] - 4*G[{0, 0, yu^(-1), 0, 1}, yw] + 
     4*G[{0, 0, yu^(-1), 0, yu^(-1)}, yw] + 
     4*G[{0, 0, yu^(-1), 0, yv^(-1)}, yw] - 
     4*G[{0, 0, yu^(-1), 0, 1/(yu*yv)}, yw] - 
     4*G[{0, 0, yu^(-1), 1, 1}, yw] - 4*G[{0, 0, yu^(-1), yu^(-1), yu^(-1)}, 
       yw] + 4*G[{0, 0, yu^(-1), yu^(-1), yv^(-1)}, yw] - 
     8*G[{0, 0, yu^(-1), yu^(-1), 1/(yu*yv)}, yw] + 
     4*G[{0, 0, yu^(-1), yv^(-1), yu^(-1)}, yw] + 
     4*G[{0, 0, yu^(-1), yv^(-1), yv^(-1)}, yw] - 
     4*G[{0, 0, yu^(-1), 1/(yu*yv), yu^(-1)}, yw] + 
     4*G[{0, 0, yu^(-1), 1/(yu*yv), yv^(-1)}, yw] + 
     4*G[{0, 0, yu, 1, 1}, yv^(-1)] + 4*G[{0, 0, yu, yu, 1}, yv^(-1)] - 
     12*G[{0, 0, yu, yu, yu}, yv^(-1)] - 4*G[{0, 0, yv^(-1), 0, 1}, yw] + 
     4*G[{0, 0, yv^(-1), 0, yu^(-1)}, yw] + 
     4*G[{0, 0, yv^(-1), 0, yv^(-1)}, yw] - 
     4*G[{0, 0, yv^(-1), 0, 1/(yu*yv)}, yw] - 
     4*G[{0, 0, yv^(-1), 1, 1}, yw] + 4*G[{0, 0, yv^(-1), yu^(-1), yu^(-1)}, 
       yw] - 4*G[{0, 0, yv^(-1), yv^(-1), yu^(-1)}, yw] - 
     4*G[{0, 0, yv^(-1), yv^(-1), yv^(-1)}, yw] - 
     8*G[{0, 0, yv^(-1), yv^(-1), 1/(yu*yv)}, yw] - 
     4*G[{0, 0, yv^(-1), 1/(yu*yv), yv^(-1)}, yw] + 
     4*G[{0, 0, 1/(yu*yv), 0, 1}, yw] - 4*G[{0, 0, 1/(yu*yv), 0, yu^(-1)}, 
       yw] - 4*G[{0, 0, 1/(yu*yv), 0, yv^(-1)}, yw] + 
     4*G[{0, 0, 1/(yu*yv), 0, 1/(yu*yv)}, yw] + 
     4*G[{0, 0, 1/(yu*yv), 1, 1}, yw] - 
     4*G[{0, 0, 1/(yu*yv), yu^(-1), yu^(-1)}, yw] - 
     4*G[{0, 0, 1/(yu*yv), yv^(-1), yv^(-1)}, yw] - 
     4*G[{0, 0, 1/(yu*yv), 1/(yu*yv), yu^(-1)}, yw] - 
     4*G[{0, 0, 1/(yu*yv), 1/(yu*yv), yv^(-1)}, yw] - 
     4*G[{0, 1, 0, 1, 1}, yu^(-1)] - 4*G[{0, 1, 0, 1, 1}, yv^(-1)] - 
     2*G[{0, 1, 0, 1, 1}, yw] - 4*G[{0, 1, 0, 1, yu^(-1)}, yw] + 
     2*G[{0, 1, 0, 1, yu}, yv^(-1)] - 4*G[{0, 1, 0, 1, yv^(-1)}, yw] + 
     2*G[{0, 1, 0, 1, 1/(yu*yv)}, yw] - 2*G[{0, 1, 0, yu^(-1), 1}, yw] - 
     2*G[{0, 1, 0, yu^(-1), yv^(-1)}, yw] + 
     2*G[{0, 1, 0, yu^(-1), 1/(yu*yv)}, yw] + 
     2*G[{0, 1, 0, yu, 1}, yv^(-1)] - 4*G[{0, 1, 0, yu, yu}, yv^(-1)] - 
     2*G[{0, 1, 0, yv^(-1), 1}, yw] - 2*G[{0, 1, 0, yv^(-1), yu^(-1)}, yw] + 
     2*G[{0, 1, 0, yv^(-1), 1/(yu*yv)}, yw] + 
     4*G[{0, 1, 0, 1/(yu*yv), 1}, yw] - 2*G[{0, 1, 0, 1/(yu*yv), yu^(-1)}, 
       yw] - 2*G[{0, 1, 0, 1/(yu*yv), yv^(-1)}, yw] - 
     2*G[{0, 1, 1, 0, yu^(-1)}, yw] - 2*G[{0, 1, 1, 0, yv^(-1)}, yw] + 
     2*G[{0, 1, 1, 0, 1/(yu*yv)}, yw] + 6*G[{0, 1, 1, 1, yu^(-1)}, yw] - 
     6*G[{0, 1, 1, 1, yu}, yv^(-1)] + 6*G[{0, 1, 1, 1, yv^(-1)}, yw] + 
     6*G[{0, 1, 1, yu^(-1), 1}, yw] - 8*G[{0, 1, 1, yu^(-1), yu^(-1)}, yw] - 
     6*G[{0, 1, 1, yu^(-1), yv^(-1)}, yw] - 6*G[{0, 1, 1, yu, 1}, yv^(-1)] + 
     8*G[{0, 1, 1, yu, yu}, yv^(-1)] + 6*G[{0, 1, 1, yv^(-1), 1}, yw] - 
     6*G[{0, 1, 1, yv^(-1), yu^(-1)}, yw] - 
     8*G[{0, 1, 1, yv^(-1), yv^(-1)}, yw] - 
     4*G[{0, 1, 1, 1/(yu*yv), 1}, yw] + 4*G[{0, 1, 1, 1/(yu*yv), yu^(-1)}, 
       yw] + 4*G[{0, 1, 1, 1/(yu*yv), yv^(-1)}, yw] - 
     2*G[{0, 1, yu^(-1), 0, yu^(-1)}, yw] - 
     2*G[{0, 1, yu^(-1), 0, yv^(-1)}, yw] + 
     2*G[{0, 1, yu^(-1), 0, 1/(yu*yv)}, yw] + 
     4*G[{0, 1, yu^(-1), 1, 1}, yw] - 4*G[{0, 1, yu^(-1), 1, yu^(-1)}, yw] - 
     4*G[{0, 1, yu^(-1), 1, yv^(-1)}, yw] - 
     4*G[{0, 1, yu^(-1), yu^(-1), 1}, yw] + 
     4*G[{0, 1, yu^(-1), yu^(-1), yv^(-1)}, yw] - 
     4*G[{0, 1, yu^(-1), yv^(-1), 1}, yw] + 
     4*G[{0, 1, yu^(-1), yv^(-1), yu^(-1)}, yw] + 
     4*G[{0, 1, yu^(-1), yv^(-1), yv^(-1)}, yw] - 
     2*G[{0, 1, yu, 0, yu}, yv^(-1)] - 4*G[{0, 1, yu, 1, 1}, yv^(-1)] + 
     4*G[{0, 1, yu, 1, yu}, yv^(-1)] + 4*G[{0, 1, yu, yu, 1}, yv^(-1)] - 
     2*G[{0, 1, yv^(-1), 0, yu^(-1)}, yw] - 
     2*G[{0, 1, yv^(-1), 0, yv^(-1)}, yw] + 
     2*G[{0, 1, yv^(-1), 0, 1/(yu*yv)}, yw] + 
     4*G[{0, 1, yv^(-1), 1, 1}, yw] - 4*G[{0, 1, yv^(-1), 1, yu^(-1)}, yw] - 
     4*G[{0, 1, yv^(-1), 1, yv^(-1)}, yw] - 
     4*G[{0, 1, yv^(-1), yu^(-1), 1}, yw] + 
     4*G[{0, 1, yv^(-1), yu^(-1), yu^(-1)}, yw] + 
     4*G[{0, 1, yv^(-1), yu^(-1), yv^(-1)}, yw] - 
     4*G[{0, 1, yv^(-1), yv^(-1), 1}, yw] + 
     4*G[{0, 1, yv^(-1), yv^(-1), yu^(-1)}, yw] - 
     4*G[{0, 1, 1/(yu*yv), 1, 1}, yw] + 2*G[{0, 1, 1/(yu*yv), 1, yu^(-1)}, 
       yw] + 2*G[{0, 1, 1/(yu*yv), 1, yv^(-1)}, yw] + 
     2*G[{0, 1, 1/(yu*yv), yu^(-1), 1}, yw] - 
     2*G[{0, 1, 1/(yu*yv), yu^(-1), yv^(-1)}, yw] + 
     2*G[{0, 1, 1/(yu*yv), yv^(-1), 1}, yw] - 
     2*G[{0, 1, 1/(yu*yv), yv^(-1), yu^(-1)}, yw] - 
     4*G[{0, yu^(-1), 0, yu^(-1), yu^(-1)}, yw] + 
     2*G[{0, yu^(-1), 0, yu^(-1), yv^(-1)}, yw] - 
     4*G[{0, yu^(-1), 0, yu^(-1), 1/(yu*yv)}, yw] + 
     2*G[{0, yu^(-1), 0, yv^(-1), yu^(-1)}, yw] - 
     2*G[{0, yu^(-1), 0, 1/(yu*yv), 1}, yw] + 
     4*G[{0, yu^(-1), 0, 1/(yu*yv), yv^(-1)}, yw] - 
     2*G[{0, yu^(-1), 1, 1, yu^(-1)}, yw] - 
     2*G[{0, yu^(-1), 1, 1, yv^(-1)}, yw] - 
     2*G[{0, yu^(-1), 1, yu^(-1), 1}, yw] + 
     2*G[{0, yu^(-1), 1, yu^(-1), yv^(-1)}, yw] - 
     2*G[{0, yu^(-1), 1, yv^(-1), 1}, yw] + 
     2*G[{0, yu^(-1), 1, yv^(-1), yu^(-1)}, yw] + 
     4*G[{0, yu^(-1), 1, yv^(-1), yv^(-1)}, yw] + 
     4*G[{0, yu^(-1), yu^(-1), 0, yv^(-1)}, yw] - 
     4*G[{0, yu^(-1), yu^(-1), 0, 1/(yu*yv)}, yw] - 
     4*G[{0, yu^(-1), yu^(-1), 1, 1}, yw] + 
     8*G[{0, yu^(-1), yu^(-1), yu^(-1), yu^(-1)}, yw] + 
     4*G[{0, yu^(-1), yu^(-1), 1/(yu*yv), 1}, yw] - 
     4*G[{0, yu^(-1), yu^(-1), 1/(yu*yv), yu^(-1)}, yw] - 
     4*G[{0, yu^(-1), yu^(-1), 1/(yu*yv), yv^(-1)}, yw] + 
     2*G[{0, yu^(-1), yv^(-1), 0, yv^(-1)}, yw] - 
     2*G[{0, yu^(-1), yv^(-1), 0, 1/(yu*yv)}, yw] + 
     2*G[{0, yu^(-1), 1/(yu*yv), 0, yv^(-1)}, yw] + 
     2*G[{0, yu^(-1), 1/(yu*yv), 1, yu^(-1)}, yw] + 
     2*G[{0, yu^(-1), 1/(yu*yv), 1, yv^(-1)}, yw] + 
     2*G[{0, yu^(-1), 1/(yu*yv), yu^(-1), 1}, yw] - 
     4*G[{0, yu^(-1), 1/(yu*yv), yu^(-1), yu^(-1)}, yw] - 
     2*G[{0, yu^(-1), 1/(yu*yv), yu^(-1), yv^(-1)}, yw] + 
     2*G[{0, yu^(-1), 1/(yu*yv), yv^(-1), 1}, yw] - 
     2*G[{0, yu^(-1), 1/(yu*yv), yv^(-1), yu^(-1)}, yw] + 
     2*G[{0, yu, 0, yu, 1}, yv^(-1)] - 4*G[{0, yu, 0, yu, yu}, yv^(-1)] + 
     2*G[{0, yu, 1, 1, yu}, yv^(-1)] + 2*G[{0, yu, 1, yu, 1}, yv^(-1)] + 
     4*G[{0, yu, yu, 1, 1}, yv^(-1)] - 8*G[{0, yu, yu, yu, yu}, yv^(-1)] - 
     2*G[{0, yv^(-1), 0, yv^(-1), yu^(-1)}, yw] - 
     4*G[{0, yv^(-1), 0, yv^(-1), yv^(-1)}, yw] - 
     4*G[{0, yv^(-1), 0, yv^(-1), 1/(yu*yv)}, yw] - 
     2*G[{0, yv^(-1), 0, 1/(yu*yv), 1}, yw] + 
     2*G[{0, yv^(-1), 0, 1/(yu*yv), yu^(-1)}, yw] - 
     2*G[{0, yv^(-1), 1, 1, yu^(-1)}, yw] - 
     2*G[{0, yv^(-1), 1, 1, yv^(-1)}, yw] - 
     2*G[{0, yv^(-1), 1, yu^(-1), 1}, yw] + 
     4*G[{0, yv^(-1), 1, yu^(-1), yu^(-1)}, yw] + 
     2*G[{0, yv^(-1), 1, yu^(-1), yv^(-1)}, yw] - 
     2*G[{0, yv^(-1), 1, yv^(-1), 1}, yw] + 
     2*G[{0, yv^(-1), 1, yv^(-1), yu^(-1)}, yw] - 
     2*G[{0, yv^(-1), yu^(-1), 0, 1/(yu*yv)}, yw] - 
     4*G[{0, yv^(-1), yv^(-1), 0, 1/(yu*yv)}, yw] - 
     4*G[{0, yv^(-1), yv^(-1), 1, 1}, yw] + 
     8*G[{0, yv^(-1), yv^(-1), yv^(-1), yv^(-1)}, yw] + 
     4*G[{0, yv^(-1), yv^(-1), 1/(yu*yv), 1}, yw] - 
     4*G[{0, yv^(-1), yv^(-1), 1/(yu*yv), yu^(-1)}, yw] - 
     4*G[{0, yv^(-1), yv^(-1), 1/(yu*yv), yv^(-1)}, yw] + 
     2*G[{0, yv^(-1), 1/(yu*yv), 1, yu^(-1)}, yw] + 
     2*G[{0, yv^(-1), 1/(yu*yv), 1, yv^(-1)}, yw] + 
     2*G[{0, yv^(-1), 1/(yu*yv), yu^(-1), 1}, yw] - 
     2*G[{0, yv^(-1), 1/(yu*yv), yu^(-1), yv^(-1)}, yw] + 
     2*G[{0, yv^(-1), 1/(yu*yv), yv^(-1), 1}, yw] - 
     2*G[{0, yv^(-1), 1/(yu*yv), yv^(-1), yu^(-1)}, yw] - 
     4*G[{0, yv^(-1), 1/(yu*yv), yv^(-1), yv^(-1)}, yw] + 
     2*G[{0, 1/(yu*yv), 0, 1/(yu*yv), 1}, yw] - 
     4*G[{0, 1/(yu*yv), 0, 1/(yu*yv), yu^(-1)}, yw] - 
     4*G[{0, 1/(yu*yv), 0, 1/(yu*yv), yv^(-1)}, yw] - 
     2*G[{0, 1/(yu*yv), 1, 1, yu^(-1)}, yw] - 
     2*G[{0, 1/(yu*yv), 1, 1, yv^(-1)}, yw] - 
     2*G[{0, 1/(yu*yv), 1, yu^(-1), 1}, yw] + 
     4*G[{0, 1/(yu*yv), 1, yu^(-1), yu^(-1)}, yw] + 
     2*G[{0, 1/(yu*yv), 1, yu^(-1), yv^(-1)}, yw] - 
     2*G[{0, 1/(yu*yv), 1, yv^(-1), 1}, yw] + 
     2*G[{0, 1/(yu*yv), 1, yv^(-1), yu^(-1)}, yw] + 
     4*G[{0, 1/(yu*yv), 1, yv^(-1), yv^(-1)}, yw] + 
     4*G[{0, 1/(yu*yv), 1, 1/(yu*yv), 1}, yw] - 
     4*G[{0, 1/(yu*yv), 1, 1/(yu*yv), yu^(-1)}, yw] - 
     4*G[{0, 1/(yu*yv), 1, 1/(yu*yv), yv^(-1)}, yw] + 
     4*G[{0, 1/(yu*yv), yu^(-1), 1, yu^(-1)}, yw] + 
     4*G[{0, 1/(yu*yv), yu^(-1), 1, yv^(-1)}, yw] + 
     4*G[{0, 1/(yu*yv), yu^(-1), yu^(-1), 1}, yw] - 
     8*G[{0, 1/(yu*yv), yu^(-1), yu^(-1), yu^(-1)}, yw] - 
     4*G[{0, 1/(yu*yv), yu^(-1), yu^(-1), yv^(-1)}, yw] + 
     4*G[{0, 1/(yu*yv), yu^(-1), yv^(-1), 1}, yw] - 
     4*G[{0, 1/(yu*yv), yu^(-1), yv^(-1), yu^(-1)}, yw] - 
     4*G[{0, 1/(yu*yv), yu^(-1), yv^(-1), yv^(-1)}, yw] - 
     4*G[{0, 1/(yu*yv), yu^(-1), 1/(yu*yv), 1}, yw] + 
     4*G[{0, 1/(yu*yv), yu^(-1), 1/(yu*yv), yu^(-1)}, yw] + 
     4*G[{0, 1/(yu*yv), yu^(-1), 1/(yu*yv), yv^(-1)}, yw] + 
     4*G[{0, 1/(yu*yv), yv^(-1), 1, yu^(-1)}, yw] + 
     4*G[{0, 1/(yu*yv), yv^(-1), 1, yv^(-1)}, yw] + 
     4*G[{0, 1/(yu*yv), yv^(-1), yu^(-1), 1}, yw] - 
     4*G[{0, 1/(yu*yv), yv^(-1), yu^(-1), yu^(-1)}, yw] - 
     4*G[{0, 1/(yu*yv), yv^(-1), yu^(-1), yv^(-1)}, yw] + 
     4*G[{0, 1/(yu*yv), yv^(-1), yv^(-1), 1}, yw] - 
     4*G[{0, 1/(yu*yv), yv^(-1), yv^(-1), yu^(-1)}, yw] - 
     8*G[{0, 1/(yu*yv), yv^(-1), yv^(-1), yv^(-1)}, yw] - 
     4*G[{0, 1/(yu*yv), yv^(-1), 1/(yu*yv), 1}, yw] + 
     4*G[{0, 1/(yu*yv), yv^(-1), 1/(yu*yv), yu^(-1)}, yw] + 
     4*G[{0, 1/(yu*yv), yv^(-1), 1/(yu*yv), yv^(-1)}, yw] + 
     4*G[{0, 1/(yu*yv), 1/(yu*yv), 1, 1}, yw] - 
     6*G[{0, 1/(yu*yv), 1/(yu*yv), 1, yu^(-1)}, yw] - 
     6*G[{0, 1/(yu*yv), 1/(yu*yv), 1, yv^(-1)}, yw] - 
     6*G[{0, 1/(yu*yv), 1/(yu*yv), yu^(-1), 1}, yw] + 
     4*G[{0, 1/(yu*yv), 1/(yu*yv), yu^(-1), yu^(-1)}, yw] + 
     6*G[{0, 1/(yu*yv), 1/(yu*yv), yu^(-1), yv^(-1)}, yw] - 
     6*G[{0, 1/(yu*yv), 1/(yu*yv), yv^(-1), 1}, yw] + 
     6*G[{0, 1/(yu*yv), 1/(yu*yv), yv^(-1), yu^(-1)}, yw] + 
     4*G[{0, 1/(yu*yv), 1/(yu*yv), yv^(-1), yv^(-1)}, yw] + 
     (Pi^2*Zeta[3])/3 - 2*G[{0, 1}, yu^(-1)]*Zeta[3] - 
     2*G[{0, 1}, yv^(-1)]*Zeta[3] - 2*G[{0, 1}, yw]*Zeta[3] + 
     2*G[{0, yu^(-1)}, yw]*Zeta[3] + 2*G[{0, yu}, yv^(-1)]*Zeta[3] + 
     2*G[{0, yv^(-1)}, yw]*Zeta[3] - 2*G[{0, 1/(yu*yv)}, yw]*Zeta[3] - 
     2*Zeta[5]
 
H1uvwRegII = (Pi^4*G[{0}, yu^(-1)])/30 + (Pi^4*G[{0}, yv^(-1)])/30 - 
     (Pi^4*G[{0}, yw])/30 + (Pi^4*G[{1}, yu^(-1)])/72 + 
     (Pi^2*G[{0}, yu^(-1)]^2*G[{1}, yu^(-1)])/12 + 
     (Pi^2*G[{0}, yu^(-1)]*G[{0}, yv^(-1)]*G[{1}, yu^(-1)])/6 + 
     (Pi^2*G[{0}, yv^(-1)]^2*G[{1}, yu^(-1)])/12 - 
     (Pi^2*G[{0}, yu^(-1)]*G[{0}, yw]*G[{1}, yu^(-1)])/6 - 
     (Pi^2*G[{0}, yv^(-1)]*G[{0}, yw]*G[{1}, yu^(-1)])/6 + 
     (Pi^2*G[{0}, yw]^2*G[{1}, yu^(-1)])/12 - 
     (Pi^2*G[{0}, yu^(-1)]*G[{1}, yu^(-1)]^2)/12 - 
     (Pi^2*G[{0}, yv^(-1)]*G[{1}, yu^(-1)]^2)/12 + 
     (Pi^2*G[{0}, yw]*G[{1}, yu^(-1)]^2)/12 - (Pi^4*G[{1}, yw])/72 - 
     (Pi^2*G[{0}, yu^(-1)]^2*G[{1}, yw])/12 - 
     (Pi^2*G[{0}, yu^(-1)]*G[{0}, yv^(-1)]*G[{1}, yw])/6 - 
     (Pi^2*G[{0}, yv^(-1)]^2*G[{1}, yw])/12 + 
     (Pi^2*G[{0}, yu^(-1)]*G[{0}, yw]*G[{1}, yw])/6 + 
     (Pi^2*G[{0}, yv^(-1)]*G[{0}, yw]*G[{1}, yw])/6 - 
     (Pi^2*G[{0}, yw]^2*G[{1}, yw])/12 + 
     (Pi^2*G[{0}, yu^(-1)]*G[{1}, yu^(-1)]*G[{1}, yw])/6 + 
     (Pi^2*G[{0}, yv^(-1)]*G[{1}, yu^(-1)]*G[{1}, yw])/6 - 
     (Pi^2*G[{0}, yw]*G[{1}, yu^(-1)]*G[{1}, yw])/6 - 
     (Pi^2*G[{0}, yu^(-1)]*G[{1}, yw]^2)/12 - 
     (Pi^2*G[{0}, yv^(-1)]*G[{1}, yw]^2)/12 + (Pi^2*G[{0}, yw]*G[{1}, yw]^2)/
      12 + (Pi^2*G[{1}, yu^(-1)]*G[{0, 1}, yu^(-1)])/3 + 
     (G[{0}, yu^(-1)]^2*G[{1}, yu^(-1)]*G[{0, 1}, yu^(-1)])/2 + 
     G[{0}, yu^(-1)]*G[{0}, yv^(-1)]*G[{1}, yu^(-1)]*G[{0, 1}, yu^(-1)] + 
     (G[{0}, yv^(-1)]^2*G[{1}, yu^(-1)]*G[{0, 1}, yu^(-1)])/2 - 
     G[{0}, yu^(-1)]*G[{0}, yw]*G[{1}, yu^(-1)]*G[{0, 1}, yu^(-1)] - 
     G[{0}, yv^(-1)]*G[{0}, yw]*G[{1}, yu^(-1)]*G[{0, 1}, yu^(-1)] + 
     (G[{0}, yw]^2*G[{1}, yu^(-1)]*G[{0, 1}, yu^(-1)])/2 - 
     (G[{0}, yu^(-1)]*G[{1}, yu^(-1)]^2*G[{0, 1}, yu^(-1)])/2 - 
     (G[{0}, yv^(-1)]*G[{1}, yu^(-1)]^2*G[{0, 1}, yu^(-1)])/2 + 
     (G[{0}, yw]*G[{1}, yu^(-1)]^2*G[{0, 1}, yu^(-1)])/2 - 
     (Pi^2*G[{1}, yw]*G[{0, 1}, yu^(-1)])/3 - 
     (G[{0}, yu^(-1)]^2*G[{1}, yw]*G[{0, 1}, yu^(-1)])/2 - 
     G[{0}, yu^(-1)]*G[{0}, yv^(-1)]*G[{1}, yw]*G[{0, 1}, yu^(-1)] - 
     (G[{0}, yv^(-1)]^2*G[{1}, yw]*G[{0, 1}, yu^(-1)])/2 + 
     G[{0}, yu^(-1)]*G[{0}, yw]*G[{1}, yw]*G[{0, 1}, yu^(-1)] + 
     G[{0}, yv^(-1)]*G[{0}, yw]*G[{1}, yw]*G[{0, 1}, yu^(-1)] - 
     (G[{0}, yw]^2*G[{1}, yw]*G[{0, 1}, yu^(-1)])/2 + 
     G[{0}, yu^(-1)]*G[{1}, yu^(-1)]*G[{1}, yw]*G[{0, 1}, yu^(-1)] + 
     G[{0}, yv^(-1)]*G[{1}, yu^(-1)]*G[{1}, yw]*G[{0, 1}, yu^(-1)] - 
     G[{0}, yw]*G[{1}, yu^(-1)]*G[{1}, yw]*G[{0, 1}, yu^(-1)] - 
     (G[{0}, yu^(-1)]*G[{1}, yw]^2*G[{0, 1}, yu^(-1)])/2 - 
     (G[{0}, yv^(-1)]*G[{1}, yw]^2*G[{0, 1}, yu^(-1)])/2 + 
     (G[{0}, yw]*G[{1}, yw]^2*G[{0, 1}, yu^(-1)])/2 + 
     (G[{1}, yu^(-1)]*G[{0, 1}, yu^(-1)]^2)/2 - 
     (G[{1}, yw]*G[{0, 1}, yu^(-1)]^2)/2 - 
     (Pi^2*G[{1}, yu^(-1)]*G[{0, 1}, yv^(-1)])/6 - 
     (Pi^2*G[{1}, yw]*G[{0, 1}, yv^(-1)])/6 - 
     (G[{0}, yu^(-1)]^2*G[{1}, yw]*G[{0, 1}, yv^(-1)])/2 - 
     G[{0}, yu^(-1)]*G[{0}, yv^(-1)]*G[{1}, yw]*G[{0, 1}, yv^(-1)] - 
     (G[{0}, yv^(-1)]^2*G[{1}, yw]*G[{0, 1}, yv^(-1)])/2 + 
     G[{0}, yu^(-1)]*G[{0}, yw]*G[{1}, yw]*G[{0, 1}, yv^(-1)] + 
     G[{0}, yv^(-1)]*G[{0}, yw]*G[{1}, yw]*G[{0, 1}, yv^(-1)] - 
     (G[{0}, yw]^2*G[{1}, yw]*G[{0, 1}, yv^(-1)])/2 + 
     (G[{1}, yu^(-1)]^2*G[{1}, yw]*G[{0, 1}, yv^(-1)])/2 - 
     (G[{0}, yu^(-1)]*G[{1}, yw]^2*G[{0, 1}, yv^(-1)])/2 - 
     (G[{0}, yv^(-1)]*G[{1}, yw]^2*G[{0, 1}, yv^(-1)])/2 + 
     (G[{0}, yw]*G[{1}, yw]^2*G[{0, 1}, yv^(-1)])/2 - 
     G[{1}, yu^(-1)]*G[{0, 1}, yu^(-1)]*G[{0, 1}, yv^(-1)] - 
     (G[{0}, yu^(-1)]*G[{0, 1}, yv^(-1)]^2)/2 - 
     (G[{0}, yv^(-1)]*G[{0, 1}, yv^(-1)]^2)/2 + 
     (G[{0}, yw]*G[{0, 1}, yv^(-1)]^2)/2 - (G[{1}, yw]*G[{0, 1}, yv^(-1)]^2)/
      2 + (Pi^2*G[{1}, yu^(-1)]*G[{0, 1}, yw])/3 + 
     (G[{0}, yu^(-1)]^2*G[{1}, yu^(-1)]*G[{0, 1}, yw])/2 + 
     G[{0}, yu^(-1)]*G[{0}, yv^(-1)]*G[{1}, yu^(-1)]*G[{0, 1}, yw] + 
     (G[{0}, yv^(-1)]^2*G[{1}, yu^(-1)]*G[{0, 1}, yw])/2 - 
     G[{0}, yu^(-1)]*G[{0}, yw]*G[{1}, yu^(-1)]*G[{0, 1}, yw] - 
     G[{0}, yv^(-1)]*G[{0}, yw]*G[{1}, yu^(-1)]*G[{0, 1}, yw] + 
     (G[{0}, yw]^2*G[{1}, yu^(-1)]*G[{0, 1}, yw])/2 - 
     G[{0}, yu^(-1)]*G[{1}, yu^(-1)]^2*G[{0, 1}, yw] - 
     G[{0}, yv^(-1)]*G[{1}, yu^(-1)]^2*G[{0, 1}, yw] + 
     G[{0}, yw]*G[{1}, yu^(-1)]^2*G[{0, 1}, yw] + 
     (G[{1}, yu^(-1)]^3*G[{0, 1}, yw])/2 - (Pi^2*G[{1}, yw]*G[{0, 1}, yw])/
      3 - (G[{0}, yu^(-1)]^2*G[{1}, yw]*G[{0, 1}, yw])/2 - 
     G[{0}, yu^(-1)]*G[{0}, yv^(-1)]*G[{1}, yw]*G[{0, 1}, yw] - 
     (G[{0}, yv^(-1)]^2*G[{1}, yw]*G[{0, 1}, yw])/2 + 
     G[{0}, yu^(-1)]*G[{0}, yw]*G[{1}, yw]*G[{0, 1}, yw] + 
     G[{0}, yv^(-1)]*G[{0}, yw]*G[{1}, yw]*G[{0, 1}, yw] - 
     (G[{0}, yw]^2*G[{1}, yw]*G[{0, 1}, yw])/2 + 
     G[{0}, yu^(-1)]*G[{1}, yu^(-1)]*G[{1}, yw]*G[{0, 1}, yw] + 
     G[{0}, yv^(-1)]*G[{1}, yu^(-1)]*G[{1}, yw]*G[{0, 1}, yw] - 
     G[{0}, yw]*G[{1}, yu^(-1)]*G[{1}, yw]*G[{0, 1}, yw] - 
     (G[{1}, yu^(-1)]^2*G[{1}, yw]*G[{0, 1}, yw])/2 - 
     G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*G[{1}, yw]*G[{0, 1}, yw] - 
     (G[{0}, yu^(-1)]*G[{1}, yw]^2*G[{0, 1}, yw])/2 - 
     (G[{0}, yv^(-1)]*G[{1}, yw]^2*G[{0, 1}, yw])/2 + 
     (G[{0}, yw]*G[{1}, yw]^2*G[{0, 1}, yw])/2 - 
     (Pi^2*G[{yu}, yv^(-1)]*G[{0, 1}, yw])/3 - 
     (G[{0}, yu^(-1)]^2*G[{yu}, yv^(-1)]*G[{0, 1}, yw])/2 - 
     G[{0}, yu^(-1)]*G[{0}, yv^(-1)]*G[{yu}, yv^(-1)]*G[{0, 1}, yw] - 
     (G[{0}, yv^(-1)]^2*G[{yu}, yv^(-1)]*G[{0, 1}, yw])/2 + 
     G[{0}, yu^(-1)]*G[{0}, yw]*G[{yu}, yv^(-1)]*G[{0, 1}, yw] + 
     G[{0}, yv^(-1)]*G[{0}, yw]*G[{yu}, yv^(-1)]*G[{0, 1}, yw] - 
     (G[{0}, yw]^2*G[{yu}, yv^(-1)]*G[{0, 1}, yw])/2 + 
     (G[{1}, yu^(-1)]^2*G[{yu}, yv^(-1)]*G[{0, 1}, yw])/2 - 
     G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*G[{yu}, yv^(-1)]*G[{0, 1}, yw] + 
     G[{0}, yu^(-1)]*G[{1}, yw]*G[{yu}, yv^(-1)]*G[{0, 1}, yw] + 
     G[{0}, yv^(-1)]*G[{1}, yw]*G[{yu}, yv^(-1)]*G[{0, 1}, yw] - 
     G[{0}, yw]*G[{1}, yw]*G[{yu}, yv^(-1)]*G[{0, 1}, yw] + 
     G[{1}, yw]^2*G[{yu}, yv^(-1)]*G[{0, 1}, yw] + 
     G[{0}, yu^(-1)]*G[{yu}, yv^(-1)]^2*G[{0, 1}, yw] + 
     G[{0}, yv^(-1)]*G[{yu}, yv^(-1)]^2*G[{0, 1}, yw] - 
     G[{0}, yw]*G[{yu}, yv^(-1)]^2*G[{0, 1}, yw] - 
     G[{1}, yw]*G[{yu}, yv^(-1)]^2*G[{0, 1}, yw] - 
     (2*G[{yu}, yv^(-1)]^3*G[{0, 1}, yw])/3 + G[{1}, yu^(-1)]*
      G[{0, 1}, yu^(-1)]*G[{0, 1}, yw] - G[{1}, yw]*G[{0, 1}, yu^(-1)]*
      G[{0, 1}, yw] - G[{yu}, yv^(-1)]*G[{0, 1}, yu^(-1)]*G[{0, 1}, yw] - 
     (Pi^2*G[{1}, yu^(-1)]*G[{0, yu^(-1)}, yw])/6 - 
     (G[{0}, yu^(-1)]^2*G[{1}, yu^(-1)]*G[{0, yu^(-1)}, yw])/2 - 
     G[{0}, yu^(-1)]*G[{0}, yv^(-1)]*G[{1}, yu^(-1)]*G[{0, yu^(-1)}, yw] - 
     (G[{0}, yv^(-1)]^2*G[{1}, yu^(-1)]*G[{0, yu^(-1)}, yw])/2 + 
     G[{0}, yu^(-1)]*G[{0}, yw]*G[{1}, yu^(-1)]*G[{0, yu^(-1)}, yw] + 
     G[{0}, yv^(-1)]*G[{0}, yw]*G[{1}, yu^(-1)]*G[{0, yu^(-1)}, yw] - 
     (G[{0}, yw]^2*G[{1}, yu^(-1)]*G[{0, yu^(-1)}, yw])/2 + 
     G[{0}, yu^(-1)]*G[{1}, yu^(-1)]^2*G[{0, yu^(-1)}, yw] + 
     G[{0}, yv^(-1)]*G[{1}, yu^(-1)]^2*G[{0, yu^(-1)}, yw] - 
     G[{0}, yw]*G[{1}, yu^(-1)]^2*G[{0, yu^(-1)}, yw] - 
     (G[{1}, yu^(-1)]^3*G[{0, yu^(-1)}, yw])/2 + 
     (Pi^2*G[{1}, yv^(-1)]*G[{0, yu^(-1)}, yw])/6 + 
     (G[{0}, yu^(-1)]^2*G[{1}, yv^(-1)]*G[{0, yu^(-1)}, yw])/2 + 
     G[{0}, yu^(-1)]*G[{0}, yv^(-1)]*G[{1}, yv^(-1)]*G[{0, yu^(-1)}, yw] + 
     (G[{0}, yv^(-1)]^2*G[{1}, yv^(-1)]*G[{0, yu^(-1)}, yw])/2 - 
     G[{0}, yu^(-1)]*G[{0}, yw]*G[{1}, yv^(-1)]*G[{0, yu^(-1)}, yw] - 
     G[{0}, yv^(-1)]*G[{0}, yw]*G[{1}, yv^(-1)]*G[{0, yu^(-1)}, yw] + 
     (G[{0}, yw]^2*G[{1}, yv^(-1)]*G[{0, yu^(-1)}, yw])/2 - 
     (G[{1}, yu^(-1)]^2*G[{1}, yv^(-1)]*G[{0, yu^(-1)}, yw])/2 - 
     (3*G[{0}, yu^(-1)]*G[{1}, yv^(-1)]^2*G[{0, yu^(-1)}, yw])/2 - 
     (3*G[{0}, yv^(-1)]*G[{1}, yv^(-1)]^2*G[{0, yu^(-1)}, yw])/2 + 
     (3*G[{0}, yw]*G[{1}, yv^(-1)]^2*G[{0, yu^(-1)}, yw])/2 + 
     (G[{1}, yu^(-1)]*G[{1}, yv^(-1)]^2*G[{0, yu^(-1)}, yw])/2 + 
     G[{1}, yv^(-1)]^3*G[{0, yu^(-1)}, yw] + 
     (Pi^2*G[{1}, yw]*G[{0, yu^(-1)}, yw])/6 + 
     (G[{0}, yu^(-1)]^2*G[{1}, yw]*G[{0, yu^(-1)}, yw])/2 + 
     G[{0}, yu^(-1)]*G[{0}, yv^(-1)]*G[{1}, yw]*G[{0, yu^(-1)}, yw] + 
     (G[{0}, yv^(-1)]^2*G[{1}, yw]*G[{0, yu^(-1)}, yw])/2 - 
     G[{0}, yu^(-1)]*G[{0}, yw]*G[{1}, yw]*G[{0, yu^(-1)}, yw] - 
     G[{0}, yv^(-1)]*G[{0}, yw]*G[{1}, yw]*G[{0, yu^(-1)}, yw] + 
     (G[{0}, yw]^2*G[{1}, yw]*G[{0, yu^(-1)}, yw])/2 - 
     G[{0}, yu^(-1)]*G[{1}, yu^(-1)]*G[{1}, yw]*G[{0, yu^(-1)}, yw] - 
     G[{0}, yv^(-1)]*G[{1}, yu^(-1)]*G[{1}, yw]*G[{0, yu^(-1)}, yw] + 
     G[{0}, yw]*G[{1}, yu^(-1)]*G[{1}, yw]*G[{0, yu^(-1)}, yw] + 
     (G[{1}, yu^(-1)]^2*G[{1}, yw]*G[{0, yu^(-1)}, yw])/2 - 
     G[{0}, yu^(-1)]*G[{1}, yv^(-1)]*G[{1}, yw]*G[{0, yu^(-1)}, yw] - 
     G[{0}, yv^(-1)]*G[{1}, yv^(-1)]*G[{1}, yw]*G[{0, yu^(-1)}, yw] + 
     G[{0}, yw]*G[{1}, yv^(-1)]*G[{1}, yw]*G[{0, yu^(-1)}, yw] + 
     G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*G[{1}, yw]*G[{0, yu^(-1)}, yw] + 
     (G[{0}, yu^(-1)]*G[{1}, yw]^2*G[{0, yu^(-1)}, yw])/2 + 
     (G[{0}, yv^(-1)]*G[{1}, yw]^2*G[{0, yu^(-1)}, yw])/2 - 
     (G[{0}, yw]*G[{1}, yw]^2*G[{0, yu^(-1)}, yw])/2 - 
     G[{1}, yv^(-1)]*G[{1}, yw]^2*G[{0, yu^(-1)}, yw] + 
     G[{0}, yu^(-1)]*G[{0, 1}, yv^(-1)]*G[{0, yu^(-1)}, yw] + 
     G[{0}, yv^(-1)]*G[{0, 1}, yv^(-1)]*G[{0, yu^(-1)}, yw] - 
     G[{0}, yw]*G[{0, 1}, yv^(-1)]*G[{0, yu^(-1)}, yw] - 
     G[{1}, yv^(-1)]*G[{0, 1}, yv^(-1)]*G[{0, yu^(-1)}, yw] + 
     G[{1}, yw]*G[{0, 1}, yv^(-1)]*G[{0, yu^(-1)}, yw] + 
     G[{0}, yu^(-1)]*G[{0, 1}, yw]*G[{0, yu^(-1)}, yw] + 
     G[{0}, yv^(-1)]*G[{0, 1}, yw]*G[{0, yu^(-1)}, yw] - 
     G[{0}, yw]*G[{0, 1}, yw]*G[{0, yu^(-1)}, yw] - 
     2*G[{1}, yu^(-1)]*G[{0, 1}, yw]*G[{0, yu^(-1)}, yw] + 
     G[{1}, yw]*G[{0, 1}, yw]*G[{0, yu^(-1)}, yw] - 
     (G[{0}, yu^(-1)]*G[{0, yu^(-1)}, yw]^2)/2 - 
     (G[{0}, yv^(-1)]*G[{0, yu^(-1)}, yw]^2)/2 + 
     (G[{0}, yw]*G[{0, yu^(-1)}, yw]^2)/2 + G[{1}, yu^(-1)]*
      G[{0, yu^(-1)}, yw]^2 - (G[{1}, yw]*G[{0, yu^(-1)}, yw]^2)/2 + 
     (Pi^2*G[{1}, yw]*G[{0, yu}, yv^(-1)])/3 + 
     (G[{0}, yu^(-1)]^2*G[{1}, yw]*G[{0, yu}, yv^(-1)])/2 + 
     G[{0}, yu^(-1)]*G[{0}, yv^(-1)]*G[{1}, yw]*G[{0, yu}, yv^(-1)] + 
     (G[{0}, yv^(-1)]^2*G[{1}, yw]*G[{0, yu}, yv^(-1)])/2 - 
     G[{0}, yu^(-1)]*G[{0}, yw]*G[{1}, yw]*G[{0, yu}, yv^(-1)] - 
     G[{0}, yv^(-1)]*G[{0}, yw]*G[{1}, yw]*G[{0, yu}, yv^(-1)] + 
     (G[{0}, yw]^2*G[{1}, yw]*G[{0, yu}, yv^(-1)])/2 - 
     (G[{1}, yu^(-1)]^2*G[{1}, yw]*G[{0, yu}, yv^(-1)])/2 + 
     (G[{0}, yu^(-1)]*G[{1}, yw]^2*G[{0, yu}, yv^(-1)])/2 + 
     (G[{0}, yv^(-1)]*G[{1}, yw]^2*G[{0, yu}, yv^(-1)])/2 - 
     (G[{0}, yw]*G[{1}, yw]^2*G[{0, yu}, yv^(-1)])/2 + 
     G[{1}, yw]*G[{0, 1}, yu^(-1)]*G[{0, yu}, yv^(-1)] - 
     G[{0}, yu^(-1)]*G[{0, yu^(-1)}, yw]*G[{0, yu}, yv^(-1)] - 
     G[{0}, yv^(-1)]*G[{0, yu^(-1)}, yw]*G[{0, yu}, yv^(-1)] + 
     G[{0}, yw]*G[{0, yu^(-1)}, yw]*G[{0, yu}, yv^(-1)] + 
     G[{1}, yv^(-1)]*G[{0, yu^(-1)}, yw]*G[{0, yu}, yv^(-1)] - 
     G[{1}, yw]*G[{0, yu^(-1)}, yw]*G[{0, yu}, yv^(-1)] + 
     (Pi^2*G[{1}, yw]*G[{0, yv^(-1)}, yw])/3 + 
     (G[{0}, yu^(-1)]^2*G[{1}, yw]*G[{0, yv^(-1)}, yw])/2 + 
     G[{0}, yu^(-1)]*G[{0}, yv^(-1)]*G[{1}, yw]*G[{0, yv^(-1)}, yw] + 
     (G[{0}, yv^(-1)]^2*G[{1}, yw]*G[{0, yv^(-1)}, yw])/2 - 
     G[{0}, yu^(-1)]*G[{0}, yw]*G[{1}, yw]*G[{0, yv^(-1)}, yw] - 
     G[{0}, yv^(-1)]*G[{0}, yw]*G[{1}, yw]*G[{0, yv^(-1)}, yw] + 
     (G[{0}, yw]^2*G[{1}, yw]*G[{0, yv^(-1)}, yw])/2 - 
     2*G[{0}, yu^(-1)]*G[{1}, yu^(-1)]*G[{1}, yw]*G[{0, yv^(-1)}, yw] - 
     2*G[{0}, yv^(-1)]*G[{1}, yu^(-1)]*G[{1}, yw]*G[{0, yv^(-1)}, yw] + 
     2*G[{0}, yw]*G[{1}, yu^(-1)]*G[{1}, yw]*G[{0, yv^(-1)}, yw] + 
     (3*G[{1}, yu^(-1)]^2*G[{1}, yw]*G[{0, yv^(-1)}, yw])/2 + 
     G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*G[{1}, yw]*G[{0, yv^(-1)}, yw] + 
     (G[{0}, yu^(-1)]*G[{1}, yw]^2*G[{0, yv^(-1)}, yw])/2 + 
     (G[{0}, yv^(-1)]*G[{1}, yw]^2*G[{0, yv^(-1)}, yw])/2 - 
     (G[{0}, yw]*G[{1}, yw]^2*G[{0, yv^(-1)}, yw])/2 - 
     G[{1}, yu^(-1)]*G[{1}, yw]^2*G[{0, yv^(-1)}, yw] + 
     G[{1}, yw]*G[{0, 1}, yu^(-1)]*G[{0, yv^(-1)}, yw] - 
     (Pi^2*G[{1}, yu^(-1)]*G[{0, 1/(yu*yv)}, yw])/6 - 
     (Pi^2*G[{1}, yv^(-1)]*G[{0, 1/(yu*yv)}, yw])/6 - 
     (G[{0}, yu^(-1)]^2*G[{1}, yv^(-1)]*G[{0, 1/(yu*yv)}, yw])/2 - 
     G[{0}, yu^(-1)]*G[{0}, yv^(-1)]*G[{1}, yv^(-1)]*G[{0, 1/(yu*yv)}, yw] - 
     (G[{0}, yv^(-1)]^2*G[{1}, yv^(-1)]*G[{0, 1/(yu*yv)}, yw])/2 + 
     G[{0}, yu^(-1)]*G[{0}, yw]*G[{1}, yv^(-1)]*G[{0, 1/(yu*yv)}, yw] + 
     G[{0}, yv^(-1)]*G[{0}, yw]*G[{1}, yv^(-1)]*G[{0, 1/(yu*yv)}, yw] - 
     (G[{0}, yw]^2*G[{1}, yv^(-1)]*G[{0, 1/(yu*yv)}, yw])/2 + 
     (G[{1}, yu^(-1)]^2*G[{1}, yv^(-1)]*G[{0, 1/(yu*yv)}, yw])/2 + 
     (3*G[{0}, yu^(-1)]*G[{1}, yv^(-1)]^2*G[{0, 1/(yu*yv)}, yw])/2 + 
     (3*G[{0}, yv^(-1)]*G[{1}, yv^(-1)]^2*G[{0, 1/(yu*yv)}, yw])/2 - 
     (3*G[{0}, yw]*G[{1}, yv^(-1)]^2*G[{0, 1/(yu*yv)}, yw])/2 - 
     (G[{1}, yu^(-1)]*G[{1}, yv^(-1)]^2*G[{0, 1/(yu*yv)}, yw])/2 - 
     G[{1}, yv^(-1)]^3*G[{0, 1/(yu*yv)}, yw] - 
     (Pi^2*G[{1}, yw]*G[{0, 1/(yu*yv)}, yw])/6 - 
     (G[{0}, yu^(-1)]^2*G[{1}, yw]*G[{0, 1/(yu*yv)}, yw])/2 - 
     G[{0}, yu^(-1)]*G[{0}, yv^(-1)]*G[{1}, yw]*G[{0, 1/(yu*yv)}, yw] - 
     (G[{0}, yv^(-1)]^2*G[{1}, yw]*G[{0, 1/(yu*yv)}, yw])/2 + 
     G[{0}, yu^(-1)]*G[{0}, yw]*G[{1}, yw]*G[{0, 1/(yu*yv)}, yw] + 
     G[{0}, yv^(-1)]*G[{0}, yw]*G[{1}, yw]*G[{0, 1/(yu*yv)}, yw] - 
     (G[{0}, yw]^2*G[{1}, yw]*G[{0, 1/(yu*yv)}, yw])/2 + 
     2*G[{0}, yu^(-1)]*G[{1}, yu^(-1)]*G[{1}, yw]*G[{0, 1/(yu*yv)}, yw] + 
     2*G[{0}, yv^(-1)]*G[{1}, yu^(-1)]*G[{1}, yw]*G[{0, 1/(yu*yv)}, yw] - 
     2*G[{0}, yw]*G[{1}, yu^(-1)]*G[{1}, yw]*G[{0, 1/(yu*yv)}, yw] - 
     (3*G[{1}, yu^(-1)]^2*G[{1}, yw]*G[{0, 1/(yu*yv)}, yw])/2 + 
     G[{0}, yu^(-1)]*G[{1}, yv^(-1)]*G[{1}, yw]*G[{0, 1/(yu*yv)}, yw] + 
     G[{0}, yv^(-1)]*G[{1}, yv^(-1)]*G[{1}, yw]*G[{0, 1/(yu*yv)}, yw] - 
     G[{0}, yw]*G[{1}, yv^(-1)]*G[{1}, yw]*G[{0, 1/(yu*yv)}, yw] - 
     G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*G[{1}, yw]*G[{0, 1/(yu*yv)}, yw] - 
     (G[{0}, yu^(-1)]*G[{1}, yw]^2*G[{0, 1/(yu*yv)}, yw])/2 - 
     (G[{0}, yv^(-1)]*G[{1}, yw]^2*G[{0, 1/(yu*yv)}, yw])/2 + 
     (G[{0}, yw]*G[{1}, yw]^2*G[{0, 1/(yu*yv)}, yw])/2 + 
     G[{1}, yu^(-1)]*G[{1}, yw]^2*G[{0, 1/(yu*yv)}, yw] + 
     G[{1}, yv^(-1)]*G[{1}, yw]^2*G[{0, 1/(yu*yv)}, yw] + 
     (Pi^2*G[{yu}, yv^(-1)]*G[{0, 1/(yu*yv)}, yw])/3 + 
     (G[{0}, yu^(-1)]^2*G[{yu}, yv^(-1)]*G[{0, 1/(yu*yv)}, yw])/2 + 
     G[{0}, yu^(-1)]*G[{0}, yv^(-1)]*G[{yu}, yv^(-1)]*G[{0, 1/(yu*yv)}, yw] + 
     (G[{0}, yv^(-1)]^2*G[{yu}, yv^(-1)]*G[{0, 1/(yu*yv)}, yw])/2 - 
     G[{0}, yu^(-1)]*G[{0}, yw]*G[{yu}, yv^(-1)]*G[{0, 1/(yu*yv)}, yw] - 
     G[{0}, yv^(-1)]*G[{0}, yw]*G[{yu}, yv^(-1)]*G[{0, 1/(yu*yv)}, yw] + 
     (G[{0}, yw]^2*G[{yu}, yv^(-1)]*G[{0, 1/(yu*yv)}, yw])/2 - 
     (G[{1}, yu^(-1)]^2*G[{yu}, yv^(-1)]*G[{0, 1/(yu*yv)}, yw])/2 + 
     G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*G[{yu}, yv^(-1)]*G[{0, 1/(yu*yv)}, yw] - 
     G[{0}, yu^(-1)]*G[{1}, yw]*G[{yu}, yv^(-1)]*G[{0, 1/(yu*yv)}, yw] - 
     G[{0}, yv^(-1)]*G[{1}, yw]*G[{yu}, yv^(-1)]*G[{0, 1/(yu*yv)}, yw] + 
     G[{0}, yw]*G[{1}, yw]*G[{yu}, yv^(-1)]*G[{0, 1/(yu*yv)}, yw] - 
     G[{1}, yw]^2*G[{yu}, yv^(-1)]*G[{0, 1/(yu*yv)}, yw] - 
     G[{0}, yu^(-1)]*G[{yu}, yv^(-1)]^2*G[{0, 1/(yu*yv)}, yw] - 
     G[{0}, yv^(-1)]*G[{yu}, yv^(-1)]^2*G[{0, 1/(yu*yv)}, yw] + 
     G[{0}, yw]*G[{yu}, yv^(-1)]^2*G[{0, 1/(yu*yv)}, yw] + 
     G[{1}, yw]*G[{yu}, yv^(-1)]^2*G[{0, 1/(yu*yv)}, yw] + 
     (2*G[{yu}, yv^(-1)]^3*G[{0, 1/(yu*yv)}, yw])/3 - 
     G[{1}, yu^(-1)]*G[{0, 1}, yu^(-1)]*G[{0, 1/(yu*yv)}, yw] + 
     G[{yu}, yv^(-1)]*G[{0, 1}, yu^(-1)]*G[{0, 1/(yu*yv)}, yw] - 
     G[{0}, yu^(-1)]*G[{0, 1}, yv^(-1)]*G[{0, 1/(yu*yv)}, yw] - 
     G[{0}, yv^(-1)]*G[{0, 1}, yv^(-1)]*G[{0, 1/(yu*yv)}, yw] + 
     G[{0}, yw]*G[{0, 1}, yv^(-1)]*G[{0, 1/(yu*yv)}, yw] + 
     G[{1}, yv^(-1)]*G[{0, 1}, yv^(-1)]*G[{0, 1/(yu*yv)}, yw] - 
     G[{1}, yw]*G[{0, 1}, yv^(-1)]*G[{0, 1/(yu*yv)}, yw] - 
     G[{0}, yu^(-1)]*G[{0, 1}, yw]*G[{0, 1/(yu*yv)}, yw] - 
     G[{0}, yv^(-1)]*G[{0, 1}, yw]*G[{0, 1/(yu*yv)}, yw] + 
     G[{0}, yw]*G[{0, 1}, yw]*G[{0, 1/(yu*yv)}, yw] + 
     2*G[{1}, yu^(-1)]*G[{0, 1}, yw]*G[{0, 1/(yu*yv)}, yw] - 
     G[{1}, yw]*G[{0, 1}, yw]*G[{0, 1/(yu*yv)}, yw] + 
     G[{0}, yu^(-1)]*G[{0, yu^(-1)}, yw]*G[{0, 1/(yu*yv)}, yw] + 
     G[{0}, yv^(-1)]*G[{0, yu^(-1)}, yw]*G[{0, 1/(yu*yv)}, yw] - 
     G[{0}, yw]*G[{0, yu^(-1)}, yw]*G[{0, 1/(yu*yv)}, yw] - 
     2*G[{1}, yu^(-1)]*G[{0, yu^(-1)}, yw]*G[{0, 1/(yu*yv)}, yw] + 
     G[{1}, yw]*G[{0, yu^(-1)}, yw]*G[{0, 1/(yu*yv)}, yw] + 
     G[{0}, yu^(-1)]*G[{0, yu}, yv^(-1)]*G[{0, 1/(yu*yv)}, yw] + 
     G[{0}, yv^(-1)]*G[{0, yu}, yv^(-1)]*G[{0, 1/(yu*yv)}, yw] - 
     G[{0}, yw]*G[{0, yu}, yv^(-1)]*G[{0, 1/(yu*yv)}, yw] - 
     G[{1}, yv^(-1)]*G[{0, yu}, yv^(-1)]*G[{0, 1/(yu*yv)}, yw] + 
     G[{1}, yw]*G[{0, yu}, yv^(-1)]*G[{0, 1/(yu*yv)}, yw] + 
     G[{0}, yu^(-1)]*G[{0, yv^(-1)}, yw]*G[{0, 1/(yu*yv)}, yw] + 
     G[{0}, yv^(-1)]*G[{0, yv^(-1)}, yw]*G[{0, 1/(yu*yv)}, yw] - 
     G[{0}, yw]*G[{0, yv^(-1)}, yw]*G[{0, 1/(yu*yv)}, yw] - 
     2*G[{1}, yu^(-1)]*G[{0, yv^(-1)}, yw]*G[{0, 1/(yu*yv)}, yw] + 
     G[{1}, yw]*G[{0, yv^(-1)}, yw]*G[{0, 1/(yu*yv)}, yw] - 
     (G[{0}, yu^(-1)]*G[{0, 1/(yu*yv)}, yw]^2)/2 - 
     (G[{0}, yv^(-1)]*G[{0, 1/(yu*yv)}, yw]^2)/2 + 
     (G[{0}, yw]*G[{0, 1/(yu*yv)}, yw]^2)/2 + G[{1}, yu^(-1)]*
      G[{0, 1/(yu*yv)}, yw]^2 - (G[{1}, yw]*G[{0, 1/(yu*yv)}, yw]^2)/2 + 
     G[{1}, yu^(-1)]*G[{0, 1}, yw]*G[{1, yu}, yv^(-1)] + 
     G[{1}, yw]*G[{0, 1}, yw]*G[{1, yu}, yv^(-1)] + 
     G[{yu}, yv^(-1)]*G[{0, 1}, yw]*G[{1, yu}, yv^(-1)] + 
     G[{0}, yu^(-1)]*G[{0, yu^(-1)}, yw]*G[{1, yu}, yv^(-1)] + 
     G[{0}, yv^(-1)]*G[{0, yu^(-1)}, yw]*G[{1, yu}, yv^(-1)] - 
     G[{0}, yw]*G[{0, yu^(-1)}, yw]*G[{1, yu}, yv^(-1)] + 
     G[{1}, yw]*G[{0, yu^(-1)}, yw]*G[{1, yu}, yv^(-1)] - 
     G[{1}, yw]*G[{0, yv^(-1)}, yw]*G[{1, yu}, yv^(-1)] - 
     G[{0}, yu^(-1)]*G[{0, 1/(yu*yv)}, yw]*G[{1, yu}, yv^(-1)] - 
     G[{0}, yv^(-1)]*G[{0, 1/(yu*yv)}, yw]*G[{1, yu}, yv^(-1)] + 
     G[{0}, yw]*G[{0, 1/(yu*yv)}, yw]*G[{1, yu}, yv^(-1)] - 
     G[{1}, yu^(-1)]*G[{0, 1/(yu*yv)}, yw]*G[{1, yu}, yv^(-1)] - 
     G[{1}, yw]*G[{0, 1/(yu*yv)}, yw]*G[{1, yu}, yv^(-1)] - 
     G[{yu}, yv^(-1)]*G[{0, 1/(yu*yv)}, yw]*G[{1, yu}, yv^(-1)] + 
     (Pi^2*G[{0, 0, 1}, yv^(-1)])/6 + 
     (G[{0}, yu^(-1)]^2*G[{0, 0, 1}, yv^(-1)])/2 + 
     G[{0}, yu^(-1)]*G[{0}, yv^(-1)]*G[{0, 0, 1}, yv^(-1)] + 
     (G[{0}, yv^(-1)]^2*G[{0, 0, 1}, yv^(-1)])/2 - G[{0}, yu^(-1)]*G[{0}, yw]*
      G[{0, 0, 1}, yv^(-1)] - G[{0}, yv^(-1)]*G[{0}, yw]*
      G[{0, 0, 1}, yv^(-1)] + (G[{0}, yw]^2*G[{0, 0, 1}, yv^(-1)])/2 - 
     (G[{1}, yu^(-1)]^2*G[{0, 0, 1}, yv^(-1)])/2 + G[{0}, yu^(-1)]*G[{1}, yw]*
      G[{0, 0, 1}, yv^(-1)] + G[{0}, yv^(-1)]*G[{1}, yw]*
      G[{0, 0, 1}, yv^(-1)] - G[{0}, yw]*G[{1}, yw]*G[{0, 0, 1}, yv^(-1)] + 
     G[{0, 1}, yv^(-1)]*G[{0, 0, 1}, yv^(-1)] - G[{0, yu^(-1)}, yw]*
      G[{0, 0, 1}, yv^(-1)] + G[{0, 1/(yu*yv)}, yw]*G[{0, 0, 1}, yv^(-1)] + 
     (Pi^2*G[{0, 0, 1}, yw])/3 + (G[{0}, yu^(-1)]^2*G[{0, 0, 1}, yw])/2 + 
     G[{0}, yu^(-1)]*G[{0}, yv^(-1)]*G[{0, 0, 1}, yw] + 
     (G[{0}, yv^(-1)]^2*G[{0, 0, 1}, yw])/2 - G[{0}, yu^(-1)]*G[{0}, yw]*
      G[{0, 0, 1}, yw] - G[{0}, yv^(-1)]*G[{0}, yw]*G[{0, 0, 1}, yw] + 
     (G[{0}, yw]^2*G[{0, 0, 1}, yw])/2 + G[{0}, yu^(-1)]*G[{1}, yu^(-1)]*
      G[{0, 0, 1}, yw] + G[{0}, yv^(-1)]*G[{1}, yu^(-1)]*G[{0, 0, 1}, yw] - 
     G[{0}, yw]*G[{1}, yu^(-1)]*G[{0, 0, 1}, yw] - 
     (3*G[{1}, yu^(-1)]^2*G[{0, 0, 1}, yw])/2 + G[{1}, yu^(-1)]*
      G[{1}, yv^(-1)]*G[{0, 0, 1}, yw] - G[{0}, yu^(-1)]*G[{1}, yw]*
      G[{0, 0, 1}, yw] - G[{0}, yv^(-1)]*G[{1}, yw]*G[{0, 0, 1}, yw] + 
     G[{0}, yw]*G[{1}, yw]*G[{0, 0, 1}, yw] + 2*G[{1}, yu^(-1)]*G[{1}, yw]*
      G[{0, 0, 1}, yw] - G[{1}, yw]^2*G[{0, 0, 1}, yw] - 
     3*G[{0}, yu^(-1)]*G[{yu}, yv^(-1)]*G[{0, 0, 1}, yw] - 
     3*G[{0}, yv^(-1)]*G[{yu}, yv^(-1)]*G[{0, 0, 1}, yw] + 
     3*G[{0}, yw]*G[{yu}, yv^(-1)]*G[{0, 0, 1}, yw] + 
     3*G[{yu}, yv^(-1)]^2*G[{0, 0, 1}, yw] + G[{0, 1}, yu^(-1)]*
      G[{0, 0, 1}, yw] + G[{0, yu^(-1)}, yw]*G[{0, 0, 1}, yw] - 
     G[{0, 1/(yu*yv)}, yw]*G[{0, 0, 1}, yw] - G[{1, yu}, yv^(-1)]*
      G[{0, 0, 1}, yw] - (Pi^2*G[{0, 0, yu^(-1)}, yw])/6 - 
     (G[{0}, yu^(-1)]^2*G[{0, 0, yu^(-1)}, yw])/2 - 
     G[{0}, yu^(-1)]*G[{0}, yv^(-1)]*G[{0, 0, yu^(-1)}, yw] - 
     (G[{0}, yv^(-1)]^2*G[{0, 0, yu^(-1)}, yw])/2 + 
     G[{0}, yu^(-1)]*G[{0}, yw]*G[{0, 0, yu^(-1)}, yw] + 
     G[{0}, yv^(-1)]*G[{0}, yw]*G[{0, 0, yu^(-1)}, yw] - 
     (G[{0}, yw]^2*G[{0, 0, yu^(-1)}, yw])/2 - G[{0}, yu^(-1)]*
      G[{1}, yu^(-1)]*G[{0, 0, yu^(-1)}, yw] - G[{0}, yv^(-1)]*
      G[{1}, yu^(-1)]*G[{0, 0, yu^(-1)}, yw] + G[{0}, yw]*G[{1}, yu^(-1)]*
      G[{0, 0, yu^(-1)}, yw] + (3*G[{1}, yu^(-1)]^2*G[{0, 0, yu^(-1)}, yw])/
      2 + 3*G[{0}, yu^(-1)]*G[{1}, yv^(-1)]*G[{0, 0, yu^(-1)}, yw] + 
     3*G[{0}, yv^(-1)]*G[{1}, yv^(-1)]*G[{0, 0, yu^(-1)}, yw] - 
     3*G[{0}, yw]*G[{1}, yv^(-1)]*G[{0, 0, yu^(-1)}, yw] - 
     G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*G[{0, 0, yu^(-1)}, yw] - 
     3*G[{1}, yv^(-1)]^2*G[{0, 0, yu^(-1)}, yw] + G[{0}, yu^(-1)]*G[{1}, yw]*
      G[{0, 0, yu^(-1)}, yw] + G[{0}, yv^(-1)]*G[{1}, yw]*
      G[{0, 0, yu^(-1)}, yw] - G[{0}, yw]*G[{1}, yw]*G[{0, 0, yu^(-1)}, yw] - 
     2*G[{1}, yu^(-1)]*G[{1}, yw]*G[{0, 0, yu^(-1)}, yw] + 
     G[{1}, yw]^2*G[{0, 0, yu^(-1)}, yw] + G[{0, 1}, yv^(-1)]*
      G[{0, 0, yu^(-1)}, yw] - G[{0, yu^(-1)}, yw]*G[{0, 0, yu^(-1)}, yw] - 
     G[{0, yu}, yv^(-1)]*G[{0, 0, yu^(-1)}, yw] + G[{0, 1/(yu*yv)}, yw]*
      G[{0, 0, yu^(-1)}, yw] + G[{1, yu}, yv^(-1)]*G[{0, 0, yu^(-1)}, yw] - 
     (Pi^2*G[{0, 0, yu}, yv^(-1)])/3 - 
     (G[{0}, yu^(-1)]^2*G[{0, 0, yu}, yv^(-1)])/2 - 
     G[{0}, yu^(-1)]*G[{0}, yv^(-1)]*G[{0, 0, yu}, yv^(-1)] - 
     (G[{0}, yv^(-1)]^2*G[{0, 0, yu}, yv^(-1)])/2 + 
     G[{0}, yu^(-1)]*G[{0}, yw]*G[{0, 0, yu}, yv^(-1)] + 
     G[{0}, yv^(-1)]*G[{0}, yw]*G[{0, 0, yu}, yv^(-1)] - 
     (G[{0}, yw]^2*G[{0, 0, yu}, yv^(-1)])/2 + 
     (G[{1}, yu^(-1)]^2*G[{0, 0, yu}, yv^(-1)])/2 - 
     G[{0}, yu^(-1)]*G[{1}, yw]*G[{0, 0, yu}, yv^(-1)] - 
     G[{0}, yv^(-1)]*G[{1}, yw]*G[{0, 0, yu}, yv^(-1)] + 
     G[{0}, yw]*G[{1}, yw]*G[{0, 0, yu}, yv^(-1)] - 
     G[{0, 1}, yu^(-1)]*G[{0, 0, yu}, yv^(-1)] - G[{0, 1}, yv^(-1)]*
      G[{0, 0, yu}, yv^(-1)] + G[{0, yu^(-1)}, yw]*G[{0, 0, yu}, yv^(-1)] - 
     G[{0, 1/(yu*yv)}, yw]*G[{0, 0, yu}, yv^(-1)] - 
     (Pi^2*G[{0, 0, yv^(-1)}, yw])/3 - 
     (G[{0}, yu^(-1)]^2*G[{0, 0, yv^(-1)}, yw])/2 - 
     G[{0}, yu^(-1)]*G[{0}, yv^(-1)]*G[{0, 0, yv^(-1)}, yw] - 
     (G[{0}, yv^(-1)]^2*G[{0, 0, yv^(-1)}, yw])/2 + 
     G[{0}, yu^(-1)]*G[{0}, yw]*G[{0, 0, yv^(-1)}, yw] + 
     G[{0}, yv^(-1)]*G[{0}, yw]*G[{0, 0, yv^(-1)}, yw] - 
     (G[{0}, yw]^2*G[{0, 0, yv^(-1)}, yw])/2 + 2*G[{0}, yu^(-1)]*
      G[{1}, yu^(-1)]*G[{0, 0, yv^(-1)}, yw] + 2*G[{0}, yv^(-1)]*
      G[{1}, yu^(-1)]*G[{0, 0, yv^(-1)}, yw] - 2*G[{0}, yw]*G[{1}, yu^(-1)]*
      G[{0, 0, yv^(-1)}, yw] - (3*G[{1}, yu^(-1)]^2*G[{0, 0, yv^(-1)}, yw])/
      2 - G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*G[{0, 0, yv^(-1)}, yw] + 
     G[{0}, yu^(-1)]*G[{1}, yw]*G[{0, 0, yv^(-1)}, yw] + 
     G[{0}, yv^(-1)]*G[{1}, yw]*G[{0, 0, yv^(-1)}, yw] - 
     G[{0}, yw]*G[{1}, yw]*G[{0, 0, yv^(-1)}, yw] - 
     2*G[{1}, yu^(-1)]*G[{1}, yw]*G[{0, 0, yv^(-1)}, yw] + 
     G[{1}, yw]^2*G[{0, 0, yv^(-1)}, yw] - G[{0, 1}, yu^(-1)]*
      G[{0, 0, yv^(-1)}, yw] - G[{0, yu^(-1)}, yw]*G[{0, 0, yv^(-1)}, yw] + 
     G[{0, 1/(yu*yv)}, yw]*G[{0, 0, yv^(-1)}, yw] + 
     G[{1, yu}, yv^(-1)]*G[{0, 0, yv^(-1)}, yw] + 
     (Pi^2*G[{0, 0, 1/(yu*yv)}, yw])/6 + 
     (G[{0}, yu^(-1)]^2*G[{0, 0, 1/(yu*yv)}, yw])/2 + 
     G[{0}, yu^(-1)]*G[{0}, yv^(-1)]*G[{0, 0, 1/(yu*yv)}, yw] + 
     (G[{0}, yv^(-1)]^2*G[{0, 0, 1/(yu*yv)}, yw])/2 - 
     G[{0}, yu^(-1)]*G[{0}, yw]*G[{0, 0, 1/(yu*yv)}, yw] - 
     G[{0}, yv^(-1)]*G[{0}, yw]*G[{0, 0, 1/(yu*yv)}, yw] + 
     (G[{0}, yw]^2*G[{0, 0, 1/(yu*yv)}, yw])/2 - 2*G[{0}, yu^(-1)]*
      G[{1}, yu^(-1)]*G[{0, 0, 1/(yu*yv)}, yw] - 2*G[{0}, yv^(-1)]*
      G[{1}, yu^(-1)]*G[{0, 0, 1/(yu*yv)}, yw] + 2*G[{0}, yw]*G[{1}, yu^(-1)]*
      G[{0, 0, 1/(yu*yv)}, yw] + (3*G[{1}, yu^(-1)]^2*
       G[{0, 0, 1/(yu*yv)}, yw])/2 - 3*G[{0}, yu^(-1)]*G[{1}, yv^(-1)]*
      G[{0, 0, 1/(yu*yv)}, yw] - 3*G[{0}, yv^(-1)]*G[{1}, yv^(-1)]*
      G[{0, 0, 1/(yu*yv)}, yw] + 3*G[{0}, yw]*G[{1}, yv^(-1)]*
      G[{0, 0, 1/(yu*yv)}, yw] + G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*
      G[{0, 0, 1/(yu*yv)}, yw] + 3*G[{1}, yv^(-1)]^2*
      G[{0, 0, 1/(yu*yv)}, yw] - G[{0}, yu^(-1)]*G[{1}, yw]*
      G[{0, 0, 1/(yu*yv)}, yw] - G[{0}, yv^(-1)]*G[{1}, yw]*
      G[{0, 0, 1/(yu*yv)}, yw] + G[{0}, yw]*G[{1}, yw]*
      G[{0, 0, 1/(yu*yv)}, yw] + 2*G[{1}, yu^(-1)]*G[{1}, yw]*
      G[{0, 0, 1/(yu*yv)}, yw] - G[{1}, yw]^2*G[{0, 0, 1/(yu*yv)}, yw] + 
     3*G[{0}, yu^(-1)]*G[{yu}, yv^(-1)]*G[{0, 0, 1/(yu*yv)}, yw] + 
     3*G[{0}, yv^(-1)]*G[{yu}, yv^(-1)]*G[{0, 0, 1/(yu*yv)}, yw] - 
     3*G[{0}, yw]*G[{yu}, yv^(-1)]*G[{0, 0, 1/(yu*yv)}, yw] - 
     3*G[{yu}, yv^(-1)]^2*G[{0, 0, 1/(yu*yv)}, yw] - 
     G[{0, 1}, yv^(-1)]*G[{0, 0, 1/(yu*yv)}, yw] + 
     G[{0, yu^(-1)}, yw]*G[{0, 0, 1/(yu*yv)}, yw] + 
     G[{0, yu}, yv^(-1)]*G[{0, 0, 1/(yu*yv)}, yw] - 
     G[{0, 1/(yu*yv)}, yw]*G[{0, 0, 1/(yu*yv)}, yw] - 
     G[{1, yu}, yv^(-1)]*G[{0, 0, 1/(yu*yv)}, yw] - 
     (2*Pi^2*G[{0, 1, 1}, yu^(-1)])/3 - G[{0}, yu^(-1)]^2*
      G[{0, 1, 1}, yu^(-1)] - 2*G[{0}, yu^(-1)]*G[{0}, yv^(-1)]*
      G[{0, 1, 1}, yu^(-1)] - G[{0}, yv^(-1)]^2*G[{0, 1, 1}, yu^(-1)] + 
     2*G[{0}, yu^(-1)]*G[{0}, yw]*G[{0, 1, 1}, yu^(-1)] + 
     2*G[{0}, yv^(-1)]*G[{0}, yw]*G[{0, 1, 1}, yu^(-1)] - 
     G[{0}, yw]^2*G[{0, 1, 1}, yu^(-1)] + G[{1}, yu^(-1)]^2*
      G[{0, 1, 1}, yu^(-1)] - 2*G[{1}, yu^(-1)]*G[{1}, yw]*
      G[{0, 1, 1}, yu^(-1)] + G[{1}, yw]^2*G[{0, 1, 1}, yu^(-1)] - 
     2*G[{0, 1}, yu^(-1)]*G[{0, 1, 1}, yu^(-1)] + 2*G[{0, 1}, yv^(-1)]*
      G[{0, 1, 1}, yu^(-1)] - 2*G[{0, 1}, yw]*G[{0, 1, 1}, yu^(-1)] + 
     2*G[{0, 1/(yu*yv)}, yw]*G[{0, 1, 1}, yu^(-1)] - 
     (Pi^2*G[{0, 1, 1}, yv^(-1)])/6 - 
     (G[{0}, yu^(-1)]^2*G[{0, 1, 1}, yv^(-1)])/2 - 
     G[{0}, yu^(-1)]*G[{0}, yv^(-1)]*G[{0, 1, 1}, yv^(-1)] - 
     (G[{0}, yv^(-1)]^2*G[{0, 1, 1}, yv^(-1)])/2 + G[{0}, yu^(-1)]*G[{0}, yw]*
      G[{0, 1, 1}, yv^(-1)] + G[{0}, yv^(-1)]*G[{0}, yw]*
      G[{0, 1, 1}, yv^(-1)] - (G[{0}, yw]^2*G[{0, 1, 1}, yv^(-1)])/2 + 
     (G[{1}, yu^(-1)]^2*G[{0, 1, 1}, yv^(-1)])/2 + G[{0}, yu^(-1)]*G[{1}, yw]*
      G[{0, 1, 1}, yv^(-1)] + G[{0}, yv^(-1)]*G[{1}, yw]*
      G[{0, 1, 1}, yv^(-1)] - G[{0}, yw]*G[{1}, yw]*G[{0, 1, 1}, yv^(-1)] - 
     G[{1}, yu^(-1)]*G[{1}, yw]*G[{0, 1, 1}, yv^(-1)] + 
     G[{1}, yw]^2*G[{0, 1, 1}, yv^(-1)] + G[{0, 1}, yv^(-1)]*
      G[{0, 1, 1}, yv^(-1)] + G[{0, yu^(-1)}, yw]*G[{0, 1, 1}, yv^(-1)] - 
     G[{0, 1/(yu*yv)}, yw]*G[{0, 1, 1}, yv^(-1)] + (2*Pi^2*G[{0, 1, 1}, yw])/
      3 + G[{0}, yu^(-1)]^2*G[{0, 1, 1}, yw] + 2*G[{0}, yu^(-1)]*
      G[{0}, yv^(-1)]*G[{0, 1, 1}, yw] + G[{0}, yv^(-1)]^2*G[{0, 1, 1}, yw] - 
     2*G[{0}, yu^(-1)]*G[{0}, yw]*G[{0, 1, 1}, yw] - 
     2*G[{0}, yv^(-1)]*G[{0}, yw]*G[{0, 1, 1}, yw] + 
     G[{0}, yw]^2*G[{0, 1, 1}, yw] - G[{0}, yu^(-1)]*G[{1}, yu^(-1)]*
      G[{0, 1, 1}, yw] - G[{0}, yv^(-1)]*G[{1}, yu^(-1)]*G[{0, 1, 1}, yw] + 
     G[{0}, yw]*G[{1}, yu^(-1)]*G[{0, 1, 1}, yw] + 
     2*G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*G[{0, 1, 1}, yw] + 
     G[{1}, yu^(-1)]*G[{1}, yw]*G[{0, 1, 1}, yw] - 
     G[{1}, yw]^2*G[{0, 1, 1}, yw] - 3*G[{0}, yu^(-1)]*G[{yu}, yv^(-1)]*
      G[{0, 1, 1}, yw] - 3*G[{0}, yv^(-1)]*G[{yu}, yv^(-1)]*
      G[{0, 1, 1}, yw] + 3*G[{0}, yw]*G[{yu}, yv^(-1)]*G[{0, 1, 1}, yw] - 
     G[{1}, yw]*G[{yu}, yv^(-1)]*G[{0, 1, 1}, yw] + 
     3*G[{yu}, yv^(-1)]^2*G[{0, 1, 1}, yw] + 2*G[{0, 1}, yu^(-1)]*
      G[{0, 1, 1}, yw] - G[{0, yu^(-1)}, yw]*G[{0, 1, 1}, yw] + 
     G[{0, 1/(yu*yv)}, yw]*G[{0, 1, 1}, yw] - 2*G[{1, yu}, yv^(-1)]*
      G[{0, 1, 1}, yw] + 2*G[{0, yu^(-1)}, yw]*G[{0, 1, yu^(-1)}, yw] - 
     2*G[{0, 1/(yu*yv)}, yw]*G[{0, 1, yu^(-1)}, yw] + 
     (Pi^2*G[{0, 1, yu}, yv^(-1)])/3 + 
     (G[{0}, yu^(-1)]^2*G[{0, 1, yu}, yv^(-1)])/2 + 
     G[{0}, yu^(-1)]*G[{0}, yv^(-1)]*G[{0, 1, yu}, yv^(-1)] + 
     (G[{0}, yv^(-1)]^2*G[{0, 1, yu}, yv^(-1)])/2 - 
     G[{0}, yu^(-1)]*G[{0}, yw]*G[{0, 1, yu}, yv^(-1)] - 
     G[{0}, yv^(-1)]*G[{0}, yw]*G[{0, 1, yu}, yv^(-1)] + 
     (G[{0}, yw]^2*G[{0, 1, yu}, yv^(-1)])/2 - 
     (G[{1}, yu^(-1)]^2*G[{0, 1, yu}, yv^(-1)])/2 + 
     G[{0}, yu^(-1)]*G[{1}, yw]*G[{0, 1, yu}, yv^(-1)] + 
     G[{0}, yv^(-1)]*G[{1}, yw]*G[{0, 1, yu}, yv^(-1)] - 
     G[{0}, yw]*G[{1}, yw]*G[{0, 1, yu}, yv^(-1)] + 
     G[{0, 1}, yu^(-1)]*G[{0, 1, yu}, yv^(-1)] - 2*G[{0, yu^(-1)}, yw]*
      G[{0, 1, yu}, yv^(-1)] + 2*G[{0, 1/(yu*yv)}, yw]*
      G[{0, 1, yu}, yv^(-1)] - (Pi^2*G[{0, 1, yv^(-1)}, yw])/3 - 
     (G[{0}, yu^(-1)]^2*G[{0, 1, yv^(-1)}, yw])/2 - 
     G[{0}, yu^(-1)]*G[{0}, yv^(-1)]*G[{0, 1, yv^(-1)}, yw] - 
     (G[{0}, yv^(-1)]^2*G[{0, 1, yv^(-1)}, yw])/2 + 
     G[{0}, yu^(-1)]*G[{0}, yw]*G[{0, 1, yv^(-1)}, yw] + 
     G[{0}, yv^(-1)]*G[{0}, yw]*G[{0, 1, yv^(-1)}, yw] - 
     (G[{0}, yw]^2*G[{0, 1, yv^(-1)}, yw])/2 + 2*G[{0}, yu^(-1)]*
      G[{1}, yu^(-1)]*G[{0, 1, yv^(-1)}, yw] + 2*G[{0}, yv^(-1)]*
      G[{1}, yu^(-1)]*G[{0, 1, yv^(-1)}, yw] - 2*G[{0}, yw]*G[{1}, yu^(-1)]*
      G[{0, 1, yv^(-1)}, yw] - (3*G[{1}, yu^(-1)]^2*G[{0, 1, yv^(-1)}, yw])/
      2 - G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*G[{0, 1, yv^(-1)}, yw] - 
     G[{0}, yu^(-1)]*G[{1}, yw]*G[{0, 1, yv^(-1)}, yw] - 
     G[{0}, yv^(-1)]*G[{1}, yw]*G[{0, 1, yv^(-1)}, yw] + 
     G[{0}, yw]*G[{1}, yw]*G[{0, 1, yv^(-1)}, yw] + 
     2*G[{1}, yu^(-1)]*G[{1}, yw]*G[{0, 1, yv^(-1)}, yw] - 
     G[{0, 1}, yu^(-1)]*G[{0, 1, yv^(-1)}, yw] + 2*G[{0, yu^(-1)}, yw]*
      G[{0, 1, yv^(-1)}, yw] - 2*G[{0, 1/(yu*yv)}, yw]*
      G[{0, 1, yv^(-1)}, yw] + G[{1, yu}, yv^(-1)]*G[{0, 1, yv^(-1)}, yw] - 
     G[{1}, yu^(-1)]*G[{1}, yw]*G[{0, 1, 1/(yu*yv)}, yw] + 
     G[{1}, yw]*G[{yu}, yv^(-1)]*G[{0, 1, 1/(yu*yv)}, yw] + 
     G[{0, yv^(-1)}, yw]*G[{0, 1, 1/(yu*yv)}, yw] + 
     G[{0, 1/(yu*yv)}, yw]*G[{0, 1, 1/(yu*yv)}, yw] - 
     G[{0}, yu^(-1)]*G[{1}, yu^(-1)]*G[{0, yu^(-1), 1}, yw] - 
     G[{0}, yv^(-1)]*G[{1}, yu^(-1)]*G[{0, yu^(-1), 1}, yw] + 
     G[{0}, yw]*G[{1}, yu^(-1)]*G[{0, yu^(-1), 1}, yw] + 
     G[{1}, yu^(-1)]^2*G[{0, yu^(-1), 1}, yw] - G[{1}, yu^(-1)]*G[{1}, yw]*
      G[{0, yu^(-1), 1}, yw] + G[{0}, yu^(-1)]*G[{yu}, yv^(-1)]*
      G[{0, yu^(-1), 1}, yw] + G[{0}, yv^(-1)]*G[{yu}, yv^(-1)]*
      G[{0, yu^(-1), 1}, yw] - G[{0}, yw]*G[{yu}, yv^(-1)]*
      G[{0, yu^(-1), 1}, yw] + G[{1}, yw]*G[{yu}, yv^(-1)]*
      G[{0, yu^(-1), 1}, yw] - G[{yu}, yv^(-1)]^2*G[{0, yu^(-1), 1}, yw] - 
     G[{0, 1/(yu*yv)}, yw]*G[{0, yu^(-1), 1}, yw] - 
     (Pi^2*G[{0, yu^(-1), yu^(-1)}, yw])/3 - G[{0}, yu^(-1)]^2*
      G[{0, yu^(-1), yu^(-1)}, yw] - 2*G[{0}, yu^(-1)]*G[{0}, yv^(-1)]*
      G[{0, yu^(-1), yu^(-1)}, yw] - G[{0}, yv^(-1)]^2*
      G[{0, yu^(-1), yu^(-1)}, yw] + 2*G[{0}, yu^(-1)]*G[{0}, yw]*
      G[{0, yu^(-1), yu^(-1)}, yw] + 2*G[{0}, yv^(-1)]*G[{0}, yw]*
      G[{0, yu^(-1), yu^(-1)}, yw] - G[{0}, yw]^2*G[{0, yu^(-1), yu^(-1)}, 
       yw] + 2*G[{0}, yu^(-1)]*G[{1}, yu^(-1)]*G[{0, yu^(-1), yu^(-1)}, yw] + 
     2*G[{0}, yv^(-1)]*G[{1}, yu^(-1)]*G[{0, yu^(-1), yu^(-1)}, yw] - 
     2*G[{0}, yw]*G[{1}, yu^(-1)]*G[{0, yu^(-1), yu^(-1)}, yw] - 
     G[{1}, yu^(-1)]^2*G[{0, yu^(-1), yu^(-1)}, yw] + 
     2*G[{0}, yu^(-1)]*G[{1}, yv^(-1)]*G[{0, yu^(-1), yu^(-1)}, yw] + 
     2*G[{0}, yv^(-1)]*G[{1}, yv^(-1)]*G[{0, yu^(-1), yu^(-1)}, yw] - 
     2*G[{0}, yw]*G[{1}, yv^(-1)]*G[{0, yu^(-1), yu^(-1)}, yw] - 
     2*G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*G[{0, yu^(-1), yu^(-1)}, yw] - 
     2*G[{1}, yv^(-1)]^2*G[{0, yu^(-1), yu^(-1)}, yw] + 
     G[{1}, yw]^2*G[{0, yu^(-1), yu^(-1)}, yw] + 2*G[{0, 1}, yv^(-1)]*
      G[{0, yu^(-1), yu^(-1)}, yw] - 2*G[{0, 1}, yw]*G[{0, yu^(-1), yu^(-1)}, 
       yw] + 2*G[{0, yu^(-1)}, yw]*G[{0, yu^(-1), yu^(-1)}, yw] - 
     2*G[{0, yu}, yv^(-1)]*G[{0, yu^(-1), yu^(-1)}, yw] + 
     2*G[{0, 1/(yu*yv)}, yw]*G[{0, yu^(-1), yu^(-1)}, yw] + 
     2*G[{1, yu}, yv^(-1)]*G[{0, yu^(-1), yu^(-1)}, yw] + 
     2*G[{0, 1/(yu*yv)}, yw]*G[{0, yu^(-1), yv^(-1)}, yw] + 
     (Pi^2*G[{0, yu^(-1), 1/(yu*yv)}, yw])/6 + 
     (G[{0}, yu^(-1)]^2*G[{0, yu^(-1), 1/(yu*yv)}, yw])/2 + 
     G[{0}, yu^(-1)]*G[{0}, yv^(-1)]*G[{0, yu^(-1), 1/(yu*yv)}, yw] + 
     (G[{0}, yv^(-1)]^2*G[{0, yu^(-1), 1/(yu*yv)}, yw])/2 - 
     G[{0}, yu^(-1)]*G[{0}, yw]*G[{0, yu^(-1), 1/(yu*yv)}, yw] - 
     G[{0}, yv^(-1)]*G[{0}, yw]*G[{0, yu^(-1), 1/(yu*yv)}, yw] + 
     (G[{0}, yw]^2*G[{0, yu^(-1), 1/(yu*yv)}, yw])/2 - 
     2*G[{0}, yu^(-1)]*G[{1}, yu^(-1)]*G[{0, yu^(-1), 1/(yu*yv)}, yw] - 
     2*G[{0}, yv^(-1)]*G[{1}, yu^(-1)]*G[{0, yu^(-1), 1/(yu*yv)}, yw] + 
     2*G[{0}, yw]*G[{1}, yu^(-1)]*G[{0, yu^(-1), 1/(yu*yv)}, yw] + 
     (3*G[{1}, yu^(-1)]^2*G[{0, yu^(-1), 1/(yu*yv)}, yw])/2 + 
     G[{0}, yu^(-1)]*G[{1}, yv^(-1)]*G[{0, yu^(-1), 1/(yu*yv)}, yw] + 
     G[{0}, yv^(-1)]*G[{1}, yv^(-1)]*G[{0, yu^(-1), 1/(yu*yv)}, yw] - 
     G[{0}, yw]*G[{1}, yv^(-1)]*G[{0, yu^(-1), 1/(yu*yv)}, yw] + 
     G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*G[{0, yu^(-1), 1/(yu*yv)}, yw] - 
     G[{1}, yv^(-1)]^2*G[{0, yu^(-1), 1/(yu*yv)}, yw] + 
     G[{0}, yu^(-1)]*G[{1}, yw]*G[{0, yu^(-1), 1/(yu*yv)}, yw] + 
     G[{0}, yv^(-1)]*G[{1}, yw]*G[{0, yu^(-1), 1/(yu*yv)}, yw] - 
     G[{0}, yw]*G[{1}, yw]*G[{0, yu^(-1), 1/(yu*yv)}, yw] - 
     G[{1}, yu^(-1)]*G[{1}, yw]*G[{0, yu^(-1), 1/(yu*yv)}, yw] - 
     G[{0}, yu^(-1)]*G[{yu}, yv^(-1)]*G[{0, yu^(-1), 1/(yu*yv)}, yw] - 
     G[{0}, yv^(-1)]*G[{yu}, yv^(-1)]*G[{0, yu^(-1), 1/(yu*yv)}, yw] + 
     G[{0}, yw]*G[{yu}, yv^(-1)]*G[{0, yu^(-1), 1/(yu*yv)}, yw] - 
     G[{1}, yw]*G[{yu}, yv^(-1)]*G[{0, yu^(-1), 1/(yu*yv)}, yw] + 
     G[{yu}, yv^(-1)]^2*G[{0, yu^(-1), 1/(yu*yv)}, yw] - 
     G[{0, 1}, yv^(-1)]*G[{0, yu^(-1), 1/(yu*yv)}, yw] + 
     G[{0, 1}, yw]*G[{0, yu^(-1), 1/(yu*yv)}, yw] - 
     G[{0, yu^(-1)}, yw]*G[{0, yu^(-1), 1/(yu*yv)}, yw] + 
     G[{0, yu}, yv^(-1)]*G[{0, yu^(-1), 1/(yu*yv)}, yw] - 
     2*G[{0, yv^(-1)}, yw]*G[{0, yu^(-1), 1/(yu*yv)}, yw] - 
     G[{0, 1/(yu*yv)}, yw]*G[{0, yu^(-1), 1/(yu*yv)}, yw] - 
     G[{1, yu}, yv^(-1)]*G[{0, yu^(-1), 1/(yu*yv)}, yw] + 
     G[{1}, yu^(-1)]*G[{1}, yw]*G[{0, yu, 1}, yv^(-1)] - 
     G[{0, yu^(-1)}, yw]*G[{0, yu, 1}, yv^(-1)] + G[{0, 1/(yu*yv)}, yw]*
      G[{0, yu, 1}, yv^(-1)] - 2*G[{0}, yu^(-1)]*G[{1}, yw]*
      G[{0, yu, yu}, yv^(-1)] - 2*G[{0}, yv^(-1)]*G[{1}, yw]*
      G[{0, yu, yu}, yv^(-1)] + 2*G[{0}, yw]*G[{1}, yw]*
      G[{0, yu, yu}, yv^(-1)] - G[{1}, yw]^2*G[{0, yu, yu}, yv^(-1)] + 
     2*G[{0, yu^(-1)}, yw]*G[{0, yu, yu}, yv^(-1)] - 
     2*G[{0, 1/(yu*yv)}, yw]*G[{0, yu, yu}, yv^(-1)] - 
     (Pi^2*G[{0, yv^(-1), 1}, yw])/3 - 
     (G[{0}, yu^(-1)]^2*G[{0, yv^(-1), 1}, yw])/2 - 
     G[{0}, yu^(-1)]*G[{0}, yv^(-1)]*G[{0, yv^(-1), 1}, yw] - 
     (G[{0}, yv^(-1)]^2*G[{0, yv^(-1), 1}, yw])/2 + 
     G[{0}, yu^(-1)]*G[{0}, yw]*G[{0, yv^(-1), 1}, yw] + 
     G[{0}, yv^(-1)]*G[{0}, yw]*G[{0, yv^(-1), 1}, yw] - 
     (G[{0}, yw]^2*G[{0, yv^(-1), 1}, yw])/2 + 2*G[{0}, yu^(-1)]*
      G[{1}, yu^(-1)]*G[{0, yv^(-1), 1}, yw] + 2*G[{0}, yv^(-1)]*
      G[{1}, yu^(-1)]*G[{0, yv^(-1), 1}, yw] - 2*G[{0}, yw]*G[{1}, yu^(-1)]*
      G[{0, yv^(-1), 1}, yw] - (3*G[{1}, yu^(-1)]^2*G[{0, yv^(-1), 1}, yw])/
      2 - G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*G[{0, yv^(-1), 1}, yw] - 
     G[{0}, yu^(-1)]*G[{1}, yw]*G[{0, yv^(-1), 1}, yw] - 
     G[{0}, yv^(-1)]*G[{1}, yw]*G[{0, yv^(-1), 1}, yw] + 
     G[{0}, yw]*G[{1}, yw]*G[{0, yv^(-1), 1}, yw] + 
     G[{1}, yu^(-1)]*G[{1}, yw]*G[{0, yv^(-1), 1}, yw] + 
     G[{1}, yw]*G[{yu}, yv^(-1)]*G[{0, yv^(-1), 1}, yw] - 
     G[{0, 1}, yu^(-1)]*G[{0, yv^(-1), 1}, yw] - G[{0, 1/(yu*yv)}, yw]*
      G[{0, yv^(-1), 1}, yw] + G[{1, yu}, yv^(-1)]*G[{0, yv^(-1), 1}, yw] + 
     2*G[{0, 1/(yu*yv)}, yw]*G[{0, yv^(-1), yu^(-1)}, yw] + 
     2*G[{0}, yu^(-1)]*G[{1}, yw]*G[{0, yv^(-1), yv^(-1)}, yw] + 
     2*G[{0}, yv^(-1)]*G[{1}, yw]*G[{0, yv^(-1), yv^(-1)}, yw] - 
     2*G[{0}, yw]*G[{1}, yw]*G[{0, yv^(-1), yv^(-1)}, yw] - 
     4*G[{1}, yu^(-1)]*G[{1}, yw]*G[{0, yv^(-1), yv^(-1)}, yw] + 
     G[{1}, yw]^2*G[{0, yv^(-1), yv^(-1)}, yw] + 2*G[{0, 1/(yu*yv)}, yw]*
      G[{0, yv^(-1), yv^(-1)}, yw] + G[{1}, yu^(-1)]*G[{1}, yw]*
      G[{0, yv^(-1), 1/(yu*yv)}, yw] - G[{1}, yw]*G[{yu}, yv^(-1)]*
      G[{0, yv^(-1), 1/(yu*yv)}, yw] - G[{0, 1/(yu*yv)}, yw]*
      G[{0, yv^(-1), 1/(yu*yv)}, yw] - (Pi^2*G[{0, 1/(yu*yv), 1}, yw])/3 - 
     (G[{0}, yu^(-1)]^2*G[{0, 1/(yu*yv), 1}, yw])/2 - 
     G[{0}, yu^(-1)]*G[{0}, yv^(-1)]*G[{0, 1/(yu*yv), 1}, yw] - 
     (G[{0}, yv^(-1)]^2*G[{0, 1/(yu*yv), 1}, yw])/2 + 
     G[{0}, yu^(-1)]*G[{0}, yw]*G[{0, 1/(yu*yv), 1}, yw] + 
     G[{0}, yv^(-1)]*G[{0}, yw]*G[{0, 1/(yu*yv), 1}, yw] - 
     (G[{0}, yw]^2*G[{0, 1/(yu*yv), 1}, yw])/2 + 
     (G[{1}, yu^(-1)]^2*G[{0, 1/(yu*yv), 1}, yw])/2 - 
     G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*G[{0, 1/(yu*yv), 1}, yw] + 
     G[{0}, yu^(-1)]*G[{1}, yw]*G[{0, 1/(yu*yv), 1}, yw] + 
     G[{0}, yv^(-1)]*G[{1}, yw]*G[{0, 1/(yu*yv), 1}, yw] - 
     G[{0}, yw]*G[{1}, yw]*G[{0, 1/(yu*yv), 1}, yw] - 
     G[{1}, yu^(-1)]*G[{1}, yw]*G[{0, 1/(yu*yv), 1}, yw] + 
     G[{1}, yw]^2*G[{0, 1/(yu*yv), 1}, yw] + 2*G[{0}, yu^(-1)]*
      G[{yu}, yv^(-1)]*G[{0, 1/(yu*yv), 1}, yw] + 
     2*G[{0}, yv^(-1)]*G[{yu}, yv^(-1)]*G[{0, 1/(yu*yv), 1}, yw] - 
     2*G[{0}, yw]*G[{yu}, yv^(-1)]*G[{0, 1/(yu*yv), 1}, yw] - 
     G[{1}, yw]*G[{yu}, yv^(-1)]*G[{0, 1/(yu*yv), 1}, yw] - 
     2*G[{yu}, yv^(-1)]^2*G[{0, 1/(yu*yv), 1}, yw] - 
     G[{0, 1}, yu^(-1)]*G[{0, 1/(yu*yv), 1}, yw] + 
     G[{1, yu}, yv^(-1)]*G[{0, 1/(yu*yv), 1}, yw] + 
     (Pi^2*G[{0, 1/(yu*yv), yu^(-1)}, yw])/3 + G[{0}, yu^(-1)]^2*
      G[{0, 1/(yu*yv), yu^(-1)}, yw] + 2*G[{0}, yu^(-1)]*G[{0}, yv^(-1)]*
      G[{0, 1/(yu*yv), yu^(-1)}, yw] + G[{0}, yv^(-1)]^2*
      G[{0, 1/(yu*yv), yu^(-1)}, yw] - 2*G[{0}, yu^(-1)]*G[{0}, yw]*
      G[{0, 1/(yu*yv), yu^(-1)}, yw] - 2*G[{0}, yv^(-1)]*G[{0}, yw]*
      G[{0, 1/(yu*yv), yu^(-1)}, yw] + G[{0}, yw]^2*
      G[{0, 1/(yu*yv), yu^(-1)}, yw] - 2*G[{0}, yu^(-1)]*G[{1}, yu^(-1)]*
      G[{0, 1/(yu*yv), yu^(-1)}, yw] - 2*G[{0}, yv^(-1)]*G[{1}, yu^(-1)]*
      G[{0, 1/(yu*yv), yu^(-1)}, yw] + 2*G[{0}, yw]*G[{1}, yu^(-1)]*
      G[{0, 1/(yu*yv), yu^(-1)}, yw] + G[{1}, yu^(-1)]^2*
      G[{0, 1/(yu*yv), yu^(-1)}, yw] - 2*G[{0}, yu^(-1)]*G[{1}, yv^(-1)]*
      G[{0, 1/(yu*yv), yu^(-1)}, yw] - 2*G[{0}, yv^(-1)]*G[{1}, yv^(-1)]*
      G[{0, 1/(yu*yv), yu^(-1)}, yw] + 2*G[{0}, yw]*G[{1}, yv^(-1)]*
      G[{0, 1/(yu*yv), yu^(-1)}, yw] + 2*G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*
      G[{0, 1/(yu*yv), yu^(-1)}, yw] + 2*G[{1}, yv^(-1)]^2*
      G[{0, 1/(yu*yv), yu^(-1)}, yw] - G[{1}, yw]^2*
      G[{0, 1/(yu*yv), yu^(-1)}, yw] - 2*G[{0, 1}, yv^(-1)]*
      G[{0, 1/(yu*yv), yu^(-1)}, yw] + 2*G[{0, 1}, yw]*
      G[{0, 1/(yu*yv), yu^(-1)}, yw] - 2*G[{0, yu^(-1)}, yw]*
      G[{0, 1/(yu*yv), yu^(-1)}, yw] + 2*G[{0, yu}, yv^(-1)]*
      G[{0, 1/(yu*yv), yu^(-1)}, yw] - 2*G[{0, yv^(-1)}, yw]*
      G[{0, 1/(yu*yv), yu^(-1)}, yw] + 2*G[{0, 1/(yu*yv)}, yw]*
      G[{0, 1/(yu*yv), yu^(-1)}, yw] - 2*G[{1, yu}, yv^(-1)]*
      G[{0, 1/(yu*yv), yu^(-1)}, yw] + (Pi^2*G[{0, 1/(yu*yv), yv^(-1)}, yw])/
      3 + (G[{0}, yu^(-1)]^2*G[{0, 1/(yu*yv), yv^(-1)}, yw])/2 + 
     G[{0}, yu^(-1)]*G[{0}, yv^(-1)]*G[{0, 1/(yu*yv), yv^(-1)}, yw] + 
     (G[{0}, yv^(-1)]^2*G[{0, 1/(yu*yv), yv^(-1)}, yw])/2 - 
     G[{0}, yu^(-1)]*G[{0}, yw]*G[{0, 1/(yu*yv), yv^(-1)}, yw] - 
     G[{0}, yv^(-1)]*G[{0}, yw]*G[{0, 1/(yu*yv), yv^(-1)}, yw] + 
     (G[{0}, yw]^2*G[{0, 1/(yu*yv), yv^(-1)}, yw])/2 - 
     2*G[{0}, yu^(-1)]*G[{1}, yu^(-1)]*G[{0, 1/(yu*yv), yv^(-1)}, yw] - 
     2*G[{0}, yv^(-1)]*G[{1}, yu^(-1)]*G[{0, 1/(yu*yv), yv^(-1)}, yw] + 
     2*G[{0}, yw]*G[{1}, yu^(-1)]*G[{0, 1/(yu*yv), yv^(-1)}, yw] + 
     (3*G[{1}, yu^(-1)]^2*G[{0, 1/(yu*yv), yv^(-1)}, yw])/2 + 
     G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*G[{0, 1/(yu*yv), yv^(-1)}, yw] - 
     G[{0}, yu^(-1)]*G[{1}, yw]*G[{0, 1/(yu*yv), yv^(-1)}, yw] - 
     G[{0}, yv^(-1)]*G[{1}, yw]*G[{0, 1/(yu*yv), yv^(-1)}, yw] + 
     G[{0}, yw]*G[{1}, yw]*G[{0, 1/(yu*yv), yv^(-1)}, yw] + 
     2*G[{1}, yu^(-1)]*G[{1}, yw]*G[{0, 1/(yu*yv), yv^(-1)}, yw] - 
     G[{1}, yw]^2*G[{0, 1/(yu*yv), yv^(-1)}, yw] + 
     G[{0, 1}, yu^(-1)]*G[{0, 1/(yu*yv), yv^(-1)}, yw] - 
     G[{1, yu}, yv^(-1)]*G[{0, 1/(yu*yv), yv^(-1)}, yw] - 
     (Pi^2*G[{0, 1/(yu*yv), 1/(yu*yv)}, yw])/6 - 
     (G[{0}, yu^(-1)]^2*G[{0, 1/(yu*yv), 1/(yu*yv)}, yw])/2 - 
     G[{0}, yu^(-1)]*G[{0}, yv^(-1)]*G[{0, 1/(yu*yv), 1/(yu*yv)}, yw] - 
     (G[{0}, yv^(-1)]^2*G[{0, 1/(yu*yv), 1/(yu*yv)}, yw])/2 + 
     G[{0}, yu^(-1)]*G[{0}, yw]*G[{0, 1/(yu*yv), 1/(yu*yv)}, yw] + 
     G[{0}, yv^(-1)]*G[{0}, yw]*G[{0, 1/(yu*yv), 1/(yu*yv)}, yw] - 
     (G[{0}, yw]^2*G[{0, 1/(yu*yv), 1/(yu*yv)}, yw])/2 + 
     2*G[{0}, yu^(-1)]*G[{1}, yu^(-1)]*G[{0, 1/(yu*yv), 1/(yu*yv)}, yw] + 
     2*G[{0}, yv^(-1)]*G[{1}, yu^(-1)]*G[{0, 1/(yu*yv), 1/(yu*yv)}, yw] - 
     2*G[{0}, yw]*G[{1}, yu^(-1)]*G[{0, 1/(yu*yv), 1/(yu*yv)}, yw] - 
     (3*G[{1}, yu^(-1)]^2*G[{0, 1/(yu*yv), 1/(yu*yv)}, yw])/2 - 
     G[{0}, yu^(-1)]*G[{1}, yv^(-1)]*G[{0, 1/(yu*yv), 1/(yu*yv)}, yw] - 
     G[{0}, yv^(-1)]*G[{1}, yv^(-1)]*G[{0, 1/(yu*yv), 1/(yu*yv)}, yw] + 
     G[{0}, yw]*G[{1}, yv^(-1)]*G[{0, 1/(yu*yv), 1/(yu*yv)}, yw] - 
     G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*G[{0, 1/(yu*yv), 1/(yu*yv)}, yw] + 
     G[{1}, yv^(-1)]^2*G[{0, 1/(yu*yv), 1/(yu*yv)}, yw] - 
     G[{0}, yu^(-1)]*G[{1}, yw]*G[{0, 1/(yu*yv), 1/(yu*yv)}, yw] - 
     G[{0}, yv^(-1)]*G[{1}, yw]*G[{0, 1/(yu*yv), 1/(yu*yv)}, yw] + 
     G[{0}, yw]*G[{1}, yw]*G[{0, 1/(yu*yv), 1/(yu*yv)}, yw] + 
     G[{1}, yu^(-1)]*G[{1}, yw]*G[{0, 1/(yu*yv), 1/(yu*yv)}, yw] + 
     G[{0}, yu^(-1)]*G[{yu}, yv^(-1)]*G[{0, 1/(yu*yv), 1/(yu*yv)}, yw] + 
     G[{0}, yv^(-1)]*G[{yu}, yv^(-1)]*G[{0, 1/(yu*yv), 1/(yu*yv)}, yw] - 
     G[{0}, yw]*G[{yu}, yv^(-1)]*G[{0, 1/(yu*yv), 1/(yu*yv)}, yw] + 
     G[{1}, yw]*G[{yu}, yv^(-1)]*G[{0, 1/(yu*yv), 1/(yu*yv)}, yw] - 
     G[{yu}, yv^(-1)]^2*G[{0, 1/(yu*yv), 1/(yu*yv)}, yw] + 
     G[{0, 1}, yv^(-1)]*G[{0, 1/(yu*yv), 1/(yu*yv)}, yw] - 
     G[{0, 1}, yw]*G[{0, 1/(yu*yv), 1/(yu*yv)}, yw] + 
     G[{0, yu^(-1)}, yw]*G[{0, 1/(yu*yv), 1/(yu*yv)}, yw] - 
     G[{0, yu}, yv^(-1)]*G[{0, 1/(yu*yv), 1/(yu*yv)}, yw] + 
     G[{0, yv^(-1)}, yw]*G[{0, 1/(yu*yv), 1/(yu*yv)}, yw] - 
     G[{0, 1/(yu*yv)}, yw]*G[{0, 1/(yu*yv), 1/(yu*yv)}, yw] + 
     G[{1, yu}, yv^(-1)]*G[{0, 1/(yu*yv), 1/(yu*yv)}, yw] - 
     G[{0, yu^(-1)}, yw]*G[{1, 1, yu}, yv^(-1)] + G[{0, 1/(yu*yv)}, yw]*
      G[{1, 1, yu}, yv^(-1)] - 2*G[{0, 1}, yw]*G[{1, yu, yu}, yv^(-1)] - 
     2*G[{0, yu^(-1)}, yw]*G[{1, yu, yu}, yv^(-1)] + 
     4*G[{0, 1/(yu*yv)}, yw]*G[{1, yu, yu}, yv^(-1)] - 
     G[{0}, yu^(-1)]*G[{0, 0, 0, 1}, yv^(-1)] - G[{0}, yv^(-1)]*
      G[{0, 0, 0, 1}, yv^(-1)] + G[{0}, yw]*G[{0, 0, 0, 1}, yv^(-1)] + 
     3*G[{0}, yu^(-1)]*G[{0, 0, 0, 1}, yw] + 3*G[{0}, yv^(-1)]*
      G[{0, 0, 0, 1}, yw] - 3*G[{0}, yw]*G[{0, 0, 0, 1}, yw] - 
     6*G[{yu}, yv^(-1)]*G[{0, 0, 0, 1}, yw] - 3*G[{0}, yu^(-1)]*
      G[{0, 0, 0, yu^(-1)}, yw] - 3*G[{0}, yv^(-1)]*G[{0, 0, 0, yu^(-1)}, 
       yw] + 3*G[{0}, yw]*G[{0, 0, 0, yu^(-1)}, yw] + 
     6*G[{1}, yv^(-1)]*G[{0, 0, 0, yu^(-1)}, yw] + 
     G[{0}, yu^(-1)]*G[{0, 0, 0, yu}, yv^(-1)] + 
     G[{0}, yv^(-1)]*G[{0, 0, 0, yu}, yv^(-1)] - 
     G[{0}, yw]*G[{0, 0, 0, yu}, yv^(-1)] - 3*G[{0}, yu^(-1)]*
      G[{0, 0, 0, yv^(-1)}, yw] - 3*G[{0}, yv^(-1)]*G[{0, 0, 0, yv^(-1)}, 
       yw] + 3*G[{0}, yw]*G[{0, 0, 0, yv^(-1)}, yw] + 
     6*G[{1}, yu^(-1)]*G[{0, 0, 0, yv^(-1)}, yw] + 
     3*G[{0}, yu^(-1)]*G[{0, 0, 0, 1/(yu*yv)}, yw] + 
     3*G[{0}, yv^(-1)]*G[{0, 0, 0, 1/(yu*yv)}, yw] - 
     3*G[{0}, yw]*G[{0, 0, 0, 1/(yu*yv)}, yw] - 6*G[{1}, yu^(-1)]*
      G[{0, 0, 0, 1/(yu*yv)}, yw] - 6*G[{1}, yv^(-1)]*
      G[{0, 0, 0, 1/(yu*yv)}, yw] + 6*G[{yu}, yv^(-1)]*
      G[{0, 0, 0, 1/(yu*yv)}, yw] - 2*G[{1}, yu^(-1)]*
      G[{0, 0, 1, 1}, yu^(-1)] + 2*G[{1}, yw]*G[{0, 0, 1, 1}, yu^(-1)] + 
     G[{0}, yu^(-1)]*G[{0, 0, 1, 1}, yv^(-1)] + G[{0}, yv^(-1)]*
      G[{0, 0, 1, 1}, yv^(-1)] - G[{0}, yw]*G[{0, 0, 1, 1}, yv^(-1)] + 
     G[{1}, yu^(-1)]*G[{0, 0, 1, 1}, yv^(-1)] + 4*G[{0}, yu^(-1)]*
      G[{0, 0, 1, 1}, yw] + 4*G[{0}, yv^(-1)]*G[{0, 0, 1, 1}, yw] - 
     4*G[{0}, yw]*G[{0, 0, 1, 1}, yw] - 3*G[{1}, yu^(-1)]*
      G[{0, 0, 1, 1}, yw] + 2*G[{1}, yw]*G[{0, 0, 1, 1}, yw] - 
     5*G[{yu}, yv^(-1)]*G[{0, 0, 1, 1}, yw] - 2*G[{0}, yu^(-1)]*
      G[{0, 0, 1, yu^(-1)}, yw] - 2*G[{0}, yv^(-1)]*G[{0, 0, 1, yu^(-1)}, 
       yw] + 2*G[{0}, yw]*G[{0, 0, 1, yu^(-1)}, yw] + 
     4*G[{1}, yu^(-1)]*G[{0, 0, 1, yu^(-1)}, yw] - 
     2*G[{1}, yw]*G[{0, 0, 1, yu^(-1)}, yw] - G[{0}, yu^(-1)]*
      G[{0, 0, 1, yu}, yv^(-1)] - G[{0}, yv^(-1)]*G[{0, 0, 1, yu}, yv^(-1)] + 
     G[{0}, yw]*G[{0, 0, 1, yu}, yv^(-1)] - G[{0}, yu^(-1)]*
      G[{0, 0, 1, yv^(-1)}, yw] - G[{0}, yv^(-1)]*G[{0, 0, 1, yv^(-1)}, yw] + 
     G[{0}, yw]*G[{0, 0, 1, yv^(-1)}, yw] + 2*G[{1}, yu^(-1)]*
      G[{0, 0, 1, yv^(-1)}, yw] - 2*G[{1}, yw]*G[{0, 0, 1, yv^(-1)}, yw] + 
     2*G[{0}, yu^(-1)]*G[{0, 0, 1, 1/(yu*yv)}, yw] + 
     2*G[{0}, yv^(-1)]*G[{0, 0, 1, 1/(yu*yv)}, yw] - 
     2*G[{0}, yw]*G[{0, 0, 1, 1/(yu*yv)}, yw] - 3*G[{1}, yu^(-1)]*
      G[{0, 0, 1, 1/(yu*yv)}, yw] + 2*G[{1}, yw]*G[{0, 0, 1, 1/(yu*yv)}, 
       yw] - G[{yu}, yv^(-1)]*G[{0, 0, 1, 1/(yu*yv)}, yw] - 
     2*G[{0}, yu^(-1)]*G[{0, 0, yu^(-1), 1}, yw] - 
     2*G[{0}, yv^(-1)]*G[{0, 0, yu^(-1), 1}, yw] + 
     2*G[{0}, yw]*G[{0, 0, yu^(-1), 1}, yw] + 3*G[{1}, yu^(-1)]*
      G[{0, 0, yu^(-1), 1}, yw] - 2*G[{1}, yw]*G[{0, 0, yu^(-1), 1}, yw] + 
     G[{yu}, yv^(-1)]*G[{0, 0, yu^(-1), 1}, yw] - 
     2*G[{0}, yu^(-1)]*G[{0, 0, yu^(-1), yu^(-1)}, yw] - 
     2*G[{0}, yv^(-1)]*G[{0, 0, yu^(-1), yu^(-1)}, yw] + 
     2*G[{0}, yw]*G[{0, 0, yu^(-1), yu^(-1)}, yw] + 
     4*G[{1}, yv^(-1)]*G[{0, 0, yu^(-1), yu^(-1)}, yw] - 
     G[{0}, yu^(-1)]*G[{0, 0, yu^(-1), 1/(yu*yv)}, yw] - 
     G[{0}, yv^(-1)]*G[{0, 0, yu^(-1), 1/(yu*yv)}, yw] + 
     G[{0}, yw]*G[{0, 0, yu^(-1), 1/(yu*yv)}, yw] + 
     G[{1}, yu^(-1)]*G[{0, 0, yu^(-1), 1/(yu*yv)}, yw] + 
     2*G[{1}, yv^(-1)]*G[{0, 0, yu^(-1), 1/(yu*yv)}, yw] - 
     G[{yu}, yv^(-1)]*G[{0, 0, yu^(-1), 1/(yu*yv)}, yw] - 
     G[{1}, yu^(-1)]*G[{0, 0, yu, 1}, yv^(-1)] + 2*G[{0}, yu^(-1)]*
      G[{0, 0, yu, yu}, yv^(-1)] + 2*G[{0}, yv^(-1)]*
      G[{0, 0, yu, yu}, yv^(-1)] - 2*G[{0}, yw]*G[{0, 0, yu, yu}, yv^(-1)] + 
     2*G[{1}, yw]*G[{0, 0, yu, yu}, yv^(-1)] - G[{0}, yu^(-1)]*
      G[{0, 0, yv^(-1), 1}, yw] - G[{0}, yv^(-1)]*G[{0, 0, yv^(-1), 1}, yw] + 
     G[{0}, yw]*G[{0, 0, yv^(-1), 1}, yw] + 3*G[{1}, yu^(-1)]*
      G[{0, 0, yv^(-1), 1}, yw] - 2*G[{1}, yw]*G[{0, 0, yv^(-1), 1}, yw] - 
     G[{yu}, yv^(-1)]*G[{0, 0, yv^(-1), 1}, yw] - 
     2*G[{0}, yu^(-1)]*G[{0, 0, yv^(-1), yv^(-1)}, yw] - 
     2*G[{0}, yv^(-1)]*G[{0, 0, yv^(-1), yv^(-1)}, yw] + 
     2*G[{0}, yw]*G[{0, 0, yv^(-1), yv^(-1)}, yw] + 
     4*G[{1}, yu^(-1)]*G[{0, 0, yv^(-1), yv^(-1)}, yw] + 
     2*G[{1}, yw]*G[{0, 0, yv^(-1), yv^(-1)}, yw] - 
     2*G[{0}, yu^(-1)]*G[{0, 0, yv^(-1), 1/(yu*yv)}, yw] - 
     2*G[{0}, yv^(-1)]*G[{0, 0, yv^(-1), 1/(yu*yv)}, yw] + 
     2*G[{0}, yw]*G[{0, 0, yv^(-1), 1/(yu*yv)}, yw] + 
     3*G[{1}, yu^(-1)]*G[{0, 0, yv^(-1), 1/(yu*yv)}, yw] - 
     2*G[{1}, yw]*G[{0, 0, yv^(-1), 1/(yu*yv)}, yw] + 
     G[{yu}, yv^(-1)]*G[{0, 0, yv^(-1), 1/(yu*yv)}, yw] - 
     G[{0}, yu^(-1)]*G[{0, 0, 1/(yu*yv), 1}, yw] - 
     G[{0}, yv^(-1)]*G[{0, 0, 1/(yu*yv), 1}, yw] + 
     G[{0}, yw]*G[{0, 0, 1/(yu*yv), 1}, yw] - 3*G[{1}, yu^(-1)]*
      G[{0, 0, 1/(yu*yv), 1}, yw] + 2*G[{1}, yw]*G[{0, 0, 1/(yu*yv), 1}, 
       yw] + 5*G[{yu}, yv^(-1)]*G[{0, 0, 1/(yu*yv), 1}, yw] + 
     2*G[{0}, yu^(-1)]*G[{0, 0, 1/(yu*yv), yu^(-1)}, yw] + 
     2*G[{0}, yv^(-1)]*G[{0, 0, 1/(yu*yv), yu^(-1)}, yw] - 
     2*G[{0}, yw]*G[{0, 0, 1/(yu*yv), yu^(-1)}, yw] - 
     4*G[{1}, yv^(-1)]*G[{0, 0, 1/(yu*yv), yu^(-1)}, yw] + 
     G[{0}, yu^(-1)]*G[{0, 0, 1/(yu*yv), yv^(-1)}, yw] + 
     G[{0}, yv^(-1)]*G[{0, 0, 1/(yu*yv), yv^(-1)}, yw] - 
     G[{0}, yw]*G[{0, 0, 1/(yu*yv), yv^(-1)}, yw] - 
     2*G[{1}, yu^(-1)]*G[{0, 0, 1/(yu*yv), yv^(-1)}, yw] - 
     2*G[{1}, yw]*G[{0, 0, 1/(yu*yv), yv^(-1)}, yw] + 
     G[{0}, yu^(-1)]*G[{0, 0, 1/(yu*yv), 1/(yu*yv)}, yw] + 
     G[{0}, yv^(-1)]*G[{0, 0, 1/(yu*yv), 1/(yu*yv)}, yw] - 
     G[{0}, yw]*G[{0, 0, 1/(yu*yv), 1/(yu*yv)}, yw] - 
     G[{1}, yu^(-1)]*G[{0, 0, 1/(yu*yv), 1/(yu*yv)}, yw] - 
     2*G[{1}, yv^(-1)]*G[{0, 0, 1/(yu*yv), 1/(yu*yv)}, yw] + 
     G[{yu}, yv^(-1)]*G[{0, 0, 1/(yu*yv), 1/(yu*yv)}, yw] - 
     G[{0}, yu^(-1)]*G[{0, 1, 0, yu^(-1)}, yw] - 
     G[{0}, yv^(-1)]*G[{0, 1, 0, yu^(-1)}, yw] + 
     G[{0}, yw]*G[{0, 1, 0, yu^(-1)}, yw] + 2*G[{1}, yu^(-1)]*
      G[{0, 1, 0, yu^(-1)}, yw] - G[{1}, yw]*G[{0, 1, 0, yu^(-1)}, yw] + 
     G[{0}, yu^(-1)]*G[{0, 1, 0, yu}, yv^(-1)] + 
     G[{0}, yv^(-1)]*G[{0, 1, 0, yu}, yv^(-1)] - 
     G[{0}, yw]*G[{0, 1, 0, yu}, yv^(-1)] + 
     G[{1}, yw]*G[{0, 1, 0, yu}, yv^(-1)] + G[{0}, yu^(-1)]*
      G[{0, 1, 0, 1/(yu*yv)}, yw] + G[{0}, yv^(-1)]*G[{0, 1, 0, 1/(yu*yv)}, 
       yw] - G[{0}, yw]*G[{0, 1, 0, 1/(yu*yv)}, yw] - 
     2*G[{1}, yu^(-1)]*G[{0, 1, 0, 1/(yu*yv)}, yw] + 
     G[{1}, yw]*G[{0, 1, 0, 1/(yu*yv)}, yw] + 3*G[{0}, yu^(-1)]*
      G[{0, 1, 1, 1}, yu^(-1)] + 3*G[{0}, yv^(-1)]*G[{0, 1, 1, 1}, yu^(-1)] - 
     3*G[{0}, yw]*G[{0, 1, 1, 1}, yu^(-1)] - 3*G[{1}, yu^(-1)]*
      G[{0, 1, 1, 1}, yu^(-1)] + 3*G[{1}, yw]*G[{0, 1, 1, 1}, yu^(-1)] + 
     3*G[{0}, yu^(-1)]*G[{0, 1, 1, 1}, yv^(-1)] + 
     3*G[{0}, yv^(-1)]*G[{0, 1, 1, 1}, yv^(-1)] - 
     3*G[{0}, yw]*G[{0, 1, 1, 1}, yv^(-1)] - G[{1}, yu^(-1)]*
      G[{0, 1, 1, 1}, yv^(-1)] + 3*G[{0}, yu^(-1)]*G[{0, 1, 1, 1}, yw] + 
     3*G[{0}, yv^(-1)]*G[{0, 1, 1, 1}, yw] - 3*G[{0}, yw]*
      G[{0, 1, 1, 1}, yw] - 3*G[{1}, yu^(-1)]*G[{0, 1, 1, 1}, yw] + 
     3*G[{1}, yw]*G[{0, 1, 1, 1}, yw] - 3*G[{yu}, yv^(-1)]*
      G[{0, 1, 1, 1}, yw] - G[{0}, yu^(-1)]*G[{0, 1, 1, yu}, yv^(-1)] - 
     G[{0}, yv^(-1)]*G[{0, 1, 1, yu}, yv^(-1)] + 
     G[{0}, yw]*G[{0, 1, 1, yu}, yv^(-1)] - 
     G[{1}, yw]*G[{0, 1, 1, yu}, yv^(-1)] + G[{0}, yu^(-1)]*
      G[{0, 1, 1, yv^(-1)}, yw] + G[{0}, yv^(-1)]*G[{0, 1, 1, yv^(-1)}, yw] - 
     G[{0}, yw]*G[{0, 1, 1, yv^(-1)}, yw] - 2*G[{1}, yu^(-1)]*
      G[{0, 1, 1, yv^(-1)}, yw] - G[{1}, yw]*G[{0, 1, 1, yv^(-1)}, yw] + 
     2*G[{1}, yu^(-1)]*G[{0, 1, 1, 1/(yu*yv)}, yw] - 
     2*G[{yu}, yv^(-1)]*G[{0, 1, 1, 1/(yu*yv)}, yw] + 
     G[{1}, yu^(-1)]*G[{0, 1, yu, 1}, yv^(-1)] - 2*G[{0}, yu^(-1)]*
      G[{0, 1, yu, yu}, yv^(-1)] - 2*G[{0}, yv^(-1)]*
      G[{0, 1, yu, yu}, yv^(-1)] + 2*G[{0}, yw]*G[{0, 1, yu, yu}, yv^(-1)] - 
     2*G[{1}, yw]*G[{0, 1, yu, yu}, yv^(-1)] + G[{0}, yu^(-1)]*
      G[{0, 1, yv^(-1), 1}, yw] + G[{0}, yv^(-1)]*G[{0, 1, yv^(-1), 1}, yw] - 
     G[{0}, yw]*G[{0, 1, yv^(-1), 1}, yw] - G[{1}, yu^(-1)]*
      G[{0, 1, yv^(-1), 1}, yw] - G[{yu}, yv^(-1)]*G[{0, 1, yv^(-1), 1}, 
       yw] - 2*G[{0}, yu^(-1)]*G[{0, 1, yv^(-1), yv^(-1)}, yw] - 
     2*G[{0}, yv^(-1)]*G[{0, 1, yv^(-1), yv^(-1)}, yw] + 
     2*G[{0}, yw]*G[{0, 1, yv^(-1), yv^(-1)}, yw] + 
     4*G[{1}, yu^(-1)]*G[{0, 1, yv^(-1), yv^(-1)}, yw] - 
     2*G[{1}, yw]*G[{0, 1, yv^(-1), yv^(-1)}, yw] - 
     G[{1}, yu^(-1)]*G[{0, 1, yv^(-1), 1/(yu*yv)}, yw] + 
     G[{yu}, yv^(-1)]*G[{0, 1, yv^(-1), 1/(yu*yv)}, yw] + 
     G[{1}, yu^(-1)]*G[{0, 1, 1/(yu*yv), 1}, yw] - 
     G[{1}, yw]*G[{0, 1, 1/(yu*yv), 1}, yw] - G[{yu}, yv^(-1)]*
      G[{0, 1, 1/(yu*yv), 1}, yw] + G[{1}, yw]*G[{0, 1, 1/(yu*yv), yv^(-1)}, 
       yw] - G[{0}, yu^(-1)]*G[{0, yu^(-1), 0, yv^(-1)}, yw] - 
     G[{0}, yv^(-1)]*G[{0, yu^(-1), 0, yv^(-1)}, yw] + 
     G[{0}, yw]*G[{0, yu^(-1), 0, yv^(-1)}, yw] + 
     2*G[{1}, yu^(-1)]*G[{0, yu^(-1), 0, yv^(-1)}, yw] - 
     G[{1}, yw]*G[{0, yu^(-1), 0, yv^(-1)}, yw] - 
     G[{0}, yu^(-1)]*G[{0, yu^(-1), 1, 1}, yw] - 
     G[{0}, yv^(-1)]*G[{0, yu^(-1), 1, 1}, yw] + 
     G[{0}, yw]*G[{0, yu^(-1), 1, 1}, yw] + G[{1}, yu^(-1)]*
      G[{0, yu^(-1), 1, 1}, yw] - G[{1}, yw]*G[{0, yu^(-1), 1, 1}, yw] + 
     G[{yu}, yv^(-1)]*G[{0, yu^(-1), 1, 1}, yw] + 
     G[{0}, yu^(-1)]*G[{0, yu^(-1), 1, yv^(-1)}, yw] + 
     G[{0}, yv^(-1)]*G[{0, yu^(-1), 1, yv^(-1)}, yw] - 
     G[{0}, yw]*G[{0, yu^(-1), 1, yv^(-1)}, yw] - 
     2*G[{1}, yu^(-1)]*G[{0, yu^(-1), 1, yv^(-1)}, yw] + 
     G[{1}, yw]*G[{0, yu^(-1), 1, yv^(-1)}, yw] - 
     2*G[{0}, yu^(-1)]*G[{0, yu^(-1), yu^(-1), 1}, yw] - 
     2*G[{0}, yv^(-1)]*G[{0, yu^(-1), yu^(-1), 1}, yw] + 
     2*G[{0}, yw]*G[{0, yu^(-1), yu^(-1), 1}, yw] + 
     2*G[{1}, yu^(-1)]*G[{0, yu^(-1), yu^(-1), 1}, yw] - 
     2*G[{1}, yw]*G[{0, yu^(-1), yu^(-1), 1}, yw] + 
     2*G[{yu}, yv^(-1)]*G[{0, yu^(-1), yu^(-1), 1}, yw] - 
     2*G[{0}, yu^(-1)]*G[{0, yu^(-1), yu^(-1), 1/(yu*yv)}, yw] - 
     2*G[{0}, yv^(-1)]*G[{0, yu^(-1), yu^(-1), 1/(yu*yv)}, yw] + 
     2*G[{0}, yw]*G[{0, yu^(-1), yu^(-1), 1/(yu*yv)}, yw] + 
     2*G[{1}, yu^(-1)]*G[{0, yu^(-1), yu^(-1), 1/(yu*yv)}, yw] + 
     4*G[{1}, yv^(-1)]*G[{0, yu^(-1), yu^(-1), 1/(yu*yv)}, yw] - 
     2*G[{yu}, yv^(-1)]*G[{0, yu^(-1), yu^(-1), 1/(yu*yv)}, yw] + 
     G[{0}, yu^(-1)]*G[{0, yu^(-1), 1/(yu*yv), 1}, yw] + 
     G[{0}, yv^(-1)]*G[{0, yu^(-1), 1/(yu*yv), 1}, yw] - 
     G[{0}, yw]*G[{0, yu^(-1), 1/(yu*yv), 1}, yw] + 
     G[{1}, yw]*G[{0, yu^(-1), 1/(yu*yv), 1}, yw] - 
     2*G[{yu}, yv^(-1)]*G[{0, yu^(-1), 1/(yu*yv), 1}, yw] - 
     2*G[{0}, yu^(-1)]*G[{0, yu^(-1), 1/(yu*yv), yu^(-1)}, yw] - 
     2*G[{0}, yv^(-1)]*G[{0, yu^(-1), 1/(yu*yv), yu^(-1)}, yw] + 
     2*G[{0}, yw]*G[{0, yu^(-1), 1/(yu*yv), yu^(-1)}, yw] + 
     4*G[{1}, yv^(-1)]*G[{0, yu^(-1), 1/(yu*yv), yu^(-1)}, yw] + 
     G[{0}, yu^(-1)]*G[{0, yu^(-1), 1/(yu*yv), yv^(-1)}, yw] + 
     G[{0}, yv^(-1)]*G[{0, yu^(-1), 1/(yu*yv), yv^(-1)}, yw] - 
     G[{0}, yw]*G[{0, yu^(-1), 1/(yu*yv), yv^(-1)}, yw] - 
     2*G[{1}, yu^(-1)]*G[{0, yu^(-1), 1/(yu*yv), yv^(-1)}, yw] + 
     G[{1}, yw]*G[{0, yu^(-1), 1/(yu*yv), yv^(-1)}, yw] + 
     G[{0}, yu^(-1)]*G[{0, yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] + 
     G[{0}, yv^(-1)]*G[{0, yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] - 
     G[{0}, yw]*G[{0, yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] - 
     G[{1}, yu^(-1)]*G[{0, yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] - 
     2*G[{1}, yv^(-1)]*G[{0, yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] + 
     G[{yu}, yv^(-1)]*G[{0, yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] - 
     G[{1}, yw]*G[{0, yu, 1, yu}, yv^(-1)] + 4*G[{1}, yw]*
      G[{0, yu, yu, yu}, yv^(-1)] - G[{0}, yu^(-1)]*
      G[{0, yv^(-1), 0, 1/(yu*yv)}, yw] - G[{0}, yv^(-1)]*
      G[{0, yv^(-1), 0, 1/(yu*yv)}, yw] + 
     G[{0}, yw]*G[{0, yv^(-1), 0, 1/(yu*yv)}, yw] + 
     2*G[{1}, yu^(-1)]*G[{0, yv^(-1), 0, 1/(yu*yv)}, yw] - 
     G[{1}, yw]*G[{0, yv^(-1), 0, 1/(yu*yv)}, yw] + 
     G[{0}, yu^(-1)]*G[{0, yv^(-1), 1, 1}, yw] + 
     G[{0}, yv^(-1)]*G[{0, yv^(-1), 1, 1}, yw] - 
     G[{0}, yw]*G[{0, yv^(-1), 1, 1}, yw] - 
     G[{1}, yw]*G[{0, yv^(-1), 1, 1}, yw] - 2*G[{yu}, yv^(-1)]*
      G[{0, yv^(-1), 1, 1}, yw] - 2*G[{0}, yu^(-1)]*
      G[{0, yv^(-1), 1, yv^(-1)}, yw] - 2*G[{0}, yv^(-1)]*
      G[{0, yv^(-1), 1, yv^(-1)}, yw] + 2*G[{0}, yw]*
      G[{0, yv^(-1), 1, yv^(-1)}, yw] + 4*G[{1}, yu^(-1)]*
      G[{0, yv^(-1), 1, yv^(-1)}, yw] - G[{1}, yw]*
      G[{0, yv^(-1), 1, yv^(-1)}, yw] - G[{1}, yu^(-1)]*
      G[{0, yv^(-1), 1, 1/(yu*yv)}, yw] + G[{yu}, yv^(-1)]*
      G[{0, yv^(-1), 1, 1/(yu*yv)}, yw] - 2*G[{0}, yu^(-1)]*
      G[{0, yv^(-1), yv^(-1), 1}, yw] - 2*G[{0}, yv^(-1)]*
      G[{0, yv^(-1), yv^(-1), 1}, yw] + 2*G[{0}, yw]*
      G[{0, yv^(-1), yv^(-1), 1}, yw] + 4*G[{1}, yu^(-1)]*
      G[{0, yv^(-1), yv^(-1), 1}, yw] - 2*G[{1}, yw]*
      G[{0, yv^(-1), yv^(-1), 1}, yw] + 4*G[{1}, yw]*
      G[{0, yv^(-1), yv^(-1), yv^(-1)}, yw] - G[{1}, yu^(-1)]*
      G[{0, yv^(-1), 1/(yu*yv), 1}, yw] + 
     G[{1}, yw]*G[{0, yv^(-1), 1/(yu*yv), 1}, yw] + 
     G[{yu}, yv^(-1)]*G[{0, yv^(-1), 1/(yu*yv), 1}, yw] - 
     G[{1}, yw]*G[{0, yv^(-1), 1/(yu*yv), yv^(-1)}, yw] - 
     3*G[{0}, yu^(-1)]*G[{0, 1/(yu*yv), 1, 1}, yw] - 
     3*G[{0}, yv^(-1)]*G[{0, 1/(yu*yv), 1, 1}, yw] + 
     3*G[{0}, yw]*G[{0, 1/(yu*yv), 1, 1}, yw] + 2*G[{1}, yu^(-1)]*
      G[{0, 1/(yu*yv), 1, 1}, yw] - G[{1}, yw]*G[{0, 1/(yu*yv), 1, 1}, yw] + 
     4*G[{yu}, yv^(-1)]*G[{0, 1/(yu*yv), 1, 1}, yw] + 
     G[{1}, yw]*G[{0, 1/(yu*yv), 1, yv^(-1)}, yw] - 
     G[{1}, yu^(-1)]*G[{0, 1/(yu*yv), 1, 1/(yu*yv)}, yw] + 
     G[{yu}, yv^(-1)]*G[{0, 1/(yu*yv), 1, 1/(yu*yv)}, yw] + 
     2*G[{0}, yu^(-1)]*G[{0, 1/(yu*yv), yu^(-1), 1}, yw] + 
     2*G[{0}, yv^(-1)]*G[{0, 1/(yu*yv), yu^(-1), 1}, yw] - 
     2*G[{0}, yw]*G[{0, 1/(yu*yv), yu^(-1), 1}, yw] - 
     2*G[{1}, yu^(-1)]*G[{0, 1/(yu*yv), yu^(-1), 1}, yw] + 
     2*G[{1}, yw]*G[{0, 1/(yu*yv), yu^(-1), 1}, yw] - 
     2*G[{yu}, yv^(-1)]*G[{0, 1/(yu*yv), yu^(-1), 1}, yw] + 
     2*G[{0}, yu^(-1)]*G[{0, 1/(yu*yv), yu^(-1), 1/(yu*yv)}, yw] + 
     2*G[{0}, yv^(-1)]*G[{0, 1/(yu*yv), yu^(-1), 1/(yu*yv)}, yw] - 
     2*G[{0}, yw]*G[{0, 1/(yu*yv), yu^(-1), 1/(yu*yv)}, yw] - 
     2*G[{1}, yu^(-1)]*G[{0, 1/(yu*yv), yu^(-1), 1/(yu*yv)}, yw] - 
     4*G[{1}, yv^(-1)]*G[{0, 1/(yu*yv), yu^(-1), 1/(yu*yv)}, yw] + 
     2*G[{yu}, yv^(-1)]*G[{0, 1/(yu*yv), yu^(-1), 1/(yu*yv)}, yw] + 
     G[{0}, yu^(-1)]*G[{0, 1/(yu*yv), yv^(-1), 1}, yw] + 
     G[{0}, yv^(-1)]*G[{0, 1/(yu*yv), yv^(-1), 1}, yw] - 
     G[{0}, yw]*G[{0, 1/(yu*yv), yv^(-1), 1}, yw] - 
     3*G[{1}, yu^(-1)]*G[{0, 1/(yu*yv), yv^(-1), 1}, yw] + 
     2*G[{1}, yw]*G[{0, 1/(yu*yv), yv^(-1), 1}, yw] + 
     G[{yu}, yv^(-1)]*G[{0, 1/(yu*yv), yv^(-1), 1}, yw] + 
     2*G[{0}, yu^(-1)]*G[{0, 1/(yu*yv), yv^(-1), yv^(-1)}, yw] + 
     2*G[{0}, yv^(-1)]*G[{0, 1/(yu*yv), yv^(-1), yv^(-1)}, yw] - 
     2*G[{0}, yw]*G[{0, 1/(yu*yv), yv^(-1), yv^(-1)}, yw] - 
     4*G[{1}, yu^(-1)]*G[{0, 1/(yu*yv), yv^(-1), yv^(-1)}, yw] - 
     2*G[{1}, yw]*G[{0, 1/(yu*yv), yv^(-1), yv^(-1)}, yw] + 
     G[{1}, yu^(-1)]*G[{0, 1/(yu*yv), yv^(-1), 1/(yu*yv)}, yw] - 
     G[{yu}, yv^(-1)]*G[{0, 1/(yu*yv), yv^(-1), 1/(yu*yv)}, yw] - 
     G[{0}, yu^(-1)]*G[{0, 1/(yu*yv), 1/(yu*yv), 1}, yw] - 
     G[{0}, yv^(-1)]*G[{0, 1/(yu*yv), 1/(yu*yv), 1}, yw] + 
     G[{0}, yw]*G[{0, 1/(yu*yv), 1/(yu*yv), 1}, yw] - 
     G[{1}, yw]*G[{0, 1/(yu*yv), 1/(yu*yv), 1}, yw] + 
     2*G[{yu}, yv^(-1)]*G[{0, 1/(yu*yv), 1/(yu*yv), 1}, yw] + 
     2*G[{0}, yu^(-1)]*G[{0, 1/(yu*yv), 1/(yu*yv), yu^(-1)}, yw] + 
     2*G[{0}, yv^(-1)]*G[{0, 1/(yu*yv), 1/(yu*yv), yu^(-1)}, yw] - 
     2*G[{0}, yw]*G[{0, 1/(yu*yv), 1/(yu*yv), yu^(-1)}, yw] - 
     4*G[{1}, yv^(-1)]*G[{0, 1/(yu*yv), 1/(yu*yv), yu^(-1)}, yw] - 
     G[{0}, yu^(-1)]*G[{0, 1/(yu*yv), 1/(yu*yv), yv^(-1)}, yw] - 
     G[{0}, yv^(-1)]*G[{0, 1/(yu*yv), 1/(yu*yv), yv^(-1)}, yw] + 
     G[{0}, yw]*G[{0, 1/(yu*yv), 1/(yu*yv), yv^(-1)}, yw] + 
     2*G[{1}, yu^(-1)]*G[{0, 1/(yu*yv), 1/(yu*yv), yv^(-1)}, yw] - 
     G[{1}, yw]*G[{0, 1/(yu*yv), 1/(yu*yv), yv^(-1)}, yw] - 
     G[{0}, yu^(-1)]*G[{0, 1/(yu*yv), 1/(yu*yv), 1/(yu*yv)}, yw] - 
     G[{0}, yv^(-1)]*G[{0, 1/(yu*yv), 1/(yu*yv), 1/(yu*yv)}, yw] + 
     G[{0}, yw]*G[{0, 1/(yu*yv), 1/(yu*yv), 1/(yu*yv)}, yw] + 
     G[{1}, yu^(-1)]*G[{0, 1/(yu*yv), 1/(yu*yv), 1/(yu*yv)}, yw] + 
     2*G[{1}, yv^(-1)]*G[{0, 1/(yu*yv), 1/(yu*yv), 1/(yu*yv)}, yw] - 
     G[{yu}, yv^(-1)]*G[{0, 1/(yu*yv), 1/(yu*yv), 1/(yu*yv)}, yw] + 
     6*G[{0, 0, 0, 0, 1}, yw] - 6*G[{0, 0, 0, 0, yu^(-1)}, yw] - 
     6*G[{0, 0, 0, 0, yv^(-1)}, yw] + 6*G[{0, 0, 0, 0, 1/(yu*yv)}, yw] - 
     4*G[{0, 0, 0, 1, 1}, yv^(-1)] + 6*G[{0, 0, 0, 1, 1}, yw] - 
     3*G[{0, 0, 0, 1, yu^(-1)}, yw] + 3*G[{0, 0, 0, 1, yu}, yv^(-1)] + 
     3*G[{0, 0, 0, 1, 1/(yu*yv)}, yw] - 3*G[{0, 0, 0, yu^(-1), 1}, yw] + 
     3*G[{0, 0, 0, yu^(-1), yv^(-1)}, yw] - 
     6*G[{0, 0, 0, yu^(-1), 1/(yu*yv)}, yw] + 
     3*G[{0, 0, 0, yu, 1}, yv^(-1)] - 2*G[{0, 0, 0, yu, yu}, yv^(-1)] + 
     3*G[{0, 0, 0, yv^(-1), yu^(-1)}, yw] - 
     6*G[{0, 0, 0, yv^(-1), yv^(-1)}, yw] - 
     3*G[{0, 0, 0, yv^(-1), 1/(yu*yv)}, yw] - 
     3*G[{0, 0, 0, 1/(yu*yv), 1}, yw] + 3*G[{0, 0, 0, 1/(yu*yv), yv^(-1)}, 
       yw] + 6*G[{0, 0, 0, 1/(yu*yv), 1/(yu*yv)}, yw] - 
     2*G[{0, 0, 1, 0, 1}, yv^(-1)] - G[{0, 0, 1, 0, yu^(-1)}, yw] + 
     G[{0, 0, 1, 0, yu}, yv^(-1)] + G[{0, 0, 1, 0, 1/(yu*yv)}, yw] + 
     12*G[{0, 0, 1, 1, 1}, yu^(-1)] - 6*G[{0, 0, 1, 1, 1}, yv^(-1)] + 
     3*G[{0, 0, 1, 1, 1}, yw] + 2*G[{0, 0, 1, 1, yu^(-1)}, yw] + 
     G[{0, 0, 1, 1, yu}, yv^(-1)] + 3*G[{0, 0, 1, 1, yv^(-1)}, yw] - 
     2*G[{0, 0, 1, 1, 1/(yu*yv)}, yw] + 2*G[{0, 0, 1, yu^(-1), 1}, yw] - 
     4*G[{0, 0, 1, yu^(-1), yu^(-1)}, yw] - 
     4*G[{0, 0, 1, yu^(-1), yv^(-1)}, yw] + 
     2*G[{0, 0, 1, yu^(-1), 1/(yu*yv)}, yw] + 
     2*G[{0, 0, 1, yu, yu}, yv^(-1)] + 2*G[{0, 0, 1, yv^(-1), 1}, yw] - 
     4*G[{0, 0, 1, yv^(-1), yu^(-1)}, yw] - 
     2*G[{0, 0, 1, yv^(-1), yv^(-1)}, yw] + 
     2*G[{0, 0, 1, yv^(-1), 1/(yu*yv)}, yw] - G[{0, 0, 1, 1/(yu*yv), 1}, 
      yw] + G[{0, 0, 1, 1/(yu*yv), yv^(-1)}, yw] - 
     2*G[{0, 0, 1, 1/(yu*yv), 1/(yu*yv)}, yw] - G[{0, 0, yu^(-1), 0, 1}, 
      yw] + 2*G[{0, 0, yu^(-1), 0, yu^(-1)}, yw] + 
     G[{0, 0, yu^(-1), 0, yv^(-1)}, yw] - 
     2*G[{0, 0, yu^(-1), 0, 1/(yu*yv)}, yw] + G[{0, 0, yu^(-1), 1, 1}, yw] - 
     3*G[{0, 0, yu^(-1), 1, yv^(-1)}, yw] + 
     2*G[{0, 0, yu^(-1), yu^(-1), 1}, yw] - 
     12*G[{0, 0, yu^(-1), yu^(-1), yu^(-1)}, yw] - 
     4*G[{0, 0, yu^(-1), yu^(-1), 1/(yu*yv)}, yw] + 
     G[{0, 0, yu^(-1), 1/(yu*yv), 1}, yw] - 
     2*G[{0, 0, yu^(-1), 1/(yu*yv), yu^(-1)}, yw] + 
     G[{0, 0, yu^(-1), 1/(yu*yv), yv^(-1)}, yw] + 
     4*G[{0, 0, yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] + 
     G[{0, 0, yu, 0, 1}, yv^(-1)] + G[{0, 0, yu, 1, yu}, yv^(-1)] - 
     4*G[{0, 0, yu, yu, yu}, yv^(-1)] + G[{0, 0, yv^(-1), 0, yu^(-1)}, yw] - 
     G[{0, 0, yv^(-1), 0, 1/(yu*yv)}, yw] + 3*G[{0, 0, yv^(-1), 1, 1}, yw] - 
     3*G[{0, 0, yv^(-1), 1, yv^(-1)}, yw] - 
     2*G[{0, 0, yv^(-1), yv^(-1), 1}, yw] - 
     4*G[{0, 0, yv^(-1), yv^(-1), yv^(-1)}, yw] - 
     4*G[{0, 0, yv^(-1), yv^(-1), 1/(yu*yv)}, yw] + 
     G[{0, 0, yv^(-1), 1/(yu*yv), 1}, yw] - 
     3*G[{0, 0, yv^(-1), 1/(yu*yv), yv^(-1)}, yw] + 
     2*G[{0, 0, yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] + 
     G[{0, 0, 1/(yu*yv), 0, 1}, yw] - 2*G[{0, 0, 1/(yu*yv), 0, yu^(-1)}, 
       yw] - G[{0, 0, 1/(yu*yv), 0, yv^(-1)}, yw] + 
     2*G[{0, 0, 1/(yu*yv), 0, 1/(yu*yv)}, yw] - 
     7*G[{0, 0, 1/(yu*yv), 1, 1}, yw] + 3*G[{0, 0, 1/(yu*yv), 1, yv^(-1)}, 
       yw] + 4*G[{0, 0, 1/(yu*yv), yu^(-1), yu^(-1)}, yw] + 
     2*G[{0, 0, 1/(yu*yv), yv^(-1), 1}, yw] + 
     2*G[{0, 0, 1/(yu*yv), yv^(-1), yv^(-1)}, yw] + 
     G[{0, 0, 1/(yu*yv), 1/(yu*yv), 1}, yw] - 
     6*G[{0, 0, 1/(yu*yv), 1/(yu*yv), yu^(-1)}, yw] - 
     3*G[{0, 0, 1/(yu*yv), 1/(yu*yv), yv^(-1)}, yw] + 
     4*G[{0, 0, 1/(yu*yv), 1/(yu*yv), 1/(yu*yv)}, yw] + 
     4*G[{0, 1, 0, 1, 1}, yu^(-1)] - 2*G[{0, 1, 0, 1, 1}, yv^(-1)] + 
     G[{0, 1, 0, 1, yu^(-1)}, yw] + G[{0, 1, 0, 1, yu}, yv^(-1)] - 
     G[{0, 1, 0, 1, 1/(yu*yv)}, yw] + G[{0, 1, 0, yu^(-1), 1}, yw] - 
     2*G[{0, 1, 0, yu^(-1), yu^(-1)}, yw] - 
     2*G[{0, 1, 0, yu^(-1), yv^(-1)}, yw] + G[{0, 1, 0, yu^(-1), 1/(yu*yv)}, 
      yw] - 2*G[{0, 1, 0, yu, yu}, yv^(-1)] - 
     2*G[{0, 1, 0, yv^(-1), yu^(-1)}, yw] + G[{0, 1, 0, yv^(-1), 1/(yu*yv)}, 
      yw] - G[{0, 1, 0, 1/(yu*yv), 1}, yw] + G[{0, 1, 0, 1/(yu*yv), yv^(-1)}, 
      yw] - G[{0, 1, 0, 1/(yu*yv), 1/(yu*yv)}, yw] + 
     G[{0, 1, 1, 0, yu^(-1)}, yw] - G[{0, 1, 1, 0, yu}, yv^(-1)] - 
     G[{0, 1, 1, 0, 1/(yu*yv)}, yw] - 6*G[{0, 1, 1, 1, 1}, yv^(-1)] + 
     G[{0, 1, 1, 1, yu}, yv^(-1)] + 3*G[{0, 1, 1, 1, yv^(-1)}, yw] + 
     2*G[{0, 1, 1, yu, yu}, yv^(-1)] + G[{0, 1, 1, yv^(-1), 1}, yw] + 
     2*G[{0, 1, 1, yv^(-1), yv^(-1)}, yw] + 
     2*G[{0, 1, 1, 1/(yu*yv), 1}, yw] - 2*G[{0, 1, 1, 1/(yu*yv), yv^(-1)}, 
       yw] - 2*G[{0, 1, yu^(-1), 0, yu^(-1)}, yw] + 
     2*G[{0, 1, yu^(-1), 0, 1/(yu*yv)}, yw] - G[{0, 1, yu, 1, yu}, yv^(-1)] + 
     4*G[{0, 1, yu, yu, yu}, yv^(-1)] - 2*G[{0, 1, yv^(-1), 0, yu^(-1)}, 
       yw] + 2*G[{0, 1, yv^(-1), 0, 1/(yu*yv)}, yw] + 
     G[{0, 1, yv^(-1), 1, 1}, yw] + G[{0, 1, yv^(-1), 1, yv^(-1)}, yw] + 
     2*G[{0, 1, yv^(-1), yv^(-1), 1}, yw] - 
     4*G[{0, 1, yv^(-1), yv^(-1), yv^(-1)}, yw] - 
     G[{0, 1, yv^(-1), 1/(yu*yv), 1}, yw] + 
     G[{0, 1, yv^(-1), 1/(yu*yv), yv^(-1)}, yw] - 
     G[{0, 1, 1/(yu*yv), 0, yv^(-1)}, yw] - 
     G[{0, 1, 1/(yu*yv), 0, 1/(yu*yv)}, yw] + 
     2*G[{0, 1, 1/(yu*yv), 1, 1}, yw] - G[{0, 1, 1/(yu*yv), 1, yv^(-1)}, 
      yw] - G[{0, 1, 1/(yu*yv), yv^(-1), 1}, yw] + 
     G[{0, yu^(-1), 0, yu^(-1), 1}, yw] - 
     4*G[{0, yu^(-1), 0, yu^(-1), yu^(-1)}, yw] - 
     2*G[{0, yu^(-1), 0, yu^(-1), 1/(yu*yv)}, yw] + 
     G[{0, yu^(-1), 0, yv^(-1), 1}, yw] - 
     2*G[{0, yu^(-1), 0, yv^(-1), yv^(-1)}, yw] + 
     G[{0, yu^(-1), 0, 1/(yu*yv), yv^(-1)}, yw] + 
     2*G[{0, yu^(-1), 0, 1/(yu*yv), 1/(yu*yv)}, yw] + 
     G[{0, yu^(-1), 1, 0, 1/(yu*yv)}, yw] - G[{0, yu^(-1), 1, 1, yv^(-1)}, 
      yw] - G[{0, yu^(-1), 1, yv^(-1), 1}, yw] + 
     2*G[{0, yu^(-1), 1, yv^(-1), yv^(-1)}, yw] + 
     2*G[{0, yu^(-1), yu^(-1), 0, yv^(-1)}, yw] - 
     4*G[{0, yu^(-1), yu^(-1), 0, 1/(yu*yv)}, yw] - 
     2*G[{0, yu^(-1), yu^(-1), 1, yv^(-1)}, yw] + 
     2*G[{0, yu^(-1), yu^(-1), 1/(yu*yv), 1}, yw] - 
     4*G[{0, yu^(-1), yu^(-1), 1/(yu*yv), yu^(-1)}, yw] - 
     2*G[{0, yu^(-1), yu^(-1), 1/(yu*yv), yv^(-1)}, yw] - 
     2*G[{0, yu^(-1), yv^(-1), 0, 1/(yu*yv)}, yw] + 
     G[{0, yu^(-1), 1/(yu*yv), 0, yv^(-1)}, yw] + 
     2*G[{0, yu^(-1), 1/(yu*yv), 0, 1/(yu*yv)}, yw] + 
     G[{0, yu^(-1), 1/(yu*yv), 1, 1}, yw] - 
     4*G[{0, yu^(-1), 1/(yu*yv), yu^(-1), yu^(-1)}, yw] - 
     G[{0, yu^(-1), 1/(yu*yv), yv^(-1), 1}, yw] + 
     2*G[{0, yu^(-1), 1/(yu*yv), yv^(-1), yv^(-1)}, yw] - 
     G[{0, yu^(-1), 1/(yu*yv), 1/(yu*yv), 1}, yw] + 
     2*G[{0, yu^(-1), 1/(yu*yv), 1/(yu*yv), yu^(-1)}, yw] + 
     G[{0, yu^(-1), 1/(yu*yv), 1/(yu*yv), yv^(-1)}, yw] - 
     2*G[{0, yv^(-1), 0, yv^(-1), 1/(yu*yv)}, yw] + 
     G[{0, yv^(-1), 0, 1/(yu*yv), 1}, yw] - 
     2*G[{0, yv^(-1), 0, 1/(yu*yv), yv^(-1)}, yw] + 
     G[{0, yv^(-1), 0, 1/(yu*yv), 1/(yu*yv)}, yw] + 
     G[{0, yv^(-1), 1, 0, 1/(yu*yv)}, yw] + 3*G[{0, yv^(-1), 1, 1, 1}, yw] + 
     G[{0, yv^(-1), 1, yv^(-1), 1}, yw] - 
     4*G[{0, yv^(-1), 1, yv^(-1), yv^(-1)}, yw] - 
     G[{0, yv^(-1), 1, 1/(yu*yv), 1}, yw] + 
     G[{0, yv^(-1), 1, 1/(yu*yv), yv^(-1)}, yw] - 
     2*G[{0, yv^(-1), yu^(-1), 0, 1/(yu*yv)}, yw] - 
     2*G[{0, yv^(-1), yv^(-1), 0, 1/(yu*yv)}, yw] + 
     2*G[{0, yv^(-1), yv^(-1), 1, 1}, yw] - 
     4*G[{0, yv^(-1), yv^(-1), 1, yv^(-1)}, yw] - 
     4*G[{0, yv^(-1), yv^(-1), yv^(-1), 1}, yw] + 
     G[{0, yv^(-1), 1/(yu*yv), 0, 1/(yu*yv)}, yw] - 
     2*G[{0, yv^(-1), 1/(yu*yv), 1, 1}, yw] + 
     G[{0, yv^(-1), 1/(yu*yv), 1, yv^(-1)}, yw] + 
     G[{0, yv^(-1), 1/(yu*yv), yv^(-1), 1}, yw] + 
     G[{0, 1/(yu*yv), 0, 1/(yu*yv), 1}, yw] - 
     4*G[{0, 1/(yu*yv), 0, 1/(yu*yv), yu^(-1)}, yw] - 
     2*G[{0, 1/(yu*yv), 0, 1/(yu*yv), yv^(-1)}, yw] + 
     2*G[{0, 1/(yu*yv), 0, 1/(yu*yv), 1/(yu*yv)}, yw] - 
     3*G[{0, 1/(yu*yv), 1, 1, 1}, yw] - 2*G[{0, 1/(yu*yv), 1, 1, yv^(-1)}, 
       yw] - G[{0, 1/(yu*yv), 1, yv^(-1), 1}, yw] - 
     G[{0, 1/(yu*yv), 1, 1/(yu*yv), 1}, yw] + 
     G[{0, 1/(yu*yv), 1, 1/(yu*yv), yv^(-1)}, yw] + 
     2*G[{0, 1/(yu*yv), yu^(-1), 1, yv^(-1)}, yw] - 
     2*G[{0, 1/(yu*yv), yu^(-1), 1/(yu*yv), 1}, yw] + 
     4*G[{0, 1/(yu*yv), yu^(-1), 1/(yu*yv), yu^(-1)}, yw] + 
     2*G[{0, 1/(yu*yv), yu^(-1), 1/(yu*yv), yv^(-1)}, yw] - 
     3*G[{0, 1/(yu*yv), yv^(-1), 1, 1}, yw] + 
     3*G[{0, 1/(yu*yv), yv^(-1), 1, yv^(-1)}, yw] + 
     2*G[{0, 1/(yu*yv), yv^(-1), yv^(-1), 1}, yw] + 
     4*G[{0, 1/(yu*yv), yv^(-1), yv^(-1), yv^(-1)}, yw] + 
     G[{0, 1/(yu*yv), yv^(-1), 1/(yu*yv), 1}, yw] - 
     G[{0, 1/(yu*yv), yv^(-1), 1/(yu*yv), yv^(-1)}, yw] - 
     G[{0, 1/(yu*yv), 1/(yu*yv), 1, 1}, yw] + 
     4*G[{0, 1/(yu*yv), 1/(yu*yv), yu^(-1), yu^(-1)}, yw] + 
     G[{0, 1/(yu*yv), 1/(yu*yv), yv^(-1), 1}, yw] - 
     2*G[{0, 1/(yu*yv), 1/(yu*yv), yv^(-1), yv^(-1)}, yw] + 
     G[{0, 1/(yu*yv), 1/(yu*yv), 1/(yu*yv), 1}, yw] - 
     2*G[{0, 1/(yu*yv), 1/(yu*yv), 1/(yu*yv), yu^(-1)}, yw] - 
     G[{0, 1/(yu*yv), 1/(yu*yv), 1/(yu*yv), yv^(-1)}, yw] + 
     (Pi^2*Zeta[3])/3 + G[{0}, yu^(-1)]^2*Zeta[3] + 
     2*G[{0}, yu^(-1)]*G[{0}, yv^(-1)]*Zeta[3] + G[{0}, yv^(-1)]^2*Zeta[3] - 
     2*G[{0}, yu^(-1)]*G[{0}, yw]*Zeta[3] - 2*G[{0}, yv^(-1)]*G[{0}, yw]*
      Zeta[3] + G[{0}, yw]^2*Zeta[3] - G[{1}, yu^(-1)]^2*Zeta[3] + 
     2*G[{1}, yu^(-1)]*G[{1}, yw]*Zeta[3] - G[{1}, yw]^2*Zeta[3] - 
     2*G[{0, 1}, yv^(-1)]*Zeta[3] + 2*G[{0, yu^(-1)}, yw]*Zeta[3] - 
     2*G[{0, 1/(yu*yv)}, yw]*Zeta[3] + 2*Zeta[5]
 
H1vwuRegII = (7*Pi^4*G[{0}, yu^(-1)])/360 + (7*Pi^4*G[{0}, yv^(-1)])/360 - 
     (7*Pi^4*G[{0}, yw])/360 - (Pi^2*G[{0}, yu^(-1)]*G[{1}, yu^(-1)]^2)/12 - 
     (Pi^2*G[{0}, yv^(-1)]*G[{1}, yu^(-1)]^2)/12 + 
     (Pi^2*G[{0}, yw]*G[{1}, yu^(-1)]^2)/12 + 
     (Pi^2*G[{0}, yu^(-1)]*G[{1}, yu^(-1)]*G[{1}, yv^(-1)])/6 + 
     (Pi^2*G[{0}, yv^(-1)]*G[{1}, yu^(-1)]*G[{1}, yv^(-1)])/6 - 
     (Pi^2*G[{0}, yw]*G[{1}, yu^(-1)]*G[{1}, yv^(-1)])/6 - 
     (Pi^2*G[{0}, yu^(-1)]*G[{1}, yv^(-1)]^2)/12 - 
     (Pi^2*G[{0}, yv^(-1)]*G[{1}, yv^(-1)]^2)/12 + 
     (Pi^2*G[{0}, yw]*G[{1}, yv^(-1)]^2)/12 + 
     (Pi^2*G[{0}, yu^(-1)]*G[{0, 1}, yu^(-1)])/6 + 
     (Pi^2*G[{0}, yv^(-1)]*G[{0, 1}, yu^(-1)])/6 - 
     (Pi^2*G[{0}, yw]*G[{0, 1}, yu^(-1)])/6 + 
     (Pi^2*G[{1}, yu^(-1)]*G[{0, 1}, yu^(-1)])/6 - 
     (G[{0}, yu^(-1)]*G[{1}, yu^(-1)]^2*G[{0, 1}, yu^(-1)])/2 - 
     (G[{0}, yv^(-1)]*G[{1}, yu^(-1)]^2*G[{0, 1}, yu^(-1)])/2 + 
     (G[{0}, yw]*G[{1}, yu^(-1)]^2*G[{0, 1}, yu^(-1)])/2 - 
     (Pi^2*G[{1}, yv^(-1)]*G[{0, 1}, yu^(-1)])/6 + 
     G[{0}, yu^(-1)]*G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*G[{0, 1}, yu^(-1)] + 
     G[{0}, yv^(-1)]*G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*G[{0, 1}, yu^(-1)] - 
     G[{0}, yw]*G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*G[{0, 1}, yu^(-1)] - 
     (G[{0}, yu^(-1)]*G[{1}, yv^(-1)]^2*G[{0, 1}, yu^(-1)])/2 - 
     (G[{0}, yv^(-1)]*G[{1}, yv^(-1)]^2*G[{0, 1}, yu^(-1)])/2 + 
     (G[{0}, yw]*G[{1}, yv^(-1)]^2*G[{0, 1}, yu^(-1)])/2 + 
     (Pi^2*G[{0}, yu^(-1)]*G[{0, 1}, yv^(-1)])/6 + 
     (Pi^2*G[{0}, yv^(-1)]*G[{0, 1}, yv^(-1)])/6 - 
     (Pi^2*G[{0}, yw]*G[{0, 1}, yv^(-1)])/6 - 
     (Pi^2*G[{1}, yu^(-1)]*G[{0, 1}, yv^(-1)])/6 + 
     (G[{0}, yu^(-1)]*G[{1}, yu^(-1)]^2*G[{0, 1}, yv^(-1)])/2 + 
     (G[{0}, yv^(-1)]*G[{1}, yu^(-1)]^2*G[{0, 1}, yv^(-1)])/2 - 
     (G[{0}, yw]*G[{1}, yu^(-1)]^2*G[{0, 1}, yv^(-1)])/2 - 
     (G[{1}, yu^(-1)]^3*G[{0, 1}, yv^(-1)])/2 + 
     (Pi^2*G[{1}, yv^(-1)]*G[{0, 1}, yv^(-1)])/6 + 
     (G[{1}, yu^(-1)]^2*G[{1}, yv^(-1)]*G[{0, 1}, yv^(-1)])/2 - 
     (G[{0}, yu^(-1)]*G[{1}, yv^(-1)]^2*G[{0, 1}, yv^(-1)])/2 - 
     (G[{0}, yv^(-1)]*G[{1}, yv^(-1)]^2*G[{0, 1}, yv^(-1)])/2 + 
     (G[{0}, yw]*G[{1}, yv^(-1)]^2*G[{0, 1}, yv^(-1)])/2 - 
     (Pi^2*G[{0}, yu^(-1)]*G[{0, 1}, yw])/6 - 
     (Pi^2*G[{0}, yv^(-1)]*G[{0, 1}, yw])/6 + (Pi^2*G[{0}, yw]*G[{0, 1}, yw])/
      6 + (Pi^2*G[{1}, yu^(-1)]*G[{0, 1}, yw])/6 + 
     (Pi^2*G[{1}, yv^(-1)]*G[{0, 1}, yw])/6 + G[{1}, yu^(-1)]^2*
      G[{1}, yv^(-1)]*G[{0, 1}, yw] - G[{1}, yu^(-1)]*G[{1}, yv^(-1)]^2*
      G[{0, 1}, yw] - G[{1}, yu^(-1)]^2*G[{yu}, yv^(-1)]*G[{0, 1}, yw] + 
     2*G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*G[{yu}, yv^(-1)]*G[{0, 1}, yw] - 
     G[{1}, yv^(-1)]^2*G[{yu}, yv^(-1)]*G[{0, 1}, yw] - 
     G[{0}, yu^(-1)]*G[{0, 1}, yu^(-1)]*G[{0, 1}, yw] - 
     G[{0}, yv^(-1)]*G[{0, 1}, yu^(-1)]*G[{0, 1}, yw] + 
     G[{0}, yw]*G[{0, 1}, yu^(-1)]*G[{0, 1}, yw] + 
     G[{1}, yu^(-1)]*G[{0, 1}, yu^(-1)]*G[{0, 1}, yw] - 
     G[{1}, yv^(-1)]*G[{0, 1}, yu^(-1)]*G[{0, 1}, yw] + 
     2*G[{yu}, yv^(-1)]*G[{0, 1}, yu^(-1)]*G[{0, 1}, yw] - 
     G[{0}, yu^(-1)]*G[{0, 1}, yv^(-1)]*G[{0, 1}, yw] - 
     G[{0}, yv^(-1)]*G[{0, 1}, yv^(-1)]*G[{0, 1}, yw] + 
     G[{0}, yw]*G[{0, 1}, yv^(-1)]*G[{0, 1}, yw] + 
     G[{1}, yv^(-1)]*G[{0, 1}, yv^(-1)]*G[{0, 1}, yw] + 
     2*G[{yu}, yv^(-1)]*G[{0, 1}, yv^(-1)]*G[{0, 1}, yw] - 
     (G[{0}, yu^(-1)]*G[{0, 1}, yw]^2)/2 - (G[{0}, yv^(-1)]*G[{0, 1}, yw]^2)/
      2 + (G[{0}, yw]*G[{0, 1}, yw]^2)/2 + (G[{1}, yu^(-1)]*G[{0, 1}, yw]^2)/
      2 + (G[{1}, yv^(-1)]*G[{0, 1}, yw]^2)/2 - 
     (G[{0}, yu^(-1)]*G[{1}, yu^(-1)]^2*G[{0, yu}, yv^(-1)])/2 - 
     (G[{0}, yv^(-1)]*G[{1}, yu^(-1)]^2*G[{0, yu}, yv^(-1)])/2 + 
     (G[{0}, yw]*G[{1}, yu^(-1)]^2*G[{0, yu}, yv^(-1)])/2 + 
     (G[{1}, yu^(-1)]^3*G[{0, yu}, yv^(-1)])/2 - 
     (G[{1}, yu^(-1)]^2*G[{1}, yv^(-1)]*G[{0, yu}, yv^(-1)])/2 + 
     (G[{0}, yu^(-1)]*G[{1}, yv^(-1)]^2*G[{0, yu}, yv^(-1)])/2 + 
     (G[{0}, yv^(-1)]*G[{1}, yv^(-1)]^2*G[{0, yu}, yv^(-1)])/2 - 
     (G[{0}, yw]*G[{1}, yv^(-1)]^2*G[{0, yu}, yv^(-1)])/2 + 
     G[{0}, yu^(-1)]*G[{0, 1}, yu^(-1)]*G[{0, yu}, yv^(-1)] + 
     G[{0}, yv^(-1)]*G[{0, 1}, yu^(-1)]*G[{0, yu}, yv^(-1)] - 
     G[{0}, yw]*G[{0, 1}, yu^(-1)]*G[{0, yu}, yv^(-1)] - 
     G[{1}, yu^(-1)]*G[{0, 1}, yu^(-1)]*G[{0, yu}, yv^(-1)] + 
     G[{1}, yv^(-1)]*G[{0, 1}, yu^(-1)]*G[{0, yu}, yv^(-1)] + 
     G[{0}, yu^(-1)]*G[{0, 1}, yv^(-1)]*G[{0, yu}, yv^(-1)] + 
     G[{0}, yv^(-1)]*G[{0, 1}, yv^(-1)]*G[{0, yu}, yv^(-1)] - 
     G[{0}, yw]*G[{0, 1}, yv^(-1)]*G[{0, yu}, yv^(-1)] - 
     G[{1}, yv^(-1)]*G[{0, 1}, yv^(-1)]*G[{0, yu}, yv^(-1)] + 
     G[{0}, yu^(-1)]*G[{0, 1}, yw]*G[{0, yu}, yv^(-1)] + 
     G[{0}, yv^(-1)]*G[{0, 1}, yw]*G[{0, yu}, yv^(-1)] - 
     G[{0}, yw]*G[{0, 1}, yw]*G[{0, yu}, yv^(-1)] - 
     G[{1}, yv^(-1)]*G[{0, 1}, yw]*G[{0, yu}, yv^(-1)] - 
     2*G[{yu}, yv^(-1)]*G[{0, 1}, yw]*G[{0, yu}, yv^(-1)] - 
     (G[{0}, yu^(-1)]*G[{0, yu}, yv^(-1)]^2)/2 - 
     (G[{0}, yv^(-1)]*G[{0, yu}, yv^(-1)]^2)/2 + 
     (G[{0}, yw]*G[{0, yu}, yv^(-1)]^2)/2 + 
     (G[{1}, yv^(-1)]*G[{0, yu}, yv^(-1)]^2)/2 + 
     (Pi^2*G[{0}, yu^(-1)]*G[{0, 1/(yu*yv)}, yw])/6 + 
     (Pi^2*G[{0}, yv^(-1)]*G[{0, 1/(yu*yv)}, yw])/6 - 
     (Pi^2*G[{0}, yw]*G[{0, 1/(yu*yv)}, yw])/6 - 
     (Pi^2*G[{1}, yu^(-1)]*G[{0, 1/(yu*yv)}, yw])/6 - 
     (Pi^2*G[{1}, yv^(-1)]*G[{0, 1/(yu*yv)}, yw])/6 - 
     G[{1}, yu^(-1)]^2*G[{1}, yv^(-1)]*G[{0, 1/(yu*yv)}, yw] + 
     G[{1}, yu^(-1)]*G[{1}, yv^(-1)]^2*G[{0, 1/(yu*yv)}, yw] + 
     G[{1}, yu^(-1)]^2*G[{yu}, yv^(-1)]*G[{0, 1/(yu*yv)}, yw] - 
     2*G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*G[{yu}, yv^(-1)]*
      G[{0, 1/(yu*yv)}, yw] + G[{1}, yv^(-1)]^2*G[{yu}, yv^(-1)]*
      G[{0, 1/(yu*yv)}, yw] + G[{0}, yu^(-1)]*G[{0, 1}, yu^(-1)]*
      G[{0, 1/(yu*yv)}, yw] + G[{0}, yv^(-1)]*G[{0, 1}, yu^(-1)]*
      G[{0, 1/(yu*yv)}, yw] - G[{0}, yw]*G[{0, 1}, yu^(-1)]*
      G[{0, 1/(yu*yv)}, yw] - G[{1}, yu^(-1)]*G[{0, 1}, yu^(-1)]*
      G[{0, 1/(yu*yv)}, yw] + G[{1}, yv^(-1)]*G[{0, 1}, yu^(-1)]*
      G[{0, 1/(yu*yv)}, yw] - 2*G[{yu}, yv^(-1)]*G[{0, 1}, yu^(-1)]*
      G[{0, 1/(yu*yv)}, yw] + G[{0}, yu^(-1)]*G[{0, 1}, yv^(-1)]*
      G[{0, 1/(yu*yv)}, yw] + G[{0}, yv^(-1)]*G[{0, 1}, yv^(-1)]*
      G[{0, 1/(yu*yv)}, yw] - G[{0}, yw]*G[{0, 1}, yv^(-1)]*
      G[{0, 1/(yu*yv)}, yw] - G[{1}, yv^(-1)]*G[{0, 1}, yv^(-1)]*
      G[{0, 1/(yu*yv)}, yw] - 2*G[{yu}, yv^(-1)]*G[{0, 1}, yv^(-1)]*
      G[{0, 1/(yu*yv)}, yw] + G[{0}, yu^(-1)]*G[{0, 1}, yw]*
      G[{0, 1/(yu*yv)}, yw] + G[{0}, yv^(-1)]*G[{0, 1}, yw]*
      G[{0, 1/(yu*yv)}, yw] - G[{0}, yw]*G[{0, 1}, yw]*
      G[{0, 1/(yu*yv)}, yw] - G[{1}, yu^(-1)]*G[{0, 1}, yw]*
      G[{0, 1/(yu*yv)}, yw] - G[{1}, yv^(-1)]*G[{0, 1}, yw]*
      G[{0, 1/(yu*yv)}, yw] - G[{0}, yu^(-1)]*G[{0, yu^(-1)}, yw]*
      G[{0, 1/(yu*yv)}, yw] - G[{0}, yv^(-1)]*G[{0, yu^(-1)}, yw]*
      G[{0, 1/(yu*yv)}, yw] + G[{0}, yw]*G[{0, yu^(-1)}, yw]*
      G[{0, 1/(yu*yv)}, yw] + G[{1}, yu^(-1)]*G[{0, yu^(-1)}, yw]*
      G[{0, 1/(yu*yv)}, yw] + G[{1}, yv^(-1)]*G[{0, yu^(-1)}, yw]*
      G[{0, 1/(yu*yv)}, yw] - G[{0}, yu^(-1)]*G[{0, yu}, yv^(-1)]*
      G[{0, 1/(yu*yv)}, yw] - G[{0}, yv^(-1)]*G[{0, yu}, yv^(-1)]*
      G[{0, 1/(yu*yv)}, yw] + G[{0}, yw]*G[{0, yu}, yv^(-1)]*
      G[{0, 1/(yu*yv)}, yw] + G[{1}, yv^(-1)]*G[{0, yu}, yv^(-1)]*
      G[{0, 1/(yu*yv)}, yw] + 2*G[{yu}, yv^(-1)]*G[{0, yu}, yv^(-1)]*
      G[{0, 1/(yu*yv)}, yw] - G[{0}, yu^(-1)]*G[{0, yv^(-1)}, yw]*
      G[{0, 1/(yu*yv)}, yw] - G[{0}, yv^(-1)]*G[{0, yv^(-1)}, yw]*
      G[{0, 1/(yu*yv)}, yw] + G[{0}, yw]*G[{0, yv^(-1)}, yw]*
      G[{0, 1/(yu*yv)}, yw] + G[{1}, yu^(-1)]*G[{0, yv^(-1)}, yw]*
      G[{0, 1/(yu*yv)}, yw] + G[{1}, yv^(-1)]*G[{0, yv^(-1)}, yw]*
      G[{0, 1/(yu*yv)}, yw] + (G[{0}, yu^(-1)]*G[{0, 1/(yu*yv)}, yw]^2)/2 + 
     (G[{0}, yv^(-1)]*G[{0, 1/(yu*yv)}, yw]^2)/2 - 
     (G[{0}, yw]*G[{0, 1/(yu*yv)}, yw]^2)/2 - 
     (G[{1}, yu^(-1)]*G[{0, 1/(yu*yv)}, yw]^2)/2 - 
     (G[{1}, yv^(-1)]*G[{0, 1/(yu*yv)}, yw]^2)/2 - 
     2*G[{1}, yu^(-1)]*G[{0, 1}, yw]*G[{1, yu}, yv^(-1)] + 
     2*G[{1}, yv^(-1)]*G[{0, 1}, yw]*G[{1, yu}, yv^(-1)] + 
     2*G[{1}, yu^(-1)]*G[{0, 1/(yu*yv)}, yw]*G[{1, yu}, yv^(-1)] - 
     2*G[{1}, yv^(-1)]*G[{0, 1/(yu*yv)}, yw]*G[{1, yu}, yv^(-1)] - 
     (Pi^2*G[{0, 0, 1}, yu^(-1)])/6 + G[{0}, yu^(-1)]*G[{1}, yu^(-1)]*
      G[{0, 0, 1}, yu^(-1)] + G[{0}, yv^(-1)]*G[{1}, yu^(-1)]*
      G[{0, 0, 1}, yu^(-1)] - G[{0}, yw]*G[{1}, yu^(-1)]*
      G[{0, 0, 1}, yu^(-1)] - G[{0}, yu^(-1)]*G[{1}, yv^(-1)]*
      G[{0, 0, 1}, yu^(-1)] - G[{0}, yv^(-1)]*G[{1}, yv^(-1)]*
      G[{0, 0, 1}, yu^(-1)] + G[{0}, yw]*G[{1}, yv^(-1)]*
      G[{0, 0, 1}, yu^(-1)] - G[{0, 1}, yw]*G[{0, 0, 1}, yu^(-1)] + 
     G[{0, yu}, yv^(-1)]*G[{0, 0, 1}, yu^(-1)] + G[{0, 1/(yu*yv)}, yw]*
      G[{0, 0, 1}, yu^(-1)] - (Pi^2*G[{0, 0, 1}, yv^(-1)])/6 - 
     (G[{1}, yu^(-1)]^2*G[{0, 0, 1}, yv^(-1)])/2 + 
     G[{0}, yu^(-1)]*G[{1}, yv^(-1)]*G[{0, 0, 1}, yv^(-1)] + 
     G[{0}, yv^(-1)]*G[{1}, yv^(-1)]*G[{0, 0, 1}, yv^(-1)] - 
     G[{0}, yw]*G[{1}, yv^(-1)]*G[{0, 0, 1}, yv^(-1)] - 
     G[{0, 1}, yw]*G[{0, 0, 1}, yv^(-1)] + G[{0, yu}, yv^(-1)]*
      G[{0, 0, 1}, yv^(-1)] + G[{0, 1/(yu*yv)}, yw]*G[{0, 0, 1}, yv^(-1)] - 
     (Pi^2*G[{0, 0, 1}, yw])/3 - 2*G[{0, 1}, yu^(-1)]*G[{0, 0, 1}, yw] - 
     2*G[{0, 1}, yv^(-1)]*G[{0, 0, 1}, yw] - 2*G[{0, 1}, yw]*
      G[{0, 0, 1}, yw] + 2*G[{0, yu}, yv^(-1)]*G[{0, 0, 1}, yw] + 
     2*G[{0, 1/(yu*yv)}, yw]*G[{0, 0, 1}, yw] + 2*G[{0, 1}, yw]*
      G[{0, 0, yu^(-1)}, yw] - 2*G[{0, 1/(yu*yv)}, yw]*
      G[{0, 0, yu^(-1)}, yw] + (G[{1}, yu^(-1)]^2*G[{0, 0, yu}, yv^(-1)])/2 - 
     G[{0}, yu^(-1)]*G[{1}, yv^(-1)]*G[{0, 0, yu}, yv^(-1)] - 
     G[{0}, yv^(-1)]*G[{1}, yv^(-1)]*G[{0, 0, yu}, yv^(-1)] + 
     G[{0}, yw]*G[{1}, yv^(-1)]*G[{0, 0, yu}, yv^(-1)] - 
     G[{0, 1}, yu^(-1)]*G[{0, 0, yu}, yv^(-1)] + 
     G[{0, 1}, yw]*G[{0, 0, yu}, yv^(-1)] - G[{0, yu}, yv^(-1)]*
      G[{0, 0, yu}, yv^(-1)] - G[{0, 1/(yu*yv)}, yw]*G[{0, 0, yu}, yv^(-1)] + 
     2*G[{0, 1}, yw]*G[{0, 0, yv^(-1)}, yw] - 2*G[{0, 1/(yu*yv)}, yw]*
      G[{0, 0, yv^(-1)}, yw] + (Pi^2*G[{0, 0, 1/(yu*yv)}, yw])/3 + 
     2*G[{0, 1}, yu^(-1)]*G[{0, 0, 1/(yu*yv)}, yw] + 
     2*G[{0, 1}, yv^(-1)]*G[{0, 0, 1/(yu*yv)}, yw] - 
     2*G[{0, 1}, yw]*G[{0, 0, 1/(yu*yv)}, yw] - 2*G[{0, yu}, yv^(-1)]*
      G[{0, 0, 1/(yu*yv)}, yw] + 2*G[{0, 1/(yu*yv)}, yw]*
      G[{0, 0, 1/(yu*yv)}, yw] - (Pi^2*G[{0, 1, 1}, yu^(-1)])/3 + 
     G[{0}, yu^(-1)]*G[{1}, yu^(-1)]*G[{0, 1, 1}, yu^(-1)] + 
     G[{0}, yv^(-1)]*G[{1}, yu^(-1)]*G[{0, 1, 1}, yu^(-1)] - 
     G[{0}, yw]*G[{1}, yu^(-1)]*G[{0, 1, 1}, yu^(-1)] + 
     G[{1}, yu^(-1)]^2*G[{0, 1, 1}, yu^(-1)] - G[{0}, yu^(-1)]*
      G[{1}, yv^(-1)]*G[{0, 1, 1}, yu^(-1)] - G[{0}, yv^(-1)]*G[{1}, yv^(-1)]*
      G[{0, 1, 1}, yu^(-1)] + G[{0}, yw]*G[{1}, yv^(-1)]*
      G[{0, 1, 1}, yu^(-1)] - 2*G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*
      G[{0, 1, 1}, yu^(-1)] + G[{1}, yv^(-1)]^2*G[{0, 1, 1}, yu^(-1)] + 
     G[{0, 1}, yw]*G[{0, 1, 1}, yu^(-1)] - G[{0, yu}, yv^(-1)]*
      G[{0, 1, 1}, yu^(-1)] - G[{0, 1/(yu*yv)}, yw]*G[{0, 1, 1}, yu^(-1)] - 
     (Pi^2*G[{0, 1, 1}, yv^(-1)])/3 - G[{0}, yu^(-1)]*G[{1}, yu^(-1)]*
      G[{0, 1, 1}, yv^(-1)] - G[{0}, yv^(-1)]*G[{1}, yu^(-1)]*
      G[{0, 1, 1}, yv^(-1)] + G[{0}, yw]*G[{1}, yu^(-1)]*
      G[{0, 1, 1}, yv^(-1)] + G[{0}, yu^(-1)]*G[{1}, yv^(-1)]*
      G[{0, 1, 1}, yv^(-1)] + G[{0}, yv^(-1)]*G[{1}, yv^(-1)]*
      G[{0, 1, 1}, yv^(-1)] - G[{0}, yw]*G[{1}, yv^(-1)]*
      G[{0, 1, 1}, yv^(-1)] - G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*
      G[{0, 1, 1}, yv^(-1)] + G[{1}, yv^(-1)]^2*G[{0, 1, 1}, yv^(-1)] + 
     G[{0, 1}, yw]*G[{0, 1, 1}, yv^(-1)] - G[{0, yu}, yv^(-1)]*
      G[{0, 1, 1}, yv^(-1)] - G[{0, 1/(yu*yv)}, yw]*G[{0, 1, 1}, yv^(-1)] + 
     G[{0}, yu^(-1)]*G[{1}, yu^(-1)]*G[{0, 1, 1}, yw] + 
     G[{0}, yv^(-1)]*G[{1}, yu^(-1)]*G[{0, 1, 1}, yw] - 
     G[{0}, yw]*G[{1}, yu^(-1)]*G[{0, 1, 1}, yw] - 
     (G[{1}, yu^(-1)]^2*G[{0, 1, 1}, yw])/2 + G[{0}, yu^(-1)]*G[{1}, yv^(-1)]*
      G[{0, 1, 1}, yw] + G[{0}, yv^(-1)]*G[{1}, yv^(-1)]*G[{0, 1, 1}, yw] - 
     G[{0}, yw]*G[{1}, yv^(-1)]*G[{0, 1, 1}, yw] - 
     G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*G[{0, 1, 1}, yw] - 
     (G[{1}, yv^(-1)]^2*G[{0, 1, 1}, yw])/2 - 2*G[{0}, yu^(-1)]*
      G[{yu}, yv^(-1)]*G[{0, 1, 1}, yw] - 2*G[{0}, yv^(-1)]*G[{yu}, yv^(-1)]*
      G[{0, 1, 1}, yw] + 2*G[{0}, yw]*G[{yu}, yv^(-1)]*G[{0, 1, 1}, yw] + 
     2*G[{yu}, yv^(-1)]^2*G[{0, 1, 1}, yw] - G[{0, 1}, yu^(-1)]*
      G[{0, 1, 1}, yw] - G[{0, 1}, yv^(-1)]*G[{0, 1, 1}, yw] + 
     G[{0, yu}, yv^(-1)]*G[{0, 1, 1}, yw] - (Pi^2*G[{0, 1, yu^(-1)}, yw])/6 - 
     G[{0}, yu^(-1)]*G[{1}, yu^(-1)]*G[{0, 1, yu^(-1)}, yw] - 
     G[{0}, yv^(-1)]*G[{1}, yu^(-1)]*G[{0, 1, yu^(-1)}, yw] + 
     G[{0}, yw]*G[{1}, yu^(-1)]*G[{0, 1, yu^(-1)}, yw] + 
     (G[{1}, yu^(-1)]^2*G[{0, 1, yu^(-1)}, yw])/2 + 
     G[{0}, yu^(-1)]*G[{1}, yv^(-1)]*G[{0, 1, yu^(-1)}, yw] + 
     G[{0}, yv^(-1)]*G[{1}, yv^(-1)]*G[{0, 1, yu^(-1)}, yw] - 
     G[{0}, yw]*G[{1}, yv^(-1)]*G[{0, 1, yu^(-1)}, yw] + 
     G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*G[{0, 1, yu^(-1)}, yw] - 
     (3*G[{1}, yv^(-1)]^2*G[{0, 1, yu^(-1)}, yw])/2 + 
     G[{0, 1}, yw]*G[{0, 1, yu^(-1)}, yw] + 2*G[{0, 1/(yu*yv)}, yw]*
      G[{0, 1, yu^(-1)}, yw] - 2*G[{0, 1}, yw]*G[{0, 1, yu}, yv^(-1)] + 
     2*G[{0, yu}, yv^(-1)]*G[{0, 1, yu}, yv^(-1)] + 
     2*G[{0, 1/(yu*yv)}, yw]*G[{0, 1, yu}, yv^(-1)] - 
     (Pi^2*G[{0, 1, yv^(-1)}, yw])/6 + G[{0}, yu^(-1)]*G[{1}, yu^(-1)]*
      G[{0, 1, yv^(-1)}, yw] + G[{0}, yv^(-1)]*G[{1}, yu^(-1)]*
      G[{0, 1, yv^(-1)}, yw] - G[{0}, yw]*G[{1}, yu^(-1)]*
      G[{0, 1, yv^(-1)}, yw] - (3*G[{1}, yu^(-1)]^2*G[{0, 1, yv^(-1)}, yw])/
      2 - G[{0}, yu^(-1)]*G[{1}, yv^(-1)]*G[{0, 1, yv^(-1)}, yw] - 
     G[{0}, yv^(-1)]*G[{1}, yv^(-1)]*G[{0, 1, yv^(-1)}, yw] + 
     G[{0}, yw]*G[{1}, yv^(-1)]*G[{0, 1, yv^(-1)}, yw] + 
     G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*G[{0, 1, yv^(-1)}, yw] + 
     (G[{1}, yv^(-1)]^2*G[{0, 1, yv^(-1)}, yw])/2 + 
     G[{0, 1}, yw]*G[{0, 1, yv^(-1)}, yw] + 2*G[{0, 1/(yu*yv)}, yw]*
      G[{0, 1, yv^(-1)}, yw] - G[{0}, yu^(-1)]*G[{1}, yu^(-1)]*
      G[{0, 1, 1/(yu*yv)}, yw] - G[{0}, yv^(-1)]*G[{1}, yu^(-1)]*
      G[{0, 1, 1/(yu*yv)}, yw] + G[{0}, yw]*G[{1}, yu^(-1)]*
      G[{0, 1, 1/(yu*yv)}, yw] + (3*G[{1}, yu^(-1)]^2*
       G[{0, 1, 1/(yu*yv)}, yw])/2 - G[{0}, yu^(-1)]*G[{1}, yv^(-1)]*
      G[{0, 1, 1/(yu*yv)}, yw] - G[{0}, yv^(-1)]*G[{1}, yv^(-1)]*
      G[{0, 1, 1/(yu*yv)}, yw] + G[{0}, yw]*G[{1}, yv^(-1)]*
      G[{0, 1, 1/(yu*yv)}, yw] - G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*
      G[{0, 1, 1/(yu*yv)}, yw] + (3*G[{1}, yv^(-1)]^2*
       G[{0, 1, 1/(yu*yv)}, yw])/2 + 2*G[{0}, yu^(-1)]*G[{yu}, yv^(-1)]*
      G[{0, 1, 1/(yu*yv)}, yw] + 2*G[{0}, yv^(-1)]*G[{yu}, yv^(-1)]*
      G[{0, 1, 1/(yu*yv)}, yw] - 2*G[{0}, yw]*G[{yu}, yv^(-1)]*
      G[{0, 1, 1/(yu*yv)}, yw] - 2*G[{yu}, yv^(-1)]^2*
      G[{0, 1, 1/(yu*yv)}, yw] - G[{0, 1}, yu^(-1)]*G[{0, 1, 1/(yu*yv)}, 
       yw] - G[{0, 1}, yv^(-1)]*G[{0, 1, 1/(yu*yv)}, yw] + 
     G[{0, yu}, yv^(-1)]*G[{0, 1, 1/(yu*yv)}, yw] - 
     2*G[{0, 1/(yu*yv)}, yw]*G[{0, yu^(-1), yu^(-1)}, yw] - 
     2*G[{0, 1/(yu*yv)}, yw]*G[{0, yu^(-1), yv^(-1)}, yw] + 
     2*G[{0, yv^(-1)}, yw]*G[{0, yu^(-1), 1/(yu*yv)}, yw] + 
     G[{0}, yu^(-1)]*G[{1}, yu^(-1)]*G[{0, yu, 1}, yv^(-1)] + 
     G[{0}, yv^(-1)]*G[{1}, yu^(-1)]*G[{0, yu, 1}, yv^(-1)] - 
     G[{0}, yw]*G[{1}, yu^(-1)]*G[{0, yu, 1}, yv^(-1)] - 
     G[{1}, yu^(-1)]^2*G[{0, yu, 1}, yv^(-1)] - G[{0}, yu^(-1)]*
      G[{1}, yv^(-1)]*G[{0, yu, 1}, yv^(-1)] - G[{0}, yv^(-1)]*
      G[{1}, yv^(-1)]*G[{0, yu, 1}, yv^(-1)] + G[{0}, yw]*G[{1}, yv^(-1)]*
      G[{0, yu, 1}, yv^(-1)] + G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*
      G[{0, yu, 1}, yv^(-1)] - G[{0, 1}, yw]*G[{0, yu, 1}, yv^(-1)] + 
     G[{0, 1/(yu*yv)}, yw]*G[{0, yu, 1}, yv^(-1)] + 
     G[{1}, yu^(-1)]^2*G[{0, yu, yu}, yv^(-1)] - G[{1}, yv^(-1)]^2*
      G[{0, yu, yu}, yv^(-1)] - 2*G[{0, 1}, yu^(-1)]*
      G[{0, yu, yu}, yv^(-1)] - 2*G[{0, 1}, yv^(-1)]*
      G[{0, yu, yu}, yv^(-1)] + 2*G[{0, 1}, yw]*G[{0, yu, yu}, yv^(-1)] + 
     2*G[{0, yu}, yv^(-1)]*G[{0, yu, yu}, yv^(-1)] - 
     2*G[{0, 1/(yu*yv)}, yw]*G[{0, yu, yu}, yv^(-1)] - 
     2*G[{0, 1/(yu*yv)}, yw]*G[{0, yv^(-1), yu^(-1)}, yw] - 
     2*G[{0, 1/(yu*yv)}, yw]*G[{0, yv^(-1), yv^(-1)}, yw] - 
     G[{0}, yu^(-1)]*G[{1}, yu^(-1)]*G[{0, 1/(yu*yv), 1}, yw] - 
     G[{0}, yv^(-1)]*G[{1}, yu^(-1)]*G[{0, 1/(yu*yv), 1}, yw] + 
     G[{0}, yw]*G[{1}, yu^(-1)]*G[{0, 1/(yu*yv), 1}, yw] + 
     (G[{1}, yu^(-1)]^2*G[{0, 1/(yu*yv), 1}, yw])/2 - 
     G[{0}, yu^(-1)]*G[{1}, yv^(-1)]*G[{0, 1/(yu*yv), 1}, yw] - 
     G[{0}, yv^(-1)]*G[{1}, yv^(-1)]*G[{0, 1/(yu*yv), 1}, yw] + 
     G[{0}, yw]*G[{1}, yv^(-1)]*G[{0, 1/(yu*yv), 1}, yw] + 
     G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*G[{0, 1/(yu*yv), 1}, yw] + 
     (G[{1}, yv^(-1)]^2*G[{0, 1/(yu*yv), 1}, yw])/2 + 
     2*G[{0}, yu^(-1)]*G[{yu}, yv^(-1)]*G[{0, 1/(yu*yv), 1}, yw] + 
     2*G[{0}, yv^(-1)]*G[{yu}, yv^(-1)]*G[{0, 1/(yu*yv), 1}, yw] - 
     2*G[{0}, yw]*G[{yu}, yv^(-1)]*G[{0, 1/(yu*yv), 1}, yw] - 
     2*G[{yu}, yv^(-1)]^2*G[{0, 1/(yu*yv), 1}, yw] + 
     G[{0, 1}, yu^(-1)]*G[{0, 1/(yu*yv), 1}, yw] + 
     G[{0, 1}, yv^(-1)]*G[{0, 1/(yu*yv), 1}, yw] - 
     G[{0, yu}, yv^(-1)]*G[{0, 1/(yu*yv), 1}, yw] + 
     (Pi^2*G[{0, 1/(yu*yv), yu^(-1)}, yw])/6 + G[{0}, yu^(-1)]*
      G[{1}, yu^(-1)]*G[{0, 1/(yu*yv), yu^(-1)}, yw] + 
     G[{0}, yv^(-1)]*G[{1}, yu^(-1)]*G[{0, 1/(yu*yv), yu^(-1)}, yw] - 
     G[{0}, yw]*G[{1}, yu^(-1)]*G[{0, 1/(yu*yv), yu^(-1)}, yw] - 
     (G[{1}, yu^(-1)]^2*G[{0, 1/(yu*yv), yu^(-1)}, yw])/2 - 
     G[{0}, yu^(-1)]*G[{1}, yv^(-1)]*G[{0, 1/(yu*yv), yu^(-1)}, yw] - 
     G[{0}, yv^(-1)]*G[{1}, yv^(-1)]*G[{0, 1/(yu*yv), yu^(-1)}, yw] + 
     G[{0}, yw]*G[{1}, yv^(-1)]*G[{0, 1/(yu*yv), yu^(-1)}, yw] - 
     G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*G[{0, 1/(yu*yv), yu^(-1)}, yw] + 
     (3*G[{1}, yv^(-1)]^2*G[{0, 1/(yu*yv), yu^(-1)}, yw])/2 - 
     G[{0, 1}, yw]*G[{0, 1/(yu*yv), yu^(-1)}, yw] + 
     G[{0, yu^(-1)}, yw]*G[{0, 1/(yu*yv), yu^(-1)}, yw] + 
     G[{0, yv^(-1)}, yw]*G[{0, 1/(yu*yv), yu^(-1)}, yw] - 
     G[{0, 1/(yu*yv)}, yw]*G[{0, 1/(yu*yv), yu^(-1)}, yw] + 
     (Pi^2*G[{0, 1/(yu*yv), yv^(-1)}, yw])/6 - G[{0}, yu^(-1)]*
      G[{1}, yu^(-1)]*G[{0, 1/(yu*yv), yv^(-1)}, yw] - 
     G[{0}, yv^(-1)]*G[{1}, yu^(-1)]*G[{0, 1/(yu*yv), yv^(-1)}, yw] + 
     G[{0}, yw]*G[{1}, yu^(-1)]*G[{0, 1/(yu*yv), yv^(-1)}, yw] + 
     (3*G[{1}, yu^(-1)]^2*G[{0, 1/(yu*yv), yv^(-1)}, yw])/2 + 
     G[{0}, yu^(-1)]*G[{1}, yv^(-1)]*G[{0, 1/(yu*yv), yv^(-1)}, yw] + 
     G[{0}, yv^(-1)]*G[{1}, yv^(-1)]*G[{0, 1/(yu*yv), yv^(-1)}, yw] - 
     G[{0}, yw]*G[{1}, yv^(-1)]*G[{0, 1/(yu*yv), yv^(-1)}, yw] - 
     G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*G[{0, 1/(yu*yv), yv^(-1)}, yw] - 
     (G[{1}, yv^(-1)]^2*G[{0, 1/(yu*yv), yv^(-1)}, yw])/2 - 
     G[{0, 1}, yw]*G[{0, 1/(yu*yv), yv^(-1)}, yw] + 
     G[{0, yu^(-1)}, yw]*G[{0, 1/(yu*yv), yv^(-1)}, yw] + 
     G[{0, yv^(-1)}, yw]*G[{0, 1/(yu*yv), yv^(-1)}, yw] - 
     G[{0, 1/(yu*yv)}, yw]*G[{0, 1/(yu*yv), yv^(-1)}, yw] + 
     G[{0}, yu^(-1)]*G[{1}, yu^(-1)]*G[{0, 1/(yu*yv), 1/(yu*yv)}, yw] + 
     G[{0}, yv^(-1)]*G[{1}, yu^(-1)]*G[{0, 1/(yu*yv), 1/(yu*yv)}, yw] - 
     G[{0}, yw]*G[{1}, yu^(-1)]*G[{0, 1/(yu*yv), 1/(yu*yv)}, yw] - 
     (3*G[{1}, yu^(-1)]^2*G[{0, 1/(yu*yv), 1/(yu*yv)}, yw])/2 + 
     G[{0}, yu^(-1)]*G[{1}, yv^(-1)]*G[{0, 1/(yu*yv), 1/(yu*yv)}, yw] + 
     G[{0}, yv^(-1)]*G[{1}, yv^(-1)]*G[{0, 1/(yu*yv), 1/(yu*yv)}, yw] - 
     G[{0}, yw]*G[{1}, yv^(-1)]*G[{0, 1/(yu*yv), 1/(yu*yv)}, yw] + 
     G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*G[{0, 1/(yu*yv), 1/(yu*yv)}, yw] - 
     (3*G[{1}, yv^(-1)]^2*G[{0, 1/(yu*yv), 1/(yu*yv)}, yw])/2 - 
     2*G[{0}, yu^(-1)]*G[{yu}, yv^(-1)]*G[{0, 1/(yu*yv), 1/(yu*yv)}, yw] - 
     2*G[{0}, yv^(-1)]*G[{yu}, yv^(-1)]*G[{0, 1/(yu*yv), 1/(yu*yv)}, yw] + 
     2*G[{0}, yw]*G[{yu}, yv^(-1)]*G[{0, 1/(yu*yv), 1/(yu*yv)}, yw] + 
     2*G[{yu}, yv^(-1)]^2*G[{0, 1/(yu*yv), 1/(yu*yv)}, yw] + 
     G[{0, 1}, yu^(-1)]*G[{0, 1/(yu*yv), 1/(yu*yv)}, yw] + 
     G[{0, 1}, yv^(-1)]*G[{0, 1/(yu*yv), 1/(yu*yv)}, yw] - 
     G[{0, yu}, yv^(-1)]*G[{0, 1/(yu*yv), 1/(yu*yv)}, yw] - 
     G[{0}, yu^(-1)]*G[{0, 0, 0, 1}, yu^(-1)] - G[{0}, yv^(-1)]*
      G[{0, 0, 0, 1}, yu^(-1)] + G[{0}, yw]*G[{0, 0, 0, 1}, yu^(-1)] - 
     G[{0}, yu^(-1)]*G[{0, 0, 0, 1}, yv^(-1)] - G[{0}, yv^(-1)]*
      G[{0, 0, 0, 1}, yv^(-1)] + G[{0}, yw]*G[{0, 0, 0, 1}, yv^(-1)] + 
     G[{0}, yu^(-1)]*G[{0, 0, 0, yu}, yv^(-1)] + 
     G[{0}, yv^(-1)]*G[{0, 0, 0, yu}, yv^(-1)] - 
     G[{0}, yw]*G[{0, 0, 0, yu}, yv^(-1)] - G[{0}, yu^(-1)]*
      G[{0, 0, 1, 1}, yu^(-1)] - G[{0}, yv^(-1)]*G[{0, 0, 1, 1}, yu^(-1)] + 
     G[{0}, yw]*G[{0, 0, 1, 1}, yu^(-1)] - 2*G[{1}, yu^(-1)]*
      G[{0, 0, 1, 1}, yu^(-1)] + 2*G[{1}, yv^(-1)]*G[{0, 0, 1, 1}, yu^(-1)] - 
     G[{0}, yu^(-1)]*G[{0, 0, 1, 1}, yv^(-1)] - G[{0}, yv^(-1)]*
      G[{0, 0, 1, 1}, yv^(-1)] + G[{0}, yw]*G[{0, 0, 1, 1}, yv^(-1)] + 
     G[{1}, yu^(-1)]*G[{0, 0, 1, 1}, yv^(-1)] - 2*G[{1}, yv^(-1)]*
      G[{0, 0, 1, 1}, yv^(-1)] + 2*G[{0}, yu^(-1)]*G[{0, 0, 1, 1}, yw] + 
     2*G[{0}, yv^(-1)]*G[{0, 0, 1, 1}, yw] - 2*G[{0}, yw]*
      G[{0, 0, 1, 1}, yw] - 4*G[{yu}, yv^(-1)]*G[{0, 0, 1, 1}, yw] - 
     2*G[{1}, yu^(-1)]*G[{0, 0, 1, yu^(-1)}, yw] + 
     2*G[{1}, yv^(-1)]*G[{0, 0, 1, yu^(-1)}, yw] - 
     2*G[{0}, yu^(-1)]*G[{0, 0, 1, yu}, yv^(-1)] - 
     2*G[{0}, yv^(-1)]*G[{0, 0, 1, yu}, yv^(-1)] + 
     2*G[{0}, yw]*G[{0, 0, 1, yu}, yv^(-1)] + 2*G[{1}, yv^(-1)]*
      G[{0, 0, 1, yu}, yv^(-1)] + 2*G[{1}, yu^(-1)]*G[{0, 0, 1, yv^(-1)}, 
       yw] - 2*G[{1}, yv^(-1)]*G[{0, 0, 1, yv^(-1)}, yw] - 
     2*G[{0}, yu^(-1)]*G[{0, 0, 1, 1/(yu*yv)}, yw] - 
     2*G[{0}, yv^(-1)]*G[{0, 0, 1, 1/(yu*yv)}, yw] + 
     2*G[{0}, yw]*G[{0, 0, 1, 1/(yu*yv)}, yw] + 4*G[{yu}, yv^(-1)]*
      G[{0, 0, 1, 1/(yu*yv)}, yw] + 2*G[{0}, yu^(-1)]*
      G[{0, 0, yu^(-1), 1/(yu*yv)}, yw] + 2*G[{0}, yv^(-1)]*
      G[{0, 0, yu^(-1), 1/(yu*yv)}, yw] - 2*G[{0}, yw]*
      G[{0, 0, yu^(-1), 1/(yu*yv)}, yw] - 2*G[{1}, yu^(-1)]*
      G[{0, 0, yu^(-1), 1/(yu*yv)}, yw] - 2*G[{1}, yv^(-1)]*
      G[{0, 0, yu^(-1), 1/(yu*yv)}, yw] - G[{0}, yu^(-1)]*
      G[{0, 0, yu, 1}, yv^(-1)] - G[{0}, yv^(-1)]*G[{0, 0, yu, 1}, yv^(-1)] + 
     G[{0}, yw]*G[{0, 0, yu, 1}, yv^(-1)] - G[{1}, yu^(-1)]*
      G[{0, 0, yu, 1}, yv^(-1)] + 2*G[{1}, yv^(-1)]*
      G[{0, 0, yu, 1}, yv^(-1)] + 2*G[{0}, yu^(-1)]*
      G[{0, 0, yu, yu}, yv^(-1)] + 2*G[{0}, yv^(-1)]*
      G[{0, 0, yu, yu}, yv^(-1)] - 2*G[{0}, yw]*G[{0, 0, yu, yu}, yv^(-1)] + 
     2*G[{0}, yu^(-1)]*G[{0, 0, yv^(-1), 1/(yu*yv)}, yw] + 
     2*G[{0}, yv^(-1)]*G[{0, 0, yv^(-1), 1/(yu*yv)}, yw] - 
     2*G[{0}, yw]*G[{0, 0, yv^(-1), 1/(yu*yv)}, yw] - 
     2*G[{1}, yu^(-1)]*G[{0, 0, yv^(-1), 1/(yu*yv)}, yw] - 
     2*G[{1}, yv^(-1)]*G[{0, 0, yv^(-1), 1/(yu*yv)}, yw] - 
     2*G[{0}, yu^(-1)]*G[{0, 0, 1/(yu*yv), 1}, yw] - 
     2*G[{0}, yv^(-1)]*G[{0, 0, 1/(yu*yv), 1}, yw] + 
     2*G[{0}, yw]*G[{0, 0, 1/(yu*yv), 1}, yw] + 4*G[{yu}, yv^(-1)]*
      G[{0, 0, 1/(yu*yv), 1}, yw] + 2*G[{0}, yu^(-1)]*
      G[{0, 0, 1/(yu*yv), yu^(-1)}, yw] + 2*G[{0}, yv^(-1)]*
      G[{0, 0, 1/(yu*yv), yu^(-1)}, yw] - 2*G[{0}, yw]*
      G[{0, 0, 1/(yu*yv), yu^(-1)}, yw] - 4*G[{1}, yv^(-1)]*
      G[{0, 0, 1/(yu*yv), yu^(-1)}, yw] + 2*G[{0}, yu^(-1)]*
      G[{0, 0, 1/(yu*yv), yv^(-1)}, yw] + 2*G[{0}, yv^(-1)]*
      G[{0, 0, 1/(yu*yv), yv^(-1)}, yw] - 2*G[{0}, yw]*
      G[{0, 0, 1/(yu*yv), yv^(-1)}, yw] - 4*G[{1}, yu^(-1)]*
      G[{0, 0, 1/(yu*yv), yv^(-1)}, yw] - 2*G[{0}, yu^(-1)]*
      G[{0, 0, 1/(yu*yv), 1/(yu*yv)}, yw] - 2*G[{0}, yv^(-1)]*
      G[{0, 0, 1/(yu*yv), 1/(yu*yv)}, yw] + 2*G[{0}, yw]*
      G[{0, 0, 1/(yu*yv), 1/(yu*yv)}, yw] + 4*G[{1}, yu^(-1)]*
      G[{0, 0, 1/(yu*yv), 1/(yu*yv)}, yw] + 4*G[{1}, yv^(-1)]*
      G[{0, 0, 1/(yu*yv), 1/(yu*yv)}, yw] - 4*G[{yu}, yv^(-1)]*
      G[{0, 0, 1/(yu*yv), 1/(yu*yv)}, yw] + G[{0}, yu^(-1)]*
      G[{0, 1, 0, yu^(-1)}, yw] + G[{0}, yv^(-1)]*G[{0, 1, 0, yu^(-1)}, yw] - 
     G[{0}, yw]*G[{0, 1, 0, yu^(-1)}, yw] - G[{1}, yu^(-1)]*
      G[{0, 1, 0, yu^(-1)}, yw] - G[{1}, yv^(-1)]*G[{0, 1, 0, yu^(-1)}, yw] - 
     G[{0}, yu^(-1)]*G[{0, 1, 0, yu}, yv^(-1)] - 
     G[{0}, yv^(-1)]*G[{0, 1, 0, yu}, yv^(-1)] + 
     G[{0}, yw]*G[{0, 1, 0, yu}, yv^(-1)] + G[{1}, yv^(-1)]*
      G[{0, 1, 0, yu}, yv^(-1)] + G[{0}, yu^(-1)]*G[{0, 1, 0, yv^(-1)}, yw] + 
     G[{0}, yv^(-1)]*G[{0, 1, 0, yv^(-1)}, yw] - 
     G[{0}, yw]*G[{0, 1, 0, yv^(-1)}, yw] - G[{1}, yu^(-1)]*
      G[{0, 1, 0, yv^(-1)}, yw] - G[{1}, yv^(-1)]*G[{0, 1, 0, yv^(-1)}, yw] - 
     2*G[{0}, yu^(-1)]*G[{0, 1, 0, 1/(yu*yv)}, yw] - 
     2*G[{0}, yv^(-1)]*G[{0, 1, 0, 1/(yu*yv)}, yw] + 
     2*G[{0}, yw]*G[{0, 1, 0, 1/(yu*yv)}, yw] + 2*G[{1}, yu^(-1)]*
      G[{0, 1, 0, 1/(yu*yv)}, yw] + 2*G[{1}, yv^(-1)]*
      G[{0, 1, 0, 1/(yu*yv)}, yw] - 3*G[{1}, yu^(-1)]*
      G[{0, 1, 1, 1}, yu^(-1)] + 3*G[{1}, yv^(-1)]*G[{0, 1, 1, 1}, yu^(-1)] + 
     3*G[{1}, yu^(-1)]*G[{0, 1, 1, 1}, yv^(-1)] - 
     3*G[{1}, yv^(-1)]*G[{0, 1, 1, 1}, yv^(-1)] + 
     2*G[{0}, yu^(-1)]*G[{0, 1, 1, 1}, yw] + 2*G[{0}, yv^(-1)]*
      G[{0, 1, 1, 1}, yw] - 2*G[{0}, yw]*G[{0, 1, 1, 1}, yw] + 
     G[{1}, yu^(-1)]*G[{0, 1, 1, 1}, yw] + G[{1}, yv^(-1)]*
      G[{0, 1, 1, 1}, yw] - 6*G[{yu}, yv^(-1)]*G[{0, 1, 1, 1}, yw] - 
     G[{0}, yu^(-1)]*G[{0, 1, 1, yu^(-1)}, yw] - 
     G[{0}, yv^(-1)]*G[{0, 1, 1, yu^(-1)}, yw] + 
     G[{0}, yw]*G[{0, 1, 1, yu^(-1)}, yw] + 2*G[{1}, yv^(-1)]*
      G[{0, 1, 1, yu^(-1)}, yw] - G[{0}, yu^(-1)]*G[{0, 1, 1, yv^(-1)}, yw] - 
     G[{0}, yv^(-1)]*G[{0, 1, 1, yv^(-1)}, yw] + 
     G[{0}, yw]*G[{0, 1, 1, yv^(-1)}, yw] + 2*G[{1}, yu^(-1)]*
      G[{0, 1, 1, yv^(-1)}, yw] - G[{1}, yu^(-1)]*G[{0, 1, 1, 1/(yu*yv)}, 
       yw] - G[{1}, yv^(-1)]*G[{0, 1, 1, 1/(yu*yv)}, yw] + 
     2*G[{yu}, yv^(-1)]*G[{0, 1, 1, 1/(yu*yv)}, yw] + 
     G[{0}, yu^(-1)]*G[{0, 1, yu^(-1), 1}, yw] + 
     G[{0}, yv^(-1)]*G[{0, 1, yu^(-1), 1}, yw] - 
     G[{0}, yw]*G[{0, 1, yu^(-1), 1}, yw] - G[{1}, yu^(-1)]*
      G[{0, 1, yu^(-1), 1}, yw] - G[{1}, yv^(-1)]*G[{0, 1, yu^(-1), 1}, yw] - 
     2*G[{0}, yu^(-1)]*G[{0, 1, yu^(-1), yu^(-1)}, yw] - 
     2*G[{0}, yv^(-1)]*G[{0, 1, yu^(-1), yu^(-1)}, yw] + 
     2*G[{0}, yw]*G[{0, 1, yu^(-1), yu^(-1)}, yw] + 
     4*G[{1}, yv^(-1)]*G[{0, 1, yu^(-1), yu^(-1)}, yw] + 
     G[{0}, yu^(-1)]*G[{0, 1, yu^(-1), 1/(yu*yv)}, yw] + 
     G[{0}, yv^(-1)]*G[{0, 1, yu^(-1), 1/(yu*yv)}, yw] - 
     G[{0}, yw]*G[{0, 1, yu^(-1), 1/(yu*yv)}, yw] - 
     G[{1}, yu^(-1)]*G[{0, 1, yu^(-1), 1/(yu*yv)}, yw] - 
     G[{1}, yv^(-1)]*G[{0, 1, yu^(-1), 1/(yu*yv)}, yw] + 
     G[{0}, yu^(-1)]*G[{0, 1, yv^(-1), 1}, yw] + 
     G[{0}, yv^(-1)]*G[{0, 1, yv^(-1), 1}, yw] - 
     G[{0}, yw]*G[{0, 1, yv^(-1), 1}, yw] - G[{1}, yu^(-1)]*
      G[{0, 1, yv^(-1), 1}, yw] - G[{1}, yv^(-1)]*G[{0, 1, yv^(-1), 1}, yw] - 
     2*G[{0}, yu^(-1)]*G[{0, 1, yv^(-1), yv^(-1)}, yw] - 
     2*G[{0}, yv^(-1)]*G[{0, 1, yv^(-1), yv^(-1)}, yw] + 
     2*G[{0}, yw]*G[{0, 1, yv^(-1), yv^(-1)}, yw] + 
     4*G[{1}, yu^(-1)]*G[{0, 1, yv^(-1), yv^(-1)}, yw] + 
     G[{0}, yu^(-1)]*G[{0, 1, yv^(-1), 1/(yu*yv)}, yw] + 
     G[{0}, yv^(-1)]*G[{0, 1, yv^(-1), 1/(yu*yv)}, yw] - 
     G[{0}, yw]*G[{0, 1, yv^(-1), 1/(yu*yv)}, yw] - 
     G[{1}, yu^(-1)]*G[{0, 1, yv^(-1), 1/(yu*yv)}, yw] - 
     G[{1}, yv^(-1)]*G[{0, 1, yv^(-1), 1/(yu*yv)}, yw] - 
     2*G[{0}, yu^(-1)]*G[{0, 1, 1/(yu*yv), 1}, yw] - 
     2*G[{0}, yv^(-1)]*G[{0, 1, 1/(yu*yv), 1}, yw] + 
     2*G[{0}, yw]*G[{0, 1, 1/(yu*yv), 1}, yw] + G[{1}, yu^(-1)]*
      G[{0, 1, 1/(yu*yv), 1}, yw] + G[{1}, yv^(-1)]*G[{0, 1, 1/(yu*yv), 1}, 
       yw] + 2*G[{yu}, yv^(-1)]*G[{0, 1, 1/(yu*yv), 1}, yw] + 
     G[{0}, yu^(-1)]*G[{0, 1, 1/(yu*yv), yu^(-1)}, yw] + 
     G[{0}, yv^(-1)]*G[{0, 1, 1/(yu*yv), yu^(-1)}, yw] - 
     G[{0}, yw]*G[{0, 1, 1/(yu*yv), yu^(-1)}, yw] - 
     2*G[{1}, yv^(-1)]*G[{0, 1, 1/(yu*yv), yu^(-1)}, yw] + 
     G[{0}, yu^(-1)]*G[{0, 1, 1/(yu*yv), yv^(-1)}, yw] + 
     G[{0}, yv^(-1)]*G[{0, 1, 1/(yu*yv), yv^(-1)}, yw] - 
     G[{0}, yw]*G[{0, 1, 1/(yu*yv), yv^(-1)}, yw] - 
     2*G[{1}, yu^(-1)]*G[{0, 1, 1/(yu*yv), yv^(-1)}, yw] - 
     G[{1}, yu^(-1)]*G[{0, 1, 1/(yu*yv), 1/(yu*yv)}, yw] - 
     G[{1}, yv^(-1)]*G[{0, 1, 1/(yu*yv), 1/(yu*yv)}, yw] + 
     2*G[{yu}, yv^(-1)]*G[{0, 1, 1/(yu*yv), 1/(yu*yv)}, yw] + 
     G[{0}, yu^(-1)]*G[{0, yu^(-1), 0, 1/(yu*yv)}, yw] + 
     G[{0}, yv^(-1)]*G[{0, yu^(-1), 0, 1/(yu*yv)}, yw] - 
     G[{0}, yw]*G[{0, yu^(-1), 0, 1/(yu*yv)}, yw] - 
     G[{1}, yu^(-1)]*G[{0, yu^(-1), 0, 1/(yu*yv)}, yw] - 
     G[{1}, yv^(-1)]*G[{0, yu^(-1), 0, 1/(yu*yv)}, yw] - 
     G[{1}, yu^(-1)]*G[{0, yu, 1, 1}, yv^(-1)] + 
     G[{1}, yv^(-1)]*G[{0, yu, 1, 1}, yv^(-1)] - 2*G[{1}, yu^(-1)]*
      G[{0, yu, yu, 1}, yv^(-1)] + 2*G[{1}, yv^(-1)]*
      G[{0, yu, yu, 1}, yv^(-1)] + G[{0}, yu^(-1)]*
      G[{0, yv^(-1), 0, 1/(yu*yv)}, yw] + G[{0}, yv^(-1)]*
      G[{0, yv^(-1), 0, 1/(yu*yv)}, yw] - 
     G[{0}, yw]*G[{0, yv^(-1), 0, 1/(yu*yv)}, yw] - 
     G[{1}, yu^(-1)]*G[{0, yv^(-1), 0, 1/(yu*yv)}, yw] - 
     G[{1}, yv^(-1)]*G[{0, yv^(-1), 0, 1/(yu*yv)}, yw] - 
     2*G[{0}, yu^(-1)]*G[{0, 1/(yu*yv), 1, 1}, yw] - 
     2*G[{0}, yv^(-1)]*G[{0, 1/(yu*yv), 1, 1}, yw] + 
     2*G[{0}, yw]*G[{0, 1/(yu*yv), 1, 1}, yw] - G[{1}, yu^(-1)]*
      G[{0, 1/(yu*yv), 1, 1}, yw] - G[{1}, yv^(-1)]*G[{0, 1/(yu*yv), 1, 1}, 
       yw] + 6*G[{yu}, yv^(-1)]*G[{0, 1/(yu*yv), 1, 1}, yw] + 
     G[{0}, yu^(-1)]*G[{0, 1/(yu*yv), 1, yu^(-1)}, yw] + 
     G[{0}, yv^(-1)]*G[{0, 1/(yu*yv), 1, yu^(-1)}, yw] - 
     G[{0}, yw]*G[{0, 1/(yu*yv), 1, yu^(-1)}, yw] - 
     2*G[{1}, yv^(-1)]*G[{0, 1/(yu*yv), 1, yu^(-1)}, yw] + 
     G[{0}, yu^(-1)]*G[{0, 1/(yu*yv), 1, yv^(-1)}, yw] + 
     G[{0}, yv^(-1)]*G[{0, 1/(yu*yv), 1, yv^(-1)}, yw] - 
     G[{0}, yw]*G[{0, 1/(yu*yv), 1, yv^(-1)}, yw] - 
     2*G[{1}, yu^(-1)]*G[{0, 1/(yu*yv), 1, yv^(-1)}, yw] + 
     G[{1}, yu^(-1)]*G[{0, 1/(yu*yv), 1, 1/(yu*yv)}, yw] + 
     G[{1}, yv^(-1)]*G[{0, 1/(yu*yv), 1, 1/(yu*yv)}, yw] - 
     2*G[{yu}, yv^(-1)]*G[{0, 1/(yu*yv), 1, 1/(yu*yv)}, yw] - 
     G[{0}, yu^(-1)]*G[{0, 1/(yu*yv), yu^(-1), 1}, yw] - 
     G[{0}, yv^(-1)]*G[{0, 1/(yu*yv), yu^(-1), 1}, yw] + 
     G[{0}, yw]*G[{0, 1/(yu*yv), yu^(-1), 1}, yw] + 
     G[{1}, yu^(-1)]*G[{0, 1/(yu*yv), yu^(-1), 1}, yw] + 
     G[{1}, yv^(-1)]*G[{0, 1/(yu*yv), yu^(-1), 1}, yw] + 
     2*G[{0}, yu^(-1)]*G[{0, 1/(yu*yv), yu^(-1), yu^(-1)}, yw] + 
     2*G[{0}, yv^(-1)]*G[{0, 1/(yu*yv), yu^(-1), yu^(-1)}, yw] - 
     2*G[{0}, yw]*G[{0, 1/(yu*yv), yu^(-1), yu^(-1)}, yw] - 
     4*G[{1}, yv^(-1)]*G[{0, 1/(yu*yv), yu^(-1), yu^(-1)}, yw] - 
     G[{0}, yu^(-1)]*G[{0, 1/(yu*yv), yu^(-1), 1/(yu*yv)}, yw] - 
     G[{0}, yv^(-1)]*G[{0, 1/(yu*yv), yu^(-1), 1/(yu*yv)}, yw] + 
     G[{0}, yw]*G[{0, 1/(yu*yv), yu^(-1), 1/(yu*yv)}, yw] + 
     G[{1}, yu^(-1)]*G[{0, 1/(yu*yv), yu^(-1), 1/(yu*yv)}, yw] + 
     G[{1}, yv^(-1)]*G[{0, 1/(yu*yv), yu^(-1), 1/(yu*yv)}, yw] - 
     G[{0}, yu^(-1)]*G[{0, 1/(yu*yv), yv^(-1), 1}, yw] - 
     G[{0}, yv^(-1)]*G[{0, 1/(yu*yv), yv^(-1), 1}, yw] + 
     G[{0}, yw]*G[{0, 1/(yu*yv), yv^(-1), 1}, yw] + 
     G[{1}, yu^(-1)]*G[{0, 1/(yu*yv), yv^(-1), 1}, yw] + 
     G[{1}, yv^(-1)]*G[{0, 1/(yu*yv), yv^(-1), 1}, yw] + 
     2*G[{0}, yu^(-1)]*G[{0, 1/(yu*yv), yv^(-1), yv^(-1)}, yw] + 
     2*G[{0}, yv^(-1)]*G[{0, 1/(yu*yv), yv^(-1), yv^(-1)}, yw] - 
     2*G[{0}, yw]*G[{0, 1/(yu*yv), yv^(-1), yv^(-1)}, yw] - 
     4*G[{1}, yu^(-1)]*G[{0, 1/(yu*yv), yv^(-1), yv^(-1)}, yw] - 
     G[{0}, yu^(-1)]*G[{0, 1/(yu*yv), yv^(-1), 1/(yu*yv)}, yw] - 
     G[{0}, yv^(-1)]*G[{0, 1/(yu*yv), yv^(-1), 1/(yu*yv)}, yw] + 
     G[{0}, yw]*G[{0, 1/(yu*yv), yv^(-1), 1/(yu*yv)}, yw] + 
     G[{1}, yu^(-1)]*G[{0, 1/(yu*yv), yv^(-1), 1/(yu*yv)}, yw] + 
     G[{1}, yv^(-1)]*G[{0, 1/(yu*yv), yv^(-1), 1/(yu*yv)}, yw] + 
     2*G[{0}, yu^(-1)]*G[{0, 1/(yu*yv), 1/(yu*yv), 1}, yw] + 
     2*G[{0}, yv^(-1)]*G[{0, 1/(yu*yv), 1/(yu*yv), 1}, yw] - 
     2*G[{0}, yw]*G[{0, 1/(yu*yv), 1/(yu*yv), 1}, yw] - 
     G[{1}, yu^(-1)]*G[{0, 1/(yu*yv), 1/(yu*yv), 1}, yw] - 
     G[{1}, yv^(-1)]*G[{0, 1/(yu*yv), 1/(yu*yv), 1}, yw] - 
     2*G[{yu}, yv^(-1)]*G[{0, 1/(yu*yv), 1/(yu*yv), 1}, yw] - 
     G[{0}, yu^(-1)]*G[{0, 1/(yu*yv), 1/(yu*yv), yu^(-1)}, yw] - 
     G[{0}, yv^(-1)]*G[{0, 1/(yu*yv), 1/(yu*yv), yu^(-1)}, yw] + 
     G[{0}, yw]*G[{0, 1/(yu*yv), 1/(yu*yv), yu^(-1)}, yw] + 
     2*G[{1}, yv^(-1)]*G[{0, 1/(yu*yv), 1/(yu*yv), yu^(-1)}, yw] - 
     G[{0}, yu^(-1)]*G[{0, 1/(yu*yv), 1/(yu*yv), yv^(-1)}, yw] - 
     G[{0}, yv^(-1)]*G[{0, 1/(yu*yv), 1/(yu*yv), yv^(-1)}, yw] + 
     G[{0}, yw]*G[{0, 1/(yu*yv), 1/(yu*yv), yv^(-1)}, yw] + 
     2*G[{1}, yu^(-1)]*G[{0, 1/(yu*yv), 1/(yu*yv), yv^(-1)}, yw] + 
     G[{1}, yu^(-1)]*G[{0, 1/(yu*yv), 1/(yu*yv), 1/(yu*yv)}, yw] + 
     G[{1}, yv^(-1)]*G[{0, 1/(yu*yv), 1/(yu*yv), 1/(yu*yv)}, yw] - 
     2*G[{yu}, yv^(-1)]*G[{0, 1/(yu*yv), 1/(yu*yv), 1/(yu*yv)}, yw] + 
     2*G[{0, 0, 0, 1, 1}, yu^(-1)] + 2*G[{0, 0, 0, 1, 1}, yv^(-1)] + 
     12*G[{0, 0, 0, 1, 1}, yw] - 6*G[{0, 0, 0, 1, yu^(-1)}, yw] - 
     3*G[{0, 0, 0, 1, yu}, yv^(-1)] - 6*G[{0, 0, 0, 1, yv^(-1)}, yw] - 
     6*G[{0, 0, 0, yu^(-1), 1}, yw] + 6*G[{0, 0, 0, yu^(-1), 1/(yu*yv)}, 
       yw] - 3*G[{0, 0, 0, yu, 1}, yv^(-1)] + 
     4*G[{0, 0, 0, yu, yu}, yv^(-1)] - 6*G[{0, 0, 0, yv^(-1), 1}, yw] + 
     6*G[{0, 0, 0, yv^(-1), 1/(yu*yv)}, yw] + 
     6*G[{0, 0, 0, 1/(yu*yv), yu^(-1)}, yw] + 
     6*G[{0, 0, 0, 1/(yu*yv), yv^(-1)}, yw] - 
     12*G[{0, 0, 0, 1/(yu*yv), 1/(yu*yv)}, yw] + 4*G[{0, 0, 1, 0, 1}, yw] - 
     2*G[{0, 0, 1, 0, yu^(-1)}, yw] - G[{0, 0, 1, 0, yu}, yv^(-1)] - 
     2*G[{0, 0, 1, 0, yv^(-1)}, yw] + 3*G[{0, 0, 1, 1, 1}, yu^(-1)] + 
     3*G[{0, 0, 1, 1, 1}, yv^(-1)] + 4*G[{0, 0, 1, 1, 1}, yw] - 
     6*G[{0, 0, 1, 1, yu^(-1)}, yw] + 2*G[{0, 0, 1, 1, yu}, yv^(-1)] - 
     6*G[{0, 0, 1, 1, yv^(-1)}, yw] - 4*G[{0, 0, 1, yu^(-1), yu^(-1)}, yw] - 
     2*G[{0, 0, 1, yu^(-1), 1/(yu*yv)}, yw] + 
     2*G[{0, 0, 1, yu, 1}, yv^(-1)] - 4*G[{0, 0, 1, yu, yu}, yv^(-1)] - 
     4*G[{0, 0, 1, yv^(-1), yv^(-1)}, yw] - 
     2*G[{0, 0, 1, yv^(-1), 1/(yu*yv)}, yw] - 
     4*G[{0, 0, 1, 1/(yu*yv), 1}, yw] - 2*G[{0, 0, yu^(-1), 0, 1}, yw] + 
     2*G[{0, 0, yu^(-1), 0, 1/(yu*yv)}, yw] + 
     4*G[{0, 0, yu^(-1), yu^(-1), 1/(yu*yv)}, yw] + 
     2*G[{0, 0, yu^(-1), 1/(yu*yv), yu^(-1)}, yw] - 
     2*G[{0, 0, yu^(-1), 1/(yu*yv), yv^(-1)}, yw] - 
     G[{0, 0, yu, 0, 1}, yv^(-1)] + 2*G[{0, 0, yu, 0, yu}, yv^(-1)] + 
     G[{0, 0, yu, 1, 1}, yv^(-1)] + 2*G[{0, 0, yu, yu, 1}, yv^(-1)] - 
     12*G[{0, 0, yu, yu, yu}, yv^(-1)] - 2*G[{0, 0, yv^(-1), 0, 1}, yw] + 
     2*G[{0, 0, yv^(-1), 0, 1/(yu*yv)}, yw] + 
     4*G[{0, 0, yv^(-1), yv^(-1), 1/(yu*yv)}, yw] + 
     2*G[{0, 0, yv^(-1), 1/(yu*yv), yu^(-1)}, yw] + 
     2*G[{0, 0, yv^(-1), 1/(yu*yv), yv^(-1)}, yw] + 
     2*G[{0, 0, 1/(yu*yv), 0, yu^(-1)}, yw] + 
     2*G[{0, 0, 1/(yu*yv), 0, yv^(-1)}, yw] - 
     4*G[{0, 0, 1/(yu*yv), 0, 1/(yu*yv)}, yw] - 
     4*G[{0, 0, 1/(yu*yv), 1, 1}, yw] + 
     4*G[{0, 0, 1/(yu*yv), yu^(-1), yu^(-1)}, yw] + 
     4*G[{0, 0, 1/(yu*yv), yv^(-1), yv^(-1)}, yw] + 
     4*G[{0, 0, 1/(yu*yv), 1/(yu*yv), 1}, yw] + 
     2*G[{0, 0, 1/(yu*yv), 1/(yu*yv), yu^(-1)}, yw] + 
     2*G[{0, 0, 1/(yu*yv), 1/(yu*yv), yv^(-1)}, yw] - 
     3*G[{0, 1, 0, 1, yu^(-1)}, yw] + G[{0, 1, 0, 1, yu}, yv^(-1)] - 
     3*G[{0, 1, 0, 1, yv^(-1)}, yw] - G[{0, 1, 0, yu^(-1), 1/(yu*yv)}, yw] + 
     G[{0, 1, 0, yu, 1}, yv^(-1)] - 2*G[{0, 1, 0, yu, yu}, yv^(-1)] - 
     G[{0, 1, 0, yv^(-1), 1/(yu*yv)}, yw] - 
     2*G[{0, 1, 0, 1/(yu*yv), yu^(-1)}, yw] - 
     2*G[{0, 1, 0, 1/(yu*yv), yv^(-1)}, yw] + G[{0, 1, 1, 0, yu}, yv^(-1)] + 
     6*G[{0, 1, 1, 1, 1}, yw] - G[{0, 1, 1, 1, yu^(-1)}, yw] - 
     G[{0, 1, 1, 1, yv^(-1)}, yw] - 2*G[{0, 1, 1, yu^(-1), yu^(-1)}, yw] - 
     2*G[{0, 1, 1, yv^(-1), yv^(-1)}, yw] - 
     2*G[{0, 1, 1, 1/(yu*yv), 1}, yw] + G[{0, 1, 1, 1/(yu*yv), yu^(-1)}, 
      yw] + G[{0, 1, 1, 1/(yu*yv), yv^(-1)}, yw] - 
     G[{0, 1, yu^(-1), 0, yu^(-1)}, yw] - G[{0, 1, yu^(-1), 0, yv^(-1)}, 
      yw] - G[{0, 1, yu^(-1), 0, 1/(yu*yv)}, yw] + 
     G[{0, 1, yu^(-1), 1, yu^(-1)}, yw] + G[{0, 1, yu^(-1), 1, yv^(-1)}, 
      yw] - 4*G[{0, 1, yu^(-1), yu^(-1), yu^(-1)}, yw] + 
     G[{0, 1, yu^(-1), 1/(yu*yv), yu^(-1)}, yw] + 
     G[{0, 1, yu^(-1), 1/(yu*yv), yv^(-1)}, yw] - 
     2*G[{0, 1, yu, 0, yu}, yv^(-1)] - G[{0, 1, yv^(-1), 0, yu^(-1)}, yw] - 
     G[{0, 1, yv^(-1), 0, yv^(-1)}, yw] - G[{0, 1, yv^(-1), 0, 1/(yu*yv)}, 
      yw] + G[{0, 1, yv^(-1), 1, yu^(-1)}, yw] + 
     G[{0, 1, yv^(-1), 1, yv^(-1)}, yw] - 
     4*G[{0, 1, yv^(-1), yv^(-1), yv^(-1)}, yw] + 
     G[{0, 1, yv^(-1), 1/(yu*yv), yu^(-1)}, yw] + 
     G[{0, 1, yv^(-1), 1/(yu*yv), yv^(-1)}, yw] - 
     2*G[{0, 1, 1/(yu*yv), 1, 1}, yw] - G[{0, 1, 1/(yu*yv), 1, yu^(-1)}, 
      yw] - G[{0, 1, 1/(yu*yv), 1, yv^(-1)}, yw] + 
     2*G[{0, 1, 1/(yu*yv), yu^(-1), yu^(-1)}, yw] + 
     2*G[{0, 1, 1/(yu*yv), yv^(-1), yv^(-1)}, yw] - 
     2*G[{0, 1, 1/(yu*yv), 1/(yu*yv), 1}, yw] + 
     G[{0, 1, 1/(yu*yv), 1/(yu*yv), yu^(-1)}, yw] + 
     G[{0, 1, 1/(yu*yv), 1/(yu*yv), yv^(-1)}, yw] + 
     2*G[{0, yu^(-1), 0, yu^(-1), 1/(yu*yv)}, yw] + 
     G[{0, yu^(-1), 0, 1/(yu*yv), yu^(-1)}, yw] - 
     G[{0, yu^(-1), 0, 1/(yu*yv), yv^(-1)}, yw] + 
     2*G[{0, yu^(-1), yu^(-1), 0, 1/(yu*yv)}, yw] + 
     2*G[{0, yu^(-1), yv^(-1), 0, 1/(yu*yv)}, yw] - 
     2*G[{0, yu^(-1), 1/(yu*yv), 0, yv^(-1)}, yw] + 
     G[{0, yu, 0, yu, 1}, yv^(-1)] - 4*G[{0, yu, 0, yu, yu}, yv^(-1)] + 
     2*G[{0, yv^(-1), 0, yv^(-1), 1/(yu*yv)}, yw] + 
     G[{0, yv^(-1), 0, 1/(yu*yv), yu^(-1)}, yw] + 
     G[{0, yv^(-1), 0, 1/(yu*yv), yv^(-1)}, yw] + 
     2*G[{0, yv^(-1), yu^(-1), 0, 1/(yu*yv)}, yw] + 
     2*G[{0, yv^(-1), yv^(-1), 0, 1/(yu*yv)}, yw] + 
     3*G[{0, 1/(yu*yv), 0, 1/(yu*yv), yu^(-1)}, yw] + 
     3*G[{0, 1/(yu*yv), 0, 1/(yu*yv), yv^(-1)}, yw] - 
     6*G[{0, 1/(yu*yv), 1, 1, 1}, yw] + G[{0, 1/(yu*yv), 1, 1, yu^(-1)}, 
      yw] + G[{0, 1/(yu*yv), 1, 1, yv^(-1)}, yw] + 
     2*G[{0, 1/(yu*yv), 1, yu^(-1), yu^(-1)}, yw] + 
     2*G[{0, 1/(yu*yv), 1, yv^(-1), yv^(-1)}, yw] + 
     2*G[{0, 1/(yu*yv), 1, 1/(yu*yv), 1}, yw] - 
     G[{0, 1/(yu*yv), 1, 1/(yu*yv), yu^(-1)}, yw] - 
     G[{0, 1/(yu*yv), 1, 1/(yu*yv), yv^(-1)}, yw] - 
     G[{0, 1/(yu*yv), yu^(-1), 1, yu^(-1)}, yw] - 
     G[{0, 1/(yu*yv), yu^(-1), 1, yv^(-1)}, yw] + 
     4*G[{0, 1/(yu*yv), yu^(-1), yu^(-1), yu^(-1)}, yw] - 
     G[{0, 1/(yu*yv), yu^(-1), 1/(yu*yv), yu^(-1)}, yw] - 
     G[{0, 1/(yu*yv), yu^(-1), 1/(yu*yv), yv^(-1)}, yw] - 
     G[{0, 1/(yu*yv), yv^(-1), 1, yu^(-1)}, yw] - 
     G[{0, 1/(yu*yv), yv^(-1), 1, yv^(-1)}, yw] + 
     4*G[{0, 1/(yu*yv), yv^(-1), yv^(-1), yv^(-1)}, yw] - 
     G[{0, 1/(yu*yv), yv^(-1), 1/(yu*yv), yu^(-1)}, yw] - 
     G[{0, 1/(yu*yv), yv^(-1), 1/(yu*yv), yv^(-1)}, yw] + 
     2*G[{0, 1/(yu*yv), 1/(yu*yv), 1, 1}, yw] + 
     G[{0, 1/(yu*yv), 1/(yu*yv), 1, yu^(-1)}, yw] + 
     G[{0, 1/(yu*yv), 1/(yu*yv), 1, yv^(-1)}, yw] - 
     2*G[{0, 1/(yu*yv), 1/(yu*yv), yu^(-1), yu^(-1)}, yw] - 
     2*G[{0, 1/(yu*yv), 1/(yu*yv), yv^(-1), yv^(-1)}, yw] + 
     2*G[{0, 1/(yu*yv), 1/(yu*yv), 1/(yu*yv), 1}, yw] - 
     G[{0, 1/(yu*yv), 1/(yu*yv), 1/(yu*yv), yu^(-1)}, yw] - 
     G[{0, 1/(yu*yv), 1/(yu*yv), 1/(yu*yv), yv^(-1)}, yw] + 
     (Pi^2*Zeta[3])/3 - G[{1}, yu^(-1)]^2*Zeta[3] + 
     2*G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*Zeta[3] - G[{1}, yv^(-1)]^2*Zeta[3] + 
     2*G[{0, 1}, yu^(-1)]*Zeta[3] + 2*G[{0, 1}, yv^(-1)]*Zeta[3] - 
     2*G[{0, 1}, yw]*Zeta[3] + 2*G[{0, 1/(yu*yv)}, yw]*Zeta[3] + 2*Zeta[5]
 
H1wuvRegII = (Pi^4*G[{0}, yu^(-1)])/30 + (Pi^4*G[{0}, yv^(-1)])/30 - 
     (Pi^4*G[{0}, yw])/30 + (Pi^4*G[{1}, yv^(-1)])/72 + 
     (Pi^2*G[{0}, yu^(-1)]^2*G[{1}, yv^(-1)])/12 + 
     (Pi^2*G[{0}, yu^(-1)]*G[{0}, yv^(-1)]*G[{1}, yv^(-1)])/6 + 
     (Pi^2*G[{0}, yv^(-1)]^2*G[{1}, yv^(-1)])/12 - 
     (Pi^2*G[{0}, yu^(-1)]*G[{0}, yw]*G[{1}, yv^(-1)])/6 - 
     (Pi^2*G[{0}, yv^(-1)]*G[{0}, yw]*G[{1}, yv^(-1)])/6 + 
     (Pi^2*G[{0}, yw]^2*G[{1}, yv^(-1)])/12 - 
     (Pi^2*G[{0}, yu^(-1)]*G[{1}, yv^(-1)]^2)/12 - 
     (Pi^2*G[{0}, yv^(-1)]*G[{1}, yv^(-1)]^2)/12 + 
     (Pi^2*G[{0}, yw]*G[{1}, yv^(-1)]^2)/12 - (Pi^4*G[{1}, yw])/72 - 
     (Pi^2*G[{0}, yu^(-1)]^2*G[{1}, yw])/12 - 
     (Pi^2*G[{0}, yu^(-1)]*G[{0}, yv^(-1)]*G[{1}, yw])/6 - 
     (Pi^2*G[{0}, yv^(-1)]^2*G[{1}, yw])/12 + 
     (Pi^2*G[{0}, yu^(-1)]*G[{0}, yw]*G[{1}, yw])/6 + 
     (Pi^2*G[{0}, yv^(-1)]*G[{0}, yw]*G[{1}, yw])/6 - 
     (Pi^2*G[{0}, yw]^2*G[{1}, yw])/12 + 
     (Pi^2*G[{0}, yu^(-1)]*G[{1}, yv^(-1)]*G[{1}, yw])/6 + 
     (Pi^2*G[{0}, yv^(-1)]*G[{1}, yv^(-1)]*G[{1}, yw])/6 - 
     (Pi^2*G[{0}, yw]*G[{1}, yv^(-1)]*G[{1}, yw])/6 - 
     (Pi^2*G[{0}, yu^(-1)]*G[{1}, yw]^2)/12 - 
     (Pi^2*G[{0}, yv^(-1)]*G[{1}, yw]^2)/12 + (Pi^2*G[{0}, yw]*G[{1}, yw]^2)/
      12 + (Pi^2*G[{1}, yv^(-1)]*G[{0, 1}, yu^(-1)])/6 + 
     (G[{0}, yu^(-1)]^2*G[{1}, yv^(-1)]*G[{0, 1}, yu^(-1)])/2 + 
     G[{0}, yu^(-1)]*G[{0}, yv^(-1)]*G[{1}, yv^(-1)]*G[{0, 1}, yu^(-1)] + 
     (G[{0}, yv^(-1)]^2*G[{1}, yv^(-1)]*G[{0, 1}, yu^(-1)])/2 - 
     G[{0}, yu^(-1)]*G[{0}, yw]*G[{1}, yv^(-1)]*G[{0, 1}, yu^(-1)] - 
     G[{0}, yv^(-1)]*G[{0}, yw]*G[{1}, yv^(-1)]*G[{0, 1}, yu^(-1)] + 
     (G[{0}, yw]^2*G[{1}, yv^(-1)]*G[{0, 1}, yu^(-1)])/2 - 
     (G[{0}, yu^(-1)]*G[{1}, yv^(-1)]^2*G[{0, 1}, yu^(-1)])/2 - 
     (G[{0}, yv^(-1)]*G[{1}, yv^(-1)]^2*G[{0, 1}, yu^(-1)])/2 + 
     (G[{0}, yw]*G[{1}, yv^(-1)]^2*G[{0, 1}, yu^(-1)])/2 - 
     (Pi^2*G[{1}, yw]*G[{0, 1}, yu^(-1)])/6 - 
     (G[{0}, yu^(-1)]^2*G[{1}, yw]*G[{0, 1}, yu^(-1)])/2 - 
     G[{0}, yu^(-1)]*G[{0}, yv^(-1)]*G[{1}, yw]*G[{0, 1}, yu^(-1)] - 
     (G[{0}, yv^(-1)]^2*G[{1}, yw]*G[{0, 1}, yu^(-1)])/2 + 
     G[{0}, yu^(-1)]*G[{0}, yw]*G[{1}, yw]*G[{0, 1}, yu^(-1)] + 
     G[{0}, yv^(-1)]*G[{0}, yw]*G[{1}, yw]*G[{0, 1}, yu^(-1)] - 
     (G[{0}, yw]^2*G[{1}, yw]*G[{0, 1}, yu^(-1)])/2 + 
     G[{0}, yu^(-1)]*G[{1}, yv^(-1)]*G[{1}, yw]*G[{0, 1}, yu^(-1)] + 
     G[{0}, yv^(-1)]*G[{1}, yv^(-1)]*G[{1}, yw]*G[{0, 1}, yu^(-1)] - 
     G[{0}, yw]*G[{1}, yv^(-1)]*G[{1}, yw]*G[{0, 1}, yu^(-1)] - 
     (G[{0}, yu^(-1)]*G[{1}, yw]^2*G[{0, 1}, yu^(-1)])/2 - 
     (G[{0}, yv^(-1)]*G[{1}, yw]^2*G[{0, 1}, yu^(-1)])/2 + 
     (G[{0}, yw]*G[{1}, yw]^2*G[{0, 1}, yu^(-1)])/2 - 
     (G[{0}, yu^(-1)]*G[{0, 1}, yu^(-1)]^2)/2 - 
     (G[{0}, yv^(-1)]*G[{0, 1}, yu^(-1)]^2)/2 + 
     (G[{0}, yw]*G[{0, 1}, yu^(-1)]^2)/2 + 
     (G[{1}, yv^(-1)]*G[{0, 1}, yu^(-1)]^2)/2 - 
     (G[{1}, yw]*G[{0, 1}, yu^(-1)]^2)/2 + 
     (Pi^2*G[{1}, yv^(-1)]*G[{0, 1}, yv^(-1)])/3 + 
     (G[{0}, yu^(-1)]^2*G[{1}, yv^(-1)]*G[{0, 1}, yv^(-1)])/2 + 
     G[{0}, yu^(-1)]*G[{0}, yv^(-1)]*G[{1}, yv^(-1)]*G[{0, 1}, yv^(-1)] + 
     (G[{0}, yv^(-1)]^2*G[{1}, yv^(-1)]*G[{0, 1}, yv^(-1)])/2 - 
     G[{0}, yu^(-1)]*G[{0}, yw]*G[{1}, yv^(-1)]*G[{0, 1}, yv^(-1)] - 
     G[{0}, yv^(-1)]*G[{0}, yw]*G[{1}, yv^(-1)]*G[{0, 1}, yv^(-1)] + 
     (G[{0}, yw]^2*G[{1}, yv^(-1)]*G[{0, 1}, yv^(-1)])/2 - 
     (G[{0}, yu^(-1)]*G[{1}, yv^(-1)]^2*G[{0, 1}, yv^(-1)])/2 - 
     (G[{0}, yv^(-1)]*G[{1}, yv^(-1)]^2*G[{0, 1}, yv^(-1)])/2 + 
     (G[{0}, yw]*G[{1}, yv^(-1)]^2*G[{0, 1}, yv^(-1)])/2 - 
     (Pi^2*G[{1}, yw]*G[{0, 1}, yv^(-1)])/3 - 
     (G[{0}, yu^(-1)]^2*G[{1}, yw]*G[{0, 1}, yv^(-1)])/2 - 
     G[{0}, yu^(-1)]*G[{0}, yv^(-1)]*G[{1}, yw]*G[{0, 1}, yv^(-1)] - 
     (G[{0}, yv^(-1)]^2*G[{1}, yw]*G[{0, 1}, yv^(-1)])/2 + 
     G[{0}, yu^(-1)]*G[{0}, yw]*G[{1}, yw]*G[{0, 1}, yv^(-1)] + 
     G[{0}, yv^(-1)]*G[{0}, yw]*G[{1}, yw]*G[{0, 1}, yv^(-1)] - 
     (G[{0}, yw]^2*G[{1}, yw]*G[{0, 1}, yv^(-1)])/2 + 
     G[{0}, yu^(-1)]*G[{1}, yv^(-1)]*G[{1}, yw]*G[{0, 1}, yv^(-1)] + 
     G[{0}, yv^(-1)]*G[{1}, yv^(-1)]*G[{1}, yw]*G[{0, 1}, yv^(-1)] - 
     G[{0}, yw]*G[{1}, yv^(-1)]*G[{1}, yw]*G[{0, 1}, yv^(-1)] - 
     (G[{0}, yu^(-1)]*G[{1}, yw]^2*G[{0, 1}, yv^(-1)])/2 - 
     (G[{0}, yv^(-1)]*G[{1}, yw]^2*G[{0, 1}, yv^(-1)])/2 + 
     (G[{0}, yw]*G[{1}, yw]^2*G[{0, 1}, yv^(-1)])/2 + 
     (G[{1}, yv^(-1)]*G[{0, 1}, yv^(-1)]^2)/2 - 
     (G[{1}, yw]*G[{0, 1}, yv^(-1)]^2)/2 + 
     (Pi^2*G[{1}, yv^(-1)]*G[{0, 1}, yw])/3 + 
     (G[{0}, yu^(-1)]^2*G[{1}, yv^(-1)]*G[{0, 1}, yw])/2 + 
     G[{0}, yu^(-1)]*G[{0}, yv^(-1)]*G[{1}, yv^(-1)]*G[{0, 1}, yw] + 
     (G[{0}, yv^(-1)]^2*G[{1}, yv^(-1)]*G[{0, 1}, yw])/2 - 
     G[{0}, yu^(-1)]*G[{0}, yw]*G[{1}, yv^(-1)]*G[{0, 1}, yw] - 
     G[{0}, yv^(-1)]*G[{0}, yw]*G[{1}, yv^(-1)]*G[{0, 1}, yw] + 
     (G[{0}, yw]^2*G[{1}, yv^(-1)]*G[{0, 1}, yw])/2 - 
     G[{0}, yu^(-1)]*G[{1}, yv^(-1)]^2*G[{0, 1}, yw] - 
     G[{0}, yv^(-1)]*G[{1}, yv^(-1)]^2*G[{0, 1}, yw] + 
     G[{0}, yw]*G[{1}, yv^(-1)]^2*G[{0, 1}, yw] + 
     (G[{1}, yv^(-1)]^3*G[{0, 1}, yw])/2 - (Pi^2*G[{1}, yw]*G[{0, 1}, yw])/
      3 - (G[{0}, yu^(-1)]^2*G[{1}, yw]*G[{0, 1}, yw])/2 - 
     G[{0}, yu^(-1)]*G[{0}, yv^(-1)]*G[{1}, yw]*G[{0, 1}, yw] - 
     (G[{0}, yv^(-1)]^2*G[{1}, yw]*G[{0, 1}, yw])/2 + 
     G[{0}, yu^(-1)]*G[{0}, yw]*G[{1}, yw]*G[{0, 1}, yw] + 
     G[{0}, yv^(-1)]*G[{0}, yw]*G[{1}, yw]*G[{0, 1}, yw] - 
     (G[{0}, yw]^2*G[{1}, yw]*G[{0, 1}, yw])/2 + 
     G[{0}, yu^(-1)]*G[{1}, yv^(-1)]*G[{1}, yw]*G[{0, 1}, yw] + 
     G[{0}, yv^(-1)]*G[{1}, yv^(-1)]*G[{1}, yw]*G[{0, 1}, yw] - 
     G[{0}, yw]*G[{1}, yv^(-1)]*G[{1}, yw]*G[{0, 1}, yw] - 
     (G[{1}, yv^(-1)]^2*G[{1}, yw]*G[{0, 1}, yw])/2 - 
     (G[{0}, yu^(-1)]*G[{1}, yw]^2*G[{0, 1}, yw])/2 - 
     (G[{0}, yv^(-1)]*G[{1}, yw]^2*G[{0, 1}, yw])/2 + 
     (G[{0}, yw]*G[{1}, yw]^2*G[{0, 1}, yw])/2 - 
     (Pi^2*G[{yu}, yv^(-1)]*G[{0, 1}, yw])/3 - 
     (G[{0}, yu^(-1)]^2*G[{yu}, yv^(-1)]*G[{0, 1}, yw])/2 - 
     G[{0}, yu^(-1)]*G[{0}, yv^(-1)]*G[{yu}, yv^(-1)]*G[{0, 1}, yw] - 
     (G[{0}, yv^(-1)]^2*G[{yu}, yv^(-1)]*G[{0, 1}, yw])/2 + 
     G[{0}, yu^(-1)]*G[{0}, yw]*G[{yu}, yv^(-1)]*G[{0, 1}, yw] + 
     G[{0}, yv^(-1)]*G[{0}, yw]*G[{yu}, yv^(-1)]*G[{0, 1}, yw] - 
     (G[{0}, yw]^2*G[{yu}, yv^(-1)]*G[{0, 1}, yw])/2 + 
     (G[{1}, yv^(-1)]^2*G[{yu}, yv^(-1)]*G[{0, 1}, yw])/2 + 
     G[{0}, yu^(-1)]*G[{1}, yw]*G[{yu}, yv^(-1)]*G[{0, 1}, yw] + 
     G[{0}, yv^(-1)]*G[{1}, yw]*G[{yu}, yv^(-1)]*G[{0, 1}, yw] - 
     G[{0}, yw]*G[{1}, yw]*G[{yu}, yv^(-1)]*G[{0, 1}, yw] + 
     G[{1}, yw]^2*G[{yu}, yv^(-1)]*G[{0, 1}, yw] + 
     G[{0}, yu^(-1)]*G[{yu}, yv^(-1)]^2*G[{0, 1}, yw] + 
     G[{0}, yv^(-1)]*G[{yu}, yv^(-1)]^2*G[{0, 1}, yw] - 
     G[{0}, yw]*G[{yu}, yv^(-1)]^2*G[{0, 1}, yw] - 
     G[{1}, yw]*G[{yu}, yv^(-1)]^2*G[{0, 1}, yw] - 
     (2*G[{yu}, yv^(-1)]^3*G[{0, 1}, yw])/3 + G[{1}, yv^(-1)]*
      G[{0, 1}, yv^(-1)]*G[{0, 1}, yw] - G[{1}, yw]*G[{0, 1}, yv^(-1)]*
      G[{0, 1}, yw] - G[{yu}, yv^(-1)]*G[{0, 1}, yv^(-1)]*G[{0, 1}, yw] + 
     (Pi^2*G[{1}, yw]*G[{0, yu^(-1)}, yw])/3 + 
     (G[{0}, yu^(-1)]^2*G[{1}, yw]*G[{0, yu^(-1)}, yw])/2 + 
     G[{0}, yu^(-1)]*G[{0}, yv^(-1)]*G[{1}, yw]*G[{0, yu^(-1)}, yw] + 
     (G[{0}, yv^(-1)]^2*G[{1}, yw]*G[{0, yu^(-1)}, yw])/2 - 
     G[{0}, yu^(-1)]*G[{0}, yw]*G[{1}, yw]*G[{0, yu^(-1)}, yw] - 
     G[{0}, yv^(-1)]*G[{0}, yw]*G[{1}, yw]*G[{0, yu^(-1)}, yw] + 
     (G[{0}, yw]^2*G[{1}, yw]*G[{0, yu^(-1)}, yw])/2 - 
     2*G[{0}, yu^(-1)]*G[{1}, yv^(-1)]*G[{1}, yw]*G[{0, yu^(-1)}, yw] - 
     2*G[{0}, yv^(-1)]*G[{1}, yv^(-1)]*G[{1}, yw]*G[{0, yu^(-1)}, yw] + 
     2*G[{0}, yw]*G[{1}, yv^(-1)]*G[{1}, yw]*G[{0, yu^(-1)}, yw] + 
     (3*G[{1}, yv^(-1)]^2*G[{1}, yw]*G[{0, yu^(-1)}, yw])/2 + 
     (G[{0}, yu^(-1)]*G[{1}, yw]^2*G[{0, yu^(-1)}, yw])/2 + 
     (G[{0}, yv^(-1)]*G[{1}, yw]^2*G[{0, yu^(-1)}, yw])/2 - 
     (G[{0}, yw]*G[{1}, yw]^2*G[{0, yu^(-1)}, yw])/2 - 
     G[{1}, yv^(-1)]*G[{1}, yw]^2*G[{0, yu^(-1)}, yw] + 
     G[{1}, yw]*G[{0, 1}, yv^(-1)]*G[{0, yu^(-1)}, yw] - 
     (Pi^2*G[{1}, yv^(-1)]*G[{0, yu}, yv^(-1)])/3 - 
     (G[{0}, yu^(-1)]^2*G[{1}, yv^(-1)]*G[{0, yu}, yv^(-1)])/2 - 
     G[{0}, yu^(-1)]*G[{0}, yv^(-1)]*G[{1}, yv^(-1)]*G[{0, yu}, yv^(-1)] - 
     (G[{0}, yv^(-1)]^2*G[{1}, yv^(-1)]*G[{0, yu}, yv^(-1)])/2 + 
     G[{0}, yu^(-1)]*G[{0}, yw]*G[{1}, yv^(-1)]*G[{0, yu}, yv^(-1)] + 
     G[{0}, yv^(-1)]*G[{0}, yw]*G[{1}, yv^(-1)]*G[{0, yu}, yv^(-1)] - 
     (G[{0}, yw]^2*G[{1}, yv^(-1)]*G[{0, yu}, yv^(-1)])/2 + 
     (G[{0}, yu^(-1)]*G[{1}, yv^(-1)]^2*G[{0, yu}, yv^(-1)])/2 + 
     (G[{0}, yv^(-1)]*G[{1}, yv^(-1)]^2*G[{0, yu}, yv^(-1)])/2 - 
     (G[{0}, yw]*G[{1}, yv^(-1)]^2*G[{0, yu}, yv^(-1)])/2 + 
     (Pi^2*G[{1}, yw]*G[{0, yu}, yv^(-1)])/3 + 
     (G[{0}, yu^(-1)]^2*G[{1}, yw]*G[{0, yu}, yv^(-1)])/2 + 
     G[{0}, yu^(-1)]*G[{0}, yv^(-1)]*G[{1}, yw]*G[{0, yu}, yv^(-1)] + 
     (G[{0}, yv^(-1)]^2*G[{1}, yw]*G[{0, yu}, yv^(-1)])/2 - 
     G[{0}, yu^(-1)]*G[{0}, yw]*G[{1}, yw]*G[{0, yu}, yv^(-1)] - 
     G[{0}, yv^(-1)]*G[{0}, yw]*G[{1}, yw]*G[{0, yu}, yv^(-1)] + 
     (G[{0}, yw]^2*G[{1}, yw]*G[{0, yu}, yv^(-1)])/2 - 
     G[{0}, yu^(-1)]*G[{1}, yv^(-1)]*G[{1}, yw]*G[{0, yu}, yv^(-1)] - 
     G[{0}, yv^(-1)]*G[{1}, yv^(-1)]*G[{1}, yw]*G[{0, yu}, yv^(-1)] + 
     G[{0}, yw]*G[{1}, yv^(-1)]*G[{1}, yw]*G[{0, yu}, yv^(-1)] + 
     (G[{0}, yu^(-1)]*G[{1}, yw]^2*G[{0, yu}, yv^(-1)])/2 + 
     (G[{0}, yv^(-1)]*G[{1}, yw]^2*G[{0, yu}, yv^(-1)])/2 - 
     (G[{0}, yw]*G[{1}, yw]^2*G[{0, yu}, yv^(-1)])/2 - 
     G[{1}, yv^(-1)]*G[{0, 1}, yv^(-1)]*G[{0, yu}, yv^(-1)] + 
     G[{1}, yw]*G[{0, 1}, yv^(-1)]*G[{0, yu}, yv^(-1)] - 
     G[{1}, yv^(-1)]*G[{0, 1}, yw]*G[{0, yu}, yv^(-1)] + 
     G[{1}, yw]*G[{0, 1}, yw]*G[{0, yu}, yv^(-1)] + 
     G[{yu}, yv^(-1)]*G[{0, 1}, yw]*G[{0, yu}, yv^(-1)] - 
     G[{1}, yw]*G[{0, yu^(-1)}, yw]*G[{0, yu}, yv^(-1)] + 
     (G[{1}, yv^(-1)]*G[{0, yu}, yv^(-1)]^2)/2 - 
     (G[{1}, yw]*G[{0, yu}, yv^(-1)]^2)/2 + 
     (Pi^2*G[{1}, yu^(-1)]*G[{0, yv^(-1)}, yw])/6 + 
     (G[{0}, yu^(-1)]^2*G[{1}, yu^(-1)]*G[{0, yv^(-1)}, yw])/2 + 
     G[{0}, yu^(-1)]*G[{0}, yv^(-1)]*G[{1}, yu^(-1)]*G[{0, yv^(-1)}, yw] + 
     (G[{0}, yv^(-1)]^2*G[{1}, yu^(-1)]*G[{0, yv^(-1)}, yw])/2 - 
     G[{0}, yu^(-1)]*G[{0}, yw]*G[{1}, yu^(-1)]*G[{0, yv^(-1)}, yw] - 
     G[{0}, yv^(-1)]*G[{0}, yw]*G[{1}, yu^(-1)]*G[{0, yv^(-1)}, yw] + 
     (G[{0}, yw]^2*G[{1}, yu^(-1)]*G[{0, yv^(-1)}, yw])/2 - 
     (3*G[{0}, yu^(-1)]*G[{1}, yu^(-1)]^2*G[{0, yv^(-1)}, yw])/2 - 
     (3*G[{0}, yv^(-1)]*G[{1}, yu^(-1)]^2*G[{0, yv^(-1)}, yw])/2 + 
     (3*G[{0}, yw]*G[{1}, yu^(-1)]^2*G[{0, yv^(-1)}, yw])/2 + 
     G[{1}, yu^(-1)]^3*G[{0, yv^(-1)}, yw] - 
     (Pi^2*G[{1}, yv^(-1)]*G[{0, yv^(-1)}, yw])/6 - 
     (G[{0}, yu^(-1)]^2*G[{1}, yv^(-1)]*G[{0, yv^(-1)}, yw])/2 - 
     G[{0}, yu^(-1)]*G[{0}, yv^(-1)]*G[{1}, yv^(-1)]*G[{0, yv^(-1)}, yw] - 
     (G[{0}, yv^(-1)]^2*G[{1}, yv^(-1)]*G[{0, yv^(-1)}, yw])/2 + 
     G[{0}, yu^(-1)]*G[{0}, yw]*G[{1}, yv^(-1)]*G[{0, yv^(-1)}, yw] + 
     G[{0}, yv^(-1)]*G[{0}, yw]*G[{1}, yv^(-1)]*G[{0, yv^(-1)}, yw] - 
     (G[{0}, yw]^2*G[{1}, yv^(-1)]*G[{0, yv^(-1)}, yw])/2 + 
     G[{0}, yu^(-1)]*G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*G[{0, yv^(-1)}, yw] + 
     G[{0}, yv^(-1)]*G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*G[{0, yv^(-1)}, yw] - 
     G[{0}, yw]*G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*G[{0, yv^(-1)}, yw] + 
     G[{0}, yu^(-1)]*G[{1}, yv^(-1)]^2*G[{0, yv^(-1)}, yw] + 
     G[{0}, yv^(-1)]*G[{1}, yv^(-1)]^2*G[{0, yv^(-1)}, yw] - 
     G[{0}, yw]*G[{1}, yv^(-1)]^2*G[{0, yv^(-1)}, yw] - 
     G[{1}, yu^(-1)]*G[{1}, yv^(-1)]^2*G[{0, yv^(-1)}, yw] - 
     (G[{1}, yv^(-1)]^3*G[{0, yv^(-1)}, yw])/2 + 
     (Pi^2*G[{1}, yw]*G[{0, yv^(-1)}, yw])/6 + 
     (G[{0}, yu^(-1)]^2*G[{1}, yw]*G[{0, yv^(-1)}, yw])/2 + 
     G[{0}, yu^(-1)]*G[{0}, yv^(-1)]*G[{1}, yw]*G[{0, yv^(-1)}, yw] + 
     (G[{0}, yv^(-1)]^2*G[{1}, yw]*G[{0, yv^(-1)}, yw])/2 - 
     G[{0}, yu^(-1)]*G[{0}, yw]*G[{1}, yw]*G[{0, yv^(-1)}, yw] - 
     G[{0}, yv^(-1)]*G[{0}, yw]*G[{1}, yw]*G[{0, yv^(-1)}, yw] + 
     (G[{0}, yw]^2*G[{1}, yw]*G[{0, yv^(-1)}, yw])/2 - 
     G[{0}, yu^(-1)]*G[{1}, yu^(-1)]*G[{1}, yw]*G[{0, yv^(-1)}, yw] - 
     G[{0}, yv^(-1)]*G[{1}, yu^(-1)]*G[{1}, yw]*G[{0, yv^(-1)}, yw] + 
     G[{0}, yw]*G[{1}, yu^(-1)]*G[{1}, yw]*G[{0, yv^(-1)}, yw] - 
     G[{0}, yu^(-1)]*G[{1}, yv^(-1)]*G[{1}, yw]*G[{0, yv^(-1)}, yw] - 
     G[{0}, yv^(-1)]*G[{1}, yv^(-1)]*G[{1}, yw]*G[{0, yv^(-1)}, yw] + 
     G[{0}, yw]*G[{1}, yv^(-1)]*G[{1}, yw]*G[{0, yv^(-1)}, yw] + 
     2*G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*G[{1}, yw]*G[{0, yv^(-1)}, yw] + 
     (G[{1}, yv^(-1)]^2*G[{1}, yw]*G[{0, yv^(-1)}, yw])/2 + 
     (G[{0}, yu^(-1)]*G[{1}, yw]^2*G[{0, yv^(-1)}, yw])/2 + 
     (G[{0}, yv^(-1)]*G[{1}, yw]^2*G[{0, yv^(-1)}, yw])/2 - 
     (G[{0}, yw]*G[{1}, yw]^2*G[{0, yv^(-1)}, yw])/2 - 
     G[{1}, yu^(-1)]*G[{1}, yw]^2*G[{0, yv^(-1)}, yw] + 
     G[{0}, yu^(-1)]*G[{0, 1}, yu^(-1)]*G[{0, yv^(-1)}, yw] + 
     G[{0}, yv^(-1)]*G[{0, 1}, yu^(-1)]*G[{0, yv^(-1)}, yw] - 
     G[{0}, yw]*G[{0, 1}, yu^(-1)]*G[{0, yv^(-1)}, yw] - 
     G[{1}, yu^(-1)]*G[{0, 1}, yu^(-1)]*G[{0, yv^(-1)}, yw] - 
     G[{1}, yv^(-1)]*G[{0, 1}, yu^(-1)]*G[{0, yv^(-1)}, yw] + 
     G[{1}, yw]*G[{0, 1}, yu^(-1)]*G[{0, yv^(-1)}, yw] + 
     G[{0}, yu^(-1)]*G[{0, 1}, yw]*G[{0, yv^(-1)}, yw] + 
     G[{0}, yv^(-1)]*G[{0, 1}, yw]*G[{0, yv^(-1)}, yw] - 
     G[{0}, yw]*G[{0, 1}, yw]*G[{0, yv^(-1)}, yw] - 
     2*G[{1}, yv^(-1)]*G[{0, 1}, yw]*G[{0, yv^(-1)}, yw] + 
     G[{1}, yw]*G[{0, 1}, yw]*G[{0, yv^(-1)}, yw] - 
     G[{0}, yu^(-1)]*G[{0, yu^(-1)}, yw]*G[{0, yv^(-1)}, yw] - 
     G[{0}, yv^(-1)]*G[{0, yu^(-1)}, yw]*G[{0, yv^(-1)}, yw] + 
     G[{0}, yw]*G[{0, yu^(-1)}, yw]*G[{0, yv^(-1)}, yw] + 
     2*G[{1}, yv^(-1)]*G[{0, yu^(-1)}, yw]*G[{0, yv^(-1)}, yw] - 
     G[{1}, yw]*G[{0, yu^(-1)}, yw]*G[{0, yv^(-1)}, yw] - 
     (G[{0}, yu^(-1)]*G[{0, yv^(-1)}, yw]^2)/2 - 
     (G[{0}, yv^(-1)]*G[{0, yv^(-1)}, yw]^2)/2 + 
     (G[{0}, yw]*G[{0, yv^(-1)}, yw]^2)/2 + G[{1}, yv^(-1)]*
      G[{0, yv^(-1)}, yw]^2 - (G[{1}, yw]*G[{0, yv^(-1)}, yw]^2)/2 - 
     (Pi^2*G[{1}, yu^(-1)]*G[{0, 1/(yu*yv)}, yw])/6 - 
     (G[{0}, yu^(-1)]^2*G[{1}, yu^(-1)]*G[{0, 1/(yu*yv)}, yw])/2 - 
     G[{0}, yu^(-1)]*G[{0}, yv^(-1)]*G[{1}, yu^(-1)]*G[{0, 1/(yu*yv)}, yw] - 
     (G[{0}, yv^(-1)]^2*G[{1}, yu^(-1)]*G[{0, 1/(yu*yv)}, yw])/2 + 
     G[{0}, yu^(-1)]*G[{0}, yw]*G[{1}, yu^(-1)]*G[{0, 1/(yu*yv)}, yw] + 
     G[{0}, yv^(-1)]*G[{0}, yw]*G[{1}, yu^(-1)]*G[{0, 1/(yu*yv)}, yw] - 
     (G[{0}, yw]^2*G[{1}, yu^(-1)]*G[{0, 1/(yu*yv)}, yw])/2 + 
     (3*G[{0}, yu^(-1)]*G[{1}, yu^(-1)]^2*G[{0, 1/(yu*yv)}, yw])/2 + 
     (3*G[{0}, yv^(-1)]*G[{1}, yu^(-1)]^2*G[{0, 1/(yu*yv)}, yw])/2 - 
     (3*G[{0}, yw]*G[{1}, yu^(-1)]^2*G[{0, 1/(yu*yv)}, yw])/2 - 
     G[{1}, yu^(-1)]^3*G[{0, 1/(yu*yv)}, yw] - 
     (Pi^2*G[{1}, yv^(-1)]*G[{0, 1/(yu*yv)}, yw])/6 - 
     G[{0}, yu^(-1)]*G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*G[{0, 1/(yu*yv)}, yw] - 
     G[{0}, yv^(-1)]*G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*G[{0, 1/(yu*yv)}, yw] + 
     G[{0}, yw]*G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*G[{0, 1/(yu*yv)}, yw] + 
     G[{1}, yu^(-1)]*G[{1}, yv^(-1)]^2*G[{0, 1/(yu*yv)}, yw] - 
     (Pi^2*G[{1}, yw]*G[{0, 1/(yu*yv)}, yw])/6 - 
     (G[{0}, yu^(-1)]^2*G[{1}, yw]*G[{0, 1/(yu*yv)}, yw])/2 - 
     G[{0}, yu^(-1)]*G[{0}, yv^(-1)]*G[{1}, yw]*G[{0, 1/(yu*yv)}, yw] - 
     (G[{0}, yv^(-1)]^2*G[{1}, yw]*G[{0, 1/(yu*yv)}, yw])/2 + 
     G[{0}, yu^(-1)]*G[{0}, yw]*G[{1}, yw]*G[{0, 1/(yu*yv)}, yw] + 
     G[{0}, yv^(-1)]*G[{0}, yw]*G[{1}, yw]*G[{0, 1/(yu*yv)}, yw] - 
     (G[{0}, yw]^2*G[{1}, yw]*G[{0, 1/(yu*yv)}, yw])/2 + 
     G[{0}, yu^(-1)]*G[{1}, yu^(-1)]*G[{1}, yw]*G[{0, 1/(yu*yv)}, yw] + 
     G[{0}, yv^(-1)]*G[{1}, yu^(-1)]*G[{1}, yw]*G[{0, 1/(yu*yv)}, yw] - 
     G[{0}, yw]*G[{1}, yu^(-1)]*G[{1}, yw]*G[{0, 1/(yu*yv)}, yw] + 
     2*G[{0}, yu^(-1)]*G[{1}, yv^(-1)]*G[{1}, yw]*G[{0, 1/(yu*yv)}, yw] + 
     2*G[{0}, yv^(-1)]*G[{1}, yv^(-1)]*G[{1}, yw]*G[{0, 1/(yu*yv)}, yw] - 
     2*G[{0}, yw]*G[{1}, yv^(-1)]*G[{1}, yw]*G[{0, 1/(yu*yv)}, yw] - 
     2*G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*G[{1}, yw]*G[{0, 1/(yu*yv)}, yw] - 
     (3*G[{1}, yv^(-1)]^2*G[{1}, yw]*G[{0, 1/(yu*yv)}, yw])/2 - 
     (G[{0}, yu^(-1)]*G[{1}, yw]^2*G[{0, 1/(yu*yv)}, yw])/2 - 
     (G[{0}, yv^(-1)]*G[{1}, yw]^2*G[{0, 1/(yu*yv)}, yw])/2 + 
     (G[{0}, yw]*G[{1}, yw]^2*G[{0, 1/(yu*yv)}, yw])/2 + 
     G[{1}, yu^(-1)]*G[{1}, yw]^2*G[{0, 1/(yu*yv)}, yw] + 
     G[{1}, yv^(-1)]*G[{1}, yw]^2*G[{0, 1/(yu*yv)}, yw] + 
     (Pi^2*G[{yu}, yv^(-1)]*G[{0, 1/(yu*yv)}, yw])/3 + 
     (G[{0}, yu^(-1)]^2*G[{yu}, yv^(-1)]*G[{0, 1/(yu*yv)}, yw])/2 + 
     G[{0}, yu^(-1)]*G[{0}, yv^(-1)]*G[{yu}, yv^(-1)]*G[{0, 1/(yu*yv)}, yw] + 
     (G[{0}, yv^(-1)]^2*G[{yu}, yv^(-1)]*G[{0, 1/(yu*yv)}, yw])/2 - 
     G[{0}, yu^(-1)]*G[{0}, yw]*G[{yu}, yv^(-1)]*G[{0, 1/(yu*yv)}, yw] - 
     G[{0}, yv^(-1)]*G[{0}, yw]*G[{yu}, yv^(-1)]*G[{0, 1/(yu*yv)}, yw] + 
     (G[{0}, yw]^2*G[{yu}, yv^(-1)]*G[{0, 1/(yu*yv)}, yw])/2 - 
     (G[{1}, yv^(-1)]^2*G[{yu}, yv^(-1)]*G[{0, 1/(yu*yv)}, yw])/2 - 
     G[{0}, yu^(-1)]*G[{1}, yw]*G[{yu}, yv^(-1)]*G[{0, 1/(yu*yv)}, yw] - 
     G[{0}, yv^(-1)]*G[{1}, yw]*G[{yu}, yv^(-1)]*G[{0, 1/(yu*yv)}, yw] + 
     G[{0}, yw]*G[{1}, yw]*G[{yu}, yv^(-1)]*G[{0, 1/(yu*yv)}, yw] - 
     G[{1}, yw]^2*G[{yu}, yv^(-1)]*G[{0, 1/(yu*yv)}, yw] - 
     G[{0}, yu^(-1)]*G[{yu}, yv^(-1)]^2*G[{0, 1/(yu*yv)}, yw] - 
     G[{0}, yv^(-1)]*G[{yu}, yv^(-1)]^2*G[{0, 1/(yu*yv)}, yw] + 
     G[{0}, yw]*G[{yu}, yv^(-1)]^2*G[{0, 1/(yu*yv)}, yw] + 
     G[{1}, yw]*G[{yu}, yv^(-1)]^2*G[{0, 1/(yu*yv)}, yw] + 
     (2*G[{yu}, yv^(-1)]^3*G[{0, 1/(yu*yv)}, yw])/3 - 
     G[{0}, yu^(-1)]*G[{0, 1}, yu^(-1)]*G[{0, 1/(yu*yv)}, yw] - 
     G[{0}, yv^(-1)]*G[{0, 1}, yu^(-1)]*G[{0, 1/(yu*yv)}, yw] + 
     G[{0}, yw]*G[{0, 1}, yu^(-1)]*G[{0, 1/(yu*yv)}, yw] + 
     G[{1}, yu^(-1)]*G[{0, 1}, yu^(-1)]*G[{0, 1/(yu*yv)}, yw] + 
     G[{1}, yv^(-1)]*G[{0, 1}, yu^(-1)]*G[{0, 1/(yu*yv)}, yw] - 
     G[{1}, yw]*G[{0, 1}, yu^(-1)]*G[{0, 1/(yu*yv)}, yw] - 
     G[{1}, yv^(-1)]*G[{0, 1}, yv^(-1)]*G[{0, 1/(yu*yv)}, yw] + 
     G[{yu}, yv^(-1)]*G[{0, 1}, yv^(-1)]*G[{0, 1/(yu*yv)}, yw] - 
     G[{0}, yu^(-1)]*G[{0, 1}, yw]*G[{0, 1/(yu*yv)}, yw] - 
     G[{0}, yv^(-1)]*G[{0, 1}, yw]*G[{0, 1/(yu*yv)}, yw] + 
     G[{0}, yw]*G[{0, 1}, yw]*G[{0, 1/(yu*yv)}, yw] + 
     2*G[{1}, yv^(-1)]*G[{0, 1}, yw]*G[{0, 1/(yu*yv)}, yw] - 
     G[{1}, yw]*G[{0, 1}, yw]*G[{0, 1/(yu*yv)}, yw] + 
     G[{0}, yu^(-1)]*G[{0, yu^(-1)}, yw]*G[{0, 1/(yu*yv)}, yw] + 
     G[{0}, yv^(-1)]*G[{0, yu^(-1)}, yw]*G[{0, 1/(yu*yv)}, yw] - 
     G[{0}, yw]*G[{0, yu^(-1)}, yw]*G[{0, 1/(yu*yv)}, yw] - 
     2*G[{1}, yv^(-1)]*G[{0, yu^(-1)}, yw]*G[{0, 1/(yu*yv)}, yw] + 
     G[{1}, yw]*G[{0, yu^(-1)}, yw]*G[{0, 1/(yu*yv)}, yw] + 
     G[{1}, yv^(-1)]*G[{0, yu}, yv^(-1)]*G[{0, 1/(yu*yv)}, yw] - 
     G[{yu}, yv^(-1)]*G[{0, yu}, yv^(-1)]*G[{0, 1/(yu*yv)}, yw] + 
     G[{0}, yu^(-1)]*G[{0, yv^(-1)}, yw]*G[{0, 1/(yu*yv)}, yw] + 
     G[{0}, yv^(-1)]*G[{0, yv^(-1)}, yw]*G[{0, 1/(yu*yv)}, yw] - 
     G[{0}, yw]*G[{0, yv^(-1)}, yw]*G[{0, 1/(yu*yv)}, yw] - 
     2*G[{1}, yv^(-1)]*G[{0, yv^(-1)}, yw]*G[{0, 1/(yu*yv)}, yw] + 
     G[{1}, yw]*G[{0, yv^(-1)}, yw]*G[{0, 1/(yu*yv)}, yw] - 
     (G[{0}, yu^(-1)]*G[{0, 1/(yu*yv)}, yw]^2)/2 - 
     (G[{0}, yv^(-1)]*G[{0, 1/(yu*yv)}, yw]^2)/2 + 
     (G[{0}, yw]*G[{0, 1/(yu*yv)}, yw]^2)/2 + G[{1}, yv^(-1)]*
      G[{0, 1/(yu*yv)}, yw]^2 - (G[{1}, yw]*G[{0, 1/(yu*yv)}, yw]^2)/2 - 
     G[{1}, yv^(-1)]*G[{0, 1}, yw]*G[{1, yu}, yv^(-1)] - 
     G[{1}, yw]*G[{0, 1}, yw]*G[{1, yu}, yv^(-1)] - 
     G[{yu}, yv^(-1)]*G[{0, 1}, yw]*G[{1, yu}, yv^(-1)] + 
     G[{1}, yw]*G[{0, yu^(-1)}, yw]*G[{1, yu}, yv^(-1)] - 
     G[{0}, yu^(-1)]*G[{0, yv^(-1)}, yw]*G[{1, yu}, yv^(-1)] - 
     G[{0}, yv^(-1)]*G[{0, yv^(-1)}, yw]*G[{1, yu}, yv^(-1)] + 
     G[{0}, yw]*G[{0, yv^(-1)}, yw]*G[{1, yu}, yv^(-1)] - 
     G[{1}, yw]*G[{0, yv^(-1)}, yw]*G[{1, yu}, yv^(-1)] + 
     G[{0}, yu^(-1)]*G[{0, 1/(yu*yv)}, yw]*G[{1, yu}, yv^(-1)] + 
     G[{0}, yv^(-1)]*G[{0, 1/(yu*yv)}, yw]*G[{1, yu}, yv^(-1)] - 
     G[{0}, yw]*G[{0, 1/(yu*yv)}, yw]*G[{1, yu}, yv^(-1)] + 
     G[{1}, yv^(-1)]*G[{0, 1/(yu*yv)}, yw]*G[{1, yu}, yv^(-1)] + 
     G[{1}, yw]*G[{0, 1/(yu*yv)}, yw]*G[{1, yu}, yv^(-1)] + 
     G[{yu}, yv^(-1)]*G[{0, 1/(yu*yv)}, yw]*G[{1, yu}, yv^(-1)] + 
     (Pi^2*G[{0, 0, 1}, yu^(-1)])/6 + 
     (G[{0}, yu^(-1)]^2*G[{0, 0, 1}, yu^(-1)])/2 + 
     G[{0}, yu^(-1)]*G[{0}, yv^(-1)]*G[{0, 0, 1}, yu^(-1)] + 
     (G[{0}, yv^(-1)]^2*G[{0, 0, 1}, yu^(-1)])/2 - G[{0}, yu^(-1)]*G[{0}, yw]*
      G[{0, 0, 1}, yu^(-1)] - G[{0}, yv^(-1)]*G[{0}, yw]*
      G[{0, 0, 1}, yu^(-1)] + (G[{0}, yw]^2*G[{0, 0, 1}, yu^(-1)])/2 - 
     G[{0}, yu^(-1)]*G[{1}, yv^(-1)]*G[{0, 0, 1}, yu^(-1)] - 
     G[{0}, yv^(-1)]*G[{1}, yv^(-1)]*G[{0, 0, 1}, yu^(-1)] + 
     G[{0}, yw]*G[{1}, yv^(-1)]*G[{0, 0, 1}, yu^(-1)] + 
     G[{0}, yu^(-1)]*G[{1}, yw]*G[{0, 0, 1}, yu^(-1)] + 
     G[{0}, yv^(-1)]*G[{1}, yw]*G[{0, 0, 1}, yu^(-1)] - 
     G[{0}, yw]*G[{1}, yw]*G[{0, 0, 1}, yu^(-1)] + 
     G[{0, 1}, yu^(-1)]*G[{0, 0, 1}, yu^(-1)] - G[{0, yv^(-1)}, yw]*
      G[{0, 0, 1}, yu^(-1)] + G[{0, 1/(yu*yv)}, yw]*G[{0, 0, 1}, yu^(-1)] + 
     (Pi^2*G[{0, 0, 1}, yw])/3 + (G[{0}, yu^(-1)]^2*G[{0, 0, 1}, yw])/2 + 
     G[{0}, yu^(-1)]*G[{0}, yv^(-1)]*G[{0, 0, 1}, yw] + 
     (G[{0}, yv^(-1)]^2*G[{0, 0, 1}, yw])/2 - G[{0}, yu^(-1)]*G[{0}, yw]*
      G[{0, 0, 1}, yw] - G[{0}, yv^(-1)]*G[{0}, yw]*G[{0, 0, 1}, yw] + 
     (G[{0}, yw]^2*G[{0, 0, 1}, yw])/2 + G[{0}, yu^(-1)]*G[{1}, yv^(-1)]*
      G[{0, 0, 1}, yw] + G[{0}, yv^(-1)]*G[{1}, yv^(-1)]*G[{0, 0, 1}, yw] - 
     G[{0}, yw]*G[{1}, yv^(-1)]*G[{0, 0, 1}, yw] - 
     (3*G[{1}, yv^(-1)]^2*G[{0, 0, 1}, yw])/2 - G[{0}, yu^(-1)]*G[{1}, yw]*
      G[{0, 0, 1}, yw] - G[{0}, yv^(-1)]*G[{1}, yw]*G[{0, 0, 1}, yw] + 
     G[{0}, yw]*G[{1}, yw]*G[{0, 0, 1}, yw] + 2*G[{1}, yv^(-1)]*G[{1}, yw]*
      G[{0, 0, 1}, yw] - G[{1}, yw]^2*G[{0, 0, 1}, yw] - 
     3*G[{0}, yu^(-1)]*G[{yu}, yv^(-1)]*G[{0, 0, 1}, yw] - 
     3*G[{0}, yv^(-1)]*G[{yu}, yv^(-1)]*G[{0, 0, 1}, yw] + 
     3*G[{0}, yw]*G[{yu}, yv^(-1)]*G[{0, 0, 1}, yw] + 
     3*G[{yu}, yv^(-1)]^2*G[{0, 0, 1}, yw] + G[{0, 1}, yv^(-1)]*
      G[{0, 0, 1}, yw] - G[{0, yu}, yv^(-1)]*G[{0, 0, 1}, yw] + 
     G[{0, yv^(-1)}, yw]*G[{0, 0, 1}, yw] - G[{0, 1/(yu*yv)}, yw]*
      G[{0, 0, 1}, yw] + G[{1, yu}, yv^(-1)]*G[{0, 0, 1}, yw] - 
     (Pi^2*G[{0, 0, yu^(-1)}, yw])/3 - 
     (G[{0}, yu^(-1)]^2*G[{0, 0, yu^(-1)}, yw])/2 - 
     G[{0}, yu^(-1)]*G[{0}, yv^(-1)]*G[{0, 0, yu^(-1)}, yw] - 
     (G[{0}, yv^(-1)]^2*G[{0, 0, yu^(-1)}, yw])/2 + 
     G[{0}, yu^(-1)]*G[{0}, yw]*G[{0, 0, yu^(-1)}, yw] + 
     G[{0}, yv^(-1)]*G[{0}, yw]*G[{0, 0, yu^(-1)}, yw] - 
     (G[{0}, yw]^2*G[{0, 0, yu^(-1)}, yw])/2 + 2*G[{0}, yu^(-1)]*
      G[{1}, yv^(-1)]*G[{0, 0, yu^(-1)}, yw] + 2*G[{0}, yv^(-1)]*
      G[{1}, yv^(-1)]*G[{0, 0, yu^(-1)}, yw] - 2*G[{0}, yw]*G[{1}, yv^(-1)]*
      G[{0, 0, yu^(-1)}, yw] - (3*G[{1}, yv^(-1)]^2*G[{0, 0, yu^(-1)}, yw])/
      2 + G[{0}, yu^(-1)]*G[{1}, yw]*G[{0, 0, yu^(-1)}, yw] + 
     G[{0}, yv^(-1)]*G[{1}, yw]*G[{0, 0, yu^(-1)}, yw] - 
     G[{0}, yw]*G[{1}, yw]*G[{0, 0, yu^(-1)}, yw] - 
     2*G[{1}, yv^(-1)]*G[{1}, yw]*G[{0, 0, yu^(-1)}, yw] + 
     G[{1}, yw]^2*G[{0, 0, yu^(-1)}, yw] - G[{0, 1}, yv^(-1)]*
      G[{0, 0, yu^(-1)}, yw] + G[{0, yu}, yv^(-1)]*G[{0, 0, yu^(-1)}, yw] - 
     G[{0, yv^(-1)}, yw]*G[{0, 0, yu^(-1)}, yw] + G[{0, 1/(yu*yv)}, yw]*
      G[{0, 0, yu^(-1)}, yw] - G[{1, yu}, yv^(-1)]*G[{0, 0, yu^(-1)}, yw] - 
     (Pi^2*G[{0, 0, yv^(-1)}, yw])/6 - 
     (G[{0}, yu^(-1)]^2*G[{0, 0, yv^(-1)}, yw])/2 - 
     G[{0}, yu^(-1)]*G[{0}, yv^(-1)]*G[{0, 0, yv^(-1)}, yw] - 
     (G[{0}, yv^(-1)]^2*G[{0, 0, yv^(-1)}, yw])/2 + 
     G[{0}, yu^(-1)]*G[{0}, yw]*G[{0, 0, yv^(-1)}, yw] + 
     G[{0}, yv^(-1)]*G[{0}, yw]*G[{0, 0, yv^(-1)}, yw] - 
     (G[{0}, yw]^2*G[{0, 0, yv^(-1)}, yw])/2 + 3*G[{0}, yu^(-1)]*
      G[{1}, yu^(-1)]*G[{0, 0, yv^(-1)}, yw] + 3*G[{0}, yv^(-1)]*
      G[{1}, yu^(-1)]*G[{0, 0, yv^(-1)}, yw] - 3*G[{0}, yw]*G[{1}, yu^(-1)]*
      G[{0, 0, yv^(-1)}, yw] - 3*G[{1}, yu^(-1)]^2*G[{0, 0, yv^(-1)}, yw] - 
     G[{0}, yu^(-1)]*G[{1}, yv^(-1)]*G[{0, 0, yv^(-1)}, yw] - 
     G[{0}, yv^(-1)]*G[{1}, yv^(-1)]*G[{0, 0, yv^(-1)}, yw] + 
     G[{0}, yw]*G[{1}, yv^(-1)]*G[{0, 0, yv^(-1)}, yw] + 
     (3*G[{1}, yv^(-1)]^2*G[{0, 0, yv^(-1)}, yw])/2 + 
     G[{0}, yu^(-1)]*G[{1}, yw]*G[{0, 0, yv^(-1)}, yw] + 
     G[{0}, yv^(-1)]*G[{1}, yw]*G[{0, 0, yv^(-1)}, yw] - 
     G[{0}, yw]*G[{1}, yw]*G[{0, 0, yv^(-1)}, yw] - 
     2*G[{1}, yv^(-1)]*G[{1}, yw]*G[{0, 0, yv^(-1)}, yw] + 
     G[{1}, yw]^2*G[{0, 0, yv^(-1)}, yw] + G[{0, 1}, yu^(-1)]*
      G[{0, 0, yv^(-1)}, yw] - G[{0, yv^(-1)}, yw]*G[{0, 0, yv^(-1)}, yw] + 
     G[{0, 1/(yu*yv)}, yw]*G[{0, 0, yv^(-1)}, yw] - 
     G[{1, yu}, yv^(-1)]*G[{0, 0, yv^(-1)}, yw] + 
     (Pi^2*G[{0, 0, 1/(yu*yv)}, yw])/6 + 
     (G[{0}, yu^(-1)]^2*G[{0, 0, 1/(yu*yv)}, yw])/2 + 
     G[{0}, yu^(-1)]*G[{0}, yv^(-1)]*G[{0, 0, 1/(yu*yv)}, yw] + 
     (G[{0}, yv^(-1)]^2*G[{0, 0, 1/(yu*yv)}, yw])/2 - 
     G[{0}, yu^(-1)]*G[{0}, yw]*G[{0, 0, 1/(yu*yv)}, yw] - 
     G[{0}, yv^(-1)]*G[{0}, yw]*G[{0, 0, 1/(yu*yv)}, yw] + 
     (G[{0}, yw]^2*G[{0, 0, 1/(yu*yv)}, yw])/2 - 3*G[{0}, yu^(-1)]*
      G[{1}, yu^(-1)]*G[{0, 0, 1/(yu*yv)}, yw] - 3*G[{0}, yv^(-1)]*
      G[{1}, yu^(-1)]*G[{0, 0, 1/(yu*yv)}, yw] + 3*G[{0}, yw]*G[{1}, yu^(-1)]*
      G[{0, 0, 1/(yu*yv)}, yw] + 3*G[{1}, yu^(-1)]^2*
      G[{0, 0, 1/(yu*yv)}, yw] - 2*G[{0}, yu^(-1)]*G[{1}, yv^(-1)]*
      G[{0, 0, 1/(yu*yv)}, yw] - 2*G[{0}, yv^(-1)]*G[{1}, yv^(-1)]*
      G[{0, 0, 1/(yu*yv)}, yw] + 2*G[{0}, yw]*G[{1}, yv^(-1)]*
      G[{0, 0, 1/(yu*yv)}, yw] + (3*G[{1}, yv^(-1)]^2*
       G[{0, 0, 1/(yu*yv)}, yw])/2 - G[{0}, yu^(-1)]*G[{1}, yw]*
      G[{0, 0, 1/(yu*yv)}, yw] - G[{0}, yv^(-1)]*G[{1}, yw]*
      G[{0, 0, 1/(yu*yv)}, yw] + G[{0}, yw]*G[{1}, yw]*
      G[{0, 0, 1/(yu*yv)}, yw] + 2*G[{1}, yv^(-1)]*G[{1}, yw]*
      G[{0, 0, 1/(yu*yv)}, yw] - G[{1}, yw]^2*G[{0, 0, 1/(yu*yv)}, yw] + 
     3*G[{0}, yu^(-1)]*G[{yu}, yv^(-1)]*G[{0, 0, 1/(yu*yv)}, yw] + 
     3*G[{0}, yv^(-1)]*G[{yu}, yv^(-1)]*G[{0, 0, 1/(yu*yv)}, yw] - 
     3*G[{0}, yw]*G[{yu}, yv^(-1)]*G[{0, 0, 1/(yu*yv)}, yw] - 
     3*G[{yu}, yv^(-1)]^2*G[{0, 0, 1/(yu*yv)}, yw] - 
     G[{0, 1}, yu^(-1)]*G[{0, 0, 1/(yu*yv)}, yw] + 
     G[{0, yv^(-1)}, yw]*G[{0, 0, 1/(yu*yv)}, yw] - 
     G[{0, 1/(yu*yv)}, yw]*G[{0, 0, 1/(yu*yv)}, yw] + 
     G[{1, yu}, yv^(-1)]*G[{0, 0, 1/(yu*yv)}, yw] - 
     (Pi^2*G[{0, 1, 1}, yu^(-1)])/6 - 
     (G[{0}, yu^(-1)]^2*G[{0, 1, 1}, yu^(-1)])/2 - 
     G[{0}, yu^(-1)]*G[{0}, yv^(-1)]*G[{0, 1, 1}, yu^(-1)] - 
     (G[{0}, yv^(-1)]^2*G[{0, 1, 1}, yu^(-1)])/2 + G[{0}, yu^(-1)]*G[{0}, yw]*
      G[{0, 1, 1}, yu^(-1)] + G[{0}, yv^(-1)]*G[{0}, yw]*
      G[{0, 1, 1}, yu^(-1)] - (G[{0}, yw]^2*G[{0, 1, 1}, yu^(-1)])/2 - 
     G[{0}, yu^(-1)]*G[{1}, yv^(-1)]*G[{0, 1, 1}, yu^(-1)] - 
     G[{0}, yv^(-1)]*G[{1}, yv^(-1)]*G[{0, 1, 1}, yu^(-1)] + 
     G[{0}, yw]*G[{1}, yv^(-1)]*G[{0, 1, 1}, yu^(-1)] + 
     G[{1}, yv^(-1)]^2*G[{0, 1, 1}, yu^(-1)] + G[{0}, yu^(-1)]*G[{1}, yw]*
      G[{0, 1, 1}, yu^(-1)] + G[{0}, yv^(-1)]*G[{1}, yw]*
      G[{0, 1, 1}, yu^(-1)] - G[{0}, yw]*G[{1}, yw]*G[{0, 1, 1}, yu^(-1)] - 
     2*G[{1}, yv^(-1)]*G[{1}, yw]*G[{0, 1, 1}, yu^(-1)] + 
     G[{1}, yw]^2*G[{0, 1, 1}, yu^(-1)] + G[{0, 1}, yu^(-1)]*
      G[{0, 1, 1}, yu^(-1)] + G[{0, yv^(-1)}, yw]*G[{0, 1, 1}, yu^(-1)] - 
     G[{0, 1/(yu*yv)}, yw]*G[{0, 1, 1}, yu^(-1)] - 
     (2*Pi^2*G[{0, 1, 1}, yv^(-1)])/3 - G[{0}, yu^(-1)]^2*
      G[{0, 1, 1}, yv^(-1)] - 2*G[{0}, yu^(-1)]*G[{0}, yv^(-1)]*
      G[{0, 1, 1}, yv^(-1)] - G[{0}, yv^(-1)]^2*G[{0, 1, 1}, yv^(-1)] + 
     2*G[{0}, yu^(-1)]*G[{0}, yw]*G[{0, 1, 1}, yv^(-1)] + 
     2*G[{0}, yv^(-1)]*G[{0}, yw]*G[{0, 1, 1}, yv^(-1)] - 
     G[{0}, yw]^2*G[{0, 1, 1}, yv^(-1)] + G[{1}, yv^(-1)]^2*
      G[{0, 1, 1}, yv^(-1)] - 2*G[{1}, yv^(-1)]*G[{1}, yw]*
      G[{0, 1, 1}, yv^(-1)] + G[{1}, yw]^2*G[{0, 1, 1}, yv^(-1)] - 
     2*G[{0, 1}, yv^(-1)]*G[{0, 1, 1}, yv^(-1)] - 
     2*G[{0, 1}, yw]*G[{0, 1, 1}, yv^(-1)] + 2*G[{0, 1/(yu*yv)}, yw]*
      G[{0, 1, 1}, yv^(-1)] + (2*Pi^2*G[{0, 1, 1}, yw])/3 + 
     G[{0}, yu^(-1)]^2*G[{0, 1, 1}, yw] + 2*G[{0}, yu^(-1)]*G[{0}, yv^(-1)]*
      G[{0, 1, 1}, yw] + G[{0}, yv^(-1)]^2*G[{0, 1, 1}, yw] - 
     2*G[{0}, yu^(-1)]*G[{0}, yw]*G[{0, 1, 1}, yw] - 
     2*G[{0}, yv^(-1)]*G[{0}, yw]*G[{0, 1, 1}, yw] + 
     G[{0}, yw]^2*G[{0, 1, 1}, yw] - G[{0}, yu^(-1)]*G[{1}, yv^(-1)]*
      G[{0, 1, 1}, yw] - G[{0}, yv^(-1)]*G[{1}, yv^(-1)]*G[{0, 1, 1}, yw] + 
     G[{0}, yw]*G[{1}, yv^(-1)]*G[{0, 1, 1}, yw] + G[{1}, yv^(-1)]*G[{1}, yw]*
      G[{0, 1, 1}, yw] - G[{1}, yw]^2*G[{0, 1, 1}, yw] - 
     3*G[{0}, yu^(-1)]*G[{yu}, yv^(-1)]*G[{0, 1, 1}, yw] - 
     3*G[{0}, yv^(-1)]*G[{yu}, yv^(-1)]*G[{0, 1, 1}, yw] + 
     3*G[{0}, yw]*G[{yu}, yv^(-1)]*G[{0, 1, 1}, yw] - 
     G[{1}, yw]*G[{yu}, yv^(-1)]*G[{0, 1, 1}, yw] + 
     3*G[{yu}, yv^(-1)]^2*G[{0, 1, 1}, yw] + 2*G[{0, 1}, yv^(-1)]*
      G[{0, 1, 1}, yw] - 2*G[{0, yu}, yv^(-1)]*G[{0, 1, 1}, yw] - 
     G[{0, yv^(-1)}, yw]*G[{0, 1, 1}, yw] + G[{0, 1/(yu*yv)}, yw]*
      G[{0, 1, 1}, yw] + 2*G[{1, yu}, yv^(-1)]*G[{0, 1, 1}, yw] - 
     (Pi^2*G[{0, 1, yu^(-1)}, yw])/3 - 
     (G[{0}, yu^(-1)]^2*G[{0, 1, yu^(-1)}, yw])/2 - 
     G[{0}, yu^(-1)]*G[{0}, yv^(-1)]*G[{0, 1, yu^(-1)}, yw] - 
     (G[{0}, yv^(-1)]^2*G[{0, 1, yu^(-1)}, yw])/2 + 
     G[{0}, yu^(-1)]*G[{0}, yw]*G[{0, 1, yu^(-1)}, yw] + 
     G[{0}, yv^(-1)]*G[{0}, yw]*G[{0, 1, yu^(-1)}, yw] - 
     (G[{0}, yw]^2*G[{0, 1, yu^(-1)}, yw])/2 + 2*G[{0}, yu^(-1)]*
      G[{1}, yv^(-1)]*G[{0, 1, yu^(-1)}, yw] + 2*G[{0}, yv^(-1)]*
      G[{1}, yv^(-1)]*G[{0, 1, yu^(-1)}, yw] - 2*G[{0}, yw]*G[{1}, yv^(-1)]*
      G[{0, 1, yu^(-1)}, yw] - (3*G[{1}, yv^(-1)]^2*G[{0, 1, yu^(-1)}, yw])/
      2 - G[{0}, yu^(-1)]*G[{1}, yw]*G[{0, 1, yu^(-1)}, yw] - 
     G[{0}, yv^(-1)]*G[{1}, yw]*G[{0, 1, yu^(-1)}, yw] + 
     G[{0}, yw]*G[{1}, yw]*G[{0, 1, yu^(-1)}, yw] + 
     2*G[{1}, yv^(-1)]*G[{1}, yw]*G[{0, 1, yu^(-1)}, yw] - 
     G[{0, 1}, yv^(-1)]*G[{0, 1, yu^(-1)}, yw] + G[{0, yu}, yv^(-1)]*
      G[{0, 1, yu^(-1)}, yw] + 2*G[{0, yv^(-1)}, yw]*G[{0, 1, yu^(-1)}, yw] - 
     2*G[{0, 1/(yu*yv)}, yw]*G[{0, 1, yu^(-1)}, yw] - 
     G[{1, yu}, yv^(-1)]*G[{0, 1, yu^(-1)}, yw] + 
     (Pi^2*G[{0, 1, yu}, yv^(-1)])/3 + 
     (G[{0}, yu^(-1)]^2*G[{0, 1, yu}, yv^(-1)])/2 + 
     G[{0}, yu^(-1)]*G[{0}, yv^(-1)]*G[{0, 1, yu}, yv^(-1)] + 
     (G[{0}, yv^(-1)]^2*G[{0, 1, yu}, yv^(-1)])/2 - 
     G[{0}, yu^(-1)]*G[{0}, yw]*G[{0, 1, yu}, yv^(-1)] - 
     G[{0}, yv^(-1)]*G[{0}, yw]*G[{0, 1, yu}, yv^(-1)] + 
     (G[{0}, yw]^2*G[{0, 1, yu}, yv^(-1)])/2 - G[{0}, yu^(-1)]*
      G[{1}, yv^(-1)]*G[{0, 1, yu}, yv^(-1)] - G[{0}, yv^(-1)]*
      G[{1}, yv^(-1)]*G[{0, 1, yu}, yv^(-1)] + G[{0}, yw]*G[{1}, yv^(-1)]*
      G[{0, 1, yu}, yv^(-1)] + G[{0}, yu^(-1)]*G[{1}, yw]*
      G[{0, 1, yu}, yv^(-1)] + G[{0}, yv^(-1)]*G[{1}, yw]*
      G[{0, 1, yu}, yv^(-1)] - G[{0}, yw]*G[{1}, yw]*G[{0, 1, yu}, yv^(-1)] + 
     G[{0, 1}, yv^(-1)]*G[{0, 1, yu}, yv^(-1)] + 
     2*G[{0, 1}, yw]*G[{0, 1, yu}, yv^(-1)] - 2*G[{0, 1/(yu*yv)}, yw]*
      G[{0, 1, yu}, yv^(-1)] - G[{0, yu^(-1)}, yw]*G[{0, 1, yv^(-1)}, yw] + 
     2*G[{0, yv^(-1)}, yw]*G[{0, 1, yv^(-1)}, yw] - 
     2*G[{0, 1/(yu*yv)}, yw]*G[{0, 1, yv^(-1)}, yw] - 
     G[{1}, yv^(-1)]*G[{1}, yw]*G[{0, 1, 1/(yu*yv)}, yw] + 
     G[{1}, yw]*G[{yu}, yv^(-1)]*G[{0, 1, 1/(yu*yv)}, yw] + 
     G[{0, yu^(-1)}, yw]*G[{0, 1, 1/(yu*yv)}, yw] + 
     G[{0, 1/(yu*yv)}, yw]*G[{0, 1, 1/(yu*yv)}, yw] - 
     (Pi^2*G[{0, yu^(-1), 1}, yw])/3 - 
     (G[{0}, yu^(-1)]^2*G[{0, yu^(-1), 1}, yw])/2 - 
     G[{0}, yu^(-1)]*G[{0}, yv^(-1)]*G[{0, yu^(-1), 1}, yw] - 
     (G[{0}, yv^(-1)]^2*G[{0, yu^(-1), 1}, yw])/2 + 
     G[{0}, yu^(-1)]*G[{0}, yw]*G[{0, yu^(-1), 1}, yw] + 
     G[{0}, yv^(-1)]*G[{0}, yw]*G[{0, yu^(-1), 1}, yw] - 
     (G[{0}, yw]^2*G[{0, yu^(-1), 1}, yw])/2 + 2*G[{0}, yu^(-1)]*
      G[{1}, yv^(-1)]*G[{0, yu^(-1), 1}, yw] + 2*G[{0}, yv^(-1)]*
      G[{1}, yv^(-1)]*G[{0, yu^(-1), 1}, yw] - 2*G[{0}, yw]*G[{1}, yv^(-1)]*
      G[{0, yu^(-1), 1}, yw] - (3*G[{1}, yv^(-1)]^2*G[{0, yu^(-1), 1}, yw])/
      2 - G[{0}, yu^(-1)]*G[{1}, yw]*G[{0, yu^(-1), 1}, yw] - 
     G[{0}, yv^(-1)]*G[{1}, yw]*G[{0, yu^(-1), 1}, yw] + 
     G[{0}, yw]*G[{1}, yw]*G[{0, yu^(-1), 1}, yw] + 
     G[{1}, yv^(-1)]*G[{1}, yw]*G[{0, yu^(-1), 1}, yw] + 
     G[{1}, yw]*G[{yu}, yv^(-1)]*G[{0, yu^(-1), 1}, yw] - 
     G[{0, 1}, yv^(-1)]*G[{0, yu^(-1), 1}, yw] + G[{0, yu}, yv^(-1)]*
      G[{0, yu^(-1), 1}, yw] + G[{0, yv^(-1)}, yw]*G[{0, yu^(-1), 1}, yw] - 
     G[{0, 1/(yu*yv)}, yw]*G[{0, yu^(-1), 1}, yw] - 
     G[{1, yu}, yv^(-1)]*G[{0, yu^(-1), 1}, yw] + 
     2*G[{0}, yu^(-1)]*G[{1}, yw]*G[{0, yu^(-1), yu^(-1)}, yw] + 
     2*G[{0}, yv^(-1)]*G[{1}, yw]*G[{0, yu^(-1), yu^(-1)}, yw] - 
     2*G[{0}, yw]*G[{1}, yw]*G[{0, yu^(-1), yu^(-1)}, yw] - 
     4*G[{1}, yv^(-1)]*G[{1}, yw]*G[{0, yu^(-1), yu^(-1)}, yw] + 
     G[{1}, yw]^2*G[{0, yu^(-1), yu^(-1)}, yw] - 2*G[{0, yv^(-1)}, yw]*
      G[{0, yu^(-1), yu^(-1)}, yw] + 2*G[{0, 1/(yu*yv)}, yw]*
      G[{0, yu^(-1), yu^(-1)}, yw] - 2*G[{0, yv^(-1)}, yw]*
      G[{0, yu^(-1), yv^(-1)}, yw] + 2*G[{0, 1/(yu*yv)}, yw]*
      G[{0, yu^(-1), yv^(-1)}, yw] + G[{1}, yv^(-1)]*G[{1}, yw]*
      G[{0, yu^(-1), 1/(yu*yv)}, yw] - G[{1}, yw]*G[{yu}, yv^(-1)]*
      G[{0, yu^(-1), 1/(yu*yv)}, yw] - G[{0, yv^(-1)}, yw]*
      G[{0, yu^(-1), 1/(yu*yv)}, yw] - G[{0, 1/(yu*yv)}, yw]*
      G[{0, yu^(-1), 1/(yu*yv)}, yw] + (Pi^2*G[{0, yu, 1}, yv^(-1)])/3 + 
     (G[{0}, yu^(-1)]^2*G[{0, yu, 1}, yv^(-1)])/2 + 
     G[{0}, yu^(-1)]*G[{0}, yv^(-1)]*G[{0, yu, 1}, yv^(-1)] + 
     (G[{0}, yv^(-1)]^2*G[{0, yu, 1}, yv^(-1)])/2 - 
     G[{0}, yu^(-1)]*G[{0}, yw]*G[{0, yu, 1}, yv^(-1)] - 
     G[{0}, yv^(-1)]*G[{0}, yw]*G[{0, yu, 1}, yv^(-1)] + 
     (G[{0}, yw]^2*G[{0, yu, 1}, yv^(-1)])/2 - G[{0}, yu^(-1)]*
      G[{1}, yv^(-1)]*G[{0, yu, 1}, yv^(-1)] - G[{0}, yv^(-1)]*
      G[{1}, yv^(-1)]*G[{0, yu, 1}, yv^(-1)] + G[{0}, yw]*G[{1}, yv^(-1)]*
      G[{0, yu, 1}, yv^(-1)] + G[{0}, yu^(-1)]*G[{1}, yw]*
      G[{0, yu, 1}, yv^(-1)] + G[{0}, yv^(-1)]*G[{1}, yw]*
      G[{0, yu, 1}, yv^(-1)] - G[{0}, yw]*G[{1}, yw]*G[{0, yu, 1}, yv^(-1)] + 
     G[{0, 1}, yv^(-1)]*G[{0, yu, 1}, yv^(-1)] + 
     2*G[{0, 1}, yw]*G[{0, yu, 1}, yv^(-1)] - G[{0, yu}, yv^(-1)]*
      G[{0, yu, 1}, yv^(-1)] - 2*G[{0, 1/(yu*yv)}, yw]*
      G[{0, yu, 1}, yv^(-1)] + 2*G[{0}, yu^(-1)]*G[{1}, yv^(-1)]*
      G[{0, yu, yu}, yv^(-1)] + 2*G[{0}, yv^(-1)]*G[{1}, yv^(-1)]*
      G[{0, yu, yu}, yv^(-1)] - 2*G[{0}, yw]*G[{1}, yv^(-1)]*
      G[{0, yu, yu}, yv^(-1)] - G[{1}, yv^(-1)]^2*G[{0, yu, yu}, yv^(-1)] - 
     2*G[{0}, yu^(-1)]*G[{1}, yw]*G[{0, yu, yu}, yv^(-1)] - 
     2*G[{0}, yv^(-1)]*G[{1}, yw]*G[{0, yu, yu}, yv^(-1)] + 
     2*G[{0}, yw]*G[{1}, yw]*G[{0, yu, yu}, yv^(-1)] + 
     2*G[{1}, yv^(-1)]*G[{1}, yw]*G[{0, yu, yu}, yv^(-1)] - 
     G[{1}, yw]^2*G[{0, yu, yu}, yv^(-1)] - 2*G[{0, 1}, yw]*
      G[{0, yu, yu}, yv^(-1)] + 2*G[{0, 1/(yu*yv)}, yw]*
      G[{0, yu, yu}, yv^(-1)] - G[{0}, yu^(-1)]*G[{1}, yv^(-1)]*
      G[{0, yv^(-1), 1}, yw] - G[{0}, yv^(-1)]*G[{1}, yv^(-1)]*
      G[{0, yv^(-1), 1}, yw] + G[{0}, yw]*G[{1}, yv^(-1)]*
      G[{0, yv^(-1), 1}, yw] + G[{1}, yv^(-1)]^2*G[{0, yv^(-1), 1}, yw] - 
     G[{1}, yv^(-1)]*G[{1}, yw]*G[{0, yv^(-1), 1}, yw] + 
     G[{0}, yu^(-1)]*G[{yu}, yv^(-1)]*G[{0, yv^(-1), 1}, yw] + 
     G[{0}, yv^(-1)]*G[{yu}, yv^(-1)]*G[{0, yv^(-1), 1}, yw] - 
     G[{0}, yw]*G[{yu}, yv^(-1)]*G[{0, yv^(-1), 1}, yw] + 
     G[{1}, yw]*G[{yu}, yv^(-1)]*G[{0, yv^(-1), 1}, yw] - 
     G[{yu}, yv^(-1)]^2*G[{0, yv^(-1), 1}, yw] - G[{0, 1/(yu*yv)}, yw]*
      G[{0, yv^(-1), 1}, yw] + 2*G[{0, 1/(yu*yv)}, yw]*
      G[{0, yv^(-1), yu^(-1)}, yw] - (Pi^2*G[{0, yv^(-1), yv^(-1)}, yw])/3 - 
     G[{0}, yu^(-1)]^2*G[{0, yv^(-1), yv^(-1)}, yw] - 
     2*G[{0}, yu^(-1)]*G[{0}, yv^(-1)]*G[{0, yv^(-1), yv^(-1)}, yw] - 
     G[{0}, yv^(-1)]^2*G[{0, yv^(-1), yv^(-1)}, yw] + 
     2*G[{0}, yu^(-1)]*G[{0}, yw]*G[{0, yv^(-1), yv^(-1)}, yw] + 
     2*G[{0}, yv^(-1)]*G[{0}, yw]*G[{0, yv^(-1), yv^(-1)}, yw] - 
     G[{0}, yw]^2*G[{0, yv^(-1), yv^(-1)}, yw] + 2*G[{0}, yu^(-1)]*
      G[{1}, yu^(-1)]*G[{0, yv^(-1), yv^(-1)}, yw] + 
     2*G[{0}, yv^(-1)]*G[{1}, yu^(-1)]*G[{0, yv^(-1), yv^(-1)}, yw] - 
     2*G[{0}, yw]*G[{1}, yu^(-1)]*G[{0, yv^(-1), yv^(-1)}, yw] - 
     2*G[{1}, yu^(-1)]^2*G[{0, yv^(-1), yv^(-1)}, yw] + 
     2*G[{0}, yu^(-1)]*G[{1}, yv^(-1)]*G[{0, yv^(-1), yv^(-1)}, yw] + 
     2*G[{0}, yv^(-1)]*G[{1}, yv^(-1)]*G[{0, yv^(-1), yv^(-1)}, yw] - 
     2*G[{0}, yw]*G[{1}, yv^(-1)]*G[{0, yv^(-1), yv^(-1)}, yw] - 
     G[{1}, yv^(-1)]^2*G[{0, yv^(-1), yv^(-1)}, yw] + 
     G[{1}, yw]^2*G[{0, yv^(-1), yv^(-1)}, yw] + 2*G[{0, 1}, yu^(-1)]*
      G[{0, yv^(-1), yv^(-1)}, yw] - 2*G[{0, 1}, yw]*G[{0, yv^(-1), yv^(-1)}, 
       yw] + 2*G[{0, yu^(-1)}, yw]*G[{0, yv^(-1), yv^(-1)}, yw] + 
     2*G[{0, yv^(-1)}, yw]*G[{0, yv^(-1), yv^(-1)}, yw] + 
     2*G[{0, 1/(yu*yv)}, yw]*G[{0, yv^(-1), yv^(-1)}, yw] - 
     2*G[{1, yu}, yv^(-1)]*G[{0, yv^(-1), yv^(-1)}, yw] + 
     (Pi^2*G[{0, yv^(-1), 1/(yu*yv)}, yw])/6 + 
     (G[{0}, yu^(-1)]^2*G[{0, yv^(-1), 1/(yu*yv)}, yw])/2 + 
     G[{0}, yu^(-1)]*G[{0}, yv^(-1)]*G[{0, yv^(-1), 1/(yu*yv)}, yw] + 
     (G[{0}, yv^(-1)]^2*G[{0, yv^(-1), 1/(yu*yv)}, yw])/2 - 
     G[{0}, yu^(-1)]*G[{0}, yw]*G[{0, yv^(-1), 1/(yu*yv)}, yw] - 
     G[{0}, yv^(-1)]*G[{0}, yw]*G[{0, yv^(-1), 1/(yu*yv)}, yw] + 
     (G[{0}, yw]^2*G[{0, yv^(-1), 1/(yu*yv)}, yw])/2 + 
     G[{0}, yu^(-1)]*G[{1}, yu^(-1)]*G[{0, yv^(-1), 1/(yu*yv)}, yw] + 
     G[{0}, yv^(-1)]*G[{1}, yu^(-1)]*G[{0, yv^(-1), 1/(yu*yv)}, yw] - 
     G[{0}, yw]*G[{1}, yu^(-1)]*G[{0, yv^(-1), 1/(yu*yv)}, yw] - 
     G[{1}, yu^(-1)]^2*G[{0, yv^(-1), 1/(yu*yv)}, yw] - 
     2*G[{0}, yu^(-1)]*G[{1}, yv^(-1)]*G[{0, yv^(-1), 1/(yu*yv)}, yw] - 
     2*G[{0}, yv^(-1)]*G[{1}, yv^(-1)]*G[{0, yv^(-1), 1/(yu*yv)}, yw] + 
     2*G[{0}, yw]*G[{1}, yv^(-1)]*G[{0, yv^(-1), 1/(yu*yv)}, yw] + 
     (3*G[{1}, yv^(-1)]^2*G[{0, yv^(-1), 1/(yu*yv)}, yw])/2 + 
     G[{0}, yu^(-1)]*G[{1}, yw]*G[{0, yv^(-1), 1/(yu*yv)}, yw] + 
     G[{0}, yv^(-1)]*G[{1}, yw]*G[{0, yv^(-1), 1/(yu*yv)}, yw] - 
     G[{0}, yw]*G[{1}, yw]*G[{0, yv^(-1), 1/(yu*yv)}, yw] - 
     G[{1}, yv^(-1)]*G[{1}, yw]*G[{0, yv^(-1), 1/(yu*yv)}, yw] - 
     G[{0}, yu^(-1)]*G[{yu}, yv^(-1)]*G[{0, yv^(-1), 1/(yu*yv)}, yw] - 
     G[{0}, yv^(-1)]*G[{yu}, yv^(-1)]*G[{0, yv^(-1), 1/(yu*yv)}, yw] + 
     G[{0}, yw]*G[{yu}, yv^(-1)]*G[{0, yv^(-1), 1/(yu*yv)}, yw] - 
     G[{1}, yw]*G[{yu}, yv^(-1)]*G[{0, yv^(-1), 1/(yu*yv)}, yw] + 
     G[{yu}, yv^(-1)]^2*G[{0, yv^(-1), 1/(yu*yv)}, yw] - 
     G[{0, 1}, yu^(-1)]*G[{0, yv^(-1), 1/(yu*yv)}, yw] + 
     G[{0, 1}, yw]*G[{0, yv^(-1), 1/(yu*yv)}, yw] - 
     G[{0, yu^(-1)}, yw]*G[{0, yv^(-1), 1/(yu*yv)}, yw] - 
     G[{0, yv^(-1)}, yw]*G[{0, yv^(-1), 1/(yu*yv)}, yw] - 
     G[{0, 1/(yu*yv)}, yw]*G[{0, yv^(-1), 1/(yu*yv)}, yw] + 
     G[{1, yu}, yv^(-1)]*G[{0, yv^(-1), 1/(yu*yv)}, yw] - 
     (Pi^2*G[{0, 1/(yu*yv), 1}, yw])/3 - 
     (G[{0}, yu^(-1)]^2*G[{0, 1/(yu*yv), 1}, yw])/2 - 
     G[{0}, yu^(-1)]*G[{0}, yv^(-1)]*G[{0, 1/(yu*yv), 1}, yw] - 
     (G[{0}, yv^(-1)]^2*G[{0, 1/(yu*yv), 1}, yw])/2 + 
     G[{0}, yu^(-1)]*G[{0}, yw]*G[{0, 1/(yu*yv), 1}, yw] + 
     G[{0}, yv^(-1)]*G[{0}, yw]*G[{0, 1/(yu*yv), 1}, yw] - 
     (G[{0}, yw]^2*G[{0, 1/(yu*yv), 1}, yw])/2 + 
     (G[{1}, yv^(-1)]^2*G[{0, 1/(yu*yv), 1}, yw])/2 + 
     G[{0}, yu^(-1)]*G[{1}, yw]*G[{0, 1/(yu*yv), 1}, yw] + 
     G[{0}, yv^(-1)]*G[{1}, yw]*G[{0, 1/(yu*yv), 1}, yw] - 
     G[{0}, yw]*G[{1}, yw]*G[{0, 1/(yu*yv), 1}, yw] - 
     G[{1}, yv^(-1)]*G[{1}, yw]*G[{0, 1/(yu*yv), 1}, yw] + 
     G[{1}, yw]^2*G[{0, 1/(yu*yv), 1}, yw] + 2*G[{0}, yu^(-1)]*
      G[{yu}, yv^(-1)]*G[{0, 1/(yu*yv), 1}, yw] + 
     2*G[{0}, yv^(-1)]*G[{yu}, yv^(-1)]*G[{0, 1/(yu*yv), 1}, yw] - 
     2*G[{0}, yw]*G[{yu}, yv^(-1)]*G[{0, 1/(yu*yv), 1}, yw] - 
     G[{1}, yw]*G[{yu}, yv^(-1)]*G[{0, 1/(yu*yv), 1}, yw] - 
     2*G[{yu}, yv^(-1)]^2*G[{0, 1/(yu*yv), 1}, yw] - 
     G[{0, 1}, yv^(-1)]*G[{0, 1/(yu*yv), 1}, yw] + 
     G[{0, yu}, yv^(-1)]*G[{0, 1/(yu*yv), 1}, yw] - 
     G[{1, yu}, yv^(-1)]*G[{0, 1/(yu*yv), 1}, yw] + 
     (Pi^2*G[{0, 1/(yu*yv), yu^(-1)}, yw])/3 + 
     (G[{0}, yu^(-1)]^2*G[{0, 1/(yu*yv), yu^(-1)}, yw])/2 + 
     G[{0}, yu^(-1)]*G[{0}, yv^(-1)]*G[{0, 1/(yu*yv), yu^(-1)}, yw] + 
     (G[{0}, yv^(-1)]^2*G[{0, 1/(yu*yv), yu^(-1)}, yw])/2 - 
     G[{0}, yu^(-1)]*G[{0}, yw]*G[{0, 1/(yu*yv), yu^(-1)}, yw] - 
     G[{0}, yv^(-1)]*G[{0}, yw]*G[{0, 1/(yu*yv), yu^(-1)}, yw] + 
     (G[{0}, yw]^2*G[{0, 1/(yu*yv), yu^(-1)}, yw])/2 - 
     2*G[{0}, yu^(-1)]*G[{1}, yv^(-1)]*G[{0, 1/(yu*yv), yu^(-1)}, yw] - 
     2*G[{0}, yv^(-1)]*G[{1}, yv^(-1)]*G[{0, 1/(yu*yv), yu^(-1)}, yw] + 
     2*G[{0}, yw]*G[{1}, yv^(-1)]*G[{0, 1/(yu*yv), yu^(-1)}, yw] + 
     (3*G[{1}, yv^(-1)]^2*G[{0, 1/(yu*yv), yu^(-1)}, yw])/2 - 
     G[{0}, yu^(-1)]*G[{1}, yw]*G[{0, 1/(yu*yv), yu^(-1)}, yw] - 
     G[{0}, yv^(-1)]*G[{1}, yw]*G[{0, 1/(yu*yv), yu^(-1)}, yw] + 
     G[{0}, yw]*G[{1}, yw]*G[{0, 1/(yu*yv), yu^(-1)}, yw] + 
     2*G[{1}, yv^(-1)]*G[{1}, yw]*G[{0, 1/(yu*yv), yu^(-1)}, yw] - 
     G[{1}, yw]^2*G[{0, 1/(yu*yv), yu^(-1)}, yw] + 
     G[{0, 1}, yv^(-1)]*G[{0, 1/(yu*yv), yu^(-1)}, yw] - 
     G[{0, yu}, yv^(-1)]*G[{0, 1/(yu*yv), yu^(-1)}, yw] + 
     G[{1, yu}, yv^(-1)]*G[{0, 1/(yu*yv), yu^(-1)}, yw] + 
     (Pi^2*G[{0, 1/(yu*yv), yv^(-1)}, yw])/3 + G[{0}, yu^(-1)]^2*
      G[{0, 1/(yu*yv), yv^(-1)}, yw] + 2*G[{0}, yu^(-1)]*G[{0}, yv^(-1)]*
      G[{0, 1/(yu*yv), yv^(-1)}, yw] + G[{0}, yv^(-1)]^2*
      G[{0, 1/(yu*yv), yv^(-1)}, yw] - 2*G[{0}, yu^(-1)]*G[{0}, yw]*
      G[{0, 1/(yu*yv), yv^(-1)}, yw] - 2*G[{0}, yv^(-1)]*G[{0}, yw]*
      G[{0, 1/(yu*yv), yv^(-1)}, yw] + G[{0}, yw]^2*
      G[{0, 1/(yu*yv), yv^(-1)}, yw] - 2*G[{0}, yu^(-1)]*G[{1}, yu^(-1)]*
      G[{0, 1/(yu*yv), yv^(-1)}, yw] - 2*G[{0}, yv^(-1)]*G[{1}, yu^(-1)]*
      G[{0, 1/(yu*yv), yv^(-1)}, yw] + 2*G[{0}, yw]*G[{1}, yu^(-1)]*
      G[{0, 1/(yu*yv), yv^(-1)}, yw] + 2*G[{1}, yu^(-1)]^2*
      G[{0, 1/(yu*yv), yv^(-1)}, yw] - 2*G[{0}, yu^(-1)]*G[{1}, yv^(-1)]*
      G[{0, 1/(yu*yv), yv^(-1)}, yw] - 2*G[{0}, yv^(-1)]*G[{1}, yv^(-1)]*
      G[{0, 1/(yu*yv), yv^(-1)}, yw] + 2*G[{0}, yw]*G[{1}, yv^(-1)]*
      G[{0, 1/(yu*yv), yv^(-1)}, yw] + G[{1}, yv^(-1)]^2*
      G[{0, 1/(yu*yv), yv^(-1)}, yw] - G[{1}, yw]^2*
      G[{0, 1/(yu*yv), yv^(-1)}, yw] - 2*G[{0, 1}, yu^(-1)]*
      G[{0, 1/(yu*yv), yv^(-1)}, yw] + 2*G[{0, 1}, yw]*
      G[{0, 1/(yu*yv), yv^(-1)}, yw] - 2*G[{0, yu^(-1)}, yw]*
      G[{0, 1/(yu*yv), yv^(-1)}, yw] - 2*G[{0, yv^(-1)}, yw]*
      G[{0, 1/(yu*yv), yv^(-1)}, yw] + 2*G[{0, 1/(yu*yv)}, yw]*
      G[{0, 1/(yu*yv), yv^(-1)}, yw] + 2*G[{1, yu}, yv^(-1)]*
      G[{0, 1/(yu*yv), yv^(-1)}, yw] - 
     (Pi^2*G[{0, 1/(yu*yv), 1/(yu*yv)}, yw])/6 - 
     (G[{0}, yu^(-1)]^2*G[{0, 1/(yu*yv), 1/(yu*yv)}, yw])/2 - 
     G[{0}, yu^(-1)]*G[{0}, yv^(-1)]*G[{0, 1/(yu*yv), 1/(yu*yv)}, yw] - 
     (G[{0}, yv^(-1)]^2*G[{0, 1/(yu*yv), 1/(yu*yv)}, yw])/2 + 
     G[{0}, yu^(-1)]*G[{0}, yw]*G[{0, 1/(yu*yv), 1/(yu*yv)}, yw] + 
     G[{0}, yv^(-1)]*G[{0}, yw]*G[{0, 1/(yu*yv), 1/(yu*yv)}, yw] - 
     (G[{0}, yw]^2*G[{0, 1/(yu*yv), 1/(yu*yv)}, yw])/2 - 
     G[{0}, yu^(-1)]*G[{1}, yu^(-1)]*G[{0, 1/(yu*yv), 1/(yu*yv)}, yw] - 
     G[{0}, yv^(-1)]*G[{1}, yu^(-1)]*G[{0, 1/(yu*yv), 1/(yu*yv)}, yw] + 
     G[{0}, yw]*G[{1}, yu^(-1)]*G[{0, 1/(yu*yv), 1/(yu*yv)}, yw] + 
     G[{1}, yu^(-1)]^2*G[{0, 1/(yu*yv), 1/(yu*yv)}, yw] + 
     2*G[{0}, yu^(-1)]*G[{1}, yv^(-1)]*G[{0, 1/(yu*yv), 1/(yu*yv)}, yw] + 
     2*G[{0}, yv^(-1)]*G[{1}, yv^(-1)]*G[{0, 1/(yu*yv), 1/(yu*yv)}, yw] - 
     2*G[{0}, yw]*G[{1}, yv^(-1)]*G[{0, 1/(yu*yv), 1/(yu*yv)}, yw] - 
     (3*G[{1}, yv^(-1)]^2*G[{0, 1/(yu*yv), 1/(yu*yv)}, yw])/2 - 
     G[{0}, yu^(-1)]*G[{1}, yw]*G[{0, 1/(yu*yv), 1/(yu*yv)}, yw] - 
     G[{0}, yv^(-1)]*G[{1}, yw]*G[{0, 1/(yu*yv), 1/(yu*yv)}, yw] + 
     G[{0}, yw]*G[{1}, yw]*G[{0, 1/(yu*yv), 1/(yu*yv)}, yw] + 
     G[{1}, yv^(-1)]*G[{1}, yw]*G[{0, 1/(yu*yv), 1/(yu*yv)}, yw] + 
     G[{0}, yu^(-1)]*G[{yu}, yv^(-1)]*G[{0, 1/(yu*yv), 1/(yu*yv)}, yw] + 
     G[{0}, yv^(-1)]*G[{yu}, yv^(-1)]*G[{0, 1/(yu*yv), 1/(yu*yv)}, yw] - 
     G[{0}, yw]*G[{yu}, yv^(-1)]*G[{0, 1/(yu*yv), 1/(yu*yv)}, yw] + 
     G[{1}, yw]*G[{yu}, yv^(-1)]*G[{0, 1/(yu*yv), 1/(yu*yv)}, yw] - 
     G[{yu}, yv^(-1)]^2*G[{0, 1/(yu*yv), 1/(yu*yv)}, yw] + 
     G[{0, 1}, yu^(-1)]*G[{0, 1/(yu*yv), 1/(yu*yv)}, yw] - 
     G[{0, 1}, yw]*G[{0, 1/(yu*yv), 1/(yu*yv)}, yw] + 
     G[{0, yu^(-1)}, yw]*G[{0, 1/(yu*yv), 1/(yu*yv)}, yw] + 
     G[{0, yv^(-1)}, yw]*G[{0, 1/(yu*yv), 1/(yu*yv)}, yw] - 
     G[{0, 1/(yu*yv)}, yw]*G[{0, 1/(yu*yv), 1/(yu*yv)}, yw] - 
     G[{1, yu}, yv^(-1)]*G[{0, 1/(yu*yv), 1/(yu*yv)}, yw] + 
     2*G[{0, 1}, yw]*G[{1, 1, yu}, yv^(-1)] + G[{0, yv^(-1)}, yw]*
      G[{1, 1, yu}, yv^(-1)] - 3*G[{0, 1/(yu*yv)}, yw]*
      G[{1, 1, yu}, yv^(-1)] + 2*G[{0, 1}, yw]*G[{1, yu, yu}, yv^(-1)] + 
     2*G[{0, yv^(-1)}, yw]*G[{1, yu, yu}, yv^(-1)] - 
     4*G[{0, 1/(yu*yv)}, yw]*G[{1, yu, yu}, yv^(-1)] - 
     G[{0}, yu^(-1)]*G[{0, 0, 0, 1}, yu^(-1)] - G[{0}, yv^(-1)]*
      G[{0, 0, 0, 1}, yu^(-1)] + G[{0}, yw]*G[{0, 0, 0, 1}, yu^(-1)] + 
     3*G[{0}, yu^(-1)]*G[{0, 0, 0, 1}, yw] + 3*G[{0}, yv^(-1)]*
      G[{0, 0, 0, 1}, yw] - 3*G[{0}, yw]*G[{0, 0, 0, 1}, yw] - 
     6*G[{yu}, yv^(-1)]*G[{0, 0, 0, 1}, yw] - 3*G[{0}, yu^(-1)]*
      G[{0, 0, 0, yu^(-1)}, yw] - 3*G[{0}, yv^(-1)]*G[{0, 0, 0, yu^(-1)}, 
       yw] + 3*G[{0}, yw]*G[{0, 0, 0, yu^(-1)}, yw] + 
     6*G[{1}, yv^(-1)]*G[{0, 0, 0, yu^(-1)}, yw] - 
     3*G[{0}, yu^(-1)]*G[{0, 0, 0, yv^(-1)}, yw] - 
     3*G[{0}, yv^(-1)]*G[{0, 0, 0, yv^(-1)}, yw] + 
     3*G[{0}, yw]*G[{0, 0, 0, yv^(-1)}, yw] + 6*G[{1}, yu^(-1)]*
      G[{0, 0, 0, yv^(-1)}, yw] + 3*G[{0}, yu^(-1)]*G[{0, 0, 0, 1/(yu*yv)}, 
       yw] + 3*G[{0}, yv^(-1)]*G[{0, 0, 0, 1/(yu*yv)}, yw] - 
     3*G[{0}, yw]*G[{0, 0, 0, 1/(yu*yv)}, yw] - 6*G[{1}, yu^(-1)]*
      G[{0, 0, 0, 1/(yu*yv)}, yw] - 6*G[{1}, yv^(-1)]*
      G[{0, 0, 0, 1/(yu*yv)}, yw] + 6*G[{yu}, yv^(-1)]*
      G[{0, 0, 0, 1/(yu*yv)}, yw] + G[{0}, yu^(-1)]*
      G[{0, 0, 1, 1}, yu^(-1)] + G[{0}, yv^(-1)]*G[{0, 0, 1, 1}, yu^(-1)] - 
     G[{0}, yw]*G[{0, 0, 1, 1}, yu^(-1)] - 2*G[{1}, yv^(-1)]*
      G[{0, 0, 1, 1}, yv^(-1)] + 2*G[{1}, yw]*G[{0, 0, 1, 1}, yv^(-1)] + 
     4*G[{0}, yu^(-1)]*G[{0, 0, 1, 1}, yw] + 4*G[{0}, yv^(-1)]*
      G[{0, 0, 1, 1}, yw] - 4*G[{0}, yw]*G[{0, 0, 1, 1}, yw] - 
     3*G[{1}, yv^(-1)]*G[{0, 0, 1, 1}, yw] + 2*G[{1}, yw]*
      G[{0, 0, 1, 1}, yw] - 5*G[{yu}, yv^(-1)]*G[{0, 0, 1, 1}, yw] - 
     G[{0}, yu^(-1)]*G[{0, 0, 1, yu^(-1)}, yw] - 
     G[{0}, yv^(-1)]*G[{0, 0, 1, yu^(-1)}, yw] + 
     G[{0}, yw]*G[{0, 0, 1, yu^(-1)}, yw] + 2*G[{1}, yv^(-1)]*
      G[{0, 0, 1, yu^(-1)}, yw] - 2*G[{1}, yw]*G[{0, 0, 1, yu^(-1)}, yw] + 
     2*G[{1}, yv^(-1)]*G[{0, 0, 1, yu}, yv^(-1)] - 
     2*G[{1}, yw]*G[{0, 0, 1, yu}, yv^(-1)] - 2*G[{0}, yu^(-1)]*
      G[{0, 0, 1, yv^(-1)}, yw] - 2*G[{0}, yv^(-1)]*G[{0, 0, 1, yv^(-1)}, 
       yw] + 2*G[{0}, yw]*G[{0, 0, 1, yv^(-1)}, yw] + 
     4*G[{1}, yv^(-1)]*G[{0, 0, 1, yv^(-1)}, yw] - 
     2*G[{1}, yw]*G[{0, 0, 1, yv^(-1)}, yw] + 2*G[{0}, yu^(-1)]*
      G[{0, 0, 1, 1/(yu*yv)}, yw] + 2*G[{0}, yv^(-1)]*
      G[{0, 0, 1, 1/(yu*yv)}, yw] - 2*G[{0}, yw]*G[{0, 0, 1, 1/(yu*yv)}, 
       yw] - 3*G[{1}, yv^(-1)]*G[{0, 0, 1, 1/(yu*yv)}, yw] + 
     2*G[{1}, yw]*G[{0, 0, 1, 1/(yu*yv)}, yw] - G[{yu}, yv^(-1)]*
      G[{0, 0, 1, 1/(yu*yv)}, yw] - G[{0}, yu^(-1)]*G[{0, 0, yu^(-1), 1}, 
       yw] - G[{0}, yv^(-1)]*G[{0, 0, yu^(-1), 1}, yw] + 
     G[{0}, yw]*G[{0, 0, yu^(-1), 1}, yw] + 3*G[{1}, yv^(-1)]*
      G[{0, 0, yu^(-1), 1}, yw] - 2*G[{1}, yw]*G[{0, 0, yu^(-1), 1}, yw] - 
     G[{yu}, yv^(-1)]*G[{0, 0, yu^(-1), 1}, yw] - 
     2*G[{0}, yu^(-1)]*G[{0, 0, yu^(-1), yu^(-1)}, yw] - 
     2*G[{0}, yv^(-1)]*G[{0, 0, yu^(-1), yu^(-1)}, yw] + 
     2*G[{0}, yw]*G[{0, 0, yu^(-1), yu^(-1)}, yw] + 
     4*G[{1}, yv^(-1)]*G[{0, 0, yu^(-1), yu^(-1)}, yw] + 
     2*G[{1}, yw]*G[{0, 0, yu^(-1), yu^(-1)}, yw] + 
     2*G[{0}, yu^(-1)]*G[{0, 0, yu^(-1), yv^(-1)}, yw] + 
     2*G[{0}, yv^(-1)]*G[{0, 0, yu^(-1), yv^(-1)}, yw] - 
     2*G[{0}, yw]*G[{0, 0, yu^(-1), yv^(-1)}, yw] - 
     4*G[{1}, yv^(-1)]*G[{0, 0, yu^(-1), yv^(-1)}, yw] + 
     2*G[{1}, yw]*G[{0, 0, yu^(-1), yv^(-1)}, yw] - 
     2*G[{0}, yu^(-1)]*G[{0, 0, yu^(-1), 1/(yu*yv)}, yw] - 
     2*G[{0}, yv^(-1)]*G[{0, 0, yu^(-1), 1/(yu*yv)}, yw] + 
     2*G[{0}, yw]*G[{0, 0, yu^(-1), 1/(yu*yv)}, yw] + 
     3*G[{1}, yv^(-1)]*G[{0, 0, yu^(-1), 1/(yu*yv)}, yw] - 
     2*G[{1}, yw]*G[{0, 0, yu^(-1), 1/(yu*yv)}, yw] + 
     G[{yu}, yv^(-1)]*G[{0, 0, yu^(-1), 1/(yu*yv)}, yw] + 
     2*G[{1}, yv^(-1)]*G[{0, 0, yu, 1}, yv^(-1)] - 
     2*G[{1}, yw]*G[{0, 0, yu, 1}, yv^(-1)] - 2*G[{1}, yv^(-1)]*
      G[{0, 0, yu, yu}, yv^(-1)] + 2*G[{1}, yw]*G[{0, 0, yu, yu}, yv^(-1)] - 
     2*G[{0}, yu^(-1)]*G[{0, 0, yv^(-1), 1}, yw] - 
     2*G[{0}, yv^(-1)]*G[{0, 0, yv^(-1), 1}, yw] + 
     2*G[{0}, yw]*G[{0, 0, yv^(-1), 1}, yw] + 3*G[{1}, yv^(-1)]*
      G[{0, 0, yv^(-1), 1}, yw] - 2*G[{1}, yw]*G[{0, 0, yv^(-1), 1}, yw] + 
     G[{yu}, yv^(-1)]*G[{0, 0, yv^(-1), 1}, yw] + 
     2*G[{0}, yu^(-1)]*G[{0, 0, yv^(-1), yu^(-1)}, yw] + 
     2*G[{0}, yv^(-1)]*G[{0, 0, yv^(-1), yu^(-1)}, yw] - 
     2*G[{0}, yw]*G[{0, 0, yv^(-1), yu^(-1)}, yw] - 
     4*G[{1}, yv^(-1)]*G[{0, 0, yv^(-1), yu^(-1)}, yw] + 
     2*G[{1}, yw]*G[{0, 0, yv^(-1), yu^(-1)}, yw] - 
     2*G[{0}, yu^(-1)]*G[{0, 0, yv^(-1), yv^(-1)}, yw] - 
     2*G[{0}, yv^(-1)]*G[{0, 0, yv^(-1), yv^(-1)}, yw] + 
     2*G[{0}, yw]*G[{0, 0, yv^(-1), yv^(-1)}, yw] + 
     4*G[{1}, yu^(-1)]*G[{0, 0, yv^(-1), yv^(-1)}, yw] - 
     G[{0}, yu^(-1)]*G[{0, 0, yv^(-1), 1/(yu*yv)}, yw] - 
     G[{0}, yv^(-1)]*G[{0, 0, yv^(-1), 1/(yu*yv)}, yw] + 
     G[{0}, yw]*G[{0, 0, yv^(-1), 1/(yu*yv)}, yw] + 
     2*G[{1}, yu^(-1)]*G[{0, 0, yv^(-1), 1/(yu*yv)}, yw] + 
     G[{1}, yv^(-1)]*G[{0, 0, yv^(-1), 1/(yu*yv)}, yw] - 
     G[{yu}, yv^(-1)]*G[{0, 0, yv^(-1), 1/(yu*yv)}, yw] - 
     G[{0}, yu^(-1)]*G[{0, 0, 1/(yu*yv), 1}, yw] - 
     G[{0}, yv^(-1)]*G[{0, 0, 1/(yu*yv), 1}, yw] + 
     G[{0}, yw]*G[{0, 0, 1/(yu*yv), 1}, yw] - 3*G[{1}, yv^(-1)]*
      G[{0, 0, 1/(yu*yv), 1}, yw] + 2*G[{1}, yw]*G[{0, 0, 1/(yu*yv), 1}, 
       yw] + 5*G[{yu}, yv^(-1)]*G[{0, 0, 1/(yu*yv), 1}, yw] + 
     G[{0}, yu^(-1)]*G[{0, 0, 1/(yu*yv), yu^(-1)}, yw] + 
     G[{0}, yv^(-1)]*G[{0, 0, 1/(yu*yv), yu^(-1)}, yw] - 
     G[{0}, yw]*G[{0, 0, 1/(yu*yv), yu^(-1)}, yw] - 
     2*G[{1}, yv^(-1)]*G[{0, 0, 1/(yu*yv), yu^(-1)}, yw] - 
     2*G[{1}, yw]*G[{0, 0, 1/(yu*yv), yu^(-1)}, yw] + 
     2*G[{0}, yu^(-1)]*G[{0, 0, 1/(yu*yv), yv^(-1)}, yw] + 
     2*G[{0}, yv^(-1)]*G[{0, 0, 1/(yu*yv), yv^(-1)}, yw] - 
     2*G[{0}, yw]*G[{0, 0, 1/(yu*yv), yv^(-1)}, yw] - 
     4*G[{1}, yu^(-1)]*G[{0, 0, 1/(yu*yv), yv^(-1)}, yw] + 
     G[{0}, yu^(-1)]*G[{0, 0, 1/(yu*yv), 1/(yu*yv)}, yw] + 
     G[{0}, yv^(-1)]*G[{0, 0, 1/(yu*yv), 1/(yu*yv)}, yw] - 
     G[{0}, yw]*G[{0, 0, 1/(yu*yv), 1/(yu*yv)}, yw] - 
     2*G[{1}, yu^(-1)]*G[{0, 0, 1/(yu*yv), 1/(yu*yv)}, yw] - 
     G[{1}, yv^(-1)]*G[{0, 0, 1/(yu*yv), 1/(yu*yv)}, yw] + 
     G[{yu}, yv^(-1)]*G[{0, 0, 1/(yu*yv), 1/(yu*yv)}, yw] - 
     G[{0}, yu^(-1)]*G[{0, 1, 0, yv^(-1)}, yw] - 
     G[{0}, yv^(-1)]*G[{0, 1, 0, yv^(-1)}, yw] + 
     G[{0}, yw]*G[{0, 1, 0, yv^(-1)}, yw] + 2*G[{1}, yv^(-1)]*
      G[{0, 1, 0, yv^(-1)}, yw] - G[{1}, yw]*G[{0, 1, 0, yv^(-1)}, yw] + 
     G[{0}, yu^(-1)]*G[{0, 1, 0, 1/(yu*yv)}, yw] + 
     G[{0}, yv^(-1)]*G[{0, 1, 0, 1/(yu*yv)}, yw] - 
     G[{0}, yw]*G[{0, 1, 0, 1/(yu*yv)}, yw] - 2*G[{1}, yv^(-1)]*
      G[{0, 1, 0, 1/(yu*yv)}, yw] + G[{1}, yw]*G[{0, 1, 0, 1/(yu*yv)}, yw] + 
     3*G[{0}, yu^(-1)]*G[{0, 1, 1, 1}, yu^(-1)] + 
     3*G[{0}, yv^(-1)]*G[{0, 1, 1, 1}, yu^(-1)] - 
     3*G[{0}, yw]*G[{0, 1, 1, 1}, yu^(-1)] + 3*G[{0}, yu^(-1)]*
      G[{0, 1, 1, 1}, yv^(-1)] + 3*G[{0}, yv^(-1)]*G[{0, 1, 1, 1}, yv^(-1)] - 
     3*G[{0}, yw]*G[{0, 1, 1, 1}, yv^(-1)] - 3*G[{1}, yv^(-1)]*
      G[{0, 1, 1, 1}, yv^(-1)] + 3*G[{1}, yw]*G[{0, 1, 1, 1}, yv^(-1)] + 
     3*G[{0}, yu^(-1)]*G[{0, 1, 1, 1}, yw] + 3*G[{0}, yv^(-1)]*
      G[{0, 1, 1, 1}, yw] - 3*G[{0}, yw]*G[{0, 1, 1, 1}, yw] - 
     3*G[{1}, yv^(-1)]*G[{0, 1, 1, 1}, yw] + 3*G[{1}, yw]*
      G[{0, 1, 1, 1}, yw] - 3*G[{yu}, yv^(-1)]*G[{0, 1, 1, 1}, yw] + 
     G[{0}, yu^(-1)]*G[{0, 1, 1, yu^(-1)}, yw] + 
     G[{0}, yv^(-1)]*G[{0, 1, 1, yu^(-1)}, yw] - 
     G[{0}, yw]*G[{0, 1, 1, yu^(-1)}, yw] - 2*G[{1}, yv^(-1)]*
      G[{0, 1, 1, yu^(-1)}, yw] - G[{1}, yw]*G[{0, 1, 1, yu^(-1)}, yw] + 
     G[{0}, yu^(-1)]*G[{0, 1, 1, yu}, yv^(-1)] + 
     G[{0}, yv^(-1)]*G[{0, 1, 1, yu}, yv^(-1)] - 
     G[{0}, yw]*G[{0, 1, 1, yu}, yv^(-1)] + G[{1}, yv^(-1)]*
      G[{0, 1, 1, yu}, yv^(-1)] - G[{1}, yw]*G[{0, 1, 1, yu}, yv^(-1)] + 
     2*G[{1}, yv^(-1)]*G[{0, 1, 1, 1/(yu*yv)}, yw] - 
     2*G[{yu}, yv^(-1)]*G[{0, 1, 1, 1/(yu*yv)}, yw] + 
     G[{0}, yu^(-1)]*G[{0, 1, yu^(-1), 1}, yw] + 
     G[{0}, yv^(-1)]*G[{0, 1, yu^(-1), 1}, yw] - 
     G[{0}, yw]*G[{0, 1, yu^(-1), 1}, yw] - G[{1}, yv^(-1)]*
      G[{0, 1, yu^(-1), 1}, yw] - G[{yu}, yv^(-1)]*G[{0, 1, yu^(-1), 1}, 
       yw] - 2*G[{0}, yu^(-1)]*G[{0, 1, yu^(-1), yu^(-1)}, yw] - 
     2*G[{0}, yv^(-1)]*G[{0, 1, yu^(-1), yu^(-1)}, yw] + 
     2*G[{0}, yw]*G[{0, 1, yu^(-1), yu^(-1)}, yw] + 
     4*G[{1}, yv^(-1)]*G[{0, 1, yu^(-1), yu^(-1)}, yw] - 
     2*G[{1}, yw]*G[{0, 1, yu^(-1), yu^(-1)}, yw] - 
     G[{1}, yv^(-1)]*G[{0, 1, yu^(-1), 1/(yu*yv)}, yw] + 
     G[{yu}, yv^(-1)]*G[{0, 1, yu^(-1), 1/(yu*yv)}, yw] + 
     G[{0}, yu^(-1)]*G[{0, 1, yu, 1}, yv^(-1)] + 
     G[{0}, yv^(-1)]*G[{0, 1, yu, 1}, yv^(-1)] - 
     G[{0}, yw]*G[{0, 1, yu, 1}, yv^(-1)] - 2*G[{0}, yu^(-1)]*
      G[{0, 1, yu, yu}, yv^(-1)] - 2*G[{0}, yv^(-1)]*
      G[{0, 1, yu, yu}, yv^(-1)] + 2*G[{0}, yw]*G[{0, 1, yu, yu}, yv^(-1)] + 
     2*G[{1}, yv^(-1)]*G[{0, 1, yu, yu}, yv^(-1)] - 
     2*G[{1}, yw]*G[{0, 1, yu, yu}, yv^(-1)] + G[{1}, yv^(-1)]*
      G[{0, 1, 1/(yu*yv), 1}, yw] - G[{1}, yw]*G[{0, 1, 1/(yu*yv), 1}, yw] - 
     G[{yu}, yv^(-1)]*G[{0, 1, 1/(yu*yv), 1}, yw] + 
     G[{1}, yw]*G[{0, 1, 1/(yu*yv), yu^(-1)}, yw] + 
     G[{0}, yu^(-1)]*G[{0, yu^(-1), 0, yv^(-1)}, yw] + 
     G[{0}, yv^(-1)]*G[{0, yu^(-1), 0, yv^(-1)}, yw] - 
     G[{0}, yw]*G[{0, yu^(-1), 0, yv^(-1)}, yw] - 
     2*G[{1}, yv^(-1)]*G[{0, yu^(-1), 0, yv^(-1)}, yw] + 
     G[{1}, yw]*G[{0, yu^(-1), 0, yv^(-1)}, yw] - 
     G[{0}, yu^(-1)]*G[{0, yu^(-1), 0, 1/(yu*yv)}, yw] - 
     G[{0}, yv^(-1)]*G[{0, yu^(-1), 0, 1/(yu*yv)}, yw] + 
     G[{0}, yw]*G[{0, yu^(-1), 0, 1/(yu*yv)}, yw] + 
     2*G[{1}, yv^(-1)]*G[{0, yu^(-1), 0, 1/(yu*yv)}, yw] - 
     G[{1}, yw]*G[{0, yu^(-1), 0, 1/(yu*yv)}, yw] + 
     G[{0}, yu^(-1)]*G[{0, yu^(-1), 1, 1}, yw] + 
     G[{0}, yv^(-1)]*G[{0, yu^(-1), 1, 1}, yw] - 
     G[{0}, yw]*G[{0, yu^(-1), 1, 1}, yw] - 
     G[{1}, yw]*G[{0, yu^(-1), 1, 1}, yw] - 2*G[{yu}, yv^(-1)]*
      G[{0, yu^(-1), 1, 1}, yw] - 2*G[{0}, yu^(-1)]*
      G[{0, yu^(-1), 1, yu^(-1)}, yw] - 2*G[{0}, yv^(-1)]*
      G[{0, yu^(-1), 1, yu^(-1)}, yw] + 2*G[{0}, yw]*
      G[{0, yu^(-1), 1, yu^(-1)}, yw] + 4*G[{1}, yv^(-1)]*
      G[{0, yu^(-1), 1, yu^(-1)}, yw] - G[{1}, yw]*
      G[{0, yu^(-1), 1, yu^(-1)}, yw] - G[{1}, yv^(-1)]*
      G[{0, yu^(-1), 1, 1/(yu*yv)}, yw] + G[{yu}, yv^(-1)]*
      G[{0, yu^(-1), 1, 1/(yu*yv)}, yw] - 2*G[{0}, yu^(-1)]*
      G[{0, yu^(-1), yu^(-1), 1}, yw] - 2*G[{0}, yv^(-1)]*
      G[{0, yu^(-1), yu^(-1), 1}, yw] + 2*G[{0}, yw]*
      G[{0, yu^(-1), yu^(-1), 1}, yw] + 4*G[{1}, yv^(-1)]*
      G[{0, yu^(-1), yu^(-1), 1}, yw] - 2*G[{1}, yw]*
      G[{0, yu^(-1), yu^(-1), 1}, yw] + 4*G[{1}, yw]*
      G[{0, yu^(-1), yu^(-1), yu^(-1)}, yw] - G[{1}, yv^(-1)]*
      G[{0, yu^(-1), 1/(yu*yv), 1}, yw] + 
     G[{1}, yw]*G[{0, yu^(-1), 1/(yu*yv), 1}, yw] + 
     G[{yu}, yv^(-1)]*G[{0, yu^(-1), 1/(yu*yv), 1}, yw] - 
     G[{1}, yw]*G[{0, yu^(-1), 1/(yu*yv), yu^(-1)}, yw] + 
     G[{0}, yu^(-1)]*G[{0, yu, 1, 1}, yv^(-1)] + 
     G[{0}, yv^(-1)]*G[{0, yu, 1, 1}, yv^(-1)] - 
     G[{0}, yw]*G[{0, yu, 1, 1}, yv^(-1)] + G[{1}, yv^(-1)]*
      G[{0, yu, 1, 1}, yv^(-1)] - G[{1}, yw]*G[{0, yu, 1, 1}, yv^(-1)] - 
     2*G[{0}, yu^(-1)]*G[{0, yu, 1, yu}, yv^(-1)] - 
     2*G[{0}, yv^(-1)]*G[{0, yu, 1, yu}, yv^(-1)] + 
     2*G[{0}, yw]*G[{0, yu, 1, yu}, yv^(-1)] + G[{1}, yv^(-1)]*
      G[{0, yu, 1, yu}, yv^(-1)] - G[{1}, yw]*G[{0, yu, 1, yu}, yv^(-1)] - 
     2*G[{0}, yu^(-1)]*G[{0, yu, yu, 1}, yv^(-1)] - 
     2*G[{0}, yv^(-1)]*G[{0, yu, yu, 1}, yv^(-1)] + 
     2*G[{0}, yw]*G[{0, yu, yu, 1}, yv^(-1)] + 2*G[{1}, yv^(-1)]*
      G[{0, yu, yu, 1}, yv^(-1)] - 2*G[{1}, yw]*G[{0, yu, yu, 1}, yv^(-1)] - 
     4*G[{1}, yv^(-1)]*G[{0, yu, yu, yu}, yv^(-1)] + 
     4*G[{1}, yw]*G[{0, yu, yu, yu}, yv^(-1)] - G[{0}, yu^(-1)]*
      G[{0, yv^(-1), 1, 1}, yw] - G[{0}, yv^(-1)]*G[{0, yv^(-1), 1, 1}, yw] + 
     G[{0}, yw]*G[{0, yv^(-1), 1, 1}, yw] + G[{1}, yv^(-1)]*
      G[{0, yv^(-1), 1, 1}, yw] - G[{1}, yw]*G[{0, yv^(-1), 1, 1}, yw] + 
     G[{yu}, yv^(-1)]*G[{0, yv^(-1), 1, 1}, yw] + 
     G[{0}, yu^(-1)]*G[{0, yv^(-1), 1, yu^(-1)}, yw] + 
     G[{0}, yv^(-1)]*G[{0, yv^(-1), 1, yu^(-1)}, yw] - 
     G[{0}, yw]*G[{0, yv^(-1), 1, yu^(-1)}, yw] - 
     2*G[{1}, yv^(-1)]*G[{0, yv^(-1), 1, yu^(-1)}, yw] + 
     G[{1}, yw]*G[{0, yv^(-1), 1, yu^(-1)}, yw] - 
     2*G[{0}, yu^(-1)]*G[{0, yv^(-1), yv^(-1), 1}, yw] - 
     2*G[{0}, yv^(-1)]*G[{0, yv^(-1), yv^(-1), 1}, yw] + 
     2*G[{0}, yw]*G[{0, yv^(-1), yv^(-1), 1}, yw] + 
     2*G[{1}, yv^(-1)]*G[{0, yv^(-1), yv^(-1), 1}, yw] - 
     2*G[{1}, yw]*G[{0, yv^(-1), yv^(-1), 1}, yw] + 
     2*G[{yu}, yv^(-1)]*G[{0, yv^(-1), yv^(-1), 1}, yw] - 
     2*G[{0}, yu^(-1)]*G[{0, yv^(-1), yv^(-1), 1/(yu*yv)}, yw] - 
     2*G[{0}, yv^(-1)]*G[{0, yv^(-1), yv^(-1), 1/(yu*yv)}, yw] + 
     2*G[{0}, yw]*G[{0, yv^(-1), yv^(-1), 1/(yu*yv)}, yw] + 
     4*G[{1}, yu^(-1)]*G[{0, yv^(-1), yv^(-1), 1/(yu*yv)}, yw] + 
     2*G[{1}, yv^(-1)]*G[{0, yv^(-1), yv^(-1), 1/(yu*yv)}, yw] - 
     2*G[{yu}, yv^(-1)]*G[{0, yv^(-1), yv^(-1), 1/(yu*yv)}, yw] + 
     G[{0}, yu^(-1)]*G[{0, yv^(-1), 1/(yu*yv), 1}, yw] + 
     G[{0}, yv^(-1)]*G[{0, yv^(-1), 1/(yu*yv), 1}, yw] - 
     G[{0}, yw]*G[{0, yv^(-1), 1/(yu*yv), 1}, yw] + 
     G[{1}, yw]*G[{0, yv^(-1), 1/(yu*yv), 1}, yw] - 
     2*G[{yu}, yv^(-1)]*G[{0, yv^(-1), 1/(yu*yv), 1}, yw] + 
     G[{0}, yu^(-1)]*G[{0, yv^(-1), 1/(yu*yv), yu^(-1)}, yw] + 
     G[{0}, yv^(-1)]*G[{0, yv^(-1), 1/(yu*yv), yu^(-1)}, yw] - 
     G[{0}, yw]*G[{0, yv^(-1), 1/(yu*yv), yu^(-1)}, yw] - 
     2*G[{1}, yv^(-1)]*G[{0, yv^(-1), 1/(yu*yv), yu^(-1)}, yw] + 
     G[{1}, yw]*G[{0, yv^(-1), 1/(yu*yv), yu^(-1)}, yw] - 
     2*G[{0}, yu^(-1)]*G[{0, yv^(-1), 1/(yu*yv), yv^(-1)}, yw] - 
     2*G[{0}, yv^(-1)]*G[{0, yv^(-1), 1/(yu*yv), yv^(-1)}, yw] + 
     2*G[{0}, yw]*G[{0, yv^(-1), 1/(yu*yv), yv^(-1)}, yw] + 
     4*G[{1}, yu^(-1)]*G[{0, yv^(-1), 1/(yu*yv), yv^(-1)}, yw] + 
     G[{0}, yu^(-1)]*G[{0, yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] + 
     G[{0}, yv^(-1)]*G[{0, yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] - 
     G[{0}, yw]*G[{0, yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] - 
     2*G[{1}, yu^(-1)]*G[{0, yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] - 
     G[{1}, yv^(-1)]*G[{0, yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] + 
     G[{yu}, yv^(-1)]*G[{0, yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] - 
     3*G[{0}, yu^(-1)]*G[{0, 1/(yu*yv), 1, 1}, yw] - 
     3*G[{0}, yv^(-1)]*G[{0, 1/(yu*yv), 1, 1}, yw] + 
     3*G[{0}, yw]*G[{0, 1/(yu*yv), 1, 1}, yw] + 2*G[{1}, yv^(-1)]*
      G[{0, 1/(yu*yv), 1, 1}, yw] - G[{1}, yw]*G[{0, 1/(yu*yv), 1, 1}, yw] + 
     4*G[{yu}, yv^(-1)]*G[{0, 1/(yu*yv), 1, 1}, yw] + 
     G[{1}, yw]*G[{0, 1/(yu*yv), 1, yu^(-1)}, yw] - 
     G[{1}, yv^(-1)]*G[{0, 1/(yu*yv), 1, 1/(yu*yv)}, yw] + 
     G[{yu}, yv^(-1)]*G[{0, 1/(yu*yv), 1, 1/(yu*yv)}, yw] + 
     G[{0}, yu^(-1)]*G[{0, 1/(yu*yv), yu^(-1), 1}, yw] + 
     G[{0}, yv^(-1)]*G[{0, 1/(yu*yv), yu^(-1), 1}, yw] - 
     G[{0}, yw]*G[{0, 1/(yu*yv), yu^(-1), 1}, yw] - 
     3*G[{1}, yv^(-1)]*G[{0, 1/(yu*yv), yu^(-1), 1}, yw] + 
     2*G[{1}, yw]*G[{0, 1/(yu*yv), yu^(-1), 1}, yw] + 
     G[{yu}, yv^(-1)]*G[{0, 1/(yu*yv), yu^(-1), 1}, yw] + 
     2*G[{0}, yu^(-1)]*G[{0, 1/(yu*yv), yu^(-1), yu^(-1)}, yw] + 
     2*G[{0}, yv^(-1)]*G[{0, 1/(yu*yv), yu^(-1), yu^(-1)}, yw] - 
     2*G[{0}, yw]*G[{0, 1/(yu*yv), yu^(-1), yu^(-1)}, yw] - 
     4*G[{1}, yv^(-1)]*G[{0, 1/(yu*yv), yu^(-1), yu^(-1)}, yw] - 
     2*G[{1}, yw]*G[{0, 1/(yu*yv), yu^(-1), yu^(-1)}, yw] + 
     G[{1}, yv^(-1)]*G[{0, 1/(yu*yv), yu^(-1), 1/(yu*yv)}, yw] - 
     G[{yu}, yv^(-1)]*G[{0, 1/(yu*yv), yu^(-1), 1/(yu*yv)}, yw] + 
     2*G[{0}, yu^(-1)]*G[{0, 1/(yu*yv), yv^(-1), 1}, yw] + 
     2*G[{0}, yv^(-1)]*G[{0, 1/(yu*yv), yv^(-1), 1}, yw] - 
     2*G[{0}, yw]*G[{0, 1/(yu*yv), yv^(-1), 1}, yw] - 
     2*G[{1}, yv^(-1)]*G[{0, 1/(yu*yv), yv^(-1), 1}, yw] + 
     2*G[{1}, yw]*G[{0, 1/(yu*yv), yv^(-1), 1}, yw] - 
     2*G[{yu}, yv^(-1)]*G[{0, 1/(yu*yv), yv^(-1), 1}, yw] + 
     2*G[{0}, yu^(-1)]*G[{0, 1/(yu*yv), yv^(-1), 1/(yu*yv)}, yw] + 
     2*G[{0}, yv^(-1)]*G[{0, 1/(yu*yv), yv^(-1), 1/(yu*yv)}, yw] - 
     2*G[{0}, yw]*G[{0, 1/(yu*yv), yv^(-1), 1/(yu*yv)}, yw] - 
     4*G[{1}, yu^(-1)]*G[{0, 1/(yu*yv), yv^(-1), 1/(yu*yv)}, yw] - 
     2*G[{1}, yv^(-1)]*G[{0, 1/(yu*yv), yv^(-1), 1/(yu*yv)}, yw] + 
     2*G[{yu}, yv^(-1)]*G[{0, 1/(yu*yv), yv^(-1), 1/(yu*yv)}, yw] - 
     G[{0}, yu^(-1)]*G[{0, 1/(yu*yv), 1/(yu*yv), 1}, yw] - 
     G[{0}, yv^(-1)]*G[{0, 1/(yu*yv), 1/(yu*yv), 1}, yw] + 
     G[{0}, yw]*G[{0, 1/(yu*yv), 1/(yu*yv), 1}, yw] - 
     G[{1}, yw]*G[{0, 1/(yu*yv), 1/(yu*yv), 1}, yw] + 
     2*G[{yu}, yv^(-1)]*G[{0, 1/(yu*yv), 1/(yu*yv), 1}, yw] - 
     G[{0}, yu^(-1)]*G[{0, 1/(yu*yv), 1/(yu*yv), yu^(-1)}, yw] - 
     G[{0}, yv^(-1)]*G[{0, 1/(yu*yv), 1/(yu*yv), yu^(-1)}, yw] + 
     G[{0}, yw]*G[{0, 1/(yu*yv), 1/(yu*yv), yu^(-1)}, yw] + 
     2*G[{1}, yv^(-1)]*G[{0, 1/(yu*yv), 1/(yu*yv), yu^(-1)}, yw] - 
     G[{1}, yw]*G[{0, 1/(yu*yv), 1/(yu*yv), yu^(-1)}, yw] + 
     2*G[{0}, yu^(-1)]*G[{0, 1/(yu*yv), 1/(yu*yv), yv^(-1)}, yw] + 
     2*G[{0}, yv^(-1)]*G[{0, 1/(yu*yv), 1/(yu*yv), yv^(-1)}, yw] - 
     2*G[{0}, yw]*G[{0, 1/(yu*yv), 1/(yu*yv), yv^(-1)}, yw] - 
     4*G[{1}, yu^(-1)]*G[{0, 1/(yu*yv), 1/(yu*yv), yv^(-1)}, yw] - 
     G[{0}, yu^(-1)]*G[{0, 1/(yu*yv), 1/(yu*yv), 1/(yu*yv)}, yw] - 
     G[{0}, yv^(-1)]*G[{0, 1/(yu*yv), 1/(yu*yv), 1/(yu*yv)}, yw] + 
     G[{0}, yw]*G[{0, 1/(yu*yv), 1/(yu*yv), 1/(yu*yv)}, yw] + 
     2*G[{1}, yu^(-1)]*G[{0, 1/(yu*yv), 1/(yu*yv), 1/(yu*yv)}, yw] + 
     G[{1}, yv^(-1)]*G[{0, 1/(yu*yv), 1/(yu*yv), 1/(yu*yv)}, yw] - 
     G[{yu}, yv^(-1)]*G[{0, 1/(yu*yv), 1/(yu*yv), 1/(yu*yv)}, yw] + 
     6*G[{0, 0, 0, 0, 1}, yw] - 6*G[{0, 0, 0, 0, yu^(-1)}, yw] - 
     6*G[{0, 0, 0, 0, yv^(-1)}, yw] + 6*G[{0, 0, 0, 0, 1/(yu*yv)}, yw] - 
     4*G[{0, 0, 0, 1, 1}, yu^(-1)] + 6*G[{0, 0, 0, 1, 1}, yw] - 
     3*G[{0, 0, 0, 1, yv^(-1)}, yw] + 3*G[{0, 0, 0, 1, 1/(yu*yv)}, yw] - 
     6*G[{0, 0, 0, yu^(-1), yu^(-1)}, yw] + 
     3*G[{0, 0, 0, yu^(-1), yv^(-1)}, yw] - 
     3*G[{0, 0, 0, yu^(-1), 1/(yu*yv)}, yw] - 
     3*G[{0, 0, 0, yv^(-1), 1}, yw] + 3*G[{0, 0, 0, yv^(-1), yu^(-1)}, yw] - 
     6*G[{0, 0, 0, yv^(-1), 1/(yu*yv)}, yw] - 
     3*G[{0, 0, 0, 1/(yu*yv), 1}, yw] + 3*G[{0, 0, 0, 1/(yu*yv), yu^(-1)}, 
       yw] + 6*G[{0, 0, 0, 1/(yu*yv), 1/(yu*yv)}, yw] - 
     2*G[{0, 0, 1, 0, 1}, yu^(-1)] - G[{0, 0, 1, 0, yv^(-1)}, yw] + 
     G[{0, 0, 1, 0, 1/(yu*yv)}, yw] - 6*G[{0, 0, 1, 1, 1}, yu^(-1)] + 
     12*G[{0, 0, 1, 1, 1}, yv^(-1)] + 3*G[{0, 0, 1, 1, 1}, yw] + 
     3*G[{0, 0, 1, 1, yu^(-1)}, yw] - 4*G[{0, 0, 1, 1, yu}, yv^(-1)] + 
     2*G[{0, 0, 1, 1, yv^(-1)}, yw] - 2*G[{0, 0, 1, 1, 1/(yu*yv)}, yw] + 
     2*G[{0, 0, 1, yu^(-1), 1}, yw] - 2*G[{0, 0, 1, yu^(-1), yu^(-1)}, yw] - 
     2*G[{0, 0, 1, yu^(-1), yv^(-1)}, yw] + 
     2*G[{0, 0, 1, yu^(-1), 1/(yu*yv)}, yw] - 
     4*G[{0, 0, 1, yu, 1}, yv^(-1)] + 2*G[{0, 0, 1, yv^(-1), 1}, yw] - 
     2*G[{0, 0, 1, yv^(-1), yu^(-1)}, yw] - 
     4*G[{0, 0, 1, yv^(-1), yv^(-1)}, yw] + 
     2*G[{0, 0, 1, yv^(-1), 1/(yu*yv)}, yw] - G[{0, 0, 1, 1/(yu*yv), 1}, 
      yw] + G[{0, 0, 1, 1/(yu*yv), yu^(-1)}, yw] - 
     2*G[{0, 0, 1, 1/(yu*yv), 1/(yu*yv)}, yw] + 
     G[{0, 0, yu^(-1), 0, yv^(-1)}, yw] - G[{0, 0, yu^(-1), 0, 1/(yu*yv)}, 
      yw] + 3*G[{0, 0, yu^(-1), 1, 1}, yw] - 
     3*G[{0, 0, yu^(-1), 1, yu^(-1)}, yw] - 
     2*G[{0, 0, yu^(-1), yu^(-1), 1}, yw] - 
     4*G[{0, 0, yu^(-1), yu^(-1), yu^(-1)}, yw] + 
     4*G[{0, 0, yu^(-1), yu^(-1), yv^(-1)}, yw] - 
     4*G[{0, 0, yu^(-1), yu^(-1), 1/(yu*yv)}, yw] - 
     2*G[{0, 0, yu^(-1), yv^(-1), 1}, yw] + 
     4*G[{0, 0, yu^(-1), yv^(-1), yu^(-1)}, yw] + 
     4*G[{0, 0, yu^(-1), yv^(-1), yv^(-1)}, yw] + 
     G[{0, 0, yu^(-1), 1/(yu*yv), 1}, yw] - 
     3*G[{0, 0, yu^(-1), 1/(yu*yv), yu^(-1)}, yw] + 
     2*G[{0, 0, yu^(-1), 1/(yu*yv), yv^(-1)}, yw] + 
     2*G[{0, 0, yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] - 
     4*G[{0, 0, yu, 1, 1}, yv^(-1)] + 2*G[{0, 0, yu, 1, yu}, yv^(-1)] + 
     4*G[{0, 0, yu, yu, 1}, yv^(-1)] - G[{0, 0, yv^(-1), 0, 1}, yw] + 
     G[{0, 0, yv^(-1), 0, yu^(-1)}, yw] + 
     2*G[{0, 0, yv^(-1), 0, yv^(-1)}, yw] - 
     2*G[{0, 0, yv^(-1), 0, 1/(yu*yv)}, yw] + G[{0, 0, yv^(-1), 1, 1}, yw] - 
     3*G[{0, 0, yv^(-1), 1, yu^(-1)}, yw] - 
     2*G[{0, 0, yv^(-1), yu^(-1), 1}, yw] + 
     4*G[{0, 0, yv^(-1), yu^(-1), yu^(-1)}, yw] + 
     2*G[{0, 0, yv^(-1), yv^(-1), 1}, yw] - 
     4*G[{0, 0, yv^(-1), yv^(-1), yu^(-1)}, yw] - 
     12*G[{0, 0, yv^(-1), yv^(-1), yv^(-1)}, yw] - 
     4*G[{0, 0, yv^(-1), yv^(-1), 1/(yu*yv)}, yw] + 
     G[{0, 0, yv^(-1), 1/(yu*yv), 1}, yw] - 
     G[{0, 0, yv^(-1), 1/(yu*yv), yu^(-1)}, yw] - 
     2*G[{0, 0, yv^(-1), 1/(yu*yv), yv^(-1)}, yw] + 
     4*G[{0, 0, yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] + 
     G[{0, 0, 1/(yu*yv), 0, 1}, yw] - G[{0, 0, 1/(yu*yv), 0, yu^(-1)}, yw] - 
     2*G[{0, 0, 1/(yu*yv), 0, yv^(-1)}, yw] + 
     2*G[{0, 0, 1/(yu*yv), 0, 1/(yu*yv)}, yw] - 
     7*G[{0, 0, 1/(yu*yv), 1, 1}, yw] + 3*G[{0, 0, 1/(yu*yv), 1, yu^(-1)}, 
       yw] + 2*G[{0, 0, 1/(yu*yv), yu^(-1), 1}, yw] + 
     2*G[{0, 0, 1/(yu*yv), yu^(-1), yu^(-1)}, yw] + 
     4*G[{0, 0, 1/(yu*yv), yv^(-1), yv^(-1)}, yw] + 
     G[{0, 0, 1/(yu*yv), 1/(yu*yv), 1}, yw] - 
     3*G[{0, 0, 1/(yu*yv), 1/(yu*yv), yu^(-1)}, yw] - 
     6*G[{0, 0, 1/(yu*yv), 1/(yu*yv), yv^(-1)}, yw] + 
     4*G[{0, 0, 1/(yu*yv), 1/(yu*yv), 1/(yu*yv)}, yw] - 
     2*G[{0, 1, 0, 1, 1}, yu^(-1)] + 4*G[{0, 1, 0, 1, 1}, yv^(-1)] - 
     G[{0, 1, 0, 1, yu}, yv^(-1)] + G[{0, 1, 0, 1, yv^(-1)}, yw] - 
     G[{0, 1, 0, 1, 1/(yu*yv)}, yw] - G[{0, 1, 0, yu^(-1), yv^(-1)}, yw] + 
     G[{0, 1, 0, yu^(-1), 1/(yu*yv)}, yw] - G[{0, 1, 0, yu, 1}, yv^(-1)] + 
     G[{0, 1, 0, yv^(-1), 1}, yw] - G[{0, 1, 0, yv^(-1), yu^(-1)}, yw] - 
     2*G[{0, 1, 0, yv^(-1), yv^(-1)}, yw] + G[{0, 1, 0, yv^(-1), 1/(yu*yv)}, 
      yw] - G[{0, 1, 0, 1/(yu*yv), 1}, yw] + G[{0, 1, 0, 1/(yu*yv), yu^(-1)}, 
      yw] - G[{0, 1, 0, 1/(yu*yv), 1/(yu*yv)}, yw] + 
     2*G[{0, 1, 1, 0, yu}, yv^(-1)] + G[{0, 1, 1, 0, yv^(-1)}, yw] - 
     G[{0, 1, 1, 0, 1/(yu*yv)}, yw] - 6*G[{0, 1, 1, 1, 1}, yu^(-1)] + 
     3*G[{0, 1, 1, 1, yu^(-1)}, yw] - 3*G[{0, 1, 1, 1, yu}, yv^(-1)] + 
     G[{0, 1, 1, yu^(-1), 1}, yw] + 2*G[{0, 1, 1, yu^(-1), yu^(-1)}, yw] - 
     G[{0, 1, 1, yu, 1}, yv^(-1)] - 2*G[{0, 1, 1, yu, yu}, yv^(-1)] + 
     2*G[{0, 1, 1, 1/(yu*yv), 1}, yw] - 2*G[{0, 1, 1, 1/(yu*yv), yu^(-1)}, 
       yw] - 2*G[{0, 1, yu^(-1), 0, yv^(-1)}, yw] + 
     2*G[{0, 1, yu^(-1), 0, 1/(yu*yv)}, yw] + G[{0, 1, yu^(-1), 1, 1}, yw] + 
     G[{0, 1, yu^(-1), 1, yu^(-1)}, yw] + 
     2*G[{0, 1, yu^(-1), yu^(-1), 1}, yw] - 
     4*G[{0, 1, yu^(-1), yu^(-1), yu^(-1)}, yw] - 
     G[{0, 1, yu^(-1), 1/(yu*yv), 1}, yw] + 
     G[{0, 1, yu^(-1), 1/(yu*yv), yu^(-1)}, yw] - G[{0, 1, yu, 0, yu}, 
      yv^(-1)] - G[{0, 1, yu, 1, 1}, yv^(-1)] - G[{0, 1, yu, 1, yu}, 
      yv^(-1)] - 2*G[{0, 1, yu, yu, 1}, yv^(-1)] + 
     4*G[{0, 1, yu, yu, yu}, yv^(-1)] + G[{0, 1, yv^(-1), 0, yu^(-1)}, yw] - 
     2*G[{0, 1, yv^(-1), 0, yv^(-1)}, yw] + 
     2*G[{0, 1, yv^(-1), 0, 1/(yu*yv)}, yw] - 
     G[{0, 1, 1/(yu*yv), 0, yu^(-1)}, yw] - 
     G[{0, 1, 1/(yu*yv), 0, 1/(yu*yv)}, yw] + 
     2*G[{0, 1, 1/(yu*yv), 1, 1}, yw] - G[{0, 1, 1/(yu*yv), 1, yu^(-1)}, 
      yw] - G[{0, 1, 1/(yu*yv), yu^(-1), 1}, yw] + 
     2*G[{0, yu^(-1), 0, yu^(-1), yv^(-1)}, yw] - 
     2*G[{0, yu^(-1), 0, yu^(-1), 1/(yu*yv)}, yw] - 
     G[{0, yu^(-1), 0, yv^(-1), 1}, yw] + 
     2*G[{0, yu^(-1), 0, yv^(-1), yu^(-1)}, yw] + 
     2*G[{0, yu^(-1), 0, yv^(-1), yv^(-1)}, yw] + 
     G[{0, yu^(-1), 0, 1/(yu*yv), 1}, yw] - 
     2*G[{0, yu^(-1), 0, 1/(yu*yv), yu^(-1)}, yw] + 
     G[{0, yu^(-1), 0, 1/(yu*yv), yv^(-1)}, yw] + 
     G[{0, yu^(-1), 0, 1/(yu*yv), 1/(yu*yv)}, yw] - 
     G[{0, yu^(-1), 1, 0, yv^(-1)}, yw] + G[{0, yu^(-1), 1, 0, 1/(yu*yv)}, 
      yw] + 3*G[{0, yu^(-1), 1, 1, 1}, yw] + G[{0, yu^(-1), 1, yu^(-1), 1}, 
      yw] - 4*G[{0, yu^(-1), 1, yu^(-1), yu^(-1)}, yw] - 
     G[{0, yu^(-1), 1, 1/(yu*yv), 1}, yw] + 
     G[{0, yu^(-1), 1, 1/(yu*yv), yu^(-1)}, yw] + 
     2*G[{0, yu^(-1), yu^(-1), 0, yv^(-1)}, yw] - 
     2*G[{0, yu^(-1), yu^(-1), 0, 1/(yu*yv)}, yw] + 
     2*G[{0, yu^(-1), yu^(-1), 1, 1}, yw] - 
     4*G[{0, yu^(-1), yu^(-1), 1, yu^(-1)}, yw] - 
     4*G[{0, yu^(-1), yu^(-1), yu^(-1), 1}, yw] + 
     2*G[{0, yu^(-1), yv^(-1), 0, yv^(-1)}, yw] - 
     2*G[{0, yu^(-1), yv^(-1), 0, 1/(yu*yv)}, yw] + 
     G[{0, yu^(-1), 1/(yu*yv), 0, yv^(-1)}, yw] + 
     G[{0, yu^(-1), 1/(yu*yv), 0, 1/(yu*yv)}, yw] - 
     2*G[{0, yu^(-1), 1/(yu*yv), 1, 1}, yw] + 
     G[{0, yu^(-1), 1/(yu*yv), 1, yu^(-1)}, yw] + 
     G[{0, yu^(-1), 1/(yu*yv), yu^(-1), 1}, yw] + G[{0, yu, 0, yu, 1}, 
      yv^(-1)] - 3*G[{0, yu, 1, 1, 1}, yv^(-1)] - G[{0, yu, 1, yu, 1}, 
      yv^(-1)] + 4*G[{0, yu, 1, yu, yu}, yv^(-1)] - 
     2*G[{0, yu, yu, 1, 1}, yv^(-1)] + 4*G[{0, yu, yu, 1, yu}, yv^(-1)] + 
     4*G[{0, yu, yu, yu, 1}, yv^(-1)] + G[{0, yv^(-1), 0, yv^(-1), 1}, yw] - 
     2*G[{0, yv^(-1), 0, yv^(-1), yu^(-1)}, yw] - 
     4*G[{0, yv^(-1), 0, yv^(-1), yv^(-1)}, yw] - 
     2*G[{0, yv^(-1), 0, yv^(-1), 1/(yu*yv)}, yw] + 
     2*G[{0, yv^(-1), 0, 1/(yu*yv), 1/(yu*yv)}, yw] + 
     G[{0, yv^(-1), 1, 0, 1/(yu*yv)}, yw] - G[{0, yv^(-1), 1, 1, yu^(-1)}, 
      yw] - G[{0, yv^(-1), 1, yu^(-1), 1}, yw] + 
     2*G[{0, yv^(-1), 1, yu^(-1), yu^(-1)}, yw] - 
     2*G[{0, yv^(-1), yu^(-1), 0, 1/(yu*yv)}, yw] - 
     4*G[{0, yv^(-1), yv^(-1), 0, 1/(yu*yv)}, yw] - 
     2*G[{0, yv^(-1), yv^(-1), 1, yu^(-1)}, yw] + 
     2*G[{0, yv^(-1), yv^(-1), 1/(yu*yv), 1}, yw] - 
     2*G[{0, yv^(-1), yv^(-1), 1/(yu*yv), yu^(-1)}, yw] - 
     4*G[{0, yv^(-1), yv^(-1), 1/(yu*yv), yv^(-1)}, yw] + 
     2*G[{0, yv^(-1), 1/(yu*yv), 0, 1/(yu*yv)}, yw] + 
     G[{0, yv^(-1), 1/(yu*yv), 1, 1}, yw] - 
     G[{0, yv^(-1), 1/(yu*yv), yu^(-1), 1}, yw] + 
     2*G[{0, yv^(-1), 1/(yu*yv), yu^(-1), yu^(-1)}, yw] - 
     4*G[{0, yv^(-1), 1/(yu*yv), yv^(-1), yv^(-1)}, yw] - 
     G[{0, yv^(-1), 1/(yu*yv), 1/(yu*yv), 1}, yw] + 
     G[{0, yv^(-1), 1/(yu*yv), 1/(yu*yv), yu^(-1)}, yw] + 
     2*G[{0, yv^(-1), 1/(yu*yv), 1/(yu*yv), yv^(-1)}, yw] + 
     G[{0, 1/(yu*yv), 0, 1/(yu*yv), 1}, yw] - 
     2*G[{0, 1/(yu*yv), 0, 1/(yu*yv), yu^(-1)}, yw] - 
     4*G[{0, 1/(yu*yv), 0, 1/(yu*yv), yv^(-1)}, yw] + 
     2*G[{0, 1/(yu*yv), 0, 1/(yu*yv), 1/(yu*yv)}, yw] - 
     3*G[{0, 1/(yu*yv), 1, 1, 1}, yw] - 2*G[{0, 1/(yu*yv), 1, 1, yu^(-1)}, 
       yw] - G[{0, 1/(yu*yv), 1, yu^(-1), 1}, yw] - 
     G[{0, 1/(yu*yv), 1, 1/(yu*yv), 1}, yw] + 
     G[{0, 1/(yu*yv), 1, 1/(yu*yv), yu^(-1)}, yw] - 
     3*G[{0, 1/(yu*yv), yu^(-1), 1, 1}, yw] + 
     3*G[{0, 1/(yu*yv), yu^(-1), 1, yu^(-1)}, yw] + 
     2*G[{0, 1/(yu*yv), yu^(-1), yu^(-1), 1}, yw] + 
     4*G[{0, 1/(yu*yv), yu^(-1), yu^(-1), yu^(-1)}, yw] + 
     G[{0, 1/(yu*yv), yu^(-1), 1/(yu*yv), 1}, yw] - 
     G[{0, 1/(yu*yv), yu^(-1), 1/(yu*yv), yu^(-1)}, yw] + 
     2*G[{0, 1/(yu*yv), yv^(-1), 1, yu^(-1)}, yw] - 
     2*G[{0, 1/(yu*yv), yv^(-1), 1/(yu*yv), 1}, yw] + 
     2*G[{0, 1/(yu*yv), yv^(-1), 1/(yu*yv), yu^(-1)}, yw] + 
     4*G[{0, 1/(yu*yv), yv^(-1), 1/(yu*yv), yv^(-1)}, yw] - 
     G[{0, 1/(yu*yv), 1/(yu*yv), 1, 1}, yw] + 
     G[{0, 1/(yu*yv), 1/(yu*yv), yu^(-1), 1}, yw] - 
     2*G[{0, 1/(yu*yv), 1/(yu*yv), yu^(-1), yu^(-1)}, yw] + 
     4*G[{0, 1/(yu*yv), 1/(yu*yv), yv^(-1), yv^(-1)}, yw] + 
     G[{0, 1/(yu*yv), 1/(yu*yv), 1/(yu*yv), 1}, yw] - 
     G[{0, 1/(yu*yv), 1/(yu*yv), 1/(yu*yv), yu^(-1)}, yw] - 
     2*G[{0, 1/(yu*yv), 1/(yu*yv), 1/(yu*yv), yv^(-1)}, yw] + 
     (Pi^2*Zeta[3])/3 + G[{0}, yu^(-1)]^2*Zeta[3] + 
     2*G[{0}, yu^(-1)]*G[{0}, yv^(-1)]*Zeta[3] + G[{0}, yv^(-1)]^2*Zeta[3] - 
     2*G[{0}, yu^(-1)]*G[{0}, yw]*Zeta[3] - 2*G[{0}, yv^(-1)]*G[{0}, yw]*
      Zeta[3] + G[{0}, yw]^2*Zeta[3] - G[{1}, yv^(-1)]^2*Zeta[3] + 
     2*G[{1}, yv^(-1)]*G[{1}, yw]*Zeta[3] - G[{1}, yw]^2*Zeta[3] - 
     2*G[{0, 1}, yu^(-1)]*Zeta[3] + 2*G[{0, yv^(-1)}, yw]*Zeta[3] - 
     2*G[{0, 1/(yu*yv)}, yw]*Zeta[3] + 2*Zeta[5]
 
J1uvwRegII = (Pi^4*G[{0}, yu^(-1)])/30 - (Pi^2*G[{0}, yu^(-1)]^3)/9 + 
     (Pi^4*G[{0}, yv^(-1)])/30 - (Pi^2*G[{0}, yu^(-1)]^2*G[{0}, yv^(-1)])/3 - 
     (Pi^2*G[{0}, yu^(-1)]*G[{0}, yv^(-1)]^2)/3 - (Pi^2*G[{0}, yv^(-1)]^3)/
      9 - (Pi^4*G[{0}, yw])/30 + (Pi^2*G[{0}, yu^(-1)]^2*G[{0}, yw])/3 + 
     (2*Pi^2*G[{0}, yu^(-1)]*G[{0}, yv^(-1)]*G[{0}, yw])/3 + 
     (Pi^2*G[{0}, yv^(-1)]^2*G[{0}, yw])/3 - 
     (Pi^2*G[{0}, yu^(-1)]*G[{0}, yw]^2)/3 - 
     (Pi^2*G[{0}, yv^(-1)]*G[{0}, yw]^2)/3 + (Pi^2*G[{0}, yw]^3)/9 + 
     (Pi^4*G[{1}, yu^(-1)])/18 + (Pi^2*G[{0}, yu^(-1)]^2*G[{1}, yu^(-1)])/3 + 
     (2*Pi^2*G[{0}, yu^(-1)]*G[{0}, yv^(-1)]*G[{1}, yu^(-1)])/3 + 
     (Pi^2*G[{0}, yv^(-1)]^2*G[{1}, yu^(-1)])/3 - 
     (2*Pi^2*G[{0}, yu^(-1)]*G[{0}, yw]*G[{1}, yu^(-1)])/3 - 
     (2*Pi^2*G[{0}, yv^(-1)]*G[{0}, yw]*G[{1}, yu^(-1)])/3 + 
     (Pi^2*G[{0}, yw]^2*G[{1}, yu^(-1)])/3 - 
     (Pi^2*G[{0}, yu^(-1)]*G[{1}, yu^(-1)]^2)/3 - 
     (Pi^2*G[{0}, yv^(-1)]*G[{1}, yu^(-1)]^2)/3 + 
     (Pi^2*G[{0}, yw]*G[{1}, yu^(-1)]^2)/3 - (Pi^4*G[{1}, yw])/18 - 
     (Pi^2*G[{0}, yu^(-1)]^2*G[{1}, yw])/3 - 
     (2*Pi^2*G[{0}, yu^(-1)]*G[{0}, yv^(-1)]*G[{1}, yw])/3 - 
     (Pi^2*G[{0}, yv^(-1)]^2*G[{1}, yw])/3 + 
     (2*Pi^2*G[{0}, yu^(-1)]*G[{0}, yw]*G[{1}, yw])/3 + 
     (2*Pi^2*G[{0}, yv^(-1)]*G[{0}, yw]*G[{1}, yw])/3 - 
     (Pi^2*G[{0}, yw]^2*G[{1}, yw])/3 + 
     (2*Pi^2*G[{0}, yu^(-1)]*G[{1}, yu^(-1)]*G[{1}, yw])/3 + 
     (2*Pi^2*G[{0}, yv^(-1)]*G[{1}, yu^(-1)]*G[{1}, yw])/3 - 
     (2*Pi^2*G[{0}, yw]*G[{1}, yu^(-1)]*G[{1}, yw])/3 - 
     (Pi^2*G[{0}, yu^(-1)]*G[{1}, yw]^2)/3 - 
     (Pi^2*G[{0}, yv^(-1)]*G[{1}, yw]^2)/3 + (Pi^2*G[{0}, yw]*G[{1}, yw]^2)/
      3 - (2*G[{0}, yu^(-1)]^3*G[{0, 1}, yu^(-1)])/3 - 
     2*G[{0}, yu^(-1)]^2*G[{0}, yv^(-1)]*G[{0, 1}, yu^(-1)] - 
     2*G[{0}, yu^(-1)]*G[{0}, yv^(-1)]^2*G[{0, 1}, yu^(-1)] - 
     (2*G[{0}, yv^(-1)]^3*G[{0, 1}, yu^(-1)])/3 + 2*G[{0}, yu^(-1)]^2*
      G[{0}, yw]*G[{0, 1}, yu^(-1)] + 4*G[{0}, yu^(-1)]*G[{0}, yv^(-1)]*
      G[{0}, yw]*G[{0, 1}, yu^(-1)] + 2*G[{0}, yv^(-1)]^2*G[{0}, yw]*
      G[{0, 1}, yu^(-1)] - 2*G[{0}, yu^(-1)]*G[{0}, yw]^2*
      G[{0, 1}, yu^(-1)] - 2*G[{0}, yv^(-1)]*G[{0}, yw]^2*
      G[{0, 1}, yu^(-1)] + (2*G[{0}, yw]^3*G[{0, 1}, yu^(-1)])/3 + 
     (4*Pi^2*G[{1}, yu^(-1)]*G[{0, 1}, yu^(-1)])/3 + 
     2*G[{0}, yu^(-1)]^2*G[{1}, yu^(-1)]*G[{0, 1}, yu^(-1)] + 
     4*G[{0}, yu^(-1)]*G[{0}, yv^(-1)]*G[{1}, yu^(-1)]*G[{0, 1}, yu^(-1)] + 
     2*G[{0}, yv^(-1)]^2*G[{1}, yu^(-1)]*G[{0, 1}, yu^(-1)] - 
     4*G[{0}, yu^(-1)]*G[{0}, yw]*G[{1}, yu^(-1)]*G[{0, 1}, yu^(-1)] - 
     4*G[{0}, yv^(-1)]*G[{0}, yw]*G[{1}, yu^(-1)]*G[{0, 1}, yu^(-1)] + 
     2*G[{0}, yw]^2*G[{1}, yu^(-1)]*G[{0, 1}, yu^(-1)] - 
     2*G[{0}, yu^(-1)]*G[{1}, yu^(-1)]^2*G[{0, 1}, yu^(-1)] - 
     2*G[{0}, yv^(-1)]*G[{1}, yu^(-1)]^2*G[{0, 1}, yu^(-1)] + 
     2*G[{0}, yw]*G[{1}, yu^(-1)]^2*G[{0, 1}, yu^(-1)] - 
     (4*Pi^2*G[{1}, yw]*G[{0, 1}, yu^(-1)])/3 - 2*G[{0}, yu^(-1)]^2*
      G[{1}, yw]*G[{0, 1}, yu^(-1)] - 4*G[{0}, yu^(-1)]*G[{0}, yv^(-1)]*
      G[{1}, yw]*G[{0, 1}, yu^(-1)] - 2*G[{0}, yv^(-1)]^2*G[{1}, yw]*
      G[{0, 1}, yu^(-1)] + 4*G[{0}, yu^(-1)]*G[{0}, yw]*G[{1}, yw]*
      G[{0, 1}, yu^(-1)] + 4*G[{0}, yv^(-1)]*G[{0}, yw]*G[{1}, yw]*
      G[{0, 1}, yu^(-1)] - 2*G[{0}, yw]^2*G[{1}, yw]*G[{0, 1}, yu^(-1)] + 
     4*G[{0}, yu^(-1)]*G[{1}, yu^(-1)]*G[{1}, yw]*G[{0, 1}, yu^(-1)] + 
     4*G[{0}, yv^(-1)]*G[{1}, yu^(-1)]*G[{1}, yw]*G[{0, 1}, yu^(-1)] - 
     4*G[{0}, yw]*G[{1}, yu^(-1)]*G[{1}, yw]*G[{0, 1}, yu^(-1)] - 
     2*G[{0}, yu^(-1)]*G[{1}, yw]^2*G[{0, 1}, yu^(-1)] - 
     2*G[{0}, yv^(-1)]*G[{1}, yw]^2*G[{0, 1}, yu^(-1)] + 
     2*G[{0}, yw]*G[{1}, yw]^2*G[{0, 1}, yu^(-1)] - 
     2*G[{0}, yu^(-1)]*G[{0, 1}, yu^(-1)]^2 - 2*G[{0}, yv^(-1)]*
      G[{0, 1}, yu^(-1)]^2 + 2*G[{0}, yw]*G[{0, 1}, yu^(-1)]^2 + 
     2*G[{1}, yu^(-1)]*G[{0, 1}, yu^(-1)]^2 - 
     2*G[{1}, yw]*G[{0, 1}, yu^(-1)]^2 + 
     (2*Pi^2*G[{0}, yu^(-1)]*G[{0, 1}, yv^(-1)])/3 - 
     (2*G[{0}, yu^(-1)]^3*G[{0, 1}, yv^(-1)])/3 + 
     (2*Pi^2*G[{0}, yv^(-1)]*G[{0, 1}, yv^(-1)])/3 - 
     2*G[{0}, yu^(-1)]^2*G[{0}, yv^(-1)]*G[{0, 1}, yv^(-1)] - 
     2*G[{0}, yu^(-1)]*G[{0}, yv^(-1)]^2*G[{0, 1}, yv^(-1)] - 
     (2*G[{0}, yv^(-1)]^3*G[{0, 1}, yv^(-1)])/3 - 
     (2*Pi^2*G[{0}, yw]*G[{0, 1}, yv^(-1)])/3 + 2*G[{0}, yu^(-1)]^2*
      G[{0}, yw]*G[{0, 1}, yv^(-1)] + 4*G[{0}, yu^(-1)]*G[{0}, yv^(-1)]*
      G[{0}, yw]*G[{0, 1}, yv^(-1)] + 2*G[{0}, yv^(-1)]^2*G[{0}, yw]*
      G[{0, 1}, yv^(-1)] - 2*G[{0}, yu^(-1)]*G[{0}, yw]^2*
      G[{0, 1}, yv^(-1)] - 2*G[{0}, yv^(-1)]*G[{0}, yw]^2*
      G[{0, 1}, yv^(-1)] + (2*G[{0}, yw]^3*G[{0, 1}, yv^(-1)])/3 - 
     (2*Pi^2*G[{1}, yu^(-1)]*G[{0, 1}, yv^(-1)])/3 + 
     2*G[{0}, yu^(-1)]*G[{1}, yu^(-1)]^2*G[{0, 1}, yv^(-1)] + 
     2*G[{0}, yv^(-1)]*G[{1}, yu^(-1)]^2*G[{0, 1}, yv^(-1)] - 
     2*G[{0}, yw]*G[{1}, yu^(-1)]^2*G[{0, 1}, yv^(-1)] - 
     (4*G[{1}, yu^(-1)]^3*G[{0, 1}, yv^(-1)])/3 - 
     (2*Pi^2*G[{1}, yw]*G[{0, 1}, yv^(-1)])/3 - 2*G[{0}, yu^(-1)]^2*
      G[{1}, yw]*G[{0, 1}, yv^(-1)] - 4*G[{0}, yu^(-1)]*G[{0}, yv^(-1)]*
      G[{1}, yw]*G[{0, 1}, yv^(-1)] - 2*G[{0}, yv^(-1)]^2*G[{1}, yw]*
      G[{0, 1}, yv^(-1)] + 4*G[{0}, yu^(-1)]*G[{0}, yw]*G[{1}, yw]*
      G[{0, 1}, yv^(-1)] + 4*G[{0}, yv^(-1)]*G[{0}, yw]*G[{1}, yw]*
      G[{0, 1}, yv^(-1)] - 2*G[{0}, yw]^2*G[{1}, yw]*G[{0, 1}, yv^(-1)] + 
     2*G[{1}, yu^(-1)]^2*G[{1}, yw]*G[{0, 1}, yv^(-1)] - 
     2*G[{0}, yu^(-1)]*G[{1}, yw]^2*G[{0, 1}, yv^(-1)] - 
     2*G[{0}, yv^(-1)]*G[{1}, yw]^2*G[{0, 1}, yv^(-1)] + 
     2*G[{0}, yw]*G[{1}, yw]^2*G[{0, 1}, yv^(-1)] - 
     4*G[{1}, yu^(-1)]*G[{0, 1}, yu^(-1)]*G[{0, 1}, yv^(-1)] - 
     2*G[{1}, yw]*G[{0, 1}, yv^(-1)]^2 - (2*G[{0}, yu^(-1)]^3*G[{0, 1}, yw])/
      3 - 2*G[{0}, yu^(-1)]^2*G[{0}, yv^(-1)]*G[{0, 1}, yw] - 
     2*G[{0}, yu^(-1)]*G[{0}, yv^(-1)]^2*G[{0, 1}, yw] - 
     (2*G[{0}, yv^(-1)]^3*G[{0, 1}, yw])/3 + 2*G[{0}, yu^(-1)]^2*G[{0}, yw]*
      G[{0, 1}, yw] + 4*G[{0}, yu^(-1)]*G[{0}, yv^(-1)]*G[{0}, yw]*
      G[{0, 1}, yw] + 2*G[{0}, yv^(-1)]^2*G[{0}, yw]*G[{0, 1}, yw] - 
     2*G[{0}, yu^(-1)]*G[{0}, yw]^2*G[{0, 1}, yw] - 
     2*G[{0}, yv^(-1)]*G[{0}, yw]^2*G[{0, 1}, yw] + 
     (2*G[{0}, yw]^3*G[{0, 1}, yw])/3 + 
     (4*Pi^2*G[{1}, yu^(-1)]*G[{0, 1}, yw])/3 + 2*G[{0}, yu^(-1)]^2*
      G[{1}, yu^(-1)]*G[{0, 1}, yw] + 4*G[{0}, yu^(-1)]*G[{0}, yv^(-1)]*
      G[{1}, yu^(-1)]*G[{0, 1}, yw] + 2*G[{0}, yv^(-1)]^2*G[{1}, yu^(-1)]*
      G[{0, 1}, yw] - 4*G[{0}, yu^(-1)]*G[{0}, yw]*G[{1}, yu^(-1)]*
      G[{0, 1}, yw] - 4*G[{0}, yv^(-1)]*G[{0}, yw]*G[{1}, yu^(-1)]*
      G[{0, 1}, yw] + 2*G[{0}, yw]^2*G[{1}, yu^(-1)]*G[{0, 1}, yw] - 
     2*G[{0}, yu^(-1)]*G[{1}, yu^(-1)]^2*G[{0, 1}, yw] - 
     2*G[{0}, yv^(-1)]*G[{1}, yu^(-1)]^2*G[{0, 1}, yw] + 
     2*G[{0}, yw]*G[{1}, yu^(-1)]^2*G[{0, 1}, yw] + 
     (2*G[{1}, yu^(-1)]^3*G[{0, 1}, yw])/3 - 4*G[{0}, yu^(-1)]*
      G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*G[{0, 1}, yw] - 
     4*G[{0}, yv^(-1)]*G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*G[{0, 1}, yw] + 
     4*G[{0}, yw]*G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*G[{0, 1}, yw] + 
     4*G[{1}, yu^(-1)]^2*G[{1}, yv^(-1)]*G[{0, 1}, yw] - 
     (4*Pi^2*G[{1}, yw]*G[{0, 1}, yw])/3 - 2*G[{0}, yu^(-1)]^2*G[{1}, yw]*
      G[{0, 1}, yw] - 4*G[{0}, yu^(-1)]*G[{0}, yv^(-1)]*G[{1}, yw]*
      G[{0, 1}, yw] - 2*G[{0}, yv^(-1)]^2*G[{1}, yw]*G[{0, 1}, yw] + 
     4*G[{0}, yu^(-1)]*G[{0}, yw]*G[{1}, yw]*G[{0, 1}, yw] + 
     4*G[{0}, yv^(-1)]*G[{0}, yw]*G[{1}, yw]*G[{0, 1}, yw] - 
     2*G[{0}, yw]^2*G[{1}, yw]*G[{0, 1}, yw] + 4*G[{0}, yu^(-1)]*
      G[{1}, yu^(-1)]*G[{1}, yw]*G[{0, 1}, yw] + 4*G[{0}, yv^(-1)]*
      G[{1}, yu^(-1)]*G[{1}, yw]*G[{0, 1}, yw] - 4*G[{0}, yw]*G[{1}, yu^(-1)]*
      G[{1}, yw]*G[{0, 1}, yw] - 2*G[{1}, yu^(-1)]^2*G[{1}, yw]*
      G[{0, 1}, yw] - 4*G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*G[{1}, yw]*
      G[{0, 1}, yw] - 2*G[{0}, yu^(-1)]*G[{1}, yw]^2*G[{0, 1}, yw] - 
     2*G[{0}, yv^(-1)]*G[{1}, yw]^2*G[{0, 1}, yw] + 
     2*G[{0}, yw]*G[{1}, yw]^2*G[{0, 1}, yw] - 
     (4*Pi^2*G[{yu}, yv^(-1)]*G[{0, 1}, yw])/3 + 2*G[{0}, yu^(-1)]^2*
      G[{yu}, yv^(-1)]*G[{0, 1}, yw] + 4*G[{0}, yu^(-1)]*G[{0}, yv^(-1)]*
      G[{yu}, yv^(-1)]*G[{0, 1}, yw] + 2*G[{0}, yv^(-1)]^2*G[{yu}, yv^(-1)]*
      G[{0, 1}, yw] - 4*G[{0}, yu^(-1)]*G[{0}, yw]*G[{yu}, yv^(-1)]*
      G[{0, 1}, yw] - 4*G[{0}, yv^(-1)]*G[{0}, yw]*G[{yu}, yv^(-1)]*
      G[{0, 1}, yw] + 2*G[{0}, yw]^2*G[{yu}, yv^(-1)]*G[{0, 1}, yw] - 
     2*G[{1}, yu^(-1)]^2*G[{yu}, yv^(-1)]*G[{0, 1}, yw] + 
     4*G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*G[{yu}, yv^(-1)]*G[{0, 1}, yw] + 
     4*G[{0}, yu^(-1)]*G[{1}, yw]*G[{yu}, yv^(-1)]*G[{0, 1}, yw] + 
     4*G[{0}, yv^(-1)]*G[{1}, yw]*G[{yu}, yv^(-1)]*G[{0, 1}, yw] - 
     4*G[{0}, yw]*G[{1}, yw]*G[{yu}, yv^(-1)]*G[{0, 1}, yw] + 
     4*G[{1}, yw]^2*G[{yu}, yv^(-1)]*G[{0, 1}, yw] - 
     4*G[{0}, yu^(-1)]*G[{yu}, yv^(-1)]^2*G[{0, 1}, yw] - 
     4*G[{0}, yv^(-1)]*G[{yu}, yv^(-1)]^2*G[{0, 1}, yw] + 
     4*G[{0}, yw]*G[{yu}, yv^(-1)]^2*G[{0, 1}, yw] - 
     4*G[{1}, yw]*G[{yu}, yv^(-1)]^2*G[{0, 1}, yw] + 
     (8*G[{yu}, yv^(-1)]^3*G[{0, 1}, yw])/3 - 4*G[{0}, yu^(-1)]*
      G[{0, 1}, yu^(-1)]*G[{0, 1}, yw] - 4*G[{0}, yv^(-1)]*G[{0, 1}, yu^(-1)]*
      G[{0, 1}, yw] + 4*G[{0}, yw]*G[{0, 1}, yu^(-1)]*G[{0, 1}, yw] + 
     4*G[{1}, yu^(-1)]*G[{0, 1}, yu^(-1)]*G[{0, 1}, yw] - 
     4*G[{1}, yw]*G[{0, 1}, yu^(-1)]*G[{0, 1}, yw] + 
     4*G[{yu}, yv^(-1)]*G[{0, 1}, yu^(-1)]*G[{0, 1}, yw] - 
     (2*Pi^2*G[{0}, yu^(-1)]*G[{0, yu^(-1)}, yw])/3 + 
     (2*G[{0}, yu^(-1)]^3*G[{0, yu^(-1)}, yw])/3 - 
     (2*Pi^2*G[{0}, yv^(-1)]*G[{0, yu^(-1)}, yw])/3 + 
     2*G[{0}, yu^(-1)]^2*G[{0}, yv^(-1)]*G[{0, yu^(-1)}, yw] + 
     2*G[{0}, yu^(-1)]*G[{0}, yv^(-1)]^2*G[{0, yu^(-1)}, yw] + 
     (2*G[{0}, yv^(-1)]^3*G[{0, yu^(-1)}, yw])/3 + 
     (2*Pi^2*G[{0}, yw]*G[{0, yu^(-1)}, yw])/3 - 2*G[{0}, yu^(-1)]^2*
      G[{0}, yw]*G[{0, yu^(-1)}, yw] - 4*G[{0}, yu^(-1)]*G[{0}, yv^(-1)]*
      G[{0}, yw]*G[{0, yu^(-1)}, yw] - 2*G[{0}, yv^(-1)]^2*G[{0}, yw]*
      G[{0, yu^(-1)}, yw] + 2*G[{0}, yu^(-1)]*G[{0}, yw]^2*
      G[{0, yu^(-1)}, yw] + 2*G[{0}, yv^(-1)]*G[{0}, yw]^2*
      G[{0, yu^(-1)}, yw] - (2*G[{0}, yw]^3*G[{0, yu^(-1)}, yw])/3 - 
     (2*Pi^2*G[{1}, yu^(-1)]*G[{0, yu^(-1)}, yw])/3 - 
     2*G[{0}, yu^(-1)]^2*G[{1}, yu^(-1)]*G[{0, yu^(-1)}, yw] - 
     4*G[{0}, yu^(-1)]*G[{0}, yv^(-1)]*G[{1}, yu^(-1)]*G[{0, yu^(-1)}, yw] - 
     2*G[{0}, yv^(-1)]^2*G[{1}, yu^(-1)]*G[{0, yu^(-1)}, yw] + 
     4*G[{0}, yu^(-1)]*G[{0}, yw]*G[{1}, yu^(-1)]*G[{0, yu^(-1)}, yw] + 
     4*G[{0}, yv^(-1)]*G[{0}, yw]*G[{1}, yu^(-1)]*G[{0, yu^(-1)}, yw] - 
     2*G[{0}, yw]^2*G[{1}, yu^(-1)]*G[{0, yu^(-1)}, yw] + 
     2*G[{0}, yu^(-1)]*G[{1}, yu^(-1)]^2*G[{0, yu^(-1)}, yw] + 
     2*G[{0}, yv^(-1)]*G[{1}, yu^(-1)]^2*G[{0, yu^(-1)}, yw] - 
     2*G[{0}, yw]*G[{1}, yu^(-1)]^2*G[{0, yu^(-1)}, yw] - 
     (2*G[{1}, yu^(-1)]^3*G[{0, yu^(-1)}, yw])/3 + 2*Pi^2*G[{1}, yv^(-1)]*
      G[{0, yu^(-1)}, yw] - 2*G[{0}, yu^(-1)]^2*G[{1}, yv^(-1)]*
      G[{0, yu^(-1)}, yw] - 4*G[{0}, yu^(-1)]*G[{0}, yv^(-1)]*G[{1}, yv^(-1)]*
      G[{0, yu^(-1)}, yw] - 2*G[{0}, yv^(-1)]^2*G[{1}, yv^(-1)]*
      G[{0, yu^(-1)}, yw] + 4*G[{0}, yu^(-1)]*G[{0}, yw]*G[{1}, yv^(-1)]*
      G[{0, yu^(-1)}, yw] + 4*G[{0}, yv^(-1)]*G[{0}, yw]*G[{1}, yv^(-1)]*
      G[{0, yu^(-1)}, yw] - 2*G[{0}, yw]^2*G[{1}, yv^(-1)]*
      G[{0, yu^(-1)}, yw] + 4*G[{0}, yu^(-1)]*G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*
      G[{0, yu^(-1)}, yw] + 4*G[{0}, yv^(-1)]*G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*
      G[{0, yu^(-1)}, yw] - 4*G[{0}, yw]*G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*
      G[{0, yu^(-1)}, yw] - 2*G[{1}, yu^(-1)]^2*G[{1}, yv^(-1)]*
      G[{0, yu^(-1)}, yw] + 2*G[{0}, yu^(-1)]*G[{1}, yv^(-1)]^2*
      G[{0, yu^(-1)}, yw] + 2*G[{0}, yv^(-1)]*G[{1}, yv^(-1)]^2*
      G[{0, yu^(-1)}, yw] - 2*G[{0}, yw]*G[{1}, yv^(-1)]^2*
      G[{0, yu^(-1)}, yw] - 2*G[{1}, yu^(-1)]*G[{1}, yv^(-1)]^2*
      G[{0, yu^(-1)}, yw] - (4*G[{1}, yv^(-1)]^3*G[{0, yu^(-1)}, yw])/3 + 
     (2*Pi^2*G[{1}, yw]*G[{0, yu^(-1)}, yw])/3 + 2*G[{0}, yu^(-1)]^2*
      G[{1}, yw]*G[{0, yu^(-1)}, yw] + 4*G[{0}, yu^(-1)]*G[{0}, yv^(-1)]*
      G[{1}, yw]*G[{0, yu^(-1)}, yw] + 2*G[{0}, yv^(-1)]^2*G[{1}, yw]*
      G[{0, yu^(-1)}, yw] - 4*G[{0}, yu^(-1)]*G[{0}, yw]*G[{1}, yw]*
      G[{0, yu^(-1)}, yw] - 4*G[{0}, yv^(-1)]*G[{0}, yw]*G[{1}, yw]*
      G[{0, yu^(-1)}, yw] + 2*G[{0}, yw]^2*G[{1}, yw]*G[{0, yu^(-1)}, yw] - 
     4*G[{0}, yu^(-1)]*G[{1}, yu^(-1)]*G[{1}, yw]*G[{0, yu^(-1)}, yw] - 
     4*G[{0}, yv^(-1)]*G[{1}, yu^(-1)]*G[{1}, yw]*G[{0, yu^(-1)}, yw] + 
     4*G[{0}, yw]*G[{1}, yu^(-1)]*G[{1}, yw]*G[{0, yu^(-1)}, yw] + 
     2*G[{1}, yu^(-1)]^2*G[{1}, yw]*G[{0, yu^(-1)}, yw] - 
     4*G[{0}, yu^(-1)]*G[{1}, yv^(-1)]*G[{1}, yw]*G[{0, yu^(-1)}, yw] - 
     4*G[{0}, yv^(-1)]*G[{1}, yv^(-1)]*G[{1}, yw]*G[{0, yu^(-1)}, yw] + 
     4*G[{0}, yw]*G[{1}, yv^(-1)]*G[{1}, yw]*G[{0, yu^(-1)}, yw] + 
     4*G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*G[{1}, yw]*G[{0, yu^(-1)}, yw] + 
     2*G[{0}, yu^(-1)]*G[{1}, yw]^2*G[{0, yu^(-1)}, yw] + 
     2*G[{0}, yv^(-1)]*G[{1}, yw]^2*G[{0, yu^(-1)}, yw] - 
     2*G[{0}, yw]*G[{1}, yw]^2*G[{0, yu^(-1)}, yw] - 
     4*G[{1}, yv^(-1)]*G[{1}, yw]^2*G[{0, yu^(-1)}, yw] + 
     4*G[{1}, yv^(-1)]*G[{0, 1}, yv^(-1)]*G[{0, yu^(-1)}, yw] + 
     4*G[{1}, yw]*G[{0, 1}, yv^(-1)]*G[{0, yu^(-1)}, yw] + 
     4*G[{1}, yw]*G[{0, 1}, yw]*G[{0, yu^(-1)}, yw] - 
     2*G[{1}, yw]*G[{0, yu^(-1)}, yw]^2 + 
     (2*G[{0}, yu^(-1)]^3*G[{0, yu}, yv^(-1)])/3 + 
     2*G[{0}, yu^(-1)]^2*G[{0}, yv^(-1)]*G[{0, yu}, yv^(-1)] + 
     2*G[{0}, yu^(-1)]*G[{0}, yv^(-1)]^2*G[{0, yu}, yv^(-1)] + 
     (2*G[{0}, yv^(-1)]^3*G[{0, yu}, yv^(-1)])/3 - 
     2*G[{0}, yu^(-1)]^2*G[{0}, yw]*G[{0, yu}, yv^(-1)] - 
     4*G[{0}, yu^(-1)]*G[{0}, yv^(-1)]*G[{0}, yw]*G[{0, yu}, yv^(-1)] - 
     2*G[{0}, yv^(-1)]^2*G[{0}, yw]*G[{0, yu}, yv^(-1)] + 
     2*G[{0}, yu^(-1)]*G[{0}, yw]^2*G[{0, yu}, yv^(-1)] + 
     2*G[{0}, yv^(-1)]*G[{0}, yw]^2*G[{0, yu}, yv^(-1)] - 
     (2*G[{0}, yw]^3*G[{0, yu}, yv^(-1)])/3 - 2*G[{0}, yu^(-1)]*
      G[{1}, yu^(-1)]^2*G[{0, yu}, yv^(-1)] - 2*G[{0}, yv^(-1)]*
      G[{1}, yu^(-1)]^2*G[{0, yu}, yv^(-1)] + 2*G[{0}, yw]*G[{1}, yu^(-1)]^2*
      G[{0, yu}, yv^(-1)] + (4*G[{1}, yu^(-1)]^3*G[{0, yu}, yv^(-1)])/3 + 
     (4*Pi^2*G[{1}, yw]*G[{0, yu}, yv^(-1)])/3 + 2*G[{0}, yu^(-1)]^2*
      G[{1}, yw]*G[{0, yu}, yv^(-1)] + 4*G[{0}, yu^(-1)]*G[{0}, yv^(-1)]*
      G[{1}, yw]*G[{0, yu}, yv^(-1)] + 2*G[{0}, yv^(-1)]^2*G[{1}, yw]*
      G[{0, yu}, yv^(-1)] - 4*G[{0}, yu^(-1)]*G[{0}, yw]*G[{1}, yw]*
      G[{0, yu}, yv^(-1)] - 4*G[{0}, yv^(-1)]*G[{0}, yw]*G[{1}, yw]*
      G[{0, yu}, yv^(-1)] + 2*G[{0}, yw]^2*G[{1}, yw]*G[{0, yu}, yv^(-1)] - 
     2*G[{1}, yu^(-1)]^2*G[{1}, yw]*G[{0, yu}, yv^(-1)] + 
     2*G[{0}, yu^(-1)]*G[{1}, yw]^2*G[{0, yu}, yv^(-1)] + 
     2*G[{0}, yv^(-1)]*G[{1}, yw]^2*G[{0, yu}, yv^(-1)] - 
     2*G[{0}, yw]*G[{1}, yw]^2*G[{0, yu}, yv^(-1)] + 
     4*G[{0}, yu^(-1)]*G[{0, 1}, yu^(-1)]*G[{0, yu}, yv^(-1)] + 
     4*G[{0}, yv^(-1)]*G[{0, 1}, yu^(-1)]*G[{0, yu}, yv^(-1)] - 
     4*G[{0}, yw]*G[{0, 1}, yu^(-1)]*G[{0, yu}, yv^(-1)] + 
     4*G[{1}, yw]*G[{0, 1}, yu^(-1)]*G[{0, yu}, yv^(-1)] - 
     4*G[{1}, yv^(-1)]*G[{0, yu^(-1)}, yw]*G[{0, yu}, yv^(-1)] - 
     4*G[{1}, yw]*G[{0, yu^(-1)}, yw]*G[{0, yu}, yv^(-1)] + 
     (2*G[{0}, yu^(-1)]^3*G[{0, yv^(-1)}, yw])/3 + 
     2*G[{0}, yu^(-1)]^2*G[{0}, yv^(-1)]*G[{0, yv^(-1)}, yw] + 
     2*G[{0}, yu^(-1)]*G[{0}, yv^(-1)]^2*G[{0, yv^(-1)}, yw] + 
     (2*G[{0}, yv^(-1)]^3*G[{0, yv^(-1)}, yw])/3 - 
     2*G[{0}, yu^(-1)]^2*G[{0}, yw]*G[{0, yv^(-1)}, yw] - 
     4*G[{0}, yu^(-1)]*G[{0}, yv^(-1)]*G[{0}, yw]*G[{0, yv^(-1)}, yw] - 
     2*G[{0}, yv^(-1)]^2*G[{0}, yw]*G[{0, yv^(-1)}, yw] + 
     2*G[{0}, yu^(-1)]*G[{0}, yw]^2*G[{0, yv^(-1)}, yw] + 
     2*G[{0}, yv^(-1)]*G[{0}, yw]^2*G[{0, yv^(-1)}, yw] - 
     (2*G[{0}, yw]^3*G[{0, yv^(-1)}, yw])/3 - 4*G[{0}, yu^(-1)]^2*
      G[{1}, yu^(-1)]*G[{0, yv^(-1)}, yw] - 8*G[{0}, yu^(-1)]*G[{0}, yv^(-1)]*
      G[{1}, yu^(-1)]*G[{0, yv^(-1)}, yw] - 4*G[{0}, yv^(-1)]^2*
      G[{1}, yu^(-1)]*G[{0, yv^(-1)}, yw] + 8*G[{0}, yu^(-1)]*G[{0}, yw]*
      G[{1}, yu^(-1)]*G[{0, yv^(-1)}, yw] + 8*G[{0}, yv^(-1)]*G[{0}, yw]*
      G[{1}, yu^(-1)]*G[{0, yv^(-1)}, yw] - 4*G[{0}, yw]^2*G[{1}, yu^(-1)]*
      G[{0, yv^(-1)}, yw] + 6*G[{0}, yu^(-1)]*G[{1}, yu^(-1)]^2*
      G[{0, yv^(-1)}, yw] + 6*G[{0}, yv^(-1)]*G[{1}, yu^(-1)]^2*
      G[{0, yv^(-1)}, yw] - 6*G[{0}, yw]*G[{1}, yu^(-1)]^2*
      G[{0, yv^(-1)}, yw] - (8*G[{1}, yu^(-1)]^3*G[{0, yv^(-1)}, yw])/3 + 
     4*G[{0}, yu^(-1)]*G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*G[{0, yv^(-1)}, yw] + 
     4*G[{0}, yv^(-1)]*G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*G[{0, yv^(-1)}, yw] - 
     4*G[{0}, yw]*G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*G[{0, yv^(-1)}, yw] - 
     4*G[{1}, yu^(-1)]^2*G[{1}, yv^(-1)]*G[{0, yv^(-1)}, yw] + 
     (4*Pi^2*G[{1}, yw]*G[{0, yv^(-1)}, yw])/3 + 2*G[{0}, yu^(-1)]^2*
      G[{1}, yw]*G[{0, yv^(-1)}, yw] + 4*G[{0}, yu^(-1)]*G[{0}, yv^(-1)]*
      G[{1}, yw]*G[{0, yv^(-1)}, yw] + 2*G[{0}, yv^(-1)]^2*G[{1}, yw]*
      G[{0, yv^(-1)}, yw] - 4*G[{0}, yu^(-1)]*G[{0}, yw]*G[{1}, yw]*
      G[{0, yv^(-1)}, yw] - 4*G[{0}, yv^(-1)]*G[{0}, yw]*G[{1}, yw]*
      G[{0, yv^(-1)}, yw] + 2*G[{0}, yw]^2*G[{1}, yw]*G[{0, yv^(-1)}, yw] - 
     8*G[{0}, yu^(-1)]*G[{1}, yu^(-1)]*G[{1}, yw]*G[{0, yv^(-1)}, yw] - 
     8*G[{0}, yv^(-1)]*G[{1}, yu^(-1)]*G[{1}, yw]*G[{0, yv^(-1)}, yw] + 
     8*G[{0}, yw]*G[{1}, yu^(-1)]*G[{1}, yw]*G[{0, yv^(-1)}, yw] + 
     6*G[{1}, yu^(-1)]^2*G[{1}, yw]*G[{0, yv^(-1)}, yw] + 
     4*G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*G[{1}, yw]*G[{0, yv^(-1)}, yw] + 
     2*G[{0}, yu^(-1)]*G[{1}, yw]^2*G[{0, yv^(-1)}, yw] + 
     2*G[{0}, yv^(-1)]*G[{1}, yw]^2*G[{0, yv^(-1)}, yw] - 
     2*G[{0}, yw]*G[{1}, yw]^2*G[{0, yv^(-1)}, yw] - 
     4*G[{1}, yu^(-1)]*G[{1}, yw]^2*G[{0, yv^(-1)}, yw] + 
     4*G[{0}, yu^(-1)]*G[{0, 1}, yu^(-1)]*G[{0, yv^(-1)}, yw] + 
     4*G[{0}, yv^(-1)]*G[{0, 1}, yu^(-1)]*G[{0, yv^(-1)}, yw] - 
     4*G[{0}, yw]*G[{0, 1}, yu^(-1)]*G[{0, yv^(-1)}, yw] - 
     8*G[{1}, yu^(-1)]*G[{0, 1}, yu^(-1)]*G[{0, yv^(-1)}, yw] + 
     4*G[{1}, yw]*G[{0, 1}, yu^(-1)]*G[{0, yv^(-1)}, yw] + 
     (2*Pi^2*G[{0}, yu^(-1)]*G[{0, 1/(yu*yv)}, yw])/3 - 
     (2*G[{0}, yu^(-1)]^3*G[{0, 1/(yu*yv)}, yw])/3 + 
     (2*Pi^2*G[{0}, yv^(-1)]*G[{0, 1/(yu*yv)}, yw])/3 - 
     2*G[{0}, yu^(-1)]^2*G[{0}, yv^(-1)]*G[{0, 1/(yu*yv)}, yw] - 
     2*G[{0}, yu^(-1)]*G[{0}, yv^(-1)]^2*G[{0, 1/(yu*yv)}, yw] - 
     (2*G[{0}, yv^(-1)]^3*G[{0, 1/(yu*yv)}, yw])/3 - 
     (2*Pi^2*G[{0}, yw]*G[{0, 1/(yu*yv)}, yw])/3 + 
     2*G[{0}, yu^(-1)]^2*G[{0}, yw]*G[{0, 1/(yu*yv)}, yw] + 
     4*G[{0}, yu^(-1)]*G[{0}, yv^(-1)]*G[{0}, yw]*G[{0, 1/(yu*yv)}, yw] + 
     2*G[{0}, yv^(-1)]^2*G[{0}, yw]*G[{0, 1/(yu*yv)}, yw] - 
     2*G[{0}, yu^(-1)]*G[{0}, yw]^2*G[{0, 1/(yu*yv)}, yw] - 
     2*G[{0}, yv^(-1)]*G[{0}, yw]^2*G[{0, 1/(yu*yv)}, yw] + 
     (2*G[{0}, yw]^3*G[{0, 1/(yu*yv)}, yw])/3 - 
     (2*Pi^2*G[{1}, yu^(-1)]*G[{0, 1/(yu*yv)}, yw])/3 + 
     4*G[{0}, yu^(-1)]^2*G[{1}, yu^(-1)]*G[{0, 1/(yu*yv)}, yw] + 
     8*G[{0}, yu^(-1)]*G[{0}, yv^(-1)]*G[{1}, yu^(-1)]*
      G[{0, 1/(yu*yv)}, yw] + 4*G[{0}, yv^(-1)]^2*G[{1}, yu^(-1)]*
      G[{0, 1/(yu*yv)}, yw] - 8*G[{0}, yu^(-1)]*G[{0}, yw]*G[{1}, yu^(-1)]*
      G[{0, 1/(yu*yv)}, yw] - 8*G[{0}, yv^(-1)]*G[{0}, yw]*G[{1}, yu^(-1)]*
      G[{0, 1/(yu*yv)}, yw] + 4*G[{0}, yw]^2*G[{1}, yu^(-1)]*
      G[{0, 1/(yu*yv)}, yw] - 6*G[{0}, yu^(-1)]*G[{1}, yu^(-1)]^2*
      G[{0, 1/(yu*yv)}, yw] - 6*G[{0}, yv^(-1)]*G[{1}, yu^(-1)]^2*
      G[{0, 1/(yu*yv)}, yw] + 6*G[{0}, yw]*G[{1}, yu^(-1)]^2*
      G[{0, 1/(yu*yv)}, yw] + (8*G[{1}, yu^(-1)]^3*G[{0, 1/(yu*yv)}, yw])/3 - 
     2*Pi^2*G[{1}, yv^(-1)]*G[{0, 1/(yu*yv)}, yw] + 
     2*G[{0}, yu^(-1)]^2*G[{1}, yv^(-1)]*G[{0, 1/(yu*yv)}, yw] + 
     4*G[{0}, yu^(-1)]*G[{0}, yv^(-1)]*G[{1}, yv^(-1)]*
      G[{0, 1/(yu*yv)}, yw] + 2*G[{0}, yv^(-1)]^2*G[{1}, yv^(-1)]*
      G[{0, 1/(yu*yv)}, yw] - 4*G[{0}, yu^(-1)]*G[{0}, yw]*G[{1}, yv^(-1)]*
      G[{0, 1/(yu*yv)}, yw] - 4*G[{0}, yv^(-1)]*G[{0}, yw]*G[{1}, yv^(-1)]*
      G[{0, 1/(yu*yv)}, yw] + 2*G[{0}, yw]^2*G[{1}, yv^(-1)]*
      G[{0, 1/(yu*yv)}, yw] - 4*G[{0}, yu^(-1)]*G[{1}, yu^(-1)]*
      G[{1}, yv^(-1)]*G[{0, 1/(yu*yv)}, yw] - 4*G[{0}, yv^(-1)]*
      G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*G[{0, 1/(yu*yv)}, yw] + 
     4*G[{0}, yw]*G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*G[{0, 1/(yu*yv)}, yw] + 
     2*G[{1}, yu^(-1)]^2*G[{1}, yv^(-1)]*G[{0, 1/(yu*yv)}, yw] - 
     2*G[{0}, yu^(-1)]*G[{1}, yv^(-1)]^2*G[{0, 1/(yu*yv)}, yw] - 
     2*G[{0}, yv^(-1)]*G[{1}, yv^(-1)]^2*G[{0, 1/(yu*yv)}, yw] + 
     2*G[{0}, yw]*G[{1}, yv^(-1)]^2*G[{0, 1/(yu*yv)}, yw] + 
     2*G[{1}, yu^(-1)]*G[{1}, yv^(-1)]^2*G[{0, 1/(yu*yv)}, yw] + 
     (4*G[{1}, yv^(-1)]^3*G[{0, 1/(yu*yv)}, yw])/3 - 
     (2*Pi^2*G[{1}, yw]*G[{0, 1/(yu*yv)}, yw])/3 - 
     2*G[{0}, yu^(-1)]^2*G[{1}, yw]*G[{0, 1/(yu*yv)}, yw] - 
     4*G[{0}, yu^(-1)]*G[{0}, yv^(-1)]*G[{1}, yw]*G[{0, 1/(yu*yv)}, yw] - 
     2*G[{0}, yv^(-1)]^2*G[{1}, yw]*G[{0, 1/(yu*yv)}, yw] + 
     4*G[{0}, yu^(-1)]*G[{0}, yw]*G[{1}, yw]*G[{0, 1/(yu*yv)}, yw] + 
     4*G[{0}, yv^(-1)]*G[{0}, yw]*G[{1}, yw]*G[{0, 1/(yu*yv)}, yw] - 
     2*G[{0}, yw]^2*G[{1}, yw]*G[{0, 1/(yu*yv)}, yw] + 
     8*G[{0}, yu^(-1)]*G[{1}, yu^(-1)]*G[{1}, yw]*G[{0, 1/(yu*yv)}, yw] + 
     8*G[{0}, yv^(-1)]*G[{1}, yu^(-1)]*G[{1}, yw]*G[{0, 1/(yu*yv)}, yw] - 
     8*G[{0}, yw]*G[{1}, yu^(-1)]*G[{1}, yw]*G[{0, 1/(yu*yv)}, yw] - 
     6*G[{1}, yu^(-1)]^2*G[{1}, yw]*G[{0, 1/(yu*yv)}, yw] + 
     4*G[{0}, yu^(-1)]*G[{1}, yv^(-1)]*G[{1}, yw]*G[{0, 1/(yu*yv)}, yw] + 
     4*G[{0}, yv^(-1)]*G[{1}, yv^(-1)]*G[{1}, yw]*G[{0, 1/(yu*yv)}, yw] - 
     4*G[{0}, yw]*G[{1}, yv^(-1)]*G[{1}, yw]*G[{0, 1/(yu*yv)}, yw] - 
     4*G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*G[{1}, yw]*G[{0, 1/(yu*yv)}, yw] - 
     2*G[{0}, yu^(-1)]*G[{1}, yw]^2*G[{0, 1/(yu*yv)}, yw] - 
     2*G[{0}, yv^(-1)]*G[{1}, yw]^2*G[{0, 1/(yu*yv)}, yw] + 
     2*G[{0}, yw]*G[{1}, yw]^2*G[{0, 1/(yu*yv)}, yw] + 
     4*G[{1}, yu^(-1)]*G[{1}, yw]^2*G[{0, 1/(yu*yv)}, yw] + 
     4*G[{1}, yv^(-1)]*G[{1}, yw]^2*G[{0, 1/(yu*yv)}, yw] + 
     (4*Pi^2*G[{yu}, yv^(-1)]*G[{0, 1/(yu*yv)}, yw])/3 - 
     2*G[{0}, yu^(-1)]^2*G[{yu}, yv^(-1)]*G[{0, 1/(yu*yv)}, yw] - 
     4*G[{0}, yu^(-1)]*G[{0}, yv^(-1)]*G[{yu}, yv^(-1)]*
      G[{0, 1/(yu*yv)}, yw] - 2*G[{0}, yv^(-1)]^2*G[{yu}, yv^(-1)]*
      G[{0, 1/(yu*yv)}, yw] + 4*G[{0}, yu^(-1)]*G[{0}, yw]*G[{yu}, yv^(-1)]*
      G[{0, 1/(yu*yv)}, yw] + 4*G[{0}, yv^(-1)]*G[{0}, yw]*G[{yu}, yv^(-1)]*
      G[{0, 1/(yu*yv)}, yw] - 2*G[{0}, yw]^2*G[{yu}, yv^(-1)]*
      G[{0, 1/(yu*yv)}, yw] + 2*G[{1}, yu^(-1)]^2*G[{yu}, yv^(-1)]*
      G[{0, 1/(yu*yv)}, yw] - 4*G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*
      G[{yu}, yv^(-1)]*G[{0, 1/(yu*yv)}, yw] - 4*G[{0}, yu^(-1)]*G[{1}, yw]*
      G[{yu}, yv^(-1)]*G[{0, 1/(yu*yv)}, yw] - 4*G[{0}, yv^(-1)]*G[{1}, yw]*
      G[{yu}, yv^(-1)]*G[{0, 1/(yu*yv)}, yw] + 4*G[{0}, yw]*G[{1}, yw]*
      G[{yu}, yv^(-1)]*G[{0, 1/(yu*yv)}, yw] - 4*G[{1}, yw]^2*
      G[{yu}, yv^(-1)]*G[{0, 1/(yu*yv)}, yw] + 4*G[{0}, yu^(-1)]*
      G[{yu}, yv^(-1)]^2*G[{0, 1/(yu*yv)}, yw] + 4*G[{0}, yv^(-1)]*
      G[{yu}, yv^(-1)]^2*G[{0, 1/(yu*yv)}, yw] - 
     4*G[{0}, yw]*G[{yu}, yv^(-1)]^2*G[{0, 1/(yu*yv)}, yw] + 
     4*G[{1}, yw]*G[{yu}, yv^(-1)]^2*G[{0, 1/(yu*yv)}, yw] - 
     (8*G[{yu}, yv^(-1)]^3*G[{0, 1/(yu*yv)}, yw])/3 + 
     4*G[{1}, yu^(-1)]*G[{0, 1}, yu^(-1)]*G[{0, 1/(yu*yv)}, yw] - 
     4*G[{yu}, yv^(-1)]*G[{0, 1}, yu^(-1)]*G[{0, 1/(yu*yv)}, yw] - 
     4*G[{1}, yv^(-1)]*G[{0, 1}, yv^(-1)]*G[{0, 1/(yu*yv)}, yw] - 
     4*G[{1}, yw]*G[{0, 1}, yv^(-1)]*G[{0, 1/(yu*yv)}, yw] - 
     4*G[{1}, yw]*G[{0, 1}, yw]*G[{0, 1/(yu*yv)}, yw] + 
     4*G[{1}, yw]*G[{0, yu^(-1)}, yw]*G[{0, 1/(yu*yv)}, yw] + 
     4*G[{1}, yv^(-1)]*G[{0, yu}, yv^(-1)]*G[{0, 1/(yu*yv)}, yw] + 
     4*G[{1}, yw]*G[{0, yu}, yv^(-1)]*G[{0, 1/(yu*yv)}, yw] + 
     4*G[{1}, yw]*G[{0, yv^(-1)}, yw]*G[{0, 1/(yu*yv)}, yw] - 
     2*G[{1}, yw]*G[{0, 1/(yu*yv)}, yw]^2 + 4*G[{0}, yu^(-1)]*G[{0, 1}, yw]*
      G[{1, yu}, yv^(-1)] + 4*G[{0}, yv^(-1)]*G[{0, 1}, yw]*
      G[{1, yu}, yv^(-1)] - 4*G[{0}, yw]*G[{0, 1}, yw]*G[{1, yu}, yv^(-1)] - 
     4*G[{1}, yu^(-1)]*G[{0, 1}, yw]*G[{1, yu}, yv^(-1)] + 
     4*G[{1}, yw]*G[{0, 1}, yw]*G[{1, yu}, yv^(-1)] - 
     4*G[{yu}, yv^(-1)]*G[{0, 1}, yw]*G[{1, yu}, yv^(-1)] + 
     4*G[{1}, yw]*G[{0, yu^(-1)}, yw]*G[{1, yu}, yv^(-1)] - 
     4*G[{0}, yu^(-1)]*G[{0, yv^(-1)}, yw]*G[{1, yu}, yv^(-1)] - 
     4*G[{0}, yv^(-1)]*G[{0, yv^(-1)}, yw]*G[{1, yu}, yv^(-1)] + 
     4*G[{0}, yw]*G[{0, yv^(-1)}, yw]*G[{1, yu}, yv^(-1)] - 
     4*G[{1}, yw]*G[{0, yv^(-1)}, yw]*G[{1, yu}, yv^(-1)] + 
     4*G[{1}, yu^(-1)]*G[{0, 1/(yu*yv)}, yw]*G[{1, yu}, yv^(-1)] - 
     4*G[{1}, yw]*G[{0, 1/(yu*yv)}, yw]*G[{1, yu}, yv^(-1)] + 
     4*G[{yu}, yv^(-1)]*G[{0, 1/(yu*yv)}, yw]*G[{1, yu}, yv^(-1)] + 
     (2*Pi^2*G[{0, 0, 1}, yv^(-1)])/3 + 2*G[{0}, yu^(-1)]^2*
      G[{0, 0, 1}, yv^(-1)] + 4*G[{0}, yu^(-1)]*G[{0}, yv^(-1)]*
      G[{0, 0, 1}, yv^(-1)] + 2*G[{0}, yv^(-1)]^2*G[{0, 0, 1}, yv^(-1)] - 
     4*G[{0}, yu^(-1)]*G[{0}, yw]*G[{0, 0, 1}, yv^(-1)] - 
     4*G[{0}, yv^(-1)]*G[{0}, yw]*G[{0, 0, 1}, yv^(-1)] + 
     2*G[{0}, yw]^2*G[{0, 0, 1}, yv^(-1)] - 2*G[{1}, yu^(-1)]^2*
      G[{0, 0, 1}, yv^(-1)] + 4*G[{0}, yu^(-1)]*G[{1}, yw]*
      G[{0, 0, 1}, yv^(-1)] + 4*G[{0}, yv^(-1)]*G[{1}, yw]*
      G[{0, 0, 1}, yv^(-1)] - 4*G[{0}, yw]*G[{1}, yw]*G[{0, 0, 1}, yv^(-1)] + 
     4*G[{0, 1}, yv^(-1)]*G[{0, 0, 1}, yv^(-1)] - 4*G[{0, yu^(-1)}, yw]*
      G[{0, 0, 1}, yv^(-1)] + 4*G[{0, 1/(yu*yv)}, yw]*G[{0, 0, 1}, yv^(-1)] + 
     (4*Pi^2*G[{0, 0, 1}, yw])/3 - 2*G[{0}, yu^(-1)]^2*G[{0, 0, 1}, yw] - 
     4*G[{0}, yu^(-1)]*G[{0}, yv^(-1)]*G[{0, 0, 1}, yw] - 
     2*G[{0}, yv^(-1)]^2*G[{0, 0, 1}, yw] + 4*G[{0}, yu^(-1)]*G[{0}, yw]*
      G[{0, 0, 1}, yw] + 4*G[{0}, yv^(-1)]*G[{0}, yw]*G[{0, 0, 1}, yw] - 
     2*G[{0}, yw]^2*G[{0, 0, 1}, yw] + 4*G[{0}, yu^(-1)]*G[{1}, yu^(-1)]*
      G[{0, 0, 1}, yw] + 4*G[{0}, yv^(-1)]*G[{1}, yu^(-1)]*G[{0, 0, 1}, yw] - 
     4*G[{0}, yw]*G[{1}, yu^(-1)]*G[{0, 0, 1}, yw] - 
     2*G[{1}, yu^(-1)]^2*G[{0, 0, 1}, yw] - 4*G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*
      G[{0, 0, 1}, yw] - 4*G[{0}, yu^(-1)]*G[{1}, yw]*G[{0, 0, 1}, yw] - 
     4*G[{0}, yv^(-1)]*G[{1}, yw]*G[{0, 0, 1}, yw] + 
     4*G[{0}, yw]*G[{1}, yw]*G[{0, 0, 1}, yw] + 8*G[{1}, yu^(-1)]*G[{1}, yw]*
      G[{0, 0, 1}, yw] - 4*G[{1}, yw]^2*G[{0, 0, 1}, yw] + 
     4*G[{0}, yu^(-1)]*G[{yu}, yv^(-1)]*G[{0, 0, 1}, yw] + 
     4*G[{0}, yv^(-1)]*G[{yu}, yv^(-1)]*G[{0, 0, 1}, yw] - 
     4*G[{0}, yw]*G[{yu}, yv^(-1)]*G[{0, 0, 1}, yw] - 
     4*G[{yu}, yv^(-1)]^2*G[{0, 0, 1}, yw] - 4*G[{0, 1}, yu^(-1)]*
      G[{0, 0, 1}, yw] - 4*G[{0, yu^(-1)}, yw]*G[{0, 0, 1}, yw] + 
     4*G[{0, 1/(yu*yv)}, yw]*G[{0, 0, 1}, yw] + 4*G[{1, yu}, yv^(-1)]*
      G[{0, 0, 1}, yw] - 2*Pi^2*G[{0, 0, yu^(-1)}, yw] + 
     2*G[{0}, yu^(-1)]^2*G[{0, 0, yu^(-1)}, yw] + 
     4*G[{0}, yu^(-1)]*G[{0}, yv^(-1)]*G[{0, 0, yu^(-1)}, yw] + 
     2*G[{0}, yv^(-1)]^2*G[{0, 0, yu^(-1)}, yw] - 
     4*G[{0}, yu^(-1)]*G[{0}, yw]*G[{0, 0, yu^(-1)}, yw] - 
     4*G[{0}, yv^(-1)]*G[{0}, yw]*G[{0, 0, yu^(-1)}, yw] + 
     2*G[{0}, yw]^2*G[{0, 0, yu^(-1)}, yw] - 4*G[{0}, yu^(-1)]*
      G[{1}, yu^(-1)]*G[{0, 0, yu^(-1)}, yw] - 4*G[{0}, yv^(-1)]*
      G[{1}, yu^(-1)]*G[{0, 0, yu^(-1)}, yw] + 4*G[{0}, yw]*G[{1}, yu^(-1)]*
      G[{0, 0, yu^(-1)}, yw] + 2*G[{1}, yu^(-1)]^2*G[{0, 0, yu^(-1)}, yw] - 
     4*G[{0}, yu^(-1)]*G[{1}, yv^(-1)]*G[{0, 0, yu^(-1)}, yw] - 
     4*G[{0}, yv^(-1)]*G[{1}, yv^(-1)]*G[{0, 0, yu^(-1)}, yw] + 
     4*G[{0}, yw]*G[{1}, yv^(-1)]*G[{0, 0, yu^(-1)}, yw] + 
     4*G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*G[{0, 0, yu^(-1)}, yw] + 
     4*G[{1}, yv^(-1)]^2*G[{0, 0, yu^(-1)}, yw] + 
     4*G[{0}, yu^(-1)]*G[{1}, yw]*G[{0, 0, yu^(-1)}, yw] + 
     4*G[{0}, yv^(-1)]*G[{1}, yw]*G[{0, 0, yu^(-1)}, yw] - 
     4*G[{0}, yw]*G[{1}, yw]*G[{0, 0, yu^(-1)}, yw] - 
     8*G[{1}, yu^(-1)]*G[{1}, yw]*G[{0, 0, yu^(-1)}, yw] + 
     4*G[{1}, yw]^2*G[{0, 0, yu^(-1)}, yw] - 4*G[{0, 1}, yv^(-1)]*
      G[{0, 0, yu^(-1)}, yw] + 4*G[{0, yu^(-1)}, yw]*G[{0, 0, yu^(-1)}, yw] + 
     4*G[{0, yu}, yv^(-1)]*G[{0, 0, yu^(-1)}, yw] - 
     4*G[{0, 1/(yu*yv)}, yw]*G[{0, 0, yu^(-1)}, yw] - 
     4*G[{1, yu}, yv^(-1)]*G[{0, 0, yu^(-1)}, yw] - 
     (4*Pi^2*G[{0, 0, yu}, yv^(-1)])/3 - 2*G[{0}, yu^(-1)]^2*
      G[{0, 0, yu}, yv^(-1)] - 4*G[{0}, yu^(-1)]*G[{0}, yv^(-1)]*
      G[{0, 0, yu}, yv^(-1)] - 2*G[{0}, yv^(-1)]^2*G[{0, 0, yu}, yv^(-1)] + 
     4*G[{0}, yu^(-1)]*G[{0}, yw]*G[{0, 0, yu}, yv^(-1)] + 
     4*G[{0}, yv^(-1)]*G[{0}, yw]*G[{0, 0, yu}, yv^(-1)] - 
     2*G[{0}, yw]^2*G[{0, 0, yu}, yv^(-1)] + 2*G[{1}, yu^(-1)]^2*
      G[{0, 0, yu}, yv^(-1)] - 4*G[{0}, yu^(-1)]*G[{1}, yw]*
      G[{0, 0, yu}, yv^(-1)] - 4*G[{0}, yv^(-1)]*G[{1}, yw]*
      G[{0, 0, yu}, yv^(-1)] + 4*G[{0}, yw]*G[{1}, yw]*
      G[{0, 0, yu}, yv^(-1)] - 4*G[{0, 1}, yu^(-1)]*G[{0, 0, yu}, yv^(-1)] - 
     4*G[{0, 1}, yv^(-1)]*G[{0, 0, yu}, yv^(-1)] + 4*G[{0, yu^(-1)}, yw]*
      G[{0, 0, yu}, yv^(-1)] - 4*G[{0, 1/(yu*yv)}, yw]*
      G[{0, 0, yu}, yv^(-1)] - (4*Pi^2*G[{0, 0, yv^(-1)}, yw])/3 + 
     2*G[{0}, yu^(-1)]^2*G[{0, 0, yv^(-1)}, yw] + 
     4*G[{0}, yu^(-1)]*G[{0}, yv^(-1)]*G[{0, 0, yv^(-1)}, yw] + 
     2*G[{0}, yv^(-1)]^2*G[{0, 0, yv^(-1)}, yw] - 
     4*G[{0}, yu^(-1)]*G[{0}, yw]*G[{0, 0, yv^(-1)}, yw] - 
     4*G[{0}, yv^(-1)]*G[{0}, yw]*G[{0, 0, yv^(-1)}, yw] + 
     2*G[{0}, yw]^2*G[{0, 0, yv^(-1)}, yw] - 8*G[{0}, yu^(-1)]*
      G[{1}, yu^(-1)]*G[{0, 0, yv^(-1)}, yw] - 8*G[{0}, yv^(-1)]*
      G[{1}, yu^(-1)]*G[{0, 0, yv^(-1)}, yw] + 8*G[{0}, yw]*G[{1}, yu^(-1)]*
      G[{0, 0, yv^(-1)}, yw] + 6*G[{1}, yu^(-1)]^2*G[{0, 0, yv^(-1)}, yw] + 
     4*G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*G[{0, 0, yv^(-1)}, yw] + 
     4*G[{0}, yu^(-1)]*G[{1}, yw]*G[{0, 0, yv^(-1)}, yw] + 
     4*G[{0}, yv^(-1)]*G[{1}, yw]*G[{0, 0, yv^(-1)}, yw] - 
     4*G[{0}, yw]*G[{1}, yw]*G[{0, 0, yv^(-1)}, yw] - 
     8*G[{1}, yu^(-1)]*G[{1}, yw]*G[{0, 0, yv^(-1)}, yw] + 
     4*G[{1}, yw]^2*G[{0, 0, yv^(-1)}, yw] + 4*G[{0, 1}, yu^(-1)]*
      G[{0, 0, yv^(-1)}, yw] + 4*G[{0, yu^(-1)}, yw]*G[{0, 0, yv^(-1)}, yw] - 
     4*G[{0, 1/(yu*yv)}, yw]*G[{0, 0, yv^(-1)}, yw] - 
     4*G[{1, yu}, yv^(-1)]*G[{0, 0, yv^(-1)}, yw] + 
     2*Pi^2*G[{0, 0, 1/(yu*yv)}, yw] - 2*G[{0}, yu^(-1)]^2*
      G[{0, 0, 1/(yu*yv)}, yw] - 4*G[{0}, yu^(-1)]*G[{0}, yv^(-1)]*
      G[{0, 0, 1/(yu*yv)}, yw] - 2*G[{0}, yv^(-1)]^2*
      G[{0, 0, 1/(yu*yv)}, yw] + 4*G[{0}, yu^(-1)]*G[{0}, yw]*
      G[{0, 0, 1/(yu*yv)}, yw] + 4*G[{0}, yv^(-1)]*G[{0}, yw]*
      G[{0, 0, 1/(yu*yv)}, yw] - 2*G[{0}, yw]^2*G[{0, 0, 1/(yu*yv)}, yw] + 
     8*G[{0}, yu^(-1)]*G[{1}, yu^(-1)]*G[{0, 0, 1/(yu*yv)}, yw] + 
     8*G[{0}, yv^(-1)]*G[{1}, yu^(-1)]*G[{0, 0, 1/(yu*yv)}, yw] - 
     8*G[{0}, yw]*G[{1}, yu^(-1)]*G[{0, 0, 1/(yu*yv)}, yw] - 
     6*G[{1}, yu^(-1)]^2*G[{0, 0, 1/(yu*yv)}, yw] + 
     4*G[{0}, yu^(-1)]*G[{1}, yv^(-1)]*G[{0, 0, 1/(yu*yv)}, yw] + 
     4*G[{0}, yv^(-1)]*G[{1}, yv^(-1)]*G[{0, 0, 1/(yu*yv)}, yw] - 
     4*G[{0}, yw]*G[{1}, yv^(-1)]*G[{0, 0, 1/(yu*yv)}, yw] - 
     4*G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*G[{0, 0, 1/(yu*yv)}, yw] - 
     4*G[{1}, yv^(-1)]^2*G[{0, 0, 1/(yu*yv)}, yw] - 
     4*G[{0}, yu^(-1)]*G[{1}, yw]*G[{0, 0, 1/(yu*yv)}, yw] - 
     4*G[{0}, yv^(-1)]*G[{1}, yw]*G[{0, 0, 1/(yu*yv)}, yw] + 
     4*G[{0}, yw]*G[{1}, yw]*G[{0, 0, 1/(yu*yv)}, yw] + 
     8*G[{1}, yu^(-1)]*G[{1}, yw]*G[{0, 0, 1/(yu*yv)}, yw] - 
     4*G[{1}, yw]^2*G[{0, 0, 1/(yu*yv)}, yw] - 4*G[{0}, yu^(-1)]*
      G[{yu}, yv^(-1)]*G[{0, 0, 1/(yu*yv)}, yw] - 
     4*G[{0}, yv^(-1)]*G[{yu}, yv^(-1)]*G[{0, 0, 1/(yu*yv)}, yw] + 
     4*G[{0}, yw]*G[{yu}, yv^(-1)]*G[{0, 0, 1/(yu*yv)}, yw] + 
     4*G[{yu}, yv^(-1)]^2*G[{0, 0, 1/(yu*yv)}, yw] + 
     4*G[{0, 1}, yv^(-1)]*G[{0, 0, 1/(yu*yv)}, yw] - 
     4*G[{0, yu^(-1)}, yw]*G[{0, 0, 1/(yu*yv)}, yw] - 
     4*G[{0, yu}, yv^(-1)]*G[{0, 0, 1/(yu*yv)}, yw] + 
     4*G[{0, 1/(yu*yv)}, yw]*G[{0, 0, 1/(yu*yv)}, yw] + 
     4*G[{1, yu}, yv^(-1)]*G[{0, 0, 1/(yu*yv)}, yw] - 
     (8*Pi^2*G[{0, 1, 1}, yu^(-1)])/3 + 4*G[{1}, yu^(-1)]^2*
      G[{0, 1, 1}, yu^(-1)] - 8*G[{1}, yu^(-1)]*G[{1}, yw]*
      G[{0, 1, 1}, yu^(-1)] + 4*G[{1}, yw]^2*G[{0, 1, 1}, yu^(-1)] + 
     8*G[{0, 1}, yv^(-1)]*G[{0, 1, 1}, yu^(-1)] - 8*G[{0, yu}, yv^(-1)]*
      G[{0, 1, 1}, yu^(-1)] + 8*G[{0, yv^(-1)}, yw]*G[{0, 1, 1}, yu^(-1)] - 
     8*G[{0, 1/(yu*yv)}, yw]*G[{0, 1, 1}, yu^(-1)] - 
     2*Pi^2*G[{0, 1, 1}, yv^(-1)] + 2*G[{0}, yu^(-1)]^2*
      G[{0, 1, 1}, yv^(-1)] + 4*G[{0}, yu^(-1)]*G[{0}, yv^(-1)]*
      G[{0, 1, 1}, yv^(-1)] + 2*G[{0}, yv^(-1)]^2*G[{0, 1, 1}, yv^(-1)] - 
     4*G[{0}, yu^(-1)]*G[{0}, yw]*G[{0, 1, 1}, yv^(-1)] - 
     4*G[{0}, yv^(-1)]*G[{0}, yw]*G[{0, 1, 1}, yv^(-1)] + 
     2*G[{0}, yw]^2*G[{0, 1, 1}, yv^(-1)] - 4*G[{0}, yu^(-1)]*G[{1}, yu^(-1)]*
      G[{0, 1, 1}, yv^(-1)] - 4*G[{0}, yv^(-1)]*G[{1}, yu^(-1)]*
      G[{0, 1, 1}, yv^(-1)] + 4*G[{0}, yw]*G[{1}, yu^(-1)]*
      G[{0, 1, 1}, yv^(-1)] + 2*G[{1}, yu^(-1)]^2*G[{0, 1, 1}, yv^(-1)] + 
     4*G[{0}, yu^(-1)]*G[{1}, yw]*G[{0, 1, 1}, yv^(-1)] + 
     4*G[{0}, yv^(-1)]*G[{1}, yw]*G[{0, 1, 1}, yv^(-1)] - 
     4*G[{0}, yw]*G[{1}, yw]*G[{0, 1, 1}, yv^(-1)] - 
     4*G[{1}, yu^(-1)]*G[{1}, yw]*G[{0, 1, 1}, yv^(-1)] + 
     4*G[{1}, yw]^2*G[{0, 1, 1}, yv^(-1)] - 4*G[{0, 1}, yv^(-1)]*
      G[{0, 1, 1}, yv^(-1)] - 4*G[{0, yu^(-1)}, yw]*G[{0, 1, 1}, yv^(-1)] + 
     4*G[{0, 1/(yu*yv)}, yw]*G[{0, 1, 1}, yv^(-1)] + 
     (8*Pi^2*G[{0, 1, 1}, yw])/3 + 4*G[{1}, yu^(-1)]*G[{1}, yw]*
      G[{0, 1, 1}, yw] - 4*G[{1}, yw]^2*G[{0, 1, 1}, yw] - 
     4*G[{1}, yw]*G[{yu}, yv^(-1)]*G[{0, 1, 1}, yw] - 
     4*G[{0, yu^(-1)}, yw]*G[{0, 1, 1}, yw] + 4*G[{0, 1/(yu*yv)}, yw]*
      G[{0, 1, 1}, yw] + (4*Pi^2*G[{0, 1, yu}, yv^(-1)])/3 + 
     2*G[{0}, yu^(-1)]^2*G[{0, 1, yu}, yv^(-1)] + 
     4*G[{0}, yu^(-1)]*G[{0}, yv^(-1)]*G[{0, 1, yu}, yv^(-1)] + 
     2*G[{0}, yv^(-1)]^2*G[{0, 1, yu}, yv^(-1)] - 
     4*G[{0}, yu^(-1)]*G[{0}, yw]*G[{0, 1, yu}, yv^(-1)] - 
     4*G[{0}, yv^(-1)]*G[{0}, yw]*G[{0, 1, yu}, yv^(-1)] + 
     2*G[{0}, yw]^2*G[{0, 1, yu}, yv^(-1)] - 2*G[{1}, yu^(-1)]^2*
      G[{0, 1, yu}, yv^(-1)] + 4*G[{0}, yu^(-1)]*G[{1}, yw]*
      G[{0, 1, yu}, yv^(-1)] + 4*G[{0}, yv^(-1)]*G[{1}, yw]*
      G[{0, 1, yu}, yv^(-1)] - 4*G[{0}, yw]*G[{1}, yw]*
      G[{0, 1, yu}, yv^(-1)] + 4*G[{0, 1}, yu^(-1)]*G[{0, 1, yu}, yv^(-1)] - 
     (4*Pi^2*G[{0, 1, yv^(-1)}, yw])/3 - 2*G[{0}, yu^(-1)]^2*
      G[{0, 1, yv^(-1)}, yw] - 4*G[{0}, yu^(-1)]*G[{0}, yv^(-1)]*
      G[{0, 1, yv^(-1)}, yw] - 2*G[{0}, yv^(-1)]^2*G[{0, 1, yv^(-1)}, yw] + 
     4*G[{0}, yu^(-1)]*G[{0}, yw]*G[{0, 1, yv^(-1)}, yw] + 
     4*G[{0}, yv^(-1)]*G[{0}, yw]*G[{0, 1, yv^(-1)}, yw] - 
     2*G[{0}, yw]^2*G[{0, 1, yv^(-1)}, yw] + 8*G[{0}, yu^(-1)]*
      G[{1}, yu^(-1)]*G[{0, 1, yv^(-1)}, yw] + 8*G[{0}, yv^(-1)]*
      G[{1}, yu^(-1)]*G[{0, 1, yv^(-1)}, yw] - 8*G[{0}, yw]*G[{1}, yu^(-1)]*
      G[{0, 1, yv^(-1)}, yw] - 6*G[{1}, yu^(-1)]^2*G[{0, 1, yv^(-1)}, yw] - 
     4*G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*G[{0, 1, yv^(-1)}, yw] - 
     4*G[{0}, yu^(-1)]*G[{1}, yw]*G[{0, 1, yv^(-1)}, yw] - 
     4*G[{0}, yv^(-1)]*G[{1}, yw]*G[{0, 1, yv^(-1)}, yw] + 
     4*G[{0}, yw]*G[{1}, yw]*G[{0, 1, yv^(-1)}, yw] + 
     8*G[{1}, yu^(-1)]*G[{1}, yw]*G[{0, 1, yv^(-1)}, yw] - 
     4*G[{0, 1}, yu^(-1)]*G[{0, 1, yv^(-1)}, yw] + 4*G[{1, yu}, yv^(-1)]*
      G[{0, 1, yv^(-1)}, yw] - 4*G[{0}, yu^(-1)]*G[{1}, yu^(-1)]*
      G[{0, 1, 1/(yu*yv)}, yw] - 4*G[{0}, yv^(-1)]*G[{1}, yu^(-1)]*
      G[{0, 1, 1/(yu*yv)}, yw] + 4*G[{0}, yw]*G[{1}, yu^(-1)]*
      G[{0, 1, 1/(yu*yv)}, yw] + 4*G[{1}, yu^(-1)]^2*
      G[{0, 1, 1/(yu*yv)}, yw] - 4*G[{1}, yu^(-1)]*G[{1}, yw]*
      G[{0, 1, 1/(yu*yv)}, yw] + 4*G[{0}, yu^(-1)]*G[{yu}, yv^(-1)]*
      G[{0, 1, 1/(yu*yv)}, yw] + 4*G[{0}, yv^(-1)]*G[{yu}, yv^(-1)]*
      G[{0, 1, 1/(yu*yv)}, yw] - 4*G[{0}, yw]*G[{yu}, yv^(-1)]*
      G[{0, 1, 1/(yu*yv)}, yw] + 4*G[{1}, yw]*G[{yu}, yv^(-1)]*
      G[{0, 1, 1/(yu*yv)}, yw] - 4*G[{yu}, yv^(-1)]^2*
      G[{0, 1, 1/(yu*yv)}, yw] + 4*G[{0, yv^(-1)}, yw]*
      G[{0, 1, 1/(yu*yv)}, yw] + 4*G[{0, 1/(yu*yv)}, yw]*
      G[{0, 1, 1/(yu*yv)}, yw] - 4*G[{1}, yu^(-1)]*G[{1}, yw]*
      G[{0, yu^(-1), 1}, yw] + 4*G[{1}, yw]*G[{yu}, yv^(-1)]*
      G[{0, yu^(-1), 1}, yw] - 4*G[{0, 1/(yu*yv)}, yw]*
      G[{0, yu^(-1), 1}, yw] - (8*Pi^2*G[{0, yu^(-1), yu^(-1)}, yw])/3 + 
     4*G[{1}, yw]^2*G[{0, yu^(-1), yu^(-1)}, yw] + 
     (2*Pi^2*G[{0, yu^(-1), 1/(yu*yv)}, yw])/3 + 2*G[{0}, yu^(-1)]^2*
      G[{0, yu^(-1), 1/(yu*yv)}, yw] + 4*G[{0}, yu^(-1)]*G[{0}, yv^(-1)]*
      G[{0, yu^(-1), 1/(yu*yv)}, yw] + 2*G[{0}, yv^(-1)]^2*
      G[{0, yu^(-1), 1/(yu*yv)}, yw] - 4*G[{0}, yu^(-1)]*G[{0}, yw]*
      G[{0, yu^(-1), 1/(yu*yv)}, yw] - 4*G[{0}, yv^(-1)]*G[{0}, yw]*
      G[{0, yu^(-1), 1/(yu*yv)}, yw] + 2*G[{0}, yw]^2*
      G[{0, yu^(-1), 1/(yu*yv)}, yw] - 4*G[{0}, yu^(-1)]*G[{1}, yu^(-1)]*
      G[{0, yu^(-1), 1/(yu*yv)}, yw] - 4*G[{0}, yv^(-1)]*G[{1}, yu^(-1)]*
      G[{0, yu^(-1), 1/(yu*yv)}, yw] + 4*G[{0}, yw]*G[{1}, yu^(-1)]*
      G[{0, yu^(-1), 1/(yu*yv)}, yw] + 2*G[{1}, yu^(-1)]^2*
      G[{0, yu^(-1), 1/(yu*yv)}, yw] - 4*G[{0}, yu^(-1)]*G[{1}, yv^(-1)]*
      G[{0, yu^(-1), 1/(yu*yv)}, yw] - 4*G[{0}, yv^(-1)]*G[{1}, yv^(-1)]*
      G[{0, yu^(-1), 1/(yu*yv)}, yw] + 4*G[{0}, yw]*G[{1}, yv^(-1)]*
      G[{0, yu^(-1), 1/(yu*yv)}, yw] + 4*G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*
      G[{0, yu^(-1), 1/(yu*yv)}, yw] + 4*G[{1}, yv^(-1)]^2*
      G[{0, yu^(-1), 1/(yu*yv)}, yw] + 4*G[{0}, yu^(-1)]*G[{1}, yw]*
      G[{0, yu^(-1), 1/(yu*yv)}, yw] + 4*G[{0}, yv^(-1)]*G[{1}, yw]*
      G[{0, yu^(-1), 1/(yu*yv)}, yw] - 4*G[{0}, yw]*G[{1}, yw]*
      G[{0, yu^(-1), 1/(yu*yv)}, yw] - 4*G[{1}, yu^(-1)]*G[{1}, yw]*
      G[{0, yu^(-1), 1/(yu*yv)}, yw] - 4*G[{1}, yw]*G[{yu}, yv^(-1)]*
      G[{0, yu^(-1), 1/(yu*yv)}, yw] - 4*G[{0, 1}, yv^(-1)]*
      G[{0, yu^(-1), 1/(yu*yv)}, yw] + 4*G[{0, 1}, yw]*
      G[{0, yu^(-1), 1/(yu*yv)}, yw] - 4*G[{0, yu^(-1)}, yw]*
      G[{0, yu^(-1), 1/(yu*yv)}, yw] + 4*G[{0, yu}, yv^(-1)]*
      G[{0, yu^(-1), 1/(yu*yv)}, yw] - 4*G[{0, 1/(yu*yv)}, yw]*
      G[{0, yu^(-1), 1/(yu*yv)}, yw] - 4*G[{1, yu}, yv^(-1)]*
      G[{0, yu^(-1), 1/(yu*yv)}, yw] + 4*G[{0}, yu^(-1)]*G[{1}, yu^(-1)]*
      G[{0, yu, 1}, yv^(-1)] + 4*G[{0}, yv^(-1)]*G[{1}, yu^(-1)]*
      G[{0, yu, 1}, yv^(-1)] - 4*G[{0}, yw]*G[{1}, yu^(-1)]*
      G[{0, yu, 1}, yv^(-1)] - 4*G[{1}, yu^(-1)]^2*G[{0, yu, 1}, yv^(-1)] + 
     4*G[{1}, yu^(-1)]*G[{1}, yw]*G[{0, yu, 1}, yv^(-1)] + 
     4*G[{0, yu^(-1)}, yw]*G[{0, yu, 1}, yv^(-1)] - 
     4*G[{0, 1/(yu*yv)}, yw]*G[{0, yu, 1}, yv^(-1)] - 
     4*G[{0}, yu^(-1)]^2*G[{0, yu, yu}, yv^(-1)] - 
     8*G[{0}, yu^(-1)]*G[{0}, yv^(-1)]*G[{0, yu, yu}, yv^(-1)] - 
     4*G[{0}, yv^(-1)]^2*G[{0, yu, yu}, yv^(-1)] + 
     8*G[{0}, yu^(-1)]*G[{0}, yw]*G[{0, yu, yu}, yv^(-1)] + 
     8*G[{0}, yv^(-1)]*G[{0}, yw]*G[{0, yu, yu}, yv^(-1)] - 
     4*G[{0}, yw]^2*G[{0, yu, yu}, yv^(-1)] + 4*G[{1}, yu^(-1)]^2*
      G[{0, yu, yu}, yv^(-1)] - 8*G[{0}, yu^(-1)]*G[{1}, yw]*
      G[{0, yu, yu}, yv^(-1)] - 8*G[{0}, yv^(-1)]*G[{1}, yw]*
      G[{0, yu, yu}, yv^(-1)] + 8*G[{0}, yw]*G[{1}, yw]*
      G[{0, yu, yu}, yv^(-1)] - 4*G[{1}, yw]^2*G[{0, yu, yu}, yv^(-1)] - 
     8*G[{0, 1}, yu^(-1)]*G[{0, yu, yu}, yv^(-1)] - 
     (4*Pi^2*G[{0, yv^(-1), 1}, yw])/3 - 2*G[{0}, yu^(-1)]^2*
      G[{0, yv^(-1), 1}, yw] - 4*G[{0}, yu^(-1)]*G[{0}, yv^(-1)]*
      G[{0, yv^(-1), 1}, yw] - 2*G[{0}, yv^(-1)]^2*G[{0, yv^(-1), 1}, yw] + 
     4*G[{0}, yu^(-1)]*G[{0}, yw]*G[{0, yv^(-1), 1}, yw] + 
     4*G[{0}, yv^(-1)]*G[{0}, yw]*G[{0, yv^(-1), 1}, yw] - 
     2*G[{0}, yw]^2*G[{0, yv^(-1), 1}, yw] + 4*G[{0}, yu^(-1)]*
      G[{1}, yu^(-1)]*G[{0, yv^(-1), 1}, yw] + 4*G[{0}, yv^(-1)]*
      G[{1}, yu^(-1)]*G[{0, yv^(-1), 1}, yw] - 4*G[{0}, yw]*G[{1}, yu^(-1)]*
      G[{0, yv^(-1), 1}, yw] - 2*G[{1}, yu^(-1)]^2*G[{0, yv^(-1), 1}, yw] - 
     4*G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*G[{0, yv^(-1), 1}, yw] - 
     4*G[{0}, yu^(-1)]*G[{1}, yw]*G[{0, yv^(-1), 1}, yw] - 
     4*G[{0}, yv^(-1)]*G[{1}, yw]*G[{0, yv^(-1), 1}, yw] + 
     4*G[{0}, yw]*G[{1}, yw]*G[{0, yv^(-1), 1}, yw] + 
     4*G[{1}, yu^(-1)]*G[{1}, yw]*G[{0, yv^(-1), 1}, yw] + 
     4*G[{0}, yu^(-1)]*G[{yu}, yv^(-1)]*G[{0, yv^(-1), 1}, yw] + 
     4*G[{0}, yv^(-1)]*G[{yu}, yv^(-1)]*G[{0, yv^(-1), 1}, yw] - 
     4*G[{0}, yw]*G[{yu}, yv^(-1)]*G[{0, yv^(-1), 1}, yw] + 
     4*G[{1}, yw]*G[{yu}, yv^(-1)]*G[{0, yv^(-1), 1}, yw] - 
     4*G[{yu}, yv^(-1)]^2*G[{0, yv^(-1), 1}, yw] - 4*G[{0, 1}, yu^(-1)]*
      G[{0, yv^(-1), 1}, yw] - 4*G[{0, 1/(yu*yv)}, yw]*
      G[{0, yv^(-1), 1}, yw] + 4*G[{1, yu}, yv^(-1)]*G[{0, yv^(-1), 1}, yw] + 
     4*G[{0}, yu^(-1)]^2*G[{0, yv^(-1), yv^(-1)}, yw] + 
     8*G[{0}, yu^(-1)]*G[{0}, yv^(-1)]*G[{0, yv^(-1), yv^(-1)}, yw] + 
     4*G[{0}, yv^(-1)]^2*G[{0, yv^(-1), yv^(-1)}, yw] - 
     8*G[{0}, yu^(-1)]*G[{0}, yw]*G[{0, yv^(-1), yv^(-1)}, yw] - 
     8*G[{0}, yv^(-1)]*G[{0}, yw]*G[{0, yv^(-1), yv^(-1)}, yw] + 
     4*G[{0}, yw]^2*G[{0, yv^(-1), yv^(-1)}, yw] - 
     16*G[{0}, yu^(-1)]*G[{1}, yu^(-1)]*G[{0, yv^(-1), yv^(-1)}, yw] - 
     16*G[{0}, yv^(-1)]*G[{1}, yu^(-1)]*G[{0, yv^(-1), yv^(-1)}, yw] + 
     16*G[{0}, yw]*G[{1}, yu^(-1)]*G[{0, yv^(-1), yv^(-1)}, yw] + 
     12*G[{1}, yu^(-1)]^2*G[{0, yv^(-1), yv^(-1)}, yw] + 
     8*G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*G[{0, yv^(-1), yv^(-1)}, yw] + 
     8*G[{0}, yu^(-1)]*G[{1}, yw]*G[{0, yv^(-1), yv^(-1)}, yw] + 
     8*G[{0}, yv^(-1)]*G[{1}, yw]*G[{0, yv^(-1), yv^(-1)}, yw] - 
     8*G[{0}, yw]*G[{1}, yw]*G[{0, yv^(-1), yv^(-1)}, yw] - 
     16*G[{1}, yu^(-1)]*G[{1}, yw]*G[{0, yv^(-1), yv^(-1)}, yw] + 
     4*G[{1}, yw]^2*G[{0, yv^(-1), yv^(-1)}, yw] + 8*G[{0, 1}, yu^(-1)]*
      G[{0, yv^(-1), yv^(-1)}, yw] - 8*G[{1, yu}, yv^(-1)]*
      G[{0, yv^(-1), yv^(-1)}, yw] + 4*G[{0}, yu^(-1)]*G[{1}, yu^(-1)]*
      G[{0, yv^(-1), 1/(yu*yv)}, yw] + 4*G[{0}, yv^(-1)]*G[{1}, yu^(-1)]*
      G[{0, yv^(-1), 1/(yu*yv)}, yw] - 4*G[{0}, yw]*G[{1}, yu^(-1)]*
      G[{0, yv^(-1), 1/(yu*yv)}, yw] - 4*G[{1}, yu^(-1)]^2*
      G[{0, yv^(-1), 1/(yu*yv)}, yw] + 4*G[{1}, yu^(-1)]*G[{1}, yw]*
      G[{0, yv^(-1), 1/(yu*yv)}, yw] - 4*G[{0}, yu^(-1)]*G[{yu}, yv^(-1)]*
      G[{0, yv^(-1), 1/(yu*yv)}, yw] - 4*G[{0}, yv^(-1)]*G[{yu}, yv^(-1)]*
      G[{0, yv^(-1), 1/(yu*yv)}, yw] + 4*G[{0}, yw]*G[{yu}, yv^(-1)]*
      G[{0, yv^(-1), 1/(yu*yv)}, yw] - 4*G[{1}, yw]*G[{yu}, yv^(-1)]*
      G[{0, yv^(-1), 1/(yu*yv)}, yw] + 4*G[{yu}, yv^(-1)]^2*
      G[{0, yv^(-1), 1/(yu*yv)}, yw] - 4*G[{0, 1/(yu*yv)}, yw]*
      G[{0, yv^(-1), 1/(yu*yv)}, yw] - (4*Pi^2*G[{0, 1/(yu*yv), 1}, yw])/3 + 
     2*G[{0}, yu^(-1)]^2*G[{0, 1/(yu*yv), 1}, yw] + 
     4*G[{0}, yu^(-1)]*G[{0}, yv^(-1)]*G[{0, 1/(yu*yv), 1}, yw] + 
     2*G[{0}, yv^(-1)]^2*G[{0, 1/(yu*yv), 1}, yw] - 
     4*G[{0}, yu^(-1)]*G[{0}, yw]*G[{0, 1/(yu*yv), 1}, yw] - 
     4*G[{0}, yv^(-1)]*G[{0}, yw]*G[{0, 1/(yu*yv), 1}, yw] + 
     2*G[{0}, yw]^2*G[{0, 1/(yu*yv), 1}, yw] - 4*G[{0}, yu^(-1)]*
      G[{1}, yu^(-1)]*G[{0, 1/(yu*yv), 1}, yw] - 4*G[{0}, yv^(-1)]*
      G[{1}, yu^(-1)]*G[{0, 1/(yu*yv), 1}, yw] + 4*G[{0}, yw]*G[{1}, yu^(-1)]*
      G[{0, 1/(yu*yv), 1}, yw] + 2*G[{1}, yu^(-1)]^2*
      G[{0, 1/(yu*yv), 1}, yw] + 4*G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*
      G[{0, 1/(yu*yv), 1}, yw] + 4*G[{0}, yu^(-1)]*G[{1}, yw]*
      G[{0, 1/(yu*yv), 1}, yw] + 4*G[{0}, yv^(-1)]*G[{1}, yw]*
      G[{0, 1/(yu*yv), 1}, yw] - 4*G[{0}, yw]*G[{1}, yw]*
      G[{0, 1/(yu*yv), 1}, yw] - 4*G[{1}, yu^(-1)]*G[{1}, yw]*
      G[{0, 1/(yu*yv), 1}, yw] + 4*G[{1}, yw]^2*G[{0, 1/(yu*yv), 1}, yw] - 
     4*G[{0}, yu^(-1)]*G[{yu}, yv^(-1)]*G[{0, 1/(yu*yv), 1}, yw] - 
     4*G[{0}, yv^(-1)]*G[{yu}, yv^(-1)]*G[{0, 1/(yu*yv), 1}, yw] + 
     4*G[{0}, yw]*G[{yu}, yv^(-1)]*G[{0, 1/(yu*yv), 1}, yw] - 
     4*G[{1}, yw]*G[{yu}, yv^(-1)]*G[{0, 1/(yu*yv), 1}, yw] + 
     4*G[{yu}, yv^(-1)]^2*G[{0, 1/(yu*yv), 1}, yw] + 
     4*G[{0, 1}, yu^(-1)]*G[{0, 1/(yu*yv), 1}, yw] - 
     4*G[{1, yu}, yv^(-1)]*G[{0, 1/(yu*yv), 1}, yw] + 
     (8*Pi^2*G[{0, 1/(yu*yv), yu^(-1)}, yw])/3 - 
     4*G[{1}, yw]^2*G[{0, 1/(yu*yv), yu^(-1)}, yw] + 
     (4*Pi^2*G[{0, 1/(yu*yv), yv^(-1)}, yw])/3 - 2*G[{0}, yu^(-1)]^2*
      G[{0, 1/(yu*yv), yv^(-1)}, yw] - 4*G[{0}, yu^(-1)]*G[{0}, yv^(-1)]*
      G[{0, 1/(yu*yv), yv^(-1)}, yw] - 2*G[{0}, yv^(-1)]^2*
      G[{0, 1/(yu*yv), yv^(-1)}, yw] + 4*G[{0}, yu^(-1)]*G[{0}, yw]*
      G[{0, 1/(yu*yv), yv^(-1)}, yw] + 4*G[{0}, yv^(-1)]*G[{0}, yw]*
      G[{0, 1/(yu*yv), yv^(-1)}, yw] - 2*G[{0}, yw]^2*
      G[{0, 1/(yu*yv), yv^(-1)}, yw] + 8*G[{0}, yu^(-1)]*G[{1}, yu^(-1)]*
      G[{0, 1/(yu*yv), yv^(-1)}, yw] + 8*G[{0}, yv^(-1)]*G[{1}, yu^(-1)]*
      G[{0, 1/(yu*yv), yv^(-1)}, yw] - 8*G[{0}, yw]*G[{1}, yu^(-1)]*
      G[{0, 1/(yu*yv), yv^(-1)}, yw] - 6*G[{1}, yu^(-1)]^2*
      G[{0, 1/(yu*yv), yv^(-1)}, yw] - 4*G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*
      G[{0, 1/(yu*yv), yv^(-1)}, yw] - 4*G[{0}, yu^(-1)]*G[{1}, yw]*
      G[{0, 1/(yu*yv), yv^(-1)}, yw] - 4*G[{0}, yv^(-1)]*G[{1}, yw]*
      G[{0, 1/(yu*yv), yv^(-1)}, yw] + 4*G[{0}, yw]*G[{1}, yw]*
      G[{0, 1/(yu*yv), yv^(-1)}, yw] + 8*G[{1}, yu^(-1)]*G[{1}, yw]*
      G[{0, 1/(yu*yv), yv^(-1)}, yw] - 4*G[{1}, yw]^2*
      G[{0, 1/(yu*yv), yv^(-1)}, yw] - 4*G[{0, 1}, yu^(-1)]*
      G[{0, 1/(yu*yv), yv^(-1)}, yw] + 4*G[{1, yu}, yv^(-1)]*
      G[{0, 1/(yu*yv), yv^(-1)}, yw] - 
     (2*Pi^2*G[{0, 1/(yu*yv), 1/(yu*yv)}, yw])/3 - 
     2*G[{0}, yu^(-1)]^2*G[{0, 1/(yu*yv), 1/(yu*yv)}, yw] - 
     4*G[{0}, yu^(-1)]*G[{0}, yv^(-1)]*G[{0, 1/(yu*yv), 1/(yu*yv)}, yw] - 
     2*G[{0}, yv^(-1)]^2*G[{0, 1/(yu*yv), 1/(yu*yv)}, yw] + 
     4*G[{0}, yu^(-1)]*G[{0}, yw]*G[{0, 1/(yu*yv), 1/(yu*yv)}, yw] + 
     4*G[{0}, yv^(-1)]*G[{0}, yw]*G[{0, 1/(yu*yv), 1/(yu*yv)}, yw] - 
     2*G[{0}, yw]^2*G[{0, 1/(yu*yv), 1/(yu*yv)}, yw] + 
     4*G[{0}, yu^(-1)]*G[{1}, yu^(-1)]*G[{0, 1/(yu*yv), 1/(yu*yv)}, yw] + 
     4*G[{0}, yv^(-1)]*G[{1}, yu^(-1)]*G[{0, 1/(yu*yv), 1/(yu*yv)}, yw] - 
     4*G[{0}, yw]*G[{1}, yu^(-1)]*G[{0, 1/(yu*yv), 1/(yu*yv)}, yw] - 
     2*G[{1}, yu^(-1)]^2*G[{0, 1/(yu*yv), 1/(yu*yv)}, yw] + 
     4*G[{0}, yu^(-1)]*G[{1}, yv^(-1)]*G[{0, 1/(yu*yv), 1/(yu*yv)}, yw] + 
     4*G[{0}, yv^(-1)]*G[{1}, yv^(-1)]*G[{0, 1/(yu*yv), 1/(yu*yv)}, yw] - 
     4*G[{0}, yw]*G[{1}, yv^(-1)]*G[{0, 1/(yu*yv), 1/(yu*yv)}, yw] - 
     4*G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*G[{0, 1/(yu*yv), 1/(yu*yv)}, yw] - 
     4*G[{1}, yv^(-1)]^2*G[{0, 1/(yu*yv), 1/(yu*yv)}, yw] - 
     4*G[{0}, yu^(-1)]*G[{1}, yw]*G[{0, 1/(yu*yv), 1/(yu*yv)}, yw] - 
     4*G[{0}, yv^(-1)]*G[{1}, yw]*G[{0, 1/(yu*yv), 1/(yu*yv)}, yw] + 
     4*G[{0}, yw]*G[{1}, yw]*G[{0, 1/(yu*yv), 1/(yu*yv)}, yw] + 
     4*G[{1}, yu^(-1)]*G[{1}, yw]*G[{0, 1/(yu*yv), 1/(yu*yv)}, yw] + 
     4*G[{1}, yw]*G[{yu}, yv^(-1)]*G[{0, 1/(yu*yv), 1/(yu*yv)}, yw] + 
     4*G[{0, 1}, yv^(-1)]*G[{0, 1/(yu*yv), 1/(yu*yv)}, yw] - 
     4*G[{0, 1}, yw]*G[{0, 1/(yu*yv), 1/(yu*yv)}, yw] + 
     4*G[{0, yu^(-1)}, yw]*G[{0, 1/(yu*yv), 1/(yu*yv)}, yw] - 
     4*G[{0, yu}, yv^(-1)]*G[{0, 1/(yu*yv), 1/(yu*yv)}, yw] + 
     4*G[{0, yv^(-1)}, yw]*G[{0, 1/(yu*yv), 1/(yu*yv)}, yw] - 
     4*G[{0, 1/(yu*yv)}, yw]*G[{0, 1/(yu*yv), 1/(yu*yv)}, yw] + 
     4*G[{1, yu}, yv^(-1)]*G[{0, 1/(yu*yv), 1/(yu*yv)}, yw] + 
     4*G[{0, yu^(-1)}, yw]*G[{1, 1, yu}, yv^(-1)] - 
     4*G[{0, 1/(yu*yv)}, yw]*G[{1, 1, yu}, yv^(-1)] + 
     8*G[{0, yv^(-1)}, yw]*G[{1, yu, yu}, yv^(-1)] - 
     8*G[{0, 1/(yu*yv)}, yw]*G[{1, yu, yu}, yv^(-1)] - 
     4*G[{0}, yu^(-1)]*G[{0, 0, 0, 1}, yv^(-1)] - 
     4*G[{0}, yv^(-1)]*G[{0, 0, 0, 1}, yv^(-1)] + 
     4*G[{0}, yw]*G[{0, 0, 0, 1}, yv^(-1)] - 4*G[{0}, yu^(-1)]*
      G[{0, 0, 0, 1}, yw] - 4*G[{0}, yv^(-1)]*G[{0, 0, 0, 1}, yw] + 
     4*G[{0}, yw]*G[{0, 0, 0, 1}, yw] + 8*G[{yu}, yv^(-1)]*
      G[{0, 0, 0, 1}, yw] + 4*G[{0}, yu^(-1)]*G[{0, 0, 0, yu^(-1)}, yw] + 
     4*G[{0}, yv^(-1)]*G[{0, 0, 0, yu^(-1)}, yw] - 
     4*G[{0}, yw]*G[{0, 0, 0, yu^(-1)}, yw] - 8*G[{1}, yv^(-1)]*
      G[{0, 0, 0, yu^(-1)}, yw] + 4*G[{0}, yu^(-1)]*
      G[{0, 0, 0, yu}, yv^(-1)] + 4*G[{0}, yv^(-1)]*
      G[{0, 0, 0, yu}, yv^(-1)] - 4*G[{0}, yw]*G[{0, 0, 0, yu}, yv^(-1)] + 
     4*G[{0}, yu^(-1)]*G[{0, 0, 0, yv^(-1)}, yw] + 
     4*G[{0}, yv^(-1)]*G[{0, 0, 0, yv^(-1)}, yw] - 
     4*G[{0}, yw]*G[{0, 0, 0, yv^(-1)}, yw] - 8*G[{1}, yu^(-1)]*
      G[{0, 0, 0, yv^(-1)}, yw] - 4*G[{0}, yu^(-1)]*G[{0, 0, 0, 1/(yu*yv)}, 
       yw] - 4*G[{0}, yv^(-1)]*G[{0, 0, 0, 1/(yu*yv)}, yw] + 
     4*G[{0}, yw]*G[{0, 0, 0, 1/(yu*yv)}, yw] + 8*G[{1}, yu^(-1)]*
      G[{0, 0, 0, 1/(yu*yv)}, yw] + 8*G[{1}, yv^(-1)]*
      G[{0, 0, 0, 1/(yu*yv)}, yw] - 8*G[{yu}, yv^(-1)]*
      G[{0, 0, 0, 1/(yu*yv)}, yw] + 8*G[{0}, yu^(-1)]*
      G[{0, 0, 1, 1}, yu^(-1)] + 8*G[{0}, yv^(-1)]*G[{0, 0, 1, 1}, yu^(-1)] - 
     8*G[{0}, yw]*G[{0, 0, 1, 1}, yu^(-1)] - 8*G[{1}, yu^(-1)]*
      G[{0, 0, 1, 1}, yu^(-1)] + 8*G[{1}, yw]*G[{0, 0, 1, 1}, yu^(-1)] - 
     4*G[{0}, yu^(-1)]*G[{0, 0, 1, 1}, yv^(-1)] - 
     4*G[{0}, yv^(-1)]*G[{0, 0, 1, 1}, yv^(-1)] + 
     4*G[{0}, yw]*G[{0, 0, 1, 1}, yv^(-1)] + 4*G[{1}, yu^(-1)]*
      G[{0, 0, 1, 1}, yv^(-1)] - 4*G[{1}, yu^(-1)]*G[{0, 0, 1, 1}, yw] + 
     8*G[{1}, yw]*G[{0, 0, 1, 1}, yw] + 4*G[{yu}, yv^(-1)]*
      G[{0, 0, 1, 1}, yw] - 8*G[{1}, yw]*G[{0, 0, 1, yu^(-1)}, yw] - 
     4*G[{0}, yu^(-1)]*G[{0, 0, 1, yu}, yv^(-1)] - 
     4*G[{0}, yv^(-1)]*G[{0, 0, 1, yu}, yv^(-1)] + 
     4*G[{0}, yw]*G[{0, 0, 1, yu}, yv^(-1)] - 4*G[{0}, yu^(-1)]*
      G[{0, 0, 1, yv^(-1)}, yw] - 4*G[{0}, yv^(-1)]*G[{0, 0, 1, yv^(-1)}, 
       yw] + 4*G[{0}, yw]*G[{0, 0, 1, yv^(-1)}, yw] + 
     8*G[{1}, yu^(-1)]*G[{0, 0, 1, yv^(-1)}, yw] - 
     8*G[{1}, yw]*G[{0, 0, 1, yv^(-1)}, yw] - 4*G[{1}, yu^(-1)]*
      G[{0, 0, 1, 1/(yu*yv)}, yw] + 8*G[{1}, yw]*G[{0, 0, 1, 1/(yu*yv)}, 
       yw] + 4*G[{yu}, yv^(-1)]*G[{0, 0, 1, 1/(yu*yv)}, yw] + 
     4*G[{1}, yu^(-1)]*G[{0, 0, yu^(-1), 1}, yw] - 
     8*G[{1}, yw]*G[{0, 0, yu^(-1), 1}, yw] - 4*G[{yu}, yv^(-1)]*
      G[{0, 0, yu^(-1), 1}, yw] + 4*G[{0}, yu^(-1)]*
      G[{0, 0, yu^(-1), 1/(yu*yv)}, yw] + 4*G[{0}, yv^(-1)]*
      G[{0, 0, yu^(-1), 1/(yu*yv)}, yw] - 4*G[{0}, yw]*
      G[{0, 0, yu^(-1), 1/(yu*yv)}, yw] - 4*G[{1}, yu^(-1)]*
      G[{0, 0, yu^(-1), 1/(yu*yv)}, yw] - 8*G[{1}, yv^(-1)]*
      G[{0, 0, yu^(-1), 1/(yu*yv)}, yw] + 4*G[{yu}, yv^(-1)]*
      G[{0, 0, yu^(-1), 1/(yu*yv)}, yw] - 4*G[{1}, yu^(-1)]*
      G[{0, 0, yu, 1}, yv^(-1)] + 8*G[{0}, yu^(-1)]*
      G[{0, 0, yu, yu}, yv^(-1)] + 8*G[{0}, yv^(-1)]*
      G[{0, 0, yu, yu}, yv^(-1)] - 8*G[{0}, yw]*G[{0, 0, yu, yu}, yv^(-1)] + 
     8*G[{1}, yw]*G[{0, 0, yu, yu}, yv^(-1)] - 4*G[{0}, yu^(-1)]*
      G[{0, 0, yv^(-1), 1}, yw] - 4*G[{0}, yv^(-1)]*G[{0, 0, yv^(-1), 1}, 
       yw] + 4*G[{0}, yw]*G[{0, 0, yv^(-1), 1}, yw] + 
     4*G[{1}, yu^(-1)]*G[{0, 0, yv^(-1), 1}, yw] - 
     8*G[{1}, yw]*G[{0, 0, yv^(-1), 1}, yw] + 4*G[{yu}, yv^(-1)]*
      G[{0, 0, yv^(-1), 1}, yw] + 8*G[{0}, yu^(-1)]*
      G[{0, 0, yv^(-1), yv^(-1)}, yw] + 8*G[{0}, yv^(-1)]*
      G[{0, 0, yv^(-1), yv^(-1)}, yw] - 8*G[{0}, yw]*
      G[{0, 0, yv^(-1), yv^(-1)}, yw] - 16*G[{1}, yu^(-1)]*
      G[{0, 0, yv^(-1), yv^(-1)}, yw] + 8*G[{1}, yw]*
      G[{0, 0, yv^(-1), yv^(-1)}, yw] + 4*G[{1}, yu^(-1)]*
      G[{0, 0, yv^(-1), 1/(yu*yv)}, yw] - 8*G[{1}, yw]*
      G[{0, 0, yv^(-1), 1/(yu*yv)}, yw] - 4*G[{yu}, yv^(-1)]*
      G[{0, 0, yv^(-1), 1/(yu*yv)}, yw] + 4*G[{0}, yu^(-1)]*
      G[{0, 0, 1/(yu*yv), 1}, yw] + 4*G[{0}, yv^(-1)]*
      G[{0, 0, 1/(yu*yv), 1}, yw] - 4*G[{0}, yw]*G[{0, 0, 1/(yu*yv), 1}, 
       yw] - 4*G[{1}, yu^(-1)]*G[{0, 0, 1/(yu*yv), 1}, yw] + 
     8*G[{1}, yw]*G[{0, 0, 1/(yu*yv), 1}, yw] - 4*G[{yu}, yv^(-1)]*
      G[{0, 0, 1/(yu*yv), 1}, yw] - 4*G[{0}, yu^(-1)]*
      G[{0, 0, 1/(yu*yv), yv^(-1)}, yw] - 4*G[{0}, yv^(-1)]*
      G[{0, 0, 1/(yu*yv), yv^(-1)}, yw] + 4*G[{0}, yw]*
      G[{0, 0, 1/(yu*yv), yv^(-1)}, yw] + 8*G[{1}, yu^(-1)]*
      G[{0, 0, 1/(yu*yv), yv^(-1)}, yw] - 8*G[{1}, yw]*
      G[{0, 0, 1/(yu*yv), yv^(-1)}, yw] - 4*G[{0}, yu^(-1)]*
      G[{0, 0, 1/(yu*yv), 1/(yu*yv)}, yw] - 4*G[{0}, yv^(-1)]*
      G[{0, 0, 1/(yu*yv), 1/(yu*yv)}, yw] + 4*G[{0}, yw]*
      G[{0, 0, 1/(yu*yv), 1/(yu*yv)}, yw] + 4*G[{1}, yu^(-1)]*
      G[{0, 0, 1/(yu*yv), 1/(yu*yv)}, yw] + 8*G[{1}, yv^(-1)]*
      G[{0, 0, 1/(yu*yv), 1/(yu*yv)}, yw] - 4*G[{yu}, yv^(-1)]*
      G[{0, 0, 1/(yu*yv), 1/(yu*yv)}, yw] - 4*G[{1}, yw]*
      G[{0, 1, 0, yu^(-1)}, yw] + 4*G[{1}, yw]*G[{0, 1, 0, yu}, yv^(-1)] + 
     4*G[{1}, yw]*G[{0, 1, 0, 1/(yu*yv)}, yw] - 12*G[{1}, yu^(-1)]*
      G[{0, 1, 1, 1}, yu^(-1)] + 12*G[{1}, yw]*G[{0, 1, 1, 1}, yu^(-1)] - 
     4*G[{0}, yu^(-1)]*G[{0, 1, 1, 1}, yv^(-1)] - 
     4*G[{0}, yv^(-1)]*G[{0, 1, 1, 1}, yv^(-1)] + 
     4*G[{0}, yw]*G[{0, 1, 1, 1}, yv^(-1)] + 4*G[{1}, yu^(-1)]*
      G[{0, 1, 1, 1}, yv^(-1)] - 4*G[{1}, yu^(-1)]*G[{0, 1, 1, 1}, yw] + 
     12*G[{1}, yw]*G[{0, 1, 1, 1}, yw] + 4*G[{yu}, yv^(-1)]*
      G[{0, 1, 1, 1}, yw] - 4*G[{1}, yw]*G[{0, 1, 1, yu}, yv^(-1)] - 
     4*G[{1}, yw]*G[{0, 1, 1, yv^(-1)}, yw] + 4*G[{1}, yu^(-1)]*
      G[{0, 1, yu, 1}, yv^(-1)] - 8*G[{0}, yu^(-1)]*
      G[{0, 1, yu, yu}, yv^(-1)] - 8*G[{0}, yv^(-1)]*
      G[{0, 1, yu, yu}, yv^(-1)] + 8*G[{0}, yw]*G[{0, 1, yu, yu}, yv^(-1)] - 
     8*G[{1}, yw]*G[{0, 1, yu, yu}, yv^(-1)] + 4*G[{0}, yu^(-1)]*
      G[{0, 1, yv^(-1), 1}, yw] + 4*G[{0}, yv^(-1)]*G[{0, 1, yv^(-1), 1}, 
       yw] - 4*G[{0}, yw]*G[{0, 1, yv^(-1), 1}, yw] - 
     4*G[{1}, yu^(-1)]*G[{0, 1, yv^(-1), 1}, yw] - 
     4*G[{yu}, yv^(-1)]*G[{0, 1, yv^(-1), 1}, yw] - 
     8*G[{0}, yu^(-1)]*G[{0, 1, yv^(-1), yv^(-1)}, yw] - 
     8*G[{0}, yv^(-1)]*G[{0, 1, yv^(-1), yv^(-1)}, yw] + 
     8*G[{0}, yw]*G[{0, 1, yv^(-1), yv^(-1)}, yw] + 
     16*G[{1}, yu^(-1)]*G[{0, 1, yv^(-1), yv^(-1)}, yw] - 
     8*G[{1}, yw]*G[{0, 1, yv^(-1), yv^(-1)}, yw] - 
     4*G[{1}, yu^(-1)]*G[{0, 1, yv^(-1), 1/(yu*yv)}, yw] + 
     4*G[{yu}, yv^(-1)]*G[{0, 1, yv^(-1), 1/(yu*yv)}, yw] - 
     4*G[{0}, yu^(-1)]*G[{0, 1, 1/(yu*yv), 1}, yw] - 
     4*G[{0}, yv^(-1)]*G[{0, 1, 1/(yu*yv), 1}, yw] + 
     4*G[{0}, yw]*G[{0, 1, 1/(yu*yv), 1}, yw] + 4*G[{1}, yu^(-1)]*
      G[{0, 1, 1/(yu*yv), 1}, yw] - 4*G[{1}, yw]*G[{0, 1, 1/(yu*yv), 1}, 
       yw] + 4*G[{yu}, yv^(-1)]*G[{0, 1, 1/(yu*yv), 1}, yw] + 
     4*G[{0}, yu^(-1)]*G[{0, 1, 1/(yu*yv), yv^(-1)}, yw] + 
     4*G[{0}, yv^(-1)]*G[{0, 1, 1/(yu*yv), yv^(-1)}, yw] - 
     4*G[{0}, yw]*G[{0, 1, 1/(yu*yv), yv^(-1)}, yw] - 
     8*G[{1}, yu^(-1)]*G[{0, 1, 1/(yu*yv), yv^(-1)}, yw] + 
     4*G[{1}, yw]*G[{0, 1, 1/(yu*yv), yv^(-1)}, yw] - 
     4*G[{1}, yw]*G[{0, yu^(-1), 0, yv^(-1)}, yw] + 
     4*G[{1}, yu^(-1)]*G[{0, yu^(-1), 1, 1}, yw] - 
     4*G[{1}, yw]*G[{0, yu^(-1), 1, 1}, yw] - 4*G[{yu}, yv^(-1)]*
      G[{0, yu^(-1), 1, 1}, yw] + 4*G[{1}, yw]*G[{0, yu^(-1), 1, yv^(-1)}, 
       yw] - 8*G[{1}, yw]*G[{0, yu^(-1), yu^(-1), 1}, yw] + 
     4*G[{1}, yw]*G[{0, yu^(-1), 1/(yu*yv), 1}, yw] + 
     4*G[{1}, yw]*G[{0, yu^(-1), 1/(yu*yv), yv^(-1)}, yw] + 
     4*G[{0}, yu^(-1)]*G[{0, yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] + 
     4*G[{0}, yv^(-1)]*G[{0, yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] - 
     4*G[{0}, yw]*G[{0, yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] - 
     4*G[{1}, yu^(-1)]*G[{0, yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] - 
     8*G[{1}, yv^(-1)]*G[{0, yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] + 
     4*G[{yu}, yv^(-1)]*G[{0, yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] - 
     4*G[{0}, yu^(-1)]*G[{0, yu, 1, yu}, yv^(-1)] - 
     4*G[{0}, yv^(-1)]*G[{0, yu, 1, yu}, yv^(-1)] + 
     4*G[{0}, yw]*G[{0, yu, 1, yu}, yv^(-1)] - 
     4*G[{1}, yw]*G[{0, yu, 1, yu}, yv^(-1)] - 8*G[{1}, yu^(-1)]*
      G[{0, yu, yu, 1}, yv^(-1)] + 16*G[{0}, yu^(-1)]*
      G[{0, yu, yu, yu}, yv^(-1)] + 16*G[{0}, yv^(-1)]*
      G[{0, yu, yu, yu}, yv^(-1)] - 16*G[{0}, yw]*G[{0, yu, yu, yu}, 
       yv^(-1)] + 16*G[{1}, yw]*G[{0, yu, yu, yu}, yv^(-1)] - 
     4*G[{1}, yw]*G[{0, yv^(-1), 0, 1/(yu*yv)}, yw] - 
     4*G[{1}, yw]*G[{0, yv^(-1), 1, 1}, yw] - 4*G[{0}, yu^(-1)]*
      G[{0, yv^(-1), 1, yv^(-1)}, yw] - 4*G[{0}, yv^(-1)]*
      G[{0, yv^(-1), 1, yv^(-1)}, yw] + 4*G[{0}, yw]*
      G[{0, yv^(-1), 1, yv^(-1)}, yw] + 8*G[{1}, yu^(-1)]*
      G[{0, yv^(-1), 1, yv^(-1)}, yw] - 4*G[{1}, yw]*
      G[{0, yv^(-1), 1, yv^(-1)}, yw] - 4*G[{1}, yu^(-1)]*
      G[{0, yv^(-1), 1, 1/(yu*yv)}, yw] + 4*G[{yu}, yv^(-1)]*
      G[{0, yv^(-1), 1, 1/(yu*yv)}, yw] - 8*G[{0}, yu^(-1)]*
      G[{0, yv^(-1), yv^(-1), 1}, yw] - 8*G[{0}, yv^(-1)]*
      G[{0, yv^(-1), yv^(-1), 1}, yw] + 8*G[{0}, yw]*
      G[{0, yv^(-1), yv^(-1), 1}, yw] + 8*G[{1}, yu^(-1)]*
      G[{0, yv^(-1), yv^(-1), 1}, yw] - 8*G[{1}, yw]*
      G[{0, yv^(-1), yv^(-1), 1}, yw] + 8*G[{yu}, yv^(-1)]*
      G[{0, yv^(-1), yv^(-1), 1}, yw] + 16*G[{0}, yu^(-1)]*
      G[{0, yv^(-1), yv^(-1), yv^(-1)}, yw] + 16*G[{0}, yv^(-1)]*
      G[{0, yv^(-1), yv^(-1), yv^(-1)}, yw] - 16*G[{0}, yw]*
      G[{0, yv^(-1), yv^(-1), yv^(-1)}, yw] - 32*G[{1}, yu^(-1)]*
      G[{0, yv^(-1), yv^(-1), yv^(-1)}, yw] + 16*G[{1}, yw]*
      G[{0, yv^(-1), yv^(-1), yv^(-1)}, yw] + 8*G[{1}, yu^(-1)]*
      G[{0, yv^(-1), yv^(-1), 1/(yu*yv)}, yw] - 8*G[{yu}, yv^(-1)]*
      G[{0, yv^(-1), yv^(-1), 1/(yu*yv)}, yw] + 4*G[{0}, yu^(-1)]*
      G[{0, yv^(-1), 1/(yu*yv), 1}, yw] + 4*G[{0}, yv^(-1)]*
      G[{0, yv^(-1), 1/(yu*yv), 1}, yw] - 4*G[{0}, yw]*
      G[{0, yv^(-1), 1/(yu*yv), 1}, yw] - 4*G[{1}, yu^(-1)]*
      G[{0, yv^(-1), 1/(yu*yv), 1}, yw] + 4*G[{1}, yw]*
      G[{0, yv^(-1), 1/(yu*yv), 1}, yw] - 4*G[{yu}, yv^(-1)]*
      G[{0, yv^(-1), 1/(yu*yv), 1}, yw] - 4*G[{0}, yu^(-1)]*
      G[{0, yv^(-1), 1/(yu*yv), yv^(-1)}, yw] - 4*G[{0}, yv^(-1)]*
      G[{0, yv^(-1), 1/(yu*yv), yv^(-1)}, yw] + 
     4*G[{0}, yw]*G[{0, yv^(-1), 1/(yu*yv), yv^(-1)}, yw] + 
     8*G[{1}, yu^(-1)]*G[{0, yv^(-1), 1/(yu*yv), yv^(-1)}, yw] - 
     4*G[{1}, yw]*G[{0, yv^(-1), 1/(yu*yv), yv^(-1)}, yw] - 
     4*G[{1}, yw]*G[{0, 1/(yu*yv), 1, 1}, yw] + 4*G[{0}, yu^(-1)]*
      G[{0, 1/(yu*yv), 1, yv^(-1)}, yw] + 4*G[{0}, yv^(-1)]*
      G[{0, 1/(yu*yv), 1, yv^(-1)}, yw] - 4*G[{0}, yw]*
      G[{0, 1/(yu*yv), 1, yv^(-1)}, yw] - 8*G[{1}, yu^(-1)]*
      G[{0, 1/(yu*yv), 1, yv^(-1)}, yw] + 4*G[{1}, yw]*
      G[{0, 1/(yu*yv), 1, yv^(-1)}, yw] + 4*G[{1}, yu^(-1)]*
      G[{0, 1/(yu*yv), 1, 1/(yu*yv)}, yw] - 4*G[{yu}, yv^(-1)]*
      G[{0, 1/(yu*yv), 1, 1/(yu*yv)}, yw] + 8*G[{1}, yw]*
      G[{0, 1/(yu*yv), yu^(-1), 1}, yw] + 4*G[{0}, yu^(-1)]*
      G[{0, 1/(yu*yv), yv^(-1), 1}, yw] + 4*G[{0}, yv^(-1)]*
      G[{0, 1/(yu*yv), yv^(-1), 1}, yw] - 4*G[{0}, yw]*
      G[{0, 1/(yu*yv), yv^(-1), 1}, yw] - 4*G[{1}, yu^(-1)]*
      G[{0, 1/(yu*yv), yv^(-1), 1}, yw] + 8*G[{1}, yw]*
      G[{0, 1/(yu*yv), yv^(-1), 1}, yw] - 4*G[{yu}, yv^(-1)]*
      G[{0, 1/(yu*yv), yv^(-1), 1}, yw] - 8*G[{0}, yu^(-1)]*
      G[{0, 1/(yu*yv), yv^(-1), yv^(-1)}, yw] - 8*G[{0}, yv^(-1)]*
      G[{0, 1/(yu*yv), yv^(-1), yv^(-1)}, yw] + 
     8*G[{0}, yw]*G[{0, 1/(yu*yv), yv^(-1), yv^(-1)}, yw] + 
     16*G[{1}, yu^(-1)]*G[{0, 1/(yu*yv), yv^(-1), yv^(-1)}, yw] - 
     8*G[{1}, yw]*G[{0, 1/(yu*yv), yv^(-1), yv^(-1)}, yw] - 
     4*G[{1}, yu^(-1)]*G[{0, 1/(yu*yv), yv^(-1), 1/(yu*yv)}, yw] + 
     4*G[{yu}, yv^(-1)]*G[{0, 1/(yu*yv), yv^(-1), 1/(yu*yv)}, yw] - 
     4*G[{1}, yw]*G[{0, 1/(yu*yv), 1/(yu*yv), 1}, yw] - 
     4*G[{1}, yw]*G[{0, 1/(yu*yv), 1/(yu*yv), yv^(-1)}, yw] - 
     4*G[{0}, yu^(-1)]*G[{0, 1/(yu*yv), 1/(yu*yv), 1/(yu*yv)}, yw] - 
     4*G[{0}, yv^(-1)]*G[{0, 1/(yu*yv), 1/(yu*yv), 1/(yu*yv)}, yw] + 
     4*G[{0}, yw]*G[{0, 1/(yu*yv), 1/(yu*yv), 1/(yu*yv)}, yw] + 
     4*G[{1}, yu^(-1)]*G[{0, 1/(yu*yv), 1/(yu*yv), 1/(yu*yv)}, yw] + 
     8*G[{1}, yv^(-1)]*G[{0, 1/(yu*yv), 1/(yu*yv), 1/(yu*yv)}, yw] - 
     4*G[{yu}, yv^(-1)]*G[{0, 1/(yu*yv), 1/(yu*yv), 1/(yu*yv)}, yw] - 
     8*G[{0, 0, 0, 0, 1}, yw] + 8*G[{0, 0, 0, 0, yu^(-1)}, yw] + 
     8*G[{0, 0, 0, 0, yv^(-1)}, yw] - 8*G[{0, 0, 0, 0, 1/(yu*yv)}, yw] - 
     16*G[{0, 0, 0, 1, 1}, yv^(-1)] - 8*G[{0, 0, 0, 1, 1}, yw] + 
     12*G[{0, 0, 0, 1, yu^(-1)}, yw] + 12*G[{0, 0, 0, 1, yu}, yv^(-1)] - 
     12*G[{0, 0, 0, 1, 1/(yu*yv)}, yw] + 12*G[{0, 0, 0, yu^(-1), 1}, yw] - 
     16*G[{0, 0, 0, yu^(-1), yu^(-1)}, yw] - 
     12*G[{0, 0, 0, yu^(-1), yv^(-1)}, yw] + 
     24*G[{0, 0, 0, yu^(-1), 1/(yu*yv)}, yw] + 
     12*G[{0, 0, 0, yu, 1}, yv^(-1)] - 8*G[{0, 0, 0, yu, yu}, yv^(-1)] - 
     12*G[{0, 0, 0, yv^(-1), yu^(-1)}, yw] + 
     8*G[{0, 0, 0, yv^(-1), yv^(-1)}, yw] + 
     12*G[{0, 0, 0, yv^(-1), 1/(yu*yv)}, yw] - 
     4*G[{0, 0, 0, 1/(yu*yv), 1}, yw] + 16*G[{0, 0, 0, 1/(yu*yv), yu^(-1)}, 
       yw] + 4*G[{0, 0, 0, 1/(yu*yv), yv^(-1)}, yw] - 
     24*G[{0, 0, 0, 1/(yu*yv), 1/(yu*yv)}, yw] - 
     8*G[{0, 0, 1, 0, 1}, yv^(-1)] + 4*G[{0, 0, 1, 0, yu^(-1)}, yw] + 
     4*G[{0, 0, 1, 0, yu}, yv^(-1)] - 4*G[{0, 0, 1, 0, 1/(yu*yv)}, yw] + 
     24*G[{0, 0, 1, 1, 1}, yv^(-1)] - 12*G[{0, 0, 1, 1, 1}, yw] + 
     8*G[{0, 0, 1, 1, yu^(-1)}, yw] + 4*G[{0, 0, 1, 1, yu}, yv^(-1)] + 
     4*G[{0, 0, 1, 1, yv^(-1)}, yw] - 8*G[{0, 0, 1, 1, 1/(yu*yv)}, yw] + 
     8*G[{0, 0, 1, yu^(-1), 1}, yw] - 8*G[{0, 0, 1, yu^(-1), 1/(yu*yv)}, 
       yw] + 8*G[{0, 0, 1, yu, yu}, yv^(-1)] + 
     8*G[{0, 0, 1, yv^(-1), 1}, yw] - 8*G[{0, 0, 1, yv^(-1), yv^(-1)}, yw] - 
     8*G[{0, 0, 1, yv^(-1), 1/(yu*yv)}, yw] - 
     12*G[{0, 0, 1, 1/(yu*yv), 1}, yw] - 4*G[{0, 0, 1, 1/(yu*yv), yv^(-1)}, 
       yw] - 8*G[{0, 0, 1, 1/(yu*yv), 1/(yu*yv)}, yw] + 
     4*G[{0, 0, yu^(-1), 0, 1}, yw] - 8*G[{0, 0, yu^(-1), 0, yu^(-1)}, yw] - 
     4*G[{0, 0, yu^(-1), 0, yv^(-1)}, yw] + 
     8*G[{0, 0, yu^(-1), 0, 1/(yu*yv)}, yw] + 
     12*G[{0, 0, yu^(-1), 1, 1}, yw] - 4*G[{0, 0, yu^(-1), 1, yv^(-1)}, yw] + 
     8*G[{0, 0, yu^(-1), yu^(-1), 1}, yw] + 
     16*G[{0, 0, yu^(-1), yu^(-1), 1/(yu*yv)}, yw] - 
     4*G[{0, 0, yu^(-1), 1/(yu*yv), 1}, yw] + 
     8*G[{0, 0, yu^(-1), 1/(yu*yv), yu^(-1)}, yw] - 
     4*G[{0, 0, yu^(-1), 1/(yu*yv), yv^(-1)}, yw] + 
     16*G[{0, 0, yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] + 
     4*G[{0, 0, yu, 0, 1}, yv^(-1)] + 4*G[{0, 0, yu, 1, yu}, yv^(-1)] - 
     16*G[{0, 0, yu, yu, yu}, yv^(-1)] - 4*G[{0, 0, yv^(-1), 0, yu^(-1)}, 
       yw] + 4*G[{0, 0, yv^(-1), 0, 1/(yu*yv)}, yw] + 
     4*G[{0, 0, yv^(-1), 1, 1}, yw] - 4*G[{0, 0, yv^(-1), 1, yv^(-1)}, yw] - 
     8*G[{0, 0, yv^(-1), yv^(-1), 1}, yw] + 
     16*G[{0, 0, yv^(-1), yv^(-1), yv^(-1)}, yw] + 
     12*G[{0, 0, yv^(-1), 1/(yu*yv), 1}, yw] - 
     4*G[{0, 0, yv^(-1), 1/(yu*yv), yv^(-1)}, yw] + 
     8*G[{0, 0, yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] - 
     4*G[{0, 0, 1/(yu*yv), 0, 1}, yw] + 8*G[{0, 0, 1/(yu*yv), 0, yu^(-1)}, 
       yw] + 4*G[{0, 0, 1/(yu*yv), 0, yv^(-1)}, yw] - 
     8*G[{0, 0, 1/(yu*yv), 0, 1/(yu*yv)}, yw] - 
     4*G[{0, 0, 1/(yu*yv), 1, 1}, yw] + 4*G[{0, 0, 1/(yu*yv), 1, yv^(-1)}, 
       yw] + 8*G[{0, 0, 1/(yu*yv), yv^(-1), 1}, yw] - 
     8*G[{0, 0, 1/(yu*yv), yv^(-1), yv^(-1)}, yw] + 
     12*G[{0, 0, 1/(yu*yv), 1/(yu*yv), 1}, yw] - 
     8*G[{0, 0, 1/(yu*yv), 1/(yu*yv), yu^(-1)}, yw] - 
     4*G[{0, 0, 1/(yu*yv), 1/(yu*yv), yv^(-1)}, yw] + 
     16*G[{0, 0, 1/(yu*yv), 1/(yu*yv), 1/(yu*yv)}, yw] + 
     8*G[{0, 1, 0, 1, 1}, yv^(-1)] + 4*G[{0, 1, 0, 1, yu^(-1)}, yw] + 
     4*G[{0, 1, 0, 1, yu}, yv^(-1)] - 4*G[{0, 1, 0, 1, 1/(yu*yv)}, yw] + 
     4*G[{0, 1, 0, yu^(-1), 1}, yw] - 4*G[{0, 1, 0, yu^(-1), 1/(yu*yv)}, 
       yw] - 4*G[{0, 1, 0, yv^(-1), 1/(yu*yv)}, yw] - 
     4*G[{0, 1, 0, 1/(yu*yv), 1}, yw] - 4*G[{0, 1, 0, 1/(yu*yv), yv^(-1)}, 
       yw] - 4*G[{0, 1, 0, 1/(yu*yv), 1/(yu*yv)}, yw] + 
     4*G[{0, 1, 1, 0, yu^(-1)}, yw] + 4*G[{0, 1, 1, 0, yu}, yv^(-1)] - 
     4*G[{0, 1, 1, 0, 1/(yu*yv)}, yw] + 16*G[{0, 1, 1, 1, 1}, yu^(-1)] + 
     8*G[{0, 1, 1, 1, 1}, yv^(-1)] - 16*G[{0, 1, 1, 1, 1}, yw] - 
     4*G[{0, 1, 1, 1, yu}, yv^(-1)] + 4*G[{0, 1, 1, 1, yv^(-1)}, yw] + 
     4*G[{0, 1, 1, yv^(-1), 1}, yw] - 4*G[{0, 1, yu, 1, yu}, yv^(-1)] + 
     16*G[{0, 1, yu, yu, yu}, yv^(-1)] + 4*G[{0, 1, yv^(-1), 1, 1}, yw] + 
     4*G[{0, 1, yv^(-1), 1, yv^(-1)}, yw] + 
     8*G[{0, 1, yv^(-1), yv^(-1), 1}, yw] - 
     16*G[{0, 1, yv^(-1), yv^(-1), yv^(-1)}, yw] - 
     4*G[{0, 1, yv^(-1), 1/(yu*yv), 1}, yw] + 
     4*G[{0, 1, yv^(-1), 1/(yu*yv), yv^(-1)}, yw] - 
     4*G[{0, 1, 1/(yu*yv), 0, yv^(-1)}, yw] - 
     4*G[{0, 1, 1/(yu*yv), 0, 1/(yu*yv)}, yw] - 
     4*G[{0, 1, 1/(yu*yv), 1, yv^(-1)}, yw] - 
     4*G[{0, 1, 1/(yu*yv), yv^(-1), 1}, yw] + 
     8*G[{0, 1, 1/(yu*yv), yv^(-1), yv^(-1)}, yw] + 
     4*G[{0, yu^(-1), 0, yu^(-1), 1}, yw] + 
     8*G[{0, yu^(-1), 0, yu^(-1), 1/(yu*yv)}, yw] + 
     4*G[{0, yu^(-1), 0, yv^(-1), 1}, yw] - 
     4*G[{0, yu^(-1), 0, 1/(yu*yv), yv^(-1)}, yw] + 
     8*G[{0, yu^(-1), 0, 1/(yu*yv), 1/(yu*yv)}, yw] + 
     4*G[{0, yu^(-1), 1, 0, 1/(yu*yv)}, yw] + 
     8*G[{0, yu^(-1), 1, 1, 1}, yw] - 4*G[{0, yu^(-1), 1, 1, yv^(-1)}, yw] - 
     4*G[{0, yu^(-1), 1, yv^(-1), 1}, yw] + 
     8*G[{0, yu^(-1), yu^(-1), 1, 1}, yw] - 
     4*G[{0, yu^(-1), 1/(yu*yv), 0, yv^(-1)}, yw] + 
     8*G[{0, yu^(-1), 1/(yu*yv), 0, 1/(yu*yv)}, yw] - 
     4*G[{0, yu^(-1), 1/(yu*yv), 1, 1}, yw] - 
     4*G[{0, yu^(-1), 1/(yu*yv), yv^(-1), 1}, yw] - 
     4*G[{0, yu^(-1), 1/(yu*yv), 1/(yu*yv), 1}, yw] + 
     8*G[{0, yu^(-1), 1/(yu*yv), 1/(yu*yv), yu^(-1)}, yw] + 
     4*G[{0, yu^(-1), 1/(yu*yv), 1/(yu*yv), yv^(-1)}, yw] + 
     8*G[{0, yu, 1, yu, yu}, yv^(-1)] + 8*G[{0, yu, yu, 1, yu}, yv^(-1)] - 
     32*G[{0, yu, yu, yu, yu}, yv^(-1)] + 
     4*G[{0, yv^(-1), 0, 1/(yu*yv), 1}, yw] + 
     4*G[{0, yv^(-1), 0, 1/(yu*yv), 1/(yu*yv)}, yw] + 
     4*G[{0, yv^(-1), 1, 0, 1/(yu*yv)}, yw] + 
     4*G[{0, yv^(-1), 1, 1, 1}, yw] + 4*G[{0, yv^(-1), 1, yv^(-1), 1}, yw] - 
     8*G[{0, yv^(-1), 1, yv^(-1), yv^(-1)}, yw] - 
     4*G[{0, yv^(-1), 1, 1/(yu*yv), 1}, yw] + 
     4*G[{0, yv^(-1), 1, 1/(yu*yv), yv^(-1)}, yw] - 
     8*G[{0, yv^(-1), yv^(-1), 1, yv^(-1)}, yw] - 
     16*G[{0, yv^(-1), yv^(-1), yv^(-1), 1}, yw] + 
     32*G[{0, yv^(-1), yv^(-1), yv^(-1), yv^(-1)}, yw] + 
     8*G[{0, yv^(-1), yv^(-1), 1/(yu*yv), 1}, yw] - 
     8*G[{0, yv^(-1), yv^(-1), 1/(yu*yv), yv^(-1)}, yw] + 
     4*G[{0, yv^(-1), 1/(yu*yv), 0, 1/(yu*yv)}, yw] + 
     4*G[{0, yv^(-1), 1/(yu*yv), 1, yv^(-1)}, yw] + 
     4*G[{0, yv^(-1), 1/(yu*yv), yv^(-1), 1}, yw] - 
     8*G[{0, yv^(-1), 1/(yu*yv), yv^(-1), yv^(-1)}, yw] + 
     4*G[{0, 1/(yu*yv), 0, 1/(yu*yv), 1}, yw] + 
     8*G[{0, 1/(yu*yv), 0, 1/(yu*yv), 1/(yu*yv)}, yw] + 
     4*G[{0, 1/(yu*yv), 1, 1, 1}, yw] - 4*G[{0, 1/(yu*yv), 1, yv^(-1), 1}, 
       yw] + 8*G[{0, 1/(yu*yv), 1, yv^(-1), yv^(-1)}, yw] + 
     4*G[{0, 1/(yu*yv), 1, 1/(yu*yv), 1}, yw] - 
     4*G[{0, 1/(yu*yv), 1, 1/(yu*yv), yv^(-1)}, yw] - 
     8*G[{0, 1/(yu*yv), yu^(-1), 1, 1}, yw] - 
     4*G[{0, 1/(yu*yv), yv^(-1), 1, 1}, yw] + 
     4*G[{0, 1/(yu*yv), yv^(-1), 1, yv^(-1)}, yw] + 
     8*G[{0, 1/(yu*yv), yv^(-1), yv^(-1), 1}, yw] - 
     16*G[{0, 1/(yu*yv), yv^(-1), yv^(-1), yv^(-1)}, yw] - 
     4*G[{0, 1/(yu*yv), yv^(-1), 1/(yu*yv), 1}, yw] + 
     4*G[{0, 1/(yu*yv), yv^(-1), 1/(yu*yv), yv^(-1)}, yw] + 
     4*G[{0, 1/(yu*yv), 1/(yu*yv), 1, 1}, yw] + 
     4*G[{0, 1/(yu*yv), 1/(yu*yv), yv^(-1), 1}, yw] + 
     4*G[{0, 1/(yu*yv), 1/(yu*yv), 1/(yu*yv), 1}, yw] - 
     8*G[{0, 1/(yu*yv), 1/(yu*yv), 1/(yu*yv), yu^(-1)}, yw] - 
     4*G[{0, 1/(yu*yv), 1/(yu*yv), 1/(yu*yv), yv^(-1)}, yw] + 
     (8*Pi^2*Zeta[3])/3 - 4*G[{1}, yu^(-1)]^2*Zeta[3] + 
     8*G[{1}, yu^(-1)]*G[{1}, yw]*Zeta[3] - 4*G[{1}, yw]^2*Zeta[3] - 
     16*Zeta[5]
 
J1vwuRegII = (13*Pi^4*G[{0}, yu^(-1)])/90 + (13*Pi^4*G[{0}, yv^(-1)])/90 - 
     (13*Pi^4*G[{0}, yw])/90 - (Pi^2*G[{0}, yu^(-1)]*G[{1}, yu^(-1)]^2)/3 - 
     (Pi^2*G[{0}, yv^(-1)]*G[{1}, yu^(-1)]^2)/3 + 
     (Pi^2*G[{0}, yw]*G[{1}, yu^(-1)]^2)/3 + 
     (2*Pi^2*G[{0}, yu^(-1)]*G[{1}, yu^(-1)]*G[{1}, yv^(-1)])/3 + 
     (2*Pi^2*G[{0}, yv^(-1)]*G[{1}, yu^(-1)]*G[{1}, yv^(-1)])/3 - 
     (2*Pi^2*G[{0}, yw]*G[{1}, yu^(-1)]*G[{1}, yv^(-1)])/3 - 
     (Pi^2*G[{0}, yu^(-1)]*G[{1}, yv^(-1)]^2)/3 - 
     (Pi^2*G[{0}, yv^(-1)]*G[{1}, yv^(-1)]^2)/3 + 
     (Pi^2*G[{0}, yw]*G[{1}, yv^(-1)]^2)/3 + 
     (4*Pi^2*G[{0}, yu^(-1)]*G[{0, 1}, yu^(-1)])/3 + 
     (4*Pi^2*G[{0}, yv^(-1)]*G[{0, 1}, yu^(-1)])/3 - 
     (4*Pi^2*G[{0}, yw]*G[{0, 1}, yu^(-1)])/3 + 
     (2*Pi^2*G[{1}, yu^(-1)]*G[{0, 1}, yu^(-1)])/3 - 
     2*G[{0}, yu^(-1)]*G[{1}, yu^(-1)]^2*G[{0, 1}, yu^(-1)] - 
     2*G[{0}, yv^(-1)]*G[{1}, yu^(-1)]^2*G[{0, 1}, yu^(-1)] + 
     2*G[{0}, yw]*G[{1}, yu^(-1)]^2*G[{0, 1}, yu^(-1)] - 
     (2*Pi^2*G[{1}, yv^(-1)]*G[{0, 1}, yu^(-1)])/3 + 
     4*G[{0}, yu^(-1)]*G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*G[{0, 1}, yu^(-1)] + 
     4*G[{0}, yv^(-1)]*G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*G[{0, 1}, yu^(-1)] - 
     4*G[{0}, yw]*G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*G[{0, 1}, yu^(-1)] - 
     2*G[{0}, yu^(-1)]*G[{1}, yv^(-1)]^2*G[{0, 1}, yu^(-1)] - 
     2*G[{0}, yv^(-1)]*G[{1}, yv^(-1)]^2*G[{0, 1}, yu^(-1)] + 
     2*G[{0}, yw]*G[{1}, yv^(-1)]^2*G[{0, 1}, yu^(-1)] + 
     (4*Pi^2*G[{0}, yu^(-1)]*G[{0, 1}, yv^(-1)])/3 + 
     (4*Pi^2*G[{0}, yv^(-1)]*G[{0, 1}, yv^(-1)])/3 - 
     (4*Pi^2*G[{0}, yw]*G[{0, 1}, yv^(-1)])/3 - 
     (2*Pi^2*G[{1}, yu^(-1)]*G[{0, 1}, yv^(-1)])/3 - 
     (2*G[{1}, yu^(-1)]^3*G[{0, 1}, yv^(-1)])/3 + 
     (2*Pi^2*G[{1}, yv^(-1)]*G[{0, 1}, yv^(-1)])/3 + 
     2*G[{1}, yu^(-1)]^2*G[{1}, yv^(-1)]*G[{0, 1}, yv^(-1)] - 
     2*G[{0}, yu^(-1)]*G[{1}, yv^(-1)]^2*G[{0, 1}, yv^(-1)] - 
     2*G[{0}, yv^(-1)]*G[{1}, yv^(-1)]^2*G[{0, 1}, yv^(-1)] + 
     2*G[{0}, yw]*G[{1}, yv^(-1)]^2*G[{0, 1}, yv^(-1)] + 
     (2*Pi^2*G[{0}, yu^(-1)]*G[{0, 1}, yw])/3 + 
     (2*Pi^2*G[{0}, yv^(-1)]*G[{0, 1}, yw])/3 - 
     (2*Pi^2*G[{0}, yw]*G[{0, 1}, yw])/3 + 
     (2*Pi^2*G[{1}, yu^(-1)]*G[{0, 1}, yw])/3 - 2*G[{0}, yu^(-1)]*
      G[{1}, yu^(-1)]^2*G[{0, 1}, yw] - 2*G[{0}, yv^(-1)]*G[{1}, yu^(-1)]^2*
      G[{0, 1}, yw] + 2*G[{0}, yw]*G[{1}, yu^(-1)]^2*G[{0, 1}, yw] + 
     (4*G[{1}, yu^(-1)]^3*G[{0, 1}, yw])/3 + 
     (2*Pi^2*G[{1}, yv^(-1)]*G[{0, 1}, yw])/3 + 4*G[{0}, yu^(-1)]*
      G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*G[{0, 1}, yw] + 
     4*G[{0}, yv^(-1)]*G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*G[{0, 1}, yw] - 
     4*G[{0}, yw]*G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*G[{0, 1}, yw] - 
     2*G[{0}, yu^(-1)]*G[{1}, yv^(-1)]^2*G[{0, 1}, yw] - 
     2*G[{0}, yv^(-1)]*G[{1}, yv^(-1)]^2*G[{0, 1}, yw] + 
     2*G[{0}, yw]*G[{1}, yv^(-1)]^2*G[{0, 1}, yw] - 
     4*G[{1}, yu^(-1)]*G[{1}, yv^(-1)]^2*G[{0, 1}, yw] + 
     (4*G[{1}, yv^(-1)]^3*G[{0, 1}, yw])/3 - 
     (8*Pi^2*G[{yu}, yv^(-1)]*G[{0, 1}, yw])/3 + 4*G[{1}, yu^(-1)]*
      G[{0, 1}, yu^(-1)]*G[{0, 1}, yw] - 4*G[{1}, yv^(-1)]*G[{0, 1}, yu^(-1)]*
      G[{0, 1}, yw] + 4*G[{1}, yv^(-1)]*G[{0, 1}, yv^(-1)]*G[{0, 1}, yw] - 
     2*G[{0}, yu^(-1)]*G[{0, 1}, yw]^2 - 2*G[{0}, yv^(-1)]*G[{0, 1}, yw]^2 + 
     2*G[{0}, yw]*G[{0, 1}, yw]^2 + 2*G[{1}, yu^(-1)]*G[{0, 1}, yw]^2 + 
     2*G[{1}, yv^(-1)]*G[{0, 1}, yw]^2 - 
     (2*Pi^2*G[{0}, yu^(-1)]*G[{0, yu^(-1)}, yw])/3 - 
     (2*Pi^2*G[{0}, yv^(-1)]*G[{0, yu^(-1)}, yw])/3 + 
     (2*Pi^2*G[{0}, yw]*G[{0, yu^(-1)}, yw])/3 + 2*G[{0}, yu^(-1)]*
      G[{1}, yu^(-1)]^2*G[{0, yu^(-1)}, yw] + 2*G[{0}, yv^(-1)]*
      G[{1}, yu^(-1)]^2*G[{0, yu^(-1)}, yw] - 2*G[{0}, yw]*G[{1}, yu^(-1)]^2*
      G[{0, yu^(-1)}, yw] - (4*G[{1}, yu^(-1)]^3*G[{0, yu^(-1)}, yw])/3 + 
     (4*Pi^2*G[{1}, yv^(-1)]*G[{0, yu^(-1)}, yw])/3 - 
     4*G[{0}, yu^(-1)]*G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*G[{0, yu^(-1)}, yw] - 
     4*G[{0}, yv^(-1)]*G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*G[{0, yu^(-1)}, yw] + 
     4*G[{0}, yw]*G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*G[{0, yu^(-1)}, yw] + 
     2*G[{0}, yu^(-1)]*G[{1}, yv^(-1)]^2*G[{0, yu^(-1)}, yw] + 
     2*G[{0}, yv^(-1)]*G[{1}, yv^(-1)]^2*G[{0, yu^(-1)}, yw] - 
     2*G[{0}, yw]*G[{1}, yv^(-1)]^2*G[{0, yu^(-1)}, yw] + 
     4*G[{1}, yu^(-1)]*G[{1}, yv^(-1)]^2*G[{0, yu^(-1)}, yw] - 
     (8*G[{1}, yv^(-1)]^3*G[{0, yu^(-1)}, yw])/3 + 
     4*G[{0}, yu^(-1)]*G[{0, 1}, yw]*G[{0, yu^(-1)}, yw] + 
     4*G[{0}, yv^(-1)]*G[{0, 1}, yw]*G[{0, yu^(-1)}, yw] - 
     4*G[{0}, yw]*G[{0, 1}, yw]*G[{0, yu^(-1)}, yw] - 
     8*G[{1}, yu^(-1)]*G[{0, 1}, yw]*G[{0, yu^(-1)}, yw] - 
     2*G[{0}, yu^(-1)]*G[{0, yu^(-1)}, yw]^2 - 2*G[{0}, yv^(-1)]*
      G[{0, yu^(-1)}, yw]^2 + 2*G[{0}, yw]*G[{0, yu^(-1)}, yw]^2 + 
     4*G[{1}, yu^(-1)]*G[{0, yu^(-1)}, yw]^2 - 
     (4*Pi^2*G[{0}, yu^(-1)]*G[{0, yu}, yv^(-1)])/3 - 
     (4*Pi^2*G[{0}, yv^(-1)]*G[{0, yu}, yv^(-1)])/3 + 
     (4*Pi^2*G[{0}, yw]*G[{0, yu}, yv^(-1)])/3 + 
     (2*G[{1}, yu^(-1)]^3*G[{0, yu}, yv^(-1)])/3 - 
     2*G[{1}, yu^(-1)]^2*G[{1}, yv^(-1)]*G[{0, yu}, yv^(-1)] + 
     2*G[{0}, yu^(-1)]*G[{1}, yv^(-1)]^2*G[{0, yu}, yv^(-1)] + 
     2*G[{0}, yv^(-1)]*G[{1}, yv^(-1)]^2*G[{0, yu}, yv^(-1)] - 
     2*G[{0}, yw]*G[{1}, yv^(-1)]^2*G[{0, yu}, yv^(-1)] - 
     4*G[{1}, yu^(-1)]*G[{0, 1}, yu^(-1)]*G[{0, yu}, yv^(-1)] + 
     4*G[{1}, yv^(-1)]*G[{0, 1}, yu^(-1)]*G[{0, yu}, yv^(-1)] - 
     4*G[{1}, yv^(-1)]*G[{0, 1}, yv^(-1)]*G[{0, yu}, yv^(-1)] - 
     4*G[{1}, yv^(-1)]*G[{0, 1}, yw]*G[{0, yu}, yv^(-1)] + 
     2*G[{1}, yv^(-1)]*G[{0, yu}, yv^(-1)]^2 - 
     (2*Pi^2*G[{0}, yu^(-1)]*G[{0, yv^(-1)}, yw])/3 - 
     (2*Pi^2*G[{0}, yv^(-1)]*G[{0, yv^(-1)}, yw])/3 + 
     (2*Pi^2*G[{0}, yw]*G[{0, yv^(-1)}, yw])/3 + 
     (4*Pi^2*G[{1}, yu^(-1)]*G[{0, yv^(-1)}, yw])/3 + 
     2*G[{0}, yu^(-1)]*G[{1}, yu^(-1)]^2*G[{0, yv^(-1)}, yw] + 
     2*G[{0}, yv^(-1)]*G[{1}, yu^(-1)]^2*G[{0, yv^(-1)}, yw] - 
     2*G[{0}, yw]*G[{1}, yu^(-1)]^2*G[{0, yv^(-1)}, yw] - 
     (8*G[{1}, yu^(-1)]^3*G[{0, yv^(-1)}, yw])/3 - 
     4*G[{0}, yu^(-1)]*G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*G[{0, yv^(-1)}, yw] - 
     4*G[{0}, yv^(-1)]*G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*G[{0, yv^(-1)}, yw] + 
     4*G[{0}, yw]*G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*G[{0, yv^(-1)}, yw] + 
     4*G[{1}, yu^(-1)]^2*G[{1}, yv^(-1)]*G[{0, yv^(-1)}, yw] + 
     2*G[{0}, yu^(-1)]*G[{1}, yv^(-1)]^2*G[{0, yv^(-1)}, yw] + 
     2*G[{0}, yv^(-1)]*G[{1}, yv^(-1)]^2*G[{0, yv^(-1)}, yw] - 
     2*G[{0}, yw]*G[{1}, yv^(-1)]^2*G[{0, yv^(-1)}, yw] - 
     (4*G[{1}, yv^(-1)]^3*G[{0, yv^(-1)}, yw])/3 + 
     4*G[{0}, yu^(-1)]*G[{0, 1}, yw]*G[{0, yv^(-1)}, yw] + 
     4*G[{0}, yv^(-1)]*G[{0, 1}, yw]*G[{0, yv^(-1)}, yw] - 
     4*G[{0}, yw]*G[{0, 1}, yw]*G[{0, yv^(-1)}, yw] - 
     8*G[{1}, yv^(-1)]*G[{0, 1}, yw]*G[{0, yv^(-1)}, yw] - 
     4*G[{0}, yu^(-1)]*G[{0, yu^(-1)}, yw]*G[{0, yv^(-1)}, yw] - 
     4*G[{0}, yv^(-1)]*G[{0, yu^(-1)}, yw]*G[{0, yv^(-1)}, yw] + 
     4*G[{0}, yw]*G[{0, yu^(-1)}, yw]*G[{0, yv^(-1)}, yw] + 
     8*G[{1}, yv^(-1)]*G[{0, yu^(-1)}, yw]*G[{0, yv^(-1)}, yw] - 
     2*G[{0}, yu^(-1)]*G[{0, yv^(-1)}, yw]^2 - 2*G[{0}, yv^(-1)]*
      G[{0, yv^(-1)}, yw]^2 + 2*G[{0}, yw]*G[{0, yv^(-1)}, yw]^2 + 
     4*G[{1}, yv^(-1)]*G[{0, yv^(-1)}, yw]^2 + 
     (2*Pi^2*G[{0}, yu^(-1)]*G[{0, 1/(yu*yv)}, yw])/3 + 
     (2*Pi^2*G[{0}, yv^(-1)]*G[{0, 1/(yu*yv)}, yw])/3 - 
     (2*Pi^2*G[{0}, yw]*G[{0, 1/(yu*yv)}, yw])/3 - 2*Pi^2*G[{1}, yu^(-1)]*
      G[{0, 1/(yu*yv)}, yw] - 2*G[{0}, yu^(-1)]*G[{1}, yu^(-1)]^2*
      G[{0, 1/(yu*yv)}, yw] - 2*G[{0}, yv^(-1)]*G[{1}, yu^(-1)]^2*
      G[{0, 1/(yu*yv)}, yw] + 2*G[{0}, yw]*G[{1}, yu^(-1)]^2*
      G[{0, 1/(yu*yv)}, yw] + (8*G[{1}, yu^(-1)]^3*G[{0, 1/(yu*yv)}, yw])/3 - 
     2*Pi^2*G[{1}, yv^(-1)]*G[{0, 1/(yu*yv)}, yw] + 
     4*G[{0}, yu^(-1)]*G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*
      G[{0, 1/(yu*yv)}, yw] + 4*G[{0}, yv^(-1)]*G[{1}, yu^(-1)]*
      G[{1}, yv^(-1)]*G[{0, 1/(yu*yv)}, yw] - 4*G[{0}, yw]*G[{1}, yu^(-1)]*
      G[{1}, yv^(-1)]*G[{0, 1/(yu*yv)}, yw] - 4*G[{1}, yu^(-1)]^2*
      G[{1}, yv^(-1)]*G[{0, 1/(yu*yv)}, yw] - 2*G[{0}, yu^(-1)]*
      G[{1}, yv^(-1)]^2*G[{0, 1/(yu*yv)}, yw] - 2*G[{0}, yv^(-1)]*
      G[{1}, yv^(-1)]^2*G[{0, 1/(yu*yv)}, yw] + 
     2*G[{0}, yw]*G[{1}, yv^(-1)]^2*G[{0, 1/(yu*yv)}, yw] + 
     (8*G[{1}, yv^(-1)]^3*G[{0, 1/(yu*yv)}, yw])/3 + 
     (8*Pi^2*G[{yu}, yv^(-1)]*G[{0, 1/(yu*yv)}, yw])/3 - 
     4*G[{1}, yu^(-1)]*G[{0, 1}, yu^(-1)]*G[{0, 1/(yu*yv)}, yw] + 
     4*G[{1}, yv^(-1)]*G[{0, 1}, yu^(-1)]*G[{0, 1/(yu*yv)}, yw] - 
     4*G[{1}, yv^(-1)]*G[{0, 1}, yv^(-1)]*G[{0, 1/(yu*yv)}, yw] - 
     4*G[{0}, yu^(-1)]*G[{0, 1}, yw]*G[{0, 1/(yu*yv)}, yw] - 
     4*G[{0}, yv^(-1)]*G[{0, 1}, yw]*G[{0, 1/(yu*yv)}, yw] + 
     4*G[{0}, yw]*G[{0, 1}, yw]*G[{0, 1/(yu*yv)}, yw] + 
     4*G[{1}, yu^(-1)]*G[{0, 1}, yw]*G[{0, 1/(yu*yv)}, yw] + 
     4*G[{1}, yv^(-1)]*G[{0, 1}, yw]*G[{0, 1/(yu*yv)}, yw] + 
     4*G[{0}, yu^(-1)]*G[{0, yu^(-1)}, yw]*G[{0, 1/(yu*yv)}, yw] + 
     4*G[{0}, yv^(-1)]*G[{0, yu^(-1)}, yw]*G[{0, 1/(yu*yv)}, yw] - 
     4*G[{0}, yw]*G[{0, yu^(-1)}, yw]*G[{0, 1/(yu*yv)}, yw] - 
     4*G[{1}, yu^(-1)]*G[{0, yu^(-1)}, yw]*G[{0, 1/(yu*yv)}, yw] - 
     4*G[{1}, yv^(-1)]*G[{0, yu^(-1)}, yw]*G[{0, 1/(yu*yv)}, yw] + 
     4*G[{1}, yv^(-1)]*G[{0, yu}, yv^(-1)]*G[{0, 1/(yu*yv)}, yw] + 
     4*G[{0}, yu^(-1)]*G[{0, yv^(-1)}, yw]*G[{0, 1/(yu*yv)}, yw] + 
     4*G[{0}, yv^(-1)]*G[{0, yv^(-1)}, yw]*G[{0, 1/(yu*yv)}, yw] - 
     4*G[{0}, yw]*G[{0, yv^(-1)}, yw]*G[{0, 1/(yu*yv)}, yw] - 
     4*G[{1}, yu^(-1)]*G[{0, yv^(-1)}, yw]*G[{0, 1/(yu*yv)}, yw] - 
     4*G[{1}, yv^(-1)]*G[{0, yv^(-1)}, yw]*G[{0, 1/(yu*yv)}, yw] - 
     2*G[{0}, yu^(-1)]*G[{0, 1/(yu*yv)}, yw]^2 - 2*G[{0}, yv^(-1)]*
      G[{0, 1/(yu*yv)}, yw]^2 + 2*G[{0}, yw]*G[{0, 1/(yu*yv)}, yw]^2 + 
     2*G[{1}, yu^(-1)]*G[{0, 1/(yu*yv)}, yw]^2 + 2*G[{1}, yv^(-1)]*
      G[{0, 1/(yu*yv)}, yw]^2 - (2*Pi^2*G[{0, 0, 1}, yu^(-1)])/3 + 
     4*G[{0}, yu^(-1)]*G[{1}, yu^(-1)]*G[{0, 0, 1}, yu^(-1)] + 
     4*G[{0}, yv^(-1)]*G[{1}, yu^(-1)]*G[{0, 0, 1}, yu^(-1)] - 
     4*G[{0}, yw]*G[{1}, yu^(-1)]*G[{0, 0, 1}, yu^(-1)] - 
     4*G[{0}, yu^(-1)]*G[{1}, yv^(-1)]*G[{0, 0, 1}, yu^(-1)] - 
     4*G[{0}, yv^(-1)]*G[{1}, yv^(-1)]*G[{0, 0, 1}, yu^(-1)] + 
     4*G[{0}, yw]*G[{1}, yv^(-1)]*G[{0, 0, 1}, yu^(-1)] - 
     4*G[{0, 1}, yw]*G[{0, 0, 1}, yu^(-1)] + 4*G[{0, yu}, yv^(-1)]*
      G[{0, 0, 1}, yu^(-1)] + 4*G[{0, 1/(yu*yv)}, yw]*G[{0, 0, 1}, yu^(-1)] - 
     (2*Pi^2*G[{0, 0, 1}, yv^(-1)])/3 - 2*G[{1}, yu^(-1)]^2*
      G[{0, 0, 1}, yv^(-1)] + 4*G[{0}, yu^(-1)]*G[{1}, yv^(-1)]*
      G[{0, 0, 1}, yv^(-1)] + 4*G[{0}, yv^(-1)]*G[{1}, yv^(-1)]*
      G[{0, 0, 1}, yv^(-1)] - 4*G[{0}, yw]*G[{1}, yv^(-1)]*
      G[{0, 0, 1}, yv^(-1)] - 4*G[{0, 1}, yw]*G[{0, 0, 1}, yv^(-1)] + 
     4*G[{0, yu}, yv^(-1)]*G[{0, 0, 1}, yv^(-1)] + 4*G[{0, 1/(yu*yv)}, yw]*
      G[{0, 0, 1}, yv^(-1)] + (4*Pi^2*G[{0, 0, 1}, yw])/3 - 
     4*G[{1}, yu^(-1)]^2*G[{0, 0, 1}, yw] + 8*G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*
      G[{0, 0, 1}, yw] - 4*G[{1}, yv^(-1)]^2*G[{0, 0, 1}, yw] - 
     8*G[{0, 1}, yw]*G[{0, 0, 1}, yw] + 8*G[{0, yu^(-1)}, yw]*
      G[{0, 0, 1}, yw] + 8*G[{0, yv^(-1)}, yw]*G[{0, 0, 1}, yw] - 
     8*G[{0, 1/(yu*yv)}, yw]*G[{0, 0, 1}, yw] - 
     (4*Pi^2*G[{0, 0, yu^(-1)}, yw])/3 + 4*G[{1}, yu^(-1)]^2*
      G[{0, 0, yu^(-1)}, yw] - 8*G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*
      G[{0, 0, yu^(-1)}, yw] + 4*G[{1}, yv^(-1)]^2*G[{0, 0, yu^(-1)}, yw] + 
     8*G[{0, 1}, yw]*G[{0, 0, yu^(-1)}, yw] - 8*G[{0, yu^(-1)}, yw]*
      G[{0, 0, yu^(-1)}, yw] - 8*G[{0, yv^(-1)}, yw]*G[{0, 0, yu^(-1)}, yw] + 
     8*G[{0, 1/(yu*yv)}, yw]*G[{0, 0, yu^(-1)}, yw] + 
     2*G[{1}, yu^(-1)]^2*G[{0, 0, yu}, yv^(-1)] - 
     4*G[{0}, yu^(-1)]*G[{1}, yv^(-1)]*G[{0, 0, yu}, yv^(-1)] - 
     4*G[{0}, yv^(-1)]*G[{1}, yv^(-1)]*G[{0, 0, yu}, yv^(-1)] + 
     4*G[{0}, yw]*G[{1}, yv^(-1)]*G[{0, 0, yu}, yv^(-1)] - 
     4*G[{0, 1}, yu^(-1)]*G[{0, 0, yu}, yv^(-1)] + 
     4*G[{0, 1}, yw]*G[{0, 0, yu}, yv^(-1)] - 4*G[{0, yu}, yv^(-1)]*
      G[{0, 0, yu}, yv^(-1)] - 4*G[{0, 1/(yu*yv)}, yw]*
      G[{0, 0, yu}, yv^(-1)] - (4*Pi^2*G[{0, 0, yv^(-1)}, yw])/3 + 
     4*G[{1}, yu^(-1)]^2*G[{0, 0, yv^(-1)}, yw] - 
     8*G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*G[{0, 0, yv^(-1)}, yw] + 
     4*G[{1}, yv^(-1)]^2*G[{0, 0, yv^(-1)}, yw] + 
     8*G[{0, 1}, yw]*G[{0, 0, yv^(-1)}, yw] - 8*G[{0, yu^(-1)}, yw]*
      G[{0, 0, yv^(-1)}, yw] - 8*G[{0, yv^(-1)}, yw]*G[{0, 0, yv^(-1)}, yw] + 
     8*G[{0, 1/(yu*yv)}, yw]*G[{0, 0, yv^(-1)}, yw] + 
     (4*Pi^2*G[{0, 0, 1/(yu*yv)}, yw])/3 - 4*G[{1}, yu^(-1)]^2*
      G[{0, 0, 1/(yu*yv)}, yw] + 8*G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*
      G[{0, 0, 1/(yu*yv)}, yw] - 4*G[{1}, yv^(-1)]^2*
      G[{0, 0, 1/(yu*yv)}, yw] - 8*G[{0, 1}, yw]*G[{0, 0, 1/(yu*yv)}, yw] + 
     8*G[{0, yu^(-1)}, yw]*G[{0, 0, 1/(yu*yv)}, yw] + 
     8*G[{0, yv^(-1)}, yw]*G[{0, 0, 1/(yu*yv)}, yw] - 
     8*G[{0, 1/(yu*yv)}, yw]*G[{0, 0, 1/(yu*yv)}, yw] - 
     (8*Pi^2*G[{0, 1, 1}, yu^(-1)])/3 + 4*G[{0}, yu^(-1)]*G[{1}, yu^(-1)]*
      G[{0, 1, 1}, yu^(-1)] + 4*G[{0}, yv^(-1)]*G[{1}, yu^(-1)]*
      G[{0, 1, 1}, yu^(-1)] - 4*G[{0}, yw]*G[{1}, yu^(-1)]*
      G[{0, 1, 1}, yu^(-1)] + 4*G[{1}, yu^(-1)]^2*G[{0, 1, 1}, yu^(-1)] - 
     4*G[{0}, yu^(-1)]*G[{1}, yv^(-1)]*G[{0, 1, 1}, yu^(-1)] - 
     4*G[{0}, yv^(-1)]*G[{1}, yv^(-1)]*G[{0, 1, 1}, yu^(-1)] + 
     4*G[{0}, yw]*G[{1}, yv^(-1)]*G[{0, 1, 1}, yu^(-1)] - 
     8*G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*G[{0, 1, 1}, yu^(-1)] + 
     4*G[{1}, yv^(-1)]^2*G[{0, 1, 1}, yu^(-1)] - 
     4*G[{0, 1}, yw]*G[{0, 1, 1}, yu^(-1)] + 4*G[{0, yu}, yv^(-1)]*
      G[{0, 1, 1}, yu^(-1)] + 4*G[{0, 1/(yu*yv)}, yw]*G[{0, 1, 1}, yu^(-1)] - 
     (8*Pi^2*G[{0, 1, 1}, yv^(-1)])/3 + 4*G[{0}, yu^(-1)]*G[{1}, yv^(-1)]*
      G[{0, 1, 1}, yv^(-1)] + 4*G[{0}, yv^(-1)]*G[{1}, yv^(-1)]*
      G[{0, 1, 1}, yv^(-1)] - 4*G[{0}, yw]*G[{1}, yv^(-1)]*
      G[{0, 1, 1}, yv^(-1)] - 4*G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*
      G[{0, 1, 1}, yv^(-1)] + 4*G[{1}, yv^(-1)]^2*G[{0, 1, 1}, yv^(-1)] - 
     4*G[{0, 1}, yw]*G[{0, 1, 1}, yv^(-1)] + 4*G[{0, yu}, yv^(-1)]*
      G[{0, 1, 1}, yv^(-1)] + 4*G[{0, 1/(yu*yv)}, yw]*G[{0, 1, 1}, yv^(-1)] + 
     (8*Pi^2*G[{0, 1, 1}, yw])/3 - 2*G[{1}, yu^(-1)]^2*G[{0, 1, 1}, yw] + 
     4*G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*G[{0, 1, 1}, yw] - 
     2*G[{1}, yv^(-1)]^2*G[{0, 1, 1}, yw] + 4*G[{0, 1}, yu^(-1)]*
      G[{0, 1, 1}, yw] + 4*G[{0, 1}, yv^(-1)]*G[{0, 1, 1}, yw] - 
     4*G[{0, yu}, yv^(-1)]*G[{0, 1, 1}, yw] - (2*Pi^2*G[{0, 1, yu^(-1)}, yw])/
      3 - 4*G[{0}, yu^(-1)]*G[{1}, yu^(-1)]*G[{0, 1, yu^(-1)}, yw] - 
     4*G[{0}, yv^(-1)]*G[{1}, yu^(-1)]*G[{0, 1, yu^(-1)}, yw] + 
     4*G[{0}, yw]*G[{1}, yu^(-1)]*G[{0, 1, yu^(-1)}, yw] + 
     2*G[{1}, yu^(-1)]^2*G[{0, 1, yu^(-1)}, yw] + 
     4*G[{0}, yu^(-1)]*G[{1}, yv^(-1)]*G[{0, 1, yu^(-1)}, yw] + 
     4*G[{0}, yv^(-1)]*G[{1}, yv^(-1)]*G[{0, 1, yu^(-1)}, yw] - 
     4*G[{0}, yw]*G[{1}, yv^(-1)]*G[{0, 1, yu^(-1)}, yw] + 
     4*G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*G[{0, 1, yu^(-1)}, yw] - 
     6*G[{1}, yv^(-1)]^2*G[{0, 1, yu^(-1)}, yw] + 
     4*G[{0, 1}, yw]*G[{0, 1, yu^(-1)}, yw] + 8*G[{0, yu^(-1)}, yw]*
      G[{0, 1, yu^(-1)}, yw] + 8*G[{0, yv^(-1)}, yw]*G[{0, 1, yu^(-1)}, yw] - 
     8*G[{0, 1/(yu*yv)}, yw]*G[{0, 1, yu^(-1)}, yw] - 
     (2*Pi^2*G[{0, 1, yv^(-1)}, yw])/3 + 4*G[{0}, yu^(-1)]*G[{1}, yu^(-1)]*
      G[{0, 1, yv^(-1)}, yw] + 4*G[{0}, yv^(-1)]*G[{1}, yu^(-1)]*
      G[{0, 1, yv^(-1)}, yw] - 4*G[{0}, yw]*G[{1}, yu^(-1)]*
      G[{0, 1, yv^(-1)}, yw] - 6*G[{1}, yu^(-1)]^2*G[{0, 1, yv^(-1)}, yw] - 
     4*G[{0}, yu^(-1)]*G[{1}, yv^(-1)]*G[{0, 1, yv^(-1)}, yw] - 
     4*G[{0}, yv^(-1)]*G[{1}, yv^(-1)]*G[{0, 1, yv^(-1)}, yw] + 
     4*G[{0}, yw]*G[{1}, yv^(-1)]*G[{0, 1, yv^(-1)}, yw] + 
     4*G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*G[{0, 1, yv^(-1)}, yw] + 
     2*G[{1}, yv^(-1)]^2*G[{0, 1, yv^(-1)}, yw] + 
     4*G[{0, 1}, yw]*G[{0, 1, yv^(-1)}, yw] + 8*G[{0, yu^(-1)}, yw]*
      G[{0, 1, yv^(-1)}, yw] + 8*G[{0, yv^(-1)}, yw]*G[{0, 1, yv^(-1)}, yw] - 
     8*G[{0, 1/(yu*yv)}, yw]*G[{0, 1, yv^(-1)}, yw] + 
     2*G[{1}, yu^(-1)]^2*G[{0, 1, 1/(yu*yv)}, yw] - 
     4*G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*G[{0, 1, 1/(yu*yv)}, yw] + 
     2*G[{1}, yv^(-1)]^2*G[{0, 1, 1/(yu*yv)}, yw] - 
     4*G[{0, 1}, yu^(-1)]*G[{0, 1, 1/(yu*yv)}, yw] - 
     4*G[{0, 1}, yv^(-1)]*G[{0, 1, 1/(yu*yv)}, yw] + 
     4*G[{0, yu}, yv^(-1)]*G[{0, 1, 1/(yu*yv)}, yw] - 
     4*G[{0}, yu^(-1)]*G[{1}, yu^(-1)]*G[{0, yu^(-1), 1}, yw] - 
     4*G[{0}, yv^(-1)]*G[{1}, yu^(-1)]*G[{0, yu^(-1), 1}, yw] + 
     4*G[{0}, yw]*G[{1}, yu^(-1)]*G[{0, yu^(-1), 1}, yw] + 
     4*G[{1}, yu^(-1)]^2*G[{0, yu^(-1), 1}, yw] + 
     4*G[{0}, yu^(-1)]*G[{1}, yv^(-1)]*G[{0, yu^(-1), 1}, yw] + 
     4*G[{0}, yv^(-1)]*G[{1}, yv^(-1)]*G[{0, yu^(-1), 1}, yw] - 
     4*G[{0}, yw]*G[{1}, yv^(-1)]*G[{0, yu^(-1), 1}, yw] - 
     4*G[{1}, yv^(-1)]^2*G[{0, yu^(-1), 1}, yw] - 
     (4*Pi^2*G[{0, yu^(-1), yu^(-1)}, yw])/3 + 8*G[{0}, yu^(-1)]*
      G[{1}, yu^(-1)]*G[{0, yu^(-1), yu^(-1)}, yw] + 
     8*G[{0}, yv^(-1)]*G[{1}, yu^(-1)]*G[{0, yu^(-1), yu^(-1)}, yw] - 
     8*G[{0}, yw]*G[{1}, yu^(-1)]*G[{0, yu^(-1), yu^(-1)}, yw] - 
     4*G[{1}, yu^(-1)]^2*G[{0, yu^(-1), yu^(-1)}, yw] - 
     8*G[{0}, yu^(-1)]*G[{1}, yv^(-1)]*G[{0, yu^(-1), yu^(-1)}, yw] - 
     8*G[{0}, yv^(-1)]*G[{1}, yv^(-1)]*G[{0, yu^(-1), yu^(-1)}, yw] + 
     8*G[{0}, yw]*G[{1}, yv^(-1)]*G[{0, yu^(-1), yu^(-1)}, yw] - 
     8*G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*G[{0, yu^(-1), yu^(-1)}, yw] + 
     12*G[{1}, yv^(-1)]^2*G[{0, yu^(-1), yu^(-1)}, yw] - 
     8*G[{0, 1}, yw]*G[{0, yu^(-1), yu^(-1)}, yw] + 
     8*G[{0, yu^(-1)}, yw]*G[{0, yu^(-1), yu^(-1)}, yw] - 
     8*G[{0, yv^(-1)}, yw]*G[{0, yu^(-1), yu^(-1)}, yw] + 
     8*G[{0, 1/(yu*yv)}, yw]*G[{0, yu^(-1), yu^(-1)}, yw] - 
     8*G[{0, yv^(-1)}, yw]*G[{0, yu^(-1), yv^(-1)}, yw] + 
     8*G[{0, 1/(yu*yv)}, yw]*G[{0, yu^(-1), yv^(-1)}, yw] - 
     4*G[{0}, yu^(-1)]*G[{1}, yu^(-1)]*G[{0, yu^(-1), 1/(yu*yv)}, yw] - 
     4*G[{0}, yv^(-1)]*G[{1}, yu^(-1)]*G[{0, yu^(-1), 1/(yu*yv)}, yw] + 
     4*G[{0}, yw]*G[{1}, yu^(-1)]*G[{0, yu^(-1), 1/(yu*yv)}, yw] + 
     4*G[{1}, yu^(-1)]^2*G[{0, yu^(-1), 1/(yu*yv)}, yw] + 
     4*G[{0}, yu^(-1)]*G[{1}, yv^(-1)]*G[{0, yu^(-1), 1/(yu*yv)}, yw] + 
     4*G[{0}, yv^(-1)]*G[{1}, yv^(-1)]*G[{0, yu^(-1), 1/(yu*yv)}, yw] - 
     4*G[{0}, yw]*G[{1}, yv^(-1)]*G[{0, yu^(-1), 1/(yu*yv)}, yw] - 
     4*G[{1}, yv^(-1)]^2*G[{0, yu^(-1), 1/(yu*yv)}, yw] - 
     8*G[{0, yv^(-1)}, yw]*G[{0, yu^(-1), 1/(yu*yv)}, yw] - 
     4*G[{0}, yu^(-1)]*G[{1}, yv^(-1)]*G[{0, yu, 1}, yv^(-1)] - 
     4*G[{0}, yv^(-1)]*G[{1}, yv^(-1)]*G[{0, yu, 1}, yv^(-1)] + 
     4*G[{0}, yw]*G[{1}, yv^(-1)]*G[{0, yu, 1}, yv^(-1)] + 
     4*G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*G[{0, yu, 1}, yv^(-1)] + 
     4*G[{0, 1}, yw]*G[{0, yu, 1}, yv^(-1)] - 4*G[{0, 1/(yu*yv)}, yw]*
      G[{0, yu, 1}, yv^(-1)] + (8*Pi^2*G[{0, yu, yu}, yv^(-1)])/3 - 
     4*G[{1}, yv^(-1)]^2*G[{0, yu, yu}, yv^(-1)] + 
     4*G[{0}, yu^(-1)]*G[{1}, yu^(-1)]*G[{0, yv^(-1), 1}, yw] + 
     4*G[{0}, yv^(-1)]*G[{1}, yu^(-1)]*G[{0, yv^(-1), 1}, yw] - 
     4*G[{0}, yw]*G[{1}, yu^(-1)]*G[{0, yv^(-1), 1}, yw] - 
     4*G[{1}, yu^(-1)]^2*G[{0, yv^(-1), 1}, yw] - 
     4*G[{0}, yu^(-1)]*G[{1}, yv^(-1)]*G[{0, yv^(-1), 1}, yw] - 
     4*G[{0}, yv^(-1)]*G[{1}, yv^(-1)]*G[{0, yv^(-1), 1}, yw] + 
     4*G[{0}, yw]*G[{1}, yv^(-1)]*G[{0, yv^(-1), 1}, yw] + 
     4*G[{1}, yv^(-1)]^2*G[{0, yv^(-1), 1}, yw] + 8*G[{0, 1/(yu*yv)}, yw]*
      G[{0, yv^(-1), yu^(-1)}, yw] - (4*Pi^2*G[{0, yv^(-1), yv^(-1)}, yw])/
      3 - 8*G[{0}, yu^(-1)]*G[{1}, yu^(-1)]*G[{0, yv^(-1), yv^(-1)}, yw] - 
     8*G[{0}, yv^(-1)]*G[{1}, yu^(-1)]*G[{0, yv^(-1), yv^(-1)}, yw] + 
     8*G[{0}, yw]*G[{1}, yu^(-1)]*G[{0, yv^(-1), yv^(-1)}, yw] + 
     12*G[{1}, yu^(-1)]^2*G[{0, yv^(-1), yv^(-1)}, yw] + 
     8*G[{0}, yu^(-1)]*G[{1}, yv^(-1)]*G[{0, yv^(-1), yv^(-1)}, yw] + 
     8*G[{0}, yv^(-1)]*G[{1}, yv^(-1)]*G[{0, yv^(-1), yv^(-1)}, yw] - 
     8*G[{0}, yw]*G[{1}, yv^(-1)]*G[{0, yv^(-1), yv^(-1)}, yw] - 
     8*G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*G[{0, yv^(-1), yv^(-1)}, yw] - 
     4*G[{1}, yv^(-1)]^2*G[{0, yv^(-1), yv^(-1)}, yw] - 
     8*G[{0, 1}, yw]*G[{0, yv^(-1), yv^(-1)}, yw] + 
     8*G[{0, yu^(-1)}, yw]*G[{0, yv^(-1), yv^(-1)}, yw] + 
     8*G[{0, yv^(-1)}, yw]*G[{0, yv^(-1), yv^(-1)}, yw] + 
     8*G[{0, 1/(yu*yv)}, yw]*G[{0, yv^(-1), yv^(-1)}, yw] + 
     4*G[{0}, yu^(-1)]*G[{1}, yu^(-1)]*G[{0, yv^(-1), 1/(yu*yv)}, yw] + 
     4*G[{0}, yv^(-1)]*G[{1}, yu^(-1)]*G[{0, yv^(-1), 1/(yu*yv)}, yw] - 
     4*G[{0}, yw]*G[{1}, yu^(-1)]*G[{0, yv^(-1), 1/(yu*yv)}, yw] - 
     4*G[{1}, yu^(-1)]^2*G[{0, yv^(-1), 1/(yu*yv)}, yw] - 
     4*G[{0}, yu^(-1)]*G[{1}, yv^(-1)]*G[{0, yv^(-1), 1/(yu*yv)}, yw] - 
     4*G[{0}, yv^(-1)]*G[{1}, yv^(-1)]*G[{0, yv^(-1), 1/(yu*yv)}, yw] + 
     4*G[{0}, yw]*G[{1}, yv^(-1)]*G[{0, yv^(-1), 1/(yu*yv)}, yw] + 
     4*G[{1}, yv^(-1)]^2*G[{0, yv^(-1), 1/(yu*yv)}, yw] - 
     (8*Pi^2*G[{0, 1/(yu*yv), 1}, yw])/3 + 2*G[{1}, yu^(-1)]^2*
      G[{0, 1/(yu*yv), 1}, yw] - 4*G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*
      G[{0, 1/(yu*yv), 1}, yw] + 2*G[{1}, yv^(-1)]^2*
      G[{0, 1/(yu*yv), 1}, yw] - 4*G[{0, 1}, yu^(-1)]*
      G[{0, 1/(yu*yv), 1}, yw] - 4*G[{0, 1}, yv^(-1)]*
      G[{0, 1/(yu*yv), 1}, yw] + 4*G[{0, yu}, yv^(-1)]*
      G[{0, 1/(yu*yv), 1}, yw] + 2*Pi^2*G[{0, 1/(yu*yv), yu^(-1)}, yw] - 
     4*G[{0}, yu^(-1)]*G[{1}, yu^(-1)]*G[{0, 1/(yu*yv), yu^(-1)}, yw] - 
     4*G[{0}, yv^(-1)]*G[{1}, yu^(-1)]*G[{0, 1/(yu*yv), yu^(-1)}, yw] + 
     4*G[{0}, yw]*G[{1}, yu^(-1)]*G[{0, 1/(yu*yv), yu^(-1)}, yw] + 
     2*G[{1}, yu^(-1)]^2*G[{0, 1/(yu*yv), yu^(-1)}, yw] + 
     4*G[{0}, yu^(-1)]*G[{1}, yv^(-1)]*G[{0, 1/(yu*yv), yu^(-1)}, yw] + 
     4*G[{0}, yv^(-1)]*G[{1}, yv^(-1)]*G[{0, 1/(yu*yv), yu^(-1)}, yw] - 
     4*G[{0}, yw]*G[{1}, yv^(-1)]*G[{0, 1/(yu*yv), yu^(-1)}, yw] + 
     4*G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*G[{0, 1/(yu*yv), yu^(-1)}, yw] - 
     6*G[{1}, yv^(-1)]^2*G[{0, 1/(yu*yv), yu^(-1)}, yw] + 
     4*G[{0, 1}, yw]*G[{0, 1/(yu*yv), yu^(-1)}, yw] - 
     4*G[{0, yu^(-1)}, yw]*G[{0, 1/(yu*yv), yu^(-1)}, yw] - 
     4*G[{0, yv^(-1)}, yw]*G[{0, 1/(yu*yv), yu^(-1)}, yw] + 
     4*G[{0, 1/(yu*yv)}, yw]*G[{0, 1/(yu*yv), yu^(-1)}, yw] + 
     2*Pi^2*G[{0, 1/(yu*yv), yv^(-1)}, yw] + 4*G[{0}, yu^(-1)]*
      G[{1}, yu^(-1)]*G[{0, 1/(yu*yv), yv^(-1)}, yw] + 
     4*G[{0}, yv^(-1)]*G[{1}, yu^(-1)]*G[{0, 1/(yu*yv), yv^(-1)}, yw] - 
     4*G[{0}, yw]*G[{1}, yu^(-1)]*G[{0, 1/(yu*yv), yv^(-1)}, yw] - 
     6*G[{1}, yu^(-1)]^2*G[{0, 1/(yu*yv), yv^(-1)}, yw] - 
     4*G[{0}, yu^(-1)]*G[{1}, yv^(-1)]*G[{0, 1/(yu*yv), yv^(-1)}, yw] - 
     4*G[{0}, yv^(-1)]*G[{1}, yv^(-1)]*G[{0, 1/(yu*yv), yv^(-1)}, yw] + 
     4*G[{0}, yw]*G[{1}, yv^(-1)]*G[{0, 1/(yu*yv), yv^(-1)}, yw] + 
     4*G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*G[{0, 1/(yu*yv), yv^(-1)}, yw] + 
     2*G[{1}, yv^(-1)]^2*G[{0, 1/(yu*yv), yv^(-1)}, yw] + 
     4*G[{0, 1}, yw]*G[{0, 1/(yu*yv), yv^(-1)}, yw] - 
     4*G[{0, yu^(-1)}, yw]*G[{0, 1/(yu*yv), yv^(-1)}, yw] - 
     4*G[{0, yv^(-1)}, yw]*G[{0, 1/(yu*yv), yv^(-1)}, yw] + 
     4*G[{0, 1/(yu*yv)}, yw]*G[{0, 1/(yu*yv), yv^(-1)}, yw] - 
     2*G[{1}, yu^(-1)]^2*G[{0, 1/(yu*yv), 1/(yu*yv)}, yw] + 
     4*G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*G[{0, 1/(yu*yv), 1/(yu*yv)}, yw] - 
     2*G[{1}, yv^(-1)]^2*G[{0, 1/(yu*yv), 1/(yu*yv)}, yw] + 
     4*G[{0, 1}, yu^(-1)]*G[{0, 1/(yu*yv), 1/(yu*yv)}, yw] + 
     4*G[{0, 1}, yv^(-1)]*G[{0, 1/(yu*yv), 1/(yu*yv)}, yw] - 
     4*G[{0, yu}, yv^(-1)]*G[{0, 1/(yu*yv), 1/(yu*yv)}, yw] + 
     8*G[{0, 1}, yw]*G[{1, 1, yu}, yv^(-1)] - 8*G[{0, 1/(yu*yv)}, yw]*
      G[{1, 1, yu}, yv^(-1)] - 4*G[{0}, yu^(-1)]*G[{0, 0, 0, 1}, yu^(-1)] - 
     4*G[{0}, yv^(-1)]*G[{0, 0, 0, 1}, yu^(-1)] + 
     4*G[{0}, yw]*G[{0, 0, 0, 1}, yu^(-1)] - 4*G[{0}, yu^(-1)]*
      G[{0, 0, 0, 1}, yv^(-1)] - 4*G[{0}, yv^(-1)]*G[{0, 0, 0, 1}, yv^(-1)] + 
     4*G[{0}, yw]*G[{0, 0, 0, 1}, yv^(-1)] + 4*G[{0}, yu^(-1)]*
      G[{0, 0, 0, yu}, yv^(-1)] + 4*G[{0}, yv^(-1)]*
      G[{0, 0, 0, yu}, yv^(-1)] - 4*G[{0}, yw]*G[{0, 0, 0, yu}, yv^(-1)] - 
     4*G[{0}, yu^(-1)]*G[{0, 0, 1, 1}, yu^(-1)] - 
     4*G[{0}, yv^(-1)]*G[{0, 0, 1, 1}, yu^(-1)] + 
     4*G[{0}, yw]*G[{0, 0, 1, 1}, yu^(-1)] - 8*G[{1}, yu^(-1)]*
      G[{0, 0, 1, 1}, yu^(-1)] + 8*G[{1}, yv^(-1)]*G[{0, 0, 1, 1}, yu^(-1)] - 
     4*G[{0}, yu^(-1)]*G[{0, 0, 1, 1}, yv^(-1)] - 
     4*G[{0}, yv^(-1)]*G[{0, 0, 1, 1}, yv^(-1)] + 
     4*G[{0}, yw]*G[{0, 0, 1, 1}, yv^(-1)] + 4*G[{1}, yu^(-1)]*
      G[{0, 0, 1, 1}, yv^(-1)] - 8*G[{1}, yv^(-1)]*G[{0, 0, 1, 1}, yv^(-1)] + 
     8*G[{0}, yu^(-1)]*G[{0, 0, 1, 1}, yw] + 8*G[{0}, yv^(-1)]*
      G[{0, 0, 1, 1}, yw] - 8*G[{0}, yw]*G[{0, 0, 1, 1}, yw] - 
     8*G[{1}, yu^(-1)]*G[{0, 0, 1, 1}, yw] - 8*G[{1}, yv^(-1)]*
      G[{0, 0, 1, 1}, yw] - 8*G[{0}, yu^(-1)]*G[{0, 0, 1, yu^(-1)}, yw] - 
     8*G[{0}, yv^(-1)]*G[{0, 0, 1, yu^(-1)}, yw] + 
     8*G[{0}, yw]*G[{0, 0, 1, yu^(-1)}, yw] + 8*G[{1}, yu^(-1)]*
      G[{0, 0, 1, yu^(-1)}, yw] + 8*G[{1}, yv^(-1)]*G[{0, 0, 1, yu^(-1)}, 
       yw] + 8*G[{1}, yv^(-1)]*G[{0, 0, 1, yu}, yv^(-1)] - 
     8*G[{0}, yu^(-1)]*G[{0, 0, 1, yv^(-1)}, yw] - 
     8*G[{0}, yv^(-1)]*G[{0, 0, 1, yv^(-1)}, yw] + 
     8*G[{0}, yw]*G[{0, 0, 1, yv^(-1)}, yw] + 8*G[{1}, yu^(-1)]*
      G[{0, 0, 1, yv^(-1)}, yw] + 8*G[{1}, yv^(-1)]*G[{0, 0, 1, yv^(-1)}, 
       yw] + 8*G[{0}, yu^(-1)]*G[{0, 0, 1, 1/(yu*yv)}, yw] + 
     8*G[{0}, yv^(-1)]*G[{0, 0, 1, 1/(yu*yv)}, yw] - 
     8*G[{0}, yw]*G[{0, 0, 1, 1/(yu*yv)}, yw] - 8*G[{1}, yu^(-1)]*
      G[{0, 0, 1, 1/(yu*yv)}, yw] - 8*G[{1}, yv^(-1)]*
      G[{0, 0, 1, 1/(yu*yv)}, yw] - 8*G[{0}, yu^(-1)]*
      G[{0, 0, yu^(-1), 1}, yw] - 8*G[{0}, yv^(-1)]*G[{0, 0, yu^(-1), 1}, 
       yw] + 8*G[{0}, yw]*G[{0, 0, yu^(-1), 1}, yw] + 
     8*G[{1}, yu^(-1)]*G[{0, 0, yu^(-1), 1}, yw] + 
     8*G[{1}, yv^(-1)]*G[{0, 0, yu^(-1), 1}, yw] + 
     8*G[{0}, yu^(-1)]*G[{0, 0, yu^(-1), yu^(-1)}, yw] + 
     8*G[{0}, yv^(-1)]*G[{0, 0, yu^(-1), yu^(-1)}, yw] - 
     8*G[{0}, yw]*G[{0, 0, yu^(-1), yu^(-1)}, yw] - 
     16*G[{1}, yv^(-1)]*G[{0, 0, yu^(-1), yu^(-1)}, yw] + 
     8*G[{0}, yu^(-1)]*G[{0, 0, yu^(-1), yv^(-1)}, yw] + 
     8*G[{0}, yv^(-1)]*G[{0, 0, yu^(-1), yv^(-1)}, yw] - 
     8*G[{0}, yw]*G[{0, 0, yu^(-1), yv^(-1)}, yw] - 
     16*G[{1}, yv^(-1)]*G[{0, 0, yu^(-1), yv^(-1)}, yw] - 
     8*G[{0}, yu^(-1)]*G[{0, 0, yu^(-1), 1/(yu*yv)}, yw] - 
     8*G[{0}, yv^(-1)]*G[{0, 0, yu^(-1), 1/(yu*yv)}, yw] + 
     8*G[{0}, yw]*G[{0, 0, yu^(-1), 1/(yu*yv)}, yw] + 
     16*G[{1}, yv^(-1)]*G[{0, 0, yu^(-1), 1/(yu*yv)}, yw] + 
     4*G[{0}, yu^(-1)]*G[{0, 0, yu, 1}, yv^(-1)] + 
     4*G[{0}, yv^(-1)]*G[{0, 0, yu, 1}, yv^(-1)] - 
     4*G[{0}, yw]*G[{0, 0, yu, 1}, yv^(-1)] - 4*G[{1}, yu^(-1)]*
      G[{0, 0, yu, 1}, yv^(-1)] + 8*G[{1}, yv^(-1)]*
      G[{0, 0, yu, 1}, yv^(-1)] - 8*G[{0}, yu^(-1)]*G[{0, 0, yv^(-1), 1}, 
       yw] - 8*G[{0}, yv^(-1)]*G[{0, 0, yv^(-1), 1}, yw] + 
     8*G[{0}, yw]*G[{0, 0, yv^(-1), 1}, yw] + 8*G[{1}, yu^(-1)]*
      G[{0, 0, yv^(-1), 1}, yw] + 8*G[{1}, yv^(-1)]*G[{0, 0, yv^(-1), 1}, 
       yw] + 8*G[{0}, yu^(-1)]*G[{0, 0, yv^(-1), yu^(-1)}, yw] + 
     8*G[{0}, yv^(-1)]*G[{0, 0, yv^(-1), yu^(-1)}, yw] - 
     8*G[{0}, yw]*G[{0, 0, yv^(-1), yu^(-1)}, yw] - 
     16*G[{1}, yv^(-1)]*G[{0, 0, yv^(-1), yu^(-1)}, yw] + 
     8*G[{0}, yu^(-1)]*G[{0, 0, yv^(-1), yv^(-1)}, yw] + 
     8*G[{0}, yv^(-1)]*G[{0, 0, yv^(-1), yv^(-1)}, yw] - 
     8*G[{0}, yw]*G[{0, 0, yv^(-1), yv^(-1)}, yw] - 
     16*G[{1}, yu^(-1)]*G[{0, 0, yv^(-1), yv^(-1)}, yw] - 
     8*G[{0}, yu^(-1)]*G[{0, 0, yv^(-1), 1/(yu*yv)}, yw] - 
     8*G[{0}, yv^(-1)]*G[{0, 0, yv^(-1), 1/(yu*yv)}, yw] + 
     8*G[{0}, yw]*G[{0, 0, yv^(-1), 1/(yu*yv)}, yw] + 
     16*G[{1}, yu^(-1)]*G[{0, 0, yv^(-1), 1/(yu*yv)}, yw] + 
     8*G[{0}, yu^(-1)]*G[{0, 0, 1/(yu*yv), 1}, yw] + 
     8*G[{0}, yv^(-1)]*G[{0, 0, 1/(yu*yv), 1}, yw] - 
     8*G[{0}, yw]*G[{0, 0, 1/(yu*yv), 1}, yw] - 8*G[{1}, yu^(-1)]*
      G[{0, 0, 1/(yu*yv), 1}, yw] - 8*G[{1}, yv^(-1)]*
      G[{0, 0, 1/(yu*yv), 1}, yw] - 8*G[{0}, yu^(-1)]*
      G[{0, 0, 1/(yu*yv), yu^(-1)}, yw] - 8*G[{0}, yv^(-1)]*
      G[{0, 0, 1/(yu*yv), yu^(-1)}, yw] + 8*G[{0}, yw]*
      G[{0, 0, 1/(yu*yv), yu^(-1)}, yw] + 16*G[{1}, yv^(-1)]*
      G[{0, 0, 1/(yu*yv), yu^(-1)}, yw] - 8*G[{0}, yu^(-1)]*
      G[{0, 0, 1/(yu*yv), yv^(-1)}, yw] - 8*G[{0}, yv^(-1)]*
      G[{0, 0, 1/(yu*yv), yv^(-1)}, yw] + 8*G[{0}, yw]*
      G[{0, 0, 1/(yu*yv), yv^(-1)}, yw] + 16*G[{1}, yu^(-1)]*
      G[{0, 0, 1/(yu*yv), yv^(-1)}, yw] + 8*G[{0}, yu^(-1)]*
      G[{0, 0, 1/(yu*yv), 1/(yu*yv)}, yw] + 8*G[{0}, yv^(-1)]*
      G[{0, 0, 1/(yu*yv), 1/(yu*yv)}, yw] - 8*G[{0}, yw]*
      G[{0, 0, 1/(yu*yv), 1/(yu*yv)}, yw] - 8*G[{1}, yu^(-1)]*
      G[{0, 0, 1/(yu*yv), 1/(yu*yv)}, yw] - 8*G[{1}, yv^(-1)]*
      G[{0, 0, 1/(yu*yv), 1/(yu*yv)}, yw] + 4*G[{1}, yu^(-1)]*
      G[{0, 1, 0, yu^(-1)}, yw] - 4*G[{1}, yv^(-1)]*G[{0, 1, 0, yu^(-1)}, 
       yw] + 4*G[{1}, yv^(-1)]*G[{0, 1, 0, yu}, yv^(-1)] - 
     4*G[{1}, yu^(-1)]*G[{0, 1, 0, yv^(-1)}, yw] + 
     4*G[{1}, yv^(-1)]*G[{0, 1, 0, yv^(-1)}, yw] - 
     4*G[{0}, yu^(-1)]*G[{0, 1, 1, 1}, yu^(-1)] - 
     4*G[{0}, yv^(-1)]*G[{0, 1, 1, 1}, yu^(-1)] + 
     4*G[{0}, yw]*G[{0, 1, 1, 1}, yu^(-1)] - 12*G[{1}, yu^(-1)]*
      G[{0, 1, 1, 1}, yu^(-1)] + 12*G[{1}, yv^(-1)]*
      G[{0, 1, 1, 1}, yu^(-1)] - 4*G[{0}, yu^(-1)]*G[{0, 1, 1, 1}, yv^(-1)] - 
     4*G[{0}, yv^(-1)]*G[{0, 1, 1, 1}, yv^(-1)] + 
     4*G[{0}, yw]*G[{0, 1, 1, 1}, yv^(-1)] + 4*G[{1}, yu^(-1)]*
      G[{0, 1, 1, 1}, yv^(-1)] - 12*G[{1}, yv^(-1)]*
      G[{0, 1, 1, 1}, yv^(-1)] - 4*G[{1}, yu^(-1)]*G[{0, 1, 1, 1}, yw] - 
     4*G[{1}, yv^(-1)]*G[{0, 1, 1, 1}, yw] + 8*G[{yu}, yv^(-1)]*
      G[{0, 1, 1, 1}, yw] + 4*G[{1}, yu^(-1)]*G[{0, 1, 1, 1/(yu*yv)}, yw] + 
     4*G[{1}, yv^(-1)]*G[{0, 1, 1, 1/(yu*yv)}, yw] - 
     8*G[{yu}, yv^(-1)]*G[{0, 1, 1, 1/(yu*yv)}, yw] + 
     4*G[{0}, yu^(-1)]*G[{0, 1, yu^(-1), 1}, yw] + 
     4*G[{0}, yv^(-1)]*G[{0, 1, yu^(-1), 1}, yw] - 
     4*G[{0}, yw]*G[{0, 1, yu^(-1), 1}, yw] - 4*G[{1}, yu^(-1)]*
      G[{0, 1, yu^(-1), 1}, yw] - 4*G[{1}, yv^(-1)]*G[{0, 1, yu^(-1), 1}, 
       yw] - 8*G[{0}, yu^(-1)]*G[{0, 1, yu^(-1), yu^(-1)}, yw] - 
     8*G[{0}, yv^(-1)]*G[{0, 1, yu^(-1), yu^(-1)}, yw] + 
     8*G[{0}, yw]*G[{0, 1, yu^(-1), yu^(-1)}, yw] + 
     16*G[{1}, yv^(-1)]*G[{0, 1, yu^(-1), yu^(-1)}, yw] + 
     4*G[{0}, yu^(-1)]*G[{0, 1, yu^(-1), 1/(yu*yv)}, yw] + 
     4*G[{0}, yv^(-1)]*G[{0, 1, yu^(-1), 1/(yu*yv)}, yw] - 
     4*G[{0}, yw]*G[{0, 1, yu^(-1), 1/(yu*yv)}, yw] - 
     4*G[{1}, yu^(-1)]*G[{0, 1, yu^(-1), 1/(yu*yv)}, yw] - 
     4*G[{1}, yv^(-1)]*G[{0, 1, yu^(-1), 1/(yu*yv)}, yw] + 
     4*G[{0}, yu^(-1)]*G[{0, 1, yv^(-1), 1}, yw] + 
     4*G[{0}, yv^(-1)]*G[{0, 1, yv^(-1), 1}, yw] - 
     4*G[{0}, yw]*G[{0, 1, yv^(-1), 1}, yw] - 4*G[{1}, yu^(-1)]*
      G[{0, 1, yv^(-1), 1}, yw] - 4*G[{1}, yv^(-1)]*G[{0, 1, yv^(-1), 1}, 
       yw] - 8*G[{0}, yu^(-1)]*G[{0, 1, yv^(-1), yv^(-1)}, yw] - 
     8*G[{0}, yv^(-1)]*G[{0, 1, yv^(-1), yv^(-1)}, yw] + 
     8*G[{0}, yw]*G[{0, 1, yv^(-1), yv^(-1)}, yw] + 
     16*G[{1}, yu^(-1)]*G[{0, 1, yv^(-1), yv^(-1)}, yw] + 
     4*G[{0}, yu^(-1)]*G[{0, 1, yv^(-1), 1/(yu*yv)}, yw] + 
     4*G[{0}, yv^(-1)]*G[{0, 1, yv^(-1), 1/(yu*yv)}, yw] - 
     4*G[{0}, yw]*G[{0, 1, yv^(-1), 1/(yu*yv)}, yw] - 
     4*G[{1}, yu^(-1)]*G[{0, 1, yv^(-1), 1/(yu*yv)}, yw] - 
     4*G[{1}, yv^(-1)]*G[{0, 1, yv^(-1), 1/(yu*yv)}, yw] + 
     4*G[{1}, yu^(-1)]*G[{0, 1, 1/(yu*yv), 1}, yw] + 
     4*G[{1}, yv^(-1)]*G[{0, 1, 1/(yu*yv), 1}, yw] - 
     8*G[{yu}, yv^(-1)]*G[{0, 1, 1/(yu*yv), 1}, yw] - 
     4*G[{1}, yu^(-1)]*G[{0, 1, 1/(yu*yv), 1/(yu*yv)}, yw] - 
     4*G[{1}, yv^(-1)]*G[{0, 1, 1/(yu*yv), 1/(yu*yv)}, yw] + 
     8*G[{yu}, yv^(-1)]*G[{0, 1, 1/(yu*yv), 1/(yu*yv)}, yw] + 
     8*G[{1}, yu^(-1)]*G[{0, yu^(-1), 0, yv^(-1)}, yw] - 
     8*G[{1}, yv^(-1)]*G[{0, yu^(-1), 0, yv^(-1)}, yw] - 
     4*G[{1}, yu^(-1)]*G[{0, yu^(-1), 0, 1/(yu*yv)}, yw] + 
     4*G[{1}, yv^(-1)]*G[{0, yu^(-1), 0, 1/(yu*yv)}, yw] - 
     4*G[{0}, yu^(-1)]*G[{0, yu^(-1), 1, yu^(-1)}, yw] - 
     4*G[{0}, yv^(-1)]*G[{0, yu^(-1), 1, yu^(-1)}, yw] + 
     4*G[{0}, yw]*G[{0, yu^(-1), 1, yu^(-1)}, yw] + 
     8*G[{1}, yv^(-1)]*G[{0, yu^(-1), 1, yu^(-1)}, yw] + 
     4*G[{0}, yu^(-1)]*G[{0, yu^(-1), 1, yv^(-1)}, yw] + 
     4*G[{0}, yv^(-1)]*G[{0, yu^(-1), 1, yv^(-1)}, yw] - 
     4*G[{0}, yw]*G[{0, yu^(-1), 1, yv^(-1)}, yw] - 
     8*G[{1}, yu^(-1)]*G[{0, yu^(-1), 1, yv^(-1)}, yw] - 
     8*G[{0}, yu^(-1)]*G[{0, yu^(-1), yu^(-1), 1}, yw] - 
     8*G[{0}, yv^(-1)]*G[{0, yu^(-1), yu^(-1), 1}, yw] + 
     8*G[{0}, yw]*G[{0, yu^(-1), yu^(-1), 1}, yw] + 
     8*G[{1}, yu^(-1)]*G[{0, yu^(-1), yu^(-1), 1}, yw] + 
     8*G[{1}, yv^(-1)]*G[{0, yu^(-1), yu^(-1), 1}, yw] + 
     16*G[{0}, yu^(-1)]*G[{0, yu^(-1), yu^(-1), yu^(-1)}, yw] + 
     16*G[{0}, yv^(-1)]*G[{0, yu^(-1), yu^(-1), yu^(-1)}, yw] - 
     16*G[{0}, yw]*G[{0, yu^(-1), yu^(-1), yu^(-1)}, yw] - 
     32*G[{1}, yv^(-1)]*G[{0, yu^(-1), yu^(-1), yu^(-1)}, yw] - 
     8*G[{0}, yu^(-1)]*G[{0, yu^(-1), yu^(-1), 1/(yu*yv)}, yw] - 
     8*G[{0}, yv^(-1)]*G[{0, yu^(-1), yu^(-1), 1/(yu*yv)}, yw] + 
     8*G[{0}, yw]*G[{0, yu^(-1), yu^(-1), 1/(yu*yv)}, yw] + 
     8*G[{1}, yu^(-1)]*G[{0, yu^(-1), yu^(-1), 1/(yu*yv)}, yw] + 
     8*G[{1}, yv^(-1)]*G[{0, yu^(-1), yu^(-1), 1/(yu*yv)}, yw] - 
     4*G[{0}, yu^(-1)]*G[{0, yu^(-1), 1/(yu*yv), yu^(-1)}, yw] - 
     4*G[{0}, yv^(-1)]*G[{0, yu^(-1), 1/(yu*yv), yu^(-1)}, yw] + 
     4*G[{0}, yw]*G[{0, yu^(-1), 1/(yu*yv), yu^(-1)}, yw] + 
     8*G[{1}, yv^(-1)]*G[{0, yu^(-1), 1/(yu*yv), yu^(-1)}, yw] + 
     4*G[{0}, yu^(-1)]*G[{0, yu^(-1), 1/(yu*yv), yv^(-1)}, yw] + 
     4*G[{0}, yv^(-1)]*G[{0, yu^(-1), 1/(yu*yv), yv^(-1)}, yw] - 
     4*G[{0}, yw]*G[{0, yu^(-1), 1/(yu*yv), yv^(-1)}, yw] - 
     8*G[{1}, yu^(-1)]*G[{0, yu^(-1), 1/(yu*yv), yv^(-1)}, yw] + 
     4*G[{0}, yu^(-1)]*G[{0, yu, 1, 1}, yv^(-1)] + 
     4*G[{0}, yv^(-1)]*G[{0, yu, 1, 1}, yv^(-1)] - 
     4*G[{0}, yw]*G[{0, yu, 1, 1}, yv^(-1)] - 4*G[{1}, yu^(-1)]*
      G[{0, yu, 1, 1}, yv^(-1)] + 4*G[{1}, yv^(-1)]*
      G[{0, yu, 1, 1}, yv^(-1)] + 8*G[{1}, yv^(-1)]*
      G[{0, yu, yu, 1}, yv^(-1)] + 4*G[{1}, yu^(-1)]*
      G[{0, yv^(-1), 0, 1/(yu*yv)}, yw] - 4*G[{1}, yv^(-1)]*
      G[{0, yv^(-1), 0, 1/(yu*yv)}, yw] + 4*G[{0}, yu^(-1)]*
      G[{0, yv^(-1), 1, yu^(-1)}, yw] + 4*G[{0}, yv^(-1)]*
      G[{0, yv^(-1), 1, yu^(-1)}, yw] - 4*G[{0}, yw]*
      G[{0, yv^(-1), 1, yu^(-1)}, yw] - 8*G[{1}, yv^(-1)]*
      G[{0, yv^(-1), 1, yu^(-1)}, yw] - 4*G[{0}, yu^(-1)]*
      G[{0, yv^(-1), 1, yv^(-1)}, yw] - 4*G[{0}, yv^(-1)]*
      G[{0, yv^(-1), 1, yv^(-1)}, yw] + 4*G[{0}, yw]*
      G[{0, yv^(-1), 1, yv^(-1)}, yw] + 8*G[{1}, yu^(-1)]*
      G[{0, yv^(-1), 1, yv^(-1)}, yw] - 8*G[{0}, yu^(-1)]*
      G[{0, yv^(-1), yv^(-1), 1}, yw] - 8*G[{0}, yv^(-1)]*
      G[{0, yv^(-1), yv^(-1), 1}, yw] + 8*G[{0}, yw]*
      G[{0, yv^(-1), yv^(-1), 1}, yw] + 8*G[{1}, yu^(-1)]*
      G[{0, yv^(-1), yv^(-1), 1}, yw] + 8*G[{1}, yv^(-1)]*
      G[{0, yv^(-1), yv^(-1), 1}, yw] + 16*G[{0}, yu^(-1)]*
      G[{0, yv^(-1), yv^(-1), yv^(-1)}, yw] + 16*G[{0}, yv^(-1)]*
      G[{0, yv^(-1), yv^(-1), yv^(-1)}, yw] - 16*G[{0}, yw]*
      G[{0, yv^(-1), yv^(-1), yv^(-1)}, yw] - 32*G[{1}, yu^(-1)]*
      G[{0, yv^(-1), yv^(-1), yv^(-1)}, yw] - 8*G[{0}, yu^(-1)]*
      G[{0, yv^(-1), yv^(-1), 1/(yu*yv)}, yw] - 8*G[{0}, yv^(-1)]*
      G[{0, yv^(-1), yv^(-1), 1/(yu*yv)}, yw] + 
     8*G[{0}, yw]*G[{0, yv^(-1), yv^(-1), 1/(yu*yv)}, yw] + 
     8*G[{1}, yu^(-1)]*G[{0, yv^(-1), yv^(-1), 1/(yu*yv)}, yw] + 
     8*G[{1}, yv^(-1)]*G[{0, yv^(-1), yv^(-1), 1/(yu*yv)}, yw] + 
     4*G[{0}, yu^(-1)]*G[{0, yv^(-1), 1/(yu*yv), yu^(-1)}, yw] + 
     4*G[{0}, yv^(-1)]*G[{0, yv^(-1), 1/(yu*yv), yu^(-1)}, yw] - 
     4*G[{0}, yw]*G[{0, yv^(-1), 1/(yu*yv), yu^(-1)}, yw] - 
     8*G[{1}, yv^(-1)]*G[{0, yv^(-1), 1/(yu*yv), yu^(-1)}, yw] - 
     4*G[{0}, yu^(-1)]*G[{0, yv^(-1), 1/(yu*yv), yv^(-1)}, yw] - 
     4*G[{0}, yv^(-1)]*G[{0, yv^(-1), 1/(yu*yv), yv^(-1)}, yw] + 
     4*G[{0}, yw]*G[{0, yv^(-1), 1/(yu*yv), yv^(-1)}, yw] + 
     8*G[{1}, yu^(-1)]*G[{0, yv^(-1), 1/(yu*yv), yv^(-1)}, yw] + 
     4*G[{1}, yu^(-1)]*G[{0, 1/(yu*yv), 1, 1}, yw] + 
     4*G[{1}, yv^(-1)]*G[{0, 1/(yu*yv), 1, 1}, yw] - 
     8*G[{yu}, yv^(-1)]*G[{0, 1/(yu*yv), 1, 1}, yw] - 
     4*G[{1}, yu^(-1)]*G[{0, 1/(yu*yv), 1, 1/(yu*yv)}, yw] - 
     4*G[{1}, yv^(-1)]*G[{0, 1/(yu*yv), 1, 1/(yu*yv)}, yw] + 
     8*G[{yu}, yv^(-1)]*G[{0, 1/(yu*yv), 1, 1/(yu*yv)}, yw] + 
     4*G[{0}, yu^(-1)]*G[{0, 1/(yu*yv), yu^(-1), 1}, yw] + 
     4*G[{0}, yv^(-1)]*G[{0, 1/(yu*yv), yu^(-1), 1}, yw] - 
     4*G[{0}, yw]*G[{0, 1/(yu*yv), yu^(-1), 1}, yw] - 
     4*G[{1}, yu^(-1)]*G[{0, 1/(yu*yv), yu^(-1), 1}, yw] - 
     4*G[{1}, yv^(-1)]*G[{0, 1/(yu*yv), yu^(-1), 1}, yw] - 
     8*G[{0}, yu^(-1)]*G[{0, 1/(yu*yv), yu^(-1), yu^(-1)}, yw] - 
     8*G[{0}, yv^(-1)]*G[{0, 1/(yu*yv), yu^(-1), yu^(-1)}, yw] + 
     8*G[{0}, yw]*G[{0, 1/(yu*yv), yu^(-1), yu^(-1)}, yw] + 
     16*G[{1}, yv^(-1)]*G[{0, 1/(yu*yv), yu^(-1), yu^(-1)}, yw] + 
     4*G[{0}, yu^(-1)]*G[{0, 1/(yu*yv), yu^(-1), 1/(yu*yv)}, yw] + 
     4*G[{0}, yv^(-1)]*G[{0, 1/(yu*yv), yu^(-1), 1/(yu*yv)}, yw] - 
     4*G[{0}, yw]*G[{0, 1/(yu*yv), yu^(-1), 1/(yu*yv)}, yw] - 
     4*G[{1}, yu^(-1)]*G[{0, 1/(yu*yv), yu^(-1), 1/(yu*yv)}, yw] - 
     4*G[{1}, yv^(-1)]*G[{0, 1/(yu*yv), yu^(-1), 1/(yu*yv)}, yw] + 
     4*G[{0}, yu^(-1)]*G[{0, 1/(yu*yv), yv^(-1), 1}, yw] + 
     4*G[{0}, yv^(-1)]*G[{0, 1/(yu*yv), yv^(-1), 1}, yw] - 
     4*G[{0}, yw]*G[{0, 1/(yu*yv), yv^(-1), 1}, yw] - 
     4*G[{1}, yu^(-1)]*G[{0, 1/(yu*yv), yv^(-1), 1}, yw] - 
     4*G[{1}, yv^(-1)]*G[{0, 1/(yu*yv), yv^(-1), 1}, yw] - 
     8*G[{0}, yu^(-1)]*G[{0, 1/(yu*yv), yv^(-1), yv^(-1)}, yw] - 
     8*G[{0}, yv^(-1)]*G[{0, 1/(yu*yv), yv^(-1), yv^(-1)}, yw] + 
     8*G[{0}, yw]*G[{0, 1/(yu*yv), yv^(-1), yv^(-1)}, yw] + 
     16*G[{1}, yu^(-1)]*G[{0, 1/(yu*yv), yv^(-1), yv^(-1)}, yw] + 
     4*G[{0}, yu^(-1)]*G[{0, 1/(yu*yv), yv^(-1), 1/(yu*yv)}, yw] + 
     4*G[{0}, yv^(-1)]*G[{0, 1/(yu*yv), yv^(-1), 1/(yu*yv)}, yw] - 
     4*G[{0}, yw]*G[{0, 1/(yu*yv), yv^(-1), 1/(yu*yv)}, yw] - 
     4*G[{1}, yu^(-1)]*G[{0, 1/(yu*yv), yv^(-1), 1/(yu*yv)}, yw] - 
     4*G[{1}, yv^(-1)]*G[{0, 1/(yu*yv), yv^(-1), 1/(yu*yv)}, yw] - 
     4*G[{1}, yu^(-1)]*G[{0, 1/(yu*yv), 1/(yu*yv), 1}, yw] - 
     4*G[{1}, yv^(-1)]*G[{0, 1/(yu*yv), 1/(yu*yv), 1}, yw] + 
     8*G[{yu}, yv^(-1)]*G[{0, 1/(yu*yv), 1/(yu*yv), 1}, yw] + 
     4*G[{1}, yu^(-1)]*G[{0, 1/(yu*yv), 1/(yu*yv), 1/(yu*yv)}, yw] + 
     4*G[{1}, yv^(-1)]*G[{0, 1/(yu*yv), 1/(yu*yv), 1/(yu*yv)}, yw] - 
     8*G[{yu}, yv^(-1)]*G[{0, 1/(yu*yv), 1/(yu*yv), 1/(yu*yv)}, yw] + 
     8*G[{0, 0, 0, 1, 1}, yu^(-1)] + 8*G[{0, 0, 0, 1, 1}, yv^(-1)] + 
     48*G[{0, 0, 0, 1, 1}, yw] - 48*G[{0, 0, 0, 1, yu^(-1)}, yw] - 
     12*G[{0, 0, 0, 1, yu}, yv^(-1)] - 48*G[{0, 0, 0, 1, yv^(-1)}, yw] + 
     48*G[{0, 0, 0, 1, 1/(yu*yv)}, yw] - 48*G[{0, 0, 0, yu^(-1), 1}, yw] + 
     48*G[{0, 0, 0, yu^(-1), yu^(-1)}, yw] + 
     48*G[{0, 0, 0, yu^(-1), yv^(-1)}, yw] - 
     48*G[{0, 0, 0, yu^(-1), 1/(yu*yv)}, yw] - 
     12*G[{0, 0, 0, yu, 1}, yv^(-1)] + 16*G[{0, 0, 0, yu, yu}, yv^(-1)] - 
     48*G[{0, 0, 0, yv^(-1), 1}, yw] + 48*G[{0, 0, 0, yv^(-1), yu^(-1)}, 
       yw] + 48*G[{0, 0, 0, yv^(-1), yv^(-1)}, yw] - 
     48*G[{0, 0, 0, yv^(-1), 1/(yu*yv)}, yw] + 
     48*G[{0, 0, 0, 1/(yu*yv), 1}, yw] - 48*G[{0, 0, 0, 1/(yu*yv), yu^(-1)}, 
       yw] - 48*G[{0, 0, 0, 1/(yu*yv), yv^(-1)}, yw] + 
     48*G[{0, 0, 0, 1/(yu*yv), 1/(yu*yv)}, yw] + 16*G[{0, 0, 1, 0, 1}, yw] - 
     16*G[{0, 0, 1, 0, yu^(-1)}, yw] - 4*G[{0, 0, 1, 0, yu}, yv^(-1)] - 
     16*G[{0, 0, 1, 0, yv^(-1)}, yw] + 16*G[{0, 0, 1, 0, 1/(yu*yv)}, yw] + 
     12*G[{0, 0, 1, 1, 1}, yu^(-1)] + 12*G[{0, 0, 1, 1, 1}, yv^(-1)] - 
     16*G[{0, 0, 1, 1, yu^(-1)}, yw] - 8*G[{0, 0, 1, 1, yu}, yv^(-1)] - 
     16*G[{0, 0, 1, 1, yv^(-1)}, yw] - 32*G[{0, 0, 1, yu^(-1), yu^(-1)}, 
       yw] - 32*G[{0, 0, 1, yu^(-1), yv^(-1)}, yw] + 
     24*G[{0, 0, 1, yu^(-1), 1/(yu*yv)}, yw] - 
     8*G[{0, 0, 1, yu, 1}, yv^(-1)] - 32*G[{0, 0, 1, yv^(-1), yu^(-1)}, yw] - 
     32*G[{0, 0, 1, yv^(-1), yv^(-1)}, yw] + 
     24*G[{0, 0, 1, yv^(-1), 1/(yu*yv)}, yw] + 
     8*G[{0, 0, 1, 1/(yu*yv), yu^(-1)}, yw] + 
     8*G[{0, 0, 1, 1/(yu*yv), yv^(-1)}, yw] - 
     16*G[{0, 0, yu^(-1), 0, 1}, yw] + 16*G[{0, 0, yu^(-1), 0, yu^(-1)}, 
       yw] + 16*G[{0, 0, yu^(-1), 0, yv^(-1)}, yw] - 
     16*G[{0, 0, yu^(-1), 0, 1/(yu*yv)}, yw] - 
     8*G[{0, 0, yu^(-1), 1, yu^(-1)}, yw] - 
     8*G[{0, 0, yu^(-1), 1, yv^(-1)}, yw] - 
     16*G[{0, 0, yu^(-1), yu^(-1), yu^(-1)}, yw] + 
     16*G[{0, 0, yu^(-1), yu^(-1), yv^(-1)}, yw] - 
     32*G[{0, 0, yu^(-1), yu^(-1), 1/(yu*yv)}, yw] + 
     16*G[{0, 0, yu^(-1), yv^(-1), yu^(-1)}, yw] + 
     16*G[{0, 0, yu^(-1), yv^(-1), yv^(-1)}, yw] - 
     16*G[{0, 0, yu^(-1), 1/(yu*yv), yu^(-1)}, yw] + 
     16*G[{0, 0, yu^(-1), 1/(yu*yv), yv^(-1)}, yw] - 
     4*G[{0, 0, yu, 0, 1}, yv^(-1)] + 8*G[{0, 0, yu, 0, yu}, yv^(-1)] - 
     12*G[{0, 0, yu, 1, 1}, yv^(-1)] - 8*G[{0, 0, yu, yu, 1}, yv^(-1)] - 
     16*G[{0, 0, yv^(-1), 0, 1}, yw] + 16*G[{0, 0, yv^(-1), 0, yu^(-1)}, 
       yw] + 16*G[{0, 0, yv^(-1), 0, yv^(-1)}, yw] - 
     16*G[{0, 0, yv^(-1), 0, 1/(yu*yv)}, yw] - 
     8*G[{0, 0, yv^(-1), 1, yu^(-1)}, yw] - 
     8*G[{0, 0, yv^(-1), 1, yv^(-1)}, yw] + 
     16*G[{0, 0, yv^(-1), yu^(-1), yu^(-1)}, yw] - 
     16*G[{0, 0, yv^(-1), yv^(-1), yu^(-1)}, yw] - 
     16*G[{0, 0, yv^(-1), yv^(-1), yv^(-1)}, yw] - 
     32*G[{0, 0, yv^(-1), yv^(-1), 1/(yu*yv)}, yw] - 
     16*G[{0, 0, yv^(-1), 1/(yu*yv), yv^(-1)}, yw] + 
     16*G[{0, 0, 1/(yu*yv), 0, 1}, yw] - 16*G[{0, 0, 1/(yu*yv), 0, yu^(-1)}, 
       yw] - 16*G[{0, 0, 1/(yu*yv), 0, yv^(-1)}, yw] + 
     16*G[{0, 0, 1/(yu*yv), 0, 1/(yu*yv)}, yw] + 
     8*G[{0, 0, 1/(yu*yv), 1, yu^(-1)}, yw] + 
     8*G[{0, 0, 1/(yu*yv), 1, yv^(-1)}, yw] - 
     16*G[{0, 0, 1/(yu*yv), yu^(-1), yu^(-1)}, yw] - 
     16*G[{0, 0, 1/(yu*yv), yv^(-1), yv^(-1)}, yw] - 
     16*G[{0, 0, 1/(yu*yv), 1/(yu*yv), yu^(-1)}, yw] - 
     16*G[{0, 0, 1/(yu*yv), 1/(yu*yv), yv^(-1)}, yw] - 
     12*G[{0, 1, 0, 1, yu^(-1)}, yw] - 4*G[{0, 1, 0, 1, yu}, yv^(-1)] - 
     12*G[{0, 1, 0, 1, yv^(-1)}, yw] - 8*G[{0, 1, 0, yu^(-1), yu^(-1)}, yw] - 
     16*G[{0, 1, 0, yu^(-1), yv^(-1)}, yw] + 
     12*G[{0, 1, 0, yu^(-1), 1/(yu*yv)}, yw] - 
     4*G[{0, 1, 0, yu, 1}, yv^(-1)] - 16*G[{0, 1, 0, yv^(-1), yu^(-1)}, yw] - 
     8*G[{0, 1, 0, yv^(-1), yv^(-1)}, yw] + 
     12*G[{0, 1, 0, yv^(-1), 1/(yu*yv)}, yw] - 
     4*G[{0, 1, 1, 0, yu}, yv^(-1)] + 16*G[{0, 1, 1, 1, 1}, yu^(-1)] + 
     16*G[{0, 1, 1, 1, 1}, yv^(-1)] - 8*G[{0, 1, 1, 1, 1}, yw] + 
     4*G[{0, 1, 1, 1, yu^(-1)}, yw] + 4*G[{0, 1, 1, 1, yv^(-1)}, yw] + 
     8*G[{0, 1, 1, 1/(yu*yv), 1}, yw] - 4*G[{0, 1, 1, 1/(yu*yv), yu^(-1)}, 
       yw] - 4*G[{0, 1, 1, 1/(yu*yv), yv^(-1)}, yw] - 
     12*G[{0, 1, yu^(-1), 0, yu^(-1)}, yw] - 
     12*G[{0, 1, yu^(-1), 0, yv^(-1)}, yw] + 
     12*G[{0, 1, yu^(-1), 0, 1/(yu*yv)}, yw] + 
     4*G[{0, 1, yu^(-1), 1, yu^(-1)}, yw] + 
     4*G[{0, 1, yu^(-1), 1, yv^(-1)}, yw] - 
     16*G[{0, 1, yu^(-1), yu^(-1), yu^(-1)}, yw] + 
     4*G[{0, 1, yu^(-1), 1/(yu*yv), yu^(-1)}, yw] + 
     4*G[{0, 1, yu^(-1), 1/(yu*yv), yv^(-1)}, yw] - 
     12*G[{0, 1, yv^(-1), 0, yu^(-1)}, yw] - 
     12*G[{0, 1, yv^(-1), 0, yv^(-1)}, yw] + 
     12*G[{0, 1, yv^(-1), 0, 1/(yu*yv)}, yw] + 
     4*G[{0, 1, yv^(-1), 1, yu^(-1)}, yw] + 
     4*G[{0, 1, yv^(-1), 1, yv^(-1)}, yw] - 
     16*G[{0, 1, yv^(-1), yv^(-1), yv^(-1)}, yw] + 
     4*G[{0, 1, yv^(-1), 1/(yu*yv), yu^(-1)}, yw] + 
     4*G[{0, 1, yv^(-1), 1/(yu*yv), yv^(-1)}, yw] + 
     8*G[{0, 1, 1/(yu*yv), 1, 1}, yw] - 4*G[{0, 1, 1/(yu*yv), 1, yu^(-1)}, 
       yw] - 4*G[{0, 1, 1/(yu*yv), 1, yv^(-1)}, yw] - 
     8*G[{0, 1, 1/(yu*yv), 1/(yu*yv), 1}, yw] + 
     4*G[{0, 1, 1/(yu*yv), 1/(yu*yv), yu^(-1)}, yw] + 
     4*G[{0, 1, 1/(yu*yv), 1/(yu*yv), yv^(-1)}, yw] - 
     16*G[{0, yu^(-1), 0, yu^(-1), yu^(-1)}, yw] + 
     8*G[{0, yu^(-1), 0, yu^(-1), yv^(-1)}, yw] - 
     16*G[{0, yu^(-1), 0, yu^(-1), 1/(yu*yv)}, yw] + 
     8*G[{0, yu^(-1), 0, yv^(-1), yu^(-1)}, yw] - 
     4*G[{0, yu^(-1), 0, 1/(yu*yv), yu^(-1)}, yw] + 
     12*G[{0, yu^(-1), 0, 1/(yu*yv), yv^(-1)}, yw] - 
     8*G[{0, yu^(-1), 1, yu^(-1), yu^(-1)}, yw] + 
     8*G[{0, yu^(-1), 1, yv^(-1), yv^(-1)}, yw] + 
     16*G[{0, yu^(-1), yu^(-1), 0, yv^(-1)}, yw] - 
     16*G[{0, yu^(-1), yu^(-1), 0, 1/(yu*yv)}, yw] - 
     8*G[{0, yu^(-1), yu^(-1), 1, yu^(-1)}, yw] - 
     8*G[{0, yu^(-1), yu^(-1), 1, yv^(-1)}, yw] + 
     32*G[{0, yu^(-1), yu^(-1), yu^(-1), yu^(-1)}, yw] - 
     8*G[{0, yu^(-1), yu^(-1), 1/(yu*yv), yu^(-1)}, yw] - 
     8*G[{0, yu^(-1), yu^(-1), 1/(yu*yv), yv^(-1)}, yw] + 
     8*G[{0, yu^(-1), yv^(-1), 0, yv^(-1)}, yw] - 
     8*G[{0, yu^(-1), yv^(-1), 0, 1/(yu*yv)}, yw] + 
     8*G[{0, yu^(-1), 1/(yu*yv), 0, yv^(-1)}, yw] - 
     8*G[{0, yu^(-1), 1/(yu*yv), yu^(-1), yu^(-1)}, yw] + 
     8*G[{0, yu^(-1), 1/(yu*yv), yv^(-1), yv^(-1)}, yw] - 
     4*G[{0, yu, 0, yu, 1}, yv^(-1)] - 8*G[{0, yu, 1, 1, 1}, yv^(-1)] - 
     8*G[{0, yu, yu, 1, 1}, yv^(-1)] - 8*G[{0, yv^(-1), 0, yv^(-1), yu^(-1)}, 
       yw] - 16*G[{0, yv^(-1), 0, yv^(-1), yv^(-1)}, yw] - 
     16*G[{0, yv^(-1), 0, yv^(-1), 1/(yu*yv)}, yw] + 
     4*G[{0, yv^(-1), 0, 1/(yu*yv), yu^(-1)}, yw] - 
     4*G[{0, yv^(-1), 0, 1/(yu*yv), yv^(-1)}, yw] + 
     8*G[{0, yv^(-1), 1, yu^(-1), yu^(-1)}, yw] - 
     8*G[{0, yv^(-1), 1, yv^(-1), yv^(-1)}, yw] - 
     8*G[{0, yv^(-1), yu^(-1), 0, 1/(yu*yv)}, yw] - 
     16*G[{0, yv^(-1), yv^(-1), 0, 1/(yu*yv)}, yw] - 
     8*G[{0, yv^(-1), yv^(-1), 1, yu^(-1)}, yw] - 
     8*G[{0, yv^(-1), yv^(-1), 1, yv^(-1)}, yw] + 
     32*G[{0, yv^(-1), yv^(-1), yv^(-1), yv^(-1)}, yw] - 
     8*G[{0, yv^(-1), yv^(-1), 1/(yu*yv), yu^(-1)}, yw] - 
     8*G[{0, yv^(-1), yv^(-1), 1/(yu*yv), yv^(-1)}, yw] + 
     8*G[{0, yv^(-1), 1/(yu*yv), yu^(-1), yu^(-1)}, yw] - 
     8*G[{0, yv^(-1), 1/(yu*yv), yv^(-1), yv^(-1)}, yw] - 
     12*G[{0, 1/(yu*yv), 0, 1/(yu*yv), yu^(-1)}, yw] - 
     12*G[{0, 1/(yu*yv), 0, 1/(yu*yv), yv^(-1)}, yw] + 
     8*G[{0, 1/(yu*yv), 1, 1, 1}, yw] - 4*G[{0, 1/(yu*yv), 1, 1, yu^(-1)}, 
       yw] - 4*G[{0, 1/(yu*yv), 1, 1, yv^(-1)}, yw] - 
     8*G[{0, 1/(yu*yv), 1, 1/(yu*yv), 1}, yw] + 
     4*G[{0, 1/(yu*yv), 1, 1/(yu*yv), yu^(-1)}, yw] + 
     4*G[{0, 1/(yu*yv), 1, 1/(yu*yv), yv^(-1)}, yw] + 
     4*G[{0, 1/(yu*yv), yu^(-1), 1, yu^(-1)}, yw] + 
     4*G[{0, 1/(yu*yv), yu^(-1), 1, yv^(-1)}, yw] - 
     16*G[{0, 1/(yu*yv), yu^(-1), yu^(-1), yu^(-1)}, yw] + 
     4*G[{0, 1/(yu*yv), yu^(-1), 1/(yu*yv), yu^(-1)}, yw] + 
     4*G[{0, 1/(yu*yv), yu^(-1), 1/(yu*yv), yv^(-1)}, yw] + 
     4*G[{0, 1/(yu*yv), yv^(-1), 1, yu^(-1)}, yw] + 
     4*G[{0, 1/(yu*yv), yv^(-1), 1, yv^(-1)}, yw] - 
     16*G[{0, 1/(yu*yv), yv^(-1), yv^(-1), yv^(-1)}, yw] + 
     4*G[{0, 1/(yu*yv), yv^(-1), 1/(yu*yv), yu^(-1)}, yw] + 
     4*G[{0, 1/(yu*yv), yv^(-1), 1/(yu*yv), yv^(-1)}, yw] - 
     8*G[{0, 1/(yu*yv), 1/(yu*yv), 1, 1}, yw] + 
     4*G[{0, 1/(yu*yv), 1/(yu*yv), 1, yu^(-1)}, yw] + 
     4*G[{0, 1/(yu*yv), 1/(yu*yv), 1, yv^(-1)}, yw] + 
     8*G[{0, 1/(yu*yv), 1/(yu*yv), 1/(yu*yv), 1}, yw] - 
     4*G[{0, 1/(yu*yv), 1/(yu*yv), 1/(yu*yv), yu^(-1)}, yw] - 
     4*G[{0, 1/(yu*yv), 1/(yu*yv), 1/(yu*yv), yv^(-1)}, yw] + 
     (4*Pi^2*Zeta[3])/3 - 4*G[{1}, yu^(-1)]^2*Zeta[3] + 
     8*G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*Zeta[3] - 4*G[{1}, yv^(-1)]^2*
      Zeta[3] - 8*G[{0, 1}, yw]*Zeta[3] + 8*G[{0, yu^(-1)}, yw]*Zeta[3] + 
     8*G[{0, yv^(-1)}, yw]*Zeta[3] - 8*G[{0, 1/(yu*yv)}, yw]*Zeta[3] - 
     8*Zeta[5]
 
J1wuvRegII = (Pi^4*G[{0}, yu^(-1)])/30 - (Pi^2*G[{0}, yu^(-1)]^3)/9 + 
     (Pi^4*G[{0}, yv^(-1)])/30 - (Pi^2*G[{0}, yu^(-1)]^2*G[{0}, yv^(-1)])/3 - 
     (Pi^2*G[{0}, yu^(-1)]*G[{0}, yv^(-1)]^2)/3 - (Pi^2*G[{0}, yv^(-1)]^3)/
      9 - (Pi^4*G[{0}, yw])/30 + (Pi^2*G[{0}, yu^(-1)]^2*G[{0}, yw])/3 + 
     (2*Pi^2*G[{0}, yu^(-1)]*G[{0}, yv^(-1)]*G[{0}, yw])/3 + 
     (Pi^2*G[{0}, yv^(-1)]^2*G[{0}, yw])/3 - 
     (Pi^2*G[{0}, yu^(-1)]*G[{0}, yw]^2)/3 - 
     (Pi^2*G[{0}, yv^(-1)]*G[{0}, yw]^2)/3 + (Pi^2*G[{0}, yw]^3)/9 + 
     (Pi^4*G[{1}, yv^(-1)])/18 + (Pi^2*G[{0}, yu^(-1)]^2*G[{1}, yv^(-1)])/3 + 
     (2*Pi^2*G[{0}, yu^(-1)]*G[{0}, yv^(-1)]*G[{1}, yv^(-1)])/3 + 
     (Pi^2*G[{0}, yv^(-1)]^2*G[{1}, yv^(-1)])/3 - 
     (2*Pi^2*G[{0}, yu^(-1)]*G[{0}, yw]*G[{1}, yv^(-1)])/3 - 
     (2*Pi^2*G[{0}, yv^(-1)]*G[{0}, yw]*G[{1}, yv^(-1)])/3 + 
     (Pi^2*G[{0}, yw]^2*G[{1}, yv^(-1)])/3 - 
     (Pi^2*G[{0}, yu^(-1)]*G[{1}, yv^(-1)]^2)/3 - 
     (Pi^2*G[{0}, yv^(-1)]*G[{1}, yv^(-1)]^2)/3 + 
     (Pi^2*G[{0}, yw]*G[{1}, yv^(-1)]^2)/3 - (Pi^4*G[{1}, yw])/18 - 
     (Pi^2*G[{0}, yu^(-1)]^2*G[{1}, yw])/3 - 
     (2*Pi^2*G[{0}, yu^(-1)]*G[{0}, yv^(-1)]*G[{1}, yw])/3 - 
     (Pi^2*G[{0}, yv^(-1)]^2*G[{1}, yw])/3 + 
     (2*Pi^2*G[{0}, yu^(-1)]*G[{0}, yw]*G[{1}, yw])/3 + 
     (2*Pi^2*G[{0}, yv^(-1)]*G[{0}, yw]*G[{1}, yw])/3 - 
     (Pi^2*G[{0}, yw]^2*G[{1}, yw])/3 + 
     (2*Pi^2*G[{0}, yu^(-1)]*G[{1}, yv^(-1)]*G[{1}, yw])/3 + 
     (2*Pi^2*G[{0}, yv^(-1)]*G[{1}, yv^(-1)]*G[{1}, yw])/3 - 
     (2*Pi^2*G[{0}, yw]*G[{1}, yv^(-1)]*G[{1}, yw])/3 - 
     (Pi^2*G[{0}, yu^(-1)]*G[{1}, yw]^2)/3 - 
     (Pi^2*G[{0}, yv^(-1)]*G[{1}, yw]^2)/3 + (Pi^2*G[{0}, yw]*G[{1}, yw]^2)/
      3 + (2*Pi^2*G[{0}, yu^(-1)]*G[{0, 1}, yu^(-1)])/3 - 
     (2*G[{0}, yu^(-1)]^3*G[{0, 1}, yu^(-1)])/3 + 
     (2*Pi^2*G[{0}, yv^(-1)]*G[{0, 1}, yu^(-1)])/3 - 
     2*G[{0}, yu^(-1)]^2*G[{0}, yv^(-1)]*G[{0, 1}, yu^(-1)] - 
     2*G[{0}, yu^(-1)]*G[{0}, yv^(-1)]^2*G[{0, 1}, yu^(-1)] - 
     (2*G[{0}, yv^(-1)]^3*G[{0, 1}, yu^(-1)])/3 - 
     (2*Pi^2*G[{0}, yw]*G[{0, 1}, yu^(-1)])/3 + 2*G[{0}, yu^(-1)]^2*
      G[{0}, yw]*G[{0, 1}, yu^(-1)] + 4*G[{0}, yu^(-1)]*G[{0}, yv^(-1)]*
      G[{0}, yw]*G[{0, 1}, yu^(-1)] + 2*G[{0}, yv^(-1)]^2*G[{0}, yw]*
      G[{0, 1}, yu^(-1)] - 2*G[{0}, yu^(-1)]*G[{0}, yw]^2*
      G[{0, 1}, yu^(-1)] - 2*G[{0}, yv^(-1)]*G[{0}, yw]^2*
      G[{0, 1}, yu^(-1)] + (2*G[{0}, yw]^3*G[{0, 1}, yu^(-1)])/3 + 
     (2*Pi^2*G[{1}, yv^(-1)]*G[{0, 1}, yu^(-1)])/3 + 
     2*G[{0}, yu^(-1)]^2*G[{1}, yv^(-1)]*G[{0, 1}, yu^(-1)] + 
     4*G[{0}, yu^(-1)]*G[{0}, yv^(-1)]*G[{1}, yv^(-1)]*G[{0, 1}, yu^(-1)] + 
     2*G[{0}, yv^(-1)]^2*G[{1}, yv^(-1)]*G[{0, 1}, yu^(-1)] - 
     4*G[{0}, yu^(-1)]*G[{0}, yw]*G[{1}, yv^(-1)]*G[{0, 1}, yu^(-1)] - 
     4*G[{0}, yv^(-1)]*G[{0}, yw]*G[{1}, yv^(-1)]*G[{0, 1}, yu^(-1)] + 
     2*G[{0}, yw]^2*G[{1}, yv^(-1)]*G[{0, 1}, yu^(-1)] - 
     2*G[{0}, yu^(-1)]*G[{1}, yv^(-1)]^2*G[{0, 1}, yu^(-1)] - 
     2*G[{0}, yv^(-1)]*G[{1}, yv^(-1)]^2*G[{0, 1}, yu^(-1)] + 
     2*G[{0}, yw]*G[{1}, yv^(-1)]^2*G[{0, 1}, yu^(-1)] - 
     (2*Pi^2*G[{1}, yw]*G[{0, 1}, yu^(-1)])/3 - 2*G[{0}, yu^(-1)]^2*
      G[{1}, yw]*G[{0, 1}, yu^(-1)] - 4*G[{0}, yu^(-1)]*G[{0}, yv^(-1)]*
      G[{1}, yw]*G[{0, 1}, yu^(-1)] - 2*G[{0}, yv^(-1)]^2*G[{1}, yw]*
      G[{0, 1}, yu^(-1)] + 4*G[{0}, yu^(-1)]*G[{0}, yw]*G[{1}, yw]*
      G[{0, 1}, yu^(-1)] + 4*G[{0}, yv^(-1)]*G[{0}, yw]*G[{1}, yw]*
      G[{0, 1}, yu^(-1)] - 2*G[{0}, yw]^2*G[{1}, yw]*G[{0, 1}, yu^(-1)] + 
     4*G[{0}, yu^(-1)]*G[{1}, yv^(-1)]*G[{1}, yw]*G[{0, 1}, yu^(-1)] + 
     4*G[{0}, yv^(-1)]*G[{1}, yv^(-1)]*G[{1}, yw]*G[{0, 1}, yu^(-1)] - 
     4*G[{0}, yw]*G[{1}, yv^(-1)]*G[{1}, yw]*G[{0, 1}, yu^(-1)] - 
     2*G[{0}, yu^(-1)]*G[{1}, yw]^2*G[{0, 1}, yu^(-1)] - 
     2*G[{0}, yv^(-1)]*G[{1}, yw]^2*G[{0, 1}, yu^(-1)] + 
     2*G[{0}, yw]*G[{1}, yw]^2*G[{0, 1}, yu^(-1)] + 
     2*G[{1}, yv^(-1)]*G[{0, 1}, yu^(-1)]^2 - 
     2*G[{1}, yw]*G[{0, 1}, yu^(-1)]^2 - 
     (2*G[{0}, yu^(-1)]^3*G[{0, 1}, yv^(-1)])/3 - 2*G[{0}, yu^(-1)]^2*
      G[{0}, yv^(-1)]*G[{0, 1}, yv^(-1)] - 2*G[{0}, yu^(-1)]*
      G[{0}, yv^(-1)]^2*G[{0, 1}, yv^(-1)] - 
     (2*G[{0}, yv^(-1)]^3*G[{0, 1}, yv^(-1)])/3 + 2*G[{0}, yu^(-1)]^2*
      G[{0}, yw]*G[{0, 1}, yv^(-1)] + 4*G[{0}, yu^(-1)]*G[{0}, yv^(-1)]*
      G[{0}, yw]*G[{0, 1}, yv^(-1)] + 2*G[{0}, yv^(-1)]^2*G[{0}, yw]*
      G[{0, 1}, yv^(-1)] - 2*G[{0}, yu^(-1)]*G[{0}, yw]^2*
      G[{0, 1}, yv^(-1)] - 2*G[{0}, yv^(-1)]*G[{0}, yw]^2*
      G[{0, 1}, yv^(-1)] + (2*G[{0}, yw]^3*G[{0, 1}, yv^(-1)])/3 + 
     (4*Pi^2*G[{1}, yv^(-1)]*G[{0, 1}, yv^(-1)])/3 + 
     2*G[{0}, yu^(-1)]^2*G[{1}, yv^(-1)]*G[{0, 1}, yv^(-1)] + 
     4*G[{0}, yu^(-1)]*G[{0}, yv^(-1)]*G[{1}, yv^(-1)]*G[{0, 1}, yv^(-1)] + 
     2*G[{0}, yv^(-1)]^2*G[{1}, yv^(-1)]*G[{0, 1}, yv^(-1)] - 
     4*G[{0}, yu^(-1)]*G[{0}, yw]*G[{1}, yv^(-1)]*G[{0, 1}, yv^(-1)] - 
     4*G[{0}, yv^(-1)]*G[{0}, yw]*G[{1}, yv^(-1)]*G[{0, 1}, yv^(-1)] + 
     2*G[{0}, yw]^2*G[{1}, yv^(-1)]*G[{0, 1}, yv^(-1)] - 
     2*G[{0}, yu^(-1)]*G[{1}, yv^(-1)]^2*G[{0, 1}, yv^(-1)] - 
     2*G[{0}, yv^(-1)]*G[{1}, yv^(-1)]^2*G[{0, 1}, yv^(-1)] + 
     2*G[{0}, yw]*G[{1}, yv^(-1)]^2*G[{0, 1}, yv^(-1)] - 
     (4*Pi^2*G[{1}, yw]*G[{0, 1}, yv^(-1)])/3 - 2*G[{0}, yu^(-1)]^2*
      G[{1}, yw]*G[{0, 1}, yv^(-1)] - 4*G[{0}, yu^(-1)]*G[{0}, yv^(-1)]*
      G[{1}, yw]*G[{0, 1}, yv^(-1)] - 2*G[{0}, yv^(-1)]^2*G[{1}, yw]*
      G[{0, 1}, yv^(-1)] + 4*G[{0}, yu^(-1)]*G[{0}, yw]*G[{1}, yw]*
      G[{0, 1}, yv^(-1)] + 4*G[{0}, yv^(-1)]*G[{0}, yw]*G[{1}, yw]*
      G[{0, 1}, yv^(-1)] - 2*G[{0}, yw]^2*G[{1}, yw]*G[{0, 1}, yv^(-1)] + 
     4*G[{0}, yu^(-1)]*G[{1}, yv^(-1)]*G[{1}, yw]*G[{0, 1}, yv^(-1)] + 
     4*G[{0}, yv^(-1)]*G[{1}, yv^(-1)]*G[{1}, yw]*G[{0, 1}, yv^(-1)] - 
     4*G[{0}, yw]*G[{1}, yv^(-1)]*G[{1}, yw]*G[{0, 1}, yv^(-1)] - 
     2*G[{0}, yu^(-1)]*G[{1}, yw]^2*G[{0, 1}, yv^(-1)] - 
     2*G[{0}, yv^(-1)]*G[{1}, yw]^2*G[{0, 1}, yv^(-1)] + 
     2*G[{0}, yw]*G[{1}, yw]^2*G[{0, 1}, yv^(-1)] - 
     2*G[{0}, yu^(-1)]*G[{0, 1}, yv^(-1)]^2 - 2*G[{0}, yv^(-1)]*
      G[{0, 1}, yv^(-1)]^2 + 2*G[{0}, yw]*G[{0, 1}, yv^(-1)]^2 + 
     2*G[{1}, yv^(-1)]*G[{0, 1}, yv^(-1)]^2 - 
     2*G[{1}, yw]*G[{0, 1}, yv^(-1)]^2 - (2*G[{0}, yu^(-1)]^3*G[{0, 1}, yw])/
      3 - 2*G[{0}, yu^(-1)]^2*G[{0}, yv^(-1)]*G[{0, 1}, yw] - 
     2*G[{0}, yu^(-1)]*G[{0}, yv^(-1)]^2*G[{0, 1}, yw] - 
     (2*G[{0}, yv^(-1)]^3*G[{0, 1}, yw])/3 + 2*G[{0}, yu^(-1)]^2*G[{0}, yw]*
      G[{0, 1}, yw] + 4*G[{0}, yu^(-1)]*G[{0}, yv^(-1)]*G[{0}, yw]*
      G[{0, 1}, yw] + 2*G[{0}, yv^(-1)]^2*G[{0}, yw]*G[{0, 1}, yw] - 
     2*G[{0}, yu^(-1)]*G[{0}, yw]^2*G[{0, 1}, yw] - 
     2*G[{0}, yv^(-1)]*G[{0}, yw]^2*G[{0, 1}, yw] + 
     (2*G[{0}, yw]^3*G[{0, 1}, yw])/3 + 
     (4*Pi^2*G[{1}, yv^(-1)]*G[{0, 1}, yw])/3 + 2*G[{0}, yu^(-1)]^2*
      G[{1}, yv^(-1)]*G[{0, 1}, yw] + 4*G[{0}, yu^(-1)]*G[{0}, yv^(-1)]*
      G[{1}, yv^(-1)]*G[{0, 1}, yw] + 2*G[{0}, yv^(-1)]^2*G[{1}, yv^(-1)]*
      G[{0, 1}, yw] - 4*G[{0}, yu^(-1)]*G[{0}, yw]*G[{1}, yv^(-1)]*
      G[{0, 1}, yw] - 4*G[{0}, yv^(-1)]*G[{0}, yw]*G[{1}, yv^(-1)]*
      G[{0, 1}, yw] + 2*G[{0}, yw]^2*G[{1}, yv^(-1)]*G[{0, 1}, yw] - 
     2*G[{0}, yu^(-1)]*G[{1}, yv^(-1)]^2*G[{0, 1}, yw] - 
     2*G[{0}, yv^(-1)]*G[{1}, yv^(-1)]^2*G[{0, 1}, yw] + 
     2*G[{0}, yw]*G[{1}, yv^(-1)]^2*G[{0, 1}, yw] + 
     (2*G[{1}, yv^(-1)]^3*G[{0, 1}, yw])/3 - 
     (4*Pi^2*G[{1}, yw]*G[{0, 1}, yw])/3 - 2*G[{0}, yu^(-1)]^2*G[{1}, yw]*
      G[{0, 1}, yw] - 4*G[{0}, yu^(-1)]*G[{0}, yv^(-1)]*G[{1}, yw]*
      G[{0, 1}, yw] - 2*G[{0}, yv^(-1)]^2*G[{1}, yw]*G[{0, 1}, yw] + 
     4*G[{0}, yu^(-1)]*G[{0}, yw]*G[{1}, yw]*G[{0, 1}, yw] + 
     4*G[{0}, yv^(-1)]*G[{0}, yw]*G[{1}, yw]*G[{0, 1}, yw] - 
     2*G[{0}, yw]^2*G[{1}, yw]*G[{0, 1}, yw] + 4*G[{0}, yu^(-1)]*
      G[{1}, yv^(-1)]*G[{1}, yw]*G[{0, 1}, yw] + 4*G[{0}, yv^(-1)]*
      G[{1}, yv^(-1)]*G[{1}, yw]*G[{0, 1}, yw] - 4*G[{0}, yw]*G[{1}, yv^(-1)]*
      G[{1}, yw]*G[{0, 1}, yw] - 2*G[{1}, yv^(-1)]^2*G[{1}, yw]*
      G[{0, 1}, yw] - 2*G[{0}, yu^(-1)]*G[{1}, yw]^2*G[{0, 1}, yw] - 
     2*G[{0}, yv^(-1)]*G[{1}, yw]^2*G[{0, 1}, yw] + 
     2*G[{0}, yw]*G[{1}, yw]^2*G[{0, 1}, yw] - 
     (4*Pi^2*G[{yu}, yv^(-1)]*G[{0, 1}, yw])/3 + 2*G[{0}, yu^(-1)]^2*
      G[{yu}, yv^(-1)]*G[{0, 1}, yw] + 4*G[{0}, yu^(-1)]*G[{0}, yv^(-1)]*
      G[{yu}, yv^(-1)]*G[{0, 1}, yw] + 2*G[{0}, yv^(-1)]^2*G[{yu}, yv^(-1)]*
      G[{0, 1}, yw] - 4*G[{0}, yu^(-1)]*G[{0}, yw]*G[{yu}, yv^(-1)]*
      G[{0, 1}, yw] - 4*G[{0}, yv^(-1)]*G[{0}, yw]*G[{yu}, yv^(-1)]*
      G[{0, 1}, yw] + 2*G[{0}, yw]^2*G[{yu}, yv^(-1)]*G[{0, 1}, yw] - 
     2*G[{1}, yv^(-1)]^2*G[{yu}, yv^(-1)]*G[{0, 1}, yw] + 
     4*G[{0}, yu^(-1)]*G[{1}, yw]*G[{yu}, yv^(-1)]*G[{0, 1}, yw] + 
     4*G[{0}, yv^(-1)]*G[{1}, yw]*G[{yu}, yv^(-1)]*G[{0, 1}, yw] - 
     4*G[{0}, yw]*G[{1}, yw]*G[{yu}, yv^(-1)]*G[{0, 1}, yw] + 
     4*G[{1}, yw]^2*G[{yu}, yv^(-1)]*G[{0, 1}, yw] - 
     4*G[{0}, yu^(-1)]*G[{yu}, yv^(-1)]^2*G[{0, 1}, yw] - 
     4*G[{0}, yv^(-1)]*G[{yu}, yv^(-1)]^2*G[{0, 1}, yw] + 
     4*G[{0}, yw]*G[{yu}, yv^(-1)]^2*G[{0, 1}, yw] - 
     4*G[{1}, yw]*G[{yu}, yv^(-1)]^2*G[{0, 1}, yw] + 
     (8*G[{yu}, yv^(-1)]^3*G[{0, 1}, yw])/3 - 4*G[{0}, yu^(-1)]*
      G[{0, 1}, yv^(-1)]*G[{0, 1}, yw] - 4*G[{0}, yv^(-1)]*G[{0, 1}, yv^(-1)]*
      G[{0, 1}, yw] + 4*G[{0}, yw]*G[{0, 1}, yv^(-1)]*G[{0, 1}, yw] + 
     4*G[{1}, yv^(-1)]*G[{0, 1}, yv^(-1)]*G[{0, 1}, yw] - 
     4*G[{1}, yw]*G[{0, 1}, yv^(-1)]*G[{0, 1}, yw] + 
     4*G[{yu}, yv^(-1)]*G[{0, 1}, yv^(-1)]*G[{0, 1}, yw] + 
     (2*G[{0}, yu^(-1)]^3*G[{0, yu^(-1)}, yw])/3 + 
     2*G[{0}, yu^(-1)]^2*G[{0}, yv^(-1)]*G[{0, yu^(-1)}, yw] + 
     2*G[{0}, yu^(-1)]*G[{0}, yv^(-1)]^2*G[{0, yu^(-1)}, yw] + 
     (2*G[{0}, yv^(-1)]^3*G[{0, yu^(-1)}, yw])/3 - 
     2*G[{0}, yu^(-1)]^2*G[{0}, yw]*G[{0, yu^(-1)}, yw] - 
     4*G[{0}, yu^(-1)]*G[{0}, yv^(-1)]*G[{0}, yw]*G[{0, yu^(-1)}, yw] - 
     2*G[{0}, yv^(-1)]^2*G[{0}, yw]*G[{0, yu^(-1)}, yw] + 
     2*G[{0}, yu^(-1)]*G[{0}, yw]^2*G[{0, yu^(-1)}, yw] + 
     2*G[{0}, yv^(-1)]*G[{0}, yw]^2*G[{0, yu^(-1)}, yw] - 
     (2*G[{0}, yw]^3*G[{0, yu^(-1)}, yw])/3 - 4*G[{0}, yu^(-1)]^2*
      G[{1}, yv^(-1)]*G[{0, yu^(-1)}, yw] - 8*G[{0}, yu^(-1)]*G[{0}, yv^(-1)]*
      G[{1}, yv^(-1)]*G[{0, yu^(-1)}, yw] - 4*G[{0}, yv^(-1)]^2*
      G[{1}, yv^(-1)]*G[{0, yu^(-1)}, yw] + 8*G[{0}, yu^(-1)]*G[{0}, yw]*
      G[{1}, yv^(-1)]*G[{0, yu^(-1)}, yw] + 8*G[{0}, yv^(-1)]*G[{0}, yw]*
      G[{1}, yv^(-1)]*G[{0, yu^(-1)}, yw] - 4*G[{0}, yw]^2*G[{1}, yv^(-1)]*
      G[{0, yu^(-1)}, yw] + 6*G[{0}, yu^(-1)]*G[{1}, yv^(-1)]^2*
      G[{0, yu^(-1)}, yw] + 6*G[{0}, yv^(-1)]*G[{1}, yv^(-1)]^2*
      G[{0, yu^(-1)}, yw] - 6*G[{0}, yw]*G[{1}, yv^(-1)]^2*
      G[{0, yu^(-1)}, yw] - (8*G[{1}, yv^(-1)]^3*G[{0, yu^(-1)}, yw])/3 + 
     (4*Pi^2*G[{1}, yw]*G[{0, yu^(-1)}, yw])/3 + 2*G[{0}, yu^(-1)]^2*
      G[{1}, yw]*G[{0, yu^(-1)}, yw] + 4*G[{0}, yu^(-1)]*G[{0}, yv^(-1)]*
      G[{1}, yw]*G[{0, yu^(-1)}, yw] + 2*G[{0}, yv^(-1)]^2*G[{1}, yw]*
      G[{0, yu^(-1)}, yw] - 4*G[{0}, yu^(-1)]*G[{0}, yw]*G[{1}, yw]*
      G[{0, yu^(-1)}, yw] - 4*G[{0}, yv^(-1)]*G[{0}, yw]*G[{1}, yw]*
      G[{0, yu^(-1)}, yw] + 2*G[{0}, yw]^2*G[{1}, yw]*G[{0, yu^(-1)}, yw] - 
     8*G[{0}, yu^(-1)]*G[{1}, yv^(-1)]*G[{1}, yw]*G[{0, yu^(-1)}, yw] - 
     8*G[{0}, yv^(-1)]*G[{1}, yv^(-1)]*G[{1}, yw]*G[{0, yu^(-1)}, yw] + 
     8*G[{0}, yw]*G[{1}, yv^(-1)]*G[{1}, yw]*G[{0, yu^(-1)}, yw] + 
     6*G[{1}, yv^(-1)]^2*G[{1}, yw]*G[{0, yu^(-1)}, yw] + 
     2*G[{0}, yu^(-1)]*G[{1}, yw]^2*G[{0, yu^(-1)}, yw] + 
     2*G[{0}, yv^(-1)]*G[{1}, yw]^2*G[{0, yu^(-1)}, yw] - 
     2*G[{0}, yw]*G[{1}, yw]^2*G[{0, yu^(-1)}, yw] - 
     4*G[{1}, yv^(-1)]*G[{1}, yw]^2*G[{0, yu^(-1)}, yw] + 
     4*G[{0}, yu^(-1)]*G[{0, 1}, yv^(-1)]*G[{0, yu^(-1)}, yw] + 
     4*G[{0}, yv^(-1)]*G[{0, 1}, yv^(-1)]*G[{0, yu^(-1)}, yw] - 
     4*G[{0}, yw]*G[{0, 1}, yv^(-1)]*G[{0, yu^(-1)}, yw] - 
     8*G[{1}, yv^(-1)]*G[{0, 1}, yv^(-1)]*G[{0, yu^(-1)}, yw] + 
     4*G[{1}, yw]*G[{0, 1}, yv^(-1)]*G[{0, yu^(-1)}, yw] + 
     (2*G[{0}, yu^(-1)]^3*G[{0, yu}, yv^(-1)])/3 + 
     2*G[{0}, yu^(-1)]^2*G[{0}, yv^(-1)]*G[{0, yu}, yv^(-1)] + 
     2*G[{0}, yu^(-1)]*G[{0}, yv^(-1)]^2*G[{0, yu}, yv^(-1)] + 
     (2*G[{0}, yv^(-1)]^3*G[{0, yu}, yv^(-1)])/3 - 
     2*G[{0}, yu^(-1)]^2*G[{0}, yw]*G[{0, yu}, yv^(-1)] - 
     4*G[{0}, yu^(-1)]*G[{0}, yv^(-1)]*G[{0}, yw]*G[{0, yu}, yv^(-1)] - 
     2*G[{0}, yv^(-1)]^2*G[{0}, yw]*G[{0, yu}, yv^(-1)] + 
     2*G[{0}, yu^(-1)]*G[{0}, yw]^2*G[{0, yu}, yv^(-1)] + 
     2*G[{0}, yv^(-1)]*G[{0}, yw]^2*G[{0, yu}, yv^(-1)] - 
     (2*G[{0}, yw]^3*G[{0, yu}, yv^(-1)])/3 - 
     (4*Pi^2*G[{1}, yv^(-1)]*G[{0, yu}, yv^(-1)])/3 - 
     2*G[{0}, yu^(-1)]^2*G[{1}, yv^(-1)]*G[{0, yu}, yv^(-1)] - 
     4*G[{0}, yu^(-1)]*G[{0}, yv^(-1)]*G[{1}, yv^(-1)]*G[{0, yu}, yv^(-1)] - 
     2*G[{0}, yv^(-1)]^2*G[{1}, yv^(-1)]*G[{0, yu}, yv^(-1)] + 
     4*G[{0}, yu^(-1)]*G[{0}, yw]*G[{1}, yv^(-1)]*G[{0, yu}, yv^(-1)] + 
     4*G[{0}, yv^(-1)]*G[{0}, yw]*G[{1}, yv^(-1)]*G[{0, yu}, yv^(-1)] - 
     2*G[{0}, yw]^2*G[{1}, yv^(-1)]*G[{0, yu}, yv^(-1)] + 
     2*G[{0}, yu^(-1)]*G[{1}, yv^(-1)]^2*G[{0, yu}, yv^(-1)] + 
     2*G[{0}, yv^(-1)]*G[{1}, yv^(-1)]^2*G[{0, yu}, yv^(-1)] - 
     2*G[{0}, yw]*G[{1}, yv^(-1)]^2*G[{0, yu}, yv^(-1)] + 
     (4*Pi^2*G[{1}, yw]*G[{0, yu}, yv^(-1)])/3 + 2*G[{0}, yu^(-1)]^2*
      G[{1}, yw]*G[{0, yu}, yv^(-1)] + 4*G[{0}, yu^(-1)]*G[{0}, yv^(-1)]*
      G[{1}, yw]*G[{0, yu}, yv^(-1)] + 2*G[{0}, yv^(-1)]^2*G[{1}, yw]*
      G[{0, yu}, yv^(-1)] - 4*G[{0}, yu^(-1)]*G[{0}, yw]*G[{1}, yw]*
      G[{0, yu}, yv^(-1)] - 4*G[{0}, yv^(-1)]*G[{0}, yw]*G[{1}, yw]*
      G[{0, yu}, yv^(-1)] + 2*G[{0}, yw]^2*G[{1}, yw]*G[{0, yu}, yv^(-1)] - 
     4*G[{0}, yu^(-1)]*G[{1}, yv^(-1)]*G[{1}, yw]*G[{0, yu}, yv^(-1)] - 
     4*G[{0}, yv^(-1)]*G[{1}, yv^(-1)]*G[{1}, yw]*G[{0, yu}, yv^(-1)] + 
     4*G[{0}, yw]*G[{1}, yv^(-1)]*G[{1}, yw]*G[{0, yu}, yv^(-1)] + 
     2*G[{0}, yu^(-1)]*G[{1}, yw]^2*G[{0, yu}, yv^(-1)] + 
     2*G[{0}, yv^(-1)]*G[{1}, yw]^2*G[{0, yu}, yv^(-1)] - 
     2*G[{0}, yw]*G[{1}, yw]^2*G[{0, yu}, yv^(-1)] + 
     4*G[{0}, yu^(-1)]*G[{0, 1}, yv^(-1)]*G[{0, yu}, yv^(-1)] + 
     4*G[{0}, yv^(-1)]*G[{0, 1}, yv^(-1)]*G[{0, yu}, yv^(-1)] - 
     4*G[{0}, yw]*G[{0, 1}, yv^(-1)]*G[{0, yu}, yv^(-1)] - 
     4*G[{1}, yv^(-1)]*G[{0, 1}, yv^(-1)]*G[{0, yu}, yv^(-1)] + 
     4*G[{1}, yw]*G[{0, 1}, yv^(-1)]*G[{0, yu}, yv^(-1)] + 
     4*G[{0}, yu^(-1)]*G[{0, 1}, yw]*G[{0, yu}, yv^(-1)] + 
     4*G[{0}, yv^(-1)]*G[{0, 1}, yw]*G[{0, yu}, yv^(-1)] - 
     4*G[{0}, yw]*G[{0, 1}, yw]*G[{0, yu}, yv^(-1)] - 
     4*G[{1}, yv^(-1)]*G[{0, 1}, yw]*G[{0, yu}, yv^(-1)] + 
     4*G[{1}, yw]*G[{0, 1}, yw]*G[{0, yu}, yv^(-1)] - 
     4*G[{yu}, yv^(-1)]*G[{0, 1}, yw]*G[{0, yu}, yv^(-1)] - 
     4*G[{0}, yu^(-1)]*G[{0, yu^(-1)}, yw]*G[{0, yu}, yv^(-1)] - 
     4*G[{0}, yv^(-1)]*G[{0, yu^(-1)}, yw]*G[{0, yu}, yv^(-1)] + 
     4*G[{0}, yw]*G[{0, yu^(-1)}, yw]*G[{0, yu}, yv^(-1)] + 
     8*G[{1}, yv^(-1)]*G[{0, yu^(-1)}, yw]*G[{0, yu}, yv^(-1)] - 
     4*G[{1}, yw]*G[{0, yu^(-1)}, yw]*G[{0, yu}, yv^(-1)] - 
     2*G[{0}, yu^(-1)]*G[{0, yu}, yv^(-1)]^2 - 2*G[{0}, yv^(-1)]*
      G[{0, yu}, yv^(-1)]^2 + 2*G[{0}, yw]*G[{0, yu}, yv^(-1)]^2 + 
     2*G[{1}, yv^(-1)]*G[{0, yu}, yv^(-1)]^2 - 
     2*G[{1}, yw]*G[{0, yu}, yv^(-1)]^2 - 
     (2*Pi^2*G[{0}, yu^(-1)]*G[{0, yv^(-1)}, yw])/3 + 
     (2*G[{0}, yu^(-1)]^3*G[{0, yv^(-1)}, yw])/3 - 
     (2*Pi^2*G[{0}, yv^(-1)]*G[{0, yv^(-1)}, yw])/3 + 
     2*G[{0}, yu^(-1)]^2*G[{0}, yv^(-1)]*G[{0, yv^(-1)}, yw] + 
     2*G[{0}, yu^(-1)]*G[{0}, yv^(-1)]^2*G[{0, yv^(-1)}, yw] + 
     (2*G[{0}, yv^(-1)]^3*G[{0, yv^(-1)}, yw])/3 + 
     (2*Pi^2*G[{0}, yw]*G[{0, yv^(-1)}, yw])/3 - 2*G[{0}, yu^(-1)]^2*
      G[{0}, yw]*G[{0, yv^(-1)}, yw] - 4*G[{0}, yu^(-1)]*G[{0}, yv^(-1)]*
      G[{0}, yw]*G[{0, yv^(-1)}, yw] - 2*G[{0}, yv^(-1)]^2*G[{0}, yw]*
      G[{0, yv^(-1)}, yw] + 2*G[{0}, yu^(-1)]*G[{0}, yw]^2*
      G[{0, yv^(-1)}, yw] + 2*G[{0}, yv^(-1)]*G[{0}, yw]^2*
      G[{0, yv^(-1)}, yw] - (2*G[{0}, yw]^3*G[{0, yv^(-1)}, yw])/3 + 
     2*Pi^2*G[{1}, yu^(-1)]*G[{0, yv^(-1)}, yw] - 2*G[{0}, yu^(-1)]^2*
      G[{1}, yu^(-1)]*G[{0, yv^(-1)}, yw] - 4*G[{0}, yu^(-1)]*G[{0}, yv^(-1)]*
      G[{1}, yu^(-1)]*G[{0, yv^(-1)}, yw] - 2*G[{0}, yv^(-1)]^2*
      G[{1}, yu^(-1)]*G[{0, yv^(-1)}, yw] + 4*G[{0}, yu^(-1)]*G[{0}, yw]*
      G[{1}, yu^(-1)]*G[{0, yv^(-1)}, yw] + 4*G[{0}, yv^(-1)]*G[{0}, yw]*
      G[{1}, yu^(-1)]*G[{0, yv^(-1)}, yw] - 2*G[{0}, yw]^2*G[{1}, yu^(-1)]*
      G[{0, yv^(-1)}, yw] + 2*G[{0}, yu^(-1)]*G[{1}, yu^(-1)]^2*
      G[{0, yv^(-1)}, yw] + 2*G[{0}, yv^(-1)]*G[{1}, yu^(-1)]^2*
      G[{0, yv^(-1)}, yw] - 2*G[{0}, yw]*G[{1}, yu^(-1)]^2*
      G[{0, yv^(-1)}, yw] - (4*G[{1}, yu^(-1)]^3*G[{0, yv^(-1)}, yw])/3 - 
     (2*Pi^2*G[{1}, yv^(-1)]*G[{0, yv^(-1)}, yw])/3 - 
     2*G[{0}, yu^(-1)]^2*G[{1}, yv^(-1)]*G[{0, yv^(-1)}, yw] - 
     4*G[{0}, yu^(-1)]*G[{0}, yv^(-1)]*G[{1}, yv^(-1)]*G[{0, yv^(-1)}, yw] - 
     2*G[{0}, yv^(-1)]^2*G[{1}, yv^(-1)]*G[{0, yv^(-1)}, yw] + 
     4*G[{0}, yu^(-1)]*G[{0}, yw]*G[{1}, yv^(-1)]*G[{0, yv^(-1)}, yw] + 
     4*G[{0}, yv^(-1)]*G[{0}, yw]*G[{1}, yv^(-1)]*G[{0, yv^(-1)}, yw] - 
     2*G[{0}, yw]^2*G[{1}, yv^(-1)]*G[{0, yv^(-1)}, yw] + 
     4*G[{0}, yu^(-1)]*G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*G[{0, yv^(-1)}, yw] + 
     4*G[{0}, yv^(-1)]*G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*G[{0, yv^(-1)}, yw] - 
     4*G[{0}, yw]*G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*G[{0, yv^(-1)}, yw] + 
     2*G[{0}, yu^(-1)]*G[{1}, yv^(-1)]^2*G[{0, yv^(-1)}, yw] + 
     2*G[{0}, yv^(-1)]*G[{1}, yv^(-1)]^2*G[{0, yv^(-1)}, yw] - 
     2*G[{0}, yw]*G[{1}, yv^(-1)]^2*G[{0, yv^(-1)}, yw] - 
     4*G[{1}, yu^(-1)]*G[{1}, yv^(-1)]^2*G[{0, yv^(-1)}, yw] - 
     (2*G[{1}, yv^(-1)]^3*G[{0, yv^(-1)}, yw])/3 + 
     (2*Pi^2*G[{1}, yw]*G[{0, yv^(-1)}, yw])/3 + 2*G[{0}, yu^(-1)]^2*
      G[{1}, yw]*G[{0, yv^(-1)}, yw] + 4*G[{0}, yu^(-1)]*G[{0}, yv^(-1)]*
      G[{1}, yw]*G[{0, yv^(-1)}, yw] + 2*G[{0}, yv^(-1)]^2*G[{1}, yw]*
      G[{0, yv^(-1)}, yw] - 4*G[{0}, yu^(-1)]*G[{0}, yw]*G[{1}, yw]*
      G[{0, yv^(-1)}, yw] - 4*G[{0}, yv^(-1)]*G[{0}, yw]*G[{1}, yw]*
      G[{0, yv^(-1)}, yw] + 2*G[{0}, yw]^2*G[{1}, yw]*G[{0, yv^(-1)}, yw] - 
     4*G[{0}, yu^(-1)]*G[{1}, yu^(-1)]*G[{1}, yw]*G[{0, yv^(-1)}, yw] - 
     4*G[{0}, yv^(-1)]*G[{1}, yu^(-1)]*G[{1}, yw]*G[{0, yv^(-1)}, yw] + 
     4*G[{0}, yw]*G[{1}, yu^(-1)]*G[{1}, yw]*G[{0, yv^(-1)}, yw] - 
     4*G[{0}, yu^(-1)]*G[{1}, yv^(-1)]*G[{1}, yw]*G[{0, yv^(-1)}, yw] - 
     4*G[{0}, yv^(-1)]*G[{1}, yv^(-1)]*G[{1}, yw]*G[{0, yv^(-1)}, yw] + 
     4*G[{0}, yw]*G[{1}, yv^(-1)]*G[{1}, yw]*G[{0, yv^(-1)}, yw] + 
     8*G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*G[{1}, yw]*G[{0, yv^(-1)}, yw] + 
     2*G[{1}, yv^(-1)]^2*G[{1}, yw]*G[{0, yv^(-1)}, yw] + 
     2*G[{0}, yu^(-1)]*G[{1}, yw]^2*G[{0, yv^(-1)}, yw] + 
     2*G[{0}, yv^(-1)]*G[{1}, yw]^2*G[{0, yv^(-1)}, yw] - 
     2*G[{0}, yw]*G[{1}, yw]^2*G[{0, yv^(-1)}, yw] - 
     4*G[{1}, yu^(-1)]*G[{1}, yw]^2*G[{0, yv^(-1)}, yw] + 
     4*G[{1}, yu^(-1)]*G[{0, 1}, yu^(-1)]*G[{0, yv^(-1)}, yw] - 
     4*G[{1}, yv^(-1)]*G[{0, 1}, yu^(-1)]*G[{0, yv^(-1)}, yw] + 
     4*G[{1}, yw]*G[{0, 1}, yu^(-1)]*G[{0, yv^(-1)}, yw] + 
     4*G[{1}, yw]*G[{0, 1}, yw]*G[{0, yv^(-1)}, yw] - 
     4*G[{1}, yw]*G[{0, yu^(-1)}, yw]*G[{0, yv^(-1)}, yw] - 
     2*G[{1}, yw]*G[{0, yv^(-1)}, yw]^2 + 
     (2*Pi^2*G[{0}, yu^(-1)]*G[{0, 1/(yu*yv)}, yw])/3 - 
     (2*G[{0}, yu^(-1)]^3*G[{0, 1/(yu*yv)}, yw])/3 + 
     (2*Pi^2*G[{0}, yv^(-1)]*G[{0, 1/(yu*yv)}, yw])/3 - 
     2*G[{0}, yu^(-1)]^2*G[{0}, yv^(-1)]*G[{0, 1/(yu*yv)}, yw] - 
     2*G[{0}, yu^(-1)]*G[{0}, yv^(-1)]^2*G[{0, 1/(yu*yv)}, yw] - 
     (2*G[{0}, yv^(-1)]^3*G[{0, 1/(yu*yv)}, yw])/3 - 
     (2*Pi^2*G[{0}, yw]*G[{0, 1/(yu*yv)}, yw])/3 + 
     2*G[{0}, yu^(-1)]^2*G[{0}, yw]*G[{0, 1/(yu*yv)}, yw] + 
     4*G[{0}, yu^(-1)]*G[{0}, yv^(-1)]*G[{0}, yw]*G[{0, 1/(yu*yv)}, yw] + 
     2*G[{0}, yv^(-1)]^2*G[{0}, yw]*G[{0, 1/(yu*yv)}, yw] - 
     2*G[{0}, yu^(-1)]*G[{0}, yw]^2*G[{0, 1/(yu*yv)}, yw] - 
     2*G[{0}, yv^(-1)]*G[{0}, yw]^2*G[{0, 1/(yu*yv)}, yw] + 
     (2*G[{0}, yw]^3*G[{0, 1/(yu*yv)}, yw])/3 - 2*Pi^2*G[{1}, yu^(-1)]*
      G[{0, 1/(yu*yv)}, yw] + 2*G[{0}, yu^(-1)]^2*G[{1}, yu^(-1)]*
      G[{0, 1/(yu*yv)}, yw] + 4*G[{0}, yu^(-1)]*G[{0}, yv^(-1)]*
      G[{1}, yu^(-1)]*G[{0, 1/(yu*yv)}, yw] + 2*G[{0}, yv^(-1)]^2*
      G[{1}, yu^(-1)]*G[{0, 1/(yu*yv)}, yw] - 4*G[{0}, yu^(-1)]*G[{0}, yw]*
      G[{1}, yu^(-1)]*G[{0, 1/(yu*yv)}, yw] - 4*G[{0}, yv^(-1)]*G[{0}, yw]*
      G[{1}, yu^(-1)]*G[{0, 1/(yu*yv)}, yw] + 2*G[{0}, yw]^2*G[{1}, yu^(-1)]*
      G[{0, 1/(yu*yv)}, yw] - 2*G[{0}, yu^(-1)]*G[{1}, yu^(-1)]^2*
      G[{0, 1/(yu*yv)}, yw] - 2*G[{0}, yv^(-1)]*G[{1}, yu^(-1)]^2*
      G[{0, 1/(yu*yv)}, yw] + 2*G[{0}, yw]*G[{1}, yu^(-1)]^2*
      G[{0, 1/(yu*yv)}, yw] + (4*G[{1}, yu^(-1)]^3*G[{0, 1/(yu*yv)}, yw])/3 - 
     (2*Pi^2*G[{1}, yv^(-1)]*G[{0, 1/(yu*yv)}, yw])/3 + 
     4*G[{0}, yu^(-1)]^2*G[{1}, yv^(-1)]*G[{0, 1/(yu*yv)}, yw] + 
     8*G[{0}, yu^(-1)]*G[{0}, yv^(-1)]*G[{1}, yv^(-1)]*
      G[{0, 1/(yu*yv)}, yw] + 4*G[{0}, yv^(-1)]^2*G[{1}, yv^(-1)]*
      G[{0, 1/(yu*yv)}, yw] - 8*G[{0}, yu^(-1)]*G[{0}, yw]*G[{1}, yv^(-1)]*
      G[{0, 1/(yu*yv)}, yw] - 8*G[{0}, yv^(-1)]*G[{0}, yw]*G[{1}, yv^(-1)]*
      G[{0, 1/(yu*yv)}, yw] + 4*G[{0}, yw]^2*G[{1}, yv^(-1)]*
      G[{0, 1/(yu*yv)}, yw] - 4*G[{0}, yu^(-1)]*G[{1}, yu^(-1)]*
      G[{1}, yv^(-1)]*G[{0, 1/(yu*yv)}, yw] - 4*G[{0}, yv^(-1)]*
      G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*G[{0, 1/(yu*yv)}, yw] + 
     4*G[{0}, yw]*G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*G[{0, 1/(yu*yv)}, yw] - 
     6*G[{0}, yu^(-1)]*G[{1}, yv^(-1)]^2*G[{0, 1/(yu*yv)}, yw] - 
     6*G[{0}, yv^(-1)]*G[{1}, yv^(-1)]^2*G[{0, 1/(yu*yv)}, yw] + 
     6*G[{0}, yw]*G[{1}, yv^(-1)]^2*G[{0, 1/(yu*yv)}, yw] + 
     4*G[{1}, yu^(-1)]*G[{1}, yv^(-1)]^2*G[{0, 1/(yu*yv)}, yw] + 
     (8*G[{1}, yv^(-1)]^3*G[{0, 1/(yu*yv)}, yw])/3 - 
     (2*Pi^2*G[{1}, yw]*G[{0, 1/(yu*yv)}, yw])/3 - 
     2*G[{0}, yu^(-1)]^2*G[{1}, yw]*G[{0, 1/(yu*yv)}, yw] - 
     4*G[{0}, yu^(-1)]*G[{0}, yv^(-1)]*G[{1}, yw]*G[{0, 1/(yu*yv)}, yw] - 
     2*G[{0}, yv^(-1)]^2*G[{1}, yw]*G[{0, 1/(yu*yv)}, yw] + 
     4*G[{0}, yu^(-1)]*G[{0}, yw]*G[{1}, yw]*G[{0, 1/(yu*yv)}, yw] + 
     4*G[{0}, yv^(-1)]*G[{0}, yw]*G[{1}, yw]*G[{0, 1/(yu*yv)}, yw] - 
     2*G[{0}, yw]^2*G[{1}, yw]*G[{0, 1/(yu*yv)}, yw] + 
     4*G[{0}, yu^(-1)]*G[{1}, yu^(-1)]*G[{1}, yw]*G[{0, 1/(yu*yv)}, yw] + 
     4*G[{0}, yv^(-1)]*G[{1}, yu^(-1)]*G[{1}, yw]*G[{0, 1/(yu*yv)}, yw] - 
     4*G[{0}, yw]*G[{1}, yu^(-1)]*G[{1}, yw]*G[{0, 1/(yu*yv)}, yw] + 
     8*G[{0}, yu^(-1)]*G[{1}, yv^(-1)]*G[{1}, yw]*G[{0, 1/(yu*yv)}, yw] + 
     8*G[{0}, yv^(-1)]*G[{1}, yv^(-1)]*G[{1}, yw]*G[{0, 1/(yu*yv)}, yw] - 
     8*G[{0}, yw]*G[{1}, yv^(-1)]*G[{1}, yw]*G[{0, 1/(yu*yv)}, yw] - 
     8*G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*G[{1}, yw]*G[{0, 1/(yu*yv)}, yw] - 
     6*G[{1}, yv^(-1)]^2*G[{1}, yw]*G[{0, 1/(yu*yv)}, yw] - 
     2*G[{0}, yu^(-1)]*G[{1}, yw]^2*G[{0, 1/(yu*yv)}, yw] - 
     2*G[{0}, yv^(-1)]*G[{1}, yw]^2*G[{0, 1/(yu*yv)}, yw] + 
     2*G[{0}, yw]*G[{1}, yw]^2*G[{0, 1/(yu*yv)}, yw] + 
     4*G[{1}, yu^(-1)]*G[{1}, yw]^2*G[{0, 1/(yu*yv)}, yw] + 
     4*G[{1}, yv^(-1)]*G[{1}, yw]^2*G[{0, 1/(yu*yv)}, yw] + 
     (4*Pi^2*G[{yu}, yv^(-1)]*G[{0, 1/(yu*yv)}, yw])/3 - 
     2*G[{0}, yu^(-1)]^2*G[{yu}, yv^(-1)]*G[{0, 1/(yu*yv)}, yw] - 
     4*G[{0}, yu^(-1)]*G[{0}, yv^(-1)]*G[{yu}, yv^(-1)]*
      G[{0, 1/(yu*yv)}, yw] - 2*G[{0}, yv^(-1)]^2*G[{yu}, yv^(-1)]*
      G[{0, 1/(yu*yv)}, yw] + 4*G[{0}, yu^(-1)]*G[{0}, yw]*G[{yu}, yv^(-1)]*
      G[{0, 1/(yu*yv)}, yw] + 4*G[{0}, yv^(-1)]*G[{0}, yw]*G[{yu}, yv^(-1)]*
      G[{0, 1/(yu*yv)}, yw] - 2*G[{0}, yw]^2*G[{yu}, yv^(-1)]*
      G[{0, 1/(yu*yv)}, yw] + 2*G[{1}, yv^(-1)]^2*G[{yu}, yv^(-1)]*
      G[{0, 1/(yu*yv)}, yw] - 4*G[{0}, yu^(-1)]*G[{1}, yw]*G[{yu}, yv^(-1)]*
      G[{0, 1/(yu*yv)}, yw] - 4*G[{0}, yv^(-1)]*G[{1}, yw]*G[{yu}, yv^(-1)]*
      G[{0, 1/(yu*yv)}, yw] + 4*G[{0}, yw]*G[{1}, yw]*G[{yu}, yv^(-1)]*
      G[{0, 1/(yu*yv)}, yw] - 4*G[{1}, yw]^2*G[{yu}, yv^(-1)]*
      G[{0, 1/(yu*yv)}, yw] + 4*G[{0}, yu^(-1)]*G[{yu}, yv^(-1)]^2*
      G[{0, 1/(yu*yv)}, yw] + 4*G[{0}, yv^(-1)]*G[{yu}, yv^(-1)]^2*
      G[{0, 1/(yu*yv)}, yw] - 4*G[{0}, yw]*G[{yu}, yv^(-1)]^2*
      G[{0, 1/(yu*yv)}, yw] + 4*G[{1}, yw]*G[{yu}, yv^(-1)]^2*
      G[{0, 1/(yu*yv)}, yw] - (8*G[{yu}, yv^(-1)]^3*G[{0, 1/(yu*yv)}, yw])/
      3 - 4*G[{1}, yu^(-1)]*G[{0, 1}, yu^(-1)]*G[{0, 1/(yu*yv)}, yw] + 
     4*G[{1}, yv^(-1)]*G[{0, 1}, yu^(-1)]*G[{0, 1/(yu*yv)}, yw] - 
     4*G[{1}, yw]*G[{0, 1}, yu^(-1)]*G[{0, 1/(yu*yv)}, yw] + 
     4*G[{1}, yv^(-1)]*G[{0, 1}, yv^(-1)]*G[{0, 1/(yu*yv)}, yw] - 
     4*G[{yu}, yv^(-1)]*G[{0, 1}, yv^(-1)]*G[{0, 1/(yu*yv)}, yw] - 
     4*G[{1}, yw]*G[{0, 1}, yw]*G[{0, 1/(yu*yv)}, yw] + 
     4*G[{1}, yw]*G[{0, yu^(-1)}, yw]*G[{0, 1/(yu*yv)}, yw] - 
     4*G[{1}, yv^(-1)]*G[{0, yu}, yv^(-1)]*G[{0, 1/(yu*yv)}, yw] + 
     4*G[{yu}, yv^(-1)]*G[{0, yu}, yv^(-1)]*G[{0, 1/(yu*yv)}, yw] + 
     4*G[{1}, yw]*G[{0, yv^(-1)}, yw]*G[{0, 1/(yu*yv)}, yw] - 
     2*G[{1}, yw]*G[{0, 1/(yu*yv)}, yw]^2 - 4*G[{0}, yu^(-1)]*G[{0, 1}, yw]*
      G[{1, yu}, yv^(-1)] - 4*G[{0}, yv^(-1)]*G[{0, 1}, yw]*
      G[{1, yu}, yv^(-1)] + 4*G[{0}, yw]*G[{0, 1}, yw]*G[{1, yu}, yv^(-1)] + 
     4*G[{1}, yv^(-1)]*G[{0, 1}, yw]*G[{1, yu}, yv^(-1)] - 
     4*G[{1}, yw]*G[{0, 1}, yw]*G[{1, yu}, yv^(-1)] + 
     4*G[{yu}, yv^(-1)]*G[{0, 1}, yw]*G[{1, yu}, yv^(-1)] + 
     4*G[{0}, yu^(-1)]*G[{0, yu^(-1)}, yw]*G[{1, yu}, yv^(-1)] + 
     4*G[{0}, yv^(-1)]*G[{0, yu^(-1)}, yw]*G[{1, yu}, yv^(-1)] - 
     4*G[{0}, yw]*G[{0, yu^(-1)}, yw]*G[{1, yu}, yv^(-1)] + 
     4*G[{1}, yw]*G[{0, yu^(-1)}, yw]*G[{1, yu}, yv^(-1)] - 
     4*G[{1}, yw]*G[{0, yv^(-1)}, yw]*G[{1, yu}, yv^(-1)] - 
     4*G[{1}, yv^(-1)]*G[{0, 1/(yu*yv)}, yw]*G[{1, yu}, yv^(-1)] + 
     4*G[{1}, yw]*G[{0, 1/(yu*yv)}, yw]*G[{1, yu}, yv^(-1)] - 
     4*G[{yu}, yv^(-1)]*G[{0, 1/(yu*yv)}, yw]*G[{1, yu}, yv^(-1)] + 
     (2*Pi^2*G[{0, 0, 1}, yu^(-1)])/3 + 2*G[{0}, yu^(-1)]^2*
      G[{0, 0, 1}, yu^(-1)] + 4*G[{0}, yu^(-1)]*G[{0}, yv^(-1)]*
      G[{0, 0, 1}, yu^(-1)] + 2*G[{0}, yv^(-1)]^2*G[{0, 0, 1}, yu^(-1)] - 
     4*G[{0}, yu^(-1)]*G[{0}, yw]*G[{0, 0, 1}, yu^(-1)] - 
     4*G[{0}, yv^(-1)]*G[{0}, yw]*G[{0, 0, 1}, yu^(-1)] + 
     2*G[{0}, yw]^2*G[{0, 0, 1}, yu^(-1)] - 4*G[{0}, yu^(-1)]*G[{1}, yv^(-1)]*
      G[{0, 0, 1}, yu^(-1)] - 4*G[{0}, yv^(-1)]*G[{1}, yv^(-1)]*
      G[{0, 0, 1}, yu^(-1)] + 4*G[{0}, yw]*G[{1}, yv^(-1)]*
      G[{0, 0, 1}, yu^(-1)] + 4*G[{0}, yu^(-1)]*G[{1}, yw]*
      G[{0, 0, 1}, yu^(-1)] + 4*G[{0}, yv^(-1)]*G[{1}, yw]*
      G[{0, 0, 1}, yu^(-1)] - 4*G[{0}, yw]*G[{1}, yw]*G[{0, 0, 1}, yu^(-1)] + 
     4*G[{0, 1}, yu^(-1)]*G[{0, 0, 1}, yu^(-1)] - 4*G[{0, yv^(-1)}, yw]*
      G[{0, 0, 1}, yu^(-1)] + 4*G[{0, 1/(yu*yv)}, yw]*G[{0, 0, 1}, yu^(-1)] + 
     (4*Pi^2*G[{0, 0, 1}, yw])/3 - 2*G[{0}, yu^(-1)]^2*G[{0, 0, 1}, yw] - 
     4*G[{0}, yu^(-1)]*G[{0}, yv^(-1)]*G[{0, 0, 1}, yw] - 
     2*G[{0}, yv^(-1)]^2*G[{0, 0, 1}, yw] + 4*G[{0}, yu^(-1)]*G[{0}, yw]*
      G[{0, 0, 1}, yw] + 4*G[{0}, yv^(-1)]*G[{0}, yw]*G[{0, 0, 1}, yw] - 
     2*G[{0}, yw]^2*G[{0, 0, 1}, yw] + 4*G[{0}, yu^(-1)]*G[{1}, yv^(-1)]*
      G[{0, 0, 1}, yw] + 4*G[{0}, yv^(-1)]*G[{1}, yv^(-1)]*G[{0, 0, 1}, yw] - 
     4*G[{0}, yw]*G[{1}, yv^(-1)]*G[{0, 0, 1}, yw] - 
     2*G[{1}, yv^(-1)]^2*G[{0, 0, 1}, yw] - 4*G[{0}, yu^(-1)]*G[{1}, yw]*
      G[{0, 0, 1}, yw] - 4*G[{0}, yv^(-1)]*G[{1}, yw]*G[{0, 0, 1}, yw] + 
     4*G[{0}, yw]*G[{1}, yw]*G[{0, 0, 1}, yw] + 8*G[{1}, yv^(-1)]*G[{1}, yw]*
      G[{0, 0, 1}, yw] - 4*G[{1}, yw]^2*G[{0, 0, 1}, yw] + 
     4*G[{0}, yu^(-1)]*G[{yu}, yv^(-1)]*G[{0, 0, 1}, yw] + 
     4*G[{0}, yv^(-1)]*G[{yu}, yv^(-1)]*G[{0, 0, 1}, yw] - 
     4*G[{0}, yw]*G[{yu}, yv^(-1)]*G[{0, 0, 1}, yw] - 
     4*G[{yu}, yv^(-1)]^2*G[{0, 0, 1}, yw] - 4*G[{0, 1}, yv^(-1)]*
      G[{0, 0, 1}, yw] + 4*G[{0, yu}, yv^(-1)]*G[{0, 0, 1}, yw] - 
     4*G[{0, yv^(-1)}, yw]*G[{0, 0, 1}, yw] + 4*G[{0, 1/(yu*yv)}, yw]*
      G[{0, 0, 1}, yw] - 4*G[{1, yu}, yv^(-1)]*G[{0, 0, 1}, yw] - 
     (4*Pi^2*G[{0, 0, yu^(-1)}, yw])/3 + 2*G[{0}, yu^(-1)]^2*
      G[{0, 0, yu^(-1)}, yw] + 4*G[{0}, yu^(-1)]*G[{0}, yv^(-1)]*
      G[{0, 0, yu^(-1)}, yw] + 2*G[{0}, yv^(-1)]^2*G[{0, 0, yu^(-1)}, yw] - 
     4*G[{0}, yu^(-1)]*G[{0}, yw]*G[{0, 0, yu^(-1)}, yw] - 
     4*G[{0}, yv^(-1)]*G[{0}, yw]*G[{0, 0, yu^(-1)}, yw] + 
     2*G[{0}, yw]^2*G[{0, 0, yu^(-1)}, yw] - 8*G[{0}, yu^(-1)]*
      G[{1}, yv^(-1)]*G[{0, 0, yu^(-1)}, yw] - 8*G[{0}, yv^(-1)]*
      G[{1}, yv^(-1)]*G[{0, 0, yu^(-1)}, yw] + 8*G[{0}, yw]*G[{1}, yv^(-1)]*
      G[{0, 0, yu^(-1)}, yw] + 6*G[{1}, yv^(-1)]^2*G[{0, 0, yu^(-1)}, yw] + 
     4*G[{0}, yu^(-1)]*G[{1}, yw]*G[{0, 0, yu^(-1)}, yw] + 
     4*G[{0}, yv^(-1)]*G[{1}, yw]*G[{0, 0, yu^(-1)}, yw] - 
     4*G[{0}, yw]*G[{1}, yw]*G[{0, 0, yu^(-1)}, yw] - 
     8*G[{1}, yv^(-1)]*G[{1}, yw]*G[{0, 0, yu^(-1)}, yw] + 
     4*G[{1}, yw]^2*G[{0, 0, yu^(-1)}, yw] + 4*G[{0, 1}, yv^(-1)]*
      G[{0, 0, yu^(-1)}, yw] - 4*G[{0, yu}, yv^(-1)]*G[{0, 0, yu^(-1)}, yw] + 
     4*G[{0, yv^(-1)}, yw]*G[{0, 0, yu^(-1)}, yw] - 
     4*G[{0, 1/(yu*yv)}, yw]*G[{0, 0, yu^(-1)}, yw] + 
     4*G[{1, yu}, yv^(-1)]*G[{0, 0, yu^(-1)}, yw] - 
     2*Pi^2*G[{0, 0, yv^(-1)}, yw] + 2*G[{0}, yu^(-1)]^2*
      G[{0, 0, yv^(-1)}, yw] + 4*G[{0}, yu^(-1)]*G[{0}, yv^(-1)]*
      G[{0, 0, yv^(-1)}, yw] + 2*G[{0}, yv^(-1)]^2*G[{0, 0, yv^(-1)}, yw] - 
     4*G[{0}, yu^(-1)]*G[{0}, yw]*G[{0, 0, yv^(-1)}, yw] - 
     4*G[{0}, yv^(-1)]*G[{0}, yw]*G[{0, 0, yv^(-1)}, yw] + 
     2*G[{0}, yw]^2*G[{0, 0, yv^(-1)}, yw] - 4*G[{0}, yu^(-1)]*
      G[{1}, yu^(-1)]*G[{0, 0, yv^(-1)}, yw] - 4*G[{0}, yv^(-1)]*
      G[{1}, yu^(-1)]*G[{0, 0, yv^(-1)}, yw] + 4*G[{0}, yw]*G[{1}, yu^(-1)]*
      G[{0, 0, yv^(-1)}, yw] + 4*G[{1}, yu^(-1)]^2*G[{0, 0, yv^(-1)}, yw] - 
     4*G[{0}, yu^(-1)]*G[{1}, yv^(-1)]*G[{0, 0, yv^(-1)}, yw] - 
     4*G[{0}, yv^(-1)]*G[{1}, yv^(-1)]*G[{0, 0, yv^(-1)}, yw] + 
     4*G[{0}, yw]*G[{1}, yv^(-1)]*G[{0, 0, yv^(-1)}, yw] + 
     2*G[{1}, yv^(-1)]^2*G[{0, 0, yv^(-1)}, yw] + 
     4*G[{0}, yu^(-1)]*G[{1}, yw]*G[{0, 0, yv^(-1)}, yw] + 
     4*G[{0}, yv^(-1)]*G[{1}, yw]*G[{0, 0, yv^(-1)}, yw] - 
     4*G[{0}, yw]*G[{1}, yw]*G[{0, 0, yv^(-1)}, yw] - 
     8*G[{1}, yv^(-1)]*G[{1}, yw]*G[{0, 0, yv^(-1)}, yw] + 
     4*G[{1}, yw]^2*G[{0, 0, yv^(-1)}, yw] - 4*G[{0, 1}, yu^(-1)]*
      G[{0, 0, yv^(-1)}, yw] + 4*G[{0, yv^(-1)}, yw]*G[{0, 0, yv^(-1)}, yw] - 
     4*G[{0, 1/(yu*yv)}, yw]*G[{0, 0, yv^(-1)}, yw] + 
     4*G[{1, yu}, yv^(-1)]*G[{0, 0, yv^(-1)}, yw] + 
     2*Pi^2*G[{0, 0, 1/(yu*yv)}, yw] - 2*G[{0}, yu^(-1)]^2*
      G[{0, 0, 1/(yu*yv)}, yw] - 4*G[{0}, yu^(-1)]*G[{0}, yv^(-1)]*
      G[{0, 0, 1/(yu*yv)}, yw] - 2*G[{0}, yv^(-1)]^2*
      G[{0, 0, 1/(yu*yv)}, yw] + 4*G[{0}, yu^(-1)]*G[{0}, yw]*
      G[{0, 0, 1/(yu*yv)}, yw] + 4*G[{0}, yv^(-1)]*G[{0}, yw]*
      G[{0, 0, 1/(yu*yv)}, yw] - 2*G[{0}, yw]^2*G[{0, 0, 1/(yu*yv)}, yw] + 
     4*G[{0}, yu^(-1)]*G[{1}, yu^(-1)]*G[{0, 0, 1/(yu*yv)}, yw] + 
     4*G[{0}, yv^(-1)]*G[{1}, yu^(-1)]*G[{0, 0, 1/(yu*yv)}, yw] - 
     4*G[{0}, yw]*G[{1}, yu^(-1)]*G[{0, 0, 1/(yu*yv)}, yw] - 
     4*G[{1}, yu^(-1)]^2*G[{0, 0, 1/(yu*yv)}, yw] + 
     8*G[{0}, yu^(-1)]*G[{1}, yv^(-1)]*G[{0, 0, 1/(yu*yv)}, yw] + 
     8*G[{0}, yv^(-1)]*G[{1}, yv^(-1)]*G[{0, 0, 1/(yu*yv)}, yw] - 
     8*G[{0}, yw]*G[{1}, yv^(-1)]*G[{0, 0, 1/(yu*yv)}, yw] - 
     6*G[{1}, yv^(-1)]^2*G[{0, 0, 1/(yu*yv)}, yw] - 
     4*G[{0}, yu^(-1)]*G[{1}, yw]*G[{0, 0, 1/(yu*yv)}, yw] - 
     4*G[{0}, yv^(-1)]*G[{1}, yw]*G[{0, 0, 1/(yu*yv)}, yw] + 
     4*G[{0}, yw]*G[{1}, yw]*G[{0, 0, 1/(yu*yv)}, yw] + 
     8*G[{1}, yv^(-1)]*G[{1}, yw]*G[{0, 0, 1/(yu*yv)}, yw] - 
     4*G[{1}, yw]^2*G[{0, 0, 1/(yu*yv)}, yw] - 4*G[{0}, yu^(-1)]*
      G[{yu}, yv^(-1)]*G[{0, 0, 1/(yu*yv)}, yw] - 
     4*G[{0}, yv^(-1)]*G[{yu}, yv^(-1)]*G[{0, 0, 1/(yu*yv)}, yw] + 
     4*G[{0}, yw]*G[{yu}, yv^(-1)]*G[{0, 0, 1/(yu*yv)}, yw] + 
     4*G[{yu}, yv^(-1)]^2*G[{0, 0, 1/(yu*yv)}, yw] + 
     4*G[{0, 1}, yu^(-1)]*G[{0, 0, 1/(yu*yv)}, yw] - 
     4*G[{0, yv^(-1)}, yw]*G[{0, 0, 1/(yu*yv)}, yw] + 
     4*G[{0, 1/(yu*yv)}, yw]*G[{0, 0, 1/(yu*yv)}, yw] - 
     4*G[{1, yu}, yv^(-1)]*G[{0, 0, 1/(yu*yv)}, yw] - 
     2*Pi^2*G[{0, 1, 1}, yu^(-1)] + 2*G[{0}, yu^(-1)]^2*
      G[{0, 1, 1}, yu^(-1)] + 4*G[{0}, yu^(-1)]*G[{0}, yv^(-1)]*
      G[{0, 1, 1}, yu^(-1)] + 2*G[{0}, yv^(-1)]^2*G[{0, 1, 1}, yu^(-1)] - 
     4*G[{0}, yu^(-1)]*G[{0}, yw]*G[{0, 1, 1}, yu^(-1)] - 
     4*G[{0}, yv^(-1)]*G[{0}, yw]*G[{0, 1, 1}, yu^(-1)] + 
     2*G[{0}, yw]^2*G[{0, 1, 1}, yu^(-1)] - 4*G[{0}, yu^(-1)]*G[{1}, yv^(-1)]*
      G[{0, 1, 1}, yu^(-1)] - 4*G[{0}, yv^(-1)]*G[{1}, yv^(-1)]*
      G[{0, 1, 1}, yu^(-1)] + 4*G[{0}, yw]*G[{1}, yv^(-1)]*
      G[{0, 1, 1}, yu^(-1)] + 4*G[{1}, yv^(-1)]^2*G[{0, 1, 1}, yu^(-1)] + 
     4*G[{0}, yu^(-1)]*G[{1}, yw]*G[{0, 1, 1}, yu^(-1)] + 
     4*G[{0}, yv^(-1)]*G[{1}, yw]*G[{0, 1, 1}, yu^(-1)] - 
     4*G[{0}, yw]*G[{1}, yw]*G[{0, 1, 1}, yu^(-1)] - 
     8*G[{1}, yv^(-1)]*G[{1}, yw]*G[{0, 1, 1}, yu^(-1)] + 
     4*G[{1}, yw]^2*G[{0, 1, 1}, yu^(-1)] - 4*G[{0, 1}, yu^(-1)]*
      G[{0, 1, 1}, yu^(-1)] - 4*G[{0, yv^(-1)}, yw]*G[{0, 1, 1}, yu^(-1)] + 
     4*G[{0, 1/(yu*yv)}, yw]*G[{0, 1, 1}, yu^(-1)] - 
     (8*Pi^2*G[{0, 1, 1}, yv^(-1)])/3 + 4*G[{1}, yv^(-1)]^2*
      G[{0, 1, 1}, yv^(-1)] - 8*G[{1}, yv^(-1)]*G[{1}, yw]*
      G[{0, 1, 1}, yv^(-1)] + 4*G[{1}, yw]^2*G[{0, 1, 1}, yv^(-1)] + 
     8*G[{0, yu^(-1)}, yw]*G[{0, 1, 1}, yv^(-1)] - 8*G[{0, yu}, yv^(-1)]*
      G[{0, 1, 1}, yv^(-1)] - 8*G[{0, 1/(yu*yv)}, yw]*G[{0, 1, 1}, yv^(-1)] + 
     (8*Pi^2*G[{0, 1, 1}, yw])/3 + 4*G[{1}, yv^(-1)]*G[{1}, yw]*
      G[{0, 1, 1}, yw] - 4*G[{1}, yw]^2*G[{0, 1, 1}, yw] - 
     4*G[{1}, yw]*G[{yu}, yv^(-1)]*G[{0, 1, 1}, yw] - 
     4*G[{0, yv^(-1)}, yw]*G[{0, 1, 1}, yw] + 4*G[{0, 1/(yu*yv)}, yw]*
      G[{0, 1, 1}, yw] - (4*Pi^2*G[{0, 1, yu^(-1)}, yw])/3 - 
     2*G[{0}, yu^(-1)]^2*G[{0, 1, yu^(-1)}, yw] - 
     4*G[{0}, yu^(-1)]*G[{0}, yv^(-1)]*G[{0, 1, yu^(-1)}, yw] - 
     2*G[{0}, yv^(-1)]^2*G[{0, 1, yu^(-1)}, yw] + 
     4*G[{0}, yu^(-1)]*G[{0}, yw]*G[{0, 1, yu^(-1)}, yw] + 
     4*G[{0}, yv^(-1)]*G[{0}, yw]*G[{0, 1, yu^(-1)}, yw] - 
     2*G[{0}, yw]^2*G[{0, 1, yu^(-1)}, yw] + 8*G[{0}, yu^(-1)]*
      G[{1}, yv^(-1)]*G[{0, 1, yu^(-1)}, yw] + 8*G[{0}, yv^(-1)]*
      G[{1}, yv^(-1)]*G[{0, 1, yu^(-1)}, yw] - 8*G[{0}, yw]*G[{1}, yv^(-1)]*
      G[{0, 1, yu^(-1)}, yw] - 6*G[{1}, yv^(-1)]^2*G[{0, 1, yu^(-1)}, yw] - 
     4*G[{0}, yu^(-1)]*G[{1}, yw]*G[{0, 1, yu^(-1)}, yw] - 
     4*G[{0}, yv^(-1)]*G[{1}, yw]*G[{0, 1, yu^(-1)}, yw] + 
     4*G[{0}, yw]*G[{1}, yw]*G[{0, 1, yu^(-1)}, yw] + 
     8*G[{1}, yv^(-1)]*G[{1}, yw]*G[{0, 1, yu^(-1)}, yw] - 
     4*G[{0, 1}, yv^(-1)]*G[{0, 1, yu^(-1)}, yw] + 4*G[{0, yu}, yv^(-1)]*
      G[{0, 1, yu^(-1)}, yw] - 4*G[{1, yu}, yv^(-1)]*G[{0, 1, yu^(-1)}, yw] + 
     (4*Pi^2*G[{0, 1, yu}, yv^(-1)])/3 + 2*G[{0}, yu^(-1)]^2*
      G[{0, 1, yu}, yv^(-1)] + 4*G[{0}, yu^(-1)]*G[{0}, yv^(-1)]*
      G[{0, 1, yu}, yv^(-1)] + 2*G[{0}, yv^(-1)]^2*G[{0, 1, yu}, yv^(-1)] - 
     4*G[{0}, yu^(-1)]*G[{0}, yw]*G[{0, 1, yu}, yv^(-1)] - 
     4*G[{0}, yv^(-1)]*G[{0}, yw]*G[{0, 1, yu}, yv^(-1)] + 
     2*G[{0}, yw]^2*G[{0, 1, yu}, yv^(-1)] - 4*G[{0}, yu^(-1)]*
      G[{1}, yv^(-1)]*G[{0, 1, yu}, yv^(-1)] - 4*G[{0}, yv^(-1)]*
      G[{1}, yv^(-1)]*G[{0, 1, yu}, yv^(-1)] + 4*G[{0}, yw]*G[{1}, yv^(-1)]*
      G[{0, 1, yu}, yv^(-1)] + 4*G[{0}, yu^(-1)]*G[{1}, yw]*
      G[{0, 1, yu}, yv^(-1)] + 4*G[{0}, yv^(-1)]*G[{1}, yw]*
      G[{0, 1, yu}, yv^(-1)] - 4*G[{0}, yw]*G[{1}, yw]*
      G[{0, 1, yu}, yv^(-1)] + 4*G[{0, 1}, yv^(-1)]*G[{0, 1, yu}, yv^(-1)] - 
     8*G[{0, yu^(-1)}, yw]*G[{0, 1, yu}, yv^(-1)] + 
     8*G[{0, yu}, yv^(-1)]*G[{0, 1, yu}, yv^(-1)] + 
     8*G[{0, 1/(yu*yv)}, yw]*G[{0, 1, yu}, yv^(-1)] - 
     4*G[{0, yu^(-1)}, yw]*G[{0, 1, yv^(-1)}, yw] - 
     4*G[{0}, yu^(-1)]*G[{1}, yv^(-1)]*G[{0, 1, 1/(yu*yv)}, yw] - 
     4*G[{0}, yv^(-1)]*G[{1}, yv^(-1)]*G[{0, 1, 1/(yu*yv)}, yw] + 
     4*G[{0}, yw]*G[{1}, yv^(-1)]*G[{0, 1, 1/(yu*yv)}, yw] + 
     4*G[{1}, yv^(-1)]^2*G[{0, 1, 1/(yu*yv)}, yw] - 
     4*G[{1}, yv^(-1)]*G[{1}, yw]*G[{0, 1, 1/(yu*yv)}, yw] + 
     4*G[{0}, yu^(-1)]*G[{yu}, yv^(-1)]*G[{0, 1, 1/(yu*yv)}, yw] + 
     4*G[{0}, yv^(-1)]*G[{yu}, yv^(-1)]*G[{0, 1, 1/(yu*yv)}, yw] - 
     4*G[{0}, yw]*G[{yu}, yv^(-1)]*G[{0, 1, 1/(yu*yv)}, yw] + 
     4*G[{1}, yw]*G[{yu}, yv^(-1)]*G[{0, 1, 1/(yu*yv)}, yw] - 
     4*G[{yu}, yv^(-1)]^2*G[{0, 1, 1/(yu*yv)}, yw] + 
     4*G[{0, yu^(-1)}, yw]*G[{0, 1, 1/(yu*yv)}, yw] + 
     4*G[{0, 1/(yu*yv)}, yw]*G[{0, 1, 1/(yu*yv)}, yw] - 
     (4*Pi^2*G[{0, yu^(-1), 1}, yw])/3 - 2*G[{0}, yu^(-1)]^2*
      G[{0, yu^(-1), 1}, yw] - 4*G[{0}, yu^(-1)]*G[{0}, yv^(-1)]*
      G[{0, yu^(-1), 1}, yw] - 2*G[{0}, yv^(-1)]^2*G[{0, yu^(-1), 1}, yw] + 
     4*G[{0}, yu^(-1)]*G[{0}, yw]*G[{0, yu^(-1), 1}, yw] + 
     4*G[{0}, yv^(-1)]*G[{0}, yw]*G[{0, yu^(-1), 1}, yw] - 
     2*G[{0}, yw]^2*G[{0, yu^(-1), 1}, yw] + 4*G[{0}, yu^(-1)]*
      G[{1}, yv^(-1)]*G[{0, yu^(-1), 1}, yw] + 4*G[{0}, yv^(-1)]*
      G[{1}, yv^(-1)]*G[{0, yu^(-1), 1}, yw] - 4*G[{0}, yw]*G[{1}, yv^(-1)]*
      G[{0, yu^(-1), 1}, yw] - 2*G[{1}, yv^(-1)]^2*G[{0, yu^(-1), 1}, yw] - 
     4*G[{0}, yu^(-1)]*G[{1}, yw]*G[{0, yu^(-1), 1}, yw] - 
     4*G[{0}, yv^(-1)]*G[{1}, yw]*G[{0, yu^(-1), 1}, yw] + 
     4*G[{0}, yw]*G[{1}, yw]*G[{0, yu^(-1), 1}, yw] + 
     4*G[{1}, yv^(-1)]*G[{1}, yw]*G[{0, yu^(-1), 1}, yw] + 
     4*G[{0}, yu^(-1)]*G[{yu}, yv^(-1)]*G[{0, yu^(-1), 1}, yw] + 
     4*G[{0}, yv^(-1)]*G[{yu}, yv^(-1)]*G[{0, yu^(-1), 1}, yw] - 
     4*G[{0}, yw]*G[{yu}, yv^(-1)]*G[{0, yu^(-1), 1}, yw] + 
     4*G[{1}, yw]*G[{yu}, yv^(-1)]*G[{0, yu^(-1), 1}, yw] - 
     4*G[{yu}, yv^(-1)]^2*G[{0, yu^(-1), 1}, yw] - 4*G[{0, 1}, yv^(-1)]*
      G[{0, yu^(-1), 1}, yw] + 4*G[{0, yu}, yv^(-1)]*G[{0, yu^(-1), 1}, yw] + 
     4*G[{0, yv^(-1)}, yw]*G[{0, yu^(-1), 1}, yw] - 
     4*G[{0, 1/(yu*yv)}, yw]*G[{0, yu^(-1), 1}, yw] - 
     4*G[{1, yu}, yv^(-1)]*G[{0, yu^(-1), 1}, yw] + 
     4*G[{0}, yu^(-1)]^2*G[{0, yu^(-1), yu^(-1)}, yw] + 
     8*G[{0}, yu^(-1)]*G[{0}, yv^(-1)]*G[{0, yu^(-1), yu^(-1)}, yw] + 
     4*G[{0}, yv^(-1)]^2*G[{0, yu^(-1), yu^(-1)}, yw] - 
     8*G[{0}, yu^(-1)]*G[{0}, yw]*G[{0, yu^(-1), yu^(-1)}, yw] - 
     8*G[{0}, yv^(-1)]*G[{0}, yw]*G[{0, yu^(-1), yu^(-1)}, yw] + 
     4*G[{0}, yw]^2*G[{0, yu^(-1), yu^(-1)}, yw] - 
     16*G[{0}, yu^(-1)]*G[{1}, yv^(-1)]*G[{0, yu^(-1), yu^(-1)}, yw] - 
     16*G[{0}, yv^(-1)]*G[{1}, yv^(-1)]*G[{0, yu^(-1), yu^(-1)}, yw] + 
     16*G[{0}, yw]*G[{1}, yv^(-1)]*G[{0, yu^(-1), yu^(-1)}, yw] + 
     12*G[{1}, yv^(-1)]^2*G[{0, yu^(-1), yu^(-1)}, yw] + 
     8*G[{0}, yu^(-1)]*G[{1}, yw]*G[{0, yu^(-1), yu^(-1)}, yw] + 
     8*G[{0}, yv^(-1)]*G[{1}, yw]*G[{0, yu^(-1), yu^(-1)}, yw] - 
     8*G[{0}, yw]*G[{1}, yw]*G[{0, yu^(-1), yu^(-1)}, yw] - 
     16*G[{1}, yv^(-1)]*G[{1}, yw]*G[{0, yu^(-1), yu^(-1)}, yw] + 
     4*G[{1}, yw]^2*G[{0, yu^(-1), yu^(-1)}, yw] + 8*G[{0, 1}, yv^(-1)]*
      G[{0, yu^(-1), yu^(-1)}, yw] - 8*G[{0, yu}, yv^(-1)]*
      G[{0, yu^(-1), yu^(-1)}, yw] + 8*G[{1, yu}, yv^(-1)]*
      G[{0, yu^(-1), yu^(-1)}, yw] + 4*G[{0}, yu^(-1)]*G[{1}, yv^(-1)]*
      G[{0, yu^(-1), 1/(yu*yv)}, yw] + 4*G[{0}, yv^(-1)]*G[{1}, yv^(-1)]*
      G[{0, yu^(-1), 1/(yu*yv)}, yw] - 4*G[{0}, yw]*G[{1}, yv^(-1)]*
      G[{0, yu^(-1), 1/(yu*yv)}, yw] - 4*G[{1}, yv^(-1)]^2*
      G[{0, yu^(-1), 1/(yu*yv)}, yw] + 4*G[{1}, yv^(-1)]*G[{1}, yw]*
      G[{0, yu^(-1), 1/(yu*yv)}, yw] - 4*G[{0}, yu^(-1)]*G[{yu}, yv^(-1)]*
      G[{0, yu^(-1), 1/(yu*yv)}, yw] - 4*G[{0}, yv^(-1)]*G[{yu}, yv^(-1)]*
      G[{0, yu^(-1), 1/(yu*yv)}, yw] + 4*G[{0}, yw]*G[{yu}, yv^(-1)]*
      G[{0, yu^(-1), 1/(yu*yv)}, yw] - 4*G[{1}, yw]*G[{yu}, yv^(-1)]*
      G[{0, yu^(-1), 1/(yu*yv)}, yw] + 4*G[{yu}, yv^(-1)]^2*
      G[{0, yu^(-1), 1/(yu*yv)}, yw] + 4*G[{0, yv^(-1)}, yw]*
      G[{0, yu^(-1), 1/(yu*yv)}, yw] - 4*G[{0, 1/(yu*yv)}, yw]*
      G[{0, yu^(-1), 1/(yu*yv)}, yw] + (4*Pi^2*G[{0, yu, 1}, yv^(-1)])/3 + 
     2*G[{0}, yu^(-1)]^2*G[{0, yu, 1}, yv^(-1)] + 
     4*G[{0}, yu^(-1)]*G[{0}, yv^(-1)]*G[{0, yu, 1}, yv^(-1)] + 
     2*G[{0}, yv^(-1)]^2*G[{0, yu, 1}, yv^(-1)] - 
     4*G[{0}, yu^(-1)]*G[{0}, yw]*G[{0, yu, 1}, yv^(-1)] - 
     4*G[{0}, yv^(-1)]*G[{0}, yw]*G[{0, yu, 1}, yv^(-1)] + 
     2*G[{0}, yw]^2*G[{0, yu, 1}, yv^(-1)] - 4*G[{0}, yu^(-1)]*
      G[{1}, yv^(-1)]*G[{0, yu, 1}, yv^(-1)] - 4*G[{0}, yv^(-1)]*
      G[{1}, yv^(-1)]*G[{0, yu, 1}, yv^(-1)] + 4*G[{0}, yw]*G[{1}, yv^(-1)]*
      G[{0, yu, 1}, yv^(-1)] + 4*G[{0}, yu^(-1)]*G[{1}, yw]*
      G[{0, yu, 1}, yv^(-1)] + 4*G[{0}, yv^(-1)]*G[{1}, yw]*
      G[{0, yu, 1}, yv^(-1)] - 4*G[{0}, yw]*G[{1}, yw]*
      G[{0, yu, 1}, yv^(-1)] + 4*G[{0, 1}, yv^(-1)]*G[{0, yu, 1}, yv^(-1)] - 
     8*G[{0, yu^(-1)}, yw]*G[{0, yu, 1}, yv^(-1)] - 
     4*G[{0, yu}, yv^(-1)]*G[{0, yu, 1}, yv^(-1)] + 
     8*G[{0, 1/(yu*yv)}, yw]*G[{0, yu, 1}, yv^(-1)] - 
     4*G[{0}, yu^(-1)]^2*G[{0, yu, yu}, yv^(-1)] - 
     8*G[{0}, yu^(-1)]*G[{0}, yv^(-1)]*G[{0, yu, yu}, yv^(-1)] - 
     4*G[{0}, yv^(-1)]^2*G[{0, yu, yu}, yv^(-1)] + 
     8*G[{0}, yu^(-1)]*G[{0}, yw]*G[{0, yu, yu}, yv^(-1)] + 
     8*G[{0}, yv^(-1)]*G[{0}, yw]*G[{0, yu, yu}, yv^(-1)] - 
     4*G[{0}, yw]^2*G[{0, yu, yu}, yv^(-1)] + 8*G[{0}, yu^(-1)]*
      G[{1}, yv^(-1)]*G[{0, yu, yu}, yv^(-1)] + 8*G[{0}, yv^(-1)]*
      G[{1}, yv^(-1)]*G[{0, yu, yu}, yv^(-1)] - 8*G[{0}, yw]*G[{1}, yv^(-1)]*
      G[{0, yu, yu}, yv^(-1)] - 4*G[{1}, yv^(-1)]^2*G[{0, yu, yu}, yv^(-1)] - 
     8*G[{0}, yu^(-1)]*G[{1}, yw]*G[{0, yu, yu}, yv^(-1)] - 
     8*G[{0}, yv^(-1)]*G[{1}, yw]*G[{0, yu, yu}, yv^(-1)] + 
     8*G[{0}, yw]*G[{1}, yw]*G[{0, yu, yu}, yv^(-1)] + 
     8*G[{1}, yv^(-1)]*G[{1}, yw]*G[{0, yu, yu}, yv^(-1)] - 
     4*G[{1}, yw]^2*G[{0, yu, yu}, yv^(-1)] - 8*G[{0, 1}, yv^(-1)]*
      G[{0, yu, yu}, yv^(-1)] + 8*G[{0, yu^(-1)}, yw]*
      G[{0, yu, yu}, yv^(-1)] + 8*G[{0, yu}, yv^(-1)]*
      G[{0, yu, yu}, yv^(-1)] - 8*G[{0, 1/(yu*yv)}, yw]*
      G[{0, yu, yu}, yv^(-1)] - 4*G[{1}, yv^(-1)]*G[{1}, yw]*
      G[{0, yv^(-1), 1}, yw] + 4*G[{1}, yw]*G[{yu}, yv^(-1)]*
      G[{0, yv^(-1), 1}, yw] - 4*G[{0, 1/(yu*yv)}, yw]*
      G[{0, yv^(-1), 1}, yw] - (8*Pi^2*G[{0, yv^(-1), yv^(-1)}, yw])/3 + 
     4*G[{1}, yw]^2*G[{0, yv^(-1), yv^(-1)}, yw] + 
     (2*Pi^2*G[{0, yv^(-1), 1/(yu*yv)}, yw])/3 + 2*G[{0}, yu^(-1)]^2*
      G[{0, yv^(-1), 1/(yu*yv)}, yw] + 4*G[{0}, yu^(-1)]*G[{0}, yv^(-1)]*
      G[{0, yv^(-1), 1/(yu*yv)}, yw] + 2*G[{0}, yv^(-1)]^2*
      G[{0, yv^(-1), 1/(yu*yv)}, yw] - 4*G[{0}, yu^(-1)]*G[{0}, yw]*
      G[{0, yv^(-1), 1/(yu*yv)}, yw] - 4*G[{0}, yv^(-1)]*G[{0}, yw]*
      G[{0, yv^(-1), 1/(yu*yv)}, yw] + 2*G[{0}, yw]^2*
      G[{0, yv^(-1), 1/(yu*yv)}, yw] - 4*G[{0}, yu^(-1)]*G[{1}, yu^(-1)]*
      G[{0, yv^(-1), 1/(yu*yv)}, yw] - 4*G[{0}, yv^(-1)]*G[{1}, yu^(-1)]*
      G[{0, yv^(-1), 1/(yu*yv)}, yw] + 4*G[{0}, yw]*G[{1}, yu^(-1)]*
      G[{0, yv^(-1), 1/(yu*yv)}, yw] + 4*G[{1}, yu^(-1)]^2*
      G[{0, yv^(-1), 1/(yu*yv)}, yw] - 4*G[{0}, yu^(-1)]*G[{1}, yv^(-1)]*
      G[{0, yv^(-1), 1/(yu*yv)}, yw] - 4*G[{0}, yv^(-1)]*G[{1}, yv^(-1)]*
      G[{0, yv^(-1), 1/(yu*yv)}, yw] + 4*G[{0}, yw]*G[{1}, yv^(-1)]*
      G[{0, yv^(-1), 1/(yu*yv)}, yw] + 2*G[{1}, yv^(-1)]^2*
      G[{0, yv^(-1), 1/(yu*yv)}, yw] + 4*G[{0}, yu^(-1)]*G[{1}, yw]*
      G[{0, yv^(-1), 1/(yu*yv)}, yw] + 4*G[{0}, yv^(-1)]*G[{1}, yw]*
      G[{0, yv^(-1), 1/(yu*yv)}, yw] - 4*G[{0}, yw]*G[{1}, yw]*
      G[{0, yv^(-1), 1/(yu*yv)}, yw] - 4*G[{1}, yv^(-1)]*G[{1}, yw]*
      G[{0, yv^(-1), 1/(yu*yv)}, yw] - 4*G[{1}, yw]*G[{yu}, yv^(-1)]*
      G[{0, yv^(-1), 1/(yu*yv)}, yw] - 4*G[{0, 1}, yu^(-1)]*
      G[{0, yv^(-1), 1/(yu*yv)}, yw] + 4*G[{0, 1}, yw]*
      G[{0, yv^(-1), 1/(yu*yv)}, yw] - 4*G[{0, yu^(-1)}, yw]*
      G[{0, yv^(-1), 1/(yu*yv)}, yw] - 4*G[{0, yv^(-1)}, yw]*
      G[{0, yv^(-1), 1/(yu*yv)}, yw] - 4*G[{0, 1/(yu*yv)}, yw]*
      G[{0, yv^(-1), 1/(yu*yv)}, yw] + 4*G[{1, yu}, yv^(-1)]*
      G[{0, yv^(-1), 1/(yu*yv)}, yw] - (4*Pi^2*G[{0, 1/(yu*yv), 1}, yw])/3 + 
     2*G[{0}, yu^(-1)]^2*G[{0, 1/(yu*yv), 1}, yw] + 
     4*G[{0}, yu^(-1)]*G[{0}, yv^(-1)]*G[{0, 1/(yu*yv), 1}, yw] + 
     2*G[{0}, yv^(-1)]^2*G[{0, 1/(yu*yv), 1}, yw] - 
     4*G[{0}, yu^(-1)]*G[{0}, yw]*G[{0, 1/(yu*yv), 1}, yw] - 
     4*G[{0}, yv^(-1)]*G[{0}, yw]*G[{0, 1/(yu*yv), 1}, yw] + 
     2*G[{0}, yw]^2*G[{0, 1/(yu*yv), 1}, yw] - 4*G[{0}, yu^(-1)]*
      G[{1}, yv^(-1)]*G[{0, 1/(yu*yv), 1}, yw] - 4*G[{0}, yv^(-1)]*
      G[{1}, yv^(-1)]*G[{0, 1/(yu*yv), 1}, yw] + 4*G[{0}, yw]*G[{1}, yv^(-1)]*
      G[{0, 1/(yu*yv), 1}, yw] + 2*G[{1}, yv^(-1)]^2*
      G[{0, 1/(yu*yv), 1}, yw] + 4*G[{0}, yu^(-1)]*G[{1}, yw]*
      G[{0, 1/(yu*yv), 1}, yw] + 4*G[{0}, yv^(-1)]*G[{1}, yw]*
      G[{0, 1/(yu*yv), 1}, yw] - 4*G[{0}, yw]*G[{1}, yw]*
      G[{0, 1/(yu*yv), 1}, yw] - 4*G[{1}, yv^(-1)]*G[{1}, yw]*
      G[{0, 1/(yu*yv), 1}, yw] + 4*G[{1}, yw]^2*G[{0, 1/(yu*yv), 1}, yw] - 
     4*G[{0}, yu^(-1)]*G[{yu}, yv^(-1)]*G[{0, 1/(yu*yv), 1}, yw] - 
     4*G[{0}, yv^(-1)]*G[{yu}, yv^(-1)]*G[{0, 1/(yu*yv), 1}, yw] + 
     4*G[{0}, yw]*G[{yu}, yv^(-1)]*G[{0, 1/(yu*yv), 1}, yw] - 
     4*G[{1}, yw]*G[{yu}, yv^(-1)]*G[{0, 1/(yu*yv), 1}, yw] + 
     4*G[{yu}, yv^(-1)]^2*G[{0, 1/(yu*yv), 1}, yw] + 
     4*G[{0, 1}, yv^(-1)]*G[{0, 1/(yu*yv), 1}, yw] - 
     4*G[{0, yu}, yv^(-1)]*G[{0, 1/(yu*yv), 1}, yw] + 
     4*G[{1, yu}, yv^(-1)]*G[{0, 1/(yu*yv), 1}, yw] + 
     (4*Pi^2*G[{0, 1/(yu*yv), yu^(-1)}, yw])/3 - 2*G[{0}, yu^(-1)]^2*
      G[{0, 1/(yu*yv), yu^(-1)}, yw] - 4*G[{0}, yu^(-1)]*G[{0}, yv^(-1)]*
      G[{0, 1/(yu*yv), yu^(-1)}, yw] - 2*G[{0}, yv^(-1)]^2*
      G[{0, 1/(yu*yv), yu^(-1)}, yw] + 4*G[{0}, yu^(-1)]*G[{0}, yw]*
      G[{0, 1/(yu*yv), yu^(-1)}, yw] + 4*G[{0}, yv^(-1)]*G[{0}, yw]*
      G[{0, 1/(yu*yv), yu^(-1)}, yw] - 2*G[{0}, yw]^2*
      G[{0, 1/(yu*yv), yu^(-1)}, yw] + 8*G[{0}, yu^(-1)]*G[{1}, yv^(-1)]*
      G[{0, 1/(yu*yv), yu^(-1)}, yw] + 8*G[{0}, yv^(-1)]*G[{1}, yv^(-1)]*
      G[{0, 1/(yu*yv), yu^(-1)}, yw] - 8*G[{0}, yw]*G[{1}, yv^(-1)]*
      G[{0, 1/(yu*yv), yu^(-1)}, yw] - 6*G[{1}, yv^(-1)]^2*
      G[{0, 1/(yu*yv), yu^(-1)}, yw] - 4*G[{0}, yu^(-1)]*G[{1}, yw]*
      G[{0, 1/(yu*yv), yu^(-1)}, yw] - 4*G[{0}, yv^(-1)]*G[{1}, yw]*
      G[{0, 1/(yu*yv), yu^(-1)}, yw] + 4*G[{0}, yw]*G[{1}, yw]*
      G[{0, 1/(yu*yv), yu^(-1)}, yw] + 8*G[{1}, yv^(-1)]*G[{1}, yw]*
      G[{0, 1/(yu*yv), yu^(-1)}, yw] - 4*G[{1}, yw]^2*
      G[{0, 1/(yu*yv), yu^(-1)}, yw] - 4*G[{0, 1}, yv^(-1)]*
      G[{0, 1/(yu*yv), yu^(-1)}, yw] + 4*G[{0, yu}, yv^(-1)]*
      G[{0, 1/(yu*yv), yu^(-1)}, yw] - 4*G[{1, yu}, yv^(-1)]*
      G[{0, 1/(yu*yv), yu^(-1)}, yw] + 
     (8*Pi^2*G[{0, 1/(yu*yv), yv^(-1)}, yw])/3 - 
     4*G[{1}, yw]^2*G[{0, 1/(yu*yv), yv^(-1)}, yw] - 
     (2*Pi^2*G[{0, 1/(yu*yv), 1/(yu*yv)}, yw])/3 - 
     2*G[{0}, yu^(-1)]^2*G[{0, 1/(yu*yv), 1/(yu*yv)}, yw] - 
     4*G[{0}, yu^(-1)]*G[{0}, yv^(-1)]*G[{0, 1/(yu*yv), 1/(yu*yv)}, yw] - 
     2*G[{0}, yv^(-1)]^2*G[{0, 1/(yu*yv), 1/(yu*yv)}, yw] + 
     4*G[{0}, yu^(-1)]*G[{0}, yw]*G[{0, 1/(yu*yv), 1/(yu*yv)}, yw] + 
     4*G[{0}, yv^(-1)]*G[{0}, yw]*G[{0, 1/(yu*yv), 1/(yu*yv)}, yw] - 
     2*G[{0}, yw]^2*G[{0, 1/(yu*yv), 1/(yu*yv)}, yw] + 
     4*G[{0}, yu^(-1)]*G[{1}, yu^(-1)]*G[{0, 1/(yu*yv), 1/(yu*yv)}, yw] + 
     4*G[{0}, yv^(-1)]*G[{1}, yu^(-1)]*G[{0, 1/(yu*yv), 1/(yu*yv)}, yw] - 
     4*G[{0}, yw]*G[{1}, yu^(-1)]*G[{0, 1/(yu*yv), 1/(yu*yv)}, yw] - 
     4*G[{1}, yu^(-1)]^2*G[{0, 1/(yu*yv), 1/(yu*yv)}, yw] + 
     4*G[{0}, yu^(-1)]*G[{1}, yv^(-1)]*G[{0, 1/(yu*yv), 1/(yu*yv)}, yw] + 
     4*G[{0}, yv^(-1)]*G[{1}, yv^(-1)]*G[{0, 1/(yu*yv), 1/(yu*yv)}, yw] - 
     4*G[{0}, yw]*G[{1}, yv^(-1)]*G[{0, 1/(yu*yv), 1/(yu*yv)}, yw] - 
     2*G[{1}, yv^(-1)]^2*G[{0, 1/(yu*yv), 1/(yu*yv)}, yw] - 
     4*G[{0}, yu^(-1)]*G[{1}, yw]*G[{0, 1/(yu*yv), 1/(yu*yv)}, yw] - 
     4*G[{0}, yv^(-1)]*G[{1}, yw]*G[{0, 1/(yu*yv), 1/(yu*yv)}, yw] + 
     4*G[{0}, yw]*G[{1}, yw]*G[{0, 1/(yu*yv), 1/(yu*yv)}, yw] + 
     4*G[{1}, yv^(-1)]*G[{1}, yw]*G[{0, 1/(yu*yv), 1/(yu*yv)}, yw] + 
     4*G[{1}, yw]*G[{yu}, yv^(-1)]*G[{0, 1/(yu*yv), 1/(yu*yv)}, yw] + 
     4*G[{0, 1}, yu^(-1)]*G[{0, 1/(yu*yv), 1/(yu*yv)}, yw] - 
     4*G[{0, 1}, yw]*G[{0, 1/(yu*yv), 1/(yu*yv)}, yw] + 
     4*G[{0, yu^(-1)}, yw]*G[{0, 1/(yu*yv), 1/(yu*yv)}, yw] + 
     4*G[{0, yv^(-1)}, yw]*G[{0, 1/(yu*yv), 1/(yu*yv)}, yw] - 
     4*G[{0, 1/(yu*yv)}, yw]*G[{0, 1/(yu*yv), 1/(yu*yv)}, yw] - 
     4*G[{1, yu}, yv^(-1)]*G[{0, 1/(yu*yv), 1/(yu*yv)}, yw] - 
     8*G[{0, yu^(-1)}, yw]*G[{1, 1, yu}, yv^(-1)] + 
     4*G[{0, yv^(-1)}, yw]*G[{1, 1, yu}, yv^(-1)] + 
     4*G[{0, 1/(yu*yv)}, yw]*G[{1, 1, yu}, yv^(-1)] - 
     8*G[{0, yu^(-1)}, yw]*G[{1, yu, yu}, yv^(-1)] + 
     8*G[{0, 1/(yu*yv)}, yw]*G[{1, yu, yu}, yv^(-1)] - 
     4*G[{0}, yu^(-1)]*G[{0, 0, 0, 1}, yu^(-1)] - 
     4*G[{0}, yv^(-1)]*G[{0, 0, 0, 1}, yu^(-1)] + 
     4*G[{0}, yw]*G[{0, 0, 0, 1}, yu^(-1)] - 4*G[{0}, yu^(-1)]*
      G[{0, 0, 0, 1}, yw] - 4*G[{0}, yv^(-1)]*G[{0, 0, 0, 1}, yw] + 
     4*G[{0}, yw]*G[{0, 0, 0, 1}, yw] + 8*G[{yu}, yv^(-1)]*
      G[{0, 0, 0, 1}, yw] + 4*G[{0}, yu^(-1)]*G[{0, 0, 0, yu^(-1)}, yw] + 
     4*G[{0}, yv^(-1)]*G[{0, 0, 0, yu^(-1)}, yw] - 
     4*G[{0}, yw]*G[{0, 0, 0, yu^(-1)}, yw] - 8*G[{1}, yv^(-1)]*
      G[{0, 0, 0, yu^(-1)}, yw] + 4*G[{0}, yu^(-1)]*G[{0, 0, 0, yv^(-1)}, 
       yw] + 4*G[{0}, yv^(-1)]*G[{0, 0, 0, yv^(-1)}, yw] - 
     4*G[{0}, yw]*G[{0, 0, 0, yv^(-1)}, yw] - 8*G[{1}, yu^(-1)]*
      G[{0, 0, 0, yv^(-1)}, yw] - 4*G[{0}, yu^(-1)]*G[{0, 0, 0, 1/(yu*yv)}, 
       yw] - 4*G[{0}, yv^(-1)]*G[{0, 0, 0, 1/(yu*yv)}, yw] + 
     4*G[{0}, yw]*G[{0, 0, 0, 1/(yu*yv)}, yw] + 8*G[{1}, yu^(-1)]*
      G[{0, 0, 0, 1/(yu*yv)}, yw] + 8*G[{1}, yv^(-1)]*
      G[{0, 0, 0, 1/(yu*yv)}, yw] - 8*G[{yu}, yv^(-1)]*
      G[{0, 0, 0, 1/(yu*yv)}, yw] - 4*G[{0}, yu^(-1)]*
      G[{0, 0, 1, 1}, yu^(-1)] - 4*G[{0}, yv^(-1)]*G[{0, 0, 1, 1}, yu^(-1)] + 
     4*G[{0}, yw]*G[{0, 0, 1, 1}, yu^(-1)] + 8*G[{0}, yu^(-1)]*
      G[{0, 0, 1, 1}, yv^(-1)] + 8*G[{0}, yv^(-1)]*G[{0, 0, 1, 1}, yv^(-1)] - 
     8*G[{0}, yw]*G[{0, 0, 1, 1}, yv^(-1)] - 8*G[{1}, yv^(-1)]*
      G[{0, 0, 1, 1}, yv^(-1)] + 8*G[{1}, yw]*G[{0, 0, 1, 1}, yv^(-1)] - 
     4*G[{1}, yv^(-1)]*G[{0, 0, 1, 1}, yw] + 8*G[{1}, yw]*
      G[{0, 0, 1, 1}, yw] + 4*G[{yu}, yv^(-1)]*G[{0, 0, 1, 1}, yw] - 
     4*G[{0}, yu^(-1)]*G[{0, 0, 1, yu^(-1)}, yw] - 
     4*G[{0}, yv^(-1)]*G[{0, 0, 1, yu^(-1)}, yw] + 
     4*G[{0}, yw]*G[{0, 0, 1, yu^(-1)}, yw] + 8*G[{1}, yv^(-1)]*
      G[{0, 0, 1, yu^(-1)}, yw] - 8*G[{1}, yw]*G[{0, 0, 1, yu^(-1)}, yw] - 
     8*G[{0}, yu^(-1)]*G[{0, 0, 1, yu}, yv^(-1)] - 
     8*G[{0}, yv^(-1)]*G[{0, 0, 1, yu}, yv^(-1)] + 
     8*G[{0}, yw]*G[{0, 0, 1, yu}, yv^(-1)] + 8*G[{1}, yv^(-1)]*
      G[{0, 0, 1, yu}, yv^(-1)] - 8*G[{1}, yw]*G[{0, 0, 1, yu}, yv^(-1)] - 
     8*G[{1}, yw]*G[{0, 0, 1, yv^(-1)}, yw] - 4*G[{1}, yv^(-1)]*
      G[{0, 0, 1, 1/(yu*yv)}, yw] + 8*G[{1}, yw]*G[{0, 0, 1, 1/(yu*yv)}, 
       yw] + 4*G[{yu}, yv^(-1)]*G[{0, 0, 1, 1/(yu*yv)}, yw] - 
     4*G[{0}, yu^(-1)]*G[{0, 0, yu^(-1), 1}, yw] - 
     4*G[{0}, yv^(-1)]*G[{0, 0, yu^(-1), 1}, yw] + 
     4*G[{0}, yw]*G[{0, 0, yu^(-1), 1}, yw] + 4*G[{1}, yv^(-1)]*
      G[{0, 0, yu^(-1), 1}, yw] - 8*G[{1}, yw]*G[{0, 0, yu^(-1), 1}, yw] + 
     4*G[{yu}, yv^(-1)]*G[{0, 0, yu^(-1), 1}, yw] + 
     8*G[{0}, yu^(-1)]*G[{0, 0, yu^(-1), yu^(-1)}, yw] + 
     8*G[{0}, yv^(-1)]*G[{0, 0, yu^(-1), yu^(-1)}, yw] - 
     8*G[{0}, yw]*G[{0, 0, yu^(-1), yu^(-1)}, yw] - 
     16*G[{1}, yv^(-1)]*G[{0, 0, yu^(-1), yu^(-1)}, yw] + 
     8*G[{1}, yw]*G[{0, 0, yu^(-1), yu^(-1)}, yw] + 
     8*G[{1}, yw]*G[{0, 0, yu^(-1), yv^(-1)}, yw] + 
     4*G[{1}, yv^(-1)]*G[{0, 0, yu^(-1), 1/(yu*yv)}, yw] - 
     8*G[{1}, yw]*G[{0, 0, yu^(-1), 1/(yu*yv)}, yw] - 
     4*G[{yu}, yv^(-1)]*G[{0, 0, yu^(-1), 1/(yu*yv)}, yw] - 
     8*G[{0}, yu^(-1)]*G[{0, 0, yu, 1}, yv^(-1)] - 
     8*G[{0}, yv^(-1)]*G[{0, 0, yu, 1}, yv^(-1)] + 
     8*G[{0}, yw]*G[{0, 0, yu, 1}, yv^(-1)] + 8*G[{1}, yv^(-1)]*
      G[{0, 0, yu, 1}, yv^(-1)] - 8*G[{1}, yw]*G[{0, 0, yu, 1}, yv^(-1)] + 
     8*G[{0}, yu^(-1)]*G[{0, 0, yu, yu}, yv^(-1)] + 
     8*G[{0}, yv^(-1)]*G[{0, 0, yu, yu}, yv^(-1)] - 
     8*G[{0}, yw]*G[{0, 0, yu, yu}, yv^(-1)] - 8*G[{1}, yv^(-1)]*
      G[{0, 0, yu, yu}, yv^(-1)] + 8*G[{1}, yw]*G[{0, 0, yu, yu}, yv^(-1)] + 
     4*G[{1}, yv^(-1)]*G[{0, 0, yv^(-1), 1}, yw] - 
     8*G[{1}, yw]*G[{0, 0, yv^(-1), 1}, yw] - 4*G[{yu}, yv^(-1)]*
      G[{0, 0, yv^(-1), 1}, yw] + 8*G[{1}, yw]*G[{0, 0, yv^(-1), yu^(-1)}, 
       yw] + 4*G[{0}, yu^(-1)]*G[{0, 0, yv^(-1), 1/(yu*yv)}, yw] + 
     4*G[{0}, yv^(-1)]*G[{0, 0, yv^(-1), 1/(yu*yv)}, yw] - 
     4*G[{0}, yw]*G[{0, 0, yv^(-1), 1/(yu*yv)}, yw] - 
     8*G[{1}, yu^(-1)]*G[{0, 0, yv^(-1), 1/(yu*yv)}, yw] - 
     4*G[{1}, yv^(-1)]*G[{0, 0, yv^(-1), 1/(yu*yv)}, yw] + 
     4*G[{yu}, yv^(-1)]*G[{0, 0, yv^(-1), 1/(yu*yv)}, yw] + 
     4*G[{0}, yu^(-1)]*G[{0, 0, 1/(yu*yv), 1}, yw] + 
     4*G[{0}, yv^(-1)]*G[{0, 0, 1/(yu*yv), 1}, yw] - 
     4*G[{0}, yw]*G[{0, 0, 1/(yu*yv), 1}, yw] - 4*G[{1}, yv^(-1)]*
      G[{0, 0, 1/(yu*yv), 1}, yw] + 8*G[{1}, yw]*G[{0, 0, 1/(yu*yv), 1}, 
       yw] - 4*G[{yu}, yv^(-1)]*G[{0, 0, 1/(yu*yv), 1}, yw] - 
     4*G[{0}, yu^(-1)]*G[{0, 0, 1/(yu*yv), yu^(-1)}, yw] - 
     4*G[{0}, yv^(-1)]*G[{0, 0, 1/(yu*yv), yu^(-1)}, yw] + 
     4*G[{0}, yw]*G[{0, 0, 1/(yu*yv), yu^(-1)}, yw] + 
     8*G[{1}, yv^(-1)]*G[{0, 0, 1/(yu*yv), yu^(-1)}, yw] - 
     8*G[{1}, yw]*G[{0, 0, 1/(yu*yv), yu^(-1)}, yw] - 
     4*G[{0}, yu^(-1)]*G[{0, 0, 1/(yu*yv), 1/(yu*yv)}, yw] - 
     4*G[{0}, yv^(-1)]*G[{0, 0, 1/(yu*yv), 1/(yu*yv)}, yw] + 
     4*G[{0}, yw]*G[{0, 0, 1/(yu*yv), 1/(yu*yv)}, yw] + 
     8*G[{1}, yu^(-1)]*G[{0, 0, 1/(yu*yv), 1/(yu*yv)}, yw] + 
     4*G[{1}, yv^(-1)]*G[{0, 0, 1/(yu*yv), 1/(yu*yv)}, yw] - 
     4*G[{yu}, yv^(-1)]*G[{0, 0, 1/(yu*yv), 1/(yu*yv)}, yw] - 
     4*G[{1}, yw]*G[{0, 1, 0, yv^(-1)}, yw] + 
     4*G[{1}, yw]*G[{0, 1, 0, 1/(yu*yv)}, yw] - 4*G[{0}, yu^(-1)]*
      G[{0, 1, 1, 1}, yu^(-1)] - 4*G[{0}, yv^(-1)]*G[{0, 1, 1, 1}, yu^(-1)] + 
     4*G[{0}, yw]*G[{0, 1, 1, 1}, yu^(-1)] - 12*G[{1}, yv^(-1)]*
      G[{0, 1, 1, 1}, yv^(-1)] + 12*G[{1}, yw]*G[{0, 1, 1, 1}, yv^(-1)] - 
     4*G[{1}, yv^(-1)]*G[{0, 1, 1, 1}, yw] + 12*G[{1}, yw]*
      G[{0, 1, 1, 1}, yw] + 4*G[{yu}, yv^(-1)]*G[{0, 1, 1, 1}, yw] - 
     4*G[{1}, yw]*G[{0, 1, 1, yu^(-1)}, yw] + 4*G[{1}, yv^(-1)]*
      G[{0, 1, 1, yu}, yv^(-1)] - 4*G[{1}, yw]*G[{0, 1, 1, yu}, yv^(-1)] + 
     4*G[{0}, yu^(-1)]*G[{0, 1, yu^(-1), 1}, yw] + 
     4*G[{0}, yv^(-1)]*G[{0, 1, yu^(-1), 1}, yw] - 
     4*G[{0}, yw]*G[{0, 1, yu^(-1), 1}, yw] - 4*G[{1}, yv^(-1)]*
      G[{0, 1, yu^(-1), 1}, yw] - 4*G[{yu}, yv^(-1)]*
      G[{0, 1, yu^(-1), 1}, yw] - 8*G[{0}, yu^(-1)]*
      G[{0, 1, yu^(-1), yu^(-1)}, yw] - 8*G[{0}, yv^(-1)]*
      G[{0, 1, yu^(-1), yu^(-1)}, yw] + 8*G[{0}, yw]*
      G[{0, 1, yu^(-1), yu^(-1)}, yw] + 16*G[{1}, yv^(-1)]*
      G[{0, 1, yu^(-1), yu^(-1)}, yw] - 8*G[{1}, yw]*
      G[{0, 1, yu^(-1), yu^(-1)}, yw] - 4*G[{1}, yv^(-1)]*
      G[{0, 1, yu^(-1), 1/(yu*yv)}, yw] + 4*G[{yu}, yv^(-1)]*
      G[{0, 1, yu^(-1), 1/(yu*yv)}, yw] + 4*G[{0}, yu^(-1)]*
      G[{0, 1, yu, 1}, yv^(-1)] + 4*G[{0}, yv^(-1)]*
      G[{0, 1, yu, 1}, yv^(-1)] - 4*G[{0}, yw]*G[{0, 1, yu, 1}, yv^(-1)] - 
     8*G[{0}, yu^(-1)]*G[{0, 1, yu, yu}, yv^(-1)] - 
     8*G[{0}, yv^(-1)]*G[{0, 1, yu, yu}, yv^(-1)] + 
     8*G[{0}, yw]*G[{0, 1, yu, yu}, yv^(-1)] + 8*G[{1}, yv^(-1)]*
      G[{0, 1, yu, yu}, yv^(-1)] - 8*G[{1}, yw]*G[{0, 1, yu, yu}, yv^(-1)] - 
     4*G[{0}, yu^(-1)]*G[{0, 1, 1/(yu*yv), 1}, yw] - 
     4*G[{0}, yv^(-1)]*G[{0, 1, 1/(yu*yv), 1}, yw] + 
     4*G[{0}, yw]*G[{0, 1, 1/(yu*yv), 1}, yw] + 4*G[{1}, yv^(-1)]*
      G[{0, 1, 1/(yu*yv), 1}, yw] - 4*G[{1}, yw]*G[{0, 1, 1/(yu*yv), 1}, 
       yw] + 4*G[{yu}, yv^(-1)]*G[{0, 1, 1/(yu*yv), 1}, yw] + 
     4*G[{0}, yu^(-1)]*G[{0, 1, 1/(yu*yv), yu^(-1)}, yw] + 
     4*G[{0}, yv^(-1)]*G[{0, 1, 1/(yu*yv), yu^(-1)}, yw] - 
     4*G[{0}, yw]*G[{0, 1, 1/(yu*yv), yu^(-1)}, yw] - 
     8*G[{1}, yv^(-1)]*G[{0, 1, 1/(yu*yv), yu^(-1)}, yw] + 
     4*G[{1}, yw]*G[{0, 1, 1/(yu*yv), yu^(-1)}, yw] + 
     4*G[{1}, yw]*G[{0, yu^(-1), 0, yv^(-1)}, yw] - 
     4*G[{1}, yw]*G[{0, yu^(-1), 0, 1/(yu*yv)}, yw] - 
     4*G[{1}, yw]*G[{0, yu^(-1), 1, 1}, yw] - 4*G[{0}, yu^(-1)]*
      G[{0, yu^(-1), 1, yu^(-1)}, yw] - 4*G[{0}, yv^(-1)]*
      G[{0, yu^(-1), 1, yu^(-1)}, yw] + 4*G[{0}, yw]*
      G[{0, yu^(-1), 1, yu^(-1)}, yw] + 8*G[{1}, yv^(-1)]*
      G[{0, yu^(-1), 1, yu^(-1)}, yw] - 4*G[{1}, yw]*
      G[{0, yu^(-1), 1, yu^(-1)}, yw] - 4*G[{1}, yv^(-1)]*
      G[{0, yu^(-1), 1, 1/(yu*yv)}, yw] + 4*G[{yu}, yv^(-1)]*
      G[{0, yu^(-1), 1, 1/(yu*yv)}, yw] - 8*G[{0}, yu^(-1)]*
      G[{0, yu^(-1), yu^(-1), 1}, yw] - 8*G[{0}, yv^(-1)]*
      G[{0, yu^(-1), yu^(-1), 1}, yw] + 8*G[{0}, yw]*
      G[{0, yu^(-1), yu^(-1), 1}, yw] + 8*G[{1}, yv^(-1)]*
      G[{0, yu^(-1), yu^(-1), 1}, yw] - 8*G[{1}, yw]*
      G[{0, yu^(-1), yu^(-1), 1}, yw] + 8*G[{yu}, yv^(-1)]*
      G[{0, yu^(-1), yu^(-1), 1}, yw] + 16*G[{0}, yu^(-1)]*
      G[{0, yu^(-1), yu^(-1), yu^(-1)}, yw] + 16*G[{0}, yv^(-1)]*
      G[{0, yu^(-1), yu^(-1), yu^(-1)}, yw] - 16*G[{0}, yw]*
      G[{0, yu^(-1), yu^(-1), yu^(-1)}, yw] - 32*G[{1}, yv^(-1)]*
      G[{0, yu^(-1), yu^(-1), yu^(-1)}, yw] + 16*G[{1}, yw]*
      G[{0, yu^(-1), yu^(-1), yu^(-1)}, yw] + 8*G[{1}, yv^(-1)]*
      G[{0, yu^(-1), yu^(-1), 1/(yu*yv)}, yw] - 8*G[{yu}, yv^(-1)]*
      G[{0, yu^(-1), yu^(-1), 1/(yu*yv)}, yw] + 4*G[{0}, yu^(-1)]*
      G[{0, yu^(-1), 1/(yu*yv), 1}, yw] + 4*G[{0}, yv^(-1)]*
      G[{0, yu^(-1), 1/(yu*yv), 1}, yw] - 4*G[{0}, yw]*
      G[{0, yu^(-1), 1/(yu*yv), 1}, yw] - 4*G[{1}, yv^(-1)]*
      G[{0, yu^(-1), 1/(yu*yv), 1}, yw] + 4*G[{1}, yw]*
      G[{0, yu^(-1), 1/(yu*yv), 1}, yw] - 4*G[{yu}, yv^(-1)]*
      G[{0, yu^(-1), 1/(yu*yv), 1}, yw] - 4*G[{0}, yu^(-1)]*
      G[{0, yu^(-1), 1/(yu*yv), yu^(-1)}, yw] - 4*G[{0}, yv^(-1)]*
      G[{0, yu^(-1), 1/(yu*yv), yu^(-1)}, yw] + 
     4*G[{0}, yw]*G[{0, yu^(-1), 1/(yu*yv), yu^(-1)}, yw] + 
     8*G[{1}, yv^(-1)]*G[{0, yu^(-1), 1/(yu*yv), yu^(-1)}, yw] - 
     4*G[{1}, yw]*G[{0, yu^(-1), 1/(yu*yv), yu^(-1)}, yw] + 
     4*G[{1}, yv^(-1)]*G[{0, yu, 1, 1}, yv^(-1)] - 
     4*G[{1}, yw]*G[{0, yu, 1, 1}, yv^(-1)] - 4*G[{0}, yu^(-1)]*
      G[{0, yu, 1, yu}, yv^(-1)] - 4*G[{0}, yv^(-1)]*
      G[{0, yu, 1, yu}, yv^(-1)] + 4*G[{0}, yw]*G[{0, yu, 1, yu}, yv^(-1)] + 
     4*G[{1}, yv^(-1)]*G[{0, yu, 1, yu}, yv^(-1)] - 
     4*G[{1}, yw]*G[{0, yu, 1, yu}, yv^(-1)] - 8*G[{0}, yu^(-1)]*
      G[{0, yu, yu, 1}, yv^(-1)] - 8*G[{0}, yv^(-1)]*
      G[{0, yu, yu, 1}, yv^(-1)] + 8*G[{0}, yw]*G[{0, yu, yu, 1}, yv^(-1)] + 
     8*G[{1}, yv^(-1)]*G[{0, yu, yu, 1}, yv^(-1)] - 
     8*G[{1}, yw]*G[{0, yu, yu, 1}, yv^(-1)] + 16*G[{0}, yu^(-1)]*
      G[{0, yu, yu, yu}, yv^(-1)] + 16*G[{0}, yv^(-1)]*
      G[{0, yu, yu, yu}, yv^(-1)] - 16*G[{0}, yw]*G[{0, yu, yu, yu}, 
       yv^(-1)] - 16*G[{1}, yv^(-1)]*G[{0, yu, yu, yu}, yv^(-1)] + 
     16*G[{1}, yw]*G[{0, yu, yu, yu}, yv^(-1)] + 4*G[{1}, yv^(-1)]*
      G[{0, yv^(-1), 1, 1}, yw] - 4*G[{1}, yw]*G[{0, yv^(-1), 1, 1}, yw] - 
     4*G[{yu}, yv^(-1)]*G[{0, yv^(-1), 1, 1}, yw] + 
     4*G[{1}, yw]*G[{0, yv^(-1), 1, yu^(-1)}, yw] - 
     8*G[{1}, yw]*G[{0, yv^(-1), yv^(-1), 1}, yw] + 
     4*G[{1}, yw]*G[{0, yv^(-1), 1/(yu*yv), 1}, yw] + 
     4*G[{1}, yw]*G[{0, yv^(-1), 1/(yu*yv), yu^(-1)}, yw] + 
     4*G[{0}, yu^(-1)]*G[{0, yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] + 
     4*G[{0}, yv^(-1)]*G[{0, yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] - 
     4*G[{0}, yw]*G[{0, yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] - 
     8*G[{1}, yu^(-1)]*G[{0, yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] - 
     4*G[{1}, yv^(-1)]*G[{0, yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] + 
     4*G[{yu}, yv^(-1)]*G[{0, yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] - 
     4*G[{1}, yw]*G[{0, 1/(yu*yv), 1, 1}, yw] + 4*G[{0}, yu^(-1)]*
      G[{0, 1/(yu*yv), 1, yu^(-1)}, yw] + 4*G[{0}, yv^(-1)]*
      G[{0, 1/(yu*yv), 1, yu^(-1)}, yw] - 4*G[{0}, yw]*
      G[{0, 1/(yu*yv), 1, yu^(-1)}, yw] - 8*G[{1}, yv^(-1)]*
      G[{0, 1/(yu*yv), 1, yu^(-1)}, yw] + 4*G[{1}, yw]*
      G[{0, 1/(yu*yv), 1, yu^(-1)}, yw] + 4*G[{1}, yv^(-1)]*
      G[{0, 1/(yu*yv), 1, 1/(yu*yv)}, yw] - 4*G[{yu}, yv^(-1)]*
      G[{0, 1/(yu*yv), 1, 1/(yu*yv)}, yw] + 4*G[{0}, yu^(-1)]*
      G[{0, 1/(yu*yv), yu^(-1), 1}, yw] + 4*G[{0}, yv^(-1)]*
      G[{0, 1/(yu*yv), yu^(-1), 1}, yw] - 4*G[{0}, yw]*
      G[{0, 1/(yu*yv), yu^(-1), 1}, yw] - 4*G[{1}, yv^(-1)]*
      G[{0, 1/(yu*yv), yu^(-1), 1}, yw] + 8*G[{1}, yw]*
      G[{0, 1/(yu*yv), yu^(-1), 1}, yw] - 4*G[{yu}, yv^(-1)]*
      G[{0, 1/(yu*yv), yu^(-1), 1}, yw] - 8*G[{0}, yu^(-1)]*
      G[{0, 1/(yu*yv), yu^(-1), yu^(-1)}, yw] - 8*G[{0}, yv^(-1)]*
      G[{0, 1/(yu*yv), yu^(-1), yu^(-1)}, yw] + 
     8*G[{0}, yw]*G[{0, 1/(yu*yv), yu^(-1), yu^(-1)}, yw] + 
     16*G[{1}, yv^(-1)]*G[{0, 1/(yu*yv), yu^(-1), yu^(-1)}, yw] - 
     8*G[{1}, yw]*G[{0, 1/(yu*yv), yu^(-1), yu^(-1)}, yw] - 
     4*G[{1}, yv^(-1)]*G[{0, 1/(yu*yv), yu^(-1), 1/(yu*yv)}, yw] + 
     4*G[{yu}, yv^(-1)]*G[{0, 1/(yu*yv), yu^(-1), 1/(yu*yv)}, yw] + 
     8*G[{1}, yw]*G[{0, 1/(yu*yv), yv^(-1), 1}, yw] - 
     4*G[{1}, yw]*G[{0, 1/(yu*yv), 1/(yu*yv), 1}, yw] - 
     4*G[{1}, yw]*G[{0, 1/(yu*yv), 1/(yu*yv), yu^(-1)}, yw] - 
     4*G[{0}, yu^(-1)]*G[{0, 1/(yu*yv), 1/(yu*yv), 1/(yu*yv)}, yw] - 
     4*G[{0}, yv^(-1)]*G[{0, 1/(yu*yv), 1/(yu*yv), 1/(yu*yv)}, yw] + 
     4*G[{0}, yw]*G[{0, 1/(yu*yv), 1/(yu*yv), 1/(yu*yv)}, yw] + 
     8*G[{1}, yu^(-1)]*G[{0, 1/(yu*yv), 1/(yu*yv), 1/(yu*yv)}, yw] + 
     4*G[{1}, yv^(-1)]*G[{0, 1/(yu*yv), 1/(yu*yv), 1/(yu*yv)}, yw] - 
     4*G[{yu}, yv^(-1)]*G[{0, 1/(yu*yv), 1/(yu*yv), 1/(yu*yv)}, yw] - 
     8*G[{0, 0, 0, 0, 1}, yw] + 8*G[{0, 0, 0, 0, yu^(-1)}, yw] + 
     8*G[{0, 0, 0, 0, yv^(-1)}, yw] - 8*G[{0, 0, 0, 0, 1/(yu*yv)}, yw] - 
     16*G[{0, 0, 0, 1, 1}, yu^(-1)] - 8*G[{0, 0, 0, 1, 1}, yw] + 
     12*G[{0, 0, 0, 1, yv^(-1)}, yw] - 12*G[{0, 0, 0, 1, 1/(yu*yv)}, yw] + 
     8*G[{0, 0, 0, yu^(-1), yu^(-1)}, yw] - 
     12*G[{0, 0, 0, yu^(-1), yv^(-1)}, yw] + 
     12*G[{0, 0, 0, yu^(-1), 1/(yu*yv)}, yw] + 
     12*G[{0, 0, 0, yv^(-1), 1}, yw] - 12*G[{0, 0, 0, yv^(-1), yu^(-1)}, 
       yw] - 16*G[{0, 0, 0, yv^(-1), yv^(-1)}, yw] + 
     24*G[{0, 0, 0, yv^(-1), 1/(yu*yv)}, yw] - 
     4*G[{0, 0, 0, 1/(yu*yv), 1}, yw] + 4*G[{0, 0, 0, 1/(yu*yv), yu^(-1)}, 
       yw] + 16*G[{0, 0, 0, 1/(yu*yv), yv^(-1)}, yw] - 
     24*G[{0, 0, 0, 1/(yu*yv), 1/(yu*yv)}, yw] - 
     8*G[{0, 0, 1, 0, 1}, yu^(-1)] + 4*G[{0, 0, 1, 0, yv^(-1)}, yw] - 
     4*G[{0, 0, 1, 0, 1/(yu*yv)}, yw] + 24*G[{0, 0, 1, 1, 1}, yu^(-1)] - 
     12*G[{0, 0, 1, 1, 1}, yw] + 4*G[{0, 0, 1, 1, yu^(-1)}, yw] + 
     8*G[{0, 0, 1, 1, yv^(-1)}, yw] - 8*G[{0, 0, 1, 1, 1/(yu*yv)}, yw] + 
     8*G[{0, 0, 1, yu^(-1), 1}, yw] - 8*G[{0, 0, 1, yu^(-1), yu^(-1)}, yw] + 
     8*G[{0, 0, 1, yu^(-1), yv^(-1)}, yw] - 
     8*G[{0, 0, 1, yu^(-1), 1/(yu*yv)}, yw] - 
     16*G[{0, 0, 1, yu, yu}, yv^(-1)] + 8*G[{0, 0, 1, yv^(-1), 1}, yw] + 
     8*G[{0, 0, 1, yv^(-1), yu^(-1)}, yw] - 
     8*G[{0, 0, 1, yv^(-1), 1/(yu*yv)}, yw] - 
     12*G[{0, 0, 1, 1/(yu*yv), 1}, yw] - 4*G[{0, 0, 1, 1/(yu*yv), yu^(-1)}, 
       yw] - 8*G[{0, 0, 1, 1/(yu*yv), 1/(yu*yv)}, yw] - 
     4*G[{0, 0, yu^(-1), 0, yv^(-1)}, yw] + 
     4*G[{0, 0, yu^(-1), 0, 1/(yu*yv)}, yw] + 
     4*G[{0, 0, yu^(-1), 1, 1}, yw] - 4*G[{0, 0, yu^(-1), 1, yu^(-1)}, yw] - 
     8*G[{0, 0, yu^(-1), yu^(-1), 1}, yw] + 
     16*G[{0, 0, yu^(-1), yu^(-1), yu^(-1)}, yw] - 
     8*G[{0, 0, yu^(-1), yv^(-1), 1}, yw] + 
     12*G[{0, 0, yu^(-1), 1/(yu*yv), 1}, yw] - 
     4*G[{0, 0, yu^(-1), 1/(yu*yv), yu^(-1)}, yw] - 
     8*G[{0, 0, yu^(-1), 1/(yu*yv), yv^(-1)}, yw] + 
     8*G[{0, 0, yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] + 
     8*G[{0, 0, yu, 1, yu}, yv^(-1)] + 32*G[{0, 0, yu, yu, 1}, yv^(-1)] - 
     48*G[{0, 0, yu, yu, yu}, yv^(-1)] + 4*G[{0, 0, yv^(-1), 0, 1}, yw] - 
     4*G[{0, 0, yv^(-1), 0, yu^(-1)}, yw] - 
     8*G[{0, 0, yv^(-1), 0, yv^(-1)}, yw] + 
     8*G[{0, 0, yv^(-1), 0, 1/(yu*yv)}, yw] + 
     12*G[{0, 0, yv^(-1), 1, 1}, yw] - 4*G[{0, 0, yv^(-1), 1, yu^(-1)}, yw] - 
     8*G[{0, 0, yv^(-1), yu^(-1), 1}, yw] + 
     8*G[{0, 0, yv^(-1), yv^(-1), 1}, yw] + 
     16*G[{0, 0, yv^(-1), yv^(-1), 1/(yu*yv)}, yw] - 
     4*G[{0, 0, yv^(-1), 1/(yu*yv), 1}, yw] + 
     4*G[{0, 0, yv^(-1), 1/(yu*yv), yu^(-1)}, yw] + 
     8*G[{0, 0, yv^(-1), 1/(yu*yv), yv^(-1)}, yw] + 
     16*G[{0, 0, yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] - 
     4*G[{0, 0, 1/(yu*yv), 0, 1}, yw] + 4*G[{0, 0, 1/(yu*yv), 0, yu^(-1)}, 
       yw] + 8*G[{0, 0, 1/(yu*yv), 0, yv^(-1)}, yw] - 
     8*G[{0, 0, 1/(yu*yv), 0, 1/(yu*yv)}, yw] - 
     4*G[{0, 0, 1/(yu*yv), 1, 1}, yw] + 4*G[{0, 0, 1/(yu*yv), 1, yu^(-1)}, 
       yw] + 8*G[{0, 0, 1/(yu*yv), yu^(-1), 1}, yw] - 
     8*G[{0, 0, 1/(yu*yv), yu^(-1), yu^(-1)}, yw] + 
     12*G[{0, 0, 1/(yu*yv), 1/(yu*yv), 1}, yw] - 
     4*G[{0, 0, 1/(yu*yv), 1/(yu*yv), yu^(-1)}, yw] - 
     8*G[{0, 0, 1/(yu*yv), 1/(yu*yv), yv^(-1)}, yw] + 
     16*G[{0, 0, 1/(yu*yv), 1/(yu*yv), 1/(yu*yv)}, yw] + 
     8*G[{0, 1, 0, 1, 1}, yu^(-1)] + 4*G[{0, 1, 0, 1, yu}, yv^(-1)] + 
     4*G[{0, 1, 0, 1, yv^(-1)}, yw] - 4*G[{0, 1, 0, 1, 1/(yu*yv)}, yw] + 
     4*G[{0, 1, 0, yu^(-1), yv^(-1)}, yw] - 
     4*G[{0, 1, 0, yu^(-1), 1/(yu*yv)}, yw] + 
     4*G[{0, 1, 0, yu, 1}, yv^(-1)] - 16*G[{0, 1, 0, yu, yu}, yv^(-1)] + 
     4*G[{0, 1, 0, yv^(-1), 1}, yw] + 4*G[{0, 1, 0, yv^(-1), yu^(-1)}, yw] - 
     4*G[{0, 1, 0, yv^(-1), 1/(yu*yv)}, yw] - 
     4*G[{0, 1, 0, 1/(yu*yv), 1}, yw] - 4*G[{0, 1, 0, 1/(yu*yv), yu^(-1)}, 
       yw] - 4*G[{0, 1, 0, 1/(yu*yv), 1/(yu*yv)}, yw] + 
     8*G[{0, 1, 1, 0, yu}, yv^(-1)] + 4*G[{0, 1, 1, 0, yv^(-1)}, yw] - 
     4*G[{0, 1, 1, 0, 1/(yu*yv)}, yw] + 8*G[{0, 1, 1, 1, 1}, yu^(-1)] + 
     16*G[{0, 1, 1, 1, 1}, yv^(-1)] - 16*G[{0, 1, 1, 1, 1}, yw] + 
     4*G[{0, 1, 1, 1, yu^(-1)}, yw] - 4*G[{0, 1, 1, 1, yu}, yv^(-1)] + 
     4*G[{0, 1, 1, yu^(-1), 1}, yw] - 4*G[{0, 1, 1, yu, 1}, yv^(-1)] + 
     4*G[{0, 1, yu^(-1), 1, 1}, yw] + 4*G[{0, 1, yu^(-1), 1, yu^(-1)}, yw] + 
     8*G[{0, 1, yu^(-1), yu^(-1), 1}, yw] - 
     16*G[{0, 1, yu^(-1), yu^(-1), yu^(-1)}, yw] - 
     4*G[{0, 1, yu^(-1), 1/(yu*yv), 1}, yw] + 
     4*G[{0, 1, yu^(-1), 1/(yu*yv), yu^(-1)}, yw] - 
     12*G[{0, 1, yu, 0, yu}, yv^(-1)] - 4*G[{0, 1, yu, 1, 1}, yv^(-1)] - 
     4*G[{0, 1, yu, 1, yu}, yv^(-1)] - 8*G[{0, 1, yu, yu, 1}, yv^(-1)] + 
     16*G[{0, 1, yu, yu, yu}, yv^(-1)] + 4*G[{0, 1, yv^(-1), 0, yu^(-1)}, 
       yw] - 4*G[{0, 1, 1/(yu*yv), 0, yu^(-1)}, yw] - 
     4*G[{0, 1, 1/(yu*yv), 0, 1/(yu*yv)}, yw] - 
     4*G[{0, 1, 1/(yu*yv), 1, yu^(-1)}, yw] - 
     4*G[{0, 1, 1/(yu*yv), yu^(-1), 1}, yw] + 
     8*G[{0, 1, 1/(yu*yv), yu^(-1), yu^(-1)}, yw] - 
     4*G[{0, yu^(-1), 0, yv^(-1), 1}, yw] + 
     4*G[{0, yu^(-1), 0, 1/(yu*yv), 1}, yw] - 
     4*G[{0, yu^(-1), 0, 1/(yu*yv), yv^(-1)}, yw] + 
     4*G[{0, yu^(-1), 0, 1/(yu*yv), 1/(yu*yv)}, yw] - 
     4*G[{0, yu^(-1), 1, 0, yv^(-1)}, yw] + 
     4*G[{0, yu^(-1), 1, 0, 1/(yu*yv)}, yw] + 
     4*G[{0, yu^(-1), 1, 1, 1}, yw] + 4*G[{0, yu^(-1), 1, yu^(-1), 1}, yw] - 
     8*G[{0, yu^(-1), 1, yu^(-1), yu^(-1)}, yw] - 
     4*G[{0, yu^(-1), 1, 1/(yu*yv), 1}, yw] + 
     4*G[{0, yu^(-1), 1, 1/(yu*yv), yu^(-1)}, yw] - 
     8*G[{0, yu^(-1), yu^(-1), 1, yu^(-1)}, yw] - 
     16*G[{0, yu^(-1), yu^(-1), yu^(-1), 1}, yw] + 
     32*G[{0, yu^(-1), yu^(-1), yu^(-1), yu^(-1)}, yw] + 
     8*G[{0, yu^(-1), yu^(-1), 1/(yu*yv), 1}, yw] - 
     8*G[{0, yu^(-1), yu^(-1), 1/(yu*yv), yu^(-1)}, yw] - 
     4*G[{0, yu^(-1), 1/(yu*yv), 0, yv^(-1)}, yw] + 
     4*G[{0, yu^(-1), 1/(yu*yv), 0, 1/(yu*yv)}, yw] + 
     4*G[{0, yu^(-1), 1/(yu*yv), 1, yu^(-1)}, yw] + 
     4*G[{0, yu^(-1), 1/(yu*yv), yu^(-1), 1}, yw] - 
     8*G[{0, yu^(-1), 1/(yu*yv), yu^(-1), yu^(-1)}, yw] + 
     12*G[{0, yu, 0, yu, 1}, yv^(-1)] - 16*G[{0, yu, 0, yu, yu}, yv^(-1)] - 
     4*G[{0, yu, 1, 1, 1}, yv^(-1)] - 4*G[{0, yu, 1, yu, 1}, yv^(-1)] + 
     8*G[{0, yu, 1, yu, yu}, yv^(-1)] + 8*G[{0, yu, yu, 1, yu}, yv^(-1)] + 
     16*G[{0, yu, yu, yu, 1}, yv^(-1)] - 32*G[{0, yu, yu, yu, yu}, yv^(-1)] + 
     4*G[{0, yv^(-1), 0, yv^(-1), 1}, yw] + 
     8*G[{0, yv^(-1), 0, yv^(-1), 1/(yu*yv)}, yw] + 
     8*G[{0, yv^(-1), 0, 1/(yu*yv), 1/(yu*yv)}, yw] + 
     4*G[{0, yv^(-1), 1, 0, 1/(yu*yv)}, yw] + 
     8*G[{0, yv^(-1), 1, 1, 1}, yw] - 4*G[{0, yv^(-1), 1, 1, yu^(-1)}, yw] - 
     4*G[{0, yv^(-1), 1, yu^(-1), 1}, yw] + 
     8*G[{0, yv^(-1), yv^(-1), 1, 1}, yw] + 
     8*G[{0, yv^(-1), 1/(yu*yv), 0, 1/(yu*yv)}, yw] - 
     4*G[{0, yv^(-1), 1/(yu*yv), 1, 1}, yw] - 
     4*G[{0, yv^(-1), 1/(yu*yv), yu^(-1), 1}, yw] - 
     4*G[{0, yv^(-1), 1/(yu*yv), 1/(yu*yv), 1}, yw] + 
     4*G[{0, yv^(-1), 1/(yu*yv), 1/(yu*yv), yu^(-1)}, yw] + 
     8*G[{0, yv^(-1), 1/(yu*yv), 1/(yu*yv), yv^(-1)}, yw] + 
     4*G[{0, 1/(yu*yv), 0, 1/(yu*yv), 1}, yw] + 
     8*G[{0, 1/(yu*yv), 0, 1/(yu*yv), 1/(yu*yv)}, yw] + 
     4*G[{0, 1/(yu*yv), 1, 1, 1}, yw] - 4*G[{0, 1/(yu*yv), 1, yu^(-1), 1}, 
       yw] + 8*G[{0, 1/(yu*yv), 1, yu^(-1), yu^(-1)}, yw] + 
     4*G[{0, 1/(yu*yv), 1, 1/(yu*yv), 1}, yw] - 
     4*G[{0, 1/(yu*yv), 1, 1/(yu*yv), yu^(-1)}, yw] - 
     4*G[{0, 1/(yu*yv), yu^(-1), 1, 1}, yw] + 
     4*G[{0, 1/(yu*yv), yu^(-1), 1, yu^(-1)}, yw] + 
     8*G[{0, 1/(yu*yv), yu^(-1), yu^(-1), 1}, yw] - 
     16*G[{0, 1/(yu*yv), yu^(-1), yu^(-1), yu^(-1)}, yw] - 
     4*G[{0, 1/(yu*yv), yu^(-1), 1/(yu*yv), 1}, yw] + 
     4*G[{0, 1/(yu*yv), yu^(-1), 1/(yu*yv), yu^(-1)}, yw] - 
     8*G[{0, 1/(yu*yv), yv^(-1), 1, 1}, yw] + 
     4*G[{0, 1/(yu*yv), 1/(yu*yv), 1, 1}, yw] + 
     4*G[{0, 1/(yu*yv), 1/(yu*yv), yu^(-1), 1}, yw] + 
     4*G[{0, 1/(yu*yv), 1/(yu*yv), 1/(yu*yv), 1}, yw] - 
     4*G[{0, 1/(yu*yv), 1/(yu*yv), 1/(yu*yv), yu^(-1)}, yw] - 
     8*G[{0, 1/(yu*yv), 1/(yu*yv), 1/(yu*yv), yv^(-1)}, yw] + 
     (8*Pi^2*Zeta[3])/3 - 4*G[{1}, yv^(-1)]^2*Zeta[3] + 
     8*G[{1}, yv^(-1)]*G[{1}, yw]*Zeta[3] - 4*G[{1}, yw]^2*Zeta[3] - 
     16*Zeta[5]
 
K1uvwRegII = -(Pi^4*G[{0}, yu^(-1)])/15 - (Pi^4*G[{0}, yv^(-1)])/15 + 
     (Pi^4*G[{0}, yw])/15 - (Pi^4*G[{1}, yu^(-1)])/36 - 
     (Pi^2*G[{0}, yu^(-1)]^2*G[{1}, yu^(-1)])/6 - 
     (Pi^2*G[{0}, yu^(-1)]*G[{0}, yv^(-1)]*G[{1}, yu^(-1)])/3 - 
     (Pi^2*G[{0}, yv^(-1)]^2*G[{1}, yu^(-1)])/6 + 
     (Pi^2*G[{0}, yu^(-1)]*G[{0}, yw]*G[{1}, yu^(-1)])/3 + 
     (Pi^2*G[{0}, yv^(-1)]*G[{0}, yw]*G[{1}, yu^(-1)])/3 - 
     (Pi^2*G[{0}, yw]^2*G[{1}, yu^(-1)])/6 + 
     (Pi^2*G[{0}, yu^(-1)]*G[{1}, yu^(-1)]^2)/6 + 
     (Pi^2*G[{0}, yv^(-1)]*G[{1}, yu^(-1)]^2)/6 - 
     (Pi^2*G[{0}, yw]*G[{1}, yu^(-1)]^2)/6 + (11*Pi^4*G[{1}, yv^(-1)])/90 + 
     (Pi^2*G[{0}, yu^(-1)]^2*G[{1}, yv^(-1)])/6 + 
     (Pi^2*G[{0}, yu^(-1)]*G[{0}, yv^(-1)]*G[{1}, yv^(-1)])/3 + 
     (Pi^2*G[{0}, yv^(-1)]^2*G[{1}, yv^(-1)])/6 - 
     (Pi^2*G[{0}, yu^(-1)]*G[{0}, yw]*G[{1}, yv^(-1)])/3 - 
     (Pi^2*G[{0}, yv^(-1)]*G[{0}, yw]*G[{1}, yv^(-1)])/3 + 
     (Pi^2*G[{0}, yw]^2*G[{1}, yv^(-1)])/6 - 
     (Pi^2*G[{0}, yu^(-1)]*G[{1}, yv^(-1)]^2)/6 - 
     (Pi^2*G[{0}, yv^(-1)]*G[{1}, yv^(-1)]^2)/6 + 
     (Pi^2*G[{0}, yw]*G[{1}, yv^(-1)]^2)/6 + (Pi^4*G[{1}, yw])/36 + 
     (Pi^2*G[{0}, yu^(-1)]^2*G[{1}, yw])/6 + 
     (Pi^2*G[{0}, yu^(-1)]*G[{0}, yv^(-1)]*G[{1}, yw])/3 + 
     (Pi^2*G[{0}, yv^(-1)]^2*G[{1}, yw])/6 - 
     (Pi^2*G[{0}, yu^(-1)]*G[{0}, yw]*G[{1}, yw])/3 - 
     (Pi^2*G[{0}, yv^(-1)]*G[{0}, yw]*G[{1}, yw])/3 + 
     (Pi^2*G[{0}, yw]^2*G[{1}, yw])/6 - (Pi^2*G[{0}, yu^(-1)]*G[{1}, yu^(-1)]*
       G[{1}, yw])/3 - (Pi^2*G[{0}, yv^(-1)]*G[{1}, yu^(-1)]*G[{1}, yw])/3 + 
     (Pi^2*G[{0}, yw]*G[{1}, yu^(-1)]*G[{1}, yw])/3 + 
     (Pi^2*G[{0}, yu^(-1)]*G[{1}, yw]^2)/6 + 
     (Pi^2*G[{0}, yv^(-1)]*G[{1}, yw]^2)/6 - (Pi^2*G[{0}, yw]*G[{1}, yw]^2)/
      6 - (11*Pi^4*G[{1/(yu*yv)}, yw])/90 - 
     (Pi^2*G[{0}, yu^(-1)]^2*G[{1/(yu*yv)}, yw])/6 - 
     (Pi^2*G[{0}, yu^(-1)]*G[{0}, yv^(-1)]*G[{1/(yu*yv)}, yw])/3 - 
     (Pi^2*G[{0}, yv^(-1)]^2*G[{1/(yu*yv)}, yw])/6 + 
     (Pi^2*G[{0}, yu^(-1)]*G[{0}, yw]*G[{1/(yu*yv)}, yw])/3 + 
     (Pi^2*G[{0}, yv^(-1)]*G[{0}, yw]*G[{1/(yu*yv)}, yw])/3 - 
     (Pi^2*G[{0}, yw]^2*G[{1/(yu*yv)}, yw])/6 + 
     (Pi^2*G[{0}, yu^(-1)]*G[{1}, yv^(-1)]*G[{1/(yu*yv)}, yw])/3 + 
     (Pi^2*G[{0}, yv^(-1)]*G[{1}, yv^(-1)]*G[{1/(yu*yv)}, yw])/3 - 
     (Pi^2*G[{0}, yw]*G[{1}, yv^(-1)]*G[{1/(yu*yv)}, yw])/3 - 
     (Pi^2*G[{0}, yu^(-1)]*G[{1/(yu*yv)}, yw]^2)/6 - 
     (Pi^2*G[{0}, yv^(-1)]*G[{1/(yu*yv)}, yw]^2)/6 + 
     (Pi^2*G[{0}, yw]*G[{1/(yu*yv)}, yw]^2)/6 - 
     (2*Pi^2*G[{1}, yu^(-1)]*G[{0, 1}, yu^(-1)])/3 - 
     G[{0}, yu^(-1)]^2*G[{1}, yu^(-1)]*G[{0, 1}, yu^(-1)] - 
     2*G[{0}, yu^(-1)]*G[{0}, yv^(-1)]*G[{1}, yu^(-1)]*G[{0, 1}, yu^(-1)] - 
     G[{0}, yv^(-1)]^2*G[{1}, yu^(-1)]*G[{0, 1}, yu^(-1)] + 
     2*G[{0}, yu^(-1)]*G[{0}, yw]*G[{1}, yu^(-1)]*G[{0, 1}, yu^(-1)] + 
     2*G[{0}, yv^(-1)]*G[{0}, yw]*G[{1}, yu^(-1)]*G[{0, 1}, yu^(-1)] - 
     G[{0}, yw]^2*G[{1}, yu^(-1)]*G[{0, 1}, yu^(-1)] + 
     G[{0}, yu^(-1)]*G[{1}, yu^(-1)]^2*G[{0, 1}, yu^(-1)] + 
     G[{0}, yv^(-1)]*G[{1}, yu^(-1)]^2*G[{0, 1}, yu^(-1)] - 
     G[{0}, yw]*G[{1}, yu^(-1)]^2*G[{0, 1}, yu^(-1)] + 
     (Pi^2*G[{1}, yv^(-1)]*G[{0, 1}, yu^(-1)])/3 + 
     G[{0}, yu^(-1)]^2*G[{1}, yv^(-1)]*G[{0, 1}, yu^(-1)] + 
     2*G[{0}, yu^(-1)]*G[{0}, yv^(-1)]*G[{1}, yv^(-1)]*G[{0, 1}, yu^(-1)] + 
     G[{0}, yv^(-1)]^2*G[{1}, yv^(-1)]*G[{0, 1}, yu^(-1)] - 
     2*G[{0}, yu^(-1)]*G[{0}, yw]*G[{1}, yv^(-1)]*G[{0, 1}, yu^(-1)] - 
     2*G[{0}, yv^(-1)]*G[{0}, yw]*G[{1}, yv^(-1)]*G[{0, 1}, yu^(-1)] + 
     G[{0}, yw]^2*G[{1}, yv^(-1)]*G[{0, 1}, yu^(-1)] - 
     G[{0}, yu^(-1)]*G[{1}, yv^(-1)]^2*G[{0, 1}, yu^(-1)] - 
     G[{0}, yv^(-1)]*G[{1}, yv^(-1)]^2*G[{0, 1}, yu^(-1)] + 
     G[{0}, yw]*G[{1}, yv^(-1)]^2*G[{0, 1}, yu^(-1)] + 
     (2*Pi^2*G[{1}, yw]*G[{0, 1}, yu^(-1)])/3 + G[{0}, yu^(-1)]^2*G[{1}, yw]*
      G[{0, 1}, yu^(-1)] + 2*G[{0}, yu^(-1)]*G[{0}, yv^(-1)]*G[{1}, yw]*
      G[{0, 1}, yu^(-1)] + G[{0}, yv^(-1)]^2*G[{1}, yw]*G[{0, 1}, yu^(-1)] - 
     2*G[{0}, yu^(-1)]*G[{0}, yw]*G[{1}, yw]*G[{0, 1}, yu^(-1)] - 
     2*G[{0}, yv^(-1)]*G[{0}, yw]*G[{1}, yw]*G[{0, 1}, yu^(-1)] + 
     G[{0}, yw]^2*G[{1}, yw]*G[{0, 1}, yu^(-1)] - 
     2*G[{0}, yu^(-1)]*G[{1}, yu^(-1)]*G[{1}, yw]*G[{0, 1}, yu^(-1)] - 
     2*G[{0}, yv^(-1)]*G[{1}, yu^(-1)]*G[{1}, yw]*G[{0, 1}, yu^(-1)] + 
     2*G[{0}, yw]*G[{1}, yu^(-1)]*G[{1}, yw]*G[{0, 1}, yu^(-1)] + 
     G[{0}, yu^(-1)]*G[{1}, yw]^2*G[{0, 1}, yu^(-1)] + 
     G[{0}, yv^(-1)]*G[{1}, yw]^2*G[{0, 1}, yu^(-1)] - 
     G[{0}, yw]*G[{1}, yw]^2*G[{0, 1}, yu^(-1)] - 
     (Pi^2*G[{1/(yu*yv)}, yw]*G[{0, 1}, yu^(-1)])/3 - 
     G[{0}, yu^(-1)]^2*G[{1/(yu*yv)}, yw]*G[{0, 1}, yu^(-1)] - 
     2*G[{0}, yu^(-1)]*G[{0}, yv^(-1)]*G[{1/(yu*yv)}, yw]*
      G[{0, 1}, yu^(-1)] - G[{0}, yv^(-1)]^2*G[{1/(yu*yv)}, yw]*
      G[{0, 1}, yu^(-1)] + 2*G[{0}, yu^(-1)]*G[{0}, yw]*G[{1/(yu*yv)}, yw]*
      G[{0, 1}, yu^(-1)] + 2*G[{0}, yv^(-1)]*G[{0}, yw]*G[{1/(yu*yv)}, yw]*
      G[{0, 1}, yu^(-1)] - G[{0}, yw]^2*G[{1/(yu*yv)}, yw]*
      G[{0, 1}, yu^(-1)] + 2*G[{0}, yu^(-1)]*G[{1}, yv^(-1)]*
      G[{1/(yu*yv)}, yw]*G[{0, 1}, yu^(-1)] + 2*G[{0}, yv^(-1)]*
      G[{1}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, 1}, yu^(-1)] - 
     2*G[{0}, yw]*G[{1}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, 1}, yu^(-1)] - 
     G[{0}, yu^(-1)]*G[{1/(yu*yv)}, yw]^2*G[{0, 1}, yu^(-1)] - 
     G[{0}, yv^(-1)]*G[{1/(yu*yv)}, yw]^2*G[{0, 1}, yu^(-1)] + 
     G[{0}, yw]*G[{1/(yu*yv)}, yw]^2*G[{0, 1}, yu^(-1)] - 
     G[{1}, yu^(-1)]*G[{0, 1}, yu^(-1)]^2 + G[{1}, yw]*G[{0, 1}, yu^(-1)]^2 - 
     (Pi^2*G[{0}, yu^(-1)]*G[{0, 1}, yv^(-1)])/3 - 
     (Pi^2*G[{0}, yv^(-1)]*G[{0, 1}, yv^(-1)])/3 + 
     (Pi^2*G[{0}, yw]*G[{0, 1}, yv^(-1)])/3 + 
     (2*Pi^2*G[{1}, yu^(-1)]*G[{0, 1}, yv^(-1)])/3 + 
     G[{0}, yu^(-1)]^2*G[{1}, yu^(-1)]*G[{0, 1}, yv^(-1)] + 
     2*G[{0}, yu^(-1)]*G[{0}, yv^(-1)]*G[{1}, yu^(-1)]*G[{0, 1}, yv^(-1)] + 
     G[{0}, yv^(-1)]^2*G[{1}, yu^(-1)]*G[{0, 1}, yv^(-1)] - 
     2*G[{0}, yu^(-1)]*G[{0}, yw]*G[{1}, yu^(-1)]*G[{0, 1}, yv^(-1)] - 
     2*G[{0}, yv^(-1)]*G[{0}, yw]*G[{1}, yu^(-1)]*G[{0, 1}, yv^(-1)] + 
     G[{0}, yw]^2*G[{1}, yu^(-1)]*G[{0, 1}, yv^(-1)] - 
     2*G[{0}, yu^(-1)]*G[{1}, yu^(-1)]^2*G[{0, 1}, yv^(-1)] - 
     2*G[{0}, yv^(-1)]*G[{1}, yu^(-1)]^2*G[{0, 1}, yv^(-1)] + 
     2*G[{0}, yw]*G[{1}, yu^(-1)]^2*G[{0, 1}, yv^(-1)] + 
     G[{1}, yu^(-1)]^3*G[{0, 1}, yv^(-1)] + 
     (2*Pi^2*G[{1}, yv^(-1)]*G[{0, 1}, yv^(-1)])/3 + 
     G[{0}, yu^(-1)]^2*G[{1}, yv^(-1)]*G[{0, 1}, yv^(-1)] + 
     2*G[{0}, yu^(-1)]*G[{0}, yv^(-1)]*G[{1}, yv^(-1)]*G[{0, 1}, yv^(-1)] + 
     G[{0}, yv^(-1)]^2*G[{1}, yv^(-1)]*G[{0, 1}, yv^(-1)] - 
     2*G[{0}, yu^(-1)]*G[{0}, yw]*G[{1}, yv^(-1)]*G[{0, 1}, yv^(-1)] - 
     2*G[{0}, yv^(-1)]*G[{0}, yw]*G[{1}, yv^(-1)]*G[{0, 1}, yv^(-1)] + 
     G[{0}, yw]^2*G[{1}, yv^(-1)]*G[{0, 1}, yv^(-1)] - 
     2*G[{0}, yu^(-1)]*G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*G[{0, 1}, yv^(-1)] - 
     2*G[{0}, yv^(-1)]*G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*G[{0, 1}, yv^(-1)] + 
     2*G[{0}, yw]*G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*G[{0, 1}, yv^(-1)] + 
     G[{1}, yu^(-1)]^2*G[{1}, yv^(-1)]*G[{0, 1}, yv^(-1)] - 
     G[{0}, yu^(-1)]*G[{1}, yv^(-1)]^2*G[{0, 1}, yv^(-1)] - 
     G[{0}, yv^(-1)]*G[{1}, yv^(-1)]^2*G[{0, 1}, yv^(-1)] + 
     G[{0}, yw]*G[{1}, yv^(-1)]^2*G[{0, 1}, yv^(-1)] + 
     (Pi^2*G[{1}, yw]*G[{0, 1}, yv^(-1)])/3 + G[{0}, yu^(-1)]^2*G[{1}, yw]*
      G[{0, 1}, yv^(-1)] + 2*G[{0}, yu^(-1)]*G[{0}, yv^(-1)]*G[{1}, yw]*
      G[{0, 1}, yv^(-1)] + G[{0}, yv^(-1)]^2*G[{1}, yw]*G[{0, 1}, yv^(-1)] - 
     2*G[{0}, yu^(-1)]*G[{0}, yw]*G[{1}, yw]*G[{0, 1}, yv^(-1)] - 
     2*G[{0}, yv^(-1)]*G[{0}, yw]*G[{1}, yw]*G[{0, 1}, yv^(-1)] + 
     G[{0}, yw]^2*G[{1}, yw]*G[{0, 1}, yv^(-1)] - 
     G[{1}, yu^(-1)]^2*G[{1}, yw]*G[{0, 1}, yv^(-1)] + 
     G[{0}, yu^(-1)]*G[{1}, yw]^2*G[{0, 1}, yv^(-1)] + 
     G[{0}, yv^(-1)]*G[{1}, yw]^2*G[{0, 1}, yv^(-1)] - 
     G[{0}, yw]*G[{1}, yw]^2*G[{0, 1}, yv^(-1)] - 
     (2*Pi^2*G[{1/(yu*yv)}, yw]*G[{0, 1}, yv^(-1)])/3 - 
     G[{0}, yu^(-1)]^2*G[{1/(yu*yv)}, yw]*G[{0, 1}, yv^(-1)] - 
     2*G[{0}, yu^(-1)]*G[{0}, yv^(-1)]*G[{1/(yu*yv)}, yw]*
      G[{0, 1}, yv^(-1)] - G[{0}, yv^(-1)]^2*G[{1/(yu*yv)}, yw]*
      G[{0, 1}, yv^(-1)] + 2*G[{0}, yu^(-1)]*G[{0}, yw]*G[{1/(yu*yv)}, yw]*
      G[{0, 1}, yv^(-1)] + 2*G[{0}, yv^(-1)]*G[{0}, yw]*G[{1/(yu*yv)}, yw]*
      G[{0, 1}, yv^(-1)] - G[{0}, yw]^2*G[{1/(yu*yv)}, yw]*
      G[{0, 1}, yv^(-1)] + 2*G[{0}, yu^(-1)]*G[{1}, yu^(-1)]*
      G[{1/(yu*yv)}, yw]*G[{0, 1}, yv^(-1)] + 2*G[{0}, yv^(-1)]*
      G[{1}, yu^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, 1}, yv^(-1)] - 
     2*G[{0}, yw]*G[{1}, yu^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, 1}, yv^(-1)] - 
     G[{1}, yu^(-1)]^2*G[{1/(yu*yv)}, yw]*G[{0, 1}, yv^(-1)] + 
     2*G[{0}, yu^(-1)]*G[{1}, yv^(-1)]*G[{1/(yu*yv)}, yw]*
      G[{0, 1}, yv^(-1)] + 2*G[{0}, yv^(-1)]*G[{1}, yv^(-1)]*
      G[{1/(yu*yv)}, yw]*G[{0, 1}, yv^(-1)] - 2*G[{0}, yw]*G[{1}, yv^(-1)]*
      G[{1/(yu*yv)}, yw]*G[{0, 1}, yv^(-1)] - G[{0}, yu^(-1)]*
      G[{1/(yu*yv)}, yw]^2*G[{0, 1}, yv^(-1)] - G[{0}, yv^(-1)]*
      G[{1/(yu*yv)}, yw]^2*G[{0, 1}, yv^(-1)] + 
     G[{0}, yw]*G[{1/(yu*yv)}, yw]^2*G[{0, 1}, yv^(-1)] - 
     2*G[{0}, yu^(-1)]*G[{0, 1}, yu^(-1)]*G[{0, 1}, yv^(-1)] - 
     2*G[{0}, yv^(-1)]*G[{0, 1}, yu^(-1)]*G[{0, 1}, yv^(-1)] + 
     2*G[{0}, yw]*G[{0, 1}, yu^(-1)]*G[{0, 1}, yv^(-1)] + 
     2*G[{1}, yu^(-1)]*G[{0, 1}, yu^(-1)]*G[{0, 1}, yv^(-1)] + 
     2*G[{1}, yv^(-1)]*G[{0, 1}, yu^(-1)]*G[{0, 1}, yv^(-1)] - 
     2*G[{1/(yu*yv)}, yw]*G[{0, 1}, yu^(-1)]*G[{0, 1}, yv^(-1)] - 
     G[{1}, yu^(-1)]*G[{0, 1}, yv^(-1)]^2 + G[{1}, yw]*G[{0, 1}, yv^(-1)]^2 - 
     (2*Pi^2*G[{1}, yu^(-1)]*G[{0, 1}, yw])/3 - G[{0}, yu^(-1)]^2*
      G[{1}, yu^(-1)]*G[{0, 1}, yw] - 2*G[{0}, yu^(-1)]*G[{0}, yv^(-1)]*
      G[{1}, yu^(-1)]*G[{0, 1}, yw] - G[{0}, yv^(-1)]^2*G[{1}, yu^(-1)]*
      G[{0, 1}, yw] + 2*G[{0}, yu^(-1)]*G[{0}, yw]*G[{1}, yu^(-1)]*
      G[{0, 1}, yw] + 2*G[{0}, yv^(-1)]*G[{0}, yw]*G[{1}, yu^(-1)]*
      G[{0, 1}, yw] - G[{0}, yw]^2*G[{1}, yu^(-1)]*G[{0, 1}, yw] + 
     2*G[{0}, yu^(-1)]*G[{1}, yu^(-1)]^2*G[{0, 1}, yw] + 
     2*G[{0}, yv^(-1)]*G[{1}, yu^(-1)]^2*G[{0, 1}, yw] - 
     2*G[{0}, yw]*G[{1}, yu^(-1)]^2*G[{0, 1}, yw] - 
     G[{1}, yu^(-1)]^3*G[{0, 1}, yw] + (Pi^2*G[{1}, yv^(-1)]*G[{0, 1}, yw])/
      3 + G[{0}, yu^(-1)]^2*G[{1}, yv^(-1)]*G[{0, 1}, yw] + 
     2*G[{0}, yu^(-1)]*G[{0}, yv^(-1)]*G[{1}, yv^(-1)]*G[{0, 1}, yw] + 
     G[{0}, yv^(-1)]^2*G[{1}, yv^(-1)]*G[{0, 1}, yw] - 
     2*G[{0}, yu^(-1)]*G[{0}, yw]*G[{1}, yv^(-1)]*G[{0, 1}, yw] - 
     2*G[{0}, yv^(-1)]*G[{0}, yw]*G[{1}, yv^(-1)]*G[{0, 1}, yw] + 
     G[{0}, yw]^2*G[{1}, yv^(-1)]*G[{0, 1}, yw] + 
     2*G[{0}, yu^(-1)]*G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*G[{0, 1}, yw] + 
     2*G[{0}, yv^(-1)]*G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*G[{0, 1}, yw] - 
     2*G[{0}, yw]*G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*G[{0, 1}, yw] - 
     3*G[{1}, yu^(-1)]^2*G[{1}, yv^(-1)]*G[{0, 1}, yw] - 
     G[{0}, yu^(-1)]*G[{1}, yv^(-1)]^2*G[{0, 1}, yw] - 
     G[{0}, yv^(-1)]*G[{1}, yv^(-1)]^2*G[{0, 1}, yw] + 
     G[{0}, yw]*G[{1}, yv^(-1)]^2*G[{0, 1}, yw] - 
     3*G[{1}, yu^(-1)]*G[{1}, yv^(-1)]^2*G[{0, 1}, yw] + 
     (2*Pi^2*G[{1}, yw]*G[{0, 1}, yw])/3 + G[{0}, yu^(-1)]^2*G[{1}, yw]*
      G[{0, 1}, yw] + 2*G[{0}, yu^(-1)]*G[{0}, yv^(-1)]*G[{1}, yw]*
      G[{0, 1}, yw] + G[{0}, yv^(-1)]^2*G[{1}, yw]*G[{0, 1}, yw] - 
     2*G[{0}, yu^(-1)]*G[{0}, yw]*G[{1}, yw]*G[{0, 1}, yw] - 
     2*G[{0}, yv^(-1)]*G[{0}, yw]*G[{1}, yw]*G[{0, 1}, yw] + 
     G[{0}, yw]^2*G[{1}, yw]*G[{0, 1}, yw] - 2*G[{0}, yu^(-1)]*
      G[{1}, yu^(-1)]*G[{1}, yw]*G[{0, 1}, yw] - 2*G[{0}, yv^(-1)]*
      G[{1}, yu^(-1)]*G[{1}, yw]*G[{0, 1}, yw] + 2*G[{0}, yw]*G[{1}, yu^(-1)]*
      G[{1}, yw]*G[{0, 1}, yw] + G[{1}, yu^(-1)]^2*G[{1}, yw]*G[{0, 1}, yw] + 
     2*G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*G[{1}, yw]*G[{0, 1}, yw] + 
     G[{0}, yu^(-1)]*G[{1}, yw]^2*G[{0, 1}, yw] + 
     G[{0}, yv^(-1)]*G[{1}, yw]^2*G[{0, 1}, yw] - G[{0}, yw]*G[{1}, yw]^2*
      G[{0, 1}, yw] + (Pi^2*G[{yu}, yv^(-1)]*G[{0, 1}, yw])/3 - 
     2*G[{0}, yu^(-1)]*G[{1}, yu^(-1)]*G[{yu}, yv^(-1)]*G[{0, 1}, yw] - 
     2*G[{0}, yv^(-1)]*G[{1}, yu^(-1)]*G[{yu}, yv^(-1)]*G[{0, 1}, yw] + 
     2*G[{0}, yw]*G[{1}, yu^(-1)]*G[{yu}, yv^(-1)]*G[{0, 1}, yw] + 
     2*G[{1}, yu^(-1)]^2*G[{yu}, yv^(-1)]*G[{0, 1}, yw] - 
     2*G[{0}, yu^(-1)]*G[{1}, yv^(-1)]*G[{yu}, yv^(-1)]*G[{0, 1}, yw] - 
     2*G[{0}, yv^(-1)]*G[{1}, yv^(-1)]*G[{yu}, yv^(-1)]*G[{0, 1}, yw] + 
     2*G[{0}, yw]*G[{1}, yv^(-1)]*G[{yu}, yv^(-1)]*G[{0, 1}, yw] + 
     8*G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*G[{yu}, yv^(-1)]*G[{0, 1}, yw] + 
     2*G[{1}, yv^(-1)]^2*G[{yu}, yv^(-1)]*G[{0, 1}, yw] - 
     2*G[{0}, yu^(-1)]*G[{1}, yw]*G[{yu}, yv^(-1)]*G[{0, 1}, yw] - 
     2*G[{0}, yv^(-1)]*G[{1}, yw]*G[{yu}, yv^(-1)]*G[{0, 1}, yw] + 
     2*G[{0}, yw]*G[{1}, yw]*G[{yu}, yv^(-1)]*G[{0, 1}, yw] - 
     2*G[{1}, yw]^2*G[{yu}, yv^(-1)]*G[{0, 1}, yw] + 
     2*G[{0}, yu^(-1)]*G[{yu}, yv^(-1)]^2*G[{0, 1}, yw] + 
     2*G[{0}, yv^(-1)]*G[{yu}, yv^(-1)]^2*G[{0, 1}, yw] - 
     2*G[{0}, yw]*G[{yu}, yv^(-1)]^2*G[{0, 1}, yw] - 
     4*G[{1}, yu^(-1)]*G[{yu}, yv^(-1)]^2*G[{0, 1}, yw] - 
     4*G[{1}, yv^(-1)]*G[{yu}, yv^(-1)]^2*G[{0, 1}, yw] + 
     2*G[{1}, yw]*G[{yu}, yv^(-1)]^2*G[{0, 1}, yw] + 
     (4*G[{yu}, yv^(-1)]^3*G[{0, 1}, yw])/3 - 
     (Pi^2*G[{1/(yu*yv)}, yw]*G[{0, 1}, yw])/3 - G[{0}, yu^(-1)]^2*
      G[{1/(yu*yv)}, yw]*G[{0, 1}, yw] - 2*G[{0}, yu^(-1)]*G[{0}, yv^(-1)]*
      G[{1/(yu*yv)}, yw]*G[{0, 1}, yw] - G[{0}, yv^(-1)]^2*G[{1/(yu*yv)}, yw]*
      G[{0, 1}, yw] + 2*G[{0}, yu^(-1)]*G[{0}, yw]*G[{1/(yu*yv)}, yw]*
      G[{0, 1}, yw] + 2*G[{0}, yv^(-1)]*G[{0}, yw]*G[{1/(yu*yv)}, yw]*
      G[{0, 1}, yw] - G[{0}, yw]^2*G[{1/(yu*yv)}, yw]*G[{0, 1}, yw] + 
     G[{1}, yu^(-1)]^2*G[{1/(yu*yv)}, yw]*G[{0, 1}, yw] + 
     2*G[{0}, yu^(-1)]*G[{1}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, 1}, yw] + 
     2*G[{0}, yv^(-1)]*G[{1}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, 1}, yw] - 
     2*G[{0}, yw]*G[{1}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, 1}, yw] + 
     2*G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, 1}, yw] + 
     2*G[{0}, yu^(-1)]*G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, 1}, yw] + 
     2*G[{0}, yv^(-1)]*G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, 1}, yw] - 
     2*G[{0}, yw]*G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, 1}, yw] - 
     4*G[{1}, yu^(-1)]*G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, 1}, yw] - 
     4*G[{1}, yv^(-1)]*G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, 1}, yw] + 
     2*G[{yu}, yv^(-1)]^2*G[{1/(yu*yv)}, yw]*G[{0, 1}, yw] - 
     G[{0}, yu^(-1)]*G[{1/(yu*yv)}, yw]^2*G[{0, 1}, yw] - 
     G[{0}, yv^(-1)]*G[{1/(yu*yv)}, yw]^2*G[{0, 1}, yw] + 
     G[{0}, yw]*G[{1/(yu*yv)}, yw]^2*G[{0, 1}, yw] + 
     2*G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw]^2*G[{0, 1}, yw] - 
     2*G[{1}, yu^(-1)]*G[{0, 1}, yu^(-1)]*G[{0, 1}, yw] + 
     2*G[{1}, yw]*G[{0, 1}, yu^(-1)]*G[{0, 1}, yw] + 
     2*G[{yu}, yv^(-1)]*G[{0, 1}, yu^(-1)]*G[{0, 1}, yw] - 
     2*G[{0}, yu^(-1)]*G[{0, 1}, yv^(-1)]*G[{0, 1}, yw] - 
     2*G[{0}, yv^(-1)]*G[{0, 1}, yv^(-1)]*G[{0, 1}, yw] + 
     2*G[{0}, yw]*G[{0, 1}, yv^(-1)]*G[{0, 1}, yw] + 
     2*G[{1}, yu^(-1)]*G[{0, 1}, yv^(-1)]*G[{0, 1}, yw] + 
     2*G[{1}, yv^(-1)]*G[{0, 1}, yv^(-1)]*G[{0, 1}, yw] + 
     2*G[{yu}, yv^(-1)]*G[{0, 1}, yv^(-1)]*G[{0, 1}, yw] - 
     2*G[{1/(yu*yv)}, yw]*G[{0, 1}, yv^(-1)]*G[{0, 1}, yw] - 
     G[{0}, yu^(-1)]*G[{0, 1}, yw]^2 - G[{0}, yv^(-1)]*G[{0, 1}, yw]^2 + 
     G[{0}, yw]*G[{0, 1}, yw]^2 + G[{1}, yu^(-1)]*G[{0, 1}, yw]^2 + 
     2*G[{1}, yv^(-1)]*G[{0, 1}, yw]^2 - G[{yu}, yv^(-1)]*G[{0, 1}, yw]^2 - 
     G[{1/(yu*yv)}, yw]*G[{0, 1}, yw]^2 + 
     (Pi^2*G[{0}, yu^(-1)]*G[{0, yu^(-1)}, yw])/3 + 
     (Pi^2*G[{0}, yv^(-1)]*G[{0, yu^(-1)}, yw])/3 - 
     (Pi^2*G[{0}, yw]*G[{0, yu^(-1)}, yw])/3 + 
     (Pi^2*G[{1}, yu^(-1)]*G[{0, yu^(-1)}, yw])/3 + 
     G[{0}, yu^(-1)]^2*G[{1}, yu^(-1)]*G[{0, yu^(-1)}, yw] + 
     2*G[{0}, yu^(-1)]*G[{0}, yv^(-1)]*G[{1}, yu^(-1)]*G[{0, yu^(-1)}, yw] + 
     G[{0}, yv^(-1)]^2*G[{1}, yu^(-1)]*G[{0, yu^(-1)}, yw] - 
     2*G[{0}, yu^(-1)]*G[{0}, yw]*G[{1}, yu^(-1)]*G[{0, yu^(-1)}, yw] - 
     2*G[{0}, yv^(-1)]*G[{0}, yw]*G[{1}, yu^(-1)]*G[{0, yu^(-1)}, yw] + 
     G[{0}, yw]^2*G[{1}, yu^(-1)]*G[{0, yu^(-1)}, yw] - 
     2*G[{0}, yu^(-1)]*G[{1}, yu^(-1)]^2*G[{0, yu^(-1)}, yw] - 
     2*G[{0}, yv^(-1)]*G[{1}, yu^(-1)]^2*G[{0, yu^(-1)}, yw] + 
     2*G[{0}, yw]*G[{1}, yu^(-1)]^2*G[{0, yu^(-1)}, yw] + 
     G[{1}, yu^(-1)]^3*G[{0, yu^(-1)}, yw] - Pi^2*G[{1}, yv^(-1)]*
      G[{0, yu^(-1)}, yw] - G[{0}, yu^(-1)]^2*G[{1}, yv^(-1)]*
      G[{0, yu^(-1)}, yw] - 2*G[{0}, yu^(-1)]*G[{0}, yv^(-1)]*G[{1}, yv^(-1)]*
      G[{0, yu^(-1)}, yw] - G[{0}, yv^(-1)]^2*G[{1}, yv^(-1)]*
      G[{0, yu^(-1)}, yw] + 2*G[{0}, yu^(-1)]*G[{0}, yw]*G[{1}, yv^(-1)]*
      G[{0, yu^(-1)}, yw] + 2*G[{0}, yv^(-1)]*G[{0}, yw]*G[{1}, yv^(-1)]*
      G[{0, yu^(-1)}, yw] - G[{0}, yw]^2*G[{1}, yv^(-1)]*
      G[{0, yu^(-1)}, yw] + G[{1}, yu^(-1)]^2*G[{1}, yv^(-1)]*
      G[{0, yu^(-1)}, yw] + 3*G[{0}, yu^(-1)]*G[{1}, yv^(-1)]^2*
      G[{0, yu^(-1)}, yw] + 3*G[{0}, yv^(-1)]*G[{1}, yv^(-1)]^2*
      G[{0, yu^(-1)}, yw] - 3*G[{0}, yw]*G[{1}, yv^(-1)]^2*
      G[{0, yu^(-1)}, yw] - 3*G[{1}, yu^(-1)]*G[{1}, yv^(-1)]^2*
      G[{0, yu^(-1)}, yw] - 2*G[{1}, yv^(-1)]^3*G[{0, yu^(-1)}, yw] - 
     (Pi^2*G[{1}, yw]*G[{0, yu^(-1)}, yw])/3 - G[{0}, yu^(-1)]^2*G[{1}, yw]*
      G[{0, yu^(-1)}, yw] - 2*G[{0}, yu^(-1)]*G[{0}, yv^(-1)]*G[{1}, yw]*
      G[{0, yu^(-1)}, yw] - G[{0}, yv^(-1)]^2*G[{1}, yw]*
      G[{0, yu^(-1)}, yw] + 2*G[{0}, yu^(-1)]*G[{0}, yw]*G[{1}, yw]*
      G[{0, yu^(-1)}, yw] + 2*G[{0}, yv^(-1)]*G[{0}, yw]*G[{1}, yw]*
      G[{0, yu^(-1)}, yw] - G[{0}, yw]^2*G[{1}, yw]*G[{0, yu^(-1)}, yw] + 
     2*G[{0}, yu^(-1)]*G[{1}, yu^(-1)]*G[{1}, yw]*G[{0, yu^(-1)}, yw] + 
     2*G[{0}, yv^(-1)]*G[{1}, yu^(-1)]*G[{1}, yw]*G[{0, yu^(-1)}, yw] - 
     2*G[{0}, yw]*G[{1}, yu^(-1)]*G[{1}, yw]*G[{0, yu^(-1)}, yw] - 
     G[{1}, yu^(-1)]^2*G[{1}, yw]*G[{0, yu^(-1)}, yw] + 
     2*G[{0}, yu^(-1)]*G[{1}, yv^(-1)]*G[{1}, yw]*G[{0, yu^(-1)}, yw] + 
     2*G[{0}, yv^(-1)]*G[{1}, yv^(-1)]*G[{1}, yw]*G[{0, yu^(-1)}, yw] - 
     2*G[{0}, yw]*G[{1}, yv^(-1)]*G[{1}, yw]*G[{0, yu^(-1)}, yw] - 
     2*G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*G[{1}, yw]*G[{0, yu^(-1)}, yw] - 
     G[{0}, yu^(-1)]*G[{1}, yw]^2*G[{0, yu^(-1)}, yw] - 
     G[{0}, yv^(-1)]*G[{1}, yw]^2*G[{0, yu^(-1)}, yw] + 
     G[{0}, yw]*G[{1}, yw]^2*G[{0, yu^(-1)}, yw] + 
     2*G[{1}, yv^(-1)]*G[{1}, yw]^2*G[{0, yu^(-1)}, yw] + 
     (2*Pi^2*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1)}, yw])/3 + 
     G[{0}, yu^(-1)]^2*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1)}, yw] + 
     2*G[{0}, yu^(-1)]*G[{0}, yv^(-1)]*G[{1/(yu*yv)}, yw]*
      G[{0, yu^(-1)}, yw] + G[{0}, yv^(-1)]^2*G[{1/(yu*yv)}, yw]*
      G[{0, yu^(-1)}, yw] - 2*G[{0}, yu^(-1)]*G[{0}, yw]*G[{1/(yu*yv)}, yw]*
      G[{0, yu^(-1)}, yw] - 2*G[{0}, yv^(-1)]*G[{0}, yw]*G[{1/(yu*yv)}, yw]*
      G[{0, yu^(-1)}, yw] + G[{0}, yw]^2*G[{1/(yu*yv)}, yw]*
      G[{0, yu^(-1)}, yw] - G[{1}, yu^(-1)]^2*G[{1/(yu*yv)}, yw]*
      G[{0, yu^(-1)}, yw] - 4*G[{0}, yu^(-1)]*G[{1}, yv^(-1)]*
      G[{1/(yu*yv)}, yw]*G[{0, yu^(-1)}, yw] - 4*G[{0}, yv^(-1)]*
      G[{1}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1)}, yw] + 
     4*G[{0}, yw]*G[{1}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1)}, yw] + 
     2*G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*G[{1/(yu*yv)}, yw]*
      G[{0, yu^(-1)}, yw] + 4*G[{1}, yv^(-1)]^2*G[{1/(yu*yv)}, yw]*
      G[{0, yu^(-1)}, yw] + G[{0}, yu^(-1)]*G[{1/(yu*yv)}, yw]^2*
      G[{0, yu^(-1)}, yw] + G[{0}, yv^(-1)]*G[{1/(yu*yv)}, yw]^2*
      G[{0, yu^(-1)}, yw] - G[{0}, yw]*G[{1/(yu*yv)}, yw]^2*
      G[{0, yu^(-1)}, yw] - 2*G[{1}, yv^(-1)]*G[{1/(yu*yv)}, yw]^2*
      G[{0, yu^(-1)}, yw] + 2*G[{0}, yu^(-1)]*G[{0, 1}, yu^(-1)]*
      G[{0, yu^(-1)}, yw] + 2*G[{0}, yv^(-1)]*G[{0, 1}, yu^(-1)]*
      G[{0, yu^(-1)}, yw] - 2*G[{0}, yw]*G[{0, 1}, yu^(-1)]*
      G[{0, yu^(-1)}, yw] - 4*G[{1}, yv^(-1)]*G[{0, 1}, yu^(-1)]*
      G[{0, yu^(-1)}, yw] + 2*G[{1/(yu*yv)}, yw]*G[{0, 1}, yu^(-1)]*
      G[{0, yu^(-1)}, yw] - 2*G[{1}, yv^(-1)]*G[{0, 1}, yv^(-1)]*
      G[{0, yu^(-1)}, yw] - 2*G[{1}, yw]*G[{0, 1}, yv^(-1)]*
      G[{0, yu^(-1)}, yw] - 2*G[{1}, yw]*G[{0, 1}, yw]*G[{0, yu^(-1)}, yw] + 
     G[{1}, yw]*G[{0, yu^(-1)}, yw]^2 - 
     (Pi^2*G[{1}, yu^(-1)]*G[{0, yu}, yv^(-1)])/3 - 
     G[{0}, yu^(-1)]^2*G[{1}, yu^(-1)]*G[{0, yu}, yv^(-1)] - 
     2*G[{0}, yu^(-1)]*G[{0}, yv^(-1)]*G[{1}, yu^(-1)]*G[{0, yu}, yv^(-1)] - 
     G[{0}, yv^(-1)]^2*G[{1}, yu^(-1)]*G[{0, yu}, yv^(-1)] + 
     2*G[{0}, yu^(-1)]*G[{0}, yw]*G[{1}, yu^(-1)]*G[{0, yu}, yv^(-1)] + 
     2*G[{0}, yv^(-1)]*G[{0}, yw]*G[{1}, yu^(-1)]*G[{0, yu}, yv^(-1)] - 
     G[{0}, yw]^2*G[{1}, yu^(-1)]*G[{0, yu}, yv^(-1)] + 
     2*G[{0}, yu^(-1)]*G[{1}, yu^(-1)]^2*G[{0, yu}, yv^(-1)] + 
     2*G[{0}, yv^(-1)]*G[{1}, yu^(-1)]^2*G[{0, yu}, yv^(-1)] - 
     2*G[{0}, yw]*G[{1}, yu^(-1)]^2*G[{0, yu}, yv^(-1)] - 
     G[{1}, yu^(-1)]^3*G[{0, yu}, yv^(-1)] - 
     (Pi^2*G[{1}, yv^(-1)]*G[{0, yu}, yv^(-1)])/3 - 
     G[{0}, yu^(-1)]^2*G[{1}, yv^(-1)]*G[{0, yu}, yv^(-1)] - 
     2*G[{0}, yu^(-1)]*G[{0}, yv^(-1)]*G[{1}, yv^(-1)]*G[{0, yu}, yv^(-1)] - 
     G[{0}, yv^(-1)]^2*G[{1}, yv^(-1)]*G[{0, yu}, yv^(-1)] + 
     2*G[{0}, yu^(-1)]*G[{0}, yw]*G[{1}, yv^(-1)]*G[{0, yu}, yv^(-1)] + 
     2*G[{0}, yv^(-1)]*G[{0}, yw]*G[{1}, yv^(-1)]*G[{0, yu}, yv^(-1)] - 
     G[{0}, yw]^2*G[{1}, yv^(-1)]*G[{0, yu}, yv^(-1)] + 
     2*G[{0}, yu^(-1)]*G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*G[{0, yu}, yv^(-1)] + 
     2*G[{0}, yv^(-1)]*G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*G[{0, yu}, yv^(-1)] - 
     2*G[{0}, yw]*G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*G[{0, yu}, yv^(-1)] - 
     G[{1}, yu^(-1)]^2*G[{1}, yv^(-1)]*G[{0, yu}, yv^(-1)] + 
     G[{0}, yu^(-1)]*G[{1}, yv^(-1)]^2*G[{0, yu}, yv^(-1)] + 
     G[{0}, yv^(-1)]*G[{1}, yv^(-1)]^2*G[{0, yu}, yv^(-1)] - 
     G[{0}, yw]*G[{1}, yv^(-1)]^2*G[{0, yu}, yv^(-1)] - 
     (2*Pi^2*G[{1}, yw]*G[{0, yu}, yv^(-1)])/3 - G[{0}, yu^(-1)]^2*G[{1}, yw]*
      G[{0, yu}, yv^(-1)] - 2*G[{0}, yu^(-1)]*G[{0}, yv^(-1)]*G[{1}, yw]*
      G[{0, yu}, yv^(-1)] - G[{0}, yv^(-1)]^2*G[{1}, yw]*
      G[{0, yu}, yv^(-1)] + 2*G[{0}, yu^(-1)]*G[{0}, yw]*G[{1}, yw]*
      G[{0, yu}, yv^(-1)] + 2*G[{0}, yv^(-1)]*G[{0}, yw]*G[{1}, yw]*
      G[{0, yu}, yv^(-1)] - G[{0}, yw]^2*G[{1}, yw]*G[{0, yu}, yv^(-1)] + 
     G[{1}, yu^(-1)]^2*G[{1}, yw]*G[{0, yu}, yv^(-1)] - 
     G[{0}, yu^(-1)]*G[{1}, yw]^2*G[{0, yu}, yv^(-1)] - 
     G[{0}, yv^(-1)]*G[{1}, yw]^2*G[{0, yu}, yv^(-1)] + 
     G[{0}, yw]*G[{1}, yw]^2*G[{0, yu}, yv^(-1)] + 
     (Pi^2*G[{1/(yu*yv)}, yw]*G[{0, yu}, yv^(-1)])/3 + 
     G[{0}, yu^(-1)]^2*G[{1/(yu*yv)}, yw]*G[{0, yu}, yv^(-1)] + 
     2*G[{0}, yu^(-1)]*G[{0}, yv^(-1)]*G[{1/(yu*yv)}, yw]*
      G[{0, yu}, yv^(-1)] + G[{0}, yv^(-1)]^2*G[{1/(yu*yv)}, yw]*
      G[{0, yu}, yv^(-1)] - 2*G[{0}, yu^(-1)]*G[{0}, yw]*G[{1/(yu*yv)}, yw]*
      G[{0, yu}, yv^(-1)] - 2*G[{0}, yv^(-1)]*G[{0}, yw]*G[{1/(yu*yv)}, yw]*
      G[{0, yu}, yv^(-1)] + G[{0}, yw]^2*G[{1/(yu*yv)}, yw]*
      G[{0, yu}, yv^(-1)] - 2*G[{0}, yu^(-1)]*G[{1}, yu^(-1)]*
      G[{1/(yu*yv)}, yw]*G[{0, yu}, yv^(-1)] - 2*G[{0}, yv^(-1)]*
      G[{1}, yu^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, yu}, yv^(-1)] + 
     2*G[{0}, yw]*G[{1}, yu^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, yu}, yv^(-1)] + 
     G[{1}, yu^(-1)]^2*G[{1/(yu*yv)}, yw]*G[{0, yu}, yv^(-1)] - 
     2*G[{0}, yu^(-1)]*G[{1}, yv^(-1)]*G[{1/(yu*yv)}, yw]*
      G[{0, yu}, yv^(-1)] - 2*G[{0}, yv^(-1)]*G[{1}, yv^(-1)]*
      G[{1/(yu*yv)}, yw]*G[{0, yu}, yv^(-1)] + 2*G[{0}, yw]*G[{1}, yv^(-1)]*
      G[{1/(yu*yv)}, yw]*G[{0, yu}, yv^(-1)] + G[{0}, yu^(-1)]*
      G[{1/(yu*yv)}, yw]^2*G[{0, yu}, yv^(-1)] + 
     G[{0}, yv^(-1)]*G[{1/(yu*yv)}, yw]^2*G[{0, yu}, yv^(-1)] - 
     G[{0}, yw]*G[{1/(yu*yv)}, yw]^2*G[{0, yu}, yv^(-1)] - 
     2*G[{1}, yw]*G[{0, 1}, yu^(-1)]*G[{0, yu}, yv^(-1)] + 
     2*G[{0}, yu^(-1)]*G[{0, 1}, yv^(-1)]*G[{0, yu}, yv^(-1)] + 
     2*G[{0}, yv^(-1)]*G[{0, 1}, yv^(-1)]*G[{0, yu}, yv^(-1)] - 
     2*G[{0}, yw]*G[{0, 1}, yv^(-1)]*G[{0, yu}, yv^(-1)] - 
     2*G[{1}, yv^(-1)]*G[{0, 1}, yv^(-1)]*G[{0, yu}, yv^(-1)] + 
     2*G[{1/(yu*yv)}, yw]*G[{0, 1}, yv^(-1)]*G[{0, yu}, yv^(-1)] + 
     2*G[{0}, yu^(-1)]*G[{0, 1}, yw]*G[{0, yu}, yv^(-1)] + 
     2*G[{0}, yv^(-1)]*G[{0, 1}, yw]*G[{0, yu}, yv^(-1)] - 
     2*G[{0}, yw]*G[{0, 1}, yw]*G[{0, yu}, yv^(-1)] - 
     2*G[{1}, yu^(-1)]*G[{0, 1}, yw]*G[{0, yu}, yv^(-1)] - 
     2*G[{1}, yv^(-1)]*G[{0, 1}, yw]*G[{0, yu}, yv^(-1)] - 
     2*G[{yu}, yv^(-1)]*G[{0, 1}, yw]*G[{0, yu}, yv^(-1)] + 
     2*G[{1/(yu*yv)}, yw]*G[{0, 1}, yw]*G[{0, yu}, yv^(-1)] + 
     2*G[{1}, yv^(-1)]*G[{0, yu^(-1)}, yw]*G[{0, yu}, yv^(-1)] + 
     2*G[{1}, yw]*G[{0, yu^(-1)}, yw]*G[{0, yu}, yv^(-1)] - 
     G[{0}, yu^(-1)]*G[{0, yu}, yv^(-1)]^2 - G[{0}, yv^(-1)]*
      G[{0, yu}, yv^(-1)]^2 + G[{0}, yw]*G[{0, yu}, yv^(-1)]^2 + 
     G[{1}, yv^(-1)]*G[{0, yu}, yv^(-1)]^2 - G[{1/(yu*yv)}, yw]*
      G[{0, yu}, yv^(-1)]^2 + (Pi^2*G[{1}, yu^(-1)]*G[{0, yv^(-1)}, yw])/3 + 
     G[{0}, yu^(-1)]^2*G[{1}, yu^(-1)]*G[{0, yv^(-1)}, yw] + 
     2*G[{0}, yu^(-1)]*G[{0}, yv^(-1)]*G[{1}, yu^(-1)]*G[{0, yv^(-1)}, yw] + 
     G[{0}, yv^(-1)]^2*G[{1}, yu^(-1)]*G[{0, yv^(-1)}, yw] - 
     2*G[{0}, yu^(-1)]*G[{0}, yw]*G[{1}, yu^(-1)]*G[{0, yv^(-1)}, yw] - 
     2*G[{0}, yv^(-1)]*G[{0}, yw]*G[{1}, yu^(-1)]*G[{0, yv^(-1)}, yw] + 
     G[{0}, yw]^2*G[{1}, yu^(-1)]*G[{0, yv^(-1)}, yw] - 
     2*G[{0}, yu^(-1)]*G[{1}, yu^(-1)]^2*G[{0, yv^(-1)}, yw] - 
     2*G[{0}, yv^(-1)]*G[{1}, yu^(-1)]^2*G[{0, yv^(-1)}, yw] + 
     2*G[{0}, yw]*G[{1}, yu^(-1)]^2*G[{0, yv^(-1)}, yw] + 
     G[{1}, yu^(-1)]^3*G[{0, yv^(-1)}, yw] - 
     (Pi^2*G[{1}, yv^(-1)]*G[{0, yv^(-1)}, yw])/3 - 
     G[{0}, yu^(-1)]^2*G[{1}, yv^(-1)]*G[{0, yv^(-1)}, yw] - 
     2*G[{0}, yu^(-1)]*G[{0}, yv^(-1)]*G[{1}, yv^(-1)]*G[{0, yv^(-1)}, yw] - 
     G[{0}, yv^(-1)]^2*G[{1}, yv^(-1)]*G[{0, yv^(-1)}, yw] + 
     2*G[{0}, yu^(-1)]*G[{0}, yw]*G[{1}, yv^(-1)]*G[{0, yv^(-1)}, yw] + 
     2*G[{0}, yv^(-1)]*G[{0}, yw]*G[{1}, yv^(-1)]*G[{0, yv^(-1)}, yw] - 
     G[{0}, yw]^2*G[{1}, yv^(-1)]*G[{0, yv^(-1)}, yw] + 
     G[{1}, yu^(-1)]^2*G[{1}, yv^(-1)]*G[{0, yv^(-1)}, yw] + 
     G[{0}, yu^(-1)]*G[{1}, yv^(-1)]^2*G[{0, yv^(-1)}, yw] + 
     G[{0}, yv^(-1)]*G[{1}, yv^(-1)]^2*G[{0, yv^(-1)}, yw] - 
     G[{0}, yw]*G[{1}, yv^(-1)]^2*G[{0, yv^(-1)}, yw] + 
     G[{1}, yu^(-1)]*G[{1}, yv^(-1)]^2*G[{0, yv^(-1)}, yw] - 
     (2*Pi^2*G[{1}, yw]*G[{0, yv^(-1)}, yw])/3 - G[{0}, yu^(-1)]^2*G[{1}, yw]*
      G[{0, yv^(-1)}, yw] - 2*G[{0}, yu^(-1)]*G[{0}, yv^(-1)]*G[{1}, yw]*
      G[{0, yv^(-1)}, yw] - G[{0}, yv^(-1)]^2*G[{1}, yw]*
      G[{0, yv^(-1)}, yw] + 2*G[{0}, yu^(-1)]*G[{0}, yw]*G[{1}, yw]*
      G[{0, yv^(-1)}, yw] + 2*G[{0}, yv^(-1)]*G[{0}, yw]*G[{1}, yw]*
      G[{0, yv^(-1)}, yw] - G[{0}, yw]^2*G[{1}, yw]*G[{0, yv^(-1)}, yw] + 
     4*G[{0}, yu^(-1)]*G[{1}, yu^(-1)]*G[{1}, yw]*G[{0, yv^(-1)}, yw] + 
     4*G[{0}, yv^(-1)]*G[{1}, yu^(-1)]*G[{1}, yw]*G[{0, yv^(-1)}, yw] - 
     4*G[{0}, yw]*G[{1}, yu^(-1)]*G[{1}, yw]*G[{0, yv^(-1)}, yw] - 
     3*G[{1}, yu^(-1)]^2*G[{1}, yw]*G[{0, yv^(-1)}, yw] - 
     2*G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*G[{1}, yw]*G[{0, yv^(-1)}, yw] - 
     G[{0}, yu^(-1)]*G[{1}, yw]^2*G[{0, yv^(-1)}, yw] - 
     G[{0}, yv^(-1)]*G[{1}, yw]^2*G[{0, yv^(-1)}, yw] + 
     G[{0}, yw]*G[{1}, yw]^2*G[{0, yv^(-1)}, yw] + 
     2*G[{1}, yu^(-1)]*G[{1}, yw]^2*G[{0, yv^(-1)}, yw] + 
     (Pi^2*G[{1/(yu*yv)}, yw]*G[{0, yv^(-1)}, yw])/3 + 
     G[{0}, yu^(-1)]^2*G[{1/(yu*yv)}, yw]*G[{0, yv^(-1)}, yw] + 
     2*G[{0}, yu^(-1)]*G[{0}, yv^(-1)]*G[{1/(yu*yv)}, yw]*
      G[{0, yv^(-1)}, yw] + G[{0}, yv^(-1)]^2*G[{1/(yu*yv)}, yw]*
      G[{0, yv^(-1)}, yw] - 2*G[{0}, yu^(-1)]*G[{0}, yw]*G[{1/(yu*yv)}, yw]*
      G[{0, yv^(-1)}, yw] - 2*G[{0}, yv^(-1)]*G[{0}, yw]*G[{1/(yu*yv)}, yw]*
      G[{0, yv^(-1)}, yw] + G[{0}, yw]^2*G[{1/(yu*yv)}, yw]*
      G[{0, yv^(-1)}, yw] - 2*G[{0}, yu^(-1)]*G[{1}, yu^(-1)]*
      G[{1/(yu*yv)}, yw]*G[{0, yv^(-1)}, yw] - 2*G[{0}, yv^(-1)]*
      G[{1}, yu^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, yv^(-1)}, yw] + 
     2*G[{0}, yw]*G[{1}, yu^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, yv^(-1)}, yw] + 
     G[{1}, yu^(-1)]^2*G[{1/(yu*yv)}, yw]*G[{0, yv^(-1)}, yw] - 
     2*G[{0}, yu^(-1)]*G[{1}, yv^(-1)]*G[{1/(yu*yv)}, yw]*
      G[{0, yv^(-1)}, yw] - 2*G[{0}, yv^(-1)]*G[{1}, yv^(-1)]*
      G[{1/(yu*yv)}, yw]*G[{0, yv^(-1)}, yw] + 2*G[{0}, yw]*G[{1}, yv^(-1)]*
      G[{1/(yu*yv)}, yw]*G[{0, yv^(-1)}, yw] + 2*G[{1}, yu^(-1)]*
      G[{1}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, yv^(-1)}, yw] + 
     G[{0}, yu^(-1)]*G[{1/(yu*yv)}, yw]^2*G[{0, yv^(-1)}, yw] + 
     G[{0}, yv^(-1)]*G[{1/(yu*yv)}, yw]^2*G[{0, yv^(-1)}, yw] - 
     G[{0}, yw]*G[{1/(yu*yv)}, yw]^2*G[{0, yv^(-1)}, yw] - 
     2*G[{1}, yu^(-1)]*G[{1/(yu*yv)}, yw]^2*G[{0, yv^(-1)}, yw] - 
     2*G[{1}, yw]*G[{0, 1}, yu^(-1)]*G[{0, yv^(-1)}, yw] + 
     2*G[{0}, yu^(-1)]*G[{0, 1}, yv^(-1)]*G[{0, yv^(-1)}, yw] + 
     2*G[{0}, yv^(-1)]*G[{0, 1}, yv^(-1)]*G[{0, yv^(-1)}, yw] - 
     2*G[{0}, yw]*G[{0, 1}, yv^(-1)]*G[{0, yv^(-1)}, yw] - 
     4*G[{1}, yu^(-1)]*G[{0, 1}, yv^(-1)]*G[{0, yv^(-1)}, yw] - 
     2*G[{1}, yv^(-1)]*G[{0, 1}, yv^(-1)]*G[{0, yv^(-1)}, yw] + 
     2*G[{1/(yu*yv)}, yw]*G[{0, 1}, yv^(-1)]*G[{0, yv^(-1)}, yw] + 
     2*G[{0}, yu^(-1)]*G[{0, 1}, yw]*G[{0, yv^(-1)}, yw] + 
     2*G[{0}, yv^(-1)]*G[{0, 1}, yw]*G[{0, yv^(-1)}, yw] - 
     2*G[{0}, yw]*G[{0, 1}, yw]*G[{0, yv^(-1)}, yw] - 
     4*G[{1}, yv^(-1)]*G[{0, 1}, yw]*G[{0, yv^(-1)}, yw] + 
     2*G[{1/(yu*yv)}, yw]*G[{0, 1}, yw]*G[{0, yv^(-1)}, yw] - 
     2*G[{0}, yu^(-1)]*G[{0, yu^(-1)}, yw]*G[{0, yv^(-1)}, yw] - 
     2*G[{0}, yv^(-1)]*G[{0, yu^(-1)}, yw]*G[{0, yv^(-1)}, yw] + 
     2*G[{0}, yw]*G[{0, yu^(-1)}, yw]*G[{0, yv^(-1)}, yw] + 
     4*G[{1}, yv^(-1)]*G[{0, yu^(-1)}, yw]*G[{0, yv^(-1)}, yw] - 
     2*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1)}, yw]*G[{0, yv^(-1)}, yw] - 
     2*G[{0}, yu^(-1)]*G[{0, yu}, yv^(-1)]*G[{0, yv^(-1)}, yw] - 
     2*G[{0}, yv^(-1)]*G[{0, yu}, yv^(-1)]*G[{0, yv^(-1)}, yw] + 
     2*G[{0}, yw]*G[{0, yu}, yv^(-1)]*G[{0, yv^(-1)}, yw] + 
     4*G[{1}, yu^(-1)]*G[{0, yu}, yv^(-1)]*G[{0, yv^(-1)}, yw] + 
     2*G[{1}, yv^(-1)]*G[{0, yu}, yv^(-1)]*G[{0, yv^(-1)}, yw] - 
     2*G[{1/(yu*yv)}, yw]*G[{0, yu}, yv^(-1)]*G[{0, yv^(-1)}, yw] - 
     G[{0}, yu^(-1)]*G[{0, yv^(-1)}, yw]^2 - G[{0}, yv^(-1)]*
      G[{0, yv^(-1)}, yw]^2 + G[{0}, yw]*G[{0, yv^(-1)}, yw]^2 + 
     2*G[{1}, yv^(-1)]*G[{0, yv^(-1)}, yw]^2 - G[{1/(yu*yv)}, yw]*
      G[{0, yv^(-1)}, yw]^2 - (Pi^2*G[{0}, yu^(-1)]*G[{0, 1/(yu*yv)}, yw])/
      3 - (Pi^2*G[{0}, yv^(-1)]*G[{0, 1/(yu*yv)}, yw])/3 + 
     (Pi^2*G[{0}, yw]*G[{0, 1/(yu*yv)}, yw])/3 - G[{0}, yu^(-1)]^2*
      G[{1}, yu^(-1)]*G[{0, 1/(yu*yv)}, yw] - 2*G[{0}, yu^(-1)]*
      G[{0}, yv^(-1)]*G[{1}, yu^(-1)]*G[{0, 1/(yu*yv)}, yw] - 
     G[{0}, yv^(-1)]^2*G[{1}, yu^(-1)]*G[{0, 1/(yu*yv)}, yw] + 
     2*G[{0}, yu^(-1)]*G[{0}, yw]*G[{1}, yu^(-1)]*G[{0, 1/(yu*yv)}, yw] + 
     2*G[{0}, yv^(-1)]*G[{0}, yw]*G[{1}, yu^(-1)]*G[{0, 1/(yu*yv)}, yw] - 
     G[{0}, yw]^2*G[{1}, yu^(-1)]*G[{0, 1/(yu*yv)}, yw] + 
     2*G[{0}, yu^(-1)]*G[{1}, yu^(-1)]^2*G[{0, 1/(yu*yv)}, yw] + 
     2*G[{0}, yv^(-1)]*G[{1}, yu^(-1)]^2*G[{0, 1/(yu*yv)}, yw] - 
     2*G[{0}, yw]*G[{1}, yu^(-1)]^2*G[{0, 1/(yu*yv)}, yw] - 
     G[{1}, yu^(-1)]^3*G[{0, 1/(yu*yv)}, yw] + Pi^2*G[{1}, yv^(-1)]*
      G[{0, 1/(yu*yv)}, yw] + G[{0}, yu^(-1)]^2*G[{1}, yv^(-1)]*
      G[{0, 1/(yu*yv)}, yw] + 2*G[{0}, yu^(-1)]*G[{0}, yv^(-1)]*
      G[{1}, yv^(-1)]*G[{0, 1/(yu*yv)}, yw] + G[{0}, yv^(-1)]^2*
      G[{1}, yv^(-1)]*G[{0, 1/(yu*yv)}, yw] - 2*G[{0}, yu^(-1)]*G[{0}, yw]*
      G[{1}, yv^(-1)]*G[{0, 1/(yu*yv)}, yw] - 2*G[{0}, yv^(-1)]*G[{0}, yw]*
      G[{1}, yv^(-1)]*G[{0, 1/(yu*yv)}, yw] + G[{0}, yw]^2*G[{1}, yv^(-1)]*
      G[{0, 1/(yu*yv)}, yw] - 2*G[{0}, yu^(-1)]*G[{1}, yu^(-1)]*
      G[{1}, yv^(-1)]*G[{0, 1/(yu*yv)}, yw] - 2*G[{0}, yv^(-1)]*
      G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*G[{0, 1/(yu*yv)}, yw] + 
     2*G[{0}, yw]*G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*G[{0, 1/(yu*yv)}, yw] + 
     G[{1}, yu^(-1)]^2*G[{1}, yv^(-1)]*G[{0, 1/(yu*yv)}, yw] - 
     3*G[{0}, yu^(-1)]*G[{1}, yv^(-1)]^2*G[{0, 1/(yu*yv)}, yw] - 
     3*G[{0}, yv^(-1)]*G[{1}, yv^(-1)]^2*G[{0, 1/(yu*yv)}, yw] + 
     3*G[{0}, yw]*G[{1}, yv^(-1)]^2*G[{0, 1/(yu*yv)}, yw] + 
     5*G[{1}, yu^(-1)]*G[{1}, yv^(-1)]^2*G[{0, 1/(yu*yv)}, yw] + 
     2*G[{1}, yv^(-1)]^3*G[{0, 1/(yu*yv)}, yw] + 
     (Pi^2*G[{1}, yw]*G[{0, 1/(yu*yv)}, yw])/3 + G[{0}, yu^(-1)]^2*G[{1}, yw]*
      G[{0, 1/(yu*yv)}, yw] + 2*G[{0}, yu^(-1)]*G[{0}, yv^(-1)]*G[{1}, yw]*
      G[{0, 1/(yu*yv)}, yw] + G[{0}, yv^(-1)]^2*G[{1}, yw]*
      G[{0, 1/(yu*yv)}, yw] - 2*G[{0}, yu^(-1)]*G[{0}, yw]*G[{1}, yw]*
      G[{0, 1/(yu*yv)}, yw] - 2*G[{0}, yv^(-1)]*G[{0}, yw]*G[{1}, yw]*
      G[{0, 1/(yu*yv)}, yw] + G[{0}, yw]^2*G[{1}, yw]*G[{0, 1/(yu*yv)}, yw] - 
     4*G[{0}, yu^(-1)]*G[{1}, yu^(-1)]*G[{1}, yw]*G[{0, 1/(yu*yv)}, yw] - 
     4*G[{0}, yv^(-1)]*G[{1}, yu^(-1)]*G[{1}, yw]*G[{0, 1/(yu*yv)}, yw] + 
     4*G[{0}, yw]*G[{1}, yu^(-1)]*G[{1}, yw]*G[{0, 1/(yu*yv)}, yw] + 
     3*G[{1}, yu^(-1)]^2*G[{1}, yw]*G[{0, 1/(yu*yv)}, yw] - 
     2*G[{0}, yu^(-1)]*G[{1}, yv^(-1)]*G[{1}, yw]*G[{0, 1/(yu*yv)}, yw] - 
     2*G[{0}, yv^(-1)]*G[{1}, yv^(-1)]*G[{1}, yw]*G[{0, 1/(yu*yv)}, yw] + 
     2*G[{0}, yw]*G[{1}, yv^(-1)]*G[{1}, yw]*G[{0, 1/(yu*yv)}, yw] + 
     2*G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*G[{1}, yw]*G[{0, 1/(yu*yv)}, yw] + 
     G[{0}, yu^(-1)]*G[{1}, yw]^2*G[{0, 1/(yu*yv)}, yw] + 
     G[{0}, yv^(-1)]*G[{1}, yw]^2*G[{0, 1/(yu*yv)}, yw] - 
     G[{0}, yw]*G[{1}, yw]^2*G[{0, 1/(yu*yv)}, yw] - 
     2*G[{1}, yu^(-1)]*G[{1}, yw]^2*G[{0, 1/(yu*yv)}, yw] - 
     2*G[{1}, yv^(-1)]*G[{1}, yw]^2*G[{0, 1/(yu*yv)}, yw] - 
     (Pi^2*G[{yu}, yv^(-1)]*G[{0, 1/(yu*yv)}, yw])/3 + 
     2*G[{0}, yu^(-1)]*G[{1}, yu^(-1)]*G[{yu}, yv^(-1)]*
      G[{0, 1/(yu*yv)}, yw] + 2*G[{0}, yv^(-1)]*G[{1}, yu^(-1)]*
      G[{yu}, yv^(-1)]*G[{0, 1/(yu*yv)}, yw] - 2*G[{0}, yw]*G[{1}, yu^(-1)]*
      G[{yu}, yv^(-1)]*G[{0, 1/(yu*yv)}, yw] - 2*G[{1}, yu^(-1)]^2*
      G[{yu}, yv^(-1)]*G[{0, 1/(yu*yv)}, yw] + 2*G[{0}, yu^(-1)]*
      G[{1}, yv^(-1)]*G[{yu}, yv^(-1)]*G[{0, 1/(yu*yv)}, yw] + 
     2*G[{0}, yv^(-1)]*G[{1}, yv^(-1)]*G[{yu}, yv^(-1)]*
      G[{0, 1/(yu*yv)}, yw] - 2*G[{0}, yw]*G[{1}, yv^(-1)]*G[{yu}, yv^(-1)]*
      G[{0, 1/(yu*yv)}, yw] - 8*G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*
      G[{yu}, yv^(-1)]*G[{0, 1/(yu*yv)}, yw] - 2*G[{1}, yv^(-1)]^2*
      G[{yu}, yv^(-1)]*G[{0, 1/(yu*yv)}, yw] + 2*G[{0}, yu^(-1)]*G[{1}, yw]*
      G[{yu}, yv^(-1)]*G[{0, 1/(yu*yv)}, yw] + 2*G[{0}, yv^(-1)]*G[{1}, yw]*
      G[{yu}, yv^(-1)]*G[{0, 1/(yu*yv)}, yw] - 2*G[{0}, yw]*G[{1}, yw]*
      G[{yu}, yv^(-1)]*G[{0, 1/(yu*yv)}, yw] + 2*G[{1}, yw]^2*
      G[{yu}, yv^(-1)]*G[{0, 1/(yu*yv)}, yw] - 2*G[{0}, yu^(-1)]*
      G[{yu}, yv^(-1)]^2*G[{0, 1/(yu*yv)}, yw] - 2*G[{0}, yv^(-1)]*
      G[{yu}, yv^(-1)]^2*G[{0, 1/(yu*yv)}, yw] + 
     2*G[{0}, yw]*G[{yu}, yv^(-1)]^2*G[{0, 1/(yu*yv)}, yw] + 
     4*G[{1}, yu^(-1)]*G[{yu}, yv^(-1)]^2*G[{0, 1/(yu*yv)}, yw] + 
     4*G[{1}, yv^(-1)]*G[{yu}, yv^(-1)]^2*G[{0, 1/(yu*yv)}, yw] - 
     2*G[{1}, yw]*G[{yu}, yv^(-1)]^2*G[{0, 1/(yu*yv)}, yw] - 
     (4*G[{yu}, yv^(-1)]^3*G[{0, 1/(yu*yv)}, yw])/3 - 
     (2*Pi^2*G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv)}, yw])/3 - 
     G[{0}, yu^(-1)]^2*G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv)}, yw] - 
     2*G[{0}, yu^(-1)]*G[{0}, yv^(-1)]*G[{1/(yu*yv)}, yw]*
      G[{0, 1/(yu*yv)}, yw] - G[{0}, yv^(-1)]^2*G[{1/(yu*yv)}, yw]*
      G[{0, 1/(yu*yv)}, yw] + 2*G[{0}, yu^(-1)]*G[{0}, yw]*G[{1/(yu*yv)}, yw]*
      G[{0, 1/(yu*yv)}, yw] + 2*G[{0}, yv^(-1)]*G[{0}, yw]*G[{1/(yu*yv)}, yw]*
      G[{0, 1/(yu*yv)}, yw] - G[{0}, yw]^2*G[{1/(yu*yv)}, yw]*
      G[{0, 1/(yu*yv)}, yw] + 2*G[{0}, yu^(-1)]*G[{1}, yu^(-1)]*
      G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv)}, yw] + 2*G[{0}, yv^(-1)]*
      G[{1}, yu^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv)}, yw] - 
     2*G[{0}, yw]*G[{1}, yu^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv)}, yw] - 
     G[{1}, yu^(-1)]^2*G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv)}, yw] + 
     4*G[{0}, yu^(-1)]*G[{1}, yv^(-1)]*G[{1/(yu*yv)}, yw]*
      G[{0, 1/(yu*yv)}, yw] + 4*G[{0}, yv^(-1)]*G[{1}, yv^(-1)]*
      G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv)}, yw] - 4*G[{0}, yw]*G[{1}, yv^(-1)]*
      G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv)}, yw] - 6*G[{1}, yu^(-1)]*
      G[{1}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv)}, yw] - 
     4*G[{1}, yv^(-1)]^2*G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv)}, yw] - 
     2*G[{0}, yu^(-1)]*G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw]*
      G[{0, 1/(yu*yv)}, yw] - 2*G[{0}, yv^(-1)]*G[{yu}, yv^(-1)]*
      G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv)}, yw] + 
     2*G[{0}, yw]*G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv)}, yw] + 
     4*G[{1}, yu^(-1)]*G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw]*
      G[{0, 1/(yu*yv)}, yw] + 4*G[{1}, yv^(-1)]*G[{yu}, yv^(-1)]*
      G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv)}, yw] - 2*G[{yu}, yv^(-1)]^2*
      G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv)}, yw] - 
     G[{0}, yu^(-1)]*G[{1/(yu*yv)}, yw]^2*G[{0, 1/(yu*yv)}, yw] - 
     G[{0}, yv^(-1)]*G[{1/(yu*yv)}, yw]^2*G[{0, 1/(yu*yv)}, yw] + 
     G[{0}, yw]*G[{1/(yu*yv)}, yw]^2*G[{0, 1/(yu*yv)}, yw] + 
     2*G[{1}, yu^(-1)]*G[{1/(yu*yv)}, yw]^2*G[{0, 1/(yu*yv)}, yw] + 
     2*G[{1}, yv^(-1)]*G[{1/(yu*yv)}, yw]^2*G[{0, 1/(yu*yv)}, yw] - 
     2*G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw]^2*G[{0, 1/(yu*yv)}, yw] - 
     2*G[{0}, yu^(-1)]*G[{0, 1}, yu^(-1)]*G[{0, 1/(yu*yv)}, yw] - 
     2*G[{0}, yv^(-1)]*G[{0, 1}, yu^(-1)]*G[{0, 1/(yu*yv)}, yw] + 
     2*G[{0}, yw]*G[{0, 1}, yu^(-1)]*G[{0, 1/(yu*yv)}, yw] + 
     2*G[{1}, yu^(-1)]*G[{0, 1}, yu^(-1)]*G[{0, 1/(yu*yv)}, yw] + 
     4*G[{1}, yv^(-1)]*G[{0, 1}, yu^(-1)]*G[{0, 1/(yu*yv)}, yw] - 
     2*G[{yu}, yv^(-1)]*G[{0, 1}, yu^(-1)]*G[{0, 1/(yu*yv)}, yw] - 
     2*G[{1/(yu*yv)}, yw]*G[{0, 1}, yu^(-1)]*G[{0, 1/(yu*yv)}, yw] + 
     2*G[{1}, yu^(-1)]*G[{0, 1}, yv^(-1)]*G[{0, 1/(yu*yv)}, yw] + 
     2*G[{1}, yv^(-1)]*G[{0, 1}, yv^(-1)]*G[{0, 1/(yu*yv)}, yw] + 
     2*G[{1}, yw]*G[{0, 1}, yv^(-1)]*G[{0, 1/(yu*yv)}, yw] - 
     2*G[{yu}, yv^(-1)]*G[{0, 1}, yv^(-1)]*G[{0, 1/(yu*yv)}, yw] - 
     2*G[{1}, yu^(-1)]*G[{0, 1}, yw]*G[{0, 1/(yu*yv)}, yw] + 
     2*G[{1}, yw]*G[{0, 1}, yw]*G[{0, 1/(yu*yv)}, yw] + 
     2*G[{yu}, yv^(-1)]*G[{0, 1}, yw]*G[{0, 1/(yu*yv)}, yw] + 
     2*G[{1}, yu^(-1)]*G[{0, yu^(-1)}, yw]*G[{0, 1/(yu*yv)}, yw] - 
     2*G[{1}, yw]*G[{0, yu^(-1)}, yw]*G[{0, 1/(yu*yv)}, yw] - 
     2*G[{yu}, yv^(-1)]*G[{0, yu^(-1)}, yw]*G[{0, 1/(yu*yv)}, yw] - 
     2*G[{1}, yu^(-1)]*G[{0, yu}, yv^(-1)]*G[{0, 1/(yu*yv)}, yw] - 
     2*G[{1}, yv^(-1)]*G[{0, yu}, yv^(-1)]*G[{0, 1/(yu*yv)}, yw] - 
     2*G[{1}, yw]*G[{0, yu}, yv^(-1)]*G[{0, 1/(yu*yv)}, yw] + 
     2*G[{yu}, yv^(-1)]*G[{0, yu}, yv^(-1)]*G[{0, 1/(yu*yv)}, yw] + 
     2*G[{1}, yu^(-1)]*G[{0, yv^(-1)}, yw]*G[{0, 1/(yu*yv)}, yw] - 
     2*G[{1}, yw]*G[{0, yv^(-1)}, yw]*G[{0, 1/(yu*yv)}, yw] - 
     2*G[{yu}, yv^(-1)]*G[{0, yv^(-1)}, yw]*G[{0, 1/(yu*yv)}, yw] - 
     G[{1}, yu^(-1)]*G[{0, 1/(yu*yv)}, yw]^2 + 
     G[{1}, yw]*G[{0, 1/(yu*yv)}, yw]^2 + G[{yu}, yv^(-1)]*
      G[{0, 1/(yu*yv)}, yw]^2 - 2*G[{0}, yu^(-1)]*G[{0, 1}, yw]*
      G[{1, yu}, yv^(-1)] - 2*G[{0}, yv^(-1)]*G[{0, 1}, yw]*
      G[{1, yu}, yv^(-1)] + 2*G[{0}, yw]*G[{0, 1}, yw]*G[{1, yu}, yv^(-1)] + 
     4*G[{1}, yv^(-1)]*G[{0, 1}, yw]*G[{1, yu}, yv^(-1)] - 
     2*G[{1}, yw]*G[{0, 1}, yw]*G[{1, yu}, yv^(-1)] - 
     2*G[{1/(yu*yv)}, yw]*G[{0, 1}, yw]*G[{1, yu}, yv^(-1)] - 
     2*G[{0}, yu^(-1)]*G[{0, yu^(-1)}, yw]*G[{1, yu}, yv^(-1)] - 
     2*G[{0}, yv^(-1)]*G[{0, yu^(-1)}, yw]*G[{1, yu}, yv^(-1)] + 
     2*G[{0}, yw]*G[{0, yu^(-1)}, yw]*G[{1, yu}, yv^(-1)] + 
     4*G[{1}, yu^(-1)]*G[{0, yu^(-1)}, yw]*G[{1, yu}, yv^(-1)] + 
     4*G[{1}, yv^(-1)]*G[{0, yu^(-1)}, yw]*G[{1, yu}, yv^(-1)] - 
     2*G[{1}, yw]*G[{0, yu^(-1)}, yw]*G[{1, yu}, yv^(-1)] - 
     2*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1)}, yw]*G[{1, yu}, yv^(-1)] + 
     2*G[{0}, yu^(-1)]*G[{0, yv^(-1)}, yw]*G[{1, yu}, yv^(-1)] + 
     2*G[{0}, yv^(-1)]*G[{0, yv^(-1)}, yw]*G[{1, yu}, yv^(-1)] - 
     2*G[{0}, yw]*G[{0, yv^(-1)}, yw]*G[{1, yu}, yv^(-1)] - 
     4*G[{1}, yu^(-1)]*G[{0, yv^(-1)}, yw]*G[{1, yu}, yv^(-1)] - 
     4*G[{1}, yv^(-1)]*G[{0, yv^(-1)}, yw]*G[{1, yu}, yv^(-1)] + 
     2*G[{1}, yw]*G[{0, yv^(-1)}, yw]*G[{1, yu}, yv^(-1)] + 
     2*G[{1/(yu*yv)}, yw]*G[{0, yv^(-1)}, yw]*G[{1, yu}, yv^(-1)] + 
     2*G[{0}, yu^(-1)]*G[{0, 1/(yu*yv)}, yw]*G[{1, yu}, yv^(-1)] + 
     2*G[{0}, yv^(-1)]*G[{0, 1/(yu*yv)}, yw]*G[{1, yu}, yv^(-1)] - 
     2*G[{0}, yw]*G[{0, 1/(yu*yv)}, yw]*G[{1, yu}, yv^(-1)] - 
     4*G[{1}, yv^(-1)]*G[{0, 1/(yu*yv)}, yw]*G[{1, yu}, yv^(-1)] + 
     2*G[{1}, yw]*G[{0, 1/(yu*yv)}, yw]*G[{1, yu}, yv^(-1)] + 
     2*G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv)}, yw]*G[{1, yu}, yv^(-1)] - 
     Pi^2*G[{0, 0, 1}, yv^(-1)] - 2*G[{0}, yu^(-1)]^2*G[{0, 0, 1}, yv^(-1)] - 
     4*G[{0}, yu^(-1)]*G[{0}, yv^(-1)]*G[{0, 0, 1}, yv^(-1)] - 
     2*G[{0}, yv^(-1)]^2*G[{0, 0, 1}, yv^(-1)] + 4*G[{0}, yu^(-1)]*G[{0}, yw]*
      G[{0, 0, 1}, yv^(-1)] + 4*G[{0}, yv^(-1)]*G[{0}, yw]*
      G[{0, 0, 1}, yv^(-1)] - 2*G[{0}, yw]^2*G[{0, 0, 1}, yv^(-1)] + 
     2*G[{0}, yu^(-1)]*G[{1}, yu^(-1)]*G[{0, 0, 1}, yv^(-1)] + 
     2*G[{0}, yv^(-1)]*G[{1}, yu^(-1)]*G[{0, 0, 1}, yv^(-1)] - 
     2*G[{0}, yw]*G[{1}, yu^(-1)]*G[{0, 0, 1}, yv^(-1)] + 
     2*G[{0}, yu^(-1)]*G[{1}, yv^(-1)]*G[{0, 0, 1}, yv^(-1)] + 
     2*G[{0}, yv^(-1)]*G[{1}, yv^(-1)]*G[{0, 0, 1}, yv^(-1)] - 
     2*G[{0}, yw]*G[{1}, yv^(-1)]*G[{0, 0, 1}, yv^(-1)] - 
     2*G[{0}, yu^(-1)]*G[{1}, yw]*G[{0, 0, 1}, yv^(-1)] - 
     2*G[{0}, yv^(-1)]*G[{1}, yw]*G[{0, 0, 1}, yv^(-1)] + 
     2*G[{0}, yw]*G[{1}, yw]*G[{0, 0, 1}, yv^(-1)] - 
     2*G[{0}, yu^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, 0, 1}, yv^(-1)] - 
     2*G[{0}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, 0, 1}, yv^(-1)] + 
     2*G[{0}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 0, 1}, yv^(-1)] - 
     2*G[{0, 1}, yu^(-1)]*G[{0, 0, 1}, yv^(-1)] - 2*G[{0, 1}, yv^(-1)]*
      G[{0, 0, 1}, yv^(-1)] - 2*G[{0, 1}, yw]*G[{0, 0, 1}, yv^(-1)] + 
     2*G[{0, yu^(-1)}, yw]*G[{0, 0, 1}, yv^(-1)] + 2*G[{0, yu}, yv^(-1)]*
      G[{0, 0, 1}, yv^(-1)] + 2*G[{0, yv^(-1)}, yw]*G[{0, 0, 1}, yv^(-1)] - 
     2*G[{0, 1/(yu*yv)}, yw]*G[{0, 0, 1}, yv^(-1)] - 
     (Pi^2*G[{0, 0, 1}, yw])/3 - 2*G[{0}, yu^(-1)]*G[{1}, yu^(-1)]*
      G[{0, 0, 1}, yw] - 2*G[{0}, yv^(-1)]*G[{1}, yu^(-1)]*G[{0, 0, 1}, yw] + 
     2*G[{0}, yw]*G[{1}, yu^(-1)]*G[{0, 0, 1}, yw] + 
     2*G[{1}, yu^(-1)]^2*G[{0, 0, 1}, yw] + 2*G[{0}, yu^(-1)]*G[{1}, yv^(-1)]*
      G[{0, 0, 1}, yw] + 2*G[{0}, yv^(-1)]*G[{1}, yv^(-1)]*G[{0, 0, 1}, yw] - 
     2*G[{0}, yw]*G[{1}, yv^(-1)]*G[{0, 0, 1}, yw] - 
     2*G[{1}, yv^(-1)]^2*G[{0, 0, 1}, yw] + 2*G[{0}, yu^(-1)]*G[{1}, yw]*
      G[{0, 0, 1}, yw] + 2*G[{0}, yv^(-1)]*G[{1}, yw]*G[{0, 0, 1}, yw] - 
     2*G[{0}, yw]*G[{1}, yw]*G[{0, 0, 1}, yw] - 4*G[{1}, yu^(-1)]*G[{1}, yw]*
      G[{0, 0, 1}, yw] + 2*G[{1}, yw]^2*G[{0, 0, 1}, yw] - 
     2*G[{0}, yu^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, 0, 1}, yw] - 
     2*G[{0}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, 0, 1}, yw] + 
     2*G[{0}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 0, 1}, yw] + 
     4*G[{1}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, 0, 1}, yw] - 
     2*G[{1/(yu*yv)}, yw]^2*G[{0, 0, 1}, yw] - 2*G[{0, 1}, yu^(-1)]*
      G[{0, 0, 1}, yw] - 2*G[{0, 1}, yv^(-1)]*G[{0, 0, 1}, yw] - 
     2*G[{0, 1}, yw]*G[{0, 0, 1}, yw] + 2*G[{0, yu^(-1)}, yw]*
      G[{0, 0, 1}, yw] + 2*G[{0, yu}, yv^(-1)]*G[{0, 0, 1}, yw] + 
     2*G[{0, yv^(-1)}, yw]*G[{0, 0, 1}, yw] - 2*G[{0, 1/(yu*yv)}, yw]*
      G[{0, 0, 1}, yw] + (Pi^2*G[{0, 0, yu^(-1)}, yw])/3 + 
     2*G[{0}, yu^(-1)]*G[{1}, yu^(-1)]*G[{0, 0, yu^(-1)}, yw] + 
     2*G[{0}, yv^(-1)]*G[{1}, yu^(-1)]*G[{0, 0, yu^(-1)}, yw] - 
     2*G[{0}, yw]*G[{1}, yu^(-1)]*G[{0, 0, yu^(-1)}, yw] - 
     2*G[{1}, yu^(-1)]^2*G[{0, 0, yu^(-1)}, yw] - 
     2*G[{0}, yu^(-1)]*G[{1}, yv^(-1)]*G[{0, 0, yu^(-1)}, yw] - 
     2*G[{0}, yv^(-1)]*G[{1}, yv^(-1)]*G[{0, 0, yu^(-1)}, yw] + 
     2*G[{0}, yw]*G[{1}, yv^(-1)]*G[{0, 0, yu^(-1)}, yw] + 
     2*G[{1}, yv^(-1)]^2*G[{0, 0, yu^(-1)}, yw] - 
     2*G[{0}, yu^(-1)]*G[{1}, yw]*G[{0, 0, yu^(-1)}, yw] - 
     2*G[{0}, yv^(-1)]*G[{1}, yw]*G[{0, 0, yu^(-1)}, yw] + 
     2*G[{0}, yw]*G[{1}, yw]*G[{0, 0, yu^(-1)}, yw] + 
     4*G[{1}, yu^(-1)]*G[{1}, yw]*G[{0, 0, yu^(-1)}, yw] - 
     2*G[{1}, yw]^2*G[{0, 0, yu^(-1)}, yw] + 2*G[{0}, yu^(-1)]*
      G[{1/(yu*yv)}, yw]*G[{0, 0, yu^(-1)}, yw] + 
     2*G[{0}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, 0, yu^(-1)}, yw] - 
     2*G[{0}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 0, yu^(-1)}, yw] - 
     4*G[{1}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, 0, yu^(-1)}, yw] + 
     2*G[{1/(yu*yv)}, yw]^2*G[{0, 0, yu^(-1)}, yw] + 
     2*G[{0, 1}, yu^(-1)]*G[{0, 0, yu^(-1)}, yw] + 2*G[{0, 1}, yv^(-1)]*
      G[{0, 0, yu^(-1)}, yw] + 2*G[{0, 1}, yw]*G[{0, 0, yu^(-1)}, yw] - 
     2*G[{0, yu^(-1)}, yw]*G[{0, 0, yu^(-1)}, yw] - 
     2*G[{0, yu}, yv^(-1)]*G[{0, 0, yu^(-1)}, yw] - 
     2*G[{0, yv^(-1)}, yw]*G[{0, 0, yu^(-1)}, yw] + 
     2*G[{0, 1/(yu*yv)}, yw]*G[{0, 0, yu^(-1)}, yw] + 
     Pi^2*G[{0, 0, yu}, yv^(-1)] + 2*G[{0}, yu^(-1)]^2*
      G[{0, 0, yu}, yv^(-1)] + 4*G[{0}, yu^(-1)]*G[{0}, yv^(-1)]*
      G[{0, 0, yu}, yv^(-1)] + 2*G[{0}, yv^(-1)]^2*G[{0, 0, yu}, yv^(-1)] - 
     4*G[{0}, yu^(-1)]*G[{0}, yw]*G[{0, 0, yu}, yv^(-1)] - 
     4*G[{0}, yv^(-1)]*G[{0}, yw]*G[{0, 0, yu}, yv^(-1)] + 
     2*G[{0}, yw]^2*G[{0, 0, yu}, yv^(-1)] - 2*G[{0}, yu^(-1)]*
      G[{1}, yu^(-1)]*G[{0, 0, yu}, yv^(-1)] - 2*G[{0}, yv^(-1)]*
      G[{1}, yu^(-1)]*G[{0, 0, yu}, yv^(-1)] + 2*G[{0}, yw]*G[{1}, yu^(-1)]*
      G[{0, 0, yu}, yv^(-1)] - 2*G[{0}, yu^(-1)]*G[{1}, yv^(-1)]*
      G[{0, 0, yu}, yv^(-1)] - 2*G[{0}, yv^(-1)]*G[{1}, yv^(-1)]*
      G[{0, 0, yu}, yv^(-1)] + 2*G[{0}, yw]*G[{1}, yv^(-1)]*
      G[{0, 0, yu}, yv^(-1)] + 2*G[{0}, yu^(-1)]*G[{1}, yw]*
      G[{0, 0, yu}, yv^(-1)] + 2*G[{0}, yv^(-1)]*G[{1}, yw]*
      G[{0, 0, yu}, yv^(-1)] - 2*G[{0}, yw]*G[{1}, yw]*
      G[{0, 0, yu}, yv^(-1)] + 2*G[{0}, yu^(-1)]*G[{1/(yu*yv)}, yw]*
      G[{0, 0, yu}, yv^(-1)] + 2*G[{0}, yv^(-1)]*G[{1/(yu*yv)}, yw]*
      G[{0, 0, yu}, yv^(-1)] - 2*G[{0}, yw]*G[{1/(yu*yv)}, yw]*
      G[{0, 0, yu}, yv^(-1)] + 2*G[{0, 1}, yu^(-1)]*G[{0, 0, yu}, yv^(-1)] + 
     2*G[{0, 1}, yv^(-1)]*G[{0, 0, yu}, yv^(-1)] + 
     2*G[{0, 1}, yw]*G[{0, 0, yu}, yv^(-1)] - 2*G[{0, yu^(-1)}, yw]*
      G[{0, 0, yu}, yv^(-1)] - 2*G[{0, yu}, yv^(-1)]*G[{0, 0, yu}, yv^(-1)] - 
     2*G[{0, yv^(-1)}, yw]*G[{0, 0, yu}, yv^(-1)] + 
     2*G[{0, 1/(yu*yv)}, yw]*G[{0, 0, yu}, yv^(-1)] + 
     (Pi^2*G[{0, 0, yv^(-1)}, yw])/3 + 2*G[{0}, yu^(-1)]*G[{1}, yu^(-1)]*
      G[{0, 0, yv^(-1)}, yw] + 2*G[{0}, yv^(-1)]*G[{1}, yu^(-1)]*
      G[{0, 0, yv^(-1)}, yw] - 2*G[{0}, yw]*G[{1}, yu^(-1)]*
      G[{0, 0, yv^(-1)}, yw] - 2*G[{1}, yu^(-1)]^2*G[{0, 0, yv^(-1)}, yw] - 
     2*G[{0}, yu^(-1)]*G[{1}, yv^(-1)]*G[{0, 0, yv^(-1)}, yw] - 
     2*G[{0}, yv^(-1)]*G[{1}, yv^(-1)]*G[{0, 0, yv^(-1)}, yw] + 
     2*G[{0}, yw]*G[{1}, yv^(-1)]*G[{0, 0, yv^(-1)}, yw] + 
     2*G[{1}, yv^(-1)]^2*G[{0, 0, yv^(-1)}, yw] - 
     2*G[{0}, yu^(-1)]*G[{1}, yw]*G[{0, 0, yv^(-1)}, yw] - 
     2*G[{0}, yv^(-1)]*G[{1}, yw]*G[{0, 0, yv^(-1)}, yw] + 
     2*G[{0}, yw]*G[{1}, yw]*G[{0, 0, yv^(-1)}, yw] + 
     4*G[{1}, yu^(-1)]*G[{1}, yw]*G[{0, 0, yv^(-1)}, yw] - 
     2*G[{1}, yw]^2*G[{0, 0, yv^(-1)}, yw] + 2*G[{0}, yu^(-1)]*
      G[{1/(yu*yv)}, yw]*G[{0, 0, yv^(-1)}, yw] + 
     2*G[{0}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, 0, yv^(-1)}, yw] - 
     2*G[{0}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 0, yv^(-1)}, yw] - 
     4*G[{1}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, 0, yv^(-1)}, yw] + 
     2*G[{1/(yu*yv)}, yw]^2*G[{0, 0, yv^(-1)}, yw] + 
     2*G[{0, 1}, yu^(-1)]*G[{0, 0, yv^(-1)}, yw] + 2*G[{0, 1}, yv^(-1)]*
      G[{0, 0, yv^(-1)}, yw] + 2*G[{0, 1}, yw]*G[{0, 0, yv^(-1)}, yw] - 
     2*G[{0, yu^(-1)}, yw]*G[{0, 0, yv^(-1)}, yw] - 
     2*G[{0, yu}, yv^(-1)]*G[{0, 0, yv^(-1)}, yw] - 
     2*G[{0, yv^(-1)}, yw]*G[{0, 0, yv^(-1)}, yw] + 
     2*G[{0, 1/(yu*yv)}, yw]*G[{0, 0, yv^(-1)}, yw] - 
     (Pi^2*G[{0, 0, 1/(yu*yv)}, yw])/3 - 2*G[{0}, yu^(-1)]*G[{1}, yu^(-1)]*
      G[{0, 0, 1/(yu*yv)}, yw] - 2*G[{0}, yv^(-1)]*G[{1}, yu^(-1)]*
      G[{0, 0, 1/(yu*yv)}, yw] + 2*G[{0}, yw]*G[{1}, yu^(-1)]*
      G[{0, 0, 1/(yu*yv)}, yw] + 2*G[{1}, yu^(-1)]^2*
      G[{0, 0, 1/(yu*yv)}, yw] + 2*G[{0}, yu^(-1)]*G[{1}, yv^(-1)]*
      G[{0, 0, 1/(yu*yv)}, yw] + 2*G[{0}, yv^(-1)]*G[{1}, yv^(-1)]*
      G[{0, 0, 1/(yu*yv)}, yw] - 2*G[{0}, yw]*G[{1}, yv^(-1)]*
      G[{0, 0, 1/(yu*yv)}, yw] - 2*G[{1}, yv^(-1)]^2*
      G[{0, 0, 1/(yu*yv)}, yw] + 2*G[{0}, yu^(-1)]*G[{1}, yw]*
      G[{0, 0, 1/(yu*yv)}, yw] + 2*G[{0}, yv^(-1)]*G[{1}, yw]*
      G[{0, 0, 1/(yu*yv)}, yw] - 2*G[{0}, yw]*G[{1}, yw]*
      G[{0, 0, 1/(yu*yv)}, yw] - 4*G[{1}, yu^(-1)]*G[{1}, yw]*
      G[{0, 0, 1/(yu*yv)}, yw] + 2*G[{1}, yw]^2*G[{0, 0, 1/(yu*yv)}, yw] - 
     2*G[{0}, yu^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, 0, 1/(yu*yv)}, yw] - 
     2*G[{0}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, 0, 1/(yu*yv)}, yw] + 
     2*G[{0}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 0, 1/(yu*yv)}, yw] + 
     4*G[{1}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, 0, 1/(yu*yv)}, yw] - 
     2*G[{1/(yu*yv)}, yw]^2*G[{0, 0, 1/(yu*yv)}, yw] - 
     2*G[{0, 1}, yu^(-1)]*G[{0, 0, 1/(yu*yv)}, yw] - 
     2*G[{0, 1}, yv^(-1)]*G[{0, 0, 1/(yu*yv)}, yw] - 
     2*G[{0, 1}, yw]*G[{0, 0, 1/(yu*yv)}, yw] + 2*G[{0, yu^(-1)}, yw]*
      G[{0, 0, 1/(yu*yv)}, yw] + 2*G[{0, yu}, yv^(-1)]*
      G[{0, 0, 1/(yu*yv)}, yw] + 2*G[{0, yv^(-1)}, yw]*
      G[{0, 0, 1/(yu*yv)}, yw] - 2*G[{0, 1/(yu*yv)}, yw]*
      G[{0, 0, 1/(yu*yv)}, yw] + (4*Pi^2*G[{0, 1, 1}, yu^(-1)])/3 + 
     2*G[{0}, yu^(-1)]^2*G[{0, 1, 1}, yu^(-1)] + 4*G[{0}, yu^(-1)]*
      G[{0}, yv^(-1)]*G[{0, 1, 1}, yu^(-1)] + 2*G[{0}, yv^(-1)]^2*
      G[{0, 1, 1}, yu^(-1)] - 4*G[{0}, yu^(-1)]*G[{0}, yw]*
      G[{0, 1, 1}, yu^(-1)] - 4*G[{0}, yv^(-1)]*G[{0}, yw]*
      G[{0, 1, 1}, yu^(-1)] + 2*G[{0}, yw]^2*G[{0, 1, 1}, yu^(-1)] - 
     2*G[{1}, yu^(-1)]^2*G[{0, 1, 1}, yu^(-1)] - 4*G[{0}, yu^(-1)]*
      G[{1}, yv^(-1)]*G[{0, 1, 1}, yu^(-1)] - 4*G[{0}, yv^(-1)]*
      G[{1}, yv^(-1)]*G[{0, 1, 1}, yu^(-1)] + 4*G[{0}, yw]*G[{1}, yv^(-1)]*
      G[{0, 1, 1}, yu^(-1)] + 2*G[{1}, yv^(-1)]^2*G[{0, 1, 1}, yu^(-1)] + 
     4*G[{1}, yu^(-1)]*G[{1}, yw]*G[{0, 1, 1}, yu^(-1)] - 
     2*G[{1}, yw]^2*G[{0, 1, 1}, yu^(-1)] + 4*G[{0}, yu^(-1)]*
      G[{1/(yu*yv)}, yw]*G[{0, 1, 1}, yu^(-1)] + 4*G[{0}, yv^(-1)]*
      G[{1/(yu*yv)}, yw]*G[{0, 1, 1}, yu^(-1)] - 
     4*G[{0}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1, 1}, yu^(-1)] - 
     4*G[{1}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, 1, 1}, yu^(-1)] + 
     2*G[{1/(yu*yv)}, yw]^2*G[{0, 1, 1}, yu^(-1)] + 
     4*G[{0, 1}, yu^(-1)]*G[{0, 1, 1}, yu^(-1)] + 
     4*G[{0, 1}, yw]*G[{0, 1, 1}, yu^(-1)] - 4*G[{0, yu^(-1)}, yw]*
      G[{0, 1, 1}, yu^(-1)] + (Pi^2*G[{0, 1, 1}, yv^(-1)])/3 - 
     4*G[{0}, yu^(-1)]*G[{1}, yu^(-1)]*G[{0, 1, 1}, yv^(-1)] - 
     4*G[{0}, yv^(-1)]*G[{1}, yu^(-1)]*G[{0, 1, 1}, yv^(-1)] + 
     4*G[{0}, yw]*G[{1}, yu^(-1)]*G[{0, 1, 1}, yv^(-1)] + 
     4*G[{1}, yu^(-1)]^2*G[{0, 1, 1}, yv^(-1)] - 2*G[{0}, yu^(-1)]*
      G[{1}, yv^(-1)]*G[{0, 1, 1}, yv^(-1)] - 2*G[{0}, yv^(-1)]*
      G[{1}, yv^(-1)]*G[{0, 1, 1}, yv^(-1)] + 2*G[{0}, yw]*G[{1}, yv^(-1)]*
      G[{0, 1, 1}, yv^(-1)] + 6*G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*
      G[{0, 1, 1}, yv^(-1)] + 2*G[{1}, yv^(-1)]^2*G[{0, 1, 1}, yv^(-1)] - 
     2*G[{0}, yu^(-1)]*G[{1}, yw]*G[{0, 1, 1}, yv^(-1)] - 
     2*G[{0}, yv^(-1)]*G[{1}, yw]*G[{0, 1, 1}, yv^(-1)] + 
     2*G[{0}, yw]*G[{1}, yw]*G[{0, 1, 1}, yv^(-1)] + 
     2*G[{1}, yu^(-1)]*G[{1}, yw]*G[{0, 1, 1}, yv^(-1)] - 
     2*G[{1}, yw]^2*G[{0, 1, 1}, yv^(-1)] + 2*G[{0}, yu^(-1)]*
      G[{1/(yu*yv)}, yw]*G[{0, 1, 1}, yv^(-1)] + 2*G[{0}, yv^(-1)]*
      G[{1/(yu*yv)}, yw]*G[{0, 1, 1}, yv^(-1)] - 
     2*G[{0}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1, 1}, yv^(-1)] - 
     6*G[{1}, yu^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, 1, 1}, yv^(-1)] - 
     4*G[{1}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, 1, 1}, yv^(-1)] + 
     2*G[{1/(yu*yv)}, yw]^2*G[{0, 1, 1}, yv^(-1)] + 
     2*G[{0, 1}, yu^(-1)]*G[{0, 1, 1}, yv^(-1)] + 2*G[{0, 1}, yv^(-1)]*
      G[{0, 1, 1}, yv^(-1)] + 2*G[{0, 1}, yw]*G[{0, 1, 1}, yv^(-1)] + 
     2*G[{0, yu^(-1)}, yw]*G[{0, 1, 1}, yv^(-1)] - 2*G[{0, yu}, yv^(-1)]*
      G[{0, 1, 1}, yv^(-1)] - 2*G[{0, yv^(-1)}, yw]*G[{0, 1, 1}, yv^(-1)] - 
     2*G[{0, 1/(yu*yv)}, yw]*G[{0, 1, 1}, yv^(-1)] - 
     (4*Pi^2*G[{0, 1, 1}, yw])/3 - 2*G[{0}, yu^(-1)]^2*G[{0, 1, 1}, yw] - 
     4*G[{0}, yu^(-1)]*G[{0}, yv^(-1)]*G[{0, 1, 1}, yw] - 
     2*G[{0}, yv^(-1)]^2*G[{0, 1, 1}, yw] + 4*G[{0}, yu^(-1)]*G[{0}, yw]*
      G[{0, 1, 1}, yw] + 4*G[{0}, yv^(-1)]*G[{0}, yw]*G[{0, 1, 1}, yw] - 
     2*G[{0}, yw]^2*G[{0, 1, 1}, yw] + 6*G[{0}, yu^(-1)]*G[{1}, yu^(-1)]*
      G[{0, 1, 1}, yw] + 6*G[{0}, yv^(-1)]*G[{1}, yu^(-1)]*G[{0, 1, 1}, yw] - 
     6*G[{0}, yw]*G[{1}, yu^(-1)]*G[{0, 1, 1}, yw] - 
     4*G[{1}, yu^(-1)]^2*G[{0, 1, 1}, yw] + 8*G[{0}, yu^(-1)]*G[{1}, yv^(-1)]*
      G[{0, 1, 1}, yw] + 8*G[{0}, yv^(-1)]*G[{1}, yv^(-1)]*G[{0, 1, 1}, yw] - 
     8*G[{0}, yw]*G[{1}, yv^(-1)]*G[{0, 1, 1}, yw] - 
     16*G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*G[{0, 1, 1}, yw] - 
     8*G[{1}, yv^(-1)]^2*G[{0, 1, 1}, yw] - 2*G[{1}, yu^(-1)]*G[{1}, yw]*
      G[{0, 1, 1}, yw] + 2*G[{1}, yw]^2*G[{0, 1, 1}, yw] - 
     6*G[{0}, yu^(-1)]*G[{yu}, yv^(-1)]*G[{0, 1, 1}, yw] - 
     6*G[{0}, yv^(-1)]*G[{yu}, yv^(-1)]*G[{0, 1, 1}, yw] + 
     6*G[{0}, yw]*G[{yu}, yv^(-1)]*G[{0, 1, 1}, yw] + 
     12*G[{1}, yu^(-1)]*G[{yu}, yv^(-1)]*G[{0, 1, 1}, yw] + 
     12*G[{1}, yv^(-1)]*G[{yu}, yv^(-1)]*G[{0, 1, 1}, yw] + 
     2*G[{1}, yw]*G[{yu}, yv^(-1)]*G[{0, 1, 1}, yw] - 
     6*G[{yu}, yv^(-1)]^2*G[{0, 1, 1}, yw] - 4*G[{0}, yu^(-1)]*
      G[{1/(yu*yv)}, yw]*G[{0, 1, 1}, yw] - 4*G[{0}, yv^(-1)]*
      G[{1/(yu*yv)}, yw]*G[{0, 1, 1}, yw] + 4*G[{0}, yw]*G[{1/(yu*yv)}, yw]*
      G[{0, 1, 1}, yw] + 6*G[{1}, yu^(-1)]*G[{1/(yu*yv)}, yw]*
      G[{0, 1, 1}, yw] + 8*G[{1}, yv^(-1)]*G[{1/(yu*yv)}, yw]*
      G[{0, 1, 1}, yw] - 6*G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw]*
      G[{0, 1, 1}, yw] - 2*G[{1/(yu*yv)}, yw]^2*G[{0, 1, 1}, yw] - 
     4*G[{0, 1}, yu^(-1)]*G[{0, 1, 1}, yw] + 2*G[{0, yu^(-1)}, yw]*
      G[{0, 1, 1}, yw] - 2*G[{0, yv^(-1)}, yw]*G[{0, 1, 1}, yw] - 
     2*G[{0, 1/(yu*yv)}, yw]*G[{0, 1, 1}, yw] + 4*G[{1, yu}, yv^(-1)]*
      G[{0, 1, 1}, yw] - 4*G[{0}, yu^(-1)]*G[{1}, yu^(-1)]*
      G[{0, 1, yu^(-1)}, yw] - 4*G[{0}, yv^(-1)]*G[{1}, yu^(-1)]*
      G[{0, 1, yu^(-1)}, yw] + 4*G[{0}, yw]*G[{1}, yu^(-1)]*
      G[{0, 1, yu^(-1)}, yw] + 4*G[{1}, yu^(-1)]^2*G[{0, 1, yu^(-1)}, yw] + 
     8*G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*G[{0, 1, yu^(-1)}, yw] + 
     4*G[{0}, yu^(-1)]*G[{yu}, yv^(-1)]*G[{0, 1, yu^(-1)}, yw] + 
     4*G[{0}, yv^(-1)]*G[{yu}, yv^(-1)]*G[{0, 1, yu^(-1)}, yw] - 
     4*G[{0}, yw]*G[{yu}, yv^(-1)]*G[{0, 1, yu^(-1)}, yw] - 
     8*G[{1}, yu^(-1)]*G[{yu}, yv^(-1)]*G[{0, 1, yu^(-1)}, yw] - 
     8*G[{1}, yv^(-1)]*G[{yu}, yv^(-1)]*G[{0, 1, yu^(-1)}, yw] + 
     4*G[{yu}, yv^(-1)]^2*G[{0, 1, yu^(-1)}, yw] - 
     4*G[{1}, yu^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, 1, yu^(-1)}, yw] + 
     4*G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, 1, yu^(-1)}, yw] + 
     4*G[{0, yv^(-1)}, yw]*G[{0, 1, yu^(-1)}, yw] - 
     Pi^2*G[{0, 1, yu}, yv^(-1)] - 2*G[{0}, yu^(-1)]^2*
      G[{0, 1, yu}, yv^(-1)] - 4*G[{0}, yu^(-1)]*G[{0}, yv^(-1)]*
      G[{0, 1, yu}, yv^(-1)] - 2*G[{0}, yv^(-1)]^2*G[{0, 1, yu}, yv^(-1)] + 
     4*G[{0}, yu^(-1)]*G[{0}, yw]*G[{0, 1, yu}, yv^(-1)] + 
     4*G[{0}, yv^(-1)]*G[{0}, yw]*G[{0, 1, yu}, yv^(-1)] - 
     2*G[{0}, yw]^2*G[{0, 1, yu}, yv^(-1)] + 6*G[{0}, yu^(-1)]*
      G[{1}, yu^(-1)]*G[{0, 1, yu}, yv^(-1)] + 6*G[{0}, yv^(-1)]*
      G[{1}, yu^(-1)]*G[{0, 1, yu}, yv^(-1)] - 6*G[{0}, yw]*G[{1}, yu^(-1)]*
      G[{0, 1, yu}, yv^(-1)] - 4*G[{1}, yu^(-1)]^2*G[{0, 1, yu}, yv^(-1)] + 
     2*G[{0}, yu^(-1)]*G[{1}, yv^(-1)]*G[{0, 1, yu}, yv^(-1)] + 
     2*G[{0}, yv^(-1)]*G[{1}, yv^(-1)]*G[{0, 1, yu}, yv^(-1)] - 
     2*G[{0}, yw]*G[{1}, yv^(-1)]*G[{0, 1, yu}, yv^(-1)] - 
     4*G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*G[{0, 1, yu}, yv^(-1)] - 
     2*G[{0}, yu^(-1)]*G[{1}, yw]*G[{0, 1, yu}, yv^(-1)] - 
     2*G[{0}, yv^(-1)]*G[{1}, yw]*G[{0, 1, yu}, yv^(-1)] + 
     2*G[{0}, yw]*G[{1}, yw]*G[{0, 1, yu}, yv^(-1)] - 
     2*G[{0}, yu^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, 1, yu}, yv^(-1)] - 
     2*G[{0}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, 1, yu}, yv^(-1)] + 
     2*G[{0}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1, yu}, yv^(-1)] + 
     4*G[{1}, yu^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, 1, yu}, yv^(-1)] - 
     2*G[{0, 1}, yu^(-1)]*G[{0, 1, yu}, yv^(-1)] + 2*G[{0, 1}, yv^(-1)]*
      G[{0, 1, yu}, yv^(-1)] - 4*G[{0, 1}, yw]*G[{0, 1, yu}, yv^(-1)] + 
     4*G[{0, yu}, yv^(-1)]*G[{0, 1, yu}, yv^(-1)] + 
     4*G[{0, yv^(-1)}, yw]*G[{0, 1, yu}, yv^(-1)] + 
     Pi^2*G[{0, 1, yv^(-1)}, yw] + 2*G[{0}, yu^(-1)]^2*
      G[{0, 1, yv^(-1)}, yw] + 4*G[{0}, yu^(-1)]*G[{0}, yv^(-1)]*
      G[{0, 1, yv^(-1)}, yw] + 2*G[{0}, yv^(-1)]^2*G[{0, 1, yv^(-1)}, yw] - 
     4*G[{0}, yu^(-1)]*G[{0}, yw]*G[{0, 1, yv^(-1)}, yw] - 
     4*G[{0}, yv^(-1)]*G[{0}, yw]*G[{0, 1, yv^(-1)}, yw] + 
     2*G[{0}, yw]^2*G[{0, 1, yv^(-1)}, yw] - 6*G[{0}, yu^(-1)]*
      G[{1}, yu^(-1)]*G[{0, 1, yv^(-1)}, yw] - 6*G[{0}, yv^(-1)]*
      G[{1}, yu^(-1)]*G[{0, 1, yv^(-1)}, yw] + 6*G[{0}, yw]*G[{1}, yu^(-1)]*
      G[{0, 1, yv^(-1)}, yw] + 4*G[{1}, yu^(-1)]^2*G[{0, 1, yv^(-1)}, yw] - 
     6*G[{0}, yu^(-1)]*G[{1}, yv^(-1)]*G[{0, 1, yv^(-1)}, yw] - 
     6*G[{0}, yv^(-1)]*G[{1}, yv^(-1)]*G[{0, 1, yv^(-1)}, yw] + 
     6*G[{0}, yw]*G[{1}, yv^(-1)]*G[{0, 1, yv^(-1)}, yw] + 
     12*G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*G[{0, 1, yv^(-1)}, yw] + 
     6*G[{1}, yv^(-1)]^2*G[{0, 1, yv^(-1)}, yw] + 
     2*G[{0}, yu^(-1)]*G[{1}, yw]*G[{0, 1, yv^(-1)}, yw] + 
     2*G[{0}, yv^(-1)]*G[{1}, yw]*G[{0, 1, yv^(-1)}, yw] - 
     2*G[{0}, yw]*G[{1}, yw]*G[{0, 1, yv^(-1)}, yw] - 
     4*G[{1}, yu^(-1)]*G[{1}, yw]*G[{0, 1, yv^(-1)}, yw] + 
     4*G[{0}, yu^(-1)]*G[{yu}, yv^(-1)]*G[{0, 1, yv^(-1)}, yw] + 
     4*G[{0}, yv^(-1)]*G[{yu}, yv^(-1)]*G[{0, 1, yv^(-1)}, yw] - 
     4*G[{0}, yw]*G[{yu}, yv^(-1)]*G[{0, 1, yv^(-1)}, yw] - 
     8*G[{1}, yu^(-1)]*G[{yu}, yv^(-1)]*G[{0, 1, yv^(-1)}, yw] - 
     8*G[{1}, yv^(-1)]*G[{yu}, yv^(-1)]*G[{0, 1, yv^(-1)}, yw] + 
     4*G[{yu}, yv^(-1)]^2*G[{0, 1, yv^(-1)}, yw] + 
     2*G[{0}, yu^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, 1, yv^(-1)}, yw] + 
     2*G[{0}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, 1, yv^(-1)}, yw] - 
     2*G[{0}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1, yv^(-1)}, yw] - 
     4*G[{1}, yu^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, 1, yv^(-1)}, yw] - 
     4*G[{1}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, 1, yv^(-1)}, yw] + 
     4*G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, 1, yv^(-1)}, yw] + 
     2*G[{0, 1}, yu^(-1)]*G[{0, 1, yv^(-1)}, yw] - 2*G[{0, 1}, yv^(-1)]*
      G[{0, 1, yv^(-1)}, yw] + 2*G[{0, 1}, yw]*G[{0, 1, yv^(-1)}, yw] - 
     2*G[{0, yu^(-1)}, yw]*G[{0, 1, yv^(-1)}, yw] + 
     2*G[{0, yu}, yv^(-1)]*G[{0, 1, yv^(-1)}, yw] + 
     4*G[{0, yv^(-1)}, yw]*G[{0, 1, yv^(-1)}, yw] - 
     4*G[{1, yu}, yv^(-1)]*G[{0, 1, yv^(-1)}, yw] + 
     2*G[{0}, yu^(-1)]*G[{1}, yu^(-1)]*G[{0, 1, 1/(yu*yv)}, yw] + 
     2*G[{0}, yv^(-1)]*G[{1}, yu^(-1)]*G[{0, 1, 1/(yu*yv)}, yw] - 
     2*G[{0}, yw]*G[{1}, yu^(-1)]*G[{0, 1, 1/(yu*yv)}, yw] - 
     2*G[{1}, yu^(-1)]^2*G[{0, 1, 1/(yu*yv)}, yw] - 
     4*G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*G[{0, 1, 1/(yu*yv)}, yw] + 
     2*G[{1}, yu^(-1)]*G[{1}, yw]*G[{0, 1, 1/(yu*yv)}, yw] - 
     2*G[{0}, yu^(-1)]*G[{yu}, yv^(-1)]*G[{0, 1, 1/(yu*yv)}, yw] - 
     2*G[{0}, yv^(-1)]*G[{yu}, yv^(-1)]*G[{0, 1, 1/(yu*yv)}, yw] + 
     2*G[{0}, yw]*G[{yu}, yv^(-1)]*G[{0, 1, 1/(yu*yv)}, yw] + 
     4*G[{1}, yu^(-1)]*G[{yu}, yv^(-1)]*G[{0, 1, 1/(yu*yv)}, yw] + 
     4*G[{1}, yv^(-1)]*G[{yu}, yv^(-1)]*G[{0, 1, 1/(yu*yv)}, yw] - 
     2*G[{1}, yw]*G[{yu}, yv^(-1)]*G[{0, 1, 1/(yu*yv)}, yw] - 
     2*G[{yu}, yv^(-1)]^2*G[{0, 1, 1/(yu*yv)}, yw] + 
     2*G[{1}, yu^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, 1, 1/(yu*yv)}, yw] - 
     2*G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, 1, 1/(yu*yv)}, yw] - 
     2*G[{0, yv^(-1)}, yw]*G[{0, 1, 1/(yu*yv)}, yw] - 
     2*G[{0, 1/(yu*yv)}, yw]*G[{0, 1, 1/(yu*yv)}, yw] - 
     2*G[{0}, yu^(-1)]*G[{1}, yu^(-1)]*G[{0, yu^(-1), 1}, yw] - 
     2*G[{0}, yv^(-1)]*G[{1}, yu^(-1)]*G[{0, yu^(-1), 1}, yw] + 
     2*G[{0}, yw]*G[{1}, yu^(-1)]*G[{0, yu^(-1), 1}, yw] + 
     2*G[{1}, yu^(-1)]^2*G[{0, yu^(-1), 1}, yw] + 
     4*G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*G[{0, yu^(-1), 1}, yw] + 
     2*G[{1}, yu^(-1)]*G[{1}, yw]*G[{0, yu^(-1), 1}, yw] + 
     2*G[{0}, yu^(-1)]*G[{yu}, yv^(-1)]*G[{0, yu^(-1), 1}, yw] + 
     2*G[{0}, yv^(-1)]*G[{yu}, yv^(-1)]*G[{0, yu^(-1), 1}, yw] - 
     2*G[{0}, yw]*G[{yu}, yv^(-1)]*G[{0, yu^(-1), 1}, yw] - 
     4*G[{1}, yu^(-1)]*G[{yu}, yv^(-1)]*G[{0, yu^(-1), 1}, yw] - 
     4*G[{1}, yv^(-1)]*G[{yu}, yv^(-1)]*G[{0, yu^(-1), 1}, yw] - 
     2*G[{1}, yw]*G[{yu}, yv^(-1)]*G[{0, yu^(-1), 1}, yw] + 
     2*G[{yu}, yv^(-1)]^2*G[{0, yu^(-1), 1}, yw] - 
     2*G[{1}, yu^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1), 1}, yw] + 
     2*G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1), 1}, yw] + 
     2*G[{0, yv^(-1)}, yw]*G[{0, yu^(-1), 1}, yw] + 
     2*G[{0, 1/(yu*yv)}, yw]*G[{0, yu^(-1), 1}, yw] + 
     (4*Pi^2*G[{0, yu^(-1), yu^(-1)}, yw])/3 + 2*G[{0}, yu^(-1)]^2*
      G[{0, yu^(-1), yu^(-1)}, yw] + 4*G[{0}, yu^(-1)]*G[{0}, yv^(-1)]*
      G[{0, yu^(-1), yu^(-1)}, yw] + 2*G[{0}, yv^(-1)]^2*
      G[{0, yu^(-1), yu^(-1)}, yw] - 4*G[{0}, yu^(-1)]*G[{0}, yw]*
      G[{0, yu^(-1), yu^(-1)}, yw] - 4*G[{0}, yv^(-1)]*G[{0}, yw]*
      G[{0, yu^(-1), yu^(-1)}, yw] + 2*G[{0}, yw]^2*G[{0, yu^(-1), yu^(-1)}, 
       yw] - 2*G[{1}, yu^(-1)]^2*G[{0, yu^(-1), yu^(-1)}, yw] - 
     8*G[{0}, yu^(-1)]*G[{1}, yv^(-1)]*G[{0, yu^(-1), yu^(-1)}, yw] - 
     8*G[{0}, yv^(-1)]*G[{1}, yv^(-1)]*G[{0, yu^(-1), yu^(-1)}, yw] + 
     8*G[{0}, yw]*G[{1}, yv^(-1)]*G[{0, yu^(-1), yu^(-1)}, yw] + 
     4*G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*G[{0, yu^(-1), yu^(-1)}, yw] + 
     8*G[{1}, yv^(-1)]^2*G[{0, yu^(-1), yu^(-1)}, yw] - 
     2*G[{1}, yw]^2*G[{0, yu^(-1), yu^(-1)}, yw] + 
     4*G[{0}, yu^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1), yu^(-1)}, yw] + 
     4*G[{0}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1), yu^(-1)}, yw] - 
     4*G[{0}, yw]*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1), yu^(-1)}, yw] - 
     8*G[{1}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1), yu^(-1)}, yw] + 
     2*G[{1/(yu*yv)}, yw]^2*G[{0, yu^(-1), yu^(-1)}, yw] + 
     4*G[{0, 1}, yu^(-1)]*G[{0, yu^(-1), yu^(-1)}, yw] - 
     4*G[{0, yv^(-1)}, yw]*G[{0, yu^(-1), yu^(-1)}, yw] - 
     4*G[{1, yu}, yv^(-1)]*G[{0, yu^(-1), yu^(-1)}, yw] - 
     4*G[{0, yv^(-1)}, yw]*G[{0, yu^(-1), yv^(-1)}, yw] - 
     Pi^2*G[{0, yu^(-1), 1/(yu*yv)}, yw] - 2*G[{0}, yu^(-1)]^2*
      G[{0, yu^(-1), 1/(yu*yv)}, yw] - 4*G[{0}, yu^(-1)]*G[{0}, yv^(-1)]*
      G[{0, yu^(-1), 1/(yu*yv)}, yw] - 2*G[{0}, yv^(-1)]^2*
      G[{0, yu^(-1), 1/(yu*yv)}, yw] + 4*G[{0}, yu^(-1)]*G[{0}, yw]*
      G[{0, yu^(-1), 1/(yu*yv)}, yw] + 4*G[{0}, yv^(-1)]*G[{0}, yw]*
      G[{0, yu^(-1), 1/(yu*yv)}, yw] - 2*G[{0}, yw]^2*
      G[{0, yu^(-1), 1/(yu*yv)}, yw] + 4*G[{0}, yu^(-1)]*G[{1}, yu^(-1)]*
      G[{0, yu^(-1), 1/(yu*yv)}, yw] + 4*G[{0}, yv^(-1)]*G[{1}, yu^(-1)]*
      G[{0, yu^(-1), 1/(yu*yv)}, yw] - 4*G[{0}, yw]*G[{1}, yu^(-1)]*
      G[{0, yu^(-1), 1/(yu*yv)}, yw] - 2*G[{1}, yu^(-1)]^2*
      G[{0, yu^(-1), 1/(yu*yv)}, yw] + 6*G[{0}, yu^(-1)]*G[{1}, yv^(-1)]*
      G[{0, yu^(-1), 1/(yu*yv)}, yw] + 6*G[{0}, yv^(-1)]*G[{1}, yv^(-1)]*
      G[{0, yu^(-1), 1/(yu*yv)}, yw] - 6*G[{0}, yw]*G[{1}, yv^(-1)]*
      G[{0, yu^(-1), 1/(yu*yv)}, yw] - 8*G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*
      G[{0, yu^(-1), 1/(yu*yv)}, yw] - 6*G[{1}, yv^(-1)]^2*
      G[{0, yu^(-1), 1/(yu*yv)}, yw] - 2*G[{0}, yu^(-1)]*G[{1}, yw]*
      G[{0, yu^(-1), 1/(yu*yv)}, yw] - 2*G[{0}, yv^(-1)]*G[{1}, yw]*
      G[{0, yu^(-1), 1/(yu*yv)}, yw] + 2*G[{0}, yw]*G[{1}, yw]*
      G[{0, yu^(-1), 1/(yu*yv)}, yw] + 2*G[{1}, yu^(-1)]*G[{1}, yw]*
      G[{0, yu^(-1), 1/(yu*yv)}, yw] - 2*G[{0}, yu^(-1)]*G[{yu}, yv^(-1)]*
      G[{0, yu^(-1), 1/(yu*yv)}, yw] - 2*G[{0}, yv^(-1)]*G[{yu}, yv^(-1)]*
      G[{0, yu^(-1), 1/(yu*yv)}, yw] + 2*G[{0}, yw]*G[{yu}, yv^(-1)]*
      G[{0, yu^(-1), 1/(yu*yv)}, yw] + 4*G[{1}, yu^(-1)]*G[{yu}, yv^(-1)]*
      G[{0, yu^(-1), 1/(yu*yv)}, yw] + 4*G[{1}, yv^(-1)]*G[{yu}, yv^(-1)]*
      G[{0, yu^(-1), 1/(yu*yv)}, yw] + 2*G[{1}, yw]*G[{yu}, yv^(-1)]*
      G[{0, yu^(-1), 1/(yu*yv)}, yw] - 2*G[{yu}, yv^(-1)]^2*
      G[{0, yu^(-1), 1/(yu*yv)}, yw] - 2*G[{0}, yu^(-1)]*G[{1/(yu*yv)}, yw]*
      G[{0, yu^(-1), 1/(yu*yv)}, yw] - 2*G[{0}, yv^(-1)]*G[{1/(yu*yv)}, yw]*
      G[{0, yu^(-1), 1/(yu*yv)}, yw] + 2*G[{0}, yw]*G[{1/(yu*yv)}, yw]*
      G[{0, yu^(-1), 1/(yu*yv)}, yw] + 2*G[{1}, yu^(-1)]*G[{1/(yu*yv)}, yw]*
      G[{0, yu^(-1), 1/(yu*yv)}, yw] + 4*G[{1}, yv^(-1)]*G[{1/(yu*yv)}, yw]*
      G[{0, yu^(-1), 1/(yu*yv)}, yw] - 2*G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw]*
      G[{0, yu^(-1), 1/(yu*yv)}, yw] - 2*G[{0, 1}, yu^(-1)]*
      G[{0, yu^(-1), 1/(yu*yv)}, yw] + 2*G[{0, 1}, yv^(-1)]*
      G[{0, yu^(-1), 1/(yu*yv)}, yw] - 2*G[{0, 1}, yw]*
      G[{0, yu^(-1), 1/(yu*yv)}, yw] + 2*G[{0, yu^(-1)}, yw]*
      G[{0, yu^(-1), 1/(yu*yv)}, yw] - 2*G[{0, yu}, yv^(-1)]*
      G[{0, yu^(-1), 1/(yu*yv)}, yw] + 2*G[{0, yv^(-1)}, yw]*
      G[{0, yu^(-1), 1/(yu*yv)}, yw] + 2*G[{0, 1/(yu*yv)}, yw]*
      G[{0, yu^(-1), 1/(yu*yv)}, yw] + 4*G[{1, yu}, yv^(-1)]*
      G[{0, yu^(-1), 1/(yu*yv)}, yw] + 2*G[{0}, yu^(-1)]*G[{1}, yu^(-1)]*
      G[{0, yu, 1}, yv^(-1)] + 2*G[{0}, yv^(-1)]*G[{1}, yu^(-1)]*
      G[{0, yu, 1}, yv^(-1)] - 2*G[{0}, yw]*G[{1}, yu^(-1)]*
      G[{0, yu, 1}, yv^(-1)] - 2*G[{1}, yu^(-1)]^2*G[{0, yu, 1}, yv^(-1)] - 
     2*G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*G[{0, yu, 1}, yv^(-1)] - 
     2*G[{1}, yu^(-1)]*G[{1}, yw]*G[{0, yu, 1}, yv^(-1)] + 
     2*G[{1}, yu^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, yu, 1}, yv^(-1)] - 
     2*G[{0, 1}, yw]*G[{0, yu, 1}, yv^(-1)] - 2*G[{0, yu^(-1)}, yw]*
      G[{0, yu, 1}, yv^(-1)] + 2*G[{0, yv^(-1)}, yw]*G[{0, yu, 1}, yv^(-1)] + 
     2*G[{0, 1/(yu*yv)}, yw]*G[{0, yu, 1}, yv^(-1)] + 
     (2*Pi^2*G[{0, yu, yu}, yv^(-1)])/3 + 2*G[{0}, yu^(-1)]^2*
      G[{0, yu, yu}, yv^(-1)] + 4*G[{0}, yu^(-1)]*G[{0}, yv^(-1)]*
      G[{0, yu, yu}, yv^(-1)] + 2*G[{0}, yv^(-1)]^2*G[{0, yu, yu}, yv^(-1)] - 
     4*G[{0}, yu^(-1)]*G[{0}, yw]*G[{0, yu, yu}, yv^(-1)] - 
     4*G[{0}, yv^(-1)]*G[{0}, yw]*G[{0, yu, yu}, yv^(-1)] + 
     2*G[{0}, yw]^2*G[{0, yu, yu}, yv^(-1)] - 4*G[{0}, yu^(-1)]*
      G[{1}, yu^(-1)]*G[{0, yu, yu}, yv^(-1)] - 4*G[{0}, yv^(-1)]*
      G[{1}, yu^(-1)]*G[{0, yu, yu}, yv^(-1)] + 4*G[{0}, yw]*G[{1}, yu^(-1)]*
      G[{0, yu, yu}, yv^(-1)] + 2*G[{1}, yu^(-1)]^2*G[{0, yu, yu}, yv^(-1)] - 
     2*G[{1}, yv^(-1)]^2*G[{0, yu, yu}, yv^(-1)] + 
     4*G[{0}, yu^(-1)]*G[{1}, yw]*G[{0, yu, yu}, yv^(-1)] + 
     4*G[{0}, yv^(-1)]*G[{1}, yw]*G[{0, yu, yu}, yv^(-1)] - 
     4*G[{0}, yw]*G[{1}, yw]*G[{0, yu, yu}, yv^(-1)] + 
     2*G[{1}, yw]^2*G[{0, yu, yu}, yv^(-1)] + 4*G[{1}, yv^(-1)]*
      G[{1/(yu*yv)}, yw]*G[{0, yu, yu}, yv^(-1)] - 2*G[{1/(yu*yv)}, yw]^2*
      G[{0, yu, yu}, yv^(-1)] - 4*G[{0, 1}, yv^(-1)]*
      G[{0, yu, yu}, yv^(-1)] + 4*G[{0, 1}, yw]*G[{0, yu, yu}, yv^(-1)] + 
     4*G[{0, yu}, yv^(-1)]*G[{0, yu, yu}, yv^(-1)] - 
     4*G[{0, yv^(-1)}, yw]*G[{0, yu, yu}, yv^(-1)] + 
     Pi^2*G[{0, yv^(-1), 1}, yw] + 2*G[{0}, yu^(-1)]^2*
      G[{0, yv^(-1), 1}, yw] + 4*G[{0}, yu^(-1)]*G[{0}, yv^(-1)]*
      G[{0, yv^(-1), 1}, yw] + 2*G[{0}, yv^(-1)]^2*G[{0, yv^(-1), 1}, yw] - 
     4*G[{0}, yu^(-1)]*G[{0}, yw]*G[{0, yv^(-1), 1}, yw] - 
     4*G[{0}, yv^(-1)]*G[{0}, yw]*G[{0, yv^(-1), 1}, yw] + 
     2*G[{0}, yw]^2*G[{0, yv^(-1), 1}, yw] - 4*G[{0}, yu^(-1)]*
      G[{1}, yu^(-1)]*G[{0, yv^(-1), 1}, yw] - 4*G[{0}, yv^(-1)]*
      G[{1}, yu^(-1)]*G[{0, yv^(-1), 1}, yw] + 4*G[{0}, yw]*G[{1}, yu^(-1)]*
      G[{0, yv^(-1), 1}, yw] + 2*G[{1}, yu^(-1)]^2*G[{0, yv^(-1), 1}, yw] - 
     6*G[{0}, yu^(-1)]*G[{1}, yv^(-1)]*G[{0, yv^(-1), 1}, yw] - 
     6*G[{0}, yv^(-1)]*G[{1}, yv^(-1)]*G[{0, yv^(-1), 1}, yw] + 
     6*G[{0}, yw]*G[{1}, yv^(-1)]*G[{0, yv^(-1), 1}, yw] + 
     8*G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*G[{0, yv^(-1), 1}, yw] + 
     6*G[{1}, yv^(-1)]^2*G[{0, yv^(-1), 1}, yw] + 
     2*G[{0}, yu^(-1)]*G[{1}, yw]*G[{0, yv^(-1), 1}, yw] + 
     2*G[{0}, yv^(-1)]*G[{1}, yw]*G[{0, yv^(-1), 1}, yw] - 
     2*G[{0}, yw]*G[{1}, yw]*G[{0, yv^(-1), 1}, yw] - 
     2*G[{1}, yu^(-1)]*G[{1}, yw]*G[{0, yv^(-1), 1}, yw] + 
     2*G[{0}, yu^(-1)]*G[{yu}, yv^(-1)]*G[{0, yv^(-1), 1}, yw] + 
     2*G[{0}, yv^(-1)]*G[{yu}, yv^(-1)]*G[{0, yv^(-1), 1}, yw] - 
     2*G[{0}, yw]*G[{yu}, yv^(-1)]*G[{0, yv^(-1), 1}, yw] - 
     4*G[{1}, yu^(-1)]*G[{yu}, yv^(-1)]*G[{0, yv^(-1), 1}, yw] - 
     4*G[{1}, yv^(-1)]*G[{yu}, yv^(-1)]*G[{0, yv^(-1), 1}, yw] - 
     2*G[{1}, yw]*G[{yu}, yv^(-1)]*G[{0, yv^(-1), 1}, yw] + 
     2*G[{yu}, yv^(-1)]^2*G[{0, yv^(-1), 1}, yw] + 
     2*G[{0}, yu^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, yv^(-1), 1}, yw] + 
     2*G[{0}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, yv^(-1), 1}, yw] - 
     2*G[{0}, yw]*G[{1/(yu*yv)}, yw]*G[{0, yv^(-1), 1}, yw] - 
     2*G[{1}, yu^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, yv^(-1), 1}, yw] - 
     4*G[{1}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, yv^(-1), 1}, yw] + 
     2*G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, yv^(-1), 1}, yw] + 
     2*G[{0, 1}, yu^(-1)]*G[{0, yv^(-1), 1}, yw] - 2*G[{0, 1}, yv^(-1)]*
      G[{0, yv^(-1), 1}, yw] + 2*G[{0, 1}, yw]*G[{0, yv^(-1), 1}, yw] - 
     2*G[{0, yu^(-1)}, yw]*G[{0, yv^(-1), 1}, yw] + 
     2*G[{0, yu}, yv^(-1)]*G[{0, yv^(-1), 1}, yw] - 
     2*G[{0, yv^(-1)}, yw]*G[{0, yv^(-1), 1}, yw] + 
     2*G[{0, 1/(yu*yv)}, yw]*G[{0, yv^(-1), 1}, yw] - 
     4*G[{1, yu}, yv^(-1)]*G[{0, yv^(-1), 1}, yw] - 
     (2*Pi^2*G[{0, yv^(-1), yv^(-1)}, yw])/3 - 2*G[{0}, yu^(-1)]^2*
      G[{0, yv^(-1), yv^(-1)}, yw] - 4*G[{0}, yu^(-1)]*G[{0}, yv^(-1)]*
      G[{0, yv^(-1), yv^(-1)}, yw] - 2*G[{0}, yv^(-1)]^2*
      G[{0, yv^(-1), yv^(-1)}, yw] + 4*G[{0}, yu^(-1)]*G[{0}, yw]*
      G[{0, yv^(-1), yv^(-1)}, yw] + 4*G[{0}, yv^(-1)]*G[{0}, yw]*
      G[{0, yv^(-1), yv^(-1)}, yw] - 2*G[{0}, yw]^2*G[{0, yv^(-1), yv^(-1)}, 
       yw] + 4*G[{0}, yu^(-1)]*G[{1}, yu^(-1)]*G[{0, yv^(-1), yv^(-1)}, yw] + 
     4*G[{0}, yv^(-1)]*G[{1}, yu^(-1)]*G[{0, yv^(-1), yv^(-1)}, yw] - 
     4*G[{0}, yw]*G[{1}, yu^(-1)]*G[{0, yv^(-1), yv^(-1)}, yw] - 
     2*G[{1}, yu^(-1)]^2*G[{0, yv^(-1), yv^(-1)}, yw] + 
     4*G[{0}, yu^(-1)]*G[{1}, yv^(-1)]*G[{0, yv^(-1), yv^(-1)}, yw] + 
     4*G[{0}, yv^(-1)]*G[{1}, yv^(-1)]*G[{0, yv^(-1), yv^(-1)}, yw] - 
     4*G[{0}, yw]*G[{1}, yv^(-1)]*G[{0, yv^(-1), yv^(-1)}, yw] - 
     4*G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*G[{0, yv^(-1), yv^(-1)}, yw] - 
     4*G[{1}, yv^(-1)]^2*G[{0, yv^(-1), yv^(-1)}, yw] - 
     4*G[{0}, yu^(-1)]*G[{1}, yw]*G[{0, yv^(-1), yv^(-1)}, yw] - 
     4*G[{0}, yv^(-1)]*G[{1}, yw]*G[{0, yv^(-1), yv^(-1)}, yw] + 
     4*G[{0}, yw]*G[{1}, yw]*G[{0, yv^(-1), yv^(-1)}, yw] + 
     8*G[{1}, yu^(-1)]*G[{1}, yw]*G[{0, yv^(-1), yv^(-1)}, yw] - 
     2*G[{1}, yw]^2*G[{0, yv^(-1), yv^(-1)}, yw] + 2*G[{1/(yu*yv)}, yw]^2*
      G[{0, yv^(-1), yv^(-1)}, yw] + 4*G[{0, 1}, yv^(-1)]*
      G[{0, yv^(-1), yv^(-1)}, yw] - 4*G[{0, 1}, yw]*G[{0, yv^(-1), yv^(-1)}, 
       yw] + 4*G[{0, yu^(-1)}, yw]*G[{0, yv^(-1), yv^(-1)}, yw] - 
     4*G[{0, yu}, yv^(-1)]*G[{0, yv^(-1), yv^(-1)}, yw] + 
     4*G[{0, yv^(-1)}, yw]*G[{0, yv^(-1), yv^(-1)}, yw] + 
     4*G[{1, yu}, yv^(-1)]*G[{0, yv^(-1), yv^(-1)}, yw] + 
     2*G[{0}, yu^(-1)]*G[{1}, yu^(-1)]*G[{0, yv^(-1), 1/(yu*yv)}, yw] + 
     2*G[{0}, yv^(-1)]*G[{1}, yu^(-1)]*G[{0, yv^(-1), 1/(yu*yv)}, yw] - 
     2*G[{0}, yw]*G[{1}, yu^(-1)]*G[{0, yv^(-1), 1/(yu*yv)}, yw] - 
     2*G[{1}, yu^(-1)]^2*G[{0, yv^(-1), 1/(yu*yv)}, yw] - 
     4*G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*G[{0, yv^(-1), 1/(yu*yv)}, yw] - 
     2*G[{1}, yu^(-1)]*G[{1}, yw]*G[{0, yv^(-1), 1/(yu*yv)}, yw] - 
     2*G[{0}, yu^(-1)]*G[{yu}, yv^(-1)]*G[{0, yv^(-1), 1/(yu*yv)}, yw] - 
     2*G[{0}, yv^(-1)]*G[{yu}, yv^(-1)]*G[{0, yv^(-1), 1/(yu*yv)}, yw] + 
     2*G[{0}, yw]*G[{yu}, yv^(-1)]*G[{0, yv^(-1), 1/(yu*yv)}, yw] + 
     4*G[{1}, yu^(-1)]*G[{yu}, yv^(-1)]*G[{0, yv^(-1), 1/(yu*yv)}, yw] + 
     4*G[{1}, yv^(-1)]*G[{yu}, yv^(-1)]*G[{0, yv^(-1), 1/(yu*yv)}, yw] + 
     2*G[{1}, yw]*G[{yu}, yv^(-1)]*G[{0, yv^(-1), 1/(yu*yv)}, yw] - 
     2*G[{yu}, yv^(-1)]^2*G[{0, yv^(-1), 1/(yu*yv)}, yw] + 
     2*G[{1}, yu^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, yv^(-1), 1/(yu*yv)}, yw] - 
     2*G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, yv^(-1), 1/(yu*yv)}, yw] + 
     2*G[{0, 1/(yu*yv)}, yw]*G[{0, yv^(-1), 1/(yu*yv)}, yw] + 
     (Pi^2*G[{0, 1/(yu*yv), 1}, yw])/3 - 2*G[{0}, yu^(-1)]*G[{1}, yv^(-1)]*
      G[{0, 1/(yu*yv), 1}, yw] - 2*G[{0}, yv^(-1)]*G[{1}, yv^(-1)]*
      G[{0, 1/(yu*yv), 1}, yw] + 2*G[{0}, yw]*G[{1}, yv^(-1)]*
      G[{0, 1/(yu*yv), 1}, yw] + 4*G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*
      G[{0, 1/(yu*yv), 1}, yw] + 2*G[{1}, yv^(-1)]^2*
      G[{0, 1/(yu*yv), 1}, yw] - 2*G[{0}, yu^(-1)]*G[{1}, yw]*
      G[{0, 1/(yu*yv), 1}, yw] - 2*G[{0}, yv^(-1)]*G[{1}, yw]*
      G[{0, 1/(yu*yv), 1}, yw] + 2*G[{0}, yw]*G[{1}, yw]*
      G[{0, 1/(yu*yv), 1}, yw] + 2*G[{1}, yu^(-1)]*G[{1}, yw]*
      G[{0, 1/(yu*yv), 1}, yw] - 2*G[{1}, yw]^2*G[{0, 1/(yu*yv), 1}, yw] + 
     2*G[{0}, yu^(-1)]*G[{yu}, yv^(-1)]*G[{0, 1/(yu*yv), 1}, yw] + 
     2*G[{0}, yv^(-1)]*G[{yu}, yv^(-1)]*G[{0, 1/(yu*yv), 1}, yw] - 
     2*G[{0}, yw]*G[{yu}, yv^(-1)]*G[{0, 1/(yu*yv), 1}, yw] - 
     4*G[{1}, yu^(-1)]*G[{yu}, yv^(-1)]*G[{0, 1/(yu*yv), 1}, yw] - 
     4*G[{1}, yv^(-1)]*G[{yu}, yv^(-1)]*G[{0, 1/(yu*yv), 1}, yw] + 
     2*G[{1}, yw]*G[{yu}, yv^(-1)]*G[{0, 1/(yu*yv), 1}, yw] + 
     2*G[{yu}, yv^(-1)]^2*G[{0, 1/(yu*yv), 1}, yw] + 
     2*G[{0}, yu^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv), 1}, yw] + 
     2*G[{0}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv), 1}, yw] - 
     2*G[{0}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv), 1}, yw] - 
     2*G[{1}, yu^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv), 1}, yw] - 
     4*G[{1}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv), 1}, yw] + 
     2*G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv), 1}, yw] + 
     2*G[{1/(yu*yv)}, yw]^2*G[{0, 1/(yu*yv), 1}, yw] + 
     2*G[{0, 1}, yu^(-1)]*G[{0, 1/(yu*yv), 1}, yw] + 
     2*G[{0, 1}, yv^(-1)]*G[{0, 1/(yu*yv), 1}, yw] - 
     2*G[{0, 1}, yw]*G[{0, 1/(yu*yv), 1}, yw] + 2*G[{0, yu^(-1)}, yw]*
      G[{0, 1/(yu*yv), 1}, yw] - 2*G[{0, yu}, yv^(-1)]*
      G[{0, 1/(yu*yv), 1}, yw] + 2*G[{0, yv^(-1)}, yw]*
      G[{0, 1/(yu*yv), 1}, yw] - 2*G[{0, 1/(yu*yv)}, yw]*
      G[{0, 1/(yu*yv), 1}, yw] - (4*Pi^2*G[{0, 1/(yu*yv), yu^(-1)}, yw])/3 - 
     2*G[{0}, yu^(-1)]^2*G[{0, 1/(yu*yv), yu^(-1)}, yw] - 
     4*G[{0}, yu^(-1)]*G[{0}, yv^(-1)]*G[{0, 1/(yu*yv), yu^(-1)}, yw] - 
     2*G[{0}, yv^(-1)]^2*G[{0, 1/(yu*yv), yu^(-1)}, yw] + 
     4*G[{0}, yu^(-1)]*G[{0}, yw]*G[{0, 1/(yu*yv), yu^(-1)}, yw] + 
     4*G[{0}, yv^(-1)]*G[{0}, yw]*G[{0, 1/(yu*yv), yu^(-1)}, yw] - 
     2*G[{0}, yw]^2*G[{0, 1/(yu*yv), yu^(-1)}, yw] + 
     4*G[{0}, yu^(-1)]*G[{1}, yu^(-1)]*G[{0, 1/(yu*yv), yu^(-1)}, yw] + 
     4*G[{0}, yv^(-1)]*G[{1}, yu^(-1)]*G[{0, 1/(yu*yv), yu^(-1)}, yw] - 
     4*G[{0}, yw]*G[{1}, yu^(-1)]*G[{0, 1/(yu*yv), yu^(-1)}, yw] - 
     2*G[{1}, yu^(-1)]^2*G[{0, 1/(yu*yv), yu^(-1)}, yw] + 
     8*G[{0}, yu^(-1)]*G[{1}, yv^(-1)]*G[{0, 1/(yu*yv), yu^(-1)}, yw] + 
     8*G[{0}, yv^(-1)]*G[{1}, yv^(-1)]*G[{0, 1/(yu*yv), yu^(-1)}, yw] - 
     8*G[{0}, yw]*G[{1}, yv^(-1)]*G[{0, 1/(yu*yv), yu^(-1)}, yw] - 
     12*G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*G[{0, 1/(yu*yv), yu^(-1)}, yw] - 
     8*G[{1}, yv^(-1)]^2*G[{0, 1/(yu*yv), yu^(-1)}, yw] + 
     2*G[{1}, yw]^2*G[{0, 1/(yu*yv), yu^(-1)}, yw] - 
     4*G[{0}, yu^(-1)]*G[{yu}, yv^(-1)]*G[{0, 1/(yu*yv), yu^(-1)}, yw] - 
     4*G[{0}, yv^(-1)]*G[{yu}, yv^(-1)]*G[{0, 1/(yu*yv), yu^(-1)}, yw] + 
     4*G[{0}, yw]*G[{yu}, yv^(-1)]*G[{0, 1/(yu*yv), yu^(-1)}, yw] + 
     8*G[{1}, yu^(-1)]*G[{yu}, yv^(-1)]*G[{0, 1/(yu*yv), yu^(-1)}, yw] + 
     8*G[{1}, yv^(-1)]*G[{yu}, yv^(-1)]*G[{0, 1/(yu*yv), yu^(-1)}, yw] - 
     4*G[{yu}, yv^(-1)]^2*G[{0, 1/(yu*yv), yu^(-1)}, yw] - 
     4*G[{0}, yu^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv), yu^(-1)}, yw] - 
     4*G[{0}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv), yu^(-1)}, yw] + 
     4*G[{0}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv), yu^(-1)}, yw] + 
     4*G[{1}, yu^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv), yu^(-1)}, yw] + 
     8*G[{1}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv), yu^(-1)}, yw] - 
     4*G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv), yu^(-1)}, yw] - 
     2*G[{1/(yu*yv)}, yw]^2*G[{0, 1/(yu*yv), yu^(-1)}, yw] - 
     4*G[{0, 1}, yu^(-1)]*G[{0, 1/(yu*yv), yu^(-1)}, yw] + 
     4*G[{1, yu}, yv^(-1)]*G[{0, 1/(yu*yv), yu^(-1)}, yw] - 
     (Pi^2*G[{0, 1/(yu*yv), yv^(-1)}, yw])/3 + 2*G[{0}, yu^(-1)]*
      G[{1}, yu^(-1)]*G[{0, 1/(yu*yv), yv^(-1)}, yw] + 
     2*G[{0}, yv^(-1)]*G[{1}, yu^(-1)]*G[{0, 1/(yu*yv), yv^(-1)}, yw] - 
     2*G[{0}, yw]*G[{1}, yu^(-1)]*G[{0, 1/(yu*yv), yv^(-1)}, yw] - 
     2*G[{1}, yu^(-1)]^2*G[{0, 1/(yu*yv), yv^(-1)}, yw] + 
     2*G[{0}, yu^(-1)]*G[{1}, yv^(-1)]*G[{0, 1/(yu*yv), yv^(-1)}, yw] + 
     2*G[{0}, yv^(-1)]*G[{1}, yv^(-1)]*G[{0, 1/(yu*yv), yv^(-1)}, yw] - 
     2*G[{0}, yw]*G[{1}, yv^(-1)]*G[{0, 1/(yu*yv), yv^(-1)}, yw] - 
     8*G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*G[{0, 1/(yu*yv), yv^(-1)}, yw] - 
     2*G[{1}, yv^(-1)]^2*G[{0, 1/(yu*yv), yv^(-1)}, yw] + 
     2*G[{0}, yu^(-1)]*G[{1}, yw]*G[{0, 1/(yu*yv), yv^(-1)}, yw] + 
     2*G[{0}, yv^(-1)]*G[{1}, yw]*G[{0, 1/(yu*yv), yv^(-1)}, yw] - 
     2*G[{0}, yw]*G[{1}, yw]*G[{0, 1/(yu*yv), yv^(-1)}, yw] - 
     4*G[{1}, yu^(-1)]*G[{1}, yw]*G[{0, 1/(yu*yv), yv^(-1)}, yw] + 
     2*G[{1}, yw]^2*G[{0, 1/(yu*yv), yv^(-1)}, yw] - 
     4*G[{0}, yu^(-1)]*G[{yu}, yv^(-1)]*G[{0, 1/(yu*yv), yv^(-1)}, yw] - 
     4*G[{0}, yv^(-1)]*G[{yu}, yv^(-1)]*G[{0, 1/(yu*yv), yv^(-1)}, yw] + 
     4*G[{0}, yw]*G[{yu}, yv^(-1)]*G[{0, 1/(yu*yv), yv^(-1)}, yw] + 
     8*G[{1}, yu^(-1)]*G[{yu}, yv^(-1)]*G[{0, 1/(yu*yv), yv^(-1)}, yw] + 
     8*G[{1}, yv^(-1)]*G[{yu}, yv^(-1)]*G[{0, 1/(yu*yv), yv^(-1)}, yw] - 
     4*G[{yu}, yv^(-1)]^2*G[{0, 1/(yu*yv), yv^(-1)}, yw] - 
     2*G[{0}, yu^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv), yv^(-1)}, yw] - 
     2*G[{0}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv), yv^(-1)}, yw] + 
     2*G[{0}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv), yv^(-1)}, yw] + 
     4*G[{1}, yu^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv), yv^(-1)}, yw] + 
     4*G[{1}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv), yv^(-1)}, yw] - 
     4*G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv), yv^(-1)}, yw] - 
     2*G[{1/(yu*yv)}, yw]^2*G[{0, 1/(yu*yv), yv^(-1)}, yw] - 
     2*G[{0, 1}, yu^(-1)]*G[{0, 1/(yu*yv), yv^(-1)}, yw] - 
     2*G[{0, 1}, yv^(-1)]*G[{0, 1/(yu*yv), yv^(-1)}, yw] + 
     2*G[{0, 1}, yw]*G[{0, 1/(yu*yv), yv^(-1)}, yw] - 
     2*G[{0, yu^(-1)}, yw]*G[{0, 1/(yu*yv), yv^(-1)}, yw] + 
     2*G[{0, yu}, yv^(-1)]*G[{0, 1/(yu*yv), yv^(-1)}, yw] - 
     2*G[{0, yv^(-1)}, yw]*G[{0, 1/(yu*yv), yv^(-1)}, yw] + 
     2*G[{0, 1/(yu*yv)}, yw]*G[{0, 1/(yu*yv), yv^(-1)}, yw] + 
     Pi^2*G[{0, 1/(yu*yv), 1/(yu*yv)}, yw] + 2*G[{0}, yu^(-1)]^2*
      G[{0, 1/(yu*yv), 1/(yu*yv)}, yw] + 4*G[{0}, yu^(-1)]*G[{0}, yv^(-1)]*
      G[{0, 1/(yu*yv), 1/(yu*yv)}, yw] + 2*G[{0}, yv^(-1)]^2*
      G[{0, 1/(yu*yv), 1/(yu*yv)}, yw] - 4*G[{0}, yu^(-1)]*G[{0}, yw]*
      G[{0, 1/(yu*yv), 1/(yu*yv)}, yw] - 4*G[{0}, yv^(-1)]*G[{0}, yw]*
      G[{0, 1/(yu*yv), 1/(yu*yv)}, yw] + 2*G[{0}, yw]^2*
      G[{0, 1/(yu*yv), 1/(yu*yv)}, yw] - 8*G[{0}, yu^(-1)]*G[{1}, yu^(-1)]*
      G[{0, 1/(yu*yv), 1/(yu*yv)}, yw] - 8*G[{0}, yv^(-1)]*G[{1}, yu^(-1)]*
      G[{0, 1/(yu*yv), 1/(yu*yv)}, yw] + 8*G[{0}, yw]*G[{1}, yu^(-1)]*
      G[{0, 1/(yu*yv), 1/(yu*yv)}, yw] + 6*G[{1}, yu^(-1)]^2*
      G[{0, 1/(yu*yv), 1/(yu*yv)}, yw] - 6*G[{0}, yu^(-1)]*G[{1}, yv^(-1)]*
      G[{0, 1/(yu*yv), 1/(yu*yv)}, yw] - 6*G[{0}, yv^(-1)]*G[{1}, yv^(-1)]*
      G[{0, 1/(yu*yv), 1/(yu*yv)}, yw] + 6*G[{0}, yw]*G[{1}, yv^(-1)]*
      G[{0, 1/(yu*yv), 1/(yu*yv)}, yw] + 16*G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*
      G[{0, 1/(yu*yv), 1/(yu*yv)}, yw] + 6*G[{1}, yv^(-1)]^2*
      G[{0, 1/(yu*yv), 1/(yu*yv)}, yw] + 2*G[{0}, yu^(-1)]*G[{1}, yw]*
      G[{0, 1/(yu*yv), 1/(yu*yv)}, yw] + 2*G[{0}, yv^(-1)]*G[{1}, yw]*
      G[{0, 1/(yu*yv), 1/(yu*yv)}, yw] - 2*G[{0}, yw]*G[{1}, yw]*
      G[{0, 1/(yu*yv), 1/(yu*yv)}, yw] - 2*G[{1}, yu^(-1)]*G[{1}, yw]*
      G[{0, 1/(yu*yv), 1/(yu*yv)}, yw] + 6*G[{0}, yu^(-1)]*G[{yu}, yv^(-1)]*
      G[{0, 1/(yu*yv), 1/(yu*yv)}, yw] + 6*G[{0}, yv^(-1)]*G[{yu}, yv^(-1)]*
      G[{0, 1/(yu*yv), 1/(yu*yv)}, yw] - 6*G[{0}, yw]*G[{yu}, yv^(-1)]*
      G[{0, 1/(yu*yv), 1/(yu*yv)}, yw] - 12*G[{1}, yu^(-1)]*G[{yu}, yv^(-1)]*
      G[{0, 1/(yu*yv), 1/(yu*yv)}, yw] - 12*G[{1}, yv^(-1)]*G[{yu}, yv^(-1)]*
      G[{0, 1/(yu*yv), 1/(yu*yv)}, yw] - 2*G[{1}, yw]*G[{yu}, yv^(-1)]*
      G[{0, 1/(yu*yv), 1/(yu*yv)}, yw] + 6*G[{yu}, yv^(-1)]^2*
      G[{0, 1/(yu*yv), 1/(yu*yv)}, yw] + 2*G[{0}, yu^(-1)]*G[{1/(yu*yv)}, yw]*
      G[{0, 1/(yu*yv), 1/(yu*yv)}, yw] + 2*G[{0}, yv^(-1)]*G[{1/(yu*yv)}, yw]*
      G[{0, 1/(yu*yv), 1/(yu*yv)}, yw] - 2*G[{0}, yw]*G[{1/(yu*yv)}, yw]*
      G[{0, 1/(yu*yv), 1/(yu*yv)}, yw] - 6*G[{1}, yu^(-1)]*G[{1/(yu*yv)}, yw]*
      G[{0, 1/(yu*yv), 1/(yu*yv)}, yw] - 4*G[{1}, yv^(-1)]*G[{1/(yu*yv)}, yw]*
      G[{0, 1/(yu*yv), 1/(yu*yv)}, yw] + 6*G[{yu}, yv^(-1)]*
      G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv), 1/(yu*yv)}, yw] + 
     2*G[{0, 1}, yu^(-1)]*G[{0, 1/(yu*yv), 1/(yu*yv)}, yw] - 
     2*G[{0, 1}, yv^(-1)]*G[{0, 1/(yu*yv), 1/(yu*yv)}, yw] + 
     2*G[{0, 1}, yw]*G[{0, 1/(yu*yv), 1/(yu*yv)}, yw] - 
     2*G[{0, yu^(-1)}, yw]*G[{0, 1/(yu*yv), 1/(yu*yv)}, yw] + 
     2*G[{0, yu}, yv^(-1)]*G[{0, 1/(yu*yv), 1/(yu*yv)}, yw] - 
     2*G[{0, yv^(-1)}, yw]*G[{0, 1/(yu*yv), 1/(yu*yv)}, yw] + 
     2*G[{0, 1/(yu*yv)}, yw]*G[{0, 1/(yu*yv), 1/(yu*yv)}, yw] - 
     4*G[{1, yu}, yv^(-1)]*G[{0, 1/(yu*yv), 1/(yu*yv)}, yw] - 
     2*G[{0, 1}, yw]*G[{1, 1, yu}, yv^(-1)] - 2*G[{0, yu^(-1)}, yw]*
      G[{1, 1, yu}, yv^(-1)] + 2*G[{0, yv^(-1)}, yw]*G[{1, 1, yu}, yv^(-1)] + 
     2*G[{0, 1/(yu*yv)}, yw]*G[{1, 1, yu}, yv^(-1)] - 
     4*G[{0, yu^(-1)}, yw]*G[{1, yu, yu}, yv^(-1)] + 
     4*G[{0, yv^(-1)}, yw]*G[{1, yu, yu}, yv^(-1)] + 
     4*G[{1}, yu^(-1)]*G[{0, 0, 1, 1}, yu^(-1)] - 
     4*G[{1}, yw]*G[{0, 0, 1, 1}, yu^(-1)] + 4*G[{0}, yu^(-1)]*
      G[{0, 0, 1, 1}, yv^(-1)] + 4*G[{0}, yv^(-1)]*G[{0, 0, 1, 1}, yv^(-1)] - 
     4*G[{0}, yw]*G[{0, 0, 1, 1}, yv^(-1)] - 4*G[{1}, yu^(-1)]*
      G[{0, 0, 1, 1}, yv^(-1)] - 4*G[{1}, yv^(-1)]*G[{0, 0, 1, 1}, yv^(-1)] + 
     4*G[{1/(yu*yv)}, yw]*G[{0, 0, 1, 1}, yv^(-1)] + 
     4*G[{1}, yu^(-1)]*G[{0, 0, 1, 1}, yw] - 4*G[{1}, yw]*
      G[{0, 0, 1, 1}, yw] - 4*G[{yu}, yv^(-1)]*G[{0, 0, 1, 1}, yw] - 
     4*G[{1}, yu^(-1)]*G[{0, 0, 1, yu^(-1)}, yw] + 
     4*G[{1}, yw]*G[{0, 0, 1, yu^(-1)}, yw] + 4*G[{yu}, yv^(-1)]*
      G[{0, 0, 1, yu^(-1)}, yw] - 4*G[{0}, yu^(-1)]*
      G[{0, 0, 1, yu}, yv^(-1)] - 4*G[{0}, yv^(-1)]*
      G[{0, 0, 1, yu}, yv^(-1)] + 4*G[{0}, yw]*G[{0, 0, 1, yu}, yv^(-1)] + 
     4*G[{1}, yu^(-1)]*G[{0, 0, 1, yu}, yv^(-1)] + 
     4*G[{1}, yv^(-1)]*G[{0, 0, 1, yu}, yv^(-1)] - 4*G[{1/(yu*yv)}, yw]*
      G[{0, 0, 1, yu}, yv^(-1)] - 4*G[{1}, yu^(-1)]*G[{0, 0, 1, yv^(-1)}, 
       yw] + 4*G[{1}, yw]*G[{0, 0, 1, yv^(-1)}, yw] + 
     4*G[{yu}, yv^(-1)]*G[{0, 0, 1, yv^(-1)}, yw] + 
     4*G[{1}, yu^(-1)]*G[{0, 0, 1, 1/(yu*yv)}, yw] - 
     4*G[{1}, yw]*G[{0, 0, 1, 1/(yu*yv)}, yw] - 4*G[{yu}, yv^(-1)]*
      G[{0, 0, 1, 1/(yu*yv)}, yw] - 4*G[{1}, yu^(-1)]*
      G[{0, 0, yu^(-1), 1}, yw] + 4*G[{1}, yw]*G[{0, 0, yu^(-1), 1}, yw] + 
     4*G[{yu}, yv^(-1)]*G[{0, 0, yu^(-1), 1}, yw] + 
     4*G[{0}, yu^(-1)]*G[{0, 0, yu^(-1), yu^(-1)}, yw] + 
     4*G[{0}, yv^(-1)]*G[{0, 0, yu^(-1), yu^(-1)}, yw] - 
     4*G[{0}, yw]*G[{0, 0, yu^(-1), yu^(-1)}, yw] - 
     8*G[{1}, yv^(-1)]*G[{0, 0, yu^(-1), yu^(-1)}, yw] + 
     4*G[{1/(yu*yv)}, yw]*G[{0, 0, yu^(-1), yu^(-1)}, yw] + 
     4*G[{0}, yu^(-1)]*G[{0, 0, yu^(-1), yv^(-1)}, yw] + 
     4*G[{0}, yv^(-1)]*G[{0, 0, yu^(-1), yv^(-1)}, yw] - 
     4*G[{0}, yw]*G[{0, 0, yu^(-1), yv^(-1)}, yw] - 
     8*G[{1}, yv^(-1)]*G[{0, 0, yu^(-1), yv^(-1)}, yw] + 
     4*G[{1/(yu*yv)}, yw]*G[{0, 0, yu^(-1), yv^(-1)}, yw] - 
     4*G[{0}, yu^(-1)]*G[{0, 0, yu^(-1), 1/(yu*yv)}, yw] - 
     4*G[{0}, yv^(-1)]*G[{0, 0, yu^(-1), 1/(yu*yv)}, yw] + 
     4*G[{0}, yw]*G[{0, 0, yu^(-1), 1/(yu*yv)}, yw] + 
     8*G[{1}, yv^(-1)]*G[{0, 0, yu^(-1), 1/(yu*yv)}, yw] - 
     4*G[{1/(yu*yv)}, yw]*G[{0, 0, yu^(-1), 1/(yu*yv)}, yw] - 
     4*G[{0}, yu^(-1)]*G[{0, 0, yu, 1}, yv^(-1)] - 
     4*G[{0}, yv^(-1)]*G[{0, 0, yu, 1}, yv^(-1)] + 
     4*G[{0}, yw]*G[{0, 0, yu, 1}, yv^(-1)] + 4*G[{1}, yu^(-1)]*
      G[{0, 0, yu, 1}, yv^(-1)] + 4*G[{1}, yv^(-1)]*
      G[{0, 0, yu, 1}, yv^(-1)] - 4*G[{1/(yu*yv)}, yw]*
      G[{0, 0, yu, 1}, yv^(-1)] - 4*G[{1}, yw]*G[{0, 0, yu, yu}, yv^(-1)] - 
     4*G[{1}, yu^(-1)]*G[{0, 0, yv^(-1), 1}, yw] + 
     4*G[{1}, yw]*G[{0, 0, yv^(-1), 1}, yw] + 4*G[{yu}, yv^(-1)]*
      G[{0, 0, yv^(-1), 1}, yw] + 4*G[{0}, yu^(-1)]*
      G[{0, 0, yv^(-1), yu^(-1)}, yw] + 4*G[{0}, yv^(-1)]*
      G[{0, 0, yv^(-1), yu^(-1)}, yw] - 4*G[{0}, yw]*
      G[{0, 0, yv^(-1), yu^(-1)}, yw] - 8*G[{1}, yv^(-1)]*
      G[{0, 0, yv^(-1), yu^(-1)}, yw] + 4*G[{1/(yu*yv)}, yw]*
      G[{0, 0, yv^(-1), yu^(-1)}, yw] - 4*G[{1}, yw]*
      G[{0, 0, yv^(-1), yv^(-1)}, yw] + 4*G[{1}, yw]*
      G[{0, 0, yv^(-1), 1/(yu*yv)}, yw] + 4*G[{1}, yu^(-1)]*
      G[{0, 0, 1/(yu*yv), 1}, yw] - 4*G[{1}, yw]*G[{0, 0, 1/(yu*yv), 1}, 
       yw] - 4*G[{yu}, yv^(-1)]*G[{0, 0, 1/(yu*yv), 1}, yw] - 
     4*G[{0}, yu^(-1)]*G[{0, 0, 1/(yu*yv), yu^(-1)}, yw] - 
     4*G[{0}, yv^(-1)]*G[{0, 0, 1/(yu*yv), yu^(-1)}, yw] + 
     4*G[{0}, yw]*G[{0, 0, 1/(yu*yv), yu^(-1)}, yw] + 
     8*G[{1}, yv^(-1)]*G[{0, 0, 1/(yu*yv), yu^(-1)}, yw] - 
     4*G[{1/(yu*yv)}, yw]*G[{0, 0, 1/(yu*yv), yu^(-1)}, yw] + 
     4*G[{1}, yw]*G[{0, 0, 1/(yu*yv), yv^(-1)}, yw] + 
     4*G[{0}, yu^(-1)]*G[{0, 0, 1/(yu*yv), 1/(yu*yv)}, yw] + 
     4*G[{0}, yv^(-1)]*G[{0, 0, 1/(yu*yv), 1/(yu*yv)}, yw] - 
     4*G[{0}, yw]*G[{0, 0, 1/(yu*yv), 1/(yu*yv)}, yw] - 
     4*G[{1}, yu^(-1)]*G[{0, 0, 1/(yu*yv), 1/(yu*yv)}, yw] - 
     8*G[{1}, yv^(-1)]*G[{0, 0, 1/(yu*yv), 1/(yu*yv)}, yw] + 
     4*G[{yu}, yv^(-1)]*G[{0, 0, 1/(yu*yv), 1/(yu*yv)}, yw] + 
     4*G[{1/(yu*yv)}, yw]*G[{0, 0, 1/(yu*yv), 1/(yu*yv)}, yw] + 
     2*G[{0}, yu^(-1)]*G[{0, 1, 0, yu^(-1)}, yw] + 
     2*G[{0}, yv^(-1)]*G[{0, 1, 0, yu^(-1)}, yw] - 
     2*G[{0}, yw]*G[{0, 1, 0, yu^(-1)}, yw] - 2*G[{1}, yu^(-1)]*
      G[{0, 1, 0, yu^(-1)}, yw] - 4*G[{1}, yv^(-1)]*G[{0, 1, 0, yu^(-1)}, 
       yw] + 2*G[{1}, yw]*G[{0, 1, 0, yu^(-1)}, yw] + 
     2*G[{yu}, yv^(-1)]*G[{0, 1, 0, yu^(-1)}, yw] + 
     2*G[{1/(yu*yv)}, yw]*G[{0, 1, 0, yu^(-1)}, yw] - 
     2*G[{0}, yu^(-1)]*G[{0, 1, 0, yu}, yv^(-1)] - 
     2*G[{0}, yv^(-1)]*G[{0, 1, 0, yu}, yv^(-1)] + 
     2*G[{0}, yw]*G[{0, 1, 0, yu}, yv^(-1)] + 2*G[{1}, yu^(-1)]*
      G[{0, 1, 0, yu}, yv^(-1)] + 2*G[{1}, yv^(-1)]*
      G[{0, 1, 0, yu}, yv^(-1)] - 2*G[{1}, yw]*G[{0, 1, 0, yu}, yv^(-1)] - 
     2*G[{1/(yu*yv)}, yw]*G[{0, 1, 0, yu}, yv^(-1)] - 
     2*G[{1}, yu^(-1)]*G[{0, 1, 0, yv^(-1)}, yw] + 
     2*G[{yu}, yv^(-1)]*G[{0, 1, 0, yv^(-1)}, yw] - 
     2*G[{0}, yu^(-1)]*G[{0, 1, 0, 1/(yu*yv)}, yw] - 
     2*G[{0}, yv^(-1)]*G[{0, 1, 0, 1/(yu*yv)}, yw] + 
     2*G[{0}, yw]*G[{0, 1, 0, 1/(yu*yv)}, yw] + 4*G[{1}, yu^(-1)]*
      G[{0, 1, 0, 1/(yu*yv)}, yw] + 4*G[{1}, yv^(-1)]*
      G[{0, 1, 0, 1/(yu*yv)}, yw] - 2*G[{1}, yw]*G[{0, 1, 0, 1/(yu*yv)}, 
       yw] - 4*G[{yu}, yv^(-1)]*G[{0, 1, 0, 1/(yu*yv)}, yw] - 
     2*G[{1/(yu*yv)}, yw]*G[{0, 1, 0, 1/(yu*yv)}, yw] - 
     6*G[{0}, yu^(-1)]*G[{0, 1, 1, 1}, yu^(-1)] - 
     6*G[{0}, yv^(-1)]*G[{0, 1, 1, 1}, yu^(-1)] + 
     6*G[{0}, yw]*G[{0, 1, 1, 1}, yu^(-1)] + 6*G[{1}, yu^(-1)]*
      G[{0, 1, 1, 1}, yu^(-1)] + 6*G[{1}, yv^(-1)]*G[{0, 1, 1, 1}, yu^(-1)] - 
     6*G[{1}, yw]*G[{0, 1, 1, 1}, yu^(-1)] - 6*G[{1/(yu*yv)}, yw]*
      G[{0, 1, 1, 1}, yu^(-1)] + 6*G[{1}, yu^(-1)]*G[{0, 1, 1, 1}, yv^(-1)] + 
     6*G[{0}, yu^(-1)]*G[{0, 1, 1, 1}, yw] + 6*G[{0}, yv^(-1)]*
      G[{0, 1, 1, 1}, yw] - 6*G[{0}, yw]*G[{0, 1, 1, 1}, yw] - 
     6*G[{1}, yu^(-1)]*G[{0, 1, 1, 1}, yw] - 12*G[{1}, yv^(-1)]*
      G[{0, 1, 1, 1}, yw] - 6*G[{1}, yw]*G[{0, 1, 1, 1}, yw] + 
     6*G[{yu}, yv^(-1)]*G[{0, 1, 1, 1}, yw] + 6*G[{1/(yu*yv)}, yw]*
      G[{0, 1, 1, 1}, yw] - 8*G[{0}, yu^(-1)]*G[{0, 1, 1, yu^(-1)}, yw] - 
     8*G[{0}, yv^(-1)]*G[{0, 1, 1, yu^(-1)}, yw] + 
     8*G[{0}, yw]*G[{0, 1, 1, yu^(-1)}, yw] + 12*G[{1}, yu^(-1)]*
      G[{0, 1, 1, yu^(-1)}, yw] + 16*G[{1}, yv^(-1)]*
      G[{0, 1, 1, yu^(-1)}, yw] - 12*G[{yu}, yv^(-1)]*
      G[{0, 1, 1, yu^(-1)}, yw] - 8*G[{1/(yu*yv)}, yw]*
      G[{0, 1, 1, yu^(-1)}, yw] + 6*G[{0}, yu^(-1)]*
      G[{0, 1, 1, yu}, yv^(-1)] + 6*G[{0}, yv^(-1)]*
      G[{0, 1, 1, yu}, yv^(-1)] - 6*G[{0}, yw]*G[{0, 1, 1, yu}, yv^(-1)] - 
     12*G[{1}, yu^(-1)]*G[{0, 1, 1, yu}, yv^(-1)] - 
     6*G[{1}, yv^(-1)]*G[{0, 1, 1, yu}, yv^(-1)] + 
     2*G[{1}, yw]*G[{0, 1, 1, yu}, yv^(-1)] + 6*G[{1/(yu*yv)}, yw]*
      G[{0, 1, 1, yu}, yv^(-1)] - 6*G[{0}, yu^(-1)]*G[{0, 1, 1, yv^(-1)}, 
       yw] - 6*G[{0}, yv^(-1)]*G[{0, 1, 1, yv^(-1)}, yw] + 
     6*G[{0}, yw]*G[{0, 1, 1, yv^(-1)}, yw] + 12*G[{1}, yu^(-1)]*
      G[{0, 1, 1, yv^(-1)}, yw] + 12*G[{1}, yv^(-1)]*
      G[{0, 1, 1, yv^(-1)}, yw] + 2*G[{1}, yw]*G[{0, 1, 1, yv^(-1)}, yw] - 
     12*G[{yu}, yv^(-1)]*G[{0, 1, 1, yv^(-1)}, yw] - 
     6*G[{1/(yu*yv)}, yw]*G[{0, 1, 1, yv^(-1)}, yw] + 
     4*G[{0}, yu^(-1)]*G[{0, 1, 1, 1/(yu*yv)}, yw] + 
     4*G[{0}, yv^(-1)]*G[{0, 1, 1, 1/(yu*yv)}, yw] - 
     4*G[{0}, yw]*G[{0, 1, 1, 1/(yu*yv)}, yw] - 10*G[{1}, yu^(-1)]*
      G[{0, 1, 1, 1/(yu*yv)}, yw] - 8*G[{1}, yv^(-1)]*
      G[{0, 1, 1, 1/(yu*yv)}, yw] + 10*G[{yu}, yv^(-1)]*
      G[{0, 1, 1, 1/(yu*yv)}, yw] + 4*G[{1/(yu*yv)}, yw]*
      G[{0, 1, 1, 1/(yu*yv)}, yw] - 4*G[{0}, yu^(-1)]*
      G[{0, 1, yu^(-1), 1}, yw] - 4*G[{0}, yv^(-1)]*G[{0, 1, yu^(-1), 1}, 
       yw] + 4*G[{0}, yw]*G[{0, 1, yu^(-1), 1}, yw] + 
     8*G[{1}, yu^(-1)]*G[{0, 1, yu^(-1), 1}, yw] + 
     8*G[{1}, yv^(-1)]*G[{0, 1, yu^(-1), 1}, yw] - 
     8*G[{yu}, yv^(-1)]*G[{0, 1, yu^(-1), 1}, yw] - 
     4*G[{1/(yu*yv)}, yw]*G[{0, 1, yu^(-1), 1}, yw] - 
     8*G[{1}, yu^(-1)]*G[{0, 1, yu^(-1), yu^(-1)}, yw] + 
     8*G[{yu}, yv^(-1)]*G[{0, 1, yu^(-1), yu^(-1)}, yw] + 
     4*G[{0}, yu^(-1)]*G[{0, 1, yu^(-1), yv^(-1)}, yw] + 
     4*G[{0}, yv^(-1)]*G[{0, 1, yu^(-1), yv^(-1)}, yw] - 
     4*G[{0}, yw]*G[{0, 1, yu^(-1), yv^(-1)}, yw] - 
     8*G[{1}, yu^(-1)]*G[{0, 1, yu^(-1), yv^(-1)}, yw] - 
     8*G[{1}, yv^(-1)]*G[{0, 1, yu^(-1), yv^(-1)}, yw] + 
     8*G[{yu}, yv^(-1)]*G[{0, 1, yu^(-1), yv^(-1)}, yw] + 
     4*G[{1/(yu*yv)}, yw]*G[{0, 1, yu^(-1), yv^(-1)}, yw] + 
     4*G[{1}, yu^(-1)]*G[{0, 1, yu^(-1), 1/(yu*yv)}, yw] - 
     4*G[{yu}, yv^(-1)]*G[{0, 1, yu^(-1), 1/(yu*yv)}, yw] + 
     4*G[{0}, yu^(-1)]*G[{0, 1, yu, 1}, yv^(-1)] + 
     4*G[{0}, yv^(-1)]*G[{0, 1, yu, 1}, yv^(-1)] - 
     4*G[{0}, yw]*G[{0, 1, yu, 1}, yv^(-1)] - 8*G[{1}, yu^(-1)]*
      G[{0, 1, yu, 1}, yv^(-1)] - 4*G[{1}, yv^(-1)]*
      G[{0, 1, yu, 1}, yv^(-1)] + 4*G[{1/(yu*yv)}, yw]*
      G[{0, 1, yu, 1}, yv^(-1)] - 4*G[{0}, yu^(-1)]*
      G[{0, 1, yu, yu}, yv^(-1)] - 4*G[{0}, yv^(-1)]*
      G[{0, 1, yu, yu}, yv^(-1)] + 4*G[{0}, yw]*G[{0, 1, yu, yu}, yv^(-1)] + 
     8*G[{1}, yu^(-1)]*G[{0, 1, yu, yu}, yv^(-1)] + 
     4*G[{1}, yv^(-1)]*G[{0, 1, yu, yu}, yv^(-1)] + 
     4*G[{1}, yw]*G[{0, 1, yu, yu}, yv^(-1)] - 4*G[{1/(yu*yv)}, yw]*
      G[{0, 1, yu, yu}, yv^(-1)] - 4*G[{0}, yu^(-1)]*
      G[{0, 1, yv^(-1), 1}, yw] - 4*G[{0}, yv^(-1)]*G[{0, 1, yv^(-1), 1}, 
       yw] + 4*G[{0}, yw]*G[{0, 1, yv^(-1), 1}, yw] + 
     8*G[{1}, yu^(-1)]*G[{0, 1, yv^(-1), 1}, yw] + 
     8*G[{1}, yv^(-1)]*G[{0, 1, yv^(-1), 1}, yw] - 
     8*G[{yu}, yv^(-1)]*G[{0, 1, yv^(-1), 1}, yw] - 
     4*G[{1/(yu*yv)}, yw]*G[{0, 1, yv^(-1), 1}, yw] + 
     4*G[{0}, yu^(-1)]*G[{0, 1, yv^(-1), yu^(-1)}, yw] + 
     4*G[{0}, yv^(-1)]*G[{0, 1, yv^(-1), yu^(-1)}, yw] - 
     4*G[{0}, yw]*G[{0, 1, yv^(-1), yu^(-1)}, yw] - 
     8*G[{1}, yu^(-1)]*G[{0, 1, yv^(-1), yu^(-1)}, yw] - 
     8*G[{1}, yv^(-1)]*G[{0, 1, yv^(-1), yu^(-1)}, yw] + 
     8*G[{yu}, yv^(-1)]*G[{0, 1, yv^(-1), yu^(-1)}, yw] + 
     4*G[{1/(yu*yv)}, yw]*G[{0, 1, yv^(-1), yu^(-1)}, yw] + 
     4*G[{0}, yu^(-1)]*G[{0, 1, yv^(-1), yv^(-1)}, yw] + 
     4*G[{0}, yv^(-1)]*G[{0, 1, yv^(-1), yv^(-1)}, yw] - 
     4*G[{0}, yw]*G[{0, 1, yv^(-1), yv^(-1)}, yw] - 
     8*G[{1}, yu^(-1)]*G[{0, 1, yv^(-1), yv^(-1)}, yw] - 
     8*G[{1}, yv^(-1)]*G[{0, 1, yv^(-1), yv^(-1)}, yw] + 
     4*G[{1}, yw]*G[{0, 1, yv^(-1), yv^(-1)}, yw] + 
     8*G[{yu}, yv^(-1)]*G[{0, 1, yv^(-1), yv^(-1)}, yw] + 
     4*G[{1/(yu*yv)}, yw]*G[{0, 1, yv^(-1), yv^(-1)}, yw] + 
     4*G[{1}, yu^(-1)]*G[{0, 1, yv^(-1), 1/(yu*yv)}, yw] - 
     4*G[{yu}, yv^(-1)]*G[{0, 1, yv^(-1), 1/(yu*yv)}, yw] + 
     2*G[{0}, yu^(-1)]*G[{0, 1, 1/(yu*yv), 1}, yw] + 
     2*G[{0}, yv^(-1)]*G[{0, 1, 1/(yu*yv), 1}, yw] - 
     2*G[{0}, yw]*G[{0, 1, 1/(yu*yv), 1}, yw] - 6*G[{1}, yu^(-1)]*
      G[{0, 1, 1/(yu*yv), 1}, yw] - 4*G[{1}, yv^(-1)]*
      G[{0, 1, 1/(yu*yv), 1}, yw] + 2*G[{1}, yw]*G[{0, 1, 1/(yu*yv), 1}, 
       yw] + 6*G[{yu}, yv^(-1)]*G[{0, 1, 1/(yu*yv), 1}, yw] + 
     2*G[{1/(yu*yv)}, yw]*G[{0, 1, 1/(yu*yv), 1}, yw] + 
     4*G[{1}, yu^(-1)]*G[{0, 1, 1/(yu*yv), yu^(-1)}, yw] - 
     4*G[{yu}, yv^(-1)]*G[{0, 1, 1/(yu*yv), yu^(-1)}, yw] - 
     2*G[{0}, yu^(-1)]*G[{0, 1, 1/(yu*yv), yv^(-1)}, yw] - 
     2*G[{0}, yv^(-1)]*G[{0, 1, 1/(yu*yv), yv^(-1)}, yw] + 
     2*G[{0}, yw]*G[{0, 1, 1/(yu*yv), yv^(-1)}, yw] + 
     4*G[{1}, yu^(-1)]*G[{0, 1, 1/(yu*yv), yv^(-1)}, yw] + 
     4*G[{1}, yv^(-1)]*G[{0, 1, 1/(yu*yv), yv^(-1)}, yw] - 
     2*G[{1}, yw]*G[{0, 1, 1/(yu*yv), yv^(-1)}, yw] - 
     4*G[{yu}, yv^(-1)]*G[{0, 1, 1/(yu*yv), yv^(-1)}, yw] - 
     2*G[{1/(yu*yv)}, yw]*G[{0, 1, 1/(yu*yv), yv^(-1)}, yw] - 
     2*G[{1}, yu^(-1)]*G[{0, 1, 1/(yu*yv), 1/(yu*yv)}, yw] + 
     2*G[{yu}, yv^(-1)]*G[{0, 1, 1/(yu*yv), 1/(yu*yv)}, yw] + 
     2*G[{0}, yu^(-1)]*G[{0, yu^(-1), 0, yv^(-1)}, yw] + 
     2*G[{0}, yv^(-1)]*G[{0, yu^(-1), 0, yv^(-1)}, yw] - 
     2*G[{0}, yw]*G[{0, yu^(-1), 0, yv^(-1)}, yw] - 
     4*G[{1}, yv^(-1)]*G[{0, yu^(-1), 0, yv^(-1)}, yw] + 
     2*G[{1}, yw]*G[{0, yu^(-1), 0, yv^(-1)}, yw] + 
     2*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1), 0, yv^(-1)}, yw] - 
     2*G[{1}, yu^(-1)]*G[{0, yu^(-1), 0, 1/(yu*yv)}, yw] + 
     2*G[{yu}, yv^(-1)]*G[{0, yu^(-1), 0, 1/(yu*yv)}, yw] - 
     2*G[{0}, yu^(-1)]*G[{0, yu^(-1), 1, 1}, yw] - 
     2*G[{0}, yv^(-1)]*G[{0, yu^(-1), 1, 1}, yw] + 
     2*G[{0}, yw]*G[{0, yu^(-1), 1, 1}, yw] + 2*G[{1}, yu^(-1)]*
      G[{0, yu^(-1), 1, 1}, yw] + 4*G[{1}, yv^(-1)]*G[{0, yu^(-1), 1, 1}, 
       yw] + 2*G[{1}, yw]*G[{0, yu^(-1), 1, 1}, yw] - 
     2*G[{yu}, yv^(-1)]*G[{0, yu^(-1), 1, 1}, yw] - 
     2*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1), 1, 1}, yw] - 
     4*G[{1}, yu^(-1)]*G[{0, yu^(-1), 1, yu^(-1)}, yw] + 
     4*G[{yu}, yv^(-1)]*G[{0, yu^(-1), 1, yu^(-1)}, yw] + 
     2*G[{0}, yu^(-1)]*G[{0, yu^(-1), 1, yv^(-1)}, yw] + 
     2*G[{0}, yv^(-1)]*G[{0, yu^(-1), 1, yv^(-1)}, yw] - 
     2*G[{0}, yw]*G[{0, yu^(-1), 1, yv^(-1)}, yw] - 
     4*G[{1}, yu^(-1)]*G[{0, yu^(-1), 1, yv^(-1)}, yw] - 
     4*G[{1}, yv^(-1)]*G[{0, yu^(-1), 1, yv^(-1)}, yw] - 
     2*G[{1}, yw]*G[{0, yu^(-1), 1, yv^(-1)}, yw] + 
     4*G[{yu}, yv^(-1)]*G[{0, yu^(-1), 1, yv^(-1)}, yw] + 
     2*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1), 1, yv^(-1)}, yw] + 
     2*G[{1}, yu^(-1)]*G[{0, yu^(-1), 1, 1/(yu*yv)}, yw] - 
     2*G[{yu}, yv^(-1)]*G[{0, yu^(-1), 1, 1/(yu*yv)}, yw] - 
     4*G[{1}, yu^(-1)]*G[{0, yu^(-1), yu^(-1), 1}, yw] + 
     4*G[{1}, yw]*G[{0, yu^(-1), yu^(-1), 1}, yw] + 
     4*G[{yu}, yv^(-1)]*G[{0, yu^(-1), yu^(-1), 1}, yw] + 
     8*G[{0}, yu^(-1)]*G[{0, yu^(-1), yu^(-1), yu^(-1)}, yw] + 
     8*G[{0}, yv^(-1)]*G[{0, yu^(-1), yu^(-1), yu^(-1)}, yw] - 
     8*G[{0}, yw]*G[{0, yu^(-1), yu^(-1), yu^(-1)}, yw] - 
     16*G[{1}, yv^(-1)]*G[{0, yu^(-1), yu^(-1), yu^(-1)}, yw] + 
     8*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1), yu^(-1), yu^(-1)}, yw] - 
     4*G[{0}, yu^(-1)]*G[{0, yu^(-1), yu^(-1), 1/(yu*yv)}, yw] - 
     4*G[{0}, yv^(-1)]*G[{0, yu^(-1), yu^(-1), 1/(yu*yv)}, yw] + 
     4*G[{0}, yw]*G[{0, yu^(-1), yu^(-1), 1/(yu*yv)}, yw] + 
     4*G[{1}, yu^(-1)]*G[{0, yu^(-1), yu^(-1), 1/(yu*yv)}, yw] + 
     8*G[{1}, yv^(-1)]*G[{0, yu^(-1), yu^(-1), 1/(yu*yv)}, yw] - 
     4*G[{yu}, yv^(-1)]*G[{0, yu^(-1), yu^(-1), 1/(yu*yv)}, yw] - 
     4*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1), yu^(-1), 1/(yu*yv)}, yw] + 
     2*G[{0}, yu^(-1)]*G[{0, yu^(-1), 1/(yu*yv), 1}, yw] + 
     2*G[{0}, yv^(-1)]*G[{0, yu^(-1), 1/(yu*yv), 1}, yw] - 
     2*G[{0}, yw]*G[{0, yu^(-1), 1/(yu*yv), 1}, yw] - 
     2*G[{1}, yu^(-1)]*G[{0, yu^(-1), 1/(yu*yv), 1}, yw] - 
     4*G[{1}, yv^(-1)]*G[{0, yu^(-1), 1/(yu*yv), 1}, yw] - 
     2*G[{1}, yw]*G[{0, yu^(-1), 1/(yu*yv), 1}, yw] + 
     2*G[{yu}, yv^(-1)]*G[{0, yu^(-1), 1/(yu*yv), 1}, yw] + 
     2*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1), 1/(yu*yv), 1}, yw] - 
     4*G[{0}, yu^(-1)]*G[{0, yu^(-1), 1/(yu*yv), yu^(-1)}, yw] - 
     4*G[{0}, yv^(-1)]*G[{0, yu^(-1), 1/(yu*yv), yu^(-1)}, yw] + 
     4*G[{0}, yw]*G[{0, yu^(-1), 1/(yu*yv), yu^(-1)}, yw] + 
     4*G[{1}, yu^(-1)]*G[{0, yu^(-1), 1/(yu*yv), yu^(-1)}, yw] + 
     8*G[{1}, yv^(-1)]*G[{0, yu^(-1), 1/(yu*yv), yu^(-1)}, yw] - 
     4*G[{yu}, yv^(-1)]*G[{0, yu^(-1), 1/(yu*yv), yu^(-1)}, yw] - 
     4*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1), 1/(yu*yv), yu^(-1)}, yw] - 
     2*G[{0}, yu^(-1)]*G[{0, yu^(-1), 1/(yu*yv), yv^(-1)}, yw] - 
     2*G[{0}, yv^(-1)]*G[{0, yu^(-1), 1/(yu*yv), yv^(-1)}, yw] + 
     2*G[{0}, yw]*G[{0, yu^(-1), 1/(yu*yv), yv^(-1)}, yw] + 
     4*G[{1}, yu^(-1)]*G[{0, yu^(-1), 1/(yu*yv), yv^(-1)}, yw] + 
     4*G[{1}, yv^(-1)]*G[{0, yu^(-1), 1/(yu*yv), yv^(-1)}, yw] - 
     2*G[{1}, yw]*G[{0, yu^(-1), 1/(yu*yv), yv^(-1)}, yw] - 
     4*G[{yu}, yv^(-1)]*G[{0, yu^(-1), 1/(yu*yv), yv^(-1)}, yw] - 
     2*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1), 1/(yu*yv), yv^(-1)}, yw] - 
     2*G[{1}, yu^(-1)]*G[{0, yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] + 
     2*G[{yu}, yv^(-1)]*G[{0, yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] - 
     2*G[{1}, yu^(-1)]*G[{0, yu, 1, 1}, yv^(-1)] - 
     2*G[{0}, yu^(-1)]*G[{0, yu, 1, yu}, yv^(-1)] - 
     2*G[{0}, yv^(-1)]*G[{0, yu, 1, yu}, yv^(-1)] + 
     2*G[{0}, yw]*G[{0, yu, 1, yu}, yv^(-1)] + 4*G[{1}, yu^(-1)]*
      G[{0, yu, 1, yu}, yv^(-1)] + 2*G[{1}, yv^(-1)]*
      G[{0, yu, 1, yu}, yv^(-1)] + 2*G[{1}, yw]*G[{0, yu, 1, yu}, yv^(-1)] - 
     2*G[{1/(yu*yv)}, yw]*G[{0, yu, 1, yu}, yv^(-1)] - 
     4*G[{0}, yu^(-1)]*G[{0, yu, yu, 1}, yv^(-1)] - 
     4*G[{0}, yv^(-1)]*G[{0, yu, yu, 1}, yv^(-1)] + 
     4*G[{0}, yw]*G[{0, yu, yu, 1}, yv^(-1)] + 4*G[{1}, yu^(-1)]*
      G[{0, yu, yu, 1}, yv^(-1)] + 4*G[{1}, yv^(-1)]*
      G[{0, yu, yu, 1}, yv^(-1)] - 4*G[{1/(yu*yv)}, yw]*
      G[{0, yu, yu, 1}, yv^(-1)] - 8*G[{1}, yw]*G[{0, yu, yu, yu}, yv^(-1)] + 
     2*G[{0}, yu^(-1)]*G[{0, yv^(-1), 0, 1/(yu*yv)}, yw] + 
     2*G[{0}, yv^(-1)]*G[{0, yv^(-1), 0, 1/(yu*yv)}, yw] - 
     2*G[{0}, yw]*G[{0, yv^(-1), 0, 1/(yu*yv)}, yw] - 
     2*G[{1}, yu^(-1)]*G[{0, yv^(-1), 0, 1/(yu*yv)}, yw] - 
     4*G[{1}, yv^(-1)]*G[{0, yv^(-1), 0, 1/(yu*yv)}, yw] + 
     2*G[{1}, yw]*G[{0, yv^(-1), 0, 1/(yu*yv)}, yw] + 
     2*G[{yu}, yv^(-1)]*G[{0, yv^(-1), 0, 1/(yu*yv)}, yw] + 
     2*G[{1/(yu*yv)}, yw]*G[{0, yv^(-1), 0, 1/(yu*yv)}, yw] - 
     2*G[{0}, yu^(-1)]*G[{0, yv^(-1), 1, 1}, yw] - 
     2*G[{0}, yv^(-1)]*G[{0, yv^(-1), 1, 1}, yw] + 
     2*G[{0}, yw]*G[{0, yv^(-1), 1, 1}, yw] + 2*G[{1}, yu^(-1)]*
      G[{0, yv^(-1), 1, 1}, yw] + 4*G[{1}, yv^(-1)]*G[{0, yv^(-1), 1, 1}, 
       yw] + 2*G[{1}, yw]*G[{0, yv^(-1), 1, 1}, yw] - 
     2*G[{yu}, yv^(-1)]*G[{0, yv^(-1), 1, 1}, yw] - 
     2*G[{1/(yu*yv)}, yw]*G[{0, yv^(-1), 1, 1}, yw] + 
     4*G[{0}, yu^(-1)]*G[{0, yv^(-1), 1, yu^(-1)}, yw] + 
     4*G[{0}, yv^(-1)]*G[{0, yv^(-1), 1, yu^(-1)}, yw] - 
     4*G[{0}, yw]*G[{0, yv^(-1), 1, yu^(-1)}, yw] - 
     4*G[{1}, yu^(-1)]*G[{0, yv^(-1), 1, yu^(-1)}, yw] - 
     8*G[{1}, yv^(-1)]*G[{0, yv^(-1), 1, yu^(-1)}, yw] + 
     4*G[{yu}, yv^(-1)]*G[{0, yv^(-1), 1, yu^(-1)}, yw] + 
     4*G[{1/(yu*yv)}, yw]*G[{0, yv^(-1), 1, yu^(-1)}, yw] + 
     2*G[{0}, yu^(-1)]*G[{0, yv^(-1), 1, yv^(-1)}, yw] + 
     2*G[{0}, yv^(-1)]*G[{0, yv^(-1), 1, yv^(-1)}, yw] - 
     2*G[{0}, yw]*G[{0, yv^(-1), 1, yv^(-1)}, yw] - 
     4*G[{1}, yu^(-1)]*G[{0, yv^(-1), 1, yv^(-1)}, yw] - 
     4*G[{1}, yv^(-1)]*G[{0, yv^(-1), 1, yv^(-1)}, yw] + 
     2*G[{1}, yw]*G[{0, yv^(-1), 1, yv^(-1)}, yw] + 
     4*G[{yu}, yv^(-1)]*G[{0, yv^(-1), 1, yv^(-1)}, yw] + 
     2*G[{1/(yu*yv)}, yw]*G[{0, yv^(-1), 1, yv^(-1)}, yw] + 
     2*G[{1}, yu^(-1)]*G[{0, yv^(-1), 1, 1/(yu*yv)}, yw] - 
     2*G[{yu}, yv^(-1)]*G[{0, yv^(-1), 1, 1/(yu*yv)}, yw] - 
     4*G[{1}, yu^(-1)]*G[{0, yv^(-1), yv^(-1), 1}, yw] + 
     4*G[{1}, yw]*G[{0, yv^(-1), yv^(-1), 1}, yw] + 
     4*G[{yu}, yv^(-1)]*G[{0, yv^(-1), yv^(-1), 1}, yw] - 
     8*G[{1}, yw]*G[{0, yv^(-1), yv^(-1), yv^(-1)}, yw] - 
     4*G[{0}, yu^(-1)]*G[{0, yv^(-1), yv^(-1), 1/(yu*yv)}, yw] - 
     4*G[{0}, yv^(-1)]*G[{0, yv^(-1), yv^(-1), 1/(yu*yv)}, yw] + 
     4*G[{0}, yw]*G[{0, yv^(-1), yv^(-1), 1/(yu*yv)}, yw] + 
     4*G[{1}, yu^(-1)]*G[{0, yv^(-1), yv^(-1), 1/(yu*yv)}, yw] + 
     8*G[{1}, yv^(-1)]*G[{0, yv^(-1), yv^(-1), 1/(yu*yv)}, yw] - 
     4*G[{yu}, yv^(-1)]*G[{0, yv^(-1), yv^(-1), 1/(yu*yv)}, yw] - 
     4*G[{1/(yu*yv)}, yw]*G[{0, yv^(-1), yv^(-1), 1/(yu*yv)}, yw] + 
     2*G[{0}, yu^(-1)]*G[{0, yv^(-1), 1/(yu*yv), 1}, yw] + 
     2*G[{0}, yv^(-1)]*G[{0, yv^(-1), 1/(yu*yv), 1}, yw] - 
     2*G[{0}, yw]*G[{0, yv^(-1), 1/(yu*yv), 1}, yw] - 
     2*G[{1}, yu^(-1)]*G[{0, yv^(-1), 1/(yu*yv), 1}, yw] - 
     4*G[{1}, yv^(-1)]*G[{0, yv^(-1), 1/(yu*yv), 1}, yw] - 
     2*G[{1}, yw]*G[{0, yv^(-1), 1/(yu*yv), 1}, yw] + 
     2*G[{yu}, yv^(-1)]*G[{0, yv^(-1), 1/(yu*yv), 1}, yw] + 
     2*G[{1/(yu*yv)}, yw]*G[{0, yv^(-1), 1/(yu*yv), 1}, yw] + 
     4*G[{1}, yu^(-1)]*G[{0, yv^(-1), 1/(yu*yv), yu^(-1)}, yw] - 
     4*G[{yu}, yv^(-1)]*G[{0, yv^(-1), 1/(yu*yv), yu^(-1)}, yw] - 
     2*G[{0}, yu^(-1)]*G[{0, yv^(-1), 1/(yu*yv), yv^(-1)}, yw] - 
     2*G[{0}, yv^(-1)]*G[{0, yv^(-1), 1/(yu*yv), yv^(-1)}, yw] + 
     2*G[{0}, yw]*G[{0, yv^(-1), 1/(yu*yv), yv^(-1)}, yw] + 
     4*G[{1}, yu^(-1)]*G[{0, yv^(-1), 1/(yu*yv), yv^(-1)}, yw] + 
     4*G[{1}, yv^(-1)]*G[{0, yv^(-1), 1/(yu*yv), yv^(-1)}, yw] + 
     2*G[{1}, yw]*G[{0, yv^(-1), 1/(yu*yv), yv^(-1)}, yw] - 
     4*G[{yu}, yv^(-1)]*G[{0, yv^(-1), 1/(yu*yv), yv^(-1)}, yw] - 
     2*G[{1/(yu*yv)}, yw]*G[{0, yv^(-1), 1/(yu*yv), yv^(-1)}, yw] - 
     2*G[{1}, yu^(-1)]*G[{0, yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] + 
     2*G[{yu}, yv^(-1)]*G[{0, yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] - 
     2*G[{0}, yu^(-1)]*G[{0, 1/(yu*yv), 1, 1}, yw] - 
     2*G[{0}, yv^(-1)]*G[{0, 1/(yu*yv), 1, 1}, yw] + 
     2*G[{0}, yw]*G[{0, 1/(yu*yv), 1, 1}, yw] + 2*G[{1}, yu^(-1)]*
      G[{0, 1/(yu*yv), 1, 1}, yw] + 4*G[{1}, yv^(-1)]*
      G[{0, 1/(yu*yv), 1, 1}, yw] + 2*G[{1}, yw]*G[{0, 1/(yu*yv), 1, 1}, 
       yw] - 2*G[{yu}, yv^(-1)]*G[{0, 1/(yu*yv), 1, 1}, yw] - 
     2*G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv), 1, 1}, yw] + 
     4*G[{0}, yu^(-1)]*G[{0, 1/(yu*yv), 1, yu^(-1)}, yw] + 
     4*G[{0}, yv^(-1)]*G[{0, 1/(yu*yv), 1, yu^(-1)}, yw] - 
     4*G[{0}, yw]*G[{0, 1/(yu*yv), 1, yu^(-1)}, yw] - 
     4*G[{1}, yu^(-1)]*G[{0, 1/(yu*yv), 1, yu^(-1)}, yw] - 
     8*G[{1}, yv^(-1)]*G[{0, 1/(yu*yv), 1, yu^(-1)}, yw] + 
     4*G[{yu}, yv^(-1)]*G[{0, 1/(yu*yv), 1, yu^(-1)}, yw] + 
     4*G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv), 1, yu^(-1)}, yw] + 
     2*G[{0}, yu^(-1)]*G[{0, 1/(yu*yv), 1, yv^(-1)}, yw] + 
     2*G[{0}, yv^(-1)]*G[{0, 1/(yu*yv), 1, yv^(-1)}, yw] - 
     2*G[{0}, yw]*G[{0, 1/(yu*yv), 1, yv^(-1)}, yw] - 
     4*G[{1}, yu^(-1)]*G[{0, 1/(yu*yv), 1, yv^(-1)}, yw] - 
     4*G[{1}, yv^(-1)]*G[{0, 1/(yu*yv), 1, yv^(-1)}, yw] - 
     2*G[{1}, yw]*G[{0, 1/(yu*yv), 1, yv^(-1)}, yw] + 
     4*G[{yu}, yv^(-1)]*G[{0, 1/(yu*yv), 1, yv^(-1)}, yw] + 
     2*G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv), 1, yv^(-1)}, yw] - 
     4*G[{0}, yu^(-1)]*G[{0, 1/(yu*yv), 1, 1/(yu*yv)}, yw] - 
     4*G[{0}, yv^(-1)]*G[{0, 1/(yu*yv), 1, 1/(yu*yv)}, yw] + 
     4*G[{0}, yw]*G[{0, 1/(yu*yv), 1, 1/(yu*yv)}, yw] + 
     6*G[{1}, yu^(-1)]*G[{0, 1/(yu*yv), 1, 1/(yu*yv)}, yw] + 
     8*G[{1}, yv^(-1)]*G[{0, 1/(yu*yv), 1, 1/(yu*yv)}, yw] - 
     6*G[{yu}, yv^(-1)]*G[{0, 1/(yu*yv), 1, 1/(yu*yv)}, yw] - 
     4*G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv), 1, 1/(yu*yv)}, yw] + 
     4*G[{0}, yu^(-1)]*G[{0, 1/(yu*yv), yu^(-1), 1}, yw] + 
     4*G[{0}, yv^(-1)]*G[{0, 1/(yu*yv), yu^(-1), 1}, yw] - 
     4*G[{0}, yw]*G[{0, 1/(yu*yv), yu^(-1), 1}, yw] - 
     4*G[{1}, yu^(-1)]*G[{0, 1/(yu*yv), yu^(-1), 1}, yw] - 
     8*G[{1}, yv^(-1)]*G[{0, 1/(yu*yv), yu^(-1), 1}, yw] - 
     4*G[{1}, yw]*G[{0, 1/(yu*yv), yu^(-1), 1}, yw] + 
     4*G[{yu}, yv^(-1)]*G[{0, 1/(yu*yv), yu^(-1), 1}, yw] + 
     4*G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv), yu^(-1), 1}, yw] - 
     8*G[{0}, yu^(-1)]*G[{0, 1/(yu*yv), yu^(-1), yu^(-1)}, yw] - 
     8*G[{0}, yv^(-1)]*G[{0, 1/(yu*yv), yu^(-1), yu^(-1)}, yw] + 
     8*G[{0}, yw]*G[{0, 1/(yu*yv), yu^(-1), yu^(-1)}, yw] + 
     8*G[{1}, yu^(-1)]*G[{0, 1/(yu*yv), yu^(-1), yu^(-1)}, yw] + 
     16*G[{1}, yv^(-1)]*G[{0, 1/(yu*yv), yu^(-1), yu^(-1)}, yw] - 
     8*G[{yu}, yv^(-1)]*G[{0, 1/(yu*yv), yu^(-1), yu^(-1)}, yw] - 
     8*G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv), yu^(-1), yu^(-1)}, yw] - 
     4*G[{0}, yu^(-1)]*G[{0, 1/(yu*yv), yu^(-1), yv^(-1)}, yw] - 
     4*G[{0}, yv^(-1)]*G[{0, 1/(yu*yv), yu^(-1), yv^(-1)}, yw] + 
     4*G[{0}, yw]*G[{0, 1/(yu*yv), yu^(-1), yv^(-1)}, yw] + 
     8*G[{1}, yu^(-1)]*G[{0, 1/(yu*yv), yu^(-1), yv^(-1)}, yw] + 
     8*G[{1}, yv^(-1)]*G[{0, 1/(yu*yv), yu^(-1), yv^(-1)}, yw] - 
     8*G[{yu}, yv^(-1)]*G[{0, 1/(yu*yv), yu^(-1), yv^(-1)}, yw] - 
     4*G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv), yu^(-1), yv^(-1)}, yw] + 
     4*G[{0}, yu^(-1)]*G[{0, 1/(yu*yv), yu^(-1), 1/(yu*yv)}, yw] + 
     4*G[{0}, yv^(-1)]*G[{0, 1/(yu*yv), yu^(-1), 1/(yu*yv)}, yw] - 
     4*G[{0}, yw]*G[{0, 1/(yu*yv), yu^(-1), 1/(yu*yv)}, yw] - 
     8*G[{1}, yu^(-1)]*G[{0, 1/(yu*yv), yu^(-1), 1/(yu*yv)}, yw] - 
     8*G[{1}, yv^(-1)]*G[{0, 1/(yu*yv), yu^(-1), 1/(yu*yv)}, yw] + 
     8*G[{yu}, yv^(-1)]*G[{0, 1/(yu*yv), yu^(-1), 1/(yu*yv)}, yw] + 
     4*G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv), yu^(-1), 1/(yu*yv)}, yw] + 
     4*G[{0}, yu^(-1)]*G[{0, 1/(yu*yv), yv^(-1), 1}, yw] + 
     4*G[{0}, yv^(-1)]*G[{0, 1/(yu*yv), yv^(-1), 1}, yw] - 
     4*G[{0}, yw]*G[{0, 1/(yu*yv), yv^(-1), 1}, yw] - 
     4*G[{1}, yu^(-1)]*G[{0, 1/(yu*yv), yv^(-1), 1}, yw] - 
     8*G[{1}, yv^(-1)]*G[{0, 1/(yu*yv), yv^(-1), 1}, yw] - 
     4*G[{1}, yw]*G[{0, 1/(yu*yv), yv^(-1), 1}, yw] + 
     4*G[{yu}, yv^(-1)]*G[{0, 1/(yu*yv), yv^(-1), 1}, yw] + 
     4*G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv), yv^(-1), 1}, yw] - 
     4*G[{0}, yu^(-1)]*G[{0, 1/(yu*yv), yv^(-1), yu^(-1)}, yw] - 
     4*G[{0}, yv^(-1)]*G[{0, 1/(yu*yv), yv^(-1), yu^(-1)}, yw] + 
     4*G[{0}, yw]*G[{0, 1/(yu*yv), yv^(-1), yu^(-1)}, yw] + 
     8*G[{1}, yu^(-1)]*G[{0, 1/(yu*yv), yv^(-1), yu^(-1)}, yw] + 
     8*G[{1}, yv^(-1)]*G[{0, 1/(yu*yv), yv^(-1), yu^(-1)}, yw] - 
     8*G[{yu}, yv^(-1)]*G[{0, 1/(yu*yv), yv^(-1), yu^(-1)}, yw] - 
     4*G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv), yv^(-1), yu^(-1)}, yw] - 
     4*G[{0}, yu^(-1)]*G[{0, 1/(yu*yv), yv^(-1), yv^(-1)}, yw] - 
     4*G[{0}, yv^(-1)]*G[{0, 1/(yu*yv), yv^(-1), yv^(-1)}, yw] + 
     4*G[{0}, yw]*G[{0, 1/(yu*yv), yv^(-1), yv^(-1)}, yw] + 
     8*G[{1}, yu^(-1)]*G[{0, 1/(yu*yv), yv^(-1), yv^(-1)}, yw] + 
     8*G[{1}, yv^(-1)]*G[{0, 1/(yu*yv), yv^(-1), yv^(-1)}, yw] + 
     4*G[{1}, yw]*G[{0, 1/(yu*yv), yv^(-1), yv^(-1)}, yw] - 
     8*G[{yu}, yv^(-1)]*G[{0, 1/(yu*yv), yv^(-1), yv^(-1)}, yw] - 
     4*G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv), yv^(-1), yv^(-1)}, yw] + 
     4*G[{0}, yu^(-1)]*G[{0, 1/(yu*yv), yv^(-1), 1/(yu*yv)}, yw] + 
     4*G[{0}, yv^(-1)]*G[{0, 1/(yu*yv), yv^(-1), 1/(yu*yv)}, yw] - 
     4*G[{0}, yw]*G[{0, 1/(yu*yv), yv^(-1), 1/(yu*yv)}, yw] - 
     8*G[{1}, yu^(-1)]*G[{0, 1/(yu*yv), yv^(-1), 1/(yu*yv)}, yw] - 
     8*G[{1}, yv^(-1)]*G[{0, 1/(yu*yv), yv^(-1), 1/(yu*yv)}, yw] + 
     8*G[{yu}, yv^(-1)]*G[{0, 1/(yu*yv), yv^(-1), 1/(yu*yv)}, yw] + 
     4*G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv), yv^(-1), 1/(yu*yv)}, yw] - 
     6*G[{0}, yu^(-1)]*G[{0, 1/(yu*yv), 1/(yu*yv), 1}, yw] - 
     6*G[{0}, yv^(-1)]*G[{0, 1/(yu*yv), 1/(yu*yv), 1}, yw] + 
     6*G[{0}, yw]*G[{0, 1/(yu*yv), 1/(yu*yv), 1}, yw] + 
     10*G[{1}, yu^(-1)]*G[{0, 1/(yu*yv), 1/(yu*yv), 1}, yw] + 
     12*G[{1}, yv^(-1)]*G[{0, 1/(yu*yv), 1/(yu*yv), 1}, yw] + 
     2*G[{1}, yw]*G[{0, 1/(yu*yv), 1/(yu*yv), 1}, yw] - 
     10*G[{yu}, yv^(-1)]*G[{0, 1/(yu*yv), 1/(yu*yv), 1}, yw] - 
     6*G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv), 1/(yu*yv), 1}, yw] + 
     4*G[{0}, yu^(-1)]*G[{0, 1/(yu*yv), 1/(yu*yv), yu^(-1)}, yw] + 
     4*G[{0}, yv^(-1)]*G[{0, 1/(yu*yv), 1/(yu*yv), yu^(-1)}, yw] - 
     4*G[{0}, yw]*G[{0, 1/(yu*yv), 1/(yu*yv), yu^(-1)}, yw] - 
     12*G[{1}, yu^(-1)]*G[{0, 1/(yu*yv), 1/(yu*yv), yu^(-1)}, yw] - 
     8*G[{1}, yv^(-1)]*G[{0, 1/(yu*yv), 1/(yu*yv), yu^(-1)}, yw] + 
     12*G[{yu}, yv^(-1)]*G[{0, 1/(yu*yv), 1/(yu*yv), yu^(-1)}, yw] + 
     4*G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv), 1/(yu*yv), yu^(-1)}, yw] + 
     6*G[{0}, yu^(-1)]*G[{0, 1/(yu*yv), 1/(yu*yv), yv^(-1)}, yw] + 
     6*G[{0}, yv^(-1)]*G[{0, 1/(yu*yv), 1/(yu*yv), yv^(-1)}, yw] - 
     6*G[{0}, yw]*G[{0, 1/(yu*yv), 1/(yu*yv), yv^(-1)}, yw] - 
     12*G[{1}, yu^(-1)]*G[{0, 1/(yu*yv), 1/(yu*yv), yv^(-1)}, yw] - 
     12*G[{1}, yv^(-1)]*G[{0, 1/(yu*yv), 1/(yu*yv), yv^(-1)}, yw] + 
     2*G[{1}, yw]*G[{0, 1/(yu*yv), 1/(yu*yv), yv^(-1)}, yw] + 
     12*G[{yu}, yv^(-1)]*G[{0, 1/(yu*yv), 1/(yu*yv), yv^(-1)}, yw] + 
     6*G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv), 1/(yu*yv), yv^(-1)}, yw] + 
     6*G[{1}, yu^(-1)]*G[{0, 1/(yu*yv), 1/(yu*yv), 1/(yu*yv)}, yw] - 
     6*G[{yu}, yv^(-1)]*G[{0, 1/(yu*yv), 1/(yu*yv), 1/(yu*yv)}, yw] + 
     12*G[{0, 0, 0, 1, 1}, yv^(-1)] + 12*G[{0, 0, 0, 1, 1}, yw] - 
     12*G[{0, 0, 0, 1, yu^(-1)}, yw] - 12*G[{0, 0, 0, 1, yu}, yv^(-1)] - 
     12*G[{0, 0, 0, 1, yv^(-1)}, yw] + 12*G[{0, 0, 0, 1, 1/(yu*yv)}, yw] - 
     12*G[{0, 0, 0, yu^(-1), 1}, yw] + 12*G[{0, 0, 0, yu^(-1), yu^(-1)}, 
       yw] + 12*G[{0, 0, 0, yu^(-1), yv^(-1)}, yw] - 
     12*G[{0, 0, 0, yu^(-1), 1/(yu*yv)}, yw] - 
     12*G[{0, 0, 0, yu, 1}, yv^(-1)] + 12*G[{0, 0, 0, yu, yu}, yv^(-1)] - 
     12*G[{0, 0, 0, yv^(-1), 1}, yw] + 12*G[{0, 0, 0, yv^(-1), yu^(-1)}, 
       yw] + 12*G[{0, 0, 0, yv^(-1), yv^(-1)}, yw] - 
     12*G[{0, 0, 0, yv^(-1), 1/(yu*yv)}, yw] + 
     12*G[{0, 0, 0, 1/(yu*yv), 1}, yw] - 12*G[{0, 0, 0, 1/(yu*yv), yu^(-1)}, 
       yw] - 12*G[{0, 0, 0, 1/(yu*yv), yv^(-1)}, yw] + 
     12*G[{0, 0, 0, 1/(yu*yv), 1/(yu*yv)}, yw] + 
     4*G[{0, 0, 1, 0, 1}, yv^(-1)] + 4*G[{0, 0, 1, 0, 1}, yw] - 
     4*G[{0, 0, 1, 0, yu^(-1)}, yw] - 4*G[{0, 0, 1, 0, yu}, yv^(-1)] - 
     4*G[{0, 0, 1, 0, yv^(-1)}, yw] + 4*G[{0, 0, 1, 0, 1/(yu*yv)}, yw] - 
     24*G[{0, 0, 1, 1, 1}, yu^(-1)] - 12*G[{0, 0, 1, 1, 1}, yv^(-1)] + 
     12*G[{0, 0, 1, 1, 1}, yw] - 12*G[{0, 0, 1, 1, yu^(-1)}, yw] - 
     12*G[{0, 0, 1, 1, yv^(-1)}, yw] + 8*G[{0, 0, 1, 1, 1/(yu*yv)}, yw] - 
     8*G[{0, 0, 1, yu^(-1), 1}, yw] + 4*G[{0, 0, 1, yu^(-1), 1/(yu*yv)}, 
       yw] + 4*G[{0, 0, 1, yu, 1}, yv^(-1)] - 
     16*G[{0, 0, 1, yu, yu}, yv^(-1)] - 8*G[{0, 0, 1, yv^(-1), 1}, yw] - 
     8*G[{0, 0, 1, yv^(-1), yv^(-1)}, yw] + 
     4*G[{0, 0, 1, yv^(-1), 1/(yu*yv)}, yw] + 
     8*G[{0, 0, 1, 1/(yu*yv), 1}, yw] + 4*G[{0, 0, 1, 1/(yu*yv), 1/(yu*yv)}, 
       yw] - 4*G[{0, 0, yu^(-1), 0, 1}, yw] + 
     4*G[{0, 0, yu^(-1), 0, yu^(-1)}, yw] + 
     4*G[{0, 0, yu^(-1), 0, yv^(-1)}, yw] - 
     4*G[{0, 0, yu^(-1), 0, 1/(yu*yv)}, yw] - 
     8*G[{0, 0, yu^(-1), 1, 1}, yw] + 4*G[{0, 0, yu^(-1), 1, yv^(-1)}, yw] - 
     4*G[{0, 0, yu^(-1), yu^(-1), 1}, yw] + 
     8*G[{0, 0, yu^(-1), yu^(-1), yu^(-1)}, yw] + 
     8*G[{0, 0, yu^(-1), yu^(-1), yv^(-1)}, yw] - 
     12*G[{0, 0, yu^(-1), yu^(-1), 1/(yu*yv)}, yw] + 
     8*G[{0, 0, yu^(-1), yv^(-1), yu^(-1)}, yw] + 
     8*G[{0, 0, yu^(-1), yv^(-1), yv^(-1)}, yw] - 
     4*G[{0, 0, yu^(-1), yv^(-1), 1/(yu*yv)}, yw] - 
     8*G[{0, 0, yu^(-1), 1/(yu*yv), yu^(-1)}, yw] - 
     4*G[{0, 0, yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] - 
     4*G[{0, 0, yu, 0, 1}, yv^(-1)] + 4*G[{0, 0, yu, 0, yu}, yv^(-1)] + 
     4*G[{0, 0, yu, 1, 1}, yv^(-1)] - 4*G[{0, 0, yu, 1, yu}, yv^(-1)] + 
     4*G[{0, 0, yu, yu, 1}, yv^(-1)] - 16*G[{0, 0, yu, yu, yu}, yv^(-1)] - 
     4*G[{0, 0, yv^(-1), 0, 1}, yw] + 4*G[{0, 0, yv^(-1), 0, yu^(-1)}, yw] + 
     4*G[{0, 0, yv^(-1), 0, yv^(-1)}, yw] - 
     4*G[{0, 0, yv^(-1), 0, 1/(yu*yv)}, yw] - 
     8*G[{0, 0, yv^(-1), 1, 1}, yw] + 4*G[{0, 0, yv^(-1), 1, yv^(-1)}, yw] + 
     8*G[{0, 0, yv^(-1), yu^(-1), yu^(-1)}, yw] - 
     4*G[{0, 0, yv^(-1), yu^(-1), 1/(yu*yv)}, yw] + 
     12*G[{0, 0, yv^(-1), yv^(-1), 1}, yw] - 
     8*G[{0, 0, yv^(-1), yv^(-1), yu^(-1)}, yw] - 
     16*G[{0, 0, yv^(-1), yv^(-1), yv^(-1)}, yw] - 
     4*G[{0, 0, yv^(-1), yv^(-1), 1/(yu*yv)}, yw] - 
     4*G[{0, 0, yv^(-1), 1/(yu*yv), 1}, yw] - 
     4*G[{0, 0, yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] + 
     4*G[{0, 0, 1/(yu*yv), 0, 1}, yw] - 4*G[{0, 0, 1/(yu*yv), 0, yu^(-1)}, 
       yw] - 4*G[{0, 0, 1/(yu*yv), 0, yv^(-1)}, yw] + 
     4*G[{0, 0, 1/(yu*yv), 0, 1/(yu*yv)}, yw] + 
     8*G[{0, 0, 1/(yu*yv), 1, 1}, yw] - 4*G[{0, 0, 1/(yu*yv), 1, yv^(-1)}, 
       yw] - 8*G[{0, 0, 1/(yu*yv), yu^(-1), yu^(-1)}, yw] + 
     4*G[{0, 0, 1/(yu*yv), yu^(-1), 1/(yu*yv)}, yw] - 
     4*G[{0, 0, 1/(yu*yv), yv^(-1), 1}, yw] - 
     4*G[{0, 0, 1/(yu*yv), 1/(yu*yv), 1}, yw] + 
     8*G[{0, 0, 1/(yu*yv), 1/(yu*yv), yu^(-1)}, yw] - 
     12*G[{0, 0, 1/(yu*yv), 1/(yu*yv), 1/(yu*yv)}, yw] - 
     8*G[{0, 1, 0, 1, 1}, yu^(-1)] - 4*G[{0, 1, 0, 1, 1}, yv^(-1)] + 
     2*G[{0, 1, 0, 1, 1}, yw] - 6*G[{0, 1, 0, 1, yu^(-1)}, yw] - 
     2*G[{0, 1, 0, 1, yu}, yv^(-1)] - 4*G[{0, 1, 0, 1, yv^(-1)}, yw] + 
     4*G[{0, 1, 0, 1, 1/(yu*yv)}, yw] - 4*G[{0, 1, 0, yu^(-1), 1}, yw] + 
     4*G[{0, 1, 0, yu^(-1), yu^(-1)}, yw] + 2*G[{0, 1, 0, yu, 1}, yv^(-1)] - 
     8*G[{0, 1, 0, yu, yu}, yv^(-1)] - 2*G[{0, 1, 0, yv^(-1), 1}, yw] - 
     4*G[{0, 1, 0, yv^(-1), yv^(-1)}, yw] + 
     2*G[{0, 1, 0, yv^(-1), 1/(yu*yv)}, yw] + 
     6*G[{0, 1, 0, 1/(yu*yv), 1}, yw] - 4*G[{0, 1, 0, 1/(yu*yv), yu^(-1)}, 
       yw] - 2*G[{0, 1, 0, 1/(yu*yv), yv^(-1)}, yw] + 
     4*G[{0, 1, 0, 1/(yu*yv), 1/(yu*yv)}, yw] - 
     2*G[{0, 1, 1, 0, yu^(-1)}, yw] + 2*G[{0, 1, 1, 0, yv^(-1)}, yw] + 
     2*G[{0, 1, 1, 0, 1/(yu*yv)}, yw] + 12*G[{0, 1, 1, 1, yu^(-1)}, yw] - 
     6*G[{0, 1, 1, 1, yu}, yv^(-1)] + 6*G[{0, 1, 1, 1, yv^(-1)}, yw] - 
     6*G[{0, 1, 1, 1, 1/(yu*yv)}, yw] + 12*G[{0, 1, 1, yu^(-1), 1}, yw] - 
     16*G[{0, 1, 1, yu^(-1), yu^(-1)}, yw] - 
     12*G[{0, 1, 1, yu^(-1), yv^(-1)}, yw] + 
     8*G[{0, 1, 1, yu^(-1), 1/(yu*yv)}, yw] - 
     6*G[{0, 1, 1, yu, 1}, yv^(-1)] + 12*G[{0, 1, 1, yu, yu}, yv^(-1)] + 
     10*G[{0, 1, 1, yv^(-1), 1}, yw] - 12*G[{0, 1, 1, yv^(-1), yu^(-1)}, 
       yw] - 12*G[{0, 1, 1, yv^(-1), yv^(-1)}, yw] + 
     6*G[{0, 1, 1, yv^(-1), 1/(yu*yv)}, yw] - 
     10*G[{0, 1, 1, 1/(yu*yv), 1}, yw] + 8*G[{0, 1, 1, 1/(yu*yv), yu^(-1)}, 
       yw] + 10*G[{0, 1, 1, 1/(yu*yv), yv^(-1)}, yw] - 
     4*G[{0, 1, 1, 1/(yu*yv), 1/(yu*yv)}, yw] - 
     4*G[{0, 1, yu^(-1), 0, yv^(-1)}, yw] + 8*G[{0, 1, yu^(-1), 1, 1}, yw] - 
     8*G[{0, 1, yu^(-1), 1, yu^(-1)}, yw] - 
     8*G[{0, 1, yu^(-1), 1, yv^(-1)}, yw] + 
     4*G[{0, 1, yu^(-1), 1, 1/(yu*yv)}, yw] - 
     8*G[{0, 1, yu^(-1), yu^(-1), 1}, yw] + 
     8*G[{0, 1, yu^(-1), yu^(-1), yv^(-1)}, yw] - 
     8*G[{0, 1, yu^(-1), yv^(-1), 1}, yw] + 
     8*G[{0, 1, yu^(-1), yv^(-1), yu^(-1)}, yw] + 
     8*G[{0, 1, yu^(-1), yv^(-1), yv^(-1)}, yw] - 
     4*G[{0, 1, yu^(-1), yv^(-1), 1/(yu*yv)}, yw] + 
     4*G[{0, 1, yu^(-1), 1/(yu*yv), 1}, yw] - 
     4*G[{0, 1, yu^(-1), 1/(yu*yv), yv^(-1)}, yw] - 
     6*G[{0, 1, yu, 0, yu}, yv^(-1)] - 4*G[{0, 1, yu, 1, 1}, yv^(-1)] + 
     8*G[{0, 1, yu, 1, yu}, yv^(-1)] + 4*G[{0, 1, yu, yu, 1}, yv^(-1)] - 
     8*G[{0, 1, yu, yu, yu}, yv^(-1)] - 6*G[{0, 1, yv^(-1), 0, yv^(-1)}, 
       yw] + 2*G[{0, 1, yv^(-1), 0, 1/(yu*yv)}, yw] + 
     8*G[{0, 1, yv^(-1), 1, 1}, yw] - 8*G[{0, 1, yv^(-1), 1, yu^(-1)}, yw] - 
     8*G[{0, 1, yv^(-1), 1, yv^(-1)}, yw] + 
     4*G[{0, 1, yv^(-1), 1, 1/(yu*yv)}, yw] - 
     8*G[{0, 1, yv^(-1), yu^(-1), 1}, yw] + 
     8*G[{0, 1, yv^(-1), yu^(-1), yu^(-1)}, yw] + 
     8*G[{0, 1, yv^(-1), yu^(-1), yv^(-1)}, yw] - 
     4*G[{0, 1, yv^(-1), yu^(-1), 1/(yu*yv)}, yw] - 
     12*G[{0, 1, yv^(-1), yv^(-1), 1}, yw] + 
     8*G[{0, 1, yv^(-1), yv^(-1), yu^(-1)}, yw] + 
     8*G[{0, 1, yv^(-1), yv^(-1), yv^(-1)}, yw] - 
     4*G[{0, 1, yv^(-1), yv^(-1), 1/(yu*yv)}, yw] + 
     4*G[{0, 1, yv^(-1), 1/(yu*yv), 1}, yw] - 
     4*G[{0, 1, yv^(-1), 1/(yu*yv), yv^(-1)}, yw] + 
     2*G[{0, 1, 1/(yu*yv), 0, yv^(-1)}, yw] + 
     2*G[{0, 1, 1/(yu*yv), 0, 1/(yu*yv)}, yw] - 
     8*G[{0, 1, 1/(yu*yv), 1, 1}, yw] + 4*G[{0, 1, 1/(yu*yv), 1, yu^(-1)}, 
       yw] + 6*G[{0, 1, 1/(yu*yv), 1, yv^(-1)}, yw] - 
     2*G[{0, 1, 1/(yu*yv), 1, 1/(yu*yv)}, yw] + 
     4*G[{0, 1, 1/(yu*yv), yu^(-1), 1}, yw] - 
     4*G[{0, 1, 1/(yu*yv), yu^(-1), yv^(-1)}, yw] + 
     6*G[{0, 1, 1/(yu*yv), yv^(-1), 1}, yw] - 
     4*G[{0, 1, 1/(yu*yv), yv^(-1), yu^(-1)}, yw] - 
     4*G[{0, 1, 1/(yu*yv), yv^(-1), yv^(-1)}, yw] + 
     2*G[{0, 1, 1/(yu*yv), yv^(-1), 1/(yu*yv)}, yw] - 
     2*G[{0, 1, 1/(yu*yv), 1/(yu*yv), 1}, yw] + 
     2*G[{0, 1, 1/(yu*yv), 1/(yu*yv), yv^(-1)}, yw] - 
     2*G[{0, yu^(-1), 0, yu^(-1), 1}, yw] + 
     4*G[{0, yu^(-1), 0, yu^(-1), yv^(-1)}, yw] - 
     4*G[{0, yu^(-1), 0, yu^(-1), 1/(yu*yv)}, yw] - 
     2*G[{0, yu^(-1), 0, yv^(-1), 1}, yw] + 
     4*G[{0, yu^(-1), 0, yv^(-1), yu^(-1)}, yw] + 
     4*G[{0, yu^(-1), 0, yv^(-1), yv^(-1)}, yw] - 
     2*G[{0, yu^(-1), 0, yv^(-1), 1/(yu*yv)}, yw] - 
     2*G[{0, yu^(-1), 0, 1/(yu*yv), 1}, yw] + 
     2*G[{0, yu^(-1), 0, 1/(yu*yv), yv^(-1)}, yw] - 
     4*G[{0, yu^(-1), 0, 1/(yu*yv), 1/(yu*yv)}, yw] - 
     2*G[{0, yu^(-1), 1, 0, yv^(-1)}, yw] - 
     2*G[{0, yu^(-1), 1, 0, 1/(yu*yv)}, yw] - 
     4*G[{0, yu^(-1), 1, 1, yu^(-1)}, yw] - 
     2*G[{0, yu^(-1), 1, 1, yv^(-1)}, yw] + 
     2*G[{0, yu^(-1), 1, 1, 1/(yu*yv)}, yw] - 
     4*G[{0, yu^(-1), 1, yu^(-1), 1}, yw] + 
     4*G[{0, yu^(-1), 1, yu^(-1), yv^(-1)}, yw] - 
     2*G[{0, yu^(-1), 1, yv^(-1), 1}, yw] + 
     4*G[{0, yu^(-1), 1, yv^(-1), yu^(-1)}, yw] + 
     4*G[{0, yu^(-1), 1, yv^(-1), yv^(-1)}, yw] - 
     2*G[{0, yu^(-1), 1, yv^(-1), 1/(yu*yv)}, yw] + 
     2*G[{0, yu^(-1), 1, 1/(yu*yv), 1}, yw] - 
     2*G[{0, yu^(-1), 1, 1/(yu*yv), yv^(-1)}, yw] + 
     4*G[{0, yu^(-1), yu^(-1), 0, yv^(-1)}, yw] - 
     8*G[{0, yu^(-1), yu^(-1), 1, 1}, yw] + 
     4*G[{0, yu^(-1), yu^(-1), 1, yv^(-1)}, yw] + 
     16*G[{0, yu^(-1), yu^(-1), yu^(-1), yu^(-1)}, yw] - 
     8*G[{0, yu^(-1), yu^(-1), yu^(-1), 1/(yu*yv)}, yw] + 
     4*G[{0, yu^(-1), yu^(-1), 1/(yu*yv), 1}, yw] - 
     8*G[{0, yu^(-1), yu^(-1), 1/(yu*yv), yu^(-1)}, yw] - 
     4*G[{0, yu^(-1), yu^(-1), 1/(yu*yv), yv^(-1)}, yw] + 
     4*G[{0, yu^(-1), yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] + 
     4*G[{0, yu^(-1), yv^(-1), 0, yv^(-1)}, yw] - 
     4*G[{0, yu^(-1), 1/(yu*yv), 0, 1/(yu*yv)}, yw] + 
     4*G[{0, yu^(-1), 1/(yu*yv), 1, yu^(-1)}, yw] + 
     2*G[{0, yu^(-1), 1/(yu*yv), 1, yv^(-1)}, yw] - 
     2*G[{0, yu^(-1), 1/(yu*yv), 1, 1/(yu*yv)}, yw] + 
     4*G[{0, yu^(-1), 1/(yu*yv), yu^(-1), 1}, yw] - 
     8*G[{0, yu^(-1), 1/(yu*yv), yu^(-1), yu^(-1)}, yw] - 
     4*G[{0, yu^(-1), 1/(yu*yv), yu^(-1), yv^(-1)}, yw] + 
     4*G[{0, yu^(-1), 1/(yu*yv), yu^(-1), 1/(yu*yv)}, yw] + 
     6*G[{0, yu^(-1), 1/(yu*yv), yv^(-1), 1}, yw] - 
     4*G[{0, yu^(-1), 1/(yu*yv), yv^(-1), yu^(-1)}, yw] - 
     4*G[{0, yu^(-1), 1/(yu*yv), yv^(-1), yv^(-1)}, yw] + 
     2*G[{0, yu^(-1), 1/(yu*yv), yv^(-1), 1/(yu*yv)}, yw] - 
     2*G[{0, yu^(-1), 1/(yu*yv), 1/(yu*yv), 1}, yw] + 
     2*G[{0, yu^(-1), 1/(yu*yv), 1/(yu*yv), yv^(-1)}, yw] + 
     2*G[{0, yu, 0, yu, 1}, yv^(-1)] - 8*G[{0, yu, 0, yu, yu}, yv^(-1)] + 
     2*G[{0, yu, 1, 1, yu}, yv^(-1)] + 2*G[{0, yu, 1, yu, 1}, yv^(-1)] - 
     4*G[{0, yu, 1, yu, yu}, yv^(-1)] + 4*G[{0, yu, yu, 1, 1}, yv^(-1)] - 
     4*G[{0, yu, yu, 1, yu}, yv^(-1)] + 4*G[{0, yv^(-1), 0, yv^(-1), 1}, 
       yw] - 4*G[{0, yv^(-1), 0, yv^(-1), yu^(-1)}, yw] - 
     8*G[{0, yv^(-1), 0, yv^(-1), yv^(-1)}, yw] - 
     2*G[{0, yv^(-1), 0, yv^(-1), 1/(yu*yv)}, yw] - 
     4*G[{0, yv^(-1), 0, 1/(yu*yv), 1}, yw] + 
     4*G[{0, yv^(-1), 0, 1/(yu*yv), yu^(-1)}, yw] + 
     2*G[{0, yv^(-1), 0, 1/(yu*yv), yv^(-1)}, yw] - 
     4*G[{0, yv^(-1), 0, 1/(yu*yv), 1/(yu*yv)}, yw] - 
     4*G[{0, yv^(-1), 1, 1, yu^(-1)}, yw] - 
     2*G[{0, yv^(-1), 1, 1, yv^(-1)}, yw] + 
     2*G[{0, yv^(-1), 1, 1, 1/(yu*yv)}, yw] - 
     4*G[{0, yv^(-1), 1, yu^(-1), 1}, yw] + 
     8*G[{0, yv^(-1), 1, yu^(-1), yu^(-1)}, yw] + 
     4*G[{0, yv^(-1), 1, yu^(-1), yv^(-1)}, yw] - 
     4*G[{0, yv^(-1), 1, yu^(-1), 1/(yu*yv)}, yw] - 
     6*G[{0, yv^(-1), 1, yv^(-1), 1}, yw] + 
     4*G[{0, yv^(-1), 1, yv^(-1), yu^(-1)}, yw] + 
     4*G[{0, yv^(-1), 1, yv^(-1), yv^(-1)}, yw] - 
     2*G[{0, yv^(-1), 1, yv^(-1), 1/(yu*yv)}, yw] + 
     2*G[{0, yv^(-1), 1, 1/(yu*yv), 1}, yw] - 
     2*G[{0, yv^(-1), 1, 1/(yu*yv), yv^(-1)}, yw] - 
     4*G[{0, yv^(-1), yv^(-1), 0, 1/(yu*yv)}, yw] - 
     8*G[{0, yv^(-1), yv^(-1), 1, 1}, yw] + 
     4*G[{0, yv^(-1), yv^(-1), 1, yv^(-1)}, yw] + 
     8*G[{0, yv^(-1), yv^(-1), yv^(-1), 1}, yw] + 
     4*G[{0, yv^(-1), yv^(-1), 1/(yu*yv), 1}, yw] - 
     8*G[{0, yv^(-1), yv^(-1), 1/(yu*yv), yu^(-1)}, yw] - 
     4*G[{0, yv^(-1), yv^(-1), 1/(yu*yv), yv^(-1)}, yw] + 
     4*G[{0, yv^(-1), yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] - 
     2*G[{0, yv^(-1), 1/(yu*yv), 0, 1/(yu*yv)}, yw] + 
     4*G[{0, yv^(-1), 1/(yu*yv), 1, yu^(-1)}, yw] + 
     2*G[{0, yv^(-1), 1/(yu*yv), 1, yv^(-1)}, yw] - 
     2*G[{0, yv^(-1), 1/(yu*yv), 1, 1/(yu*yv)}, yw] + 
     4*G[{0, yv^(-1), 1/(yu*yv), yu^(-1), 1}, yw] - 
     4*G[{0, yv^(-1), 1/(yu*yv), yu^(-1), yv^(-1)}, yw] + 
     2*G[{0, yv^(-1), 1/(yu*yv), yv^(-1), 1}, yw] - 
     4*G[{0, yv^(-1), 1/(yu*yv), yv^(-1), yu^(-1)}, yw] - 
     4*G[{0, yv^(-1), 1/(yu*yv), yv^(-1), yv^(-1)}, yw] + 
     2*G[{0, yv^(-1), 1/(yu*yv), yv^(-1), 1/(yu*yv)}, yw] - 
     2*G[{0, yv^(-1), 1/(yu*yv), 1/(yu*yv), 1}, yw] + 
     2*G[{0, yv^(-1), 1/(yu*yv), 1/(yu*yv), yv^(-1)}, yw] - 
     2*G[{0, 1/(yu*yv), 0, 1/(yu*yv), yv^(-1)}, yw] - 
     4*G[{0, 1/(yu*yv), 0, 1/(yu*yv), 1/(yu*yv)}, yw] - 
     4*G[{0, 1/(yu*yv), 1, 1, yu^(-1)}, yw] - 
     2*G[{0, 1/(yu*yv), 1, 1, yv^(-1)}, yw] + 
     2*G[{0, 1/(yu*yv), 1, 1, 1/(yu*yv)}, yw] - 
     4*G[{0, 1/(yu*yv), 1, yu^(-1), 1}, yw] + 
     8*G[{0, 1/(yu*yv), 1, yu^(-1), yu^(-1)}, yw] + 
     4*G[{0, 1/(yu*yv), 1, yu^(-1), yv^(-1)}, yw] - 
     4*G[{0, 1/(yu*yv), 1, yu^(-1), 1/(yu*yv)}, yw] - 
     2*G[{0, 1/(yu*yv), 1, yv^(-1), 1}, yw] + 
     4*G[{0, 1/(yu*yv), 1, yv^(-1), yu^(-1)}, yw] + 
     4*G[{0, 1/(yu*yv), 1, yv^(-1), yv^(-1)}, yw] - 
     2*G[{0, 1/(yu*yv), 1, yv^(-1), 1/(yu*yv)}, yw] + 
     6*G[{0, 1/(yu*yv), 1, 1/(yu*yv), 1}, yw] - 
     8*G[{0, 1/(yu*yv), 1, 1/(yu*yv), yu^(-1)}, yw] - 
     6*G[{0, 1/(yu*yv), 1, 1/(yu*yv), yv^(-1)}, yw] + 
     4*G[{0, 1/(yu*yv), 1, 1/(yu*yv), 1/(yu*yv)}, yw] + 
     8*G[{0, 1/(yu*yv), yu^(-1), 1, yu^(-1)}, yw] + 
     4*G[{0, 1/(yu*yv), yu^(-1), 1, yv^(-1)}, yw] - 
     4*G[{0, 1/(yu*yv), yu^(-1), 1, 1/(yu*yv)}, yw] + 
     8*G[{0, 1/(yu*yv), yu^(-1), yu^(-1), 1}, yw] - 
     16*G[{0, 1/(yu*yv), yu^(-1), yu^(-1), yu^(-1)}, yw] - 
     8*G[{0, 1/(yu*yv), yu^(-1), yu^(-1), yv^(-1)}, yw] + 
     8*G[{0, 1/(yu*yv), yu^(-1), yu^(-1), 1/(yu*yv)}, yw] + 
     8*G[{0, 1/(yu*yv), yu^(-1), yv^(-1), 1}, yw] - 
     8*G[{0, 1/(yu*yv), yu^(-1), yv^(-1), yu^(-1)}, yw] - 
     8*G[{0, 1/(yu*yv), yu^(-1), yv^(-1), yv^(-1)}, yw] + 
     4*G[{0, 1/(yu*yv), yu^(-1), yv^(-1), 1/(yu*yv)}, yw] - 
     8*G[{0, 1/(yu*yv), yu^(-1), 1/(yu*yv), 1}, yw] + 
     8*G[{0, 1/(yu*yv), yu^(-1), 1/(yu*yv), yu^(-1)}, yw] + 
     8*G[{0, 1/(yu*yv), yu^(-1), 1/(yu*yv), yv^(-1)}, yw] - 
     4*G[{0, 1/(yu*yv), yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] + 
     8*G[{0, 1/(yu*yv), yv^(-1), 1, yu^(-1)}, yw] + 
     4*G[{0, 1/(yu*yv), yv^(-1), 1, yv^(-1)}, yw] - 
     4*G[{0, 1/(yu*yv), yv^(-1), 1, 1/(yu*yv)}, yw] + 
     8*G[{0, 1/(yu*yv), yv^(-1), yu^(-1), 1}, yw] - 
     8*G[{0, 1/(yu*yv), yv^(-1), yu^(-1), yu^(-1)}, yw] - 
     8*G[{0, 1/(yu*yv), yv^(-1), yu^(-1), yv^(-1)}, yw] + 
     4*G[{0, 1/(yu*yv), yv^(-1), yu^(-1), 1/(yu*yv)}, yw] + 
     4*G[{0, 1/(yu*yv), yv^(-1), yv^(-1), 1}, yw] - 
     8*G[{0, 1/(yu*yv), yv^(-1), yv^(-1), yu^(-1)}, yw] - 
     8*G[{0, 1/(yu*yv), yv^(-1), yv^(-1), yv^(-1)}, yw] + 
     4*G[{0, 1/(yu*yv), yv^(-1), yv^(-1), 1/(yu*yv)}, yw] - 
     8*G[{0, 1/(yu*yv), yv^(-1), 1/(yu*yv), 1}, yw] + 
     8*G[{0, 1/(yu*yv), yv^(-1), 1/(yu*yv), yu^(-1)}, yw] + 
     8*G[{0, 1/(yu*yv), yv^(-1), 1/(yu*yv), yv^(-1)}, yw] - 
     4*G[{0, 1/(yu*yv), yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] + 
     8*G[{0, 1/(yu*yv), 1/(yu*yv), 1, 1}, yw] - 
     12*G[{0, 1/(yu*yv), 1/(yu*yv), 1, yu^(-1)}, yw] - 
     10*G[{0, 1/(yu*yv), 1/(yu*yv), 1, yv^(-1)}, yw] + 
     6*G[{0, 1/(yu*yv), 1/(yu*yv), 1, 1/(yu*yv)}, yw] - 
     12*G[{0, 1/(yu*yv), 1/(yu*yv), yu^(-1), 1}, yw] + 
     8*G[{0, 1/(yu*yv), 1/(yu*yv), yu^(-1), yu^(-1)}, yw] + 
     12*G[{0, 1/(yu*yv), 1/(yu*yv), yu^(-1), yv^(-1)}, yw] - 
     4*G[{0, 1/(yu*yv), 1/(yu*yv), yu^(-1), 1/(yu*yv)}, yw] - 
     14*G[{0, 1/(yu*yv), 1/(yu*yv), yv^(-1), 1}, yw] + 
     12*G[{0, 1/(yu*yv), 1/(yu*yv), yv^(-1), yu^(-1)}, yw] + 
     12*G[{0, 1/(yu*yv), 1/(yu*yv), yv^(-1), yv^(-1)}, yw] - 
     6*G[{0, 1/(yu*yv), 1/(yu*yv), yv^(-1), 1/(yu*yv)}, yw] + 
     6*G[{0, 1/(yu*yv), 1/(yu*yv), 1/(yu*yv), 1}, yw] - 
     6*G[{0, 1/(yu*yv), 1/(yu*yv), 1/(yu*yv), yv^(-1)}, yw] - 
     (4*Pi^2*Zeta[3])/3 - 2*G[{0}, yu^(-1)]^2*Zeta[3] - 
     4*G[{0}, yu^(-1)]*G[{0}, yv^(-1)]*Zeta[3] - 2*G[{0}, yv^(-1)]^2*
      Zeta[3] + 4*G[{0}, yu^(-1)]*G[{0}, yw]*Zeta[3] + 
     4*G[{0}, yv^(-1)]*G[{0}, yw]*Zeta[3] - 2*G[{0}, yw]^2*Zeta[3] + 
     2*G[{1}, yu^(-1)]^2*Zeta[3] + 4*G[{0}, yu^(-1)]*G[{1}, yv^(-1)]*
      Zeta[3] + 4*G[{0}, yv^(-1)]*G[{1}, yv^(-1)]*Zeta[3] - 
     4*G[{0}, yw]*G[{1}, yv^(-1)]*Zeta[3] - 2*G[{1}, yv^(-1)]^2*Zeta[3] - 
     4*G[{1}, yu^(-1)]*G[{1}, yw]*Zeta[3] + 2*G[{1}, yw]^2*Zeta[3] - 
     4*G[{0}, yu^(-1)]*G[{1/(yu*yv)}, yw]*Zeta[3] - 
     4*G[{0}, yv^(-1)]*G[{1/(yu*yv)}, yw]*Zeta[3] + 
     4*G[{0}, yw]*G[{1/(yu*yv)}, yw]*Zeta[3] + 4*G[{1}, yv^(-1)]*
      G[{1/(yu*yv)}, yw]*Zeta[3] - 2*G[{1/(yu*yv)}, yw]^2*Zeta[3] - 
     4*G[{0, 1}, yu^(-1)]*Zeta[3] - 4*G[{0, 1}, yv^(-1)]*Zeta[3] - 
     4*G[{0, 1}, yw]*Zeta[3] + 4*G[{0, yu^(-1)}, yw]*Zeta[3] + 
     4*G[{0, yu}, yv^(-1)]*Zeta[3] + 4*G[{0, yv^(-1)}, yw]*Zeta[3] - 
     4*G[{0, 1/(yu*yv)}, yw]*Zeta[3] - 4*Zeta[5]
 
K1vwuRegII = -(Pi^4*G[{0}, yu^(-1)])/15 - (Pi^4*G[{0}, yv^(-1)])/15 + 
     (Pi^4*G[{0}, yw])/15 + (Pi^2*G[{0}, yu^(-1)]*G[{1}, yu^(-1)]^2)/6 + 
     (Pi^2*G[{0}, yv^(-1)]*G[{1}, yu^(-1)]^2)/6 - 
     (Pi^2*G[{0}, yw]*G[{1}, yu^(-1)]^2)/6 - 
     (Pi^2*G[{0}, yu^(-1)]*G[{1}, yu^(-1)]*G[{1}, yv^(-1)])/3 - 
     (Pi^2*G[{0}, yv^(-1)]*G[{1}, yu^(-1)]*G[{1}, yv^(-1)])/3 + 
     (Pi^2*G[{0}, yw]*G[{1}, yu^(-1)]*G[{1}, yv^(-1)])/3 + 
     (Pi^2*G[{0}, yu^(-1)]*G[{1}, yv^(-1)]^2)/6 + 
     (Pi^2*G[{0}, yv^(-1)]*G[{1}, yv^(-1)]^2)/6 - 
     (Pi^2*G[{0}, yw]*G[{1}, yv^(-1)]^2)/6 + (17*Pi^4*G[{1}, yw])/180 - 
     (Pi^2*G[{0}, yu^(-1)]*G[{1}, yw]^2)/6 - 
     (Pi^2*G[{0}, yv^(-1)]*G[{1}, yw]^2)/6 + (Pi^2*G[{0}, yw]*G[{1}, yw]^2)/
      6 - (17*Pi^4*G[{1/(yu*yv)}, yw])/180 + 
     (Pi^2*G[{0}, yu^(-1)]*G[{1}, yw]*G[{1/(yu*yv)}, yw])/3 + 
     (Pi^2*G[{0}, yv^(-1)]*G[{1}, yw]*G[{1/(yu*yv)}, yw])/3 - 
     (Pi^2*G[{0}, yw]*G[{1}, yw]*G[{1/(yu*yv)}, yw])/3 - 
     (Pi^2*G[{0}, yu^(-1)]*G[{1/(yu*yv)}, yw]^2)/6 - 
     (Pi^2*G[{0}, yv^(-1)]*G[{1/(yu*yv)}, yw]^2)/6 + 
     (Pi^2*G[{0}, yw]*G[{1/(yu*yv)}, yw]^2)/6 - 
     (Pi^2*G[{0}, yu^(-1)]*G[{0, 1}, yu^(-1)])/3 - 
     (Pi^2*G[{0}, yv^(-1)]*G[{0, 1}, yu^(-1)])/3 + 
     (Pi^2*G[{0}, yw]*G[{0, 1}, yu^(-1)])/3 - 
     (Pi^2*G[{1}, yu^(-1)]*G[{0, 1}, yu^(-1)])/3 + 
     G[{0}, yu^(-1)]*G[{1}, yu^(-1)]^2*G[{0, 1}, yu^(-1)] + 
     G[{0}, yv^(-1)]*G[{1}, yu^(-1)]^2*G[{0, 1}, yu^(-1)] - 
     G[{0}, yw]*G[{1}, yu^(-1)]^2*G[{0, 1}, yu^(-1)] + 
     (Pi^2*G[{1}, yv^(-1)]*G[{0, 1}, yu^(-1)])/3 - 
     2*G[{0}, yu^(-1)]*G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*G[{0, 1}, yu^(-1)] - 
     2*G[{0}, yv^(-1)]*G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*G[{0, 1}, yu^(-1)] + 
     2*G[{0}, yw]*G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*G[{0, 1}, yu^(-1)] + 
     G[{0}, yu^(-1)]*G[{1}, yv^(-1)]^2*G[{0, 1}, yu^(-1)] + 
     G[{0}, yv^(-1)]*G[{1}, yv^(-1)]^2*G[{0, 1}, yu^(-1)] - 
     G[{0}, yw]*G[{1}, yv^(-1)]^2*G[{0, 1}, yu^(-1)] - 
     G[{0}, yu^(-1)]*G[{1}, yw]^2*G[{0, 1}, yu^(-1)] - 
     G[{0}, yv^(-1)]*G[{1}, yw]^2*G[{0, 1}, yu^(-1)] + 
     G[{0}, yw]*G[{1}, yw]^2*G[{0, 1}, yu^(-1)] + 
     2*G[{0}, yu^(-1)]*G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1}, yu^(-1)] + 
     2*G[{0}, yv^(-1)]*G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1}, yu^(-1)] - 
     2*G[{0}, yw]*G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1}, yu^(-1)] - 
     G[{0}, yu^(-1)]*G[{1/(yu*yv)}, yw]^2*G[{0, 1}, yu^(-1)] - 
     G[{0}, yv^(-1)]*G[{1/(yu*yv)}, yw]^2*G[{0, 1}, yu^(-1)] + 
     G[{0}, yw]*G[{1/(yu*yv)}, yw]^2*G[{0, 1}, yu^(-1)] - 
     G[{1}, yw]*G[{0, 1}, yu^(-1)]^2 + G[{1/(yu*yv)}, yw]*
      G[{0, 1}, yu^(-1)]^2 - (Pi^2*G[{0}, yu^(-1)]*G[{0, 1}, yv^(-1)])/3 - 
     (Pi^2*G[{0}, yv^(-1)]*G[{0, 1}, yv^(-1)])/3 + 
     (Pi^2*G[{0}, yw]*G[{0, 1}, yv^(-1)])/3 + 
     (Pi^2*G[{1}, yu^(-1)]*G[{0, 1}, yv^(-1)])/3 - 
     G[{0}, yu^(-1)]*G[{1}, yu^(-1)]^2*G[{0, 1}, yv^(-1)] - 
     G[{0}, yv^(-1)]*G[{1}, yu^(-1)]^2*G[{0, 1}, yv^(-1)] + 
     G[{0}, yw]*G[{1}, yu^(-1)]^2*G[{0, 1}, yv^(-1)] + 
     G[{1}, yu^(-1)]^3*G[{0, 1}, yv^(-1)] - 
     (Pi^2*G[{1}, yv^(-1)]*G[{0, 1}, yv^(-1)])/3 - 
     G[{1}, yu^(-1)]^2*G[{1}, yv^(-1)]*G[{0, 1}, yv^(-1)] + 
     G[{0}, yu^(-1)]*G[{1}, yv^(-1)]^2*G[{0, 1}, yv^(-1)] + 
     G[{0}, yv^(-1)]*G[{1}, yv^(-1)]^2*G[{0, 1}, yv^(-1)] - 
     G[{0}, yw]*G[{1}, yv^(-1)]^2*G[{0, 1}, yv^(-1)] - 
     2*G[{0}, yu^(-1)]*G[{1}, yu^(-1)]*G[{1}, yw]*G[{0, 1}, yv^(-1)] - 
     2*G[{0}, yv^(-1)]*G[{1}, yu^(-1)]*G[{1}, yw]*G[{0, 1}, yv^(-1)] + 
     2*G[{0}, yw]*G[{1}, yu^(-1)]*G[{1}, yw]*G[{0, 1}, yv^(-1)] + 
     G[{1}, yu^(-1)]^2*G[{1}, yw]*G[{0, 1}, yv^(-1)] - 
     G[{0}, yu^(-1)]*G[{1}, yw]^2*G[{0, 1}, yv^(-1)] - 
     G[{0}, yv^(-1)]*G[{1}, yw]^2*G[{0, 1}, yv^(-1)] + 
     G[{0}, yw]*G[{1}, yw]^2*G[{0, 1}, yv^(-1)] + 
     2*G[{0}, yu^(-1)]*G[{1}, yu^(-1)]*G[{1/(yu*yv)}, yw]*
      G[{0, 1}, yv^(-1)] + 2*G[{0}, yv^(-1)]*G[{1}, yu^(-1)]*
      G[{1/(yu*yv)}, yw]*G[{0, 1}, yv^(-1)] - 2*G[{0}, yw]*G[{1}, yu^(-1)]*
      G[{1/(yu*yv)}, yw]*G[{0, 1}, yv^(-1)] - G[{1}, yu^(-1)]^2*
      G[{1/(yu*yv)}, yw]*G[{0, 1}, yv^(-1)] + 2*G[{0}, yu^(-1)]*G[{1}, yw]*
      G[{1/(yu*yv)}, yw]*G[{0, 1}, yv^(-1)] + 2*G[{0}, yv^(-1)]*G[{1}, yw]*
      G[{1/(yu*yv)}, yw]*G[{0, 1}, yv^(-1)] - 2*G[{0}, yw]*G[{1}, yw]*
      G[{1/(yu*yv)}, yw]*G[{0, 1}, yv^(-1)] - G[{0}, yu^(-1)]*
      G[{1/(yu*yv)}, yw]^2*G[{0, 1}, yv^(-1)] - G[{0}, yv^(-1)]*
      G[{1/(yu*yv)}, yw]^2*G[{0, 1}, yv^(-1)] + 
     G[{0}, yw]*G[{1/(yu*yv)}, yw]^2*G[{0, 1}, yv^(-1)] + 
     2*G[{1}, yw]*G[{0, 1}, yu^(-1)]*G[{0, 1}, yv^(-1)] - 
     2*G[{1/(yu*yv)}, yw]*G[{0, 1}, yu^(-1)]*G[{0, 1}, yv^(-1)] - 
     G[{1}, yu^(-1)]*G[{0, 1}, yv^(-1)]^2 - G[{1}, yw]*G[{0, 1}, yv^(-1)]^2 + 
     G[{1/(yu*yv)}, yw]*G[{0, 1}, yv^(-1)]^2 - 
     (Pi^2*G[{1}, yu^(-1)]*G[{0, 1}, yw])/3 + G[{0}, yu^(-1)]*
      G[{1}, yu^(-1)]^2*G[{0, 1}, yw] + G[{0}, yv^(-1)]*G[{1}, yu^(-1)]^2*
      G[{0, 1}, yw] - G[{0}, yw]*G[{1}, yu^(-1)]^2*G[{0, 1}, yw] - 
     G[{1}, yu^(-1)]^3*G[{0, 1}, yw] - (Pi^2*G[{1}, yv^(-1)]*G[{0, 1}, yw])/
      3 - 2*G[{0}, yu^(-1)]*G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*G[{0, 1}, yw] - 
     2*G[{0}, yv^(-1)]*G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*G[{0, 1}, yw] + 
     2*G[{0}, yw]*G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*G[{0, 1}, yw] - 
     G[{1}, yu^(-1)]^2*G[{1}, yv^(-1)]*G[{0, 1}, yw] + 
     G[{0}, yu^(-1)]*G[{1}, yv^(-1)]^2*G[{0, 1}, yw] + 
     G[{0}, yv^(-1)]*G[{1}, yv^(-1)]^2*G[{0, 1}, yw] - 
     G[{0}, yw]*G[{1}, yv^(-1)]^2*G[{0, 1}, yw] + 
     G[{1}, yu^(-1)]*G[{1}, yv^(-1)]^2*G[{0, 1}, yw] - 
     G[{1}, yv^(-1)]^3*G[{0, 1}, yw] - (Pi^2*G[{1}, yw]*G[{0, 1}, yw])/3 - 
     G[{1}, yu^(-1)]^2*G[{1}, yw]*G[{0, 1}, yw] - 
     2*G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*G[{1}, yw]*G[{0, 1}, yw] - 
     G[{1}, yv^(-1)]^2*G[{1}, yw]*G[{0, 1}, yw] - 
     G[{0}, yu^(-1)]*G[{1}, yw]^2*G[{0, 1}, yw] - 
     G[{0}, yv^(-1)]*G[{1}, yw]^2*G[{0, 1}, yw] + G[{0}, yw]*G[{1}, yw]^2*
      G[{0, 1}, yw] + (2*Pi^2*G[{yu}, yv^(-1)]*G[{0, 1}, yw])/3 + 
     2*G[{1}, yu^(-1)]^2*G[{yu}, yv^(-1)]*G[{0, 1}, yw] + 
     4*G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*G[{yu}, yv^(-1)]*G[{0, 1}, yw] + 
     2*G[{1}, yv^(-1)]^2*G[{yu}, yv^(-1)]*G[{0, 1}, yw] + 
     4*G[{1}, yu^(-1)]*G[{1}, yw]*G[{yu}, yv^(-1)]*G[{0, 1}, yw] + 
     4*G[{1}, yv^(-1)]*G[{1}, yw]*G[{yu}, yv^(-1)]*G[{0, 1}, yw] + 
     2*G[{1}, yw]^2*G[{yu}, yv^(-1)]*G[{0, 1}, yw] - 
     4*G[{1}, yu^(-1)]*G[{yu}, yv^(-1)]^2*G[{0, 1}, yw] - 
     4*G[{1}, yv^(-1)]*G[{yu}, yv^(-1)]^2*G[{0, 1}, yw] - 
     4*G[{1}, yw]*G[{yu}, yv^(-1)]^2*G[{0, 1}, yw] + 
     (8*G[{yu}, yv^(-1)]^3*G[{0, 1}, yw])/3 + 
     (Pi^2*G[{1/(yu*yv)}, yw]*G[{0, 1}, yw])/3 + G[{1}, yu^(-1)]^2*
      G[{1/(yu*yv)}, yw]*G[{0, 1}, yw] + 2*G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*
      G[{1/(yu*yv)}, yw]*G[{0, 1}, yw] + G[{1}, yv^(-1)]^2*G[{1/(yu*yv)}, yw]*
      G[{0, 1}, yw] + 2*G[{0}, yu^(-1)]*G[{1}, yw]*G[{1/(yu*yv)}, yw]*
      G[{0, 1}, yw] + 2*G[{0}, yv^(-1)]*G[{1}, yw]*G[{1/(yu*yv)}, yw]*
      G[{0, 1}, yw] - 2*G[{0}, yw]*G[{1}, yw]*G[{1/(yu*yv)}, yw]*
      G[{0, 1}, yw] - 4*G[{1}, yu^(-1)]*G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw]*
      G[{0, 1}, yw] - 4*G[{1}, yv^(-1)]*G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw]*
      G[{0, 1}, yw] - 4*G[{1}, yw]*G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw]*
      G[{0, 1}, yw] + 4*G[{yu}, yv^(-1)]^2*G[{1/(yu*yv)}, yw]*G[{0, 1}, yw] - 
     G[{0}, yu^(-1)]*G[{1/(yu*yv)}, yw]^2*G[{0, 1}, yw] - 
     G[{0}, yv^(-1)]*G[{1/(yu*yv)}, yw]^2*G[{0, 1}, yw] + 
     G[{0}, yw]*G[{1/(yu*yv)}, yw]^2*G[{0, 1}, yw] + 
     2*G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw]^2*G[{0, 1}, yw] - 
     2*G[{0}, yu^(-1)]*G[{0, 1}, yu^(-1)]*G[{0, 1}, yw] - 
     2*G[{0}, yv^(-1)]*G[{0, 1}, yu^(-1)]*G[{0, 1}, yw] + 
     2*G[{0}, yw]*G[{0, 1}, yu^(-1)]*G[{0, 1}, yw] + 
     4*G[{1}, yv^(-1)]*G[{0, 1}, yu^(-1)]*G[{0, 1}, yw] - 
     2*G[{0}, yu^(-1)]*G[{0, 1}, yv^(-1)]*G[{0, 1}, yw] - 
     2*G[{0}, yv^(-1)]*G[{0, 1}, yv^(-1)]*G[{0, 1}, yw] + 
     2*G[{0}, yw]*G[{0, 1}, yv^(-1)]*G[{0, 1}, yw] + 
     2*G[{1}, yu^(-1)]*G[{0, 1}, yv^(-1)]*G[{0, 1}, yw] + 
     G[{1}, yu^(-1)]*G[{0, 1}, yw]^2 + G[{1}, yv^(-1)]*G[{0, 1}, yw]^2 + 
     G[{1}, yw]*G[{0, 1}, yw]^2 - 2*G[{yu}, yv^(-1)]*G[{0, 1}, yw]^2 - 
     G[{1/(yu*yv)}, yw]*G[{0, 1}, yw]^2 - G[{0}, yu^(-1)]*G[{1}, yu^(-1)]^2*
      G[{0, yu^(-1)}, yw] - G[{0}, yv^(-1)]*G[{1}, yu^(-1)]^2*
      G[{0, yu^(-1)}, yw] + G[{0}, yw]*G[{1}, yu^(-1)]^2*
      G[{0, yu^(-1)}, yw] + G[{1}, yu^(-1)]^3*G[{0, yu^(-1)}, yw] + 
     2*G[{0}, yu^(-1)]*G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*G[{0, yu^(-1)}, yw] + 
     2*G[{0}, yv^(-1)]*G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*G[{0, yu^(-1)}, yw] - 
     2*G[{0}, yw]*G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*G[{0, yu^(-1)}, yw] - 
     G[{1}, yu^(-1)]^2*G[{1}, yv^(-1)]*G[{0, yu^(-1)}, yw] - 
     G[{0}, yu^(-1)]*G[{1}, yv^(-1)]^2*G[{0, yu^(-1)}, yw] - 
     G[{0}, yv^(-1)]*G[{1}, yv^(-1)]^2*G[{0, yu^(-1)}, yw] + 
     G[{0}, yw]*G[{1}, yv^(-1)]^2*G[{0, yu^(-1)}, yw] - 
     3*G[{1}, yu^(-1)]*G[{1}, yv^(-1)]^2*G[{0, yu^(-1)}, yw] + 
     G[{1}, yv^(-1)]^3*G[{0, yu^(-1)}, yw] + G[{1}, yu^(-1)]^2*G[{1}, yw]*
      G[{0, yu^(-1)}, yw] - 2*G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*G[{1}, yw]*
      G[{0, yu^(-1)}, yw] - G[{1}, yv^(-1)]^2*G[{1}, yw]*
      G[{0, yu^(-1)}, yw] + G[{0}, yu^(-1)]*G[{1}, yw]^2*
      G[{0, yu^(-1)}, yw] + G[{0}, yv^(-1)]*G[{1}, yw]^2*
      G[{0, yu^(-1)}, yw] - G[{0}, yw]*G[{1}, yw]^2*G[{0, yu^(-1)}, yw] - 
     2*G[{1}, yv^(-1)]*G[{1}, yw]^2*G[{0, yu^(-1)}, yw] - 
     G[{1}, yu^(-1)]^2*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1)}, yw] + 
     2*G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*G[{1/(yu*yv)}, yw]*
      G[{0, yu^(-1)}, yw] + G[{1}, yv^(-1)]^2*G[{1/(yu*yv)}, yw]*
      G[{0, yu^(-1)}, yw] - 2*G[{0}, yu^(-1)]*G[{1}, yw]*G[{1/(yu*yv)}, yw]*
      G[{0, yu^(-1)}, yw] - 2*G[{0}, yv^(-1)]*G[{1}, yw]*G[{1/(yu*yv)}, yw]*
      G[{0, yu^(-1)}, yw] + 2*G[{0}, yw]*G[{1}, yw]*G[{1/(yu*yv)}, yw]*
      G[{0, yu^(-1)}, yw] + 4*G[{1}, yv^(-1)]*G[{1}, yw]*G[{1/(yu*yv)}, yw]*
      G[{0, yu^(-1)}, yw] + G[{0}, yu^(-1)]*G[{1/(yu*yv)}, yw]^2*
      G[{0, yu^(-1)}, yw] + G[{0}, yv^(-1)]*G[{1/(yu*yv)}, yw]^2*
      G[{0, yu^(-1)}, yw] - G[{0}, yw]*G[{1/(yu*yv)}, yw]^2*
      G[{0, yu^(-1)}, yw] - 2*G[{1}, yv^(-1)]*G[{1/(yu*yv)}, yw]^2*
      G[{0, yu^(-1)}, yw] + 2*G[{0}, yu^(-1)]*G[{0, 1}, yu^(-1)]*
      G[{0, yu^(-1)}, yw] + 2*G[{0}, yv^(-1)]*G[{0, 1}, yu^(-1)]*
      G[{0, yu^(-1)}, yw] - 2*G[{0}, yw]*G[{0, 1}, yu^(-1)]*
      G[{0, yu^(-1)}, yw] - 2*G[{1}, yu^(-1)]*G[{0, 1}, yu^(-1)]*
      G[{0, yu^(-1)}, yw] - 2*G[{1}, yv^(-1)]*G[{0, 1}, yu^(-1)]*
      G[{0, yu^(-1)}, yw] - 2*G[{1}, yw]*G[{0, 1}, yu^(-1)]*
      G[{0, yu^(-1)}, yw] + 2*G[{1/(yu*yv)}, yw]*G[{0, 1}, yu^(-1)]*
      G[{0, yu^(-1)}, yw] + 2*G[{0}, yu^(-1)]*G[{0, 1}, yv^(-1)]*
      G[{0, yu^(-1)}, yw] + 2*G[{0}, yv^(-1)]*G[{0, 1}, yv^(-1)]*
      G[{0, yu^(-1)}, yw] - 2*G[{0}, yw]*G[{0, 1}, yv^(-1)]*
      G[{0, yu^(-1)}, yw] - 2*G[{1}, yv^(-1)]*G[{0, 1}, yv^(-1)]*
      G[{0, yu^(-1)}, yw] + 2*G[{1}, yw]*G[{0, 1}, yv^(-1)]*
      G[{0, yu^(-1)}, yw] - 2*G[{1/(yu*yv)}, yw]*G[{0, 1}, yv^(-1)]*
      G[{0, yu^(-1)}, yw] + (Pi^2*G[{0}, yu^(-1)]*G[{0, yu}, yv^(-1)])/3 + 
     (Pi^2*G[{0}, yv^(-1)]*G[{0, yu}, yv^(-1)])/3 - 
     (Pi^2*G[{0}, yw]*G[{0, yu}, yv^(-1)])/3 + G[{0}, yu^(-1)]*
      G[{1}, yu^(-1)]^2*G[{0, yu}, yv^(-1)] + G[{0}, yv^(-1)]*
      G[{1}, yu^(-1)]^2*G[{0, yu}, yv^(-1)] - G[{0}, yw]*G[{1}, yu^(-1)]^2*
      G[{0, yu}, yv^(-1)] - G[{1}, yu^(-1)]^3*G[{0, yu}, yv^(-1)] + 
     G[{1}, yu^(-1)]^2*G[{1}, yv^(-1)]*G[{0, yu}, yv^(-1)] - 
     G[{0}, yu^(-1)]*G[{1}, yv^(-1)]^2*G[{0, yu}, yv^(-1)] - 
     G[{0}, yv^(-1)]*G[{1}, yv^(-1)]^2*G[{0, yu}, yv^(-1)] + 
     G[{0}, yw]*G[{1}, yv^(-1)]^2*G[{0, yu}, yv^(-1)] + 
     (Pi^2*G[{1}, yw]*G[{0, yu}, yv^(-1)])/3 + 2*G[{0}, yu^(-1)]*
      G[{1}, yu^(-1)]*G[{1}, yw]*G[{0, yu}, yv^(-1)] + 
     2*G[{0}, yv^(-1)]*G[{1}, yu^(-1)]*G[{1}, yw]*G[{0, yu}, yv^(-1)] - 
     2*G[{0}, yw]*G[{1}, yu^(-1)]*G[{1}, yw]*G[{0, yu}, yv^(-1)] - 
     G[{1}, yu^(-1)]^2*G[{1}, yw]*G[{0, yu}, yv^(-1)] + 
     G[{0}, yu^(-1)]*G[{1}, yw]^2*G[{0, yu}, yv^(-1)] + 
     G[{0}, yv^(-1)]*G[{1}, yw]^2*G[{0, yu}, yv^(-1)] - 
     G[{0}, yw]*G[{1}, yw]^2*G[{0, yu}, yv^(-1)] - 
     (Pi^2*G[{1/(yu*yv)}, yw]*G[{0, yu}, yv^(-1)])/3 - 
     2*G[{0}, yu^(-1)]*G[{1}, yu^(-1)]*G[{1/(yu*yv)}, yw]*
      G[{0, yu}, yv^(-1)] - 2*G[{0}, yv^(-1)]*G[{1}, yu^(-1)]*
      G[{1/(yu*yv)}, yw]*G[{0, yu}, yv^(-1)] + 2*G[{0}, yw]*G[{1}, yu^(-1)]*
      G[{1/(yu*yv)}, yw]*G[{0, yu}, yv^(-1)] + G[{1}, yu^(-1)]^2*
      G[{1/(yu*yv)}, yw]*G[{0, yu}, yv^(-1)] - 2*G[{0}, yu^(-1)]*G[{1}, yw]*
      G[{1/(yu*yv)}, yw]*G[{0, yu}, yv^(-1)] - 2*G[{0}, yv^(-1)]*G[{1}, yw]*
      G[{1/(yu*yv)}, yw]*G[{0, yu}, yv^(-1)] + 2*G[{0}, yw]*G[{1}, yw]*
      G[{1/(yu*yv)}, yw]*G[{0, yu}, yv^(-1)] + G[{0}, yu^(-1)]*
      G[{1/(yu*yv)}, yw]^2*G[{0, yu}, yv^(-1)] + 
     G[{0}, yv^(-1)]*G[{1/(yu*yv)}, yw]^2*G[{0, yu}, yv^(-1)] - 
     G[{0}, yw]*G[{1/(yu*yv)}, yw]^2*G[{0, yu}, yv^(-1)] + 
     2*G[{1}, yu^(-1)]*G[{0, 1}, yu^(-1)]*G[{0, yu}, yv^(-1)] - 
     2*G[{1}, yv^(-1)]*G[{0, 1}, yu^(-1)]*G[{0, yu}, yv^(-1)] + 
     2*G[{1}, yv^(-1)]*G[{0, 1}, yv^(-1)]*G[{0, yu}, yv^(-1)] + 
     2*G[{0}, yu^(-1)]*G[{0, 1}, yw]*G[{0, yu}, yv^(-1)] + 
     2*G[{0}, yv^(-1)]*G[{0, 1}, yw]*G[{0, yu}, yv^(-1)] - 
     2*G[{0}, yw]*G[{0, 1}, yw]*G[{0, yu}, yv^(-1)] - 
     2*G[{1}, yu^(-1)]*G[{0, 1}, yw]*G[{0, yu}, yv^(-1)] - 
     2*G[{0}, yu^(-1)]*G[{0, yu^(-1)}, yw]*G[{0, yu}, yv^(-1)] - 
     2*G[{0}, yv^(-1)]*G[{0, yu^(-1)}, yw]*G[{0, yu}, yv^(-1)] + 
     2*G[{0}, yw]*G[{0, yu^(-1)}, yw]*G[{0, yu}, yv^(-1)] + 
     2*G[{1}, yv^(-1)]*G[{0, yu^(-1)}, yw]*G[{0, yu}, yv^(-1)] - 
     2*G[{1}, yw]*G[{0, yu^(-1)}, yw]*G[{0, yu}, yv^(-1)] + 
     2*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1)}, yw]*G[{0, yu}, yv^(-1)] - 
     G[{1}, yv^(-1)]*G[{0, yu}, yv^(-1)]^2 - G[{0}, yu^(-1)]*
      G[{1}, yu^(-1)]^2*G[{0, yv^(-1)}, yw] - G[{0}, yv^(-1)]*
      G[{1}, yu^(-1)]^2*G[{0, yv^(-1)}, yw] + G[{0}, yw]*G[{1}, yu^(-1)]^2*
      G[{0, yv^(-1)}, yw] + G[{1}, yu^(-1)]^3*G[{0, yv^(-1)}, yw] + 
     2*G[{0}, yu^(-1)]*G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*G[{0, yv^(-1)}, yw] + 
     2*G[{0}, yv^(-1)]*G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*G[{0, yv^(-1)}, yw] - 
     2*G[{0}, yw]*G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*G[{0, yv^(-1)}, yw] - 
     G[{1}, yu^(-1)]^2*G[{1}, yv^(-1)]*G[{0, yv^(-1)}, yw] - 
     G[{0}, yu^(-1)]*G[{1}, yv^(-1)]^2*G[{0, yv^(-1)}, yw] - 
     G[{0}, yv^(-1)]*G[{1}, yv^(-1)]^2*G[{0, yv^(-1)}, yw] + 
     G[{0}, yw]*G[{1}, yv^(-1)]^2*G[{0, yv^(-1)}, yw] + 
     G[{1}, yu^(-1)]*G[{1}, yv^(-1)]^2*G[{0, yv^(-1)}, yw] + 
     G[{1}, yv^(-1)]^3*G[{0, yv^(-1)}, yw] - G[{1}, yu^(-1)]^2*G[{1}, yw]*
      G[{0, yv^(-1)}, yw] + 2*G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*G[{1}, yw]*
      G[{0, yv^(-1)}, yw] + G[{1}, yv^(-1)]^2*G[{1}, yw]*
      G[{0, yv^(-1)}, yw] + G[{0}, yu^(-1)]*G[{1}, yw]^2*
      G[{0, yv^(-1)}, yw] + G[{0}, yv^(-1)]*G[{1}, yw]^2*
      G[{0, yv^(-1)}, yw] - G[{0}, yw]*G[{1}, yw]^2*G[{0, yv^(-1)}, yw] - 
     2*G[{1}, yu^(-1)]*G[{1}, yw]^2*G[{0, yv^(-1)}, yw] + 
     G[{1}, yu^(-1)]^2*G[{1/(yu*yv)}, yw]*G[{0, yv^(-1)}, yw] - 
     2*G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*G[{1/(yu*yv)}, yw]*
      G[{0, yv^(-1)}, yw] - G[{1}, yv^(-1)]^2*G[{1/(yu*yv)}, yw]*
      G[{0, yv^(-1)}, yw] - 2*G[{0}, yu^(-1)]*G[{1}, yw]*G[{1/(yu*yv)}, yw]*
      G[{0, yv^(-1)}, yw] - 2*G[{0}, yv^(-1)]*G[{1}, yw]*G[{1/(yu*yv)}, yw]*
      G[{0, yv^(-1)}, yw] + 2*G[{0}, yw]*G[{1}, yw]*G[{1/(yu*yv)}, yw]*
      G[{0, yv^(-1)}, yw] + 4*G[{1}, yu^(-1)]*G[{1}, yw]*G[{1/(yu*yv)}, yw]*
      G[{0, yv^(-1)}, yw] + G[{0}, yu^(-1)]*G[{1/(yu*yv)}, yw]^2*
      G[{0, yv^(-1)}, yw] + G[{0}, yv^(-1)]*G[{1/(yu*yv)}, yw]^2*
      G[{0, yv^(-1)}, yw] - G[{0}, yw]*G[{1/(yu*yv)}, yw]^2*
      G[{0, yv^(-1)}, yw] - 2*G[{1}, yu^(-1)]*G[{1/(yu*yv)}, yw]^2*
      G[{0, yv^(-1)}, yw] + 2*G[{0}, yu^(-1)]*G[{0, 1}, yu^(-1)]*
      G[{0, yv^(-1)}, yw] + 2*G[{0}, yv^(-1)]*G[{0, 1}, yu^(-1)]*
      G[{0, yv^(-1)}, yw] - 2*G[{0}, yw]*G[{0, 1}, yu^(-1)]*
      G[{0, yv^(-1)}, yw] - 2*G[{1}, yu^(-1)]*G[{0, 1}, yu^(-1)]*
      G[{0, yv^(-1)}, yw] - 2*G[{1}, yv^(-1)]*G[{0, 1}, yu^(-1)]*
      G[{0, yv^(-1)}, yw] + 2*G[{1}, yw]*G[{0, 1}, yu^(-1)]*
      G[{0, yv^(-1)}, yw] - 2*G[{1/(yu*yv)}, yw]*G[{0, 1}, yu^(-1)]*
      G[{0, yv^(-1)}, yw] + 2*G[{0}, yu^(-1)]*G[{0, 1}, yv^(-1)]*
      G[{0, yv^(-1)}, yw] + 2*G[{0}, yv^(-1)]*G[{0, 1}, yv^(-1)]*
      G[{0, yv^(-1)}, yw] - 2*G[{0}, yw]*G[{0, 1}, yv^(-1)]*
      G[{0, yv^(-1)}, yw] - 4*G[{1}, yu^(-1)]*G[{0, 1}, yv^(-1)]*
      G[{0, yv^(-1)}, yw] - 2*G[{1}, yv^(-1)]*G[{0, 1}, yv^(-1)]*
      G[{0, yv^(-1)}, yw] - 2*G[{1}, yw]*G[{0, 1}, yv^(-1)]*
      G[{0, yv^(-1)}, yw] + 2*G[{1/(yu*yv)}, yw]*G[{0, 1}, yv^(-1)]*
      G[{0, yv^(-1)}, yw] - 2*G[{0}, yu^(-1)]*G[{0, yu}, yv^(-1)]*
      G[{0, yv^(-1)}, yw] - 2*G[{0}, yv^(-1)]*G[{0, yu}, yv^(-1)]*
      G[{0, yv^(-1)}, yw] + 2*G[{0}, yw]*G[{0, yu}, yv^(-1)]*
      G[{0, yv^(-1)}, yw] + 4*G[{1}, yu^(-1)]*G[{0, yu}, yv^(-1)]*
      G[{0, yv^(-1)}, yw] + 2*G[{1}, yv^(-1)]*G[{0, yu}, yv^(-1)]*
      G[{0, yv^(-1)}, yw] + 2*G[{1}, yw]*G[{0, yu}, yv^(-1)]*
      G[{0, yv^(-1)}, yw] - 2*G[{1/(yu*yv)}, yw]*G[{0, yu}, yv^(-1)]*
      G[{0, yv^(-1)}, yw] + (Pi^2*G[{1}, yu^(-1)]*G[{0, 1/(yu*yv)}, yw])/3 + 
     G[{0}, yu^(-1)]*G[{1}, yu^(-1)]^2*G[{0, 1/(yu*yv)}, yw] + 
     G[{0}, yv^(-1)]*G[{1}, yu^(-1)]^2*G[{0, 1/(yu*yv)}, yw] - 
     G[{0}, yw]*G[{1}, yu^(-1)]^2*G[{0, 1/(yu*yv)}, yw] - 
     G[{1}, yu^(-1)]^3*G[{0, 1/(yu*yv)}, yw] + 
     (Pi^2*G[{1}, yv^(-1)]*G[{0, 1/(yu*yv)}, yw])/3 - 
     2*G[{0}, yu^(-1)]*G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*
      G[{0, 1/(yu*yv)}, yw] - 2*G[{0}, yv^(-1)]*G[{1}, yu^(-1)]*
      G[{1}, yv^(-1)]*G[{0, 1/(yu*yv)}, yw] + 2*G[{0}, yw]*G[{1}, yu^(-1)]*
      G[{1}, yv^(-1)]*G[{0, 1/(yu*yv)}, yw] + 3*G[{1}, yu^(-1)]^2*
      G[{1}, yv^(-1)]*G[{0, 1/(yu*yv)}, yw] + G[{0}, yu^(-1)]*
      G[{1}, yv^(-1)]^2*G[{0, 1/(yu*yv)}, yw] + G[{0}, yv^(-1)]*
      G[{1}, yv^(-1)]^2*G[{0, 1/(yu*yv)}, yw] - G[{0}, yw]*G[{1}, yv^(-1)]^2*
      G[{0, 1/(yu*yv)}, yw] + G[{1}, yu^(-1)]*G[{1}, yv^(-1)]^2*
      G[{0, 1/(yu*yv)}, yw] - G[{1}, yv^(-1)]^3*G[{0, 1/(yu*yv)}, yw] + 
     (Pi^2*G[{1}, yw]*G[{0, 1/(yu*yv)}, yw])/3 + G[{1}, yu^(-1)]^2*G[{1}, yw]*
      G[{0, 1/(yu*yv)}, yw] + 2*G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*G[{1}, yw]*
      G[{0, 1/(yu*yv)}, yw] + G[{1}, yv^(-1)]^2*G[{1}, yw]*
      G[{0, 1/(yu*yv)}, yw] - G[{0}, yu^(-1)]*G[{1}, yw]^2*
      G[{0, 1/(yu*yv)}, yw] - G[{0}, yv^(-1)]*G[{1}, yw]^2*
      G[{0, 1/(yu*yv)}, yw] + G[{0}, yw]*G[{1}, yw]^2*G[{0, 1/(yu*yv)}, yw] + 
     2*G[{1}, yu^(-1)]*G[{1}, yw]^2*G[{0, 1/(yu*yv)}, yw] + 
     2*G[{1}, yv^(-1)]*G[{1}, yw]^2*G[{0, 1/(yu*yv)}, yw] - 
     (2*Pi^2*G[{yu}, yv^(-1)]*G[{0, 1/(yu*yv)}, yw])/3 - 
     2*G[{1}, yu^(-1)]^2*G[{yu}, yv^(-1)]*G[{0, 1/(yu*yv)}, yw] - 
     4*G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*G[{yu}, yv^(-1)]*
      G[{0, 1/(yu*yv)}, yw] - 2*G[{1}, yv^(-1)]^2*G[{yu}, yv^(-1)]*
      G[{0, 1/(yu*yv)}, yw] - 4*G[{1}, yu^(-1)]*G[{1}, yw]*G[{yu}, yv^(-1)]*
      G[{0, 1/(yu*yv)}, yw] - 4*G[{1}, yv^(-1)]*G[{1}, yw]*G[{yu}, yv^(-1)]*
      G[{0, 1/(yu*yv)}, yw] - 2*G[{1}, yw]^2*G[{yu}, yv^(-1)]*
      G[{0, 1/(yu*yv)}, yw] + 4*G[{1}, yu^(-1)]*G[{yu}, yv^(-1)]^2*
      G[{0, 1/(yu*yv)}, yw] + 4*G[{1}, yv^(-1)]*G[{yu}, yv^(-1)]^2*
      G[{0, 1/(yu*yv)}, yw] + 4*G[{1}, yw]*G[{yu}, yv^(-1)]^2*
      G[{0, 1/(yu*yv)}, yw] - (8*G[{yu}, yv^(-1)]^3*G[{0, 1/(yu*yv)}, yw])/
      3 - (Pi^2*G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv)}, yw])/3 - 
     G[{1}, yu^(-1)]^2*G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv)}, yw] - 
     2*G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*G[{1/(yu*yv)}, yw]*
      G[{0, 1/(yu*yv)}, yw] - G[{1}, yv^(-1)]^2*G[{1/(yu*yv)}, yw]*
      G[{0, 1/(yu*yv)}, yw] + 2*G[{0}, yu^(-1)]*G[{1}, yw]*G[{1/(yu*yv)}, yw]*
      G[{0, 1/(yu*yv)}, yw] + 2*G[{0}, yv^(-1)]*G[{1}, yw]*G[{1/(yu*yv)}, yw]*
      G[{0, 1/(yu*yv)}, yw] - 2*G[{0}, yw]*G[{1}, yw]*G[{1/(yu*yv)}, yw]*
      G[{0, 1/(yu*yv)}, yw] - 4*G[{1}, yu^(-1)]*G[{1}, yw]*G[{1/(yu*yv)}, yw]*
      G[{0, 1/(yu*yv)}, yw] - 4*G[{1}, yv^(-1)]*G[{1}, yw]*G[{1/(yu*yv)}, yw]*
      G[{0, 1/(yu*yv)}, yw] + 4*G[{1}, yu^(-1)]*G[{yu}, yv^(-1)]*
      G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv)}, yw] + 4*G[{1}, yv^(-1)]*
      G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv)}, yw] + 
     4*G[{1}, yw]*G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv)}, yw] - 
     4*G[{yu}, yv^(-1)]^2*G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv)}, yw] - 
     G[{0}, yu^(-1)]*G[{1/(yu*yv)}, yw]^2*G[{0, 1/(yu*yv)}, yw] - 
     G[{0}, yv^(-1)]*G[{1/(yu*yv)}, yw]^2*G[{0, 1/(yu*yv)}, yw] + 
     G[{0}, yw]*G[{1/(yu*yv)}, yw]^2*G[{0, 1/(yu*yv)}, yw] + 
     2*G[{1}, yu^(-1)]*G[{1/(yu*yv)}, yw]^2*G[{0, 1/(yu*yv)}, yw] + 
     2*G[{1}, yv^(-1)]*G[{1/(yu*yv)}, yw]^2*G[{0, 1/(yu*yv)}, yw] - 
     2*G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw]^2*G[{0, 1/(yu*yv)}, yw] - 
     2*G[{0}, yu^(-1)]*G[{0, 1}, yu^(-1)]*G[{0, 1/(yu*yv)}, yw] - 
     2*G[{0}, yv^(-1)]*G[{0, 1}, yu^(-1)]*G[{0, 1/(yu*yv)}, yw] + 
     2*G[{0}, yw]*G[{0, 1}, yu^(-1)]*G[{0, 1/(yu*yv)}, yw] + 
     4*G[{1}, yu^(-1)]*G[{0, 1}, yu^(-1)]*G[{0, 1/(yu*yv)}, yw] - 
     2*G[{0}, yu^(-1)]*G[{0, 1}, yv^(-1)]*G[{0, 1/(yu*yv)}, yw] - 
     2*G[{0}, yv^(-1)]*G[{0, 1}, yv^(-1)]*G[{0, 1/(yu*yv)}, yw] + 
     2*G[{0}, yw]*G[{0, 1}, yv^(-1)]*G[{0, 1/(yu*yv)}, yw] + 
     2*G[{1}, yu^(-1)]*G[{0, 1}, yv^(-1)]*G[{0, 1/(yu*yv)}, yw] + 
     4*G[{1}, yv^(-1)]*G[{0, 1}, yv^(-1)]*G[{0, 1/(yu*yv)}, yw] - 
     2*G[{1}, yu^(-1)]*G[{0, 1}, yw]*G[{0, 1/(yu*yv)}, yw] - 
     2*G[{1}, yv^(-1)]*G[{0, 1}, yw]*G[{0, 1/(yu*yv)}, yw] - 
     2*G[{1}, yw]*G[{0, 1}, yw]*G[{0, 1/(yu*yv)}, yw] + 
     4*G[{yu}, yv^(-1)]*G[{0, 1}, yw]*G[{0, 1/(yu*yv)}, yw] + 
     2*G[{1/(yu*yv)}, yw]*G[{0, 1}, yw]*G[{0, 1/(yu*yv)}, yw] + 
     2*G[{1}, yu^(-1)]*G[{0, yu^(-1)}, yw]*G[{0, 1/(yu*yv)}, yw] + 
     2*G[{1}, yv^(-1)]*G[{0, yu^(-1)}, yw]*G[{0, 1/(yu*yv)}, yw] + 
     2*G[{1}, yw]*G[{0, yu^(-1)}, yw]*G[{0, 1/(yu*yv)}, yw] - 
     4*G[{yu}, yv^(-1)]*G[{0, yu^(-1)}, yw]*G[{0, 1/(yu*yv)}, yw] - 
     2*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1)}, yw]*G[{0, 1/(yu*yv)}, yw] + 
     2*G[{0}, yu^(-1)]*G[{0, yu}, yv^(-1)]*G[{0, 1/(yu*yv)}, yw] + 
     2*G[{0}, yv^(-1)]*G[{0, yu}, yv^(-1)]*G[{0, 1/(yu*yv)}, yw] - 
     2*G[{0}, yw]*G[{0, yu}, yv^(-1)]*G[{0, 1/(yu*yv)}, yw] - 
     2*G[{1}, yu^(-1)]*G[{0, yu}, yv^(-1)]*G[{0, 1/(yu*yv)}, yw] - 
     4*G[{1}, yv^(-1)]*G[{0, yu}, yv^(-1)]*G[{0, 1/(yu*yv)}, yw] + 
     2*G[{1}, yu^(-1)]*G[{0, yv^(-1)}, yw]*G[{0, 1/(yu*yv)}, yw] + 
     2*G[{1}, yv^(-1)]*G[{0, yv^(-1)}, yw]*G[{0, 1/(yu*yv)}, yw] + 
     2*G[{1}, yw]*G[{0, yv^(-1)}, yw]*G[{0, 1/(yu*yv)}, yw] - 
     4*G[{yu}, yv^(-1)]*G[{0, yv^(-1)}, yw]*G[{0, 1/(yu*yv)}, yw] - 
     2*G[{1/(yu*yv)}, yw]*G[{0, yv^(-1)}, yw]*G[{0, 1/(yu*yv)}, yw] - 
     G[{1}, yu^(-1)]*G[{0, 1/(yu*yv)}, yw]^2 - G[{1}, yv^(-1)]*
      G[{0, 1/(yu*yv)}, yw]^2 - G[{1}, yw]*G[{0, 1/(yu*yv)}, yw]^2 + 
     2*G[{yu}, yv^(-1)]*G[{0, 1/(yu*yv)}, yw]^2 + G[{1/(yu*yv)}, yw]*
      G[{0, 1/(yu*yv)}, yw]^2 + 4*G[{1}, yu^(-1)]*G[{0, yu^(-1)}, yw]*
      G[{1, yu}, yv^(-1)] + 4*G[{1}, yv^(-1)]*G[{0, yu^(-1)}, yw]*
      G[{1, yu}, yv^(-1)] + 4*G[{1}, yw]*G[{0, yu^(-1)}, yw]*
      G[{1, yu}, yv^(-1)] - 4*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1)}, yw]*
      G[{1, yu}, yv^(-1)] - 4*G[{1}, yu^(-1)]*G[{0, yv^(-1)}, yw]*
      G[{1, yu}, yv^(-1)] - 4*G[{1}, yv^(-1)]*G[{0, yv^(-1)}, yw]*
      G[{1, yu}, yv^(-1)] - 4*G[{1}, yw]*G[{0, yv^(-1)}, yw]*
      G[{1, yu}, yv^(-1)] + 4*G[{1/(yu*yv)}, yw]*G[{0, yv^(-1)}, yw]*
      G[{1, yu}, yv^(-1)] + (Pi^2*G[{0, 0, 1}, yu^(-1)])/3 - 
     2*G[{0}, yu^(-1)]*G[{1}, yu^(-1)]*G[{0, 0, 1}, yu^(-1)] - 
     2*G[{0}, yv^(-1)]*G[{1}, yu^(-1)]*G[{0, 0, 1}, yu^(-1)] + 
     2*G[{0}, yw]*G[{1}, yu^(-1)]*G[{0, 0, 1}, yu^(-1)] + 
     2*G[{0}, yu^(-1)]*G[{1}, yv^(-1)]*G[{0, 0, 1}, yu^(-1)] + 
     2*G[{0}, yv^(-1)]*G[{1}, yv^(-1)]*G[{0, 0, 1}, yu^(-1)] - 
     2*G[{0}, yw]*G[{1}, yv^(-1)]*G[{0, 0, 1}, yu^(-1)] + 
     2*G[{0}, yu^(-1)]*G[{1}, yw]*G[{0, 0, 1}, yu^(-1)] + 
     2*G[{0}, yv^(-1)]*G[{1}, yw]*G[{0, 0, 1}, yu^(-1)] - 
     2*G[{0}, yw]*G[{1}, yw]*G[{0, 0, 1}, yu^(-1)] - 
     2*G[{0}, yu^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, 0, 1}, yu^(-1)] - 
     2*G[{0}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, 0, 1}, yu^(-1)] + 
     2*G[{0}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 0, 1}, yu^(-1)] + 
     2*G[{0, 1}, yu^(-1)]*G[{0, 0, 1}, yu^(-1)] - 2*G[{0, 1}, yv^(-1)]*
      G[{0, 0, 1}, yu^(-1)] + 2*G[{0, 1}, yw]*G[{0, 0, 1}, yu^(-1)] + 
     2*G[{0, yu^(-1)}, yw]*G[{0, 0, 1}, yu^(-1)] - 2*G[{0, yu}, yv^(-1)]*
      G[{0, 0, 1}, yu^(-1)] - 2*G[{0, yv^(-1)}, yw]*G[{0, 0, 1}, yu^(-1)] - 
     2*G[{0, 1/(yu*yv)}, yw]*G[{0, 0, 1}, yu^(-1)] + 
     (Pi^2*G[{0, 0, 1}, yv^(-1)])/3 + 2*G[{0}, yu^(-1)]*G[{1}, yu^(-1)]*
      G[{0, 0, 1}, yv^(-1)] + 2*G[{0}, yv^(-1)]*G[{1}, yu^(-1)]*
      G[{0, 0, 1}, yv^(-1)] - 2*G[{0}, yw]*G[{1}, yu^(-1)]*
      G[{0, 0, 1}, yv^(-1)] - 2*G[{0}, yu^(-1)]*G[{1}, yv^(-1)]*
      G[{0, 0, 1}, yv^(-1)] - 2*G[{0}, yv^(-1)]*G[{1}, yv^(-1)]*
      G[{0, 0, 1}, yv^(-1)] + 2*G[{0}, yw]*G[{1}, yv^(-1)]*
      G[{0, 0, 1}, yv^(-1)] + 2*G[{0}, yu^(-1)]*G[{1}, yw]*
      G[{0, 0, 1}, yv^(-1)] + 2*G[{0}, yv^(-1)]*G[{1}, yw]*
      G[{0, 0, 1}, yv^(-1)] - 2*G[{0}, yw]*G[{1}, yw]*G[{0, 0, 1}, yv^(-1)] - 
     2*G[{0}, yu^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, 0, 1}, yv^(-1)] - 
     2*G[{0}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, 0, 1}, yv^(-1)] + 
     2*G[{0}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 0, 1}, yv^(-1)] - 
     2*G[{0, 1}, yu^(-1)]*G[{0, 0, 1}, yv^(-1)] + 2*G[{0, 1}, yv^(-1)]*
      G[{0, 0, 1}, yv^(-1)] + 2*G[{0, 1}, yw]*G[{0, 0, 1}, yv^(-1)] - 
     2*G[{0, yu^(-1)}, yw]*G[{0, 0, 1}, yv^(-1)] - 2*G[{0, yu}, yv^(-1)]*
      G[{0, 0, 1}, yv^(-1)] + 2*G[{0, yv^(-1)}, yw]*G[{0, 0, 1}, yv^(-1)] - 
     2*G[{0, 1/(yu*yv)}, yw]*G[{0, 0, 1}, yv^(-1)] + 
     2*G[{1}, yu^(-1)]^2*G[{0, 0, 1}, yw] - 4*G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*
      G[{0, 0, 1}, yw] + 2*G[{1}, yv^(-1)]^2*G[{0, 0, 1}, yw] - 
     2*G[{1}, yw]^2*G[{0, 0, 1}, yw] + 4*G[{1}, yw]*G[{1/(yu*yv)}, yw]*
      G[{0, 0, 1}, yw] - 2*G[{1/(yu*yv)}, yw]^2*G[{0, 0, 1}, yw] - 
     4*G[{0, 1}, yu^(-1)]*G[{0, 0, 1}, yw] - 4*G[{0, 1}, yv^(-1)]*
      G[{0, 0, 1}, yw] + 4*G[{0, yu}, yv^(-1)]*G[{0, 0, 1}, yw] - 
     2*G[{1}, yu^(-1)]^2*G[{0, 0, yu^(-1)}, yw] + 
     4*G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*G[{0, 0, yu^(-1)}, yw] - 
     2*G[{1}, yv^(-1)]^2*G[{0, 0, yu^(-1)}, yw] + 
     2*G[{1}, yw]^2*G[{0, 0, yu^(-1)}, yw] - 4*G[{1}, yw]*G[{1/(yu*yv)}, yw]*
      G[{0, 0, yu^(-1)}, yw] + 2*G[{1/(yu*yv)}, yw]^2*
      G[{0, 0, yu^(-1)}, yw] + 4*G[{0, 1}, yu^(-1)]*G[{0, 0, yu^(-1)}, yw] + 
     4*G[{0, 1}, yv^(-1)]*G[{0, 0, yu^(-1)}, yw] - 4*G[{0, yu}, yv^(-1)]*
      G[{0, 0, yu^(-1)}, yw] - (Pi^2*G[{0, 0, yu}, yv^(-1)])/3 - 
     2*G[{0}, yu^(-1)]*G[{1}, yu^(-1)]*G[{0, 0, yu}, yv^(-1)] - 
     2*G[{0}, yv^(-1)]*G[{1}, yu^(-1)]*G[{0, 0, yu}, yv^(-1)] + 
     2*G[{0}, yw]*G[{1}, yu^(-1)]*G[{0, 0, yu}, yv^(-1)] + 
     2*G[{0}, yu^(-1)]*G[{1}, yv^(-1)]*G[{0, 0, yu}, yv^(-1)] + 
     2*G[{0}, yv^(-1)]*G[{1}, yv^(-1)]*G[{0, 0, yu}, yv^(-1)] - 
     2*G[{0}, yw]*G[{1}, yv^(-1)]*G[{0, 0, yu}, yv^(-1)] - 
     2*G[{0}, yu^(-1)]*G[{1}, yw]*G[{0, 0, yu}, yv^(-1)] - 
     2*G[{0}, yv^(-1)]*G[{1}, yw]*G[{0, 0, yu}, yv^(-1)] + 
     2*G[{0}, yw]*G[{1}, yw]*G[{0, 0, yu}, yv^(-1)] + 
     2*G[{0}, yu^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, 0, yu}, yv^(-1)] + 
     2*G[{0}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, 0, yu}, yv^(-1)] - 
     2*G[{0}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 0, yu}, yv^(-1)] + 
     2*G[{0, 1}, yu^(-1)]*G[{0, 0, yu}, yv^(-1)] - 2*G[{0, 1}, yv^(-1)]*
      G[{0, 0, yu}, yv^(-1)] - 2*G[{0, 1}, yw]*G[{0, 0, yu}, yv^(-1)] + 
     2*G[{0, yu^(-1)}, yw]*G[{0, 0, yu}, yv^(-1)] + 
     2*G[{0, yu}, yv^(-1)]*G[{0, 0, yu}, yv^(-1)] - 
     2*G[{0, yv^(-1)}, yw]*G[{0, 0, yu}, yv^(-1)] + 
     2*G[{0, 1/(yu*yv)}, yw]*G[{0, 0, yu}, yv^(-1)] - 
     2*G[{1}, yu^(-1)]^2*G[{0, 0, yv^(-1)}, yw] + 
     4*G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*G[{0, 0, yv^(-1)}, yw] - 
     2*G[{1}, yv^(-1)]^2*G[{0, 0, yv^(-1)}, yw] + 
     2*G[{1}, yw]^2*G[{0, 0, yv^(-1)}, yw] - 4*G[{1}, yw]*G[{1/(yu*yv)}, yw]*
      G[{0, 0, yv^(-1)}, yw] + 2*G[{1/(yu*yv)}, yw]^2*
      G[{0, 0, yv^(-1)}, yw] + 4*G[{0, 1}, yu^(-1)]*G[{0, 0, yv^(-1)}, yw] + 
     4*G[{0, 1}, yv^(-1)]*G[{0, 0, yv^(-1)}, yw] - 4*G[{0, yu}, yv^(-1)]*
      G[{0, 0, yv^(-1)}, yw] + 2*G[{1}, yu^(-1)]^2*G[{0, 0, 1/(yu*yv)}, yw] - 
     4*G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*G[{0, 0, 1/(yu*yv)}, yw] + 
     2*G[{1}, yv^(-1)]^2*G[{0, 0, 1/(yu*yv)}, yw] - 
     2*G[{1}, yw]^2*G[{0, 0, 1/(yu*yv)}, yw] + 
     4*G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 0, 1/(yu*yv)}, yw] - 
     2*G[{1/(yu*yv)}, yw]^2*G[{0, 0, 1/(yu*yv)}, yw] - 
     4*G[{0, 1}, yu^(-1)]*G[{0, 0, 1/(yu*yv)}, yw] - 
     4*G[{0, 1}, yv^(-1)]*G[{0, 0, 1/(yu*yv)}, yw] + 
     4*G[{0, yu}, yv^(-1)]*G[{0, 0, 1/(yu*yv)}, yw] + 
     (2*Pi^2*G[{0, 1, 1}, yu^(-1)])/3 - 2*G[{0}, yu^(-1)]*G[{1}, yu^(-1)]*
      G[{0, 1, 1}, yu^(-1)] - 2*G[{0}, yv^(-1)]*G[{1}, yu^(-1)]*
      G[{0, 1, 1}, yu^(-1)] + 2*G[{0}, yw]*G[{1}, yu^(-1)]*
      G[{0, 1, 1}, yu^(-1)] - 2*G[{1}, yu^(-1)]^2*G[{0, 1, 1}, yu^(-1)] + 
     2*G[{0}, yu^(-1)]*G[{1}, yv^(-1)]*G[{0, 1, 1}, yu^(-1)] + 
     2*G[{0}, yv^(-1)]*G[{1}, yv^(-1)]*G[{0, 1, 1}, yu^(-1)] - 
     2*G[{0}, yw]*G[{1}, yv^(-1)]*G[{0, 1, 1}, yu^(-1)] + 
     4*G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*G[{0, 1, 1}, yu^(-1)] - 
     2*G[{1}, yv^(-1)]^2*G[{0, 1, 1}, yu^(-1)] - 2*G[{0}, yu^(-1)]*G[{1}, yw]*
      G[{0, 1, 1}, yu^(-1)] - 2*G[{0}, yv^(-1)]*G[{1}, yw]*
      G[{0, 1, 1}, yu^(-1)] + 2*G[{0}, yw]*G[{1}, yw]*G[{0, 1, 1}, yu^(-1)] + 
     2*G[{1}, yw]^2*G[{0, 1, 1}, yu^(-1)] + 2*G[{0}, yu^(-1)]*
      G[{1/(yu*yv)}, yw]*G[{0, 1, 1}, yu^(-1)] + 2*G[{0}, yv^(-1)]*
      G[{1/(yu*yv)}, yw]*G[{0, 1, 1}, yu^(-1)] - 
     2*G[{0}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1, 1}, yu^(-1)] - 
     4*G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1, 1}, yu^(-1)] + 
     2*G[{1/(yu*yv)}, yw]^2*G[{0, 1, 1}, yu^(-1)] + 
     2*G[{0, 1}, yv^(-1)]*G[{0, 1, 1}, yu^(-1)] + 
     2*G[{0, 1}, yw]*G[{0, 1, 1}, yu^(-1)] - 2*G[{0, yu^(-1)}, yw]*
      G[{0, 1, 1}, yu^(-1)] - 2*G[{0, yu}, yv^(-1)]*G[{0, 1, 1}, yu^(-1)] + 
     2*G[{0, yv^(-1)}, yw]*G[{0, 1, 1}, yu^(-1)] - 2*G[{0, 1/(yu*yv)}, yw]*
      G[{0, 1, 1}, yu^(-1)] + (2*Pi^2*G[{0, 1, 1}, yv^(-1)])/3 - 
     2*G[{0}, yu^(-1)]*G[{1}, yu^(-1)]*G[{0, 1, 1}, yv^(-1)] - 
     2*G[{0}, yv^(-1)]*G[{1}, yu^(-1)]*G[{0, 1, 1}, yv^(-1)] + 
     2*G[{0}, yw]*G[{1}, yu^(-1)]*G[{0, 1, 1}, yv^(-1)] + 
     4*G[{1}, yu^(-1)]^2*G[{0, 1, 1}, yv^(-1)] - 2*G[{0}, yu^(-1)]*
      G[{1}, yv^(-1)]*G[{0, 1, 1}, yv^(-1)] - 2*G[{0}, yv^(-1)]*
      G[{1}, yv^(-1)]*G[{0, 1, 1}, yv^(-1)] + 2*G[{0}, yw]*G[{1}, yv^(-1)]*
      G[{0, 1, 1}, yv^(-1)] + 2*G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*
      G[{0, 1, 1}, yv^(-1)] - 2*G[{1}, yv^(-1)]^2*G[{0, 1, 1}, yv^(-1)] - 
     2*G[{0}, yu^(-1)]*G[{1}, yw]*G[{0, 1, 1}, yv^(-1)] - 
     2*G[{0}, yv^(-1)]*G[{1}, yw]*G[{0, 1, 1}, yv^(-1)] + 
     2*G[{0}, yw]*G[{1}, yw]*G[{0, 1, 1}, yv^(-1)] + 
     6*G[{1}, yu^(-1)]*G[{1}, yw]*G[{0, 1, 1}, yv^(-1)] + 
     2*G[{1}, yw]^2*G[{0, 1, 1}, yv^(-1)] + 2*G[{0}, yu^(-1)]*
      G[{1/(yu*yv)}, yw]*G[{0, 1, 1}, yv^(-1)] + 2*G[{0}, yv^(-1)]*
      G[{1/(yu*yv)}, yw]*G[{0, 1, 1}, yv^(-1)] - 
     2*G[{0}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1, 1}, yv^(-1)] - 
     6*G[{1}, yu^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, 1, 1}, yv^(-1)] - 
     4*G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1, 1}, yv^(-1)] + 
     2*G[{1/(yu*yv)}, yw]^2*G[{0, 1, 1}, yv^(-1)] + 
     2*G[{0, 1}, yw]*G[{0, 1, 1}, yv^(-1)] + 2*G[{0, yu^(-1)}, yw]*
      G[{0, 1, 1}, yv^(-1)] - 2*G[{0, yu}, yv^(-1)]*G[{0, 1, 1}, yv^(-1)] - 
     2*G[{0, yv^(-1)}, yw]*G[{0, 1, 1}, yv^(-1)] - 2*G[{0, 1/(yu*yv)}, yw]*
      G[{0, 1, 1}, yv^(-1)] - (Pi^2*G[{0, 1, 1}, yw])/3 + 
     4*G[{0}, yu^(-1)]*G[{1}, yu^(-1)]*G[{0, 1, 1}, yw] + 
     4*G[{0}, yv^(-1)]*G[{1}, yu^(-1)]*G[{0, 1, 1}, yw] - 
     4*G[{0}, yw]*G[{1}, yu^(-1)]*G[{0, 1, 1}, yw] - 
     4*G[{1}, yu^(-1)]^2*G[{0, 1, 1}, yw] + 4*G[{0}, yu^(-1)]*G[{1}, yv^(-1)]*
      G[{0, 1, 1}, yw] + 4*G[{0}, yv^(-1)]*G[{1}, yv^(-1)]*G[{0, 1, 1}, yw] - 
     4*G[{0}, yw]*G[{1}, yv^(-1)]*G[{0, 1, 1}, yw] - 
     12*G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*G[{0, 1, 1}, yw] - 
     4*G[{1}, yv^(-1)]^2*G[{0, 1, 1}, yw] + 4*G[{0}, yu^(-1)]*G[{1}, yw]*
      G[{0, 1, 1}, yw] + 4*G[{0}, yv^(-1)]*G[{1}, yw]*G[{0, 1, 1}, yw] - 
     4*G[{0}, yw]*G[{1}, yw]*G[{0, 1, 1}, yw] - 6*G[{1}, yu^(-1)]*G[{1}, yw]*
      G[{0, 1, 1}, yw] - 6*G[{1}, yv^(-1)]*G[{1}, yw]*G[{0, 1, 1}, yw] - 
     2*G[{1}, yw]^2*G[{0, 1, 1}, yw] - 8*G[{0}, yu^(-1)]*G[{yu}, yv^(-1)]*
      G[{0, 1, 1}, yw] - 8*G[{0}, yv^(-1)]*G[{yu}, yv^(-1)]*
      G[{0, 1, 1}, yw] + 8*G[{0}, yw]*G[{yu}, yv^(-1)]*G[{0, 1, 1}, yw] + 
     12*G[{1}, yu^(-1)]*G[{yu}, yv^(-1)]*G[{0, 1, 1}, yw] + 
     12*G[{1}, yv^(-1)]*G[{yu}, yv^(-1)]*G[{0, 1, 1}, yw] + 
     4*G[{1}, yw]*G[{yu}, yv^(-1)]*G[{0, 1, 1}, yw] - 
     4*G[{yu}, yv^(-1)]^2*G[{0, 1, 1}, yw] - 4*G[{0}, yu^(-1)]*
      G[{1/(yu*yv)}, yw]*G[{0, 1, 1}, yw] - 4*G[{0}, yv^(-1)]*
      G[{1/(yu*yv)}, yw]*G[{0, 1, 1}, yw] + 4*G[{0}, yw]*G[{1/(yu*yv)}, yw]*
      G[{0, 1, 1}, yw] + 6*G[{1}, yu^(-1)]*G[{1/(yu*yv)}, yw]*
      G[{0, 1, 1}, yw] + 6*G[{1}, yv^(-1)]*G[{1/(yu*yv)}, yw]*
      G[{0, 1, 1}, yw] + 4*G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1, 1}, yw] - 
     4*G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, 1, 1}, yw] - 
     2*G[{1/(yu*yv)}, yw]^2*G[{0, 1, 1}, yw] - 2*G[{0, 1}, yu^(-1)]*
      G[{0, 1, 1}, yw] - 2*G[{0, 1}, yv^(-1)]*G[{0, 1, 1}, yw] + 
     2*G[{0, 1}, yw]*G[{0, 1, 1}, yw] + 2*G[{0, yu}, yv^(-1)]*
      G[{0, 1, 1}, yw] + (Pi^2*G[{0, 1, yu^(-1)}, yw])/3 - 
     2*G[{0}, yu^(-1)]*G[{1}, yu^(-1)]*G[{0, 1, yu^(-1)}, yw] - 
     2*G[{0}, yv^(-1)]*G[{1}, yu^(-1)]*G[{0, 1, yu^(-1)}, yw] + 
     2*G[{0}, yw]*G[{1}, yu^(-1)]*G[{0, 1, yu^(-1)}, yw] + 
     4*G[{1}, yu^(-1)]^2*G[{0, 1, yu^(-1)}, yw] - 
     2*G[{0}, yu^(-1)]*G[{1}, yv^(-1)]*G[{0, 1, yu^(-1)}, yw] - 
     2*G[{0}, yv^(-1)]*G[{1}, yv^(-1)]*G[{0, 1, yu^(-1)}, yw] + 
     2*G[{0}, yw]*G[{1}, yv^(-1)]*G[{0, 1, yu^(-1)}, yw] + 
     4*G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*G[{0, 1, yu^(-1)}, yw] + 
     4*G[{1}, yv^(-1)]^2*G[{0, 1, yu^(-1)}, yw] - 
     2*G[{0}, yu^(-1)]*G[{1}, yw]*G[{0, 1, yu^(-1)}, yw] - 
     2*G[{0}, yv^(-1)]*G[{1}, yw]*G[{0, 1, yu^(-1)}, yw] + 
     2*G[{0}, yw]*G[{1}, yw]*G[{0, 1, yu^(-1)}, yw] + 
     4*G[{1}, yu^(-1)]*G[{1}, yw]*G[{0, 1, yu^(-1)}, yw] + 
     4*G[{1}, yv^(-1)]*G[{1}, yw]*G[{0, 1, yu^(-1)}, yw] + 
     4*G[{0}, yu^(-1)]*G[{yu}, yv^(-1)]*G[{0, 1, yu^(-1)}, yw] + 
     4*G[{0}, yv^(-1)]*G[{yu}, yv^(-1)]*G[{0, 1, yu^(-1)}, yw] - 
     4*G[{0}, yw]*G[{yu}, yv^(-1)]*G[{0, 1, yu^(-1)}, yw] - 
     8*G[{1}, yu^(-1)]*G[{yu}, yv^(-1)]*G[{0, 1, yu^(-1)}, yw] - 
     8*G[{1}, yv^(-1)]*G[{yu}, yv^(-1)]*G[{0, 1, yu^(-1)}, yw] - 
     4*G[{1}, yw]*G[{yu}, yv^(-1)]*G[{0, 1, yu^(-1)}, yw] + 
     4*G[{yu}, yv^(-1)]^2*G[{0, 1, yu^(-1)}, yw] + 
     2*G[{0}, yu^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, 1, yu^(-1)}, yw] + 
     2*G[{0}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, 1, yu^(-1)}, yw] - 
     2*G[{0}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1, yu^(-1)}, yw] - 
     4*G[{1}, yu^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, 1, yu^(-1)}, yw] - 
     4*G[{1}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, 1, yu^(-1)}, yw] + 
     4*G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, 1, yu^(-1)}, yw] - 
     2*G[{0, 1}, yu^(-1)]*G[{0, 1, yu^(-1)}, yw] - 2*G[{0, 1}, yv^(-1)]*
      G[{0, 1, yu^(-1)}, yw] - 2*G[{0, 1}, yw]*G[{0, 1, yu^(-1)}, yw] + 
     2*G[{0, yu}, yv^(-1)]*G[{0, 1, yu^(-1)}, yw] + 
     4*G[{0}, yu^(-1)]*G[{1}, yu^(-1)]*G[{0, 1, yu}, yv^(-1)] + 
     4*G[{0}, yv^(-1)]*G[{1}, yu^(-1)]*G[{0, 1, yu}, yv^(-1)] - 
     4*G[{0}, yw]*G[{1}, yu^(-1)]*G[{0, 1, yu}, yv^(-1)] - 
     4*G[{1}, yu^(-1)]^2*G[{0, 1, yu}, yv^(-1)] + 
     4*G[{0}, yu^(-1)]*G[{1}, yw]*G[{0, 1, yu}, yv^(-1)] + 
     4*G[{0}, yv^(-1)]*G[{1}, yw]*G[{0, 1, yu}, yv^(-1)] - 
     4*G[{0}, yw]*G[{1}, yw]*G[{0, 1, yu}, yv^(-1)] - 
     4*G[{1}, yu^(-1)]*G[{1}, yw]*G[{0, 1, yu}, yv^(-1)] - 
     4*G[{0}, yu^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, 1, yu}, yv^(-1)] - 
     4*G[{0}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, 1, yu}, yv^(-1)] + 
     4*G[{0}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1, yu}, yv^(-1)] + 
     4*G[{1}, yu^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, 1, yu}, yv^(-1)] - 
     4*G[{0, yu^(-1)}, yw]*G[{0, 1, yu}, yv^(-1)] + 
     4*G[{0, yv^(-1)}, yw]*G[{0, 1, yu}, yv^(-1)] + 
     (Pi^2*G[{0, 1, yv^(-1)}, yw])/3 - 2*G[{0}, yu^(-1)]*G[{1}, yu^(-1)]*
      G[{0, 1, yv^(-1)}, yw] - 2*G[{0}, yv^(-1)]*G[{1}, yu^(-1)]*
      G[{0, 1, yv^(-1)}, yw] + 2*G[{0}, yw]*G[{1}, yu^(-1)]*
      G[{0, 1, yv^(-1)}, yw] + 4*G[{1}, yu^(-1)]^2*G[{0, 1, yv^(-1)}, yw] - 
     2*G[{0}, yu^(-1)]*G[{1}, yv^(-1)]*G[{0, 1, yv^(-1)}, yw] - 
     2*G[{0}, yv^(-1)]*G[{1}, yv^(-1)]*G[{0, 1, yv^(-1)}, yw] + 
     2*G[{0}, yw]*G[{1}, yv^(-1)]*G[{0, 1, yv^(-1)}, yw] + 
     4*G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*G[{0, 1, yv^(-1)}, yw] + 
     4*G[{1}, yv^(-1)]^2*G[{0, 1, yv^(-1)}, yw] - 
     2*G[{0}, yu^(-1)]*G[{1}, yw]*G[{0, 1, yv^(-1)}, yw] - 
     2*G[{0}, yv^(-1)]*G[{1}, yw]*G[{0, 1, yv^(-1)}, yw] + 
     2*G[{0}, yw]*G[{1}, yw]*G[{0, 1, yv^(-1)}, yw] + 
     4*G[{1}, yu^(-1)]*G[{1}, yw]*G[{0, 1, yv^(-1)}, yw] + 
     4*G[{1}, yv^(-1)]*G[{1}, yw]*G[{0, 1, yv^(-1)}, yw] + 
     4*G[{0}, yu^(-1)]*G[{yu}, yv^(-1)]*G[{0, 1, yv^(-1)}, yw] + 
     4*G[{0}, yv^(-1)]*G[{yu}, yv^(-1)]*G[{0, 1, yv^(-1)}, yw] - 
     4*G[{0}, yw]*G[{yu}, yv^(-1)]*G[{0, 1, yv^(-1)}, yw] - 
     8*G[{1}, yu^(-1)]*G[{yu}, yv^(-1)]*G[{0, 1, yv^(-1)}, yw] - 
     8*G[{1}, yv^(-1)]*G[{yu}, yv^(-1)]*G[{0, 1, yv^(-1)}, yw] - 
     4*G[{1}, yw]*G[{yu}, yv^(-1)]*G[{0, 1, yv^(-1)}, yw] + 
     4*G[{yu}, yv^(-1)]^2*G[{0, 1, yv^(-1)}, yw] + 
     2*G[{0}, yu^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, 1, yv^(-1)}, yw] + 
     2*G[{0}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, 1, yv^(-1)}, yw] - 
     2*G[{0}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1, yv^(-1)}, yw] - 
     4*G[{1}, yu^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, 1, yv^(-1)}, yw] - 
     4*G[{1}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, 1, yv^(-1)}, yw] + 
     4*G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, 1, yv^(-1)}, yw] - 
     2*G[{0, 1}, yu^(-1)]*G[{0, 1, yv^(-1)}, yw] - 2*G[{0, 1}, yv^(-1)]*
      G[{0, 1, yv^(-1)}, yw] - 2*G[{0, 1}, yw]*G[{0, 1, yv^(-1)}, yw] + 
     2*G[{0, yu}, yv^(-1)]*G[{0, 1, yv^(-1)}, yw] - 
     (Pi^2*G[{0, 1, 1/(yu*yv)}, yw])/3 - 2*G[{1}, yu^(-1)]^2*
      G[{0, 1, 1/(yu*yv)}, yw] - 2*G[{1}, yv^(-1)]^2*
      G[{0, 1, 1/(yu*yv)}, yw] - 2*G[{1}, yu^(-1)]*G[{1}, yw]*
      G[{0, 1, 1/(yu*yv)}, yw] - 2*G[{1}, yv^(-1)]*G[{1}, yw]*
      G[{0, 1, 1/(yu*yv)}, yw] + 4*G[{1}, yu^(-1)]*G[{yu}, yv^(-1)]*
      G[{0, 1, 1/(yu*yv)}, yw] + 4*G[{1}, yv^(-1)]*G[{yu}, yv^(-1)]*
      G[{0, 1, 1/(yu*yv)}, yw] + 4*G[{1}, yw]*G[{yu}, yv^(-1)]*
      G[{0, 1, 1/(yu*yv)}, yw] - 4*G[{yu}, yv^(-1)]^2*
      G[{0, 1, 1/(yu*yv)}, yw] + 2*G[{1}, yu^(-1)]*G[{1/(yu*yv)}, yw]*
      G[{0, 1, 1/(yu*yv)}, yw] + 2*G[{1}, yv^(-1)]*G[{1/(yu*yv)}, yw]*
      G[{0, 1, 1/(yu*yv)}, yw] - 4*G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw]*
      G[{0, 1, 1/(yu*yv)}, yw] + 2*G[{0, 1}, yu^(-1)]*
      G[{0, 1, 1/(yu*yv)}, yw] + 2*G[{0, 1}, yv^(-1)]*
      G[{0, 1, 1/(yu*yv)}, yw] + 2*G[{0, 1}, yw]*G[{0, 1, 1/(yu*yv)}, yw] - 
     2*G[{0, yu}, yv^(-1)]*G[{0, 1, 1/(yu*yv)}, yw] - 
     2*G[{0}, yu^(-1)]*G[{1}, yu^(-1)]*G[{0, yu^(-1), 1}, yw] - 
     2*G[{0}, yv^(-1)]*G[{1}, yu^(-1)]*G[{0, yu^(-1), 1}, yw] + 
     2*G[{0}, yw]*G[{1}, yu^(-1)]*G[{0, yu^(-1), 1}, yw] + 
     2*G[{1}, yu^(-1)]^2*G[{0, yu^(-1), 1}, yw] - 
     2*G[{0}, yu^(-1)]*G[{1}, yv^(-1)]*G[{0, yu^(-1), 1}, yw] - 
     2*G[{0}, yv^(-1)]*G[{1}, yv^(-1)]*G[{0, yu^(-1), 1}, yw] + 
     2*G[{0}, yw]*G[{1}, yv^(-1)]*G[{0, yu^(-1), 1}, yw] + 
     4*G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*G[{0, yu^(-1), 1}, yw] + 
     2*G[{1}, yv^(-1)]^2*G[{0, yu^(-1), 1}, yw] - 
     2*G[{0}, yu^(-1)]*G[{1}, yw]*G[{0, yu^(-1), 1}, yw] - 
     2*G[{0}, yv^(-1)]*G[{1}, yw]*G[{0, yu^(-1), 1}, yw] + 
     2*G[{0}, yw]*G[{1}, yw]*G[{0, yu^(-1), 1}, yw] + 
     2*G[{1}, yu^(-1)]*G[{1}, yw]*G[{0, yu^(-1), 1}, yw] + 
     2*G[{1}, yv^(-1)]*G[{1}, yw]*G[{0, yu^(-1), 1}, yw] + 
     4*G[{0}, yu^(-1)]*G[{yu}, yv^(-1)]*G[{0, yu^(-1), 1}, yw] + 
     4*G[{0}, yv^(-1)]*G[{yu}, yv^(-1)]*G[{0, yu^(-1), 1}, yw] - 
     4*G[{0}, yw]*G[{yu}, yv^(-1)]*G[{0, yu^(-1), 1}, yw] - 
     4*G[{1}, yu^(-1)]*G[{yu}, yv^(-1)]*G[{0, yu^(-1), 1}, yw] - 
     4*G[{1}, yv^(-1)]*G[{yu}, yv^(-1)]*G[{0, yu^(-1), 1}, yw] + 
     2*G[{0}, yu^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1), 1}, yw] + 
     2*G[{0}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1), 1}, yw] - 
     2*G[{0}, yw]*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1), 1}, yw] - 
     2*G[{1}, yu^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1), 1}, yw] - 
     2*G[{1}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1), 1}, yw] - 
     2*G[{1}, yu^(-1)]^2*G[{0, yu^(-1), yu^(-1)}, yw] + 
     4*G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*G[{0, yu^(-1), yu^(-1)}, yw] - 
     2*G[{1}, yv^(-1)]^2*G[{0, yu^(-1), yu^(-1)}, yw] + 
     2*G[{1}, yw]^2*G[{0, yu^(-1), yu^(-1)}, yw] - 
     4*G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1), yu^(-1)}, yw] + 
     2*G[{1/(yu*yv)}, yw]^2*G[{0, yu^(-1), yu^(-1)}, yw] + 
     4*G[{0, 1}, yu^(-1)]*G[{0, yu^(-1), yu^(-1)}, yw] + 
     4*G[{0, 1}, yv^(-1)]*G[{0, yu^(-1), yu^(-1)}, yw] - 
     4*G[{0, yu}, yv^(-1)]*G[{0, yu^(-1), yu^(-1)}, yw] + 
     2*G[{0}, yu^(-1)]*G[{1}, yu^(-1)]*G[{0, yu^(-1), 1/(yu*yv)}, yw] + 
     2*G[{0}, yv^(-1)]*G[{1}, yu^(-1)]*G[{0, yu^(-1), 1/(yu*yv)}, yw] - 
     2*G[{0}, yw]*G[{1}, yu^(-1)]*G[{0, yu^(-1), 1/(yu*yv)}, yw] - 
     2*G[{1}, yu^(-1)]^2*G[{0, yu^(-1), 1/(yu*yv)}, yw] + 
     2*G[{0}, yu^(-1)]*G[{1}, yv^(-1)]*G[{0, yu^(-1), 1/(yu*yv)}, yw] + 
     2*G[{0}, yv^(-1)]*G[{1}, yv^(-1)]*G[{0, yu^(-1), 1/(yu*yv)}, yw] - 
     2*G[{0}, yw]*G[{1}, yv^(-1)]*G[{0, yu^(-1), 1/(yu*yv)}, yw] - 
     4*G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*G[{0, yu^(-1), 1/(yu*yv)}, yw] - 
     2*G[{1}, yv^(-1)]^2*G[{0, yu^(-1), 1/(yu*yv)}, yw] + 
     2*G[{0}, yu^(-1)]*G[{1}, yw]*G[{0, yu^(-1), 1/(yu*yv)}, yw] + 
     2*G[{0}, yv^(-1)]*G[{1}, yw]*G[{0, yu^(-1), 1/(yu*yv)}, yw] - 
     2*G[{0}, yw]*G[{1}, yw]*G[{0, yu^(-1), 1/(yu*yv)}, yw] - 
     2*G[{1}, yu^(-1)]*G[{1}, yw]*G[{0, yu^(-1), 1/(yu*yv)}, yw] - 
     2*G[{1}, yv^(-1)]*G[{1}, yw]*G[{0, yu^(-1), 1/(yu*yv)}, yw] - 
     4*G[{0}, yu^(-1)]*G[{yu}, yv^(-1)]*G[{0, yu^(-1), 1/(yu*yv)}, yw] - 
     4*G[{0}, yv^(-1)]*G[{yu}, yv^(-1)]*G[{0, yu^(-1), 1/(yu*yv)}, yw] + 
     4*G[{0}, yw]*G[{yu}, yv^(-1)]*G[{0, yu^(-1), 1/(yu*yv)}, yw] + 
     4*G[{1}, yu^(-1)]*G[{yu}, yv^(-1)]*G[{0, yu^(-1), 1/(yu*yv)}, yw] + 
     4*G[{1}, yv^(-1)]*G[{yu}, yv^(-1)]*G[{0, yu^(-1), 1/(yu*yv)}, yw] - 
     2*G[{0}, yu^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1), 1/(yu*yv)}, yw] - 
     2*G[{0}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1), 1/(yu*yv)}, yw] + 
     2*G[{0}, yw]*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1), 1/(yu*yv)}, yw] + 
     2*G[{1}, yu^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1), 1/(yu*yv)}, yw] + 
     2*G[{1}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1), 1/(yu*yv)}, yw] + 
     2*G[{0}, yu^(-1)]*G[{1}, yu^(-1)]*G[{0, yu, 1}, yv^(-1)] + 
     2*G[{0}, yv^(-1)]*G[{1}, yu^(-1)]*G[{0, yu, 1}, yv^(-1)] - 
     2*G[{0}, yw]*G[{1}, yu^(-1)]*G[{0, yu, 1}, yv^(-1)] - 
     2*G[{1}, yu^(-1)]^2*G[{0, yu, 1}, yv^(-1)] + 
     2*G[{0}, yu^(-1)]*G[{1}, yv^(-1)]*G[{0, yu, 1}, yv^(-1)] + 
     2*G[{0}, yv^(-1)]*G[{1}, yv^(-1)]*G[{0, yu, 1}, yv^(-1)] - 
     2*G[{0}, yw]*G[{1}, yv^(-1)]*G[{0, yu, 1}, yv^(-1)] - 
     2*G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*G[{0, yu, 1}, yv^(-1)] + 
     2*G[{0}, yu^(-1)]*G[{1}, yw]*G[{0, yu, 1}, yv^(-1)] + 
     2*G[{0}, yv^(-1)]*G[{1}, yw]*G[{0, yu, 1}, yv^(-1)] - 
     2*G[{0}, yw]*G[{1}, yw]*G[{0, yu, 1}, yv^(-1)] - 
     2*G[{1}, yu^(-1)]*G[{1}, yw]*G[{0, yu, 1}, yv^(-1)] - 
     2*G[{0}, yu^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, yu, 1}, yv^(-1)] - 
     2*G[{0}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, yu, 1}, yv^(-1)] + 
     2*G[{0}, yw]*G[{1/(yu*yv)}, yw]*G[{0, yu, 1}, yv^(-1)] + 
     2*G[{1}, yu^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, yu, 1}, yv^(-1)] - 
     2*G[{0, 1}, yw]*G[{0, yu, 1}, yv^(-1)] - 2*G[{0, yu^(-1)}, yw]*
      G[{0, yu, 1}, yv^(-1)] + 2*G[{0, yv^(-1)}, yw]*G[{0, yu, 1}, yv^(-1)] + 
     2*G[{0, 1/(yu*yv)}, yw]*G[{0, yu, 1}, yv^(-1)] - 
     (2*Pi^2*G[{0, yu, yu}, yv^(-1)])/3 - 4*G[{0}, yu^(-1)]*G[{1}, yu^(-1)]*
      G[{0, yu, yu}, yv^(-1)] - 4*G[{0}, yv^(-1)]*G[{1}, yu^(-1)]*
      G[{0, yu, yu}, yv^(-1)] + 4*G[{0}, yw]*G[{1}, yu^(-1)]*
      G[{0, yu, yu}, yv^(-1)] + 2*G[{1}, yu^(-1)]^2*G[{0, yu, yu}, yv^(-1)] + 
     2*G[{1}, yv^(-1)]^2*G[{0, yu, yu}, yv^(-1)] - 
     4*G[{0}, yu^(-1)]*G[{1}, yw]*G[{0, yu, yu}, yv^(-1)] - 
     4*G[{0}, yv^(-1)]*G[{1}, yw]*G[{0, yu, yu}, yv^(-1)] + 
     4*G[{0}, yw]*G[{1}, yw]*G[{0, yu, yu}, yv^(-1)] - 
     2*G[{1}, yw]^2*G[{0, yu, yu}, yv^(-1)] + 4*G[{0}, yu^(-1)]*
      G[{1/(yu*yv)}, yw]*G[{0, yu, yu}, yv^(-1)] + 
     4*G[{0}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, yu, yu}, yv^(-1)] - 
     4*G[{0}, yw]*G[{1/(yu*yv)}, yw]*G[{0, yu, yu}, yv^(-1)] + 
     4*G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{0, yu, yu}, yv^(-1)] - 
     2*G[{1/(yu*yv)}, yw]^2*G[{0, yu, yu}, yv^(-1)] + 
     4*G[{0, yu^(-1)}, yw]*G[{0, yu, yu}, yv^(-1)] - 
     4*G[{0, yv^(-1)}, yw]*G[{0, yu, yu}, yv^(-1)] - 
     2*G[{0}, yu^(-1)]*G[{1}, yu^(-1)]*G[{0, yv^(-1), 1}, yw] - 
     2*G[{0}, yv^(-1)]*G[{1}, yu^(-1)]*G[{0, yv^(-1), 1}, yw] + 
     2*G[{0}, yw]*G[{1}, yu^(-1)]*G[{0, yv^(-1), 1}, yw] + 
     2*G[{1}, yu^(-1)]^2*G[{0, yv^(-1), 1}, yw] - 
     2*G[{0}, yu^(-1)]*G[{1}, yv^(-1)]*G[{0, yv^(-1), 1}, yw] - 
     2*G[{0}, yv^(-1)]*G[{1}, yv^(-1)]*G[{0, yv^(-1), 1}, yw] + 
     2*G[{0}, yw]*G[{1}, yv^(-1)]*G[{0, yv^(-1), 1}, yw] + 
     4*G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*G[{0, yv^(-1), 1}, yw] + 
     2*G[{1}, yv^(-1)]^2*G[{0, yv^(-1), 1}, yw] - 
     2*G[{0}, yu^(-1)]*G[{1}, yw]*G[{0, yv^(-1), 1}, yw] - 
     2*G[{0}, yv^(-1)]*G[{1}, yw]*G[{0, yv^(-1), 1}, yw] + 
     2*G[{0}, yw]*G[{1}, yw]*G[{0, yv^(-1), 1}, yw] + 
     2*G[{1}, yu^(-1)]*G[{1}, yw]*G[{0, yv^(-1), 1}, yw] + 
     2*G[{1}, yv^(-1)]*G[{1}, yw]*G[{0, yv^(-1), 1}, yw] + 
     4*G[{0}, yu^(-1)]*G[{yu}, yv^(-1)]*G[{0, yv^(-1), 1}, yw] + 
     4*G[{0}, yv^(-1)]*G[{yu}, yv^(-1)]*G[{0, yv^(-1), 1}, yw] - 
     4*G[{0}, yw]*G[{yu}, yv^(-1)]*G[{0, yv^(-1), 1}, yw] - 
     4*G[{1}, yu^(-1)]*G[{yu}, yv^(-1)]*G[{0, yv^(-1), 1}, yw] - 
     4*G[{1}, yv^(-1)]*G[{yu}, yv^(-1)]*G[{0, yv^(-1), 1}, yw] + 
     2*G[{0}, yu^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, yv^(-1), 1}, yw] + 
     2*G[{0}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, yv^(-1), 1}, yw] - 
     2*G[{0}, yw]*G[{1/(yu*yv)}, yw]*G[{0, yv^(-1), 1}, yw] - 
     2*G[{1}, yu^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, yv^(-1), 1}, yw] - 
     2*G[{1}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, yv^(-1), 1}, yw] - 
     2*G[{1}, yu^(-1)]^2*G[{0, yv^(-1), yv^(-1)}, yw] + 
     4*G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*G[{0, yv^(-1), yv^(-1)}, yw] - 
     2*G[{1}, yv^(-1)]^2*G[{0, yv^(-1), yv^(-1)}, yw] + 
     2*G[{1}, yw]^2*G[{0, yv^(-1), yv^(-1)}, yw] - 
     4*G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{0, yv^(-1), yv^(-1)}, yw] + 
     2*G[{1/(yu*yv)}, yw]^2*G[{0, yv^(-1), yv^(-1)}, yw] + 
     4*G[{0, 1}, yu^(-1)]*G[{0, yv^(-1), yv^(-1)}, yw] + 
     4*G[{0, 1}, yv^(-1)]*G[{0, yv^(-1), yv^(-1)}, yw] - 
     4*G[{0, yu}, yv^(-1)]*G[{0, yv^(-1), yv^(-1)}, yw] + 
     2*G[{0}, yu^(-1)]*G[{1}, yu^(-1)]*G[{0, yv^(-1), 1/(yu*yv)}, yw] + 
     2*G[{0}, yv^(-1)]*G[{1}, yu^(-1)]*G[{0, yv^(-1), 1/(yu*yv)}, yw] - 
     2*G[{0}, yw]*G[{1}, yu^(-1)]*G[{0, yv^(-1), 1/(yu*yv)}, yw] - 
     2*G[{1}, yu^(-1)]^2*G[{0, yv^(-1), 1/(yu*yv)}, yw] + 
     2*G[{0}, yu^(-1)]*G[{1}, yv^(-1)]*G[{0, yv^(-1), 1/(yu*yv)}, yw] + 
     2*G[{0}, yv^(-1)]*G[{1}, yv^(-1)]*G[{0, yv^(-1), 1/(yu*yv)}, yw] - 
     2*G[{0}, yw]*G[{1}, yv^(-1)]*G[{0, yv^(-1), 1/(yu*yv)}, yw] - 
     4*G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*G[{0, yv^(-1), 1/(yu*yv)}, yw] - 
     2*G[{1}, yv^(-1)]^2*G[{0, yv^(-1), 1/(yu*yv)}, yw] + 
     2*G[{0}, yu^(-1)]*G[{1}, yw]*G[{0, yv^(-1), 1/(yu*yv)}, yw] + 
     2*G[{0}, yv^(-1)]*G[{1}, yw]*G[{0, yv^(-1), 1/(yu*yv)}, yw] - 
     2*G[{0}, yw]*G[{1}, yw]*G[{0, yv^(-1), 1/(yu*yv)}, yw] - 
     2*G[{1}, yu^(-1)]*G[{1}, yw]*G[{0, yv^(-1), 1/(yu*yv)}, yw] - 
     2*G[{1}, yv^(-1)]*G[{1}, yw]*G[{0, yv^(-1), 1/(yu*yv)}, yw] - 
     4*G[{0}, yu^(-1)]*G[{yu}, yv^(-1)]*G[{0, yv^(-1), 1/(yu*yv)}, yw] - 
     4*G[{0}, yv^(-1)]*G[{yu}, yv^(-1)]*G[{0, yv^(-1), 1/(yu*yv)}, yw] + 
     4*G[{0}, yw]*G[{yu}, yv^(-1)]*G[{0, yv^(-1), 1/(yu*yv)}, yw] + 
     4*G[{1}, yu^(-1)]*G[{yu}, yv^(-1)]*G[{0, yv^(-1), 1/(yu*yv)}, yw] + 
     4*G[{1}, yv^(-1)]*G[{yu}, yv^(-1)]*G[{0, yv^(-1), 1/(yu*yv)}, yw] - 
     2*G[{0}, yu^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, yv^(-1), 1/(yu*yv)}, yw] - 
     2*G[{0}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, yv^(-1), 1/(yu*yv)}, yw] + 
     2*G[{0}, yw]*G[{1/(yu*yv)}, yw]*G[{0, yv^(-1), 1/(yu*yv)}, yw] + 
     2*G[{1}, yu^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, yv^(-1), 1/(yu*yv)}, yw] + 
     2*G[{1}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, yv^(-1), 1/(yu*yv)}, yw] + 
     (Pi^2*G[{0, 1/(yu*yv), 1}, yw])/3 + 4*G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*
      G[{0, 1/(yu*yv), 1}, yw] + 2*G[{1}, yu^(-1)]*G[{1}, yw]*
      G[{0, 1/(yu*yv), 1}, yw] + 2*G[{1}, yv^(-1)]*G[{1}, yw]*
      G[{0, 1/(yu*yv), 1}, yw] + 2*G[{1}, yw]^2*G[{0, 1/(yu*yv), 1}, yw] - 
     4*G[{1}, yu^(-1)]*G[{yu}, yv^(-1)]*G[{0, 1/(yu*yv), 1}, yw] - 
     4*G[{1}, yv^(-1)]*G[{yu}, yv^(-1)]*G[{0, 1/(yu*yv), 1}, yw] - 
     4*G[{1}, yw]*G[{yu}, yv^(-1)]*G[{0, 1/(yu*yv), 1}, yw] + 
     4*G[{yu}, yv^(-1)]^2*G[{0, 1/(yu*yv), 1}, yw] - 
     2*G[{1}, yu^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv), 1}, yw] - 
     2*G[{1}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv), 1}, yw] - 
     4*G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv), 1}, yw] + 
     4*G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv), 1}, yw] + 
     2*G[{1/(yu*yv)}, yw]^2*G[{0, 1/(yu*yv), 1}, yw] + 
     2*G[{0, 1}, yu^(-1)]*G[{0, 1/(yu*yv), 1}, yw] + 
     2*G[{0, 1}, yv^(-1)]*G[{0, 1/(yu*yv), 1}, yw] - 
     2*G[{0, 1}, yw]*G[{0, 1/(yu*yv), 1}, yw] + 2*G[{0, yu^(-1)}, yw]*
      G[{0, 1/(yu*yv), 1}, yw] - 2*G[{0, yu}, yv^(-1)]*
      G[{0, 1/(yu*yv), 1}, yw] + 2*G[{0, yv^(-1)}, yw]*
      G[{0, 1/(yu*yv), 1}, yw] - 2*G[{0, 1/(yu*yv)}, yw]*
      G[{0, 1/(yu*yv), 1}, yw] - (Pi^2*G[{0, 1/(yu*yv), yu^(-1)}, yw])/3 + 
     2*G[{0}, yu^(-1)]*G[{1}, yu^(-1)]*G[{0, 1/(yu*yv), yu^(-1)}, yw] + 
     2*G[{0}, yv^(-1)]*G[{1}, yu^(-1)]*G[{0, 1/(yu*yv), yu^(-1)}, yw] - 
     2*G[{0}, yw]*G[{1}, yu^(-1)]*G[{0, 1/(yu*yv), yu^(-1)}, yw] - 
     2*G[{1}, yu^(-1)]^2*G[{0, 1/(yu*yv), yu^(-1)}, yw] + 
     2*G[{0}, yu^(-1)]*G[{1}, yv^(-1)]*G[{0, 1/(yu*yv), yu^(-1)}, yw] + 
     2*G[{0}, yv^(-1)]*G[{1}, yv^(-1)]*G[{0, 1/(yu*yv), yu^(-1)}, yw] - 
     2*G[{0}, yw]*G[{1}, yv^(-1)]*G[{0, 1/(yu*yv), yu^(-1)}, yw] - 
     8*G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*G[{0, 1/(yu*yv), yu^(-1)}, yw] - 
     2*G[{1}, yv^(-1)]^2*G[{0, 1/(yu*yv), yu^(-1)}, yw] + 
     2*G[{0}, yu^(-1)]*G[{1}, yw]*G[{0, 1/(yu*yv), yu^(-1)}, yw] + 
     2*G[{0}, yv^(-1)]*G[{1}, yw]*G[{0, 1/(yu*yv), yu^(-1)}, yw] - 
     2*G[{0}, yw]*G[{1}, yw]*G[{0, 1/(yu*yv), yu^(-1)}, yw] - 
     4*G[{1}, yu^(-1)]*G[{1}, yw]*G[{0, 1/(yu*yv), yu^(-1)}, yw] - 
     4*G[{1}, yv^(-1)]*G[{1}, yw]*G[{0, 1/(yu*yv), yu^(-1)}, yw] - 
     2*G[{1}, yw]^2*G[{0, 1/(yu*yv), yu^(-1)}, yw] - 
     4*G[{0}, yu^(-1)]*G[{yu}, yv^(-1)]*G[{0, 1/(yu*yv), yu^(-1)}, yw] - 
     4*G[{0}, yv^(-1)]*G[{yu}, yv^(-1)]*G[{0, 1/(yu*yv), yu^(-1)}, yw] + 
     4*G[{0}, yw]*G[{yu}, yv^(-1)]*G[{0, 1/(yu*yv), yu^(-1)}, yw] + 
     8*G[{1}, yu^(-1)]*G[{yu}, yv^(-1)]*G[{0, 1/(yu*yv), yu^(-1)}, yw] + 
     8*G[{1}, yv^(-1)]*G[{yu}, yv^(-1)]*G[{0, 1/(yu*yv), yu^(-1)}, yw] + 
     4*G[{1}, yw]*G[{yu}, yv^(-1)]*G[{0, 1/(yu*yv), yu^(-1)}, yw] - 
     4*G[{yu}, yv^(-1)]^2*G[{0, 1/(yu*yv), yu^(-1)}, yw] - 
     2*G[{0}, yu^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv), yu^(-1)}, yw] - 
     2*G[{0}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv), yu^(-1)}, yw] + 
     2*G[{0}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv), yu^(-1)}, yw] + 
     4*G[{1}, yu^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv), yu^(-1)}, yw] + 
     4*G[{1}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv), yu^(-1)}, yw] + 
     4*G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv), yu^(-1)}, yw] - 
     4*G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv), yu^(-1)}, yw] - 
     2*G[{1/(yu*yv)}, yw]^2*G[{0, 1/(yu*yv), yu^(-1)}, yw] - 
     2*G[{0, 1}, yu^(-1)]*G[{0, 1/(yu*yv), yu^(-1)}, yw] - 
     2*G[{0, 1}, yv^(-1)]*G[{0, 1/(yu*yv), yu^(-1)}, yw] + 
     2*G[{0, 1}, yw]*G[{0, 1/(yu*yv), yu^(-1)}, yw] - 
     2*G[{0, yu^(-1)}, yw]*G[{0, 1/(yu*yv), yu^(-1)}, yw] + 
     2*G[{0, yu}, yv^(-1)]*G[{0, 1/(yu*yv), yu^(-1)}, yw] - 
     2*G[{0, yv^(-1)}, yw]*G[{0, 1/(yu*yv), yu^(-1)}, yw] + 
     2*G[{0, 1/(yu*yv)}, yw]*G[{0, 1/(yu*yv), yu^(-1)}, yw] - 
     (Pi^2*G[{0, 1/(yu*yv), yv^(-1)}, yw])/3 + 2*G[{0}, yu^(-1)]*
      G[{1}, yu^(-1)]*G[{0, 1/(yu*yv), yv^(-1)}, yw] + 
     2*G[{0}, yv^(-1)]*G[{1}, yu^(-1)]*G[{0, 1/(yu*yv), yv^(-1)}, yw] - 
     2*G[{0}, yw]*G[{1}, yu^(-1)]*G[{0, 1/(yu*yv), yv^(-1)}, yw] - 
     2*G[{1}, yu^(-1)]^2*G[{0, 1/(yu*yv), yv^(-1)}, yw] + 
     2*G[{0}, yu^(-1)]*G[{1}, yv^(-1)]*G[{0, 1/(yu*yv), yv^(-1)}, yw] + 
     2*G[{0}, yv^(-1)]*G[{1}, yv^(-1)]*G[{0, 1/(yu*yv), yv^(-1)}, yw] - 
     2*G[{0}, yw]*G[{1}, yv^(-1)]*G[{0, 1/(yu*yv), yv^(-1)}, yw] - 
     8*G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*G[{0, 1/(yu*yv), yv^(-1)}, yw] - 
     2*G[{1}, yv^(-1)]^2*G[{0, 1/(yu*yv), yv^(-1)}, yw] + 
     2*G[{0}, yu^(-1)]*G[{1}, yw]*G[{0, 1/(yu*yv), yv^(-1)}, yw] + 
     2*G[{0}, yv^(-1)]*G[{1}, yw]*G[{0, 1/(yu*yv), yv^(-1)}, yw] - 
     2*G[{0}, yw]*G[{1}, yw]*G[{0, 1/(yu*yv), yv^(-1)}, yw] - 
     4*G[{1}, yu^(-1)]*G[{1}, yw]*G[{0, 1/(yu*yv), yv^(-1)}, yw] - 
     4*G[{1}, yv^(-1)]*G[{1}, yw]*G[{0, 1/(yu*yv), yv^(-1)}, yw] - 
     2*G[{1}, yw]^2*G[{0, 1/(yu*yv), yv^(-1)}, yw] - 
     4*G[{0}, yu^(-1)]*G[{yu}, yv^(-1)]*G[{0, 1/(yu*yv), yv^(-1)}, yw] - 
     4*G[{0}, yv^(-1)]*G[{yu}, yv^(-1)]*G[{0, 1/(yu*yv), yv^(-1)}, yw] + 
     4*G[{0}, yw]*G[{yu}, yv^(-1)]*G[{0, 1/(yu*yv), yv^(-1)}, yw] + 
     8*G[{1}, yu^(-1)]*G[{yu}, yv^(-1)]*G[{0, 1/(yu*yv), yv^(-1)}, yw] + 
     8*G[{1}, yv^(-1)]*G[{yu}, yv^(-1)]*G[{0, 1/(yu*yv), yv^(-1)}, yw] + 
     4*G[{1}, yw]*G[{yu}, yv^(-1)]*G[{0, 1/(yu*yv), yv^(-1)}, yw] - 
     4*G[{yu}, yv^(-1)]^2*G[{0, 1/(yu*yv), yv^(-1)}, yw] - 
     2*G[{0}, yu^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv), yv^(-1)}, yw] - 
     2*G[{0}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv), yv^(-1)}, yw] + 
     2*G[{0}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv), yv^(-1)}, yw] + 
     4*G[{1}, yu^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv), yv^(-1)}, yw] + 
     4*G[{1}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv), yv^(-1)}, yw] + 
     4*G[{1}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv), yv^(-1)}, yw] - 
     4*G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv), yv^(-1)}, yw] - 
     2*G[{1/(yu*yv)}, yw]^2*G[{0, 1/(yu*yv), yv^(-1)}, yw] - 
     2*G[{0, 1}, yu^(-1)]*G[{0, 1/(yu*yv), yv^(-1)}, yw] - 
     2*G[{0, 1}, yv^(-1)]*G[{0, 1/(yu*yv), yv^(-1)}, yw] + 
     2*G[{0, 1}, yw]*G[{0, 1/(yu*yv), yv^(-1)}, yw] - 
     2*G[{0, yu^(-1)}, yw]*G[{0, 1/(yu*yv), yv^(-1)}, yw] + 
     2*G[{0, yu}, yv^(-1)]*G[{0, 1/(yu*yv), yv^(-1)}, yw] - 
     2*G[{0, yv^(-1)}, yw]*G[{0, 1/(yu*yv), yv^(-1)}, yw] + 
     2*G[{0, 1/(yu*yv)}, yw]*G[{0, 1/(yu*yv), yv^(-1)}, yw] + 
     (Pi^2*G[{0, 1/(yu*yv), 1/(yu*yv)}, yw])/3 - 4*G[{0}, yu^(-1)]*
      G[{1}, yu^(-1)]*G[{0, 1/(yu*yv), 1/(yu*yv)}, yw] - 
     4*G[{0}, yv^(-1)]*G[{1}, yu^(-1)]*G[{0, 1/(yu*yv), 1/(yu*yv)}, yw] + 
     4*G[{0}, yw]*G[{1}, yu^(-1)]*G[{0, 1/(yu*yv), 1/(yu*yv)}, yw] + 
     6*G[{1}, yu^(-1)]^2*G[{0, 1/(yu*yv), 1/(yu*yv)}, yw] - 
     4*G[{0}, yu^(-1)]*G[{1}, yv^(-1)]*G[{0, 1/(yu*yv), 1/(yu*yv)}, yw] - 
     4*G[{0}, yv^(-1)]*G[{1}, yv^(-1)]*G[{0, 1/(yu*yv), 1/(yu*yv)}, yw] + 
     4*G[{0}, yw]*G[{1}, yv^(-1)]*G[{0, 1/(yu*yv), 1/(yu*yv)}, yw] + 
     8*G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*G[{0, 1/(yu*yv), 1/(yu*yv)}, yw] + 
     6*G[{1}, yv^(-1)]^2*G[{0, 1/(yu*yv), 1/(yu*yv)}, yw] - 
     4*G[{0}, yu^(-1)]*G[{1}, yw]*G[{0, 1/(yu*yv), 1/(yu*yv)}, yw] - 
     4*G[{0}, yv^(-1)]*G[{1}, yw]*G[{0, 1/(yu*yv), 1/(yu*yv)}, yw] + 
     4*G[{0}, yw]*G[{1}, yw]*G[{0, 1/(yu*yv), 1/(yu*yv)}, yw] + 
     6*G[{1}, yu^(-1)]*G[{1}, yw]*G[{0, 1/(yu*yv), 1/(yu*yv)}, yw] + 
     6*G[{1}, yv^(-1)]*G[{1}, yw]*G[{0, 1/(yu*yv), 1/(yu*yv)}, yw] + 
     8*G[{0}, yu^(-1)]*G[{yu}, yv^(-1)]*G[{0, 1/(yu*yv), 1/(yu*yv)}, yw] + 
     8*G[{0}, yv^(-1)]*G[{yu}, yv^(-1)]*G[{0, 1/(yu*yv), 1/(yu*yv)}, yw] - 
     8*G[{0}, yw]*G[{yu}, yv^(-1)]*G[{0, 1/(yu*yv), 1/(yu*yv)}, yw] - 
     12*G[{1}, yu^(-1)]*G[{yu}, yv^(-1)]*G[{0, 1/(yu*yv), 1/(yu*yv)}, yw] - 
     12*G[{1}, yv^(-1)]*G[{yu}, yv^(-1)]*G[{0, 1/(yu*yv), 1/(yu*yv)}, yw] - 
     4*G[{1}, yw]*G[{yu}, yv^(-1)]*G[{0, 1/(yu*yv), 1/(yu*yv)}, yw] + 
     4*G[{yu}, yv^(-1)]^2*G[{0, 1/(yu*yv), 1/(yu*yv)}, yw] + 
     4*G[{0}, yu^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv), 1/(yu*yv)}, yw] + 
     4*G[{0}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv), 1/(yu*yv)}, yw] - 
     4*G[{0}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv), 1/(yu*yv)}, yw] - 
     6*G[{1}, yu^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv), 1/(yu*yv)}, yw] - 
     6*G[{1}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv), 1/(yu*yv)}, yw] + 
     4*G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv), 1/(yu*yv)}, yw] - 
     2*G[{0, 1}, yu^(-1)]*G[{0, 1/(yu*yv), 1/(yu*yv)}, yw] - 
     2*G[{0, 1}, yv^(-1)]*G[{0, 1/(yu*yv), 1/(yu*yv)}, yw] - 
     2*G[{0, 1}, yw]*G[{0, 1/(yu*yv), 1/(yu*yv)}, yw] + 
     2*G[{0, yu^(-1)}, yw]*G[{0, 1/(yu*yv), 1/(yu*yv)}, yw] + 
     2*G[{0, yu}, yv^(-1)]*G[{0, 1/(yu*yv), 1/(yu*yv)}, yw] + 
     2*G[{0, yv^(-1)}, yw]*G[{0, 1/(yu*yv), 1/(yu*yv)}, yw] - 
     2*G[{0, 1/(yu*yv)}, yw]*G[{0, 1/(yu*yv), 1/(yu*yv)}, yw] - 
     4*G[{0, 1}, yw]*G[{1, 1, yu}, yv^(-1)] - 4*G[{0, yu^(-1)}, yw]*
      G[{1, 1, yu}, yv^(-1)] + 4*G[{0, yv^(-1)}, yw]*G[{1, 1, yu}, yv^(-1)] + 
     4*G[{0, 1/(yu*yv)}, yw]*G[{1, 1, yu}, yv^(-1)] - 
     8*G[{0, yu^(-1)}, yw]*G[{1, yu, yu}, yv^(-1)] + 
     8*G[{0, yv^(-1)}, yw]*G[{1, yu, yu}, yv^(-1)] + 
     4*G[{0}, yu^(-1)]*G[{0, 0, 1, 1}, yu^(-1)] + 
     4*G[{0}, yv^(-1)]*G[{0, 0, 1, 1}, yu^(-1)] - 
     4*G[{0}, yw]*G[{0, 0, 1, 1}, yu^(-1)] + 4*G[{1}, yu^(-1)]*
      G[{0, 0, 1, 1}, yu^(-1)] - 4*G[{1}, yv^(-1)]*G[{0, 0, 1, 1}, yu^(-1)] + 
     4*G[{0}, yu^(-1)]*G[{0, 0, 1, 1}, yv^(-1)] + 
     4*G[{0}, yv^(-1)]*G[{0, 0, 1, 1}, yv^(-1)] - 
     4*G[{0}, yw]*G[{0, 0, 1, 1}, yv^(-1)] - 4*G[{1}, yu^(-1)]*
      G[{0, 0, 1, 1}, yv^(-1)] + 4*G[{1}, yv^(-1)]*G[{0, 0, 1, 1}, yv^(-1)] + 
     4*G[{1}, yu^(-1)]*G[{0, 0, 1, 1}, yw] + 4*G[{1}, yv^(-1)]*
      G[{0, 0, 1, 1}, yw] + 4*G[{1}, yw]*G[{0, 0, 1, 1}, yw] - 
     8*G[{yu}, yv^(-1)]*G[{0, 0, 1, 1}, yw] - 4*G[{1/(yu*yv)}, yw]*
      G[{0, 0, 1, 1}, yw] - 4*G[{1}, yu^(-1)]*G[{0, 0, 1, yu^(-1)}, yw] - 
     4*G[{1}, yv^(-1)]*G[{0, 0, 1, yu^(-1)}, yw] - 
     4*G[{1}, yw]*G[{0, 0, 1, yu^(-1)}, yw] + 8*G[{yu}, yv^(-1)]*
      G[{0, 0, 1, yu^(-1)}, yw] + 4*G[{1/(yu*yv)}, yw]*
      G[{0, 0, 1, yu^(-1)}, yw] - 4*G[{0}, yu^(-1)]*
      G[{0, 0, 1, yu}, yv^(-1)] - 4*G[{0}, yv^(-1)]*
      G[{0, 0, 1, yu}, yv^(-1)] + 4*G[{0}, yw]*G[{0, 0, 1, yu}, yv^(-1)] + 
     4*G[{1}, yu^(-1)]*G[{0, 0, 1, yu}, yv^(-1)] - 
     4*G[{1}, yv^(-1)]*G[{0, 0, 1, yu}, yv^(-1)] - 
     4*G[{1}, yu^(-1)]*G[{0, 0, 1, yv^(-1)}, yw] - 
     4*G[{1}, yv^(-1)]*G[{0, 0, 1, yv^(-1)}, yw] - 
     4*G[{1}, yw]*G[{0, 0, 1, yv^(-1)}, yw] + 8*G[{yu}, yv^(-1)]*
      G[{0, 0, 1, yv^(-1)}, yw] + 4*G[{1/(yu*yv)}, yw]*
      G[{0, 0, 1, yv^(-1)}, yw] + 4*G[{1}, yu^(-1)]*G[{0, 0, 1, 1/(yu*yv)}, 
       yw] + 4*G[{1}, yv^(-1)]*G[{0, 0, 1, 1/(yu*yv)}, yw] + 
     4*G[{1}, yw]*G[{0, 0, 1, 1/(yu*yv)}, yw] - 8*G[{yu}, yv^(-1)]*
      G[{0, 0, 1, 1/(yu*yv)}, yw] - 4*G[{1/(yu*yv)}, yw]*
      G[{0, 0, 1, 1/(yu*yv)}, yw] - 4*G[{1}, yu^(-1)]*
      G[{0, 0, yu^(-1), 1}, yw] - 4*G[{1}, yv^(-1)]*G[{0, 0, yu^(-1), 1}, 
       yw] - 4*G[{1}, yw]*G[{0, 0, yu^(-1), 1}, yw] + 
     8*G[{yu}, yv^(-1)]*G[{0, 0, yu^(-1), 1}, yw] + 
     4*G[{1/(yu*yv)}, yw]*G[{0, 0, yu^(-1), 1}, yw] - 
     4*G[{0}, yu^(-1)]*G[{0, 0, yu, 1}, yv^(-1)] - 
     4*G[{0}, yv^(-1)]*G[{0, 0, yu, 1}, yv^(-1)] + 
     4*G[{0}, yw]*G[{0, 0, yu, 1}, yv^(-1)] + 4*G[{1}, yu^(-1)]*
      G[{0, 0, yu, 1}, yv^(-1)] - 4*G[{1}, yv^(-1)]*
      G[{0, 0, yu, 1}, yv^(-1)] + 4*G[{0}, yu^(-1)]*
      G[{0, 0, yu, yu}, yv^(-1)] + 4*G[{0}, yv^(-1)]*
      G[{0, 0, yu, yu}, yv^(-1)] - 4*G[{0}, yw]*G[{0, 0, yu, yu}, yv^(-1)] + 
     4*G[{1}, yw]*G[{0, 0, yu, yu}, yv^(-1)] - 4*G[{1/(yu*yv)}, yw]*
      G[{0, 0, yu, yu}, yv^(-1)] - 4*G[{1}, yu^(-1)]*
      G[{0, 0, yv^(-1), 1}, yw] - 4*G[{1}, yv^(-1)]*G[{0, 0, yv^(-1), 1}, 
       yw] - 4*G[{1}, yw]*G[{0, 0, yv^(-1), 1}, yw] + 
     8*G[{yu}, yv^(-1)]*G[{0, 0, yv^(-1), 1}, yw] + 
     4*G[{1/(yu*yv)}, yw]*G[{0, 0, yv^(-1), 1}, yw] + 
     4*G[{1}, yu^(-1)]*G[{0, 0, 1/(yu*yv), 1}, yw] + 
     4*G[{1}, yv^(-1)]*G[{0, 0, 1/(yu*yv), 1}, yw] + 
     4*G[{1}, yw]*G[{0, 0, 1/(yu*yv), 1}, yw] - 8*G[{yu}, yv^(-1)]*
      G[{0, 0, 1/(yu*yv), 1}, yw] - 4*G[{1/(yu*yv)}, yw]*
      G[{0, 0, 1/(yu*yv), 1}, yw] - 4*G[{1}, yu^(-1)]*
      G[{0, 0, 1/(yu*yv), 1/(yu*yv)}, yw] - 4*G[{1}, yv^(-1)]*
      G[{0, 0, 1/(yu*yv), 1/(yu*yv)}, yw] - 4*G[{1}, yw]*
      G[{0, 0, 1/(yu*yv), 1/(yu*yv)}, yw] + 8*G[{yu}, yv^(-1)]*
      G[{0, 0, 1/(yu*yv), 1/(yu*yv)}, yw] + 4*G[{1/(yu*yv)}, yw]*
      G[{0, 0, 1/(yu*yv), 1/(yu*yv)}, yw] - 2*G[{1}, yu^(-1)]*
      G[{0, 1, 0, yu^(-1)}, yw] - 2*G[{1}, yv^(-1)]*G[{0, 1, 0, yu^(-1)}, 
       yw] - 2*G[{1}, yw]*G[{0, 1, 0, yu^(-1)}, yw] + 
     4*G[{yu}, yv^(-1)]*G[{0, 1, 0, yu^(-1)}, yw] + 
     2*G[{1/(yu*yv)}, yw]*G[{0, 1, 0, yu^(-1)}, yw] + 
     2*G[{1}, yu^(-1)]*G[{0, 1, 0, yu}, yv^(-1)] - 
     2*G[{1}, yv^(-1)]*G[{0, 1, 0, yu}, yv^(-1)] + 
     2*G[{1}, yw]*G[{0, 1, 0, yu}, yv^(-1)] - 2*G[{1/(yu*yv)}, yw]*
      G[{0, 1, 0, yu}, yv^(-1)] - 2*G[{1}, yu^(-1)]*G[{0, 1, 0, yv^(-1)}, 
       yw] - 2*G[{1}, yv^(-1)]*G[{0, 1, 0, yv^(-1)}, yw] - 
     2*G[{1}, yw]*G[{0, 1, 0, yv^(-1)}, yw] + 4*G[{yu}, yv^(-1)]*
      G[{0, 1, 0, yv^(-1)}, yw] + 2*G[{1/(yu*yv)}, yw]*
      G[{0, 1, 0, yv^(-1)}, yw] + 4*G[{1}, yu^(-1)]*G[{0, 1, 0, 1/(yu*yv)}, 
       yw] + 4*G[{1}, yv^(-1)]*G[{0, 1, 0, 1/(yu*yv)}, yw] + 
     4*G[{1}, yw]*G[{0, 1, 0, 1/(yu*yv)}, yw] - 8*G[{yu}, yv^(-1)]*
      G[{0, 1, 0, 1/(yu*yv)}, yw] - 4*G[{1/(yu*yv)}, yw]*
      G[{0, 1, 0, 1/(yu*yv)}, yw] + 6*G[{1}, yu^(-1)]*
      G[{0, 1, 1, 1}, yu^(-1)] - 6*G[{1}, yv^(-1)]*G[{0, 1, 1, 1}, yu^(-1)] + 
     6*G[{1}, yw]*G[{0, 1, 1, 1}, yu^(-1)] - 6*G[{1/(yu*yv)}, yw]*
      G[{0, 1, 1, 1}, yu^(-1)] + 6*G[{1}, yu^(-1)]*G[{0, 1, 1, 1}, yv^(-1)] + 
     6*G[{1}, yv^(-1)]*G[{0, 1, 1, 1}, yv^(-1)] + 
     6*G[{1}, yw]*G[{0, 1, 1, 1}, yv^(-1)] - 6*G[{1/(yu*yv)}, yw]*
      G[{0, 1, 1, 1}, yv^(-1)] + 6*G[{0}, yu^(-1)]*G[{0, 1, 1, 1}, yw] + 
     6*G[{0}, yv^(-1)]*G[{0, 1, 1, 1}, yw] - 6*G[{0}, yw]*
      G[{0, 1, 1, 1}, yw] - 6*G[{1}, yu^(-1)]*G[{0, 1, 1, 1}, yw] - 
     6*G[{1}, yv^(-1)]*G[{0, 1, 1, 1}, yw] - 6*G[{0}, yu^(-1)]*
      G[{0, 1, 1, yu^(-1)}, yw] - 6*G[{0}, yv^(-1)]*G[{0, 1, 1, yu^(-1)}, 
       yw] + 6*G[{0}, yw]*G[{0, 1, 1, yu^(-1)}, yw] + 
     12*G[{1}, yu^(-1)]*G[{0, 1, 1, yu^(-1)}, yw] + 
     12*G[{1}, yv^(-1)]*G[{0, 1, 1, yu^(-1)}, yw] + 
     6*G[{1}, yw]*G[{0, 1, 1, yu^(-1)}, yw] - 12*G[{yu}, yv^(-1)]*
      G[{0, 1, 1, yu^(-1)}, yw] - 6*G[{1/(yu*yv)}, yw]*
      G[{0, 1, 1, yu^(-1)}, yw] + 4*G[{0}, yu^(-1)]*
      G[{0, 1, 1, yu}, yv^(-1)] + 4*G[{0}, yv^(-1)]*
      G[{0, 1, 1, yu}, yv^(-1)] - 4*G[{0}, yw]*G[{0, 1, 1, yu}, yv^(-1)] - 
     12*G[{1}, yu^(-1)]*G[{0, 1, 1, yu}, yv^(-1)] - 
     8*G[{1}, yw]*G[{0, 1, 1, yu}, yv^(-1)] + 8*G[{1/(yu*yv)}, yw]*
      G[{0, 1, 1, yu}, yv^(-1)] - 6*G[{0}, yu^(-1)]*G[{0, 1, 1, yv^(-1)}, 
       yw] - 6*G[{0}, yv^(-1)]*G[{0, 1, 1, yv^(-1)}, yw] + 
     6*G[{0}, yw]*G[{0, 1, 1, yv^(-1)}, yw] + 12*G[{1}, yu^(-1)]*
      G[{0, 1, 1, yv^(-1)}, yw] + 12*G[{1}, yv^(-1)]*
      G[{0, 1, 1, yv^(-1)}, yw] + 6*G[{1}, yw]*G[{0, 1, 1, yv^(-1)}, yw] - 
     12*G[{yu}, yv^(-1)]*G[{0, 1, 1, yv^(-1)}, yw] - 
     6*G[{1/(yu*yv)}, yw]*G[{0, 1, 1, yv^(-1)}, yw] + 
     6*G[{0}, yu^(-1)]*G[{0, 1, 1, 1/(yu*yv)}, yw] + 
     6*G[{0}, yv^(-1)]*G[{0, 1, 1, 1/(yu*yv)}, yw] - 
     6*G[{0}, yw]*G[{0, 1, 1, 1/(yu*yv)}, yw] - 10*G[{1}, yu^(-1)]*
      G[{0, 1, 1, 1/(yu*yv)}, yw] - 10*G[{1}, yv^(-1)]*
      G[{0, 1, 1, 1/(yu*yv)}, yw] - 4*G[{1}, yw]*G[{0, 1, 1, 1/(yu*yv)}, 
       yw] + 8*G[{yu}, yv^(-1)]*G[{0, 1, 1, 1/(yu*yv)}, yw] + 
     4*G[{1/(yu*yv)}, yw]*G[{0, 1, 1, 1/(yu*yv)}, yw] - 
     4*G[{0}, yu^(-1)]*G[{0, 1, yu^(-1), 1}, yw] - 
     4*G[{0}, yv^(-1)]*G[{0, 1, yu^(-1), 1}, yw] + 
     4*G[{0}, yw]*G[{0, 1, yu^(-1), 1}, yw] + 8*G[{1}, yu^(-1)]*
      G[{0, 1, yu^(-1), 1}, yw] + 8*G[{1}, yv^(-1)]*G[{0, 1, yu^(-1), 1}, 
       yw] + 4*G[{1}, yw]*G[{0, 1, yu^(-1), 1}, yw] - 
     8*G[{yu}, yv^(-1)]*G[{0, 1, yu^(-1), 1}, yw] - 
     4*G[{1/(yu*yv)}, yw]*G[{0, 1, yu^(-1), 1}, yw] + 
     4*G[{0}, yu^(-1)]*G[{0, 1, yu^(-1), yu^(-1)}, yw] + 
     4*G[{0}, yv^(-1)]*G[{0, 1, yu^(-1), yu^(-1)}, yw] - 
     4*G[{0}, yw]*G[{0, 1, yu^(-1), yu^(-1)}, yw] - 
     8*G[{1}, yu^(-1)]*G[{0, 1, yu^(-1), yu^(-1)}, yw] - 
     8*G[{1}, yv^(-1)]*G[{0, 1, yu^(-1), yu^(-1)}, yw] - 
     4*G[{1}, yw]*G[{0, 1, yu^(-1), yu^(-1)}, yw] + 
     8*G[{yu}, yv^(-1)]*G[{0, 1, yu^(-1), yu^(-1)}, yw] + 
     4*G[{1/(yu*yv)}, yw]*G[{0, 1, yu^(-1), yu^(-1)}, yw] + 
     4*G[{0}, yu^(-1)]*G[{0, 1, yu^(-1), yv^(-1)}, yw] + 
     4*G[{0}, yv^(-1)]*G[{0, 1, yu^(-1), yv^(-1)}, yw] - 
     4*G[{0}, yw]*G[{0, 1, yu^(-1), yv^(-1)}, yw] - 
     8*G[{1}, yu^(-1)]*G[{0, 1, yu^(-1), yv^(-1)}, yw] - 
     8*G[{1}, yv^(-1)]*G[{0, 1, yu^(-1), yv^(-1)}, yw] - 
     4*G[{1}, yw]*G[{0, 1, yu^(-1), yv^(-1)}, yw] + 
     8*G[{yu}, yv^(-1)]*G[{0, 1, yu^(-1), yv^(-1)}, yw] + 
     4*G[{1/(yu*yv)}, yw]*G[{0, 1, yu^(-1), yv^(-1)}, yw] - 
     4*G[{0}, yu^(-1)]*G[{0, 1, yu^(-1), 1/(yu*yv)}, yw] - 
     4*G[{0}, yv^(-1)]*G[{0, 1, yu^(-1), 1/(yu*yv)}, yw] + 
     4*G[{0}, yw]*G[{0, 1, yu^(-1), 1/(yu*yv)}, yw] + 
     4*G[{1}, yu^(-1)]*G[{0, 1, yu^(-1), 1/(yu*yv)}, yw] + 
     4*G[{1}, yv^(-1)]*G[{0, 1, yu^(-1), 1/(yu*yv)}, yw] + 
     4*G[{0}, yu^(-1)]*G[{0, 1, yu, 1}, yv^(-1)] + 
     4*G[{0}, yv^(-1)]*G[{0, 1, yu, 1}, yv^(-1)] - 
     4*G[{0}, yw]*G[{0, 1, yu, 1}, yv^(-1)] - 8*G[{1}, yu^(-1)]*
      G[{0, 1, yu, 1}, yv^(-1)] - 4*G[{1}, yw]*G[{0, 1, yu, 1}, yv^(-1)] + 
     4*G[{1/(yu*yv)}, yw]*G[{0, 1, yu, 1}, yv^(-1)] - 
     8*G[{0}, yu^(-1)]*G[{0, 1, yu, yu}, yv^(-1)] - 
     8*G[{0}, yv^(-1)]*G[{0, 1, yu, yu}, yv^(-1)] + 
     8*G[{0}, yw]*G[{0, 1, yu, yu}, yv^(-1)] + 8*G[{1}, yu^(-1)]*
      G[{0, 1, yu, yu}, yv^(-1)] - 4*G[{0}, yu^(-1)]*
      G[{0, 1, yv^(-1), 1}, yw] - 4*G[{0}, yv^(-1)]*G[{0, 1, yv^(-1), 1}, 
       yw] + 4*G[{0}, yw]*G[{0, 1, yv^(-1), 1}, yw] + 
     8*G[{1}, yu^(-1)]*G[{0, 1, yv^(-1), 1}, yw] + 
     8*G[{1}, yv^(-1)]*G[{0, 1, yv^(-1), 1}, yw] + 
     4*G[{1}, yw]*G[{0, 1, yv^(-1), 1}, yw] - 8*G[{yu}, yv^(-1)]*
      G[{0, 1, yv^(-1), 1}, yw] - 4*G[{1/(yu*yv)}, yw]*
      G[{0, 1, yv^(-1), 1}, yw] + 4*G[{0}, yu^(-1)]*
      G[{0, 1, yv^(-1), yu^(-1)}, yw] + 4*G[{0}, yv^(-1)]*
      G[{0, 1, yv^(-1), yu^(-1)}, yw] - 4*G[{0}, yw]*
      G[{0, 1, yv^(-1), yu^(-1)}, yw] - 8*G[{1}, yu^(-1)]*
      G[{0, 1, yv^(-1), yu^(-1)}, yw] - 8*G[{1}, yv^(-1)]*
      G[{0, 1, yv^(-1), yu^(-1)}, yw] - 4*G[{1}, yw]*
      G[{0, 1, yv^(-1), yu^(-1)}, yw] + 8*G[{yu}, yv^(-1)]*
      G[{0, 1, yv^(-1), yu^(-1)}, yw] + 4*G[{1/(yu*yv)}, yw]*
      G[{0, 1, yv^(-1), yu^(-1)}, yw] + 4*G[{0}, yu^(-1)]*
      G[{0, 1, yv^(-1), yv^(-1)}, yw] + 4*G[{0}, yv^(-1)]*
      G[{0, 1, yv^(-1), yv^(-1)}, yw] - 4*G[{0}, yw]*
      G[{0, 1, yv^(-1), yv^(-1)}, yw] - 8*G[{1}, yu^(-1)]*
      G[{0, 1, yv^(-1), yv^(-1)}, yw] - 8*G[{1}, yv^(-1)]*
      G[{0, 1, yv^(-1), yv^(-1)}, yw] - 4*G[{1}, yw]*
      G[{0, 1, yv^(-1), yv^(-1)}, yw] + 8*G[{yu}, yv^(-1)]*
      G[{0, 1, yv^(-1), yv^(-1)}, yw] + 4*G[{1/(yu*yv)}, yw]*
      G[{0, 1, yv^(-1), yv^(-1)}, yw] - 4*G[{0}, yu^(-1)]*
      G[{0, 1, yv^(-1), 1/(yu*yv)}, yw] - 4*G[{0}, yv^(-1)]*
      G[{0, 1, yv^(-1), 1/(yu*yv)}, yw] + 4*G[{0}, yw]*
      G[{0, 1, yv^(-1), 1/(yu*yv)}, yw] + 4*G[{1}, yu^(-1)]*
      G[{0, 1, yv^(-1), 1/(yu*yv)}, yw] + 4*G[{1}, yv^(-1)]*
      G[{0, 1, yv^(-1), 1/(yu*yv)}, yw] + 2*G[{0}, yu^(-1)]*
      G[{0, 1, 1/(yu*yv), 1}, yw] + 2*G[{0}, yv^(-1)]*
      G[{0, 1, 1/(yu*yv), 1}, yw] - 2*G[{0}, yw]*G[{0, 1, 1/(yu*yv), 1}, 
       yw] - 6*G[{1}, yu^(-1)]*G[{0, 1, 1/(yu*yv), 1}, yw] - 
     6*G[{1}, yv^(-1)]*G[{0, 1, 1/(yu*yv), 1}, yw] - 
     4*G[{1}, yw]*G[{0, 1, 1/(yu*yv), 1}, yw] + 8*G[{yu}, yv^(-1)]*
      G[{0, 1, 1/(yu*yv), 1}, yw] + 4*G[{1/(yu*yv)}, yw]*
      G[{0, 1, 1/(yu*yv), 1}, yw] - 2*G[{0}, yu^(-1)]*
      G[{0, 1, 1/(yu*yv), yu^(-1)}, yw] - 2*G[{0}, yv^(-1)]*
      G[{0, 1, 1/(yu*yv), yu^(-1)}, yw] + 2*G[{0}, yw]*
      G[{0, 1, 1/(yu*yv), yu^(-1)}, yw] + 4*G[{1}, yu^(-1)]*
      G[{0, 1, 1/(yu*yv), yu^(-1)}, yw] + 4*G[{1}, yv^(-1)]*
      G[{0, 1, 1/(yu*yv), yu^(-1)}, yw] + 2*G[{1}, yw]*
      G[{0, 1, 1/(yu*yv), yu^(-1)}, yw] - 4*G[{yu}, yv^(-1)]*
      G[{0, 1, 1/(yu*yv), yu^(-1)}, yw] - 2*G[{1/(yu*yv)}, yw]*
      G[{0, 1, 1/(yu*yv), yu^(-1)}, yw] - 2*G[{0}, yu^(-1)]*
      G[{0, 1, 1/(yu*yv), yv^(-1)}, yw] - 2*G[{0}, yv^(-1)]*
      G[{0, 1, 1/(yu*yv), yv^(-1)}, yw] + 2*G[{0}, yw]*
      G[{0, 1, 1/(yu*yv), yv^(-1)}, yw] + 4*G[{1}, yu^(-1)]*
      G[{0, 1, 1/(yu*yv), yv^(-1)}, yw] + 4*G[{1}, yv^(-1)]*
      G[{0, 1, 1/(yu*yv), yv^(-1)}, yw] + 2*G[{1}, yw]*
      G[{0, 1, 1/(yu*yv), yv^(-1)}, yw] - 4*G[{yu}, yv^(-1)]*
      G[{0, 1, 1/(yu*yv), yv^(-1)}, yw] - 2*G[{1/(yu*yv)}, yw]*
      G[{0, 1, 1/(yu*yv), yv^(-1)}, yw] + 2*G[{0}, yu^(-1)]*
      G[{0, 1, 1/(yu*yv), 1/(yu*yv)}, yw] + 2*G[{0}, yv^(-1)]*
      G[{0, 1, 1/(yu*yv), 1/(yu*yv)}, yw] - 2*G[{0}, yw]*
      G[{0, 1, 1/(yu*yv), 1/(yu*yv)}, yw] - 2*G[{1}, yu^(-1)]*
      G[{0, 1, 1/(yu*yv), 1/(yu*yv)}, yw] - 2*G[{1}, yv^(-1)]*
      G[{0, 1, 1/(yu*yv), 1/(yu*yv)}, yw] - 2*G[{1}, yu^(-1)]*
      G[{0, yu^(-1), 0, 1/(yu*yv)}, yw] - 2*G[{1}, yv^(-1)]*
      G[{0, yu^(-1), 0, 1/(yu*yv)}, yw] - 2*G[{1}, yw]*
      G[{0, yu^(-1), 0, 1/(yu*yv)}, yw] + 4*G[{yu}, yv^(-1)]*
      G[{0, yu^(-1), 0, 1/(yu*yv)}, yw] + 2*G[{1/(yu*yv)}, yw]*
      G[{0, yu^(-1), 0, 1/(yu*yv)}, yw] - 2*G[{0}, yu^(-1)]*
      G[{0, yu^(-1), 1, 1}, yw] - 2*G[{0}, yv^(-1)]*G[{0, yu^(-1), 1, 1}, 
       yw] + 2*G[{0}, yw]*G[{0, yu^(-1), 1, 1}, yw] + 
     2*G[{1}, yu^(-1)]*G[{0, yu^(-1), 1, 1}, yw] + 
     2*G[{1}, yv^(-1)]*G[{0, yu^(-1), 1, 1}, yw] + 
     2*G[{0}, yu^(-1)]*G[{0, yu^(-1), 1, yu^(-1)}, yw] + 
     2*G[{0}, yv^(-1)]*G[{0, yu^(-1), 1, yu^(-1)}, yw] - 
     2*G[{0}, yw]*G[{0, yu^(-1), 1, yu^(-1)}, yw] - 
     4*G[{1}, yu^(-1)]*G[{0, yu^(-1), 1, yu^(-1)}, yw] - 
     4*G[{1}, yv^(-1)]*G[{0, yu^(-1), 1, yu^(-1)}, yw] - 
     2*G[{1}, yw]*G[{0, yu^(-1), 1, yu^(-1)}, yw] + 
     4*G[{yu}, yv^(-1)]*G[{0, yu^(-1), 1, yu^(-1)}, yw] + 
     2*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1), 1, yu^(-1)}, yw] + 
     2*G[{0}, yu^(-1)]*G[{0, yu^(-1), 1, yv^(-1)}, yw] + 
     2*G[{0}, yv^(-1)]*G[{0, yu^(-1), 1, yv^(-1)}, yw] - 
     2*G[{0}, yw]*G[{0, yu^(-1), 1, yv^(-1)}, yw] - 
     4*G[{1}, yu^(-1)]*G[{0, yu^(-1), 1, yv^(-1)}, yw] - 
     4*G[{1}, yv^(-1)]*G[{0, yu^(-1), 1, yv^(-1)}, yw] - 
     2*G[{1}, yw]*G[{0, yu^(-1), 1, yv^(-1)}, yw] + 
     4*G[{yu}, yv^(-1)]*G[{0, yu^(-1), 1, yv^(-1)}, yw] + 
     2*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1), 1, yv^(-1)}, yw] - 
     2*G[{0}, yu^(-1)]*G[{0, yu^(-1), 1, 1/(yu*yv)}, yw] - 
     2*G[{0}, yv^(-1)]*G[{0, yu^(-1), 1, 1/(yu*yv)}, yw] + 
     2*G[{0}, yw]*G[{0, yu^(-1), 1, 1/(yu*yv)}, yw] + 
     2*G[{1}, yu^(-1)]*G[{0, yu^(-1), 1, 1/(yu*yv)}, yw] + 
     2*G[{1}, yv^(-1)]*G[{0, yu^(-1), 1, 1/(yu*yv)}, yw] - 
     4*G[{1}, yu^(-1)]*G[{0, yu^(-1), yu^(-1), 1}, yw] - 
     4*G[{1}, yv^(-1)]*G[{0, yu^(-1), yu^(-1), 1}, yw] - 
     4*G[{1}, yw]*G[{0, yu^(-1), yu^(-1), 1}, yw] + 
     8*G[{yu}, yv^(-1)]*G[{0, yu^(-1), yu^(-1), 1}, yw] + 
     4*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1), yu^(-1), 1}, yw] + 
     4*G[{1}, yu^(-1)]*G[{0, yu^(-1), yu^(-1), 1/(yu*yv)}, yw] + 
     4*G[{1}, yv^(-1)]*G[{0, yu^(-1), yu^(-1), 1/(yu*yv)}, yw] + 
     4*G[{1}, yw]*G[{0, yu^(-1), yu^(-1), 1/(yu*yv)}, yw] - 
     8*G[{yu}, yv^(-1)]*G[{0, yu^(-1), yu^(-1), 1/(yu*yv)}, yw] - 
     4*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1), yu^(-1), 1/(yu*yv)}, yw] + 
     2*G[{0}, yu^(-1)]*G[{0, yu^(-1), 1/(yu*yv), 1}, yw] + 
     2*G[{0}, yv^(-1)]*G[{0, yu^(-1), 1/(yu*yv), 1}, yw] - 
     2*G[{0}, yw]*G[{0, yu^(-1), 1/(yu*yv), 1}, yw] - 
     2*G[{1}, yu^(-1)]*G[{0, yu^(-1), 1/(yu*yv), 1}, yw] - 
     2*G[{1}, yv^(-1)]*G[{0, yu^(-1), 1/(yu*yv), 1}, yw] - 
     2*G[{0}, yu^(-1)]*G[{0, yu^(-1), 1/(yu*yv), yu^(-1)}, yw] - 
     2*G[{0}, yv^(-1)]*G[{0, yu^(-1), 1/(yu*yv), yu^(-1)}, yw] + 
     2*G[{0}, yw]*G[{0, yu^(-1), 1/(yu*yv), yu^(-1)}, yw] + 
     4*G[{1}, yu^(-1)]*G[{0, yu^(-1), 1/(yu*yv), yu^(-1)}, yw] + 
     4*G[{1}, yv^(-1)]*G[{0, yu^(-1), 1/(yu*yv), yu^(-1)}, yw] + 
     2*G[{1}, yw]*G[{0, yu^(-1), 1/(yu*yv), yu^(-1)}, yw] - 
     4*G[{yu}, yv^(-1)]*G[{0, yu^(-1), 1/(yu*yv), yu^(-1)}, yw] - 
     2*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1), 1/(yu*yv), yu^(-1)}, yw] - 
     2*G[{0}, yu^(-1)]*G[{0, yu^(-1), 1/(yu*yv), yv^(-1)}, yw] - 
     2*G[{0}, yv^(-1)]*G[{0, yu^(-1), 1/(yu*yv), yv^(-1)}, yw] + 
     2*G[{0}, yw]*G[{0, yu^(-1), 1/(yu*yv), yv^(-1)}, yw] + 
     4*G[{1}, yu^(-1)]*G[{0, yu^(-1), 1/(yu*yv), yv^(-1)}, yw] + 
     4*G[{1}, yv^(-1)]*G[{0, yu^(-1), 1/(yu*yv), yv^(-1)}, yw] + 
     2*G[{1}, yw]*G[{0, yu^(-1), 1/(yu*yv), yv^(-1)}, yw] - 
     4*G[{yu}, yv^(-1)]*G[{0, yu^(-1), 1/(yu*yv), yv^(-1)}, yw] - 
     2*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1), 1/(yu*yv), yv^(-1)}, yw] + 
     2*G[{0}, yu^(-1)]*G[{0, yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] + 
     2*G[{0}, yv^(-1)]*G[{0, yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] - 
     2*G[{0}, yw]*G[{0, yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] - 
     2*G[{1}, yu^(-1)]*G[{0, yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] - 
     2*G[{1}, yv^(-1)]*G[{0, yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] - 
     2*G[{1}, yu^(-1)]*G[{0, yu, 1, 1}, yv^(-1)] - 
     2*G[{1}, yv^(-1)]*G[{0, yu, 1, 1}, yv^(-1)] - 
     2*G[{1}, yw]*G[{0, yu, 1, 1}, yv^(-1)] + 2*G[{1/(yu*yv)}, yw]*
      G[{0, yu, 1, 1}, yv^(-1)] - 4*G[{0}, yu^(-1)]*
      G[{0, yu, 1, yu}, yv^(-1)] - 4*G[{0}, yv^(-1)]*
      G[{0, yu, 1, yu}, yv^(-1)] + 4*G[{0}, yw]*G[{0, yu, 1, yu}, yv^(-1)] + 
     4*G[{1}, yu^(-1)]*G[{0, yu, 1, yu}, yv^(-1)] - 
     4*G[{0}, yu^(-1)]*G[{0, yu, yu, 1}, yv^(-1)] - 
     4*G[{0}, yv^(-1)]*G[{0, yu, yu, 1}, yv^(-1)] + 
     4*G[{0}, yw]*G[{0, yu, yu, 1}, yv^(-1)] + 4*G[{1}, yu^(-1)]*
      G[{0, yu, yu, 1}, yv^(-1)] - 4*G[{1}, yv^(-1)]*
      G[{0, yu, yu, 1}, yv^(-1)] + 8*G[{0}, yu^(-1)]*
      G[{0, yu, yu, yu}, yv^(-1)] + 8*G[{0}, yv^(-1)]*
      G[{0, yu, yu, yu}, yv^(-1)] - 8*G[{0}, yw]*G[{0, yu, yu, yu}, 
       yv^(-1)] + 8*G[{1}, yw]*G[{0, yu, yu, yu}, yv^(-1)] - 
     8*G[{1/(yu*yv)}, yw]*G[{0, yu, yu, yu}, yv^(-1)] - 
     2*G[{1}, yu^(-1)]*G[{0, yv^(-1), 0, 1/(yu*yv)}, yw] - 
     2*G[{1}, yv^(-1)]*G[{0, yv^(-1), 0, 1/(yu*yv)}, yw] - 
     2*G[{1}, yw]*G[{0, yv^(-1), 0, 1/(yu*yv)}, yw] + 
     4*G[{yu}, yv^(-1)]*G[{0, yv^(-1), 0, 1/(yu*yv)}, yw] + 
     2*G[{1/(yu*yv)}, yw]*G[{0, yv^(-1), 0, 1/(yu*yv)}, yw] - 
     2*G[{0}, yu^(-1)]*G[{0, yv^(-1), 1, 1}, yw] - 
     2*G[{0}, yv^(-1)]*G[{0, yv^(-1), 1, 1}, yw] + 
     2*G[{0}, yw]*G[{0, yv^(-1), 1, 1}, yw] + 2*G[{1}, yu^(-1)]*
      G[{0, yv^(-1), 1, 1}, yw] + 2*G[{1}, yv^(-1)]*G[{0, yv^(-1), 1, 1}, 
       yw] + 2*G[{0}, yu^(-1)]*G[{0, yv^(-1), 1, yu^(-1)}, yw] + 
     2*G[{0}, yv^(-1)]*G[{0, yv^(-1), 1, yu^(-1)}, yw] - 
     2*G[{0}, yw]*G[{0, yv^(-1), 1, yu^(-1)}, yw] - 
     4*G[{1}, yu^(-1)]*G[{0, yv^(-1), 1, yu^(-1)}, yw] - 
     4*G[{1}, yv^(-1)]*G[{0, yv^(-1), 1, yu^(-1)}, yw] - 
     2*G[{1}, yw]*G[{0, yv^(-1), 1, yu^(-1)}, yw] + 
     4*G[{yu}, yv^(-1)]*G[{0, yv^(-1), 1, yu^(-1)}, yw] + 
     2*G[{1/(yu*yv)}, yw]*G[{0, yv^(-1), 1, yu^(-1)}, yw] + 
     2*G[{0}, yu^(-1)]*G[{0, yv^(-1), 1, yv^(-1)}, yw] + 
     2*G[{0}, yv^(-1)]*G[{0, yv^(-1), 1, yv^(-1)}, yw] - 
     2*G[{0}, yw]*G[{0, yv^(-1), 1, yv^(-1)}, yw] - 
     4*G[{1}, yu^(-1)]*G[{0, yv^(-1), 1, yv^(-1)}, yw] - 
     4*G[{1}, yv^(-1)]*G[{0, yv^(-1), 1, yv^(-1)}, yw] - 
     2*G[{1}, yw]*G[{0, yv^(-1), 1, yv^(-1)}, yw] + 
     4*G[{yu}, yv^(-1)]*G[{0, yv^(-1), 1, yv^(-1)}, yw] + 
     2*G[{1/(yu*yv)}, yw]*G[{0, yv^(-1), 1, yv^(-1)}, yw] - 
     2*G[{0}, yu^(-1)]*G[{0, yv^(-1), 1, 1/(yu*yv)}, yw] - 
     2*G[{0}, yv^(-1)]*G[{0, yv^(-1), 1, 1/(yu*yv)}, yw] + 
     2*G[{0}, yw]*G[{0, yv^(-1), 1, 1/(yu*yv)}, yw] + 
     2*G[{1}, yu^(-1)]*G[{0, yv^(-1), 1, 1/(yu*yv)}, yw] + 
     2*G[{1}, yv^(-1)]*G[{0, yv^(-1), 1, 1/(yu*yv)}, yw] - 
     4*G[{1}, yu^(-1)]*G[{0, yv^(-1), yv^(-1), 1}, yw] - 
     4*G[{1}, yv^(-1)]*G[{0, yv^(-1), yv^(-1), 1}, yw] - 
     4*G[{1}, yw]*G[{0, yv^(-1), yv^(-1), 1}, yw] + 
     8*G[{yu}, yv^(-1)]*G[{0, yv^(-1), yv^(-1), 1}, yw] + 
     4*G[{1/(yu*yv)}, yw]*G[{0, yv^(-1), yv^(-1), 1}, yw] + 
     4*G[{1}, yu^(-1)]*G[{0, yv^(-1), yv^(-1), 1/(yu*yv)}, yw] + 
     4*G[{1}, yv^(-1)]*G[{0, yv^(-1), yv^(-1), 1/(yu*yv)}, yw] + 
     4*G[{1}, yw]*G[{0, yv^(-1), yv^(-1), 1/(yu*yv)}, yw] - 
     8*G[{yu}, yv^(-1)]*G[{0, yv^(-1), yv^(-1), 1/(yu*yv)}, yw] - 
     4*G[{1/(yu*yv)}, yw]*G[{0, yv^(-1), yv^(-1), 1/(yu*yv)}, yw] + 
     2*G[{0}, yu^(-1)]*G[{0, yv^(-1), 1/(yu*yv), 1}, yw] + 
     2*G[{0}, yv^(-1)]*G[{0, yv^(-1), 1/(yu*yv), 1}, yw] - 
     2*G[{0}, yw]*G[{0, yv^(-1), 1/(yu*yv), 1}, yw] - 
     2*G[{1}, yu^(-1)]*G[{0, yv^(-1), 1/(yu*yv), 1}, yw] - 
     2*G[{1}, yv^(-1)]*G[{0, yv^(-1), 1/(yu*yv), 1}, yw] - 
     2*G[{0}, yu^(-1)]*G[{0, yv^(-1), 1/(yu*yv), yu^(-1)}, yw] - 
     2*G[{0}, yv^(-1)]*G[{0, yv^(-1), 1/(yu*yv), yu^(-1)}, yw] + 
     2*G[{0}, yw]*G[{0, yv^(-1), 1/(yu*yv), yu^(-1)}, yw] + 
     4*G[{1}, yu^(-1)]*G[{0, yv^(-1), 1/(yu*yv), yu^(-1)}, yw] + 
     4*G[{1}, yv^(-1)]*G[{0, yv^(-1), 1/(yu*yv), yu^(-1)}, yw] + 
     2*G[{1}, yw]*G[{0, yv^(-1), 1/(yu*yv), yu^(-1)}, yw] - 
     4*G[{yu}, yv^(-1)]*G[{0, yv^(-1), 1/(yu*yv), yu^(-1)}, yw] - 
     2*G[{1/(yu*yv)}, yw]*G[{0, yv^(-1), 1/(yu*yv), yu^(-1)}, yw] - 
     2*G[{0}, yu^(-1)]*G[{0, yv^(-1), 1/(yu*yv), yv^(-1)}, yw] - 
     2*G[{0}, yv^(-1)]*G[{0, yv^(-1), 1/(yu*yv), yv^(-1)}, yw] + 
     2*G[{0}, yw]*G[{0, yv^(-1), 1/(yu*yv), yv^(-1)}, yw] + 
     4*G[{1}, yu^(-1)]*G[{0, yv^(-1), 1/(yu*yv), yv^(-1)}, yw] + 
     4*G[{1}, yv^(-1)]*G[{0, yv^(-1), 1/(yu*yv), yv^(-1)}, yw] + 
     2*G[{1}, yw]*G[{0, yv^(-1), 1/(yu*yv), yv^(-1)}, yw] - 
     4*G[{yu}, yv^(-1)]*G[{0, yv^(-1), 1/(yu*yv), yv^(-1)}, yw] - 
     2*G[{1/(yu*yv)}, yw]*G[{0, yv^(-1), 1/(yu*yv), yv^(-1)}, yw] + 
     2*G[{0}, yu^(-1)]*G[{0, yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] + 
     2*G[{0}, yv^(-1)]*G[{0, yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] - 
     2*G[{0}, yw]*G[{0, yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] - 
     2*G[{1}, yu^(-1)]*G[{0, yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] - 
     2*G[{1}, yv^(-1)]*G[{0, yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] - 
     2*G[{0}, yu^(-1)]*G[{0, 1/(yu*yv), 1, 1}, yw] - 
     2*G[{0}, yv^(-1)]*G[{0, 1/(yu*yv), 1, 1}, yw] + 
     2*G[{0}, yw]*G[{0, 1/(yu*yv), 1, 1}, yw] + 2*G[{1}, yu^(-1)]*
      G[{0, 1/(yu*yv), 1, 1}, yw] + 2*G[{1}, yv^(-1)]*
      G[{0, 1/(yu*yv), 1, 1}, yw] + 2*G[{0}, yu^(-1)]*
      G[{0, 1/(yu*yv), 1, yu^(-1)}, yw] + 2*G[{0}, yv^(-1)]*
      G[{0, 1/(yu*yv), 1, yu^(-1)}, yw] - 2*G[{0}, yw]*
      G[{0, 1/(yu*yv), 1, yu^(-1)}, yw] - 4*G[{1}, yu^(-1)]*
      G[{0, 1/(yu*yv), 1, yu^(-1)}, yw] - 4*G[{1}, yv^(-1)]*
      G[{0, 1/(yu*yv), 1, yu^(-1)}, yw] - 2*G[{1}, yw]*
      G[{0, 1/(yu*yv), 1, yu^(-1)}, yw] + 4*G[{yu}, yv^(-1)]*
      G[{0, 1/(yu*yv), 1, yu^(-1)}, yw] + 2*G[{1/(yu*yv)}, yw]*
      G[{0, 1/(yu*yv), 1, yu^(-1)}, yw] + 2*G[{0}, yu^(-1)]*
      G[{0, 1/(yu*yv), 1, yv^(-1)}, yw] + 2*G[{0}, yv^(-1)]*
      G[{0, 1/(yu*yv), 1, yv^(-1)}, yw] - 2*G[{0}, yw]*
      G[{0, 1/(yu*yv), 1, yv^(-1)}, yw] - 4*G[{1}, yu^(-1)]*
      G[{0, 1/(yu*yv), 1, yv^(-1)}, yw] - 4*G[{1}, yv^(-1)]*
      G[{0, 1/(yu*yv), 1, yv^(-1)}, yw] - 2*G[{1}, yw]*
      G[{0, 1/(yu*yv), 1, yv^(-1)}, yw] + 4*G[{yu}, yv^(-1)]*
      G[{0, 1/(yu*yv), 1, yv^(-1)}, yw] + 2*G[{1/(yu*yv)}, yw]*
      G[{0, 1/(yu*yv), 1, yv^(-1)}, yw] - 2*G[{0}, yu^(-1)]*
      G[{0, 1/(yu*yv), 1, 1/(yu*yv)}, yw] - 2*G[{0}, yv^(-1)]*
      G[{0, 1/(yu*yv), 1, 1/(yu*yv)}, yw] + 2*G[{0}, yw]*
      G[{0, 1/(yu*yv), 1, 1/(yu*yv)}, yw] + 6*G[{1}, yu^(-1)]*
      G[{0, 1/(yu*yv), 1, 1/(yu*yv)}, yw] + 6*G[{1}, yv^(-1)]*
      G[{0, 1/(yu*yv), 1, 1/(yu*yv)}, yw] + 4*G[{1}, yw]*
      G[{0, 1/(yu*yv), 1, 1/(yu*yv)}, yw] - 8*G[{yu}, yv^(-1)]*
      G[{0, 1/(yu*yv), 1, 1/(yu*yv)}, yw] - 4*G[{1/(yu*yv)}, yw]*
      G[{0, 1/(yu*yv), 1, 1/(yu*yv)}, yw] + 4*G[{0}, yu^(-1)]*
      G[{0, 1/(yu*yv), yu^(-1), 1}, yw] + 4*G[{0}, yv^(-1)]*
      G[{0, 1/(yu*yv), yu^(-1), 1}, yw] - 4*G[{0}, yw]*
      G[{0, 1/(yu*yv), yu^(-1), 1}, yw] - 4*G[{1}, yu^(-1)]*
      G[{0, 1/(yu*yv), yu^(-1), 1}, yw] - 4*G[{1}, yv^(-1)]*
      G[{0, 1/(yu*yv), yu^(-1), 1}, yw] - 4*G[{0}, yu^(-1)]*
      G[{0, 1/(yu*yv), yu^(-1), yu^(-1)}, yw] - 4*G[{0}, yv^(-1)]*
      G[{0, 1/(yu*yv), yu^(-1), yu^(-1)}, yw] + 
     4*G[{0}, yw]*G[{0, 1/(yu*yv), yu^(-1), yu^(-1)}, yw] + 
     8*G[{1}, yu^(-1)]*G[{0, 1/(yu*yv), yu^(-1), yu^(-1)}, yw] + 
     8*G[{1}, yv^(-1)]*G[{0, 1/(yu*yv), yu^(-1), yu^(-1)}, yw] + 
     4*G[{1}, yw]*G[{0, 1/(yu*yv), yu^(-1), yu^(-1)}, yw] - 
     8*G[{yu}, yv^(-1)]*G[{0, 1/(yu*yv), yu^(-1), yu^(-1)}, yw] - 
     4*G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv), yu^(-1), yu^(-1)}, yw] - 
     4*G[{0}, yu^(-1)]*G[{0, 1/(yu*yv), yu^(-1), yv^(-1)}, yw] - 
     4*G[{0}, yv^(-1)]*G[{0, 1/(yu*yv), yu^(-1), yv^(-1)}, yw] + 
     4*G[{0}, yw]*G[{0, 1/(yu*yv), yu^(-1), yv^(-1)}, yw] + 
     8*G[{1}, yu^(-1)]*G[{0, 1/(yu*yv), yu^(-1), yv^(-1)}, yw] + 
     8*G[{1}, yv^(-1)]*G[{0, 1/(yu*yv), yu^(-1), yv^(-1)}, yw] + 
     4*G[{1}, yw]*G[{0, 1/(yu*yv), yu^(-1), yv^(-1)}, yw] - 
     8*G[{yu}, yv^(-1)]*G[{0, 1/(yu*yv), yu^(-1), yv^(-1)}, yw] - 
     4*G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv), yu^(-1), yv^(-1)}, yw] + 
     4*G[{0}, yu^(-1)]*G[{0, 1/(yu*yv), yu^(-1), 1/(yu*yv)}, yw] + 
     4*G[{0}, yv^(-1)]*G[{0, 1/(yu*yv), yu^(-1), 1/(yu*yv)}, yw] - 
     4*G[{0}, yw]*G[{0, 1/(yu*yv), yu^(-1), 1/(yu*yv)}, yw] - 
     8*G[{1}, yu^(-1)]*G[{0, 1/(yu*yv), yu^(-1), 1/(yu*yv)}, yw] - 
     8*G[{1}, yv^(-1)]*G[{0, 1/(yu*yv), yu^(-1), 1/(yu*yv)}, yw] - 
     4*G[{1}, yw]*G[{0, 1/(yu*yv), yu^(-1), 1/(yu*yv)}, yw] + 
     8*G[{yu}, yv^(-1)]*G[{0, 1/(yu*yv), yu^(-1), 1/(yu*yv)}, yw] + 
     4*G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv), yu^(-1), 1/(yu*yv)}, yw] + 
     4*G[{0}, yu^(-1)]*G[{0, 1/(yu*yv), yv^(-1), 1}, yw] + 
     4*G[{0}, yv^(-1)]*G[{0, 1/(yu*yv), yv^(-1), 1}, yw] - 
     4*G[{0}, yw]*G[{0, 1/(yu*yv), yv^(-1), 1}, yw] - 
     4*G[{1}, yu^(-1)]*G[{0, 1/(yu*yv), yv^(-1), 1}, yw] - 
     4*G[{1}, yv^(-1)]*G[{0, 1/(yu*yv), yv^(-1), 1}, yw] - 
     4*G[{0}, yu^(-1)]*G[{0, 1/(yu*yv), yv^(-1), yu^(-1)}, yw] - 
     4*G[{0}, yv^(-1)]*G[{0, 1/(yu*yv), yv^(-1), yu^(-1)}, yw] + 
     4*G[{0}, yw]*G[{0, 1/(yu*yv), yv^(-1), yu^(-1)}, yw] + 
     8*G[{1}, yu^(-1)]*G[{0, 1/(yu*yv), yv^(-1), yu^(-1)}, yw] + 
     8*G[{1}, yv^(-1)]*G[{0, 1/(yu*yv), yv^(-1), yu^(-1)}, yw] + 
     4*G[{1}, yw]*G[{0, 1/(yu*yv), yv^(-1), yu^(-1)}, yw] - 
     8*G[{yu}, yv^(-1)]*G[{0, 1/(yu*yv), yv^(-1), yu^(-1)}, yw] - 
     4*G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv), yv^(-1), yu^(-1)}, yw] - 
     4*G[{0}, yu^(-1)]*G[{0, 1/(yu*yv), yv^(-1), yv^(-1)}, yw] - 
     4*G[{0}, yv^(-1)]*G[{0, 1/(yu*yv), yv^(-1), yv^(-1)}, yw] + 
     4*G[{0}, yw]*G[{0, 1/(yu*yv), yv^(-1), yv^(-1)}, yw] + 
     8*G[{1}, yu^(-1)]*G[{0, 1/(yu*yv), yv^(-1), yv^(-1)}, yw] + 
     8*G[{1}, yv^(-1)]*G[{0, 1/(yu*yv), yv^(-1), yv^(-1)}, yw] + 
     4*G[{1}, yw]*G[{0, 1/(yu*yv), yv^(-1), yv^(-1)}, yw] - 
     8*G[{yu}, yv^(-1)]*G[{0, 1/(yu*yv), yv^(-1), yv^(-1)}, yw] - 
     4*G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv), yv^(-1), yv^(-1)}, yw] + 
     4*G[{0}, yu^(-1)]*G[{0, 1/(yu*yv), yv^(-1), 1/(yu*yv)}, yw] + 
     4*G[{0}, yv^(-1)]*G[{0, 1/(yu*yv), yv^(-1), 1/(yu*yv)}, yw] - 
     4*G[{0}, yw]*G[{0, 1/(yu*yv), yv^(-1), 1/(yu*yv)}, yw] - 
     8*G[{1}, yu^(-1)]*G[{0, 1/(yu*yv), yv^(-1), 1/(yu*yv)}, yw] - 
     8*G[{1}, yv^(-1)]*G[{0, 1/(yu*yv), yv^(-1), 1/(yu*yv)}, yw] - 
     4*G[{1}, yw]*G[{0, 1/(yu*yv), yv^(-1), 1/(yu*yv)}, yw] + 
     8*G[{yu}, yv^(-1)]*G[{0, 1/(yu*yv), yv^(-1), 1/(yu*yv)}, yw] + 
     4*G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv), yv^(-1), 1/(yu*yv)}, yw] - 
     6*G[{0}, yu^(-1)]*G[{0, 1/(yu*yv), 1/(yu*yv), 1}, yw] - 
     6*G[{0}, yv^(-1)]*G[{0, 1/(yu*yv), 1/(yu*yv), 1}, yw] + 
     6*G[{0}, yw]*G[{0, 1/(yu*yv), 1/(yu*yv), 1}, yw] + 
     10*G[{1}, yu^(-1)]*G[{0, 1/(yu*yv), 1/(yu*yv), 1}, yw] + 
     10*G[{1}, yv^(-1)]*G[{0, 1/(yu*yv), 1/(yu*yv), 1}, yw] + 
     4*G[{1}, yw]*G[{0, 1/(yu*yv), 1/(yu*yv), 1}, yw] - 
     8*G[{yu}, yv^(-1)]*G[{0, 1/(yu*yv), 1/(yu*yv), 1}, yw] - 
     4*G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv), 1/(yu*yv), 1}, yw] + 
     6*G[{0}, yu^(-1)]*G[{0, 1/(yu*yv), 1/(yu*yv), yu^(-1)}, yw] + 
     6*G[{0}, yv^(-1)]*G[{0, 1/(yu*yv), 1/(yu*yv), yu^(-1)}, yw] - 
     6*G[{0}, yw]*G[{0, 1/(yu*yv), 1/(yu*yv), yu^(-1)}, yw] - 
     12*G[{1}, yu^(-1)]*G[{0, 1/(yu*yv), 1/(yu*yv), yu^(-1)}, yw] - 
     12*G[{1}, yv^(-1)]*G[{0, 1/(yu*yv), 1/(yu*yv), yu^(-1)}, yw] - 
     6*G[{1}, yw]*G[{0, 1/(yu*yv), 1/(yu*yv), yu^(-1)}, yw] + 
     12*G[{yu}, yv^(-1)]*G[{0, 1/(yu*yv), 1/(yu*yv), yu^(-1)}, yw] + 
     6*G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv), 1/(yu*yv), yu^(-1)}, yw] + 
     6*G[{0}, yu^(-1)]*G[{0, 1/(yu*yv), 1/(yu*yv), yv^(-1)}, yw] + 
     6*G[{0}, yv^(-1)]*G[{0, 1/(yu*yv), 1/(yu*yv), yv^(-1)}, yw] - 
     6*G[{0}, yw]*G[{0, 1/(yu*yv), 1/(yu*yv), yv^(-1)}, yw] - 
     12*G[{1}, yu^(-1)]*G[{0, 1/(yu*yv), 1/(yu*yv), yv^(-1)}, yw] - 
     12*G[{1}, yv^(-1)]*G[{0, 1/(yu*yv), 1/(yu*yv), yv^(-1)}, yw] - 
     6*G[{1}, yw]*G[{0, 1/(yu*yv), 1/(yu*yv), yv^(-1)}, yw] + 
     12*G[{yu}, yv^(-1)]*G[{0, 1/(yu*yv), 1/(yu*yv), yv^(-1)}, yw] + 
     6*G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv), 1/(yu*yv), yv^(-1)}, yw] - 
     6*G[{0}, yu^(-1)]*G[{0, 1/(yu*yv), 1/(yu*yv), 1/(yu*yv)}, yw] - 
     6*G[{0}, yv^(-1)]*G[{0, 1/(yu*yv), 1/(yu*yv), 1/(yu*yv)}, yw] + 
     6*G[{0}, yw]*G[{0, 1/(yu*yv), 1/(yu*yv), 1/(yu*yv)}, yw] + 
     6*G[{1}, yu^(-1)]*G[{0, 1/(yu*yv), 1/(yu*yv), 1/(yu*yv)}, yw] + 
     6*G[{1}, yv^(-1)]*G[{0, 1/(yu*yv), 1/(yu*yv), 1/(yu*yv)}, yw] - 
     12*G[{0, 0, 0, 1, 1}, yu^(-1)] - 12*G[{0, 0, 0, 1, 1}, yv^(-1)] + 
     12*G[{0, 0, 0, 1, yu}, yv^(-1)] + 12*G[{0, 0, 0, yu, 1}, yv^(-1)] - 
     12*G[{0, 0, 0, yu, yu}, yv^(-1)] - 4*G[{0, 0, 1, 0, 1}, yu^(-1)] - 
     4*G[{0, 0, 1, 0, 1}, yv^(-1)] + 4*G[{0, 0, 1, 0, yu}, yv^(-1)] - 
     12*G[{0, 0, 1, 1, 1}, yu^(-1)] - 12*G[{0, 0, 1, 1, 1}, yv^(-1)] - 
     4*G[{0, 0, 1, 1, yu^(-1)}, yw] + 12*G[{0, 0, 1, 1, yu}, yv^(-1)] - 
     4*G[{0, 0, 1, 1, yv^(-1)}, yw] + 4*G[{0, 0, 1, 1, 1/(yu*yv)}, yw] - 
     4*G[{0, 0, 1, yu^(-1), 1}, yw] + 8*G[{0, 0, 1, yu^(-1), yu^(-1)}, yw] + 
     8*G[{0, 0, 1, yu^(-1), yv^(-1)}, yw] - 
     8*G[{0, 0, 1, yu^(-1), 1/(yu*yv)}, yw] + 
     8*G[{0, 0, 1, yu, 1}, yv^(-1)] - 4*G[{0, 0, 1, yv^(-1), 1}, yw] + 
     8*G[{0, 0, 1, yv^(-1), yu^(-1)}, yw] + 
     8*G[{0, 0, 1, yv^(-1), yv^(-1)}, yw] - 
     8*G[{0, 0, 1, yv^(-1), 1/(yu*yv)}, yw] + 
     4*G[{0, 0, 1, 1/(yu*yv), 1}, yw] - 8*G[{0, 0, 1, 1/(yu*yv), yu^(-1)}, 
       yw] - 8*G[{0, 0, 1, 1/(yu*yv), yv^(-1)}, yw] + 
     8*G[{0, 0, 1, 1/(yu*yv), 1/(yu*yv)}, yw] - 
     4*G[{0, 0, yu^(-1), 1, 1}, yw] + 4*G[{0, 0, yu^(-1), 1, yu^(-1)}, yw] + 
     4*G[{0, 0, yu^(-1), 1, yv^(-1)}, yw] - 
     4*G[{0, 0, yu^(-1), 1, 1/(yu*yv)}, yw] + 
     4*G[{0, 0, yu, 0, 1}, yv^(-1)] - 4*G[{0, 0, yu, 0, yu}, yv^(-1)] + 
     8*G[{0, 0, yu, 1, 1}, yv^(-1)] + 4*G[{0, 0, yu, yu, 1}, yv^(-1)] - 
     8*G[{0, 0, yu, yu, yu}, yv^(-1)] - 4*G[{0, 0, yv^(-1), 1, 1}, yw] + 
     4*G[{0, 0, yv^(-1), 1, yu^(-1)}, yw] + 
     4*G[{0, 0, yv^(-1), 1, yv^(-1)}, yw] - 
     4*G[{0, 0, yv^(-1), 1, 1/(yu*yv)}, yw] + 
     4*G[{0, 0, 1/(yu*yv), 1, 1}, yw] - 4*G[{0, 0, 1/(yu*yv), 1, yu^(-1)}, 
       yw] - 4*G[{0, 0, 1/(yu*yv), 1, yv^(-1)}, yw] + 
     4*G[{0, 0, 1/(yu*yv), 1, 1/(yu*yv)}, yw] - 
     2*G[{0, 1, 0, 1, 1}, yu^(-1)] - 2*G[{0, 1, 0, 1, 1}, yv^(-1)] - 
     2*G[{0, 1, 0, 1, 1}, yw] + 6*G[{0, 1, 0, 1, yu}, yv^(-1)] - 
     2*G[{0, 1, 0, yu^(-1), 1}, yw] + 4*G[{0, 1, 0, yu^(-1), yu^(-1)}, yw] + 
     4*G[{0, 1, 0, yu^(-1), yv^(-1)}, yw] - 
     4*G[{0, 1, 0, yu^(-1), 1/(yu*yv)}, yw] + 
     4*G[{0, 1, 0, yu, 1}, yv^(-1)] - 4*G[{0, 1, 0, yu, yu}, yv^(-1)] - 
     2*G[{0, 1, 0, yv^(-1), 1}, yw] + 4*G[{0, 1, 0, yv^(-1), yu^(-1)}, yw] + 
     4*G[{0, 1, 0, yv^(-1), yv^(-1)}, yw] - 
     4*G[{0, 1, 0, yv^(-1), 1/(yu*yv)}, yw] + 
     4*G[{0, 1, 0, 1/(yu*yv), 1}, yw] - 6*G[{0, 1, 0, 1/(yu*yv), yu^(-1)}, 
       yw] - 6*G[{0, 1, 0, 1/(yu*yv), yv^(-1)}, yw] + 
     6*G[{0, 1, 0, 1/(yu*yv), 1/(yu*yv)}, yw] - 
     2*G[{0, 1, 1, 0, yu^(-1)}, yw] + 2*G[{0, 1, 1, 0, yu}, yv^(-1)] - 
     2*G[{0, 1, 1, 0, yv^(-1)}, yw] + 2*G[{0, 1, 1, 0, 1/(yu*yv)}, yw] + 
     6*G[{0, 1, 1, 1, yu^(-1)}, yw] - 12*G[{0, 1, 1, 1, yu}, yv^(-1)] + 
     6*G[{0, 1, 1, 1, yv^(-1)}, yw] + 6*G[{0, 1, 1, yu^(-1), 1}, yw] - 
     12*G[{0, 1, 1, yu^(-1), yu^(-1)}, yw] - 
     12*G[{0, 1, 1, yu^(-1), yv^(-1)}, yw] + 
     6*G[{0, 1, 1, yu^(-1), 1/(yu*yv)}, yw] - 
     12*G[{0, 1, 1, yu, 1}, yv^(-1)] + 16*G[{0, 1, 1, yu, yu}, yv^(-1)] + 
     6*G[{0, 1, 1, yv^(-1), 1}, yw] - 12*G[{0, 1, 1, yv^(-1), yu^(-1)}, yw] - 
     12*G[{0, 1, 1, yv^(-1), yv^(-1)}, yw] + 
     6*G[{0, 1, 1, yv^(-1), 1/(yu*yv)}, yw] - 
     4*G[{0, 1, 1, 1/(yu*yv), 1}, yw] + 10*G[{0, 1, 1, 1/(yu*yv), yu^(-1)}, 
       yw] + 10*G[{0, 1, 1, 1/(yu*yv), yv^(-1)}, yw] - 
     4*G[{0, 1, 1, 1/(yu*yv), 1/(yu*yv)}, yw] + 
     2*G[{0, 1, yu^(-1), 0, yu^(-1)}, yw] + 
     2*G[{0, 1, yu^(-1), 0, yv^(-1)}, yw] - 
     2*G[{0, 1, yu^(-1), 0, 1/(yu*yv)}, yw] + 
     4*G[{0, 1, yu^(-1), 1, 1}, yw] - 8*G[{0, 1, yu^(-1), 1, yu^(-1)}, yw] - 
     8*G[{0, 1, yu^(-1), 1, yv^(-1)}, yw] + 
     4*G[{0, 1, yu^(-1), 1, 1/(yu*yv)}, yw] - 
     4*G[{0, 1, yu^(-1), yu^(-1), 1}, yw] + 
     8*G[{0, 1, yu^(-1), yu^(-1), yu^(-1)}, yw] + 
     8*G[{0, 1, yu^(-1), yu^(-1), yv^(-1)}, yw] - 
     4*G[{0, 1, yu^(-1), yu^(-1), 1/(yu*yv)}, yw] - 
     4*G[{0, 1, yu^(-1), yv^(-1), 1}, yw] + 
     8*G[{0, 1, yu^(-1), yv^(-1), yu^(-1)}, yw] + 
     8*G[{0, 1, yu^(-1), yv^(-1), yv^(-1)}, yw] - 
     4*G[{0, 1, yu^(-1), yv^(-1), 1/(yu*yv)}, yw] - 
     4*G[{0, 1, yu^(-1), 1/(yu*yv), yu^(-1)}, yw] - 
     4*G[{0, 1, yu^(-1), 1/(yu*yv), yv^(-1)}, yw] - 
     8*G[{0, 1, yu, 1, 1}, yv^(-1)] + 8*G[{0, 1, yu, 1, yu}, yv^(-1)] + 
     8*G[{0, 1, yu, yu, 1}, yv^(-1)] + 2*G[{0, 1, yv^(-1), 0, yu^(-1)}, yw] + 
     2*G[{0, 1, yv^(-1), 0, yv^(-1)}, yw] - 
     2*G[{0, 1, yv^(-1), 0, 1/(yu*yv)}, yw] + 
     4*G[{0, 1, yv^(-1), 1, 1}, yw] - 8*G[{0, 1, yv^(-1), 1, yu^(-1)}, yw] - 
     8*G[{0, 1, yv^(-1), 1, yv^(-1)}, yw] + 
     4*G[{0, 1, yv^(-1), 1, 1/(yu*yv)}, yw] - 
     4*G[{0, 1, yv^(-1), yu^(-1), 1}, yw] + 
     8*G[{0, 1, yv^(-1), yu^(-1), yu^(-1)}, yw] + 
     8*G[{0, 1, yv^(-1), yu^(-1), yv^(-1)}, yw] - 
     4*G[{0, 1, yv^(-1), yu^(-1), 1/(yu*yv)}, yw] - 
     4*G[{0, 1, yv^(-1), yv^(-1), 1}, yw] + 
     8*G[{0, 1, yv^(-1), yv^(-1), yu^(-1)}, yw] + 
     8*G[{0, 1, yv^(-1), yv^(-1), yv^(-1)}, yw] - 
     4*G[{0, 1, yv^(-1), yv^(-1), 1/(yu*yv)}, yw] - 
     4*G[{0, 1, yv^(-1), 1/(yu*yv), yu^(-1)}, yw] - 
     4*G[{0, 1, yv^(-1), 1/(yu*yv), yv^(-1)}, yw] - 
     2*G[{0, 1, 1/(yu*yv), 0, yu^(-1)}, yw] - 
     2*G[{0, 1, 1/(yu*yv), 0, yv^(-1)}, yw] + 
     2*G[{0, 1, 1/(yu*yv), 0, 1/(yu*yv)}, yw] - 
     4*G[{0, 1, 1/(yu*yv), 1, 1}, yw] + 6*G[{0, 1, 1/(yu*yv), 1, yu^(-1)}, 
       yw] + 6*G[{0, 1, 1/(yu*yv), 1, yv^(-1)}, yw] - 
     4*G[{0, 1, 1/(yu*yv), 1, 1/(yu*yv)}, yw] + 
     2*G[{0, 1, 1/(yu*yv), yu^(-1), 1}, yw] - 
     4*G[{0, 1, 1/(yu*yv), yu^(-1), yu^(-1)}, yw] - 
     4*G[{0, 1, 1/(yu*yv), yu^(-1), yv^(-1)}, yw] + 
     2*G[{0, 1, 1/(yu*yv), yu^(-1), 1/(yu*yv)}, yw] + 
     2*G[{0, 1, 1/(yu*yv), yv^(-1), 1}, yw] - 
     4*G[{0, 1, 1/(yu*yv), yv^(-1), yu^(-1)}, yw] - 
     4*G[{0, 1, 1/(yu*yv), yv^(-1), yv^(-1)}, yw] + 
     2*G[{0, 1, 1/(yu*yv), yv^(-1), 1/(yu*yv)}, yw] + 
     2*G[{0, 1, 1/(yu*yv), 1/(yu*yv), yu^(-1)}, yw] + 
     2*G[{0, 1, 1/(yu*yv), 1/(yu*yv), yv^(-1)}, yw] - 
     2*G[{0, yu^(-1), 0, 1/(yu*yv), 1}, yw] + 
     2*G[{0, yu^(-1), 0, 1/(yu*yv), yu^(-1)}, yw] + 
     2*G[{0, yu^(-1), 0, 1/(yu*yv), yv^(-1)}, yw] - 
     2*G[{0, yu^(-1), 0, 1/(yu*yv), 1/(yu*yv)}, yw] - 
     2*G[{0, yu^(-1), 1, 1, yu^(-1)}, yw] - 
     2*G[{0, yu^(-1), 1, 1, yv^(-1)}, yw] - 
     2*G[{0, yu^(-1), 1, yu^(-1), 1}, yw] + 
     4*G[{0, yu^(-1), 1, yu^(-1), yu^(-1)}, yw] + 
     4*G[{0, yu^(-1), 1, yu^(-1), yv^(-1)}, yw] - 
     2*G[{0, yu^(-1), 1, yu^(-1), 1/(yu*yv)}, yw] - 
     2*G[{0, yu^(-1), 1, yv^(-1), 1}, yw] + 
     4*G[{0, yu^(-1), 1, yv^(-1), yu^(-1)}, yw] + 
     4*G[{0, yu^(-1), 1, yv^(-1), yv^(-1)}, yw] - 
     2*G[{0, yu^(-1), 1, yv^(-1), 1/(yu*yv)}, yw] - 
     2*G[{0, yu^(-1), 1, 1/(yu*yv), yu^(-1)}, yw] - 
     2*G[{0, yu^(-1), 1, 1/(yu*yv), yv^(-1)}, yw] - 
     4*G[{0, yu^(-1), yu^(-1), 1, 1}, yw] + 
     4*G[{0, yu^(-1), yu^(-1), 1, yu^(-1)}, yw] + 
     4*G[{0, yu^(-1), yu^(-1), 1, yv^(-1)}, yw] - 
     4*G[{0, yu^(-1), yu^(-1), 1, 1/(yu*yv)}, yw] + 
     4*G[{0, yu^(-1), yu^(-1), 1/(yu*yv), 1}, yw] - 
     4*G[{0, yu^(-1), yu^(-1), 1/(yu*yv), yu^(-1)}, yw] - 
     4*G[{0, yu^(-1), yu^(-1), 1/(yu*yv), yv^(-1)}, yw] + 
     4*G[{0, yu^(-1), yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] + 
     2*G[{0, yu^(-1), 1/(yu*yv), 1, yu^(-1)}, yw] + 
     2*G[{0, yu^(-1), 1/(yu*yv), 1, yv^(-1)}, yw] + 
     2*G[{0, yu^(-1), 1/(yu*yv), yu^(-1), 1}, yw] - 
     4*G[{0, yu^(-1), 1/(yu*yv), yu^(-1), yu^(-1)}, yw] - 
     4*G[{0, yu^(-1), 1/(yu*yv), yu^(-1), yv^(-1)}, yw] + 
     2*G[{0, yu^(-1), 1/(yu*yv), yu^(-1), 1/(yu*yv)}, yw] + 
     2*G[{0, yu^(-1), 1/(yu*yv), yv^(-1), 1}, yw] - 
     4*G[{0, yu^(-1), 1/(yu*yv), yv^(-1), yu^(-1)}, yw] - 
     4*G[{0, yu^(-1), 1/(yu*yv), yv^(-1), yv^(-1)}, yw] + 
     2*G[{0, yu^(-1), 1/(yu*yv), yv^(-1), 1/(yu*yv)}, yw] + 
     2*G[{0, yu^(-1), 1/(yu*yv), 1/(yu*yv), yu^(-1)}, yw] + 
     2*G[{0, yu^(-1), 1/(yu*yv), 1/(yu*yv), yv^(-1)}, yw] + 
     2*G[{0, yu, 0, yu, 1}, yv^(-1)] + 4*G[{0, yu, 1, 1, yu}, yv^(-1)] + 
     4*G[{0, yu, 1, yu, 1}, yv^(-1)] + 8*G[{0, yu, yu, 1, 1}, yv^(-1)] - 
     16*G[{0, yu, yu, yu, yu}, yv^(-1)] - 
     2*G[{0, yv^(-1), 0, 1/(yu*yv), 1}, yw] + 
     2*G[{0, yv^(-1), 0, 1/(yu*yv), yu^(-1)}, yw] + 
     2*G[{0, yv^(-1), 0, 1/(yu*yv), yv^(-1)}, yw] - 
     2*G[{0, yv^(-1), 0, 1/(yu*yv), 1/(yu*yv)}, yw] - 
     2*G[{0, yv^(-1), 1, 1, yu^(-1)}, yw] - 
     2*G[{0, yv^(-1), 1, 1, yv^(-1)}, yw] - 
     2*G[{0, yv^(-1), 1, yu^(-1), 1}, yw] + 
     4*G[{0, yv^(-1), 1, yu^(-1), yu^(-1)}, yw] + 
     4*G[{0, yv^(-1), 1, yu^(-1), yv^(-1)}, yw] - 
     2*G[{0, yv^(-1), 1, yu^(-1), 1/(yu*yv)}, yw] - 
     2*G[{0, yv^(-1), 1, yv^(-1), 1}, yw] + 
     4*G[{0, yv^(-1), 1, yv^(-1), yu^(-1)}, yw] + 
     4*G[{0, yv^(-1), 1, yv^(-1), yv^(-1)}, yw] - 
     2*G[{0, yv^(-1), 1, yv^(-1), 1/(yu*yv)}, yw] - 
     2*G[{0, yv^(-1), 1, 1/(yu*yv), yu^(-1)}, yw] - 
     2*G[{0, yv^(-1), 1, 1/(yu*yv), yv^(-1)}, yw] - 
     4*G[{0, yv^(-1), yv^(-1), 1, 1}, yw] + 
     4*G[{0, yv^(-1), yv^(-1), 1, yu^(-1)}, yw] + 
     4*G[{0, yv^(-1), yv^(-1), 1, yv^(-1)}, yw] - 
     4*G[{0, yv^(-1), yv^(-1), 1, 1/(yu*yv)}, yw] + 
     4*G[{0, yv^(-1), yv^(-1), 1/(yu*yv), 1}, yw] - 
     4*G[{0, yv^(-1), yv^(-1), 1/(yu*yv), yu^(-1)}, yw] - 
     4*G[{0, yv^(-1), yv^(-1), 1/(yu*yv), yv^(-1)}, yw] + 
     4*G[{0, yv^(-1), yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] + 
     2*G[{0, yv^(-1), 1/(yu*yv), 1, yu^(-1)}, yw] + 
     2*G[{0, yv^(-1), 1/(yu*yv), 1, yv^(-1)}, yw] + 
     2*G[{0, yv^(-1), 1/(yu*yv), yu^(-1), 1}, yw] - 
     4*G[{0, yv^(-1), 1/(yu*yv), yu^(-1), yu^(-1)}, yw] - 
     4*G[{0, yv^(-1), 1/(yu*yv), yu^(-1), yv^(-1)}, yw] + 
     2*G[{0, yv^(-1), 1/(yu*yv), yu^(-1), 1/(yu*yv)}, yw] + 
     2*G[{0, yv^(-1), 1/(yu*yv), yv^(-1), 1}, yw] - 
     4*G[{0, yv^(-1), 1/(yu*yv), yv^(-1), yu^(-1)}, yw] - 
     4*G[{0, yv^(-1), 1/(yu*yv), yv^(-1), yv^(-1)}, yw] + 
     2*G[{0, yv^(-1), 1/(yu*yv), yv^(-1), 1/(yu*yv)}, yw] + 
     2*G[{0, yv^(-1), 1/(yu*yv), 1/(yu*yv), yu^(-1)}, yw] + 
     2*G[{0, yv^(-1), 1/(yu*yv), 1/(yu*yv), yv^(-1)}, yw] + 
     2*G[{0, 1/(yu*yv), 0, 1/(yu*yv), 1}, yw] - 
     2*G[{0, 1/(yu*yv), 0, 1/(yu*yv), yu^(-1)}, yw] - 
     2*G[{0, 1/(yu*yv), 0, 1/(yu*yv), yv^(-1)}, yw] + 
     2*G[{0, 1/(yu*yv), 0, 1/(yu*yv), 1/(yu*yv)}, yw] - 
     2*G[{0, 1/(yu*yv), 1, 1, yu^(-1)}, yw] - 
     2*G[{0, 1/(yu*yv), 1, 1, yv^(-1)}, yw] - 
     2*G[{0, 1/(yu*yv), 1, yu^(-1), 1}, yw] + 
     4*G[{0, 1/(yu*yv), 1, yu^(-1), yu^(-1)}, yw] + 
     4*G[{0, 1/(yu*yv), 1, yu^(-1), yv^(-1)}, yw] - 
     2*G[{0, 1/(yu*yv), 1, yu^(-1), 1/(yu*yv)}, yw] - 
     2*G[{0, 1/(yu*yv), 1, yv^(-1), 1}, yw] + 
     4*G[{0, 1/(yu*yv), 1, yv^(-1), yu^(-1)}, yw] + 
     4*G[{0, 1/(yu*yv), 1, yv^(-1), yv^(-1)}, yw] - 
     2*G[{0, 1/(yu*yv), 1, yv^(-1), 1/(yu*yv)}, yw] + 
     4*G[{0, 1/(yu*yv), 1, 1/(yu*yv), 1}, yw] - 
     6*G[{0, 1/(yu*yv), 1, 1/(yu*yv), yu^(-1)}, yw] - 
     6*G[{0, 1/(yu*yv), 1, 1/(yu*yv), yv^(-1)}, yw] + 
     4*G[{0, 1/(yu*yv), 1, 1/(yu*yv), 1/(yu*yv)}, yw] + 
     4*G[{0, 1/(yu*yv), yu^(-1), 1, yu^(-1)}, yw] + 
     4*G[{0, 1/(yu*yv), yu^(-1), 1, yv^(-1)}, yw] + 
     4*G[{0, 1/(yu*yv), yu^(-1), yu^(-1), 1}, yw] - 
     8*G[{0, 1/(yu*yv), yu^(-1), yu^(-1), yu^(-1)}, yw] - 
     8*G[{0, 1/(yu*yv), yu^(-1), yu^(-1), yv^(-1)}, yw] + 
     4*G[{0, 1/(yu*yv), yu^(-1), yu^(-1), 1/(yu*yv)}, yw] + 
     4*G[{0, 1/(yu*yv), yu^(-1), yv^(-1), 1}, yw] - 
     8*G[{0, 1/(yu*yv), yu^(-1), yv^(-1), yu^(-1)}, yw] - 
     8*G[{0, 1/(yu*yv), yu^(-1), yv^(-1), yv^(-1)}, yw] + 
     4*G[{0, 1/(yu*yv), yu^(-1), yv^(-1), 1/(yu*yv)}, yw] - 
     4*G[{0, 1/(yu*yv), yu^(-1), 1/(yu*yv), 1}, yw] + 
     8*G[{0, 1/(yu*yv), yu^(-1), 1/(yu*yv), yu^(-1)}, yw] + 
     8*G[{0, 1/(yu*yv), yu^(-1), 1/(yu*yv), yv^(-1)}, yw] - 
     4*G[{0, 1/(yu*yv), yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] + 
     4*G[{0, 1/(yu*yv), yv^(-1), 1, yu^(-1)}, yw] + 
     4*G[{0, 1/(yu*yv), yv^(-1), 1, yv^(-1)}, yw] + 
     4*G[{0, 1/(yu*yv), yv^(-1), yu^(-1), 1}, yw] - 
     8*G[{0, 1/(yu*yv), yv^(-1), yu^(-1), yu^(-1)}, yw] - 
     8*G[{0, 1/(yu*yv), yv^(-1), yu^(-1), yv^(-1)}, yw] + 
     4*G[{0, 1/(yu*yv), yv^(-1), yu^(-1), 1/(yu*yv)}, yw] + 
     4*G[{0, 1/(yu*yv), yv^(-1), yv^(-1), 1}, yw] - 
     8*G[{0, 1/(yu*yv), yv^(-1), yv^(-1), yu^(-1)}, yw] - 
     8*G[{0, 1/(yu*yv), yv^(-1), yv^(-1), yv^(-1)}, yw] + 
     4*G[{0, 1/(yu*yv), yv^(-1), yv^(-1), 1/(yu*yv)}, yw] - 
     4*G[{0, 1/(yu*yv), yv^(-1), 1/(yu*yv), 1}, yw] + 
     8*G[{0, 1/(yu*yv), yv^(-1), 1/(yu*yv), yu^(-1)}, yw] + 
     8*G[{0, 1/(yu*yv), yv^(-1), 1/(yu*yv), yv^(-1)}, yw] - 
     4*G[{0, 1/(yu*yv), yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] + 
     4*G[{0, 1/(yu*yv), 1/(yu*yv), 1, 1}, yw] - 
     10*G[{0, 1/(yu*yv), 1/(yu*yv), 1, yu^(-1)}, yw] - 
     10*G[{0, 1/(yu*yv), 1/(yu*yv), 1, yv^(-1)}, yw] + 
     4*G[{0, 1/(yu*yv), 1/(yu*yv), 1, 1/(yu*yv)}, yw] - 
     6*G[{0, 1/(yu*yv), 1/(yu*yv), yu^(-1), 1}, yw] + 
     12*G[{0, 1/(yu*yv), 1/(yu*yv), yu^(-1), yu^(-1)}, yw] + 
     12*G[{0, 1/(yu*yv), 1/(yu*yv), yu^(-1), yv^(-1)}, yw] - 
     6*G[{0, 1/(yu*yv), 1/(yu*yv), yu^(-1), 1/(yu*yv)}, yw] - 
     6*G[{0, 1/(yu*yv), 1/(yu*yv), yv^(-1), 1}, yw] + 
     12*G[{0, 1/(yu*yv), 1/(yu*yv), yv^(-1), yu^(-1)}, yw] + 
     12*G[{0, 1/(yu*yv), 1/(yu*yv), yv^(-1), yv^(-1)}, yw] - 
     6*G[{0, 1/(yu*yv), 1/(yu*yv), yv^(-1), 1/(yu*yv)}, yw] - 
     6*G[{0, 1/(yu*yv), 1/(yu*yv), 1/(yu*yv), yu^(-1)}, yw] - 
     6*G[{0, 1/(yu*yv), 1/(yu*yv), 1/(yu*yv), yv^(-1)}, yw] - 
     (Pi^2*Zeta[3])/3 + 2*G[{1}, yu^(-1)]^2*Zeta[3] - 
     4*G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*Zeta[3] + 2*G[{1}, yv^(-1)]^2*
      Zeta[3] + 4*G[{0}, yu^(-1)]*G[{1}, yw]*Zeta[3] + 
     4*G[{0}, yv^(-1)]*G[{1}, yw]*Zeta[3] - 4*G[{0}, yw]*G[{1}, yw]*Zeta[3] - 
     2*G[{1}, yw]^2*Zeta[3] - 4*G[{0}, yu^(-1)]*G[{1/(yu*yv)}, yw]*Zeta[3] - 
     4*G[{0}, yv^(-1)]*G[{1/(yu*yv)}, yw]*Zeta[3] + 
     4*G[{0}, yw]*G[{1/(yu*yv)}, yw]*Zeta[3] + 
     4*G[{1}, yw]*G[{1/(yu*yv)}, yw]*Zeta[3] - 2*G[{1/(yu*yv)}, yw]^2*
      Zeta[3] - 4*G[{0, 1}, yu^(-1)]*Zeta[3] - 4*G[{0, 1}, yv^(-1)]*Zeta[3] + 
     4*G[{0, 1}, yw]*Zeta[3] - 4*G[{0, 1/(yu*yv)}, yw]*Zeta[3] - 11*Zeta[5]
 
K1wuvRegII = -(Pi^4*G[{0}, yu^(-1)])/15 - (Pi^4*G[{0}, yv^(-1)])/15 + 
     (Pi^4*G[{0}, yw])/15 + (11*Pi^4*G[{1}, yu^(-1)])/90 + 
     (Pi^2*G[{0}, yu^(-1)]^2*G[{1}, yu^(-1)])/6 + 
     (Pi^2*G[{0}, yu^(-1)]*G[{0}, yv^(-1)]*G[{1}, yu^(-1)])/3 + 
     (Pi^2*G[{0}, yv^(-1)]^2*G[{1}, yu^(-1)])/6 - 
     (Pi^2*G[{0}, yu^(-1)]*G[{0}, yw]*G[{1}, yu^(-1)])/3 - 
     (Pi^2*G[{0}, yv^(-1)]*G[{0}, yw]*G[{1}, yu^(-1)])/3 + 
     (Pi^2*G[{0}, yw]^2*G[{1}, yu^(-1)])/6 - 
     (Pi^2*G[{0}, yu^(-1)]*G[{1}, yu^(-1)]^2)/6 - 
     (Pi^2*G[{0}, yv^(-1)]*G[{1}, yu^(-1)]^2)/6 + 
     (Pi^2*G[{0}, yw]*G[{1}, yu^(-1)]^2)/6 - (Pi^4*G[{1}, yv^(-1)])/36 - 
     (Pi^2*G[{0}, yu^(-1)]^2*G[{1}, yv^(-1)])/6 - 
     (Pi^2*G[{0}, yu^(-1)]*G[{0}, yv^(-1)]*G[{1}, yv^(-1)])/3 - 
     (Pi^2*G[{0}, yv^(-1)]^2*G[{1}, yv^(-1)])/6 + 
     (Pi^2*G[{0}, yu^(-1)]*G[{0}, yw]*G[{1}, yv^(-1)])/3 + 
     (Pi^2*G[{0}, yv^(-1)]*G[{0}, yw]*G[{1}, yv^(-1)])/3 - 
     (Pi^2*G[{0}, yw]^2*G[{1}, yv^(-1)])/6 + 
     (Pi^2*G[{0}, yu^(-1)]*G[{1}, yv^(-1)]^2)/6 + 
     (Pi^2*G[{0}, yv^(-1)]*G[{1}, yv^(-1)]^2)/6 - 
     (Pi^2*G[{0}, yw]*G[{1}, yv^(-1)]^2)/6 + (Pi^4*G[{1}, yw])/36 + 
     (Pi^2*G[{0}, yu^(-1)]^2*G[{1}, yw])/6 + 
     (Pi^2*G[{0}, yu^(-1)]*G[{0}, yv^(-1)]*G[{1}, yw])/3 + 
     (Pi^2*G[{0}, yv^(-1)]^2*G[{1}, yw])/6 - 
     (Pi^2*G[{0}, yu^(-1)]*G[{0}, yw]*G[{1}, yw])/3 - 
     (Pi^2*G[{0}, yv^(-1)]*G[{0}, yw]*G[{1}, yw])/3 + 
     (Pi^2*G[{0}, yw]^2*G[{1}, yw])/6 - (Pi^2*G[{0}, yu^(-1)]*G[{1}, yv^(-1)]*
       G[{1}, yw])/3 - (Pi^2*G[{0}, yv^(-1)]*G[{1}, yv^(-1)]*G[{1}, yw])/3 + 
     (Pi^2*G[{0}, yw]*G[{1}, yv^(-1)]*G[{1}, yw])/3 + 
     (Pi^2*G[{0}, yu^(-1)]*G[{1}, yw]^2)/6 + 
     (Pi^2*G[{0}, yv^(-1)]*G[{1}, yw]^2)/6 - (Pi^2*G[{0}, yw]*G[{1}, yw]^2)/
      6 - (11*Pi^4*G[{1/(yu*yv)}, yw])/90 - 
     (Pi^2*G[{0}, yu^(-1)]^2*G[{1/(yu*yv)}, yw])/6 - 
     (Pi^2*G[{0}, yu^(-1)]*G[{0}, yv^(-1)]*G[{1/(yu*yv)}, yw])/3 - 
     (Pi^2*G[{0}, yv^(-1)]^2*G[{1/(yu*yv)}, yw])/6 + 
     (Pi^2*G[{0}, yu^(-1)]*G[{0}, yw]*G[{1/(yu*yv)}, yw])/3 + 
     (Pi^2*G[{0}, yv^(-1)]*G[{0}, yw]*G[{1/(yu*yv)}, yw])/3 - 
     (Pi^2*G[{0}, yw]^2*G[{1/(yu*yv)}, yw])/6 + 
     (Pi^2*G[{0}, yu^(-1)]*G[{1}, yu^(-1)]*G[{1/(yu*yv)}, yw])/3 + 
     (Pi^2*G[{0}, yv^(-1)]*G[{1}, yu^(-1)]*G[{1/(yu*yv)}, yw])/3 - 
     (Pi^2*G[{0}, yw]*G[{1}, yu^(-1)]*G[{1/(yu*yv)}, yw])/3 - 
     (Pi^2*G[{0}, yu^(-1)]*G[{1/(yu*yv)}, yw]^2)/6 - 
     (Pi^2*G[{0}, yv^(-1)]*G[{1/(yu*yv)}, yw]^2)/6 + 
     (Pi^2*G[{0}, yw]*G[{1/(yu*yv)}, yw]^2)/6 - 
     (Pi^2*G[{0}, yu^(-1)]*G[{0, 1}, yu^(-1)])/3 - 
     (Pi^2*G[{0}, yv^(-1)]*G[{0, 1}, yu^(-1)])/3 + 
     (Pi^2*G[{0}, yw]*G[{0, 1}, yu^(-1)])/3 + 
     (2*Pi^2*G[{1}, yu^(-1)]*G[{0, 1}, yu^(-1)])/3 + 
     G[{0}, yu^(-1)]^2*G[{1}, yu^(-1)]*G[{0, 1}, yu^(-1)] + 
     2*G[{0}, yu^(-1)]*G[{0}, yv^(-1)]*G[{1}, yu^(-1)]*G[{0, 1}, yu^(-1)] + 
     G[{0}, yv^(-1)]^2*G[{1}, yu^(-1)]*G[{0, 1}, yu^(-1)] - 
     2*G[{0}, yu^(-1)]*G[{0}, yw]*G[{1}, yu^(-1)]*G[{0, 1}, yu^(-1)] - 
     2*G[{0}, yv^(-1)]*G[{0}, yw]*G[{1}, yu^(-1)]*G[{0, 1}, yu^(-1)] + 
     G[{0}, yw]^2*G[{1}, yu^(-1)]*G[{0, 1}, yu^(-1)] - 
     G[{0}, yu^(-1)]*G[{1}, yu^(-1)]^2*G[{0, 1}, yu^(-1)] - 
     G[{0}, yv^(-1)]*G[{1}, yu^(-1)]^2*G[{0, 1}, yu^(-1)] + 
     G[{0}, yw]*G[{1}, yu^(-1)]^2*G[{0, 1}, yu^(-1)] - 
     (Pi^2*G[{1}, yv^(-1)]*G[{0, 1}, yu^(-1)])/3 - 
     G[{0}, yu^(-1)]^2*G[{1}, yv^(-1)]*G[{0, 1}, yu^(-1)] - 
     2*G[{0}, yu^(-1)]*G[{0}, yv^(-1)]*G[{1}, yv^(-1)]*G[{0, 1}, yu^(-1)] - 
     G[{0}, yv^(-1)]^2*G[{1}, yv^(-1)]*G[{0, 1}, yu^(-1)] + 
     2*G[{0}, yu^(-1)]*G[{0}, yw]*G[{1}, yv^(-1)]*G[{0, 1}, yu^(-1)] + 
     2*G[{0}, yv^(-1)]*G[{0}, yw]*G[{1}, yv^(-1)]*G[{0, 1}, yu^(-1)] - 
     G[{0}, yw]^2*G[{1}, yv^(-1)]*G[{0, 1}, yu^(-1)] + 
     G[{0}, yu^(-1)]*G[{1}, yv^(-1)]^2*G[{0, 1}, yu^(-1)] + 
     G[{0}, yv^(-1)]*G[{1}, yv^(-1)]^2*G[{0, 1}, yu^(-1)] - 
     G[{0}, yw]*G[{1}, yv^(-1)]^2*G[{0, 1}, yu^(-1)] + 
     (Pi^2*G[{1}, yw]*G[{0, 1}, yu^(-1)])/3 + G[{0}, yu^(-1)]^2*G[{1}, yw]*
      G[{0, 1}, yu^(-1)] + 2*G[{0}, yu^(-1)]*G[{0}, yv^(-1)]*G[{1}, yw]*
      G[{0, 1}, yu^(-1)] + G[{0}, yv^(-1)]^2*G[{1}, yw]*G[{0, 1}, yu^(-1)] - 
     2*G[{0}, yu^(-1)]*G[{0}, yw]*G[{1}, yw]*G[{0, 1}, yu^(-1)] - 
     2*G[{0}, yv^(-1)]*G[{0}, yw]*G[{1}, yw]*G[{0, 1}, yu^(-1)] + 
     G[{0}, yw]^2*G[{1}, yw]*G[{0, 1}, yu^(-1)] - 
     2*G[{0}, yu^(-1)]*G[{1}, yv^(-1)]*G[{1}, yw]*G[{0, 1}, yu^(-1)] - 
     2*G[{0}, yv^(-1)]*G[{1}, yv^(-1)]*G[{1}, yw]*G[{0, 1}, yu^(-1)] + 
     2*G[{0}, yw]*G[{1}, yv^(-1)]*G[{1}, yw]*G[{0, 1}, yu^(-1)] + 
     G[{0}, yu^(-1)]*G[{1}, yw]^2*G[{0, 1}, yu^(-1)] + 
     G[{0}, yv^(-1)]*G[{1}, yw]^2*G[{0, 1}, yu^(-1)] - 
     G[{0}, yw]*G[{1}, yw]^2*G[{0, 1}, yu^(-1)] - 
     (2*Pi^2*G[{1/(yu*yv)}, yw]*G[{0, 1}, yu^(-1)])/3 - 
     G[{0}, yu^(-1)]^2*G[{1/(yu*yv)}, yw]*G[{0, 1}, yu^(-1)] - 
     2*G[{0}, yu^(-1)]*G[{0}, yv^(-1)]*G[{1/(yu*yv)}, yw]*
      G[{0, 1}, yu^(-1)] - G[{0}, yv^(-1)]^2*G[{1/(yu*yv)}, yw]*
      G[{0, 1}, yu^(-1)] + 2*G[{0}, yu^(-1)]*G[{0}, yw]*G[{1/(yu*yv)}, yw]*
      G[{0, 1}, yu^(-1)] + 2*G[{0}, yv^(-1)]*G[{0}, yw]*G[{1/(yu*yv)}, yw]*
      G[{0, 1}, yu^(-1)] - G[{0}, yw]^2*G[{1/(yu*yv)}, yw]*
      G[{0, 1}, yu^(-1)] + 2*G[{0}, yu^(-1)]*G[{1}, yu^(-1)]*
      G[{1/(yu*yv)}, yw]*G[{0, 1}, yu^(-1)] + 2*G[{0}, yv^(-1)]*
      G[{1}, yu^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, 1}, yu^(-1)] - 
     2*G[{0}, yw]*G[{1}, yu^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, 1}, yu^(-1)] - 
     G[{0}, yu^(-1)]*G[{1/(yu*yv)}, yw]^2*G[{0, 1}, yu^(-1)] - 
     G[{0}, yv^(-1)]*G[{1/(yu*yv)}, yw]^2*G[{0, 1}, yu^(-1)] + 
     G[{0}, yw]*G[{1/(yu*yv)}, yw]^2*G[{0, 1}, yu^(-1)] - 
     G[{1}, yv^(-1)]*G[{0, 1}, yu^(-1)]^2 + G[{1}, yw]*G[{0, 1}, yu^(-1)]^2 + 
     (Pi^2*G[{1}, yu^(-1)]*G[{0, 1}, yv^(-1)])/3 + 
     G[{0}, yu^(-1)]^2*G[{1}, yu^(-1)]*G[{0, 1}, yv^(-1)] + 
     2*G[{0}, yu^(-1)]*G[{0}, yv^(-1)]*G[{1}, yu^(-1)]*G[{0, 1}, yv^(-1)] + 
     G[{0}, yv^(-1)]^2*G[{1}, yu^(-1)]*G[{0, 1}, yv^(-1)] - 
     2*G[{0}, yu^(-1)]*G[{0}, yw]*G[{1}, yu^(-1)]*G[{0, 1}, yv^(-1)] - 
     2*G[{0}, yv^(-1)]*G[{0}, yw]*G[{1}, yu^(-1)]*G[{0, 1}, yv^(-1)] + 
     G[{0}, yw]^2*G[{1}, yu^(-1)]*G[{0, 1}, yv^(-1)] - 
     G[{0}, yu^(-1)]*G[{1}, yu^(-1)]^2*G[{0, 1}, yv^(-1)] - 
     G[{0}, yv^(-1)]*G[{1}, yu^(-1)]^2*G[{0, 1}, yv^(-1)] + 
     G[{0}, yw]*G[{1}, yu^(-1)]^2*G[{0, 1}, yv^(-1)] - 
     (2*Pi^2*G[{1}, yv^(-1)]*G[{0, 1}, yv^(-1)])/3 - 
     G[{0}, yu^(-1)]^2*G[{1}, yv^(-1)]*G[{0, 1}, yv^(-1)] - 
     2*G[{0}, yu^(-1)]*G[{0}, yv^(-1)]*G[{1}, yv^(-1)]*G[{0, 1}, yv^(-1)] - 
     G[{0}, yv^(-1)]^2*G[{1}, yv^(-1)]*G[{0, 1}, yv^(-1)] + 
     2*G[{0}, yu^(-1)]*G[{0}, yw]*G[{1}, yv^(-1)]*G[{0, 1}, yv^(-1)] + 
     2*G[{0}, yv^(-1)]*G[{0}, yw]*G[{1}, yv^(-1)]*G[{0, 1}, yv^(-1)] - 
     G[{0}, yw]^2*G[{1}, yv^(-1)]*G[{0, 1}, yv^(-1)] + 
     G[{0}, yu^(-1)]*G[{1}, yv^(-1)]^2*G[{0, 1}, yv^(-1)] + 
     G[{0}, yv^(-1)]*G[{1}, yv^(-1)]^2*G[{0, 1}, yv^(-1)] - 
     G[{0}, yw]*G[{1}, yv^(-1)]^2*G[{0, 1}, yv^(-1)] + 
     (2*Pi^2*G[{1}, yw]*G[{0, 1}, yv^(-1)])/3 + G[{0}, yu^(-1)]^2*G[{1}, yw]*
      G[{0, 1}, yv^(-1)] + 2*G[{0}, yu^(-1)]*G[{0}, yv^(-1)]*G[{1}, yw]*
      G[{0, 1}, yv^(-1)] + G[{0}, yv^(-1)]^2*G[{1}, yw]*G[{0, 1}, yv^(-1)] - 
     2*G[{0}, yu^(-1)]*G[{0}, yw]*G[{1}, yw]*G[{0, 1}, yv^(-1)] - 
     2*G[{0}, yv^(-1)]*G[{0}, yw]*G[{1}, yw]*G[{0, 1}, yv^(-1)] + 
     G[{0}, yw]^2*G[{1}, yw]*G[{0, 1}, yv^(-1)] - 
     2*G[{0}, yu^(-1)]*G[{1}, yv^(-1)]*G[{1}, yw]*G[{0, 1}, yv^(-1)] - 
     2*G[{0}, yv^(-1)]*G[{1}, yv^(-1)]*G[{1}, yw]*G[{0, 1}, yv^(-1)] + 
     2*G[{0}, yw]*G[{1}, yv^(-1)]*G[{1}, yw]*G[{0, 1}, yv^(-1)] + 
     G[{0}, yu^(-1)]*G[{1}, yw]^2*G[{0, 1}, yv^(-1)] + 
     G[{0}, yv^(-1)]*G[{1}, yw]^2*G[{0, 1}, yv^(-1)] - 
     G[{0}, yw]*G[{1}, yw]^2*G[{0, 1}, yv^(-1)] - 
     (Pi^2*G[{1/(yu*yv)}, yw]*G[{0, 1}, yv^(-1)])/3 - 
     G[{0}, yu^(-1)]^2*G[{1/(yu*yv)}, yw]*G[{0, 1}, yv^(-1)] - 
     2*G[{0}, yu^(-1)]*G[{0}, yv^(-1)]*G[{1/(yu*yv)}, yw]*
      G[{0, 1}, yv^(-1)] - G[{0}, yv^(-1)]^2*G[{1/(yu*yv)}, yw]*
      G[{0, 1}, yv^(-1)] + 2*G[{0}, yu^(-1)]*G[{0}, yw]*G[{1/(yu*yv)}, yw]*
      G[{0, 1}, yv^(-1)] + 2*G[{0}, yv^(-1)]*G[{0}, yw]*G[{1/(yu*yv)}, yw]*
      G[{0, 1}, yv^(-1)] - G[{0}, yw]^2*G[{1/(yu*yv)}, yw]*
      G[{0, 1}, yv^(-1)] + 2*G[{0}, yu^(-1)]*G[{1}, yu^(-1)]*
      G[{1/(yu*yv)}, yw]*G[{0, 1}, yv^(-1)] + 2*G[{0}, yv^(-1)]*
      G[{1}, yu^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, 1}, yv^(-1)] - 
     2*G[{0}, yw]*G[{1}, yu^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, 1}, yv^(-1)] - 
     G[{0}, yu^(-1)]*G[{1/(yu*yv)}, yw]^2*G[{0, 1}, yv^(-1)] - 
     G[{0}, yv^(-1)]*G[{1/(yu*yv)}, yw]^2*G[{0, 1}, yv^(-1)] + 
     G[{0}, yw]*G[{1/(yu*yv)}, yw]^2*G[{0, 1}, yv^(-1)] - 
     2*G[{0}, yu^(-1)]*G[{0, 1}, yu^(-1)]*G[{0, 1}, yv^(-1)] - 
     2*G[{0}, yv^(-1)]*G[{0, 1}, yu^(-1)]*G[{0, 1}, yv^(-1)] + 
     2*G[{0}, yw]*G[{0, 1}, yu^(-1)]*G[{0, 1}, yv^(-1)] + 
     2*G[{1}, yu^(-1)]*G[{0, 1}, yu^(-1)]*G[{0, 1}, yv^(-1)] - 
     2*G[{1/(yu*yv)}, yw]*G[{0, 1}, yu^(-1)]*G[{0, 1}, yv^(-1)] - 
     G[{1}, yv^(-1)]*G[{0, 1}, yv^(-1)]^2 + G[{1}, yw]*G[{0, 1}, yv^(-1)]^2 + 
     (Pi^2*G[{1}, yu^(-1)]*G[{0, 1}, yw])/3 + G[{0}, yu^(-1)]^2*
      G[{1}, yu^(-1)]*G[{0, 1}, yw] + 2*G[{0}, yu^(-1)]*G[{0}, yv^(-1)]*
      G[{1}, yu^(-1)]*G[{0, 1}, yw] + G[{0}, yv^(-1)]^2*G[{1}, yu^(-1)]*
      G[{0, 1}, yw] - 2*G[{0}, yu^(-1)]*G[{0}, yw]*G[{1}, yu^(-1)]*
      G[{0, 1}, yw] - 2*G[{0}, yv^(-1)]*G[{0}, yw]*G[{1}, yu^(-1)]*
      G[{0, 1}, yw] + G[{0}, yw]^2*G[{1}, yu^(-1)]*G[{0, 1}, yw] - 
     G[{0}, yu^(-1)]*G[{1}, yu^(-1)]^2*G[{0, 1}, yw] - 
     G[{0}, yv^(-1)]*G[{1}, yu^(-1)]^2*G[{0, 1}, yw] + 
     G[{0}, yw]*G[{1}, yu^(-1)]^2*G[{0, 1}, yw] - 
     (2*Pi^2*G[{1}, yv^(-1)]*G[{0, 1}, yw])/3 - G[{0}, yu^(-1)]^2*
      G[{1}, yv^(-1)]*G[{0, 1}, yw] - 2*G[{0}, yu^(-1)]*G[{0}, yv^(-1)]*
      G[{1}, yv^(-1)]*G[{0, 1}, yw] - G[{0}, yv^(-1)]^2*G[{1}, yv^(-1)]*
      G[{0, 1}, yw] + 2*G[{0}, yu^(-1)]*G[{0}, yw]*G[{1}, yv^(-1)]*
      G[{0, 1}, yw] + 2*G[{0}, yv^(-1)]*G[{0}, yw]*G[{1}, yv^(-1)]*
      G[{0, 1}, yw] - G[{0}, yw]^2*G[{1}, yv^(-1)]*G[{0, 1}, yw] + 
     2*G[{0}, yu^(-1)]*G[{1}, yv^(-1)]^2*G[{0, 1}, yw] + 
     2*G[{0}, yv^(-1)]*G[{1}, yv^(-1)]^2*G[{0, 1}, yw] - 
     2*G[{0}, yw]*G[{1}, yv^(-1)]^2*G[{0, 1}, yw] - 
     2*G[{1}, yu^(-1)]*G[{1}, yv^(-1)]^2*G[{0, 1}, yw] - 
     G[{1}, yv^(-1)]^3*G[{0, 1}, yw] + (2*Pi^2*G[{1}, yw]*G[{0, 1}, yw])/3 + 
     G[{0}, yu^(-1)]^2*G[{1}, yw]*G[{0, 1}, yw] + 
     2*G[{0}, yu^(-1)]*G[{0}, yv^(-1)]*G[{1}, yw]*G[{0, 1}, yw] + 
     G[{0}, yv^(-1)]^2*G[{1}, yw]*G[{0, 1}, yw] - 
     2*G[{0}, yu^(-1)]*G[{0}, yw]*G[{1}, yw]*G[{0, 1}, yw] - 
     2*G[{0}, yv^(-1)]*G[{0}, yw]*G[{1}, yw]*G[{0, 1}, yw] + 
     G[{0}, yw]^2*G[{1}, yw]*G[{0, 1}, yw] - 2*G[{0}, yu^(-1)]*
      G[{1}, yv^(-1)]*G[{1}, yw]*G[{0, 1}, yw] - 2*G[{0}, yv^(-1)]*
      G[{1}, yv^(-1)]*G[{1}, yw]*G[{0, 1}, yw] + 2*G[{0}, yw]*G[{1}, yv^(-1)]*
      G[{1}, yw]*G[{0, 1}, yw] + G[{1}, yv^(-1)]^2*G[{1}, yw]*G[{0, 1}, yw] + 
     G[{0}, yu^(-1)]*G[{1}, yw]^2*G[{0, 1}, yw] + 
     G[{0}, yv^(-1)]*G[{1}, yw]^2*G[{0, 1}, yw] - G[{0}, yw]*G[{1}, yw]^2*
      G[{0, 1}, yw] + (Pi^2*G[{yu}, yv^(-1)]*G[{0, 1}, yw])/3 - 
     2*G[{0}, yu^(-1)]*G[{1}, yu^(-1)]*G[{yu}, yv^(-1)]*G[{0, 1}, yw] - 
     2*G[{0}, yv^(-1)]*G[{1}, yu^(-1)]*G[{yu}, yv^(-1)]*G[{0, 1}, yw] + 
     2*G[{0}, yw]*G[{1}, yu^(-1)]*G[{yu}, yv^(-1)]*G[{0, 1}, yw] + 
     2*G[{1}, yu^(-1)]^2*G[{yu}, yv^(-1)]*G[{0, 1}, yw] - 
     2*G[{0}, yu^(-1)]*G[{1}, yv^(-1)]*G[{yu}, yv^(-1)]*G[{0, 1}, yw] - 
     2*G[{0}, yv^(-1)]*G[{1}, yv^(-1)]*G[{yu}, yv^(-1)]*G[{0, 1}, yw] + 
     2*G[{0}, yw]*G[{1}, yv^(-1)]*G[{yu}, yv^(-1)]*G[{0, 1}, yw] + 
     8*G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*G[{yu}, yv^(-1)]*G[{0, 1}, yw] + 
     2*G[{1}, yv^(-1)]^2*G[{yu}, yv^(-1)]*G[{0, 1}, yw] - 
     2*G[{0}, yu^(-1)]*G[{1}, yw]*G[{yu}, yv^(-1)]*G[{0, 1}, yw] - 
     2*G[{0}, yv^(-1)]*G[{1}, yw]*G[{yu}, yv^(-1)]*G[{0, 1}, yw] + 
     2*G[{0}, yw]*G[{1}, yw]*G[{yu}, yv^(-1)]*G[{0, 1}, yw] - 
     2*G[{1}, yw]^2*G[{yu}, yv^(-1)]*G[{0, 1}, yw] + 
     2*G[{0}, yu^(-1)]*G[{yu}, yv^(-1)]^2*G[{0, 1}, yw] + 
     2*G[{0}, yv^(-1)]*G[{yu}, yv^(-1)]^2*G[{0, 1}, yw] - 
     2*G[{0}, yw]*G[{yu}, yv^(-1)]^2*G[{0, 1}, yw] - 
     4*G[{1}, yu^(-1)]*G[{yu}, yv^(-1)]^2*G[{0, 1}, yw] - 
     4*G[{1}, yv^(-1)]*G[{yu}, yv^(-1)]^2*G[{0, 1}, yw] + 
     2*G[{1}, yw]*G[{yu}, yv^(-1)]^2*G[{0, 1}, yw] + 
     (4*G[{yu}, yv^(-1)]^3*G[{0, 1}, yw])/3 - 
     (Pi^2*G[{1/(yu*yv)}, yw]*G[{0, 1}, yw])/3 - G[{0}, yu^(-1)]^2*
      G[{1/(yu*yv)}, yw]*G[{0, 1}, yw] - 2*G[{0}, yu^(-1)]*G[{0}, yv^(-1)]*
      G[{1/(yu*yv)}, yw]*G[{0, 1}, yw] - G[{0}, yv^(-1)]^2*G[{1/(yu*yv)}, yw]*
      G[{0, 1}, yw] + 2*G[{0}, yu^(-1)]*G[{0}, yw]*G[{1/(yu*yv)}, yw]*
      G[{0, 1}, yw] + 2*G[{0}, yv^(-1)]*G[{0}, yw]*G[{1/(yu*yv)}, yw]*
      G[{0, 1}, yw] - G[{0}, yw]^2*G[{1/(yu*yv)}, yw]*G[{0, 1}, yw] + 
     2*G[{0}, yu^(-1)]*G[{1}, yu^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, 1}, yw] + 
     2*G[{0}, yv^(-1)]*G[{1}, yu^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, 1}, yw] - 
     2*G[{0}, yw]*G[{1}, yu^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, 1}, yw] + 
     G[{1}, yv^(-1)]^2*G[{1/(yu*yv)}, yw]*G[{0, 1}, yw] + 
     2*G[{0}, yu^(-1)]*G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, 1}, yw] + 
     2*G[{0}, yv^(-1)]*G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, 1}, yw] - 
     2*G[{0}, yw]*G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, 1}, yw] - 
     4*G[{1}, yu^(-1)]*G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, 1}, yw] - 
     4*G[{1}, yv^(-1)]*G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, 1}, yw] + 
     2*G[{yu}, yv^(-1)]^2*G[{1/(yu*yv)}, yw]*G[{0, 1}, yw] - 
     G[{0}, yu^(-1)]*G[{1/(yu*yv)}, yw]^2*G[{0, 1}, yw] - 
     G[{0}, yv^(-1)]*G[{1/(yu*yv)}, yw]^2*G[{0, 1}, yw] + 
     G[{0}, yw]*G[{1/(yu*yv)}, yw]^2*G[{0, 1}, yw] + 
     2*G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw]^2*G[{0, 1}, yw] - 
     2*G[{0}, yu^(-1)]*G[{0, 1}, yu^(-1)]*G[{0, 1}, yw] - 
     2*G[{0}, yv^(-1)]*G[{0, 1}, yu^(-1)]*G[{0, 1}, yw] + 
     2*G[{0}, yw]*G[{0, 1}, yu^(-1)]*G[{0, 1}, yw] + 
     2*G[{1}, yu^(-1)]*G[{0, 1}, yu^(-1)]*G[{0, 1}, yw] + 
     2*G[{yu}, yv^(-1)]*G[{0, 1}, yu^(-1)]*G[{0, 1}, yw] - 
     2*G[{1/(yu*yv)}, yw]*G[{0, 1}, yu^(-1)]*G[{0, 1}, yw] - 
     2*G[{1}, yv^(-1)]*G[{0, 1}, yv^(-1)]*G[{0, 1}, yw] + 
     2*G[{1}, yw]*G[{0, 1}, yv^(-1)]*G[{0, 1}, yw] + 
     2*G[{yu}, yv^(-1)]*G[{0, 1}, yv^(-1)]*G[{0, 1}, yw] - 
     G[{0}, yu^(-1)]*G[{0, 1}, yw]^2 - G[{0}, yv^(-1)]*G[{0, 1}, yw]^2 + 
     G[{0}, yw]*G[{0, 1}, yw]^2 + 2*G[{1}, yu^(-1)]*G[{0, 1}, yw]^2 + 
     G[{1}, yv^(-1)]*G[{0, 1}, yw]^2 - G[{yu}, yv^(-1)]*G[{0, 1}, yw]^2 - 
     G[{1/(yu*yv)}, yw]*G[{0, 1}, yw]^2 - 
     (Pi^2*G[{1}, yu^(-1)]*G[{0, yu^(-1)}, yw])/3 - 
     G[{0}, yu^(-1)]^2*G[{1}, yu^(-1)]*G[{0, yu^(-1)}, yw] - 
     2*G[{0}, yu^(-1)]*G[{0}, yv^(-1)]*G[{1}, yu^(-1)]*G[{0, yu^(-1)}, yw] - 
     G[{0}, yv^(-1)]^2*G[{1}, yu^(-1)]*G[{0, yu^(-1)}, yw] + 
     2*G[{0}, yu^(-1)]*G[{0}, yw]*G[{1}, yu^(-1)]*G[{0, yu^(-1)}, yw] + 
     2*G[{0}, yv^(-1)]*G[{0}, yw]*G[{1}, yu^(-1)]*G[{0, yu^(-1)}, yw] - 
     G[{0}, yw]^2*G[{1}, yu^(-1)]*G[{0, yu^(-1)}, yw] + 
     G[{0}, yu^(-1)]*G[{1}, yu^(-1)]^2*G[{0, yu^(-1)}, yw] + 
     G[{0}, yv^(-1)]*G[{1}, yu^(-1)]^2*G[{0, yu^(-1)}, yw] - 
     G[{0}, yw]*G[{1}, yu^(-1)]^2*G[{0, yu^(-1)}, yw] + 
     (Pi^2*G[{1}, yv^(-1)]*G[{0, yu^(-1)}, yw])/3 + 
     G[{0}, yu^(-1)]^2*G[{1}, yv^(-1)]*G[{0, yu^(-1)}, yw] + 
     2*G[{0}, yu^(-1)]*G[{0}, yv^(-1)]*G[{1}, yv^(-1)]*G[{0, yu^(-1)}, yw] + 
     G[{0}, yv^(-1)]^2*G[{1}, yv^(-1)]*G[{0, yu^(-1)}, yw] - 
     2*G[{0}, yu^(-1)]*G[{0}, yw]*G[{1}, yv^(-1)]*G[{0, yu^(-1)}, yw] - 
     2*G[{0}, yv^(-1)]*G[{0}, yw]*G[{1}, yv^(-1)]*G[{0, yu^(-1)}, yw] + 
     G[{0}, yw]^2*G[{1}, yv^(-1)]*G[{0, yu^(-1)}, yw] + 
     2*G[{0}, yu^(-1)]*G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*G[{0, yu^(-1)}, yw] + 
     2*G[{0}, yv^(-1)]*G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*G[{0, yu^(-1)}, yw] - 
     2*G[{0}, yw]*G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*G[{0, yu^(-1)}, yw] - 
     2*G[{1}, yu^(-1)]^2*G[{1}, yv^(-1)]*G[{0, yu^(-1)}, yw] - 
     2*G[{0}, yu^(-1)]*G[{1}, yv^(-1)]^2*G[{0, yu^(-1)}, yw] - 
     2*G[{0}, yv^(-1)]*G[{1}, yv^(-1)]^2*G[{0, yu^(-1)}, yw] + 
     2*G[{0}, yw]*G[{1}, yv^(-1)]^2*G[{0, yu^(-1)}, yw] - 
     2*G[{1}, yu^(-1)]*G[{1}, yv^(-1)]^2*G[{0, yu^(-1)}, yw] + 
     G[{1}, yv^(-1)]^3*G[{0, yu^(-1)}, yw] - 
     (2*Pi^2*G[{1}, yw]*G[{0, yu^(-1)}, yw])/3 - G[{0}, yu^(-1)]^2*G[{1}, yw]*
      G[{0, yu^(-1)}, yw] - 2*G[{0}, yu^(-1)]*G[{0}, yv^(-1)]*G[{1}, yw]*
      G[{0, yu^(-1)}, yw] - G[{0}, yv^(-1)]^2*G[{1}, yw]*
      G[{0, yu^(-1)}, yw] + 2*G[{0}, yu^(-1)]*G[{0}, yw]*G[{1}, yw]*
      G[{0, yu^(-1)}, yw] + 2*G[{0}, yv^(-1)]*G[{0}, yw]*G[{1}, yw]*
      G[{0, yu^(-1)}, yw] - G[{0}, yw]^2*G[{1}, yw]*G[{0, yu^(-1)}, yw] + 
     4*G[{0}, yu^(-1)]*G[{1}, yv^(-1)]*G[{1}, yw]*G[{0, yu^(-1)}, yw] + 
     4*G[{0}, yv^(-1)]*G[{1}, yv^(-1)]*G[{1}, yw]*G[{0, yu^(-1)}, yw] - 
     4*G[{0}, yw]*G[{1}, yv^(-1)]*G[{1}, yw]*G[{0, yu^(-1)}, yw] - 
     3*G[{1}, yv^(-1)]^2*G[{1}, yw]*G[{0, yu^(-1)}, yw] - 
     G[{0}, yu^(-1)]*G[{1}, yw]^2*G[{0, yu^(-1)}, yw] - 
     G[{0}, yv^(-1)]*G[{1}, yw]^2*G[{0, yu^(-1)}, yw] + 
     G[{0}, yw]*G[{1}, yw]^2*G[{0, yu^(-1)}, yw] + 
     2*G[{1}, yv^(-1)]*G[{1}, yw]^2*G[{0, yu^(-1)}, yw] + 
     (Pi^2*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1)}, yw])/3 + 
     G[{0}, yu^(-1)]^2*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1)}, yw] + 
     2*G[{0}, yu^(-1)]*G[{0}, yv^(-1)]*G[{1/(yu*yv)}, yw]*
      G[{0, yu^(-1)}, yw] + G[{0}, yv^(-1)]^2*G[{1/(yu*yv)}, yw]*
      G[{0, yu^(-1)}, yw] - 2*G[{0}, yu^(-1)]*G[{0}, yw]*G[{1/(yu*yv)}, yw]*
      G[{0, yu^(-1)}, yw] - 2*G[{0}, yv^(-1)]*G[{0}, yw]*G[{1/(yu*yv)}, yw]*
      G[{0, yu^(-1)}, yw] + G[{0}, yw]^2*G[{1/(yu*yv)}, yw]*
      G[{0, yu^(-1)}, yw] - 2*G[{0}, yu^(-1)]*G[{1}, yu^(-1)]*
      G[{1/(yu*yv)}, yw]*G[{0, yu^(-1)}, yw] - 2*G[{0}, yv^(-1)]*
      G[{1}, yu^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1)}, yw] + 
     2*G[{0}, yw]*G[{1}, yu^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1)}, yw] - 
     2*G[{0}, yu^(-1)]*G[{1}, yv^(-1)]*G[{1/(yu*yv)}, yw]*
      G[{0, yu^(-1)}, yw] - 2*G[{0}, yv^(-1)]*G[{1}, yv^(-1)]*
      G[{1/(yu*yv)}, yw]*G[{0, yu^(-1)}, yw] + 2*G[{0}, yw]*G[{1}, yv^(-1)]*
      G[{1/(yu*yv)}, yw]*G[{0, yu^(-1)}, yw] + 4*G[{1}, yu^(-1)]*
      G[{1}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1)}, yw] + 
     G[{1}, yv^(-1)]^2*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1)}, yw] + 
     G[{0}, yu^(-1)]*G[{1/(yu*yv)}, yw]^2*G[{0, yu^(-1)}, yw] + 
     G[{0}, yv^(-1)]*G[{1/(yu*yv)}, yw]^2*G[{0, yu^(-1)}, yw] - 
     G[{0}, yw]*G[{1/(yu*yv)}, yw]^2*G[{0, yu^(-1)}, yw] - 
     2*G[{1}, yv^(-1)]*G[{1/(yu*yv)}, yw]^2*G[{0, yu^(-1)}, yw] + 
     2*G[{0}, yu^(-1)]*G[{0, 1}, yu^(-1)]*G[{0, yu^(-1)}, yw] + 
     2*G[{0}, yv^(-1)]*G[{0, 1}, yu^(-1)]*G[{0, yu^(-1)}, yw] - 
     2*G[{0}, yw]*G[{0, 1}, yu^(-1)]*G[{0, yu^(-1)}, yw] - 
     2*G[{1}, yu^(-1)]*G[{0, 1}, yu^(-1)]*G[{0, yu^(-1)}, yw] - 
     2*G[{1}, yv^(-1)]*G[{0, 1}, yu^(-1)]*G[{0, yu^(-1)}, yw] + 
     2*G[{1/(yu*yv)}, yw]*G[{0, 1}, yu^(-1)]*G[{0, yu^(-1)}, yw] - 
     2*G[{1}, yw]*G[{0, 1}, yv^(-1)]*G[{0, yu^(-1)}, yw] + 
     2*G[{0}, yu^(-1)]*G[{0, 1}, yw]*G[{0, yu^(-1)}, yw] + 
     2*G[{0}, yv^(-1)]*G[{0, 1}, yw]*G[{0, yu^(-1)}, yw] - 
     2*G[{0}, yw]*G[{0, 1}, yw]*G[{0, yu^(-1)}, yw] - 
     4*G[{1}, yu^(-1)]*G[{0, 1}, yw]*G[{0, yu^(-1)}, yw] + 
     2*G[{1/(yu*yv)}, yw]*G[{0, 1}, yw]*G[{0, yu^(-1)}, yw] - 
     G[{0}, yu^(-1)]*G[{0, yu^(-1)}, yw]^2 - G[{0}, yv^(-1)]*
      G[{0, yu^(-1)}, yw]^2 + G[{0}, yw]*G[{0, yu^(-1)}, yw]^2 + 
     2*G[{1}, yu^(-1)]*G[{0, yu^(-1)}, yw]^2 - G[{1/(yu*yv)}, yw]*
      G[{0, yu^(-1)}, yw]^2 - (Pi^2*G[{1}, yu^(-1)]*G[{0, yu}, yv^(-1)])/3 - 
     G[{0}, yu^(-1)]^2*G[{1}, yu^(-1)]*G[{0, yu}, yv^(-1)] - 
     2*G[{0}, yu^(-1)]*G[{0}, yv^(-1)]*G[{1}, yu^(-1)]*G[{0, yu}, yv^(-1)] - 
     G[{0}, yv^(-1)]^2*G[{1}, yu^(-1)]*G[{0, yu}, yv^(-1)] + 
     2*G[{0}, yu^(-1)]*G[{0}, yw]*G[{1}, yu^(-1)]*G[{0, yu}, yv^(-1)] + 
     2*G[{0}, yv^(-1)]*G[{0}, yw]*G[{1}, yu^(-1)]*G[{0, yu}, yv^(-1)] - 
     G[{0}, yw]^2*G[{1}, yu^(-1)]*G[{0, yu}, yv^(-1)] + 
     G[{0}, yu^(-1)]*G[{1}, yu^(-1)]^2*G[{0, yu}, yv^(-1)] + 
     G[{0}, yv^(-1)]*G[{1}, yu^(-1)]^2*G[{0, yu}, yv^(-1)] - 
     G[{0}, yw]*G[{1}, yu^(-1)]^2*G[{0, yu}, yv^(-1)] + 
     (2*Pi^2*G[{1}, yv^(-1)]*G[{0, yu}, yv^(-1)])/3 + 
     G[{0}, yu^(-1)]^2*G[{1}, yv^(-1)]*G[{0, yu}, yv^(-1)] + 
     2*G[{0}, yu^(-1)]*G[{0}, yv^(-1)]*G[{1}, yv^(-1)]*G[{0, yu}, yv^(-1)] + 
     G[{0}, yv^(-1)]^2*G[{1}, yv^(-1)]*G[{0, yu}, yv^(-1)] - 
     2*G[{0}, yu^(-1)]*G[{0}, yw]*G[{1}, yv^(-1)]*G[{0, yu}, yv^(-1)] - 
     2*G[{0}, yv^(-1)]*G[{0}, yw]*G[{1}, yv^(-1)]*G[{0, yu}, yv^(-1)] + 
     G[{0}, yw]^2*G[{1}, yv^(-1)]*G[{0, yu}, yv^(-1)] - 
     G[{0}, yu^(-1)]*G[{1}, yv^(-1)]^2*G[{0, yu}, yv^(-1)] - 
     G[{0}, yv^(-1)]*G[{1}, yv^(-1)]^2*G[{0, yu}, yv^(-1)] + 
     G[{0}, yw]*G[{1}, yv^(-1)]^2*G[{0, yu}, yv^(-1)] - 
     (2*Pi^2*G[{1}, yw]*G[{0, yu}, yv^(-1)])/3 - G[{0}, yu^(-1)]^2*G[{1}, yw]*
      G[{0, yu}, yv^(-1)] - 2*G[{0}, yu^(-1)]*G[{0}, yv^(-1)]*G[{1}, yw]*
      G[{0, yu}, yv^(-1)] - G[{0}, yv^(-1)]^2*G[{1}, yw]*
      G[{0, yu}, yv^(-1)] + 2*G[{0}, yu^(-1)]*G[{0}, yw]*G[{1}, yw]*
      G[{0, yu}, yv^(-1)] + 2*G[{0}, yv^(-1)]*G[{0}, yw]*G[{1}, yw]*
      G[{0, yu}, yv^(-1)] - G[{0}, yw]^2*G[{1}, yw]*G[{0, yu}, yv^(-1)] + 
     2*G[{0}, yu^(-1)]*G[{1}, yv^(-1)]*G[{1}, yw]*G[{0, yu}, yv^(-1)] + 
     2*G[{0}, yv^(-1)]*G[{1}, yv^(-1)]*G[{1}, yw]*G[{0, yu}, yv^(-1)] - 
     2*G[{0}, yw]*G[{1}, yv^(-1)]*G[{1}, yw]*G[{0, yu}, yv^(-1)] - 
     G[{0}, yu^(-1)]*G[{1}, yw]^2*G[{0, yu}, yv^(-1)] - 
     G[{0}, yv^(-1)]*G[{1}, yw]^2*G[{0, yu}, yv^(-1)] + 
     G[{0}, yw]*G[{1}, yw]^2*G[{0, yu}, yv^(-1)] + 
     (Pi^2*G[{1/(yu*yv)}, yw]*G[{0, yu}, yv^(-1)])/3 + 
     G[{0}, yu^(-1)]^2*G[{1/(yu*yv)}, yw]*G[{0, yu}, yv^(-1)] + 
     2*G[{0}, yu^(-1)]*G[{0}, yv^(-1)]*G[{1/(yu*yv)}, yw]*
      G[{0, yu}, yv^(-1)] + G[{0}, yv^(-1)]^2*G[{1/(yu*yv)}, yw]*
      G[{0, yu}, yv^(-1)] - 2*G[{0}, yu^(-1)]*G[{0}, yw]*G[{1/(yu*yv)}, yw]*
      G[{0, yu}, yv^(-1)] - 2*G[{0}, yv^(-1)]*G[{0}, yw]*G[{1/(yu*yv)}, yw]*
      G[{0, yu}, yv^(-1)] + G[{0}, yw]^2*G[{1/(yu*yv)}, yw]*
      G[{0, yu}, yv^(-1)] - 2*G[{0}, yu^(-1)]*G[{1}, yu^(-1)]*
      G[{1/(yu*yv)}, yw]*G[{0, yu}, yv^(-1)] - 2*G[{0}, yv^(-1)]*
      G[{1}, yu^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, yu}, yv^(-1)] + 
     2*G[{0}, yw]*G[{1}, yu^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, yu}, yv^(-1)] + 
     G[{0}, yu^(-1)]*G[{1/(yu*yv)}, yw]^2*G[{0, yu}, yv^(-1)] + 
     G[{0}, yv^(-1)]*G[{1/(yu*yv)}, yw]^2*G[{0, yu}, yv^(-1)] - 
     G[{0}, yw]*G[{1/(yu*yv)}, yw]^2*G[{0, yu}, yv^(-1)] + 
     2*G[{0}, yu^(-1)]*G[{0, 1}, yu^(-1)]*G[{0, yu}, yv^(-1)] + 
     2*G[{0}, yv^(-1)]*G[{0, 1}, yu^(-1)]*G[{0, yu}, yv^(-1)] - 
     2*G[{0}, yw]*G[{0, 1}, yu^(-1)]*G[{0, yu}, yv^(-1)] - 
     2*G[{1}, yu^(-1)]*G[{0, 1}, yu^(-1)]*G[{0, yu}, yv^(-1)] + 
     2*G[{1/(yu*yv)}, yw]*G[{0, 1}, yu^(-1)]*G[{0, yu}, yv^(-1)] + 
     2*G[{1}, yv^(-1)]*G[{0, 1}, yv^(-1)]*G[{0, yu}, yv^(-1)] - 
     2*G[{1}, yw]*G[{0, 1}, yv^(-1)]*G[{0, yu}, yv^(-1)] + 
     2*G[{1}, yv^(-1)]*G[{0, 1}, yw]*G[{0, yu}, yv^(-1)] - 
     2*G[{1}, yw]*G[{0, 1}, yw]*G[{0, yu}, yv^(-1)] - 
     2*G[{yu}, yv^(-1)]*G[{0, 1}, yw]*G[{0, yu}, yv^(-1)] + 
     2*G[{1}, yw]*G[{0, yu^(-1)}, yw]*G[{0, yu}, yv^(-1)] - 
     G[{1}, yv^(-1)]*G[{0, yu}, yv^(-1)]^2 + 
     G[{1}, yw]*G[{0, yu}, yv^(-1)]^2 + 
     (Pi^2*G[{0}, yu^(-1)]*G[{0, yv^(-1)}, yw])/3 + 
     (Pi^2*G[{0}, yv^(-1)]*G[{0, yv^(-1)}, yw])/3 - 
     (Pi^2*G[{0}, yw]*G[{0, yv^(-1)}, yw])/3 - Pi^2*G[{1}, yu^(-1)]*
      G[{0, yv^(-1)}, yw] - G[{0}, yu^(-1)]^2*G[{1}, yu^(-1)]*
      G[{0, yv^(-1)}, yw] - 2*G[{0}, yu^(-1)]*G[{0}, yv^(-1)]*G[{1}, yu^(-1)]*
      G[{0, yv^(-1)}, yw] - G[{0}, yv^(-1)]^2*G[{1}, yu^(-1)]*
      G[{0, yv^(-1)}, yw] + 2*G[{0}, yu^(-1)]*G[{0}, yw]*G[{1}, yu^(-1)]*
      G[{0, yv^(-1)}, yw] + 2*G[{0}, yv^(-1)]*G[{0}, yw]*G[{1}, yu^(-1)]*
      G[{0, yv^(-1)}, yw] - G[{0}, yw]^2*G[{1}, yu^(-1)]*
      G[{0, yv^(-1)}, yw] + 3*G[{0}, yu^(-1)]*G[{1}, yu^(-1)]^2*
      G[{0, yv^(-1)}, yw] + 3*G[{0}, yv^(-1)]*G[{1}, yu^(-1)]^2*
      G[{0, yv^(-1)}, yw] - 3*G[{0}, yw]*G[{1}, yu^(-1)]^2*
      G[{0, yv^(-1)}, yw] - 2*G[{1}, yu^(-1)]^3*G[{0, yv^(-1)}, yw] + 
     (Pi^2*G[{1}, yv^(-1)]*G[{0, yv^(-1)}, yw])/3 + 
     G[{0}, yu^(-1)]^2*G[{1}, yv^(-1)]*G[{0, yv^(-1)}, yw] + 
     2*G[{0}, yu^(-1)]*G[{0}, yv^(-1)]*G[{1}, yv^(-1)]*G[{0, yv^(-1)}, yw] + 
     G[{0}, yv^(-1)]^2*G[{1}, yv^(-1)]*G[{0, yv^(-1)}, yw] - 
     2*G[{0}, yu^(-1)]*G[{0}, yw]*G[{1}, yv^(-1)]*G[{0, yv^(-1)}, yw] - 
     2*G[{0}, yv^(-1)]*G[{0}, yw]*G[{1}, yv^(-1)]*G[{0, yv^(-1)}, yw] + 
     G[{0}, yw]^2*G[{1}, yv^(-1)]*G[{0, yv^(-1)}, yw] - 
     2*G[{0}, yu^(-1)]*G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*G[{0, yv^(-1)}, yw] - 
     2*G[{0}, yv^(-1)]*G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*G[{0, yv^(-1)}, yw] + 
     2*G[{0}, yw]*G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*G[{0, yv^(-1)}, yw] - 
     2*G[{0}, yu^(-1)]*G[{1}, yv^(-1)]^2*G[{0, yv^(-1)}, yw] - 
     2*G[{0}, yv^(-1)]*G[{1}, yv^(-1)]^2*G[{0, yv^(-1)}, yw] + 
     2*G[{0}, yw]*G[{1}, yv^(-1)]^2*G[{0, yv^(-1)}, yw] + 
     4*G[{1}, yu^(-1)]*G[{1}, yv^(-1)]^2*G[{0, yv^(-1)}, yw] + 
     G[{1}, yv^(-1)]^3*G[{0, yv^(-1)}, yw] - 
     (Pi^2*G[{1}, yw]*G[{0, yv^(-1)}, yw])/3 - G[{0}, yu^(-1)]^2*G[{1}, yw]*
      G[{0, yv^(-1)}, yw] - 2*G[{0}, yu^(-1)]*G[{0}, yv^(-1)]*G[{1}, yw]*
      G[{0, yv^(-1)}, yw] - G[{0}, yv^(-1)]^2*G[{1}, yw]*
      G[{0, yv^(-1)}, yw] + 2*G[{0}, yu^(-1)]*G[{0}, yw]*G[{1}, yw]*
      G[{0, yv^(-1)}, yw] + 2*G[{0}, yv^(-1)]*G[{0}, yw]*G[{1}, yw]*
      G[{0, yv^(-1)}, yw] - G[{0}, yw]^2*G[{1}, yw]*G[{0, yv^(-1)}, yw] + 
     2*G[{0}, yu^(-1)]*G[{1}, yu^(-1)]*G[{1}, yw]*G[{0, yv^(-1)}, yw] + 
     2*G[{0}, yv^(-1)]*G[{1}, yu^(-1)]*G[{1}, yw]*G[{0, yv^(-1)}, yw] - 
     2*G[{0}, yw]*G[{1}, yu^(-1)]*G[{1}, yw]*G[{0, yv^(-1)}, yw] + 
     2*G[{0}, yu^(-1)]*G[{1}, yv^(-1)]*G[{1}, yw]*G[{0, yv^(-1)}, yw] + 
     2*G[{0}, yv^(-1)]*G[{1}, yv^(-1)]*G[{1}, yw]*G[{0, yv^(-1)}, yw] - 
     2*G[{0}, yw]*G[{1}, yv^(-1)]*G[{1}, yw]*G[{0, yv^(-1)}, yw] - 
     4*G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*G[{1}, yw]*G[{0, yv^(-1)}, yw] - 
     G[{1}, yv^(-1)]^2*G[{1}, yw]*G[{0, yv^(-1)}, yw] - 
     G[{0}, yu^(-1)]*G[{1}, yw]^2*G[{0, yv^(-1)}, yw] - 
     G[{0}, yv^(-1)]*G[{1}, yw]^2*G[{0, yv^(-1)}, yw] + 
     G[{0}, yw]*G[{1}, yw]^2*G[{0, yv^(-1)}, yw] + 
     2*G[{1}, yu^(-1)]*G[{1}, yw]^2*G[{0, yv^(-1)}, yw] + 
     (2*Pi^2*G[{1/(yu*yv)}, yw]*G[{0, yv^(-1)}, yw])/3 + 
     G[{0}, yu^(-1)]^2*G[{1/(yu*yv)}, yw]*G[{0, yv^(-1)}, yw] + 
     2*G[{0}, yu^(-1)]*G[{0}, yv^(-1)]*G[{1/(yu*yv)}, yw]*
      G[{0, yv^(-1)}, yw] + G[{0}, yv^(-1)]^2*G[{1/(yu*yv)}, yw]*
      G[{0, yv^(-1)}, yw] - 2*G[{0}, yu^(-1)]*G[{0}, yw]*G[{1/(yu*yv)}, yw]*
      G[{0, yv^(-1)}, yw] - 2*G[{0}, yv^(-1)]*G[{0}, yw]*G[{1/(yu*yv)}, yw]*
      G[{0, yv^(-1)}, yw] + G[{0}, yw]^2*G[{1/(yu*yv)}, yw]*
      G[{0, yv^(-1)}, yw] - 4*G[{0}, yu^(-1)]*G[{1}, yu^(-1)]*
      G[{1/(yu*yv)}, yw]*G[{0, yv^(-1)}, yw] - 4*G[{0}, yv^(-1)]*
      G[{1}, yu^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, yv^(-1)}, yw] + 
     4*G[{0}, yw]*G[{1}, yu^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, yv^(-1)}, yw] + 
     4*G[{1}, yu^(-1)]^2*G[{1/(yu*yv)}, yw]*G[{0, yv^(-1)}, yw] - 
     G[{1}, yv^(-1)]^2*G[{1/(yu*yv)}, yw]*G[{0, yv^(-1)}, yw] + 
     G[{0}, yu^(-1)]*G[{1/(yu*yv)}, yw]^2*G[{0, yv^(-1)}, yw] + 
     G[{0}, yv^(-1)]*G[{1/(yu*yv)}, yw]^2*G[{0, yv^(-1)}, yw] - 
     G[{0}, yw]*G[{1/(yu*yv)}, yw]^2*G[{0, yv^(-1)}, yw] - 
     2*G[{1}, yu^(-1)]*G[{1/(yu*yv)}, yw]^2*G[{0, yv^(-1)}, yw] - 
     2*G[{1}, yu^(-1)]*G[{0, 1}, yu^(-1)]*G[{0, yv^(-1)}, yw] + 
     2*G[{1}, yv^(-1)]*G[{0, 1}, yu^(-1)]*G[{0, yv^(-1)}, yw] - 
     2*G[{1}, yw]*G[{0, 1}, yu^(-1)]*G[{0, yv^(-1)}, yw] + 
     2*G[{0}, yu^(-1)]*G[{0, 1}, yv^(-1)]*G[{0, yv^(-1)}, yw] + 
     2*G[{0}, yv^(-1)]*G[{0, 1}, yv^(-1)]*G[{0, yv^(-1)}, yw] - 
     2*G[{0}, yw]*G[{0, 1}, yv^(-1)]*G[{0, yv^(-1)}, yw] - 
     4*G[{1}, yu^(-1)]*G[{0, 1}, yv^(-1)]*G[{0, yv^(-1)}, yw] + 
     2*G[{1/(yu*yv)}, yw]*G[{0, 1}, yv^(-1)]*G[{0, yv^(-1)}, yw] - 
     2*G[{1}, yw]*G[{0, 1}, yw]*G[{0, yv^(-1)}, yw] + 
     2*G[{1}, yw]*G[{0, yu^(-1)}, yw]*G[{0, yv^(-1)}, yw] - 
     2*G[{0}, yu^(-1)]*G[{0, yu}, yv^(-1)]*G[{0, yv^(-1)}, yw] - 
     2*G[{0}, yv^(-1)]*G[{0, yu}, yv^(-1)]*G[{0, yv^(-1)}, yw] + 
     2*G[{0}, yw]*G[{0, yu}, yv^(-1)]*G[{0, yv^(-1)}, yw] + 
     4*G[{1}, yu^(-1)]*G[{0, yu}, yv^(-1)]*G[{0, yv^(-1)}, yw] - 
     2*G[{1/(yu*yv)}, yw]*G[{0, yu}, yv^(-1)]*G[{0, yv^(-1)}, yw] + 
     G[{1}, yw]*G[{0, yv^(-1)}, yw]^2 - 
     (Pi^2*G[{0}, yu^(-1)]*G[{0, 1/(yu*yv)}, yw])/3 - 
     (Pi^2*G[{0}, yv^(-1)]*G[{0, 1/(yu*yv)}, yw])/3 + 
     (Pi^2*G[{0}, yw]*G[{0, 1/(yu*yv)}, yw])/3 + Pi^2*G[{1}, yu^(-1)]*
      G[{0, 1/(yu*yv)}, yw] + G[{0}, yu^(-1)]^2*G[{1}, yu^(-1)]*
      G[{0, 1/(yu*yv)}, yw] + 2*G[{0}, yu^(-1)]*G[{0}, yv^(-1)]*
      G[{1}, yu^(-1)]*G[{0, 1/(yu*yv)}, yw] + G[{0}, yv^(-1)]^2*
      G[{1}, yu^(-1)]*G[{0, 1/(yu*yv)}, yw] - 2*G[{0}, yu^(-1)]*G[{0}, yw]*
      G[{1}, yu^(-1)]*G[{0, 1/(yu*yv)}, yw] - 2*G[{0}, yv^(-1)]*G[{0}, yw]*
      G[{1}, yu^(-1)]*G[{0, 1/(yu*yv)}, yw] + G[{0}, yw]^2*G[{1}, yu^(-1)]*
      G[{0, 1/(yu*yv)}, yw] - 3*G[{0}, yu^(-1)]*G[{1}, yu^(-1)]^2*
      G[{0, 1/(yu*yv)}, yw] - 3*G[{0}, yv^(-1)]*G[{1}, yu^(-1)]^2*
      G[{0, 1/(yu*yv)}, yw] + 3*G[{0}, yw]*G[{1}, yu^(-1)]^2*
      G[{0, 1/(yu*yv)}, yw] + 2*G[{1}, yu^(-1)]^3*G[{0, 1/(yu*yv)}, yw] - 
     G[{0}, yu^(-1)]^2*G[{1}, yv^(-1)]*G[{0, 1/(yu*yv)}, yw] - 
     2*G[{0}, yu^(-1)]*G[{0}, yv^(-1)]*G[{1}, yv^(-1)]*
      G[{0, 1/(yu*yv)}, yw] - G[{0}, yv^(-1)]^2*G[{1}, yv^(-1)]*
      G[{0, 1/(yu*yv)}, yw] + 2*G[{0}, yu^(-1)]*G[{0}, yw]*G[{1}, yv^(-1)]*
      G[{0, 1/(yu*yv)}, yw] + 2*G[{0}, yv^(-1)]*G[{0}, yw]*G[{1}, yv^(-1)]*
      G[{0, 1/(yu*yv)}, yw] - G[{0}, yw]^2*G[{1}, yv^(-1)]*
      G[{0, 1/(yu*yv)}, yw] + 2*G[{1}, yu^(-1)]^2*G[{1}, yv^(-1)]*
      G[{0, 1/(yu*yv)}, yw] + 2*G[{0}, yu^(-1)]*G[{1}, yv^(-1)]^2*
      G[{0, 1/(yu*yv)}, yw] + 2*G[{0}, yv^(-1)]*G[{1}, yv^(-1)]^2*
      G[{0, 1/(yu*yv)}, yw] - 2*G[{0}, yw]*G[{1}, yv^(-1)]^2*
      G[{0, 1/(yu*yv)}, yw] - G[{1}, yv^(-1)]^3*G[{0, 1/(yu*yv)}, yw] + 
     (Pi^2*G[{1}, yw]*G[{0, 1/(yu*yv)}, yw])/3 + G[{0}, yu^(-1)]^2*G[{1}, yw]*
      G[{0, 1/(yu*yv)}, yw] + 2*G[{0}, yu^(-1)]*G[{0}, yv^(-1)]*G[{1}, yw]*
      G[{0, 1/(yu*yv)}, yw] + G[{0}, yv^(-1)]^2*G[{1}, yw]*
      G[{0, 1/(yu*yv)}, yw] - 2*G[{0}, yu^(-1)]*G[{0}, yw]*G[{1}, yw]*
      G[{0, 1/(yu*yv)}, yw] - 2*G[{0}, yv^(-1)]*G[{0}, yw]*G[{1}, yw]*
      G[{0, 1/(yu*yv)}, yw] + G[{0}, yw]^2*G[{1}, yw]*G[{0, 1/(yu*yv)}, yw] - 
     2*G[{0}, yu^(-1)]*G[{1}, yu^(-1)]*G[{1}, yw]*G[{0, 1/(yu*yv)}, yw] - 
     2*G[{0}, yv^(-1)]*G[{1}, yu^(-1)]*G[{1}, yw]*G[{0, 1/(yu*yv)}, yw] + 
     2*G[{0}, yw]*G[{1}, yu^(-1)]*G[{1}, yw]*G[{0, 1/(yu*yv)}, yw] - 
     4*G[{0}, yu^(-1)]*G[{1}, yv^(-1)]*G[{1}, yw]*G[{0, 1/(yu*yv)}, yw] - 
     4*G[{0}, yv^(-1)]*G[{1}, yv^(-1)]*G[{1}, yw]*G[{0, 1/(yu*yv)}, yw] + 
     4*G[{0}, yw]*G[{1}, yv^(-1)]*G[{1}, yw]*G[{0, 1/(yu*yv)}, yw] + 
     4*G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*G[{1}, yw]*G[{0, 1/(yu*yv)}, yw] + 
     3*G[{1}, yv^(-1)]^2*G[{1}, yw]*G[{0, 1/(yu*yv)}, yw] + 
     G[{0}, yu^(-1)]*G[{1}, yw]^2*G[{0, 1/(yu*yv)}, yw] + 
     G[{0}, yv^(-1)]*G[{1}, yw]^2*G[{0, 1/(yu*yv)}, yw] - 
     G[{0}, yw]*G[{1}, yw]^2*G[{0, 1/(yu*yv)}, yw] - 
     2*G[{1}, yu^(-1)]*G[{1}, yw]^2*G[{0, 1/(yu*yv)}, yw] - 
     2*G[{1}, yv^(-1)]*G[{1}, yw]^2*G[{0, 1/(yu*yv)}, yw] - 
     (Pi^2*G[{yu}, yv^(-1)]*G[{0, 1/(yu*yv)}, yw])/3 + 
     2*G[{0}, yu^(-1)]*G[{1}, yu^(-1)]*G[{yu}, yv^(-1)]*
      G[{0, 1/(yu*yv)}, yw] + 2*G[{0}, yv^(-1)]*G[{1}, yu^(-1)]*
      G[{yu}, yv^(-1)]*G[{0, 1/(yu*yv)}, yw] - 2*G[{0}, yw]*G[{1}, yu^(-1)]*
      G[{yu}, yv^(-1)]*G[{0, 1/(yu*yv)}, yw] - 2*G[{1}, yu^(-1)]^2*
      G[{yu}, yv^(-1)]*G[{0, 1/(yu*yv)}, yw] + 2*G[{0}, yu^(-1)]*
      G[{1}, yv^(-1)]*G[{yu}, yv^(-1)]*G[{0, 1/(yu*yv)}, yw] + 
     2*G[{0}, yv^(-1)]*G[{1}, yv^(-1)]*G[{yu}, yv^(-1)]*
      G[{0, 1/(yu*yv)}, yw] - 2*G[{0}, yw]*G[{1}, yv^(-1)]*G[{yu}, yv^(-1)]*
      G[{0, 1/(yu*yv)}, yw] - 8*G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*
      G[{yu}, yv^(-1)]*G[{0, 1/(yu*yv)}, yw] - 2*G[{1}, yv^(-1)]^2*
      G[{yu}, yv^(-1)]*G[{0, 1/(yu*yv)}, yw] + 2*G[{0}, yu^(-1)]*G[{1}, yw]*
      G[{yu}, yv^(-1)]*G[{0, 1/(yu*yv)}, yw] + 2*G[{0}, yv^(-1)]*G[{1}, yw]*
      G[{yu}, yv^(-1)]*G[{0, 1/(yu*yv)}, yw] - 2*G[{0}, yw]*G[{1}, yw]*
      G[{yu}, yv^(-1)]*G[{0, 1/(yu*yv)}, yw] + 2*G[{1}, yw]^2*
      G[{yu}, yv^(-1)]*G[{0, 1/(yu*yv)}, yw] - 2*G[{0}, yu^(-1)]*
      G[{yu}, yv^(-1)]^2*G[{0, 1/(yu*yv)}, yw] - 2*G[{0}, yv^(-1)]*
      G[{yu}, yv^(-1)]^2*G[{0, 1/(yu*yv)}, yw] + 
     2*G[{0}, yw]*G[{yu}, yv^(-1)]^2*G[{0, 1/(yu*yv)}, yw] + 
     4*G[{1}, yu^(-1)]*G[{yu}, yv^(-1)]^2*G[{0, 1/(yu*yv)}, yw] + 
     4*G[{1}, yv^(-1)]*G[{yu}, yv^(-1)]^2*G[{0, 1/(yu*yv)}, yw] - 
     2*G[{1}, yw]*G[{yu}, yv^(-1)]^2*G[{0, 1/(yu*yv)}, yw] - 
     (4*G[{yu}, yv^(-1)]^3*G[{0, 1/(yu*yv)}, yw])/3 - 
     (2*Pi^2*G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv)}, yw])/3 - 
     G[{0}, yu^(-1)]^2*G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv)}, yw] - 
     2*G[{0}, yu^(-1)]*G[{0}, yv^(-1)]*G[{1/(yu*yv)}, yw]*
      G[{0, 1/(yu*yv)}, yw] - G[{0}, yv^(-1)]^2*G[{1/(yu*yv)}, yw]*
      G[{0, 1/(yu*yv)}, yw] + 2*G[{0}, yu^(-1)]*G[{0}, yw]*G[{1/(yu*yv)}, yw]*
      G[{0, 1/(yu*yv)}, yw] + 2*G[{0}, yv^(-1)]*G[{0}, yw]*G[{1/(yu*yv)}, yw]*
      G[{0, 1/(yu*yv)}, yw] - G[{0}, yw]^2*G[{1/(yu*yv)}, yw]*
      G[{0, 1/(yu*yv)}, yw] + 4*G[{0}, yu^(-1)]*G[{1}, yu^(-1)]*
      G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv)}, yw] + 4*G[{0}, yv^(-1)]*
      G[{1}, yu^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv)}, yw] - 
     4*G[{0}, yw]*G[{1}, yu^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv)}, yw] - 
     4*G[{1}, yu^(-1)]^2*G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv)}, yw] + 
     2*G[{0}, yu^(-1)]*G[{1}, yv^(-1)]*G[{1/(yu*yv)}, yw]*
      G[{0, 1/(yu*yv)}, yw] + 2*G[{0}, yv^(-1)]*G[{1}, yv^(-1)]*
      G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv)}, yw] - 2*G[{0}, yw]*G[{1}, yv^(-1)]*
      G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv)}, yw] - 4*G[{1}, yu^(-1)]*
      G[{1}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv)}, yw] - 
     G[{1}, yv^(-1)]^2*G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv)}, yw] - 
     2*G[{0}, yu^(-1)]*G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw]*
      G[{0, 1/(yu*yv)}, yw] - 2*G[{0}, yv^(-1)]*G[{yu}, yv^(-1)]*
      G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv)}, yw] + 
     2*G[{0}, yw]*G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv)}, yw] + 
     4*G[{1}, yu^(-1)]*G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw]*
      G[{0, 1/(yu*yv)}, yw] + 4*G[{1}, yv^(-1)]*G[{yu}, yv^(-1)]*
      G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv)}, yw] - 2*G[{yu}, yv^(-1)]^2*
      G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv)}, yw] - 
     G[{0}, yu^(-1)]*G[{1/(yu*yv)}, yw]^2*G[{0, 1/(yu*yv)}, yw] - 
     G[{0}, yv^(-1)]*G[{1/(yu*yv)}, yw]^2*G[{0, 1/(yu*yv)}, yw] + 
     G[{0}, yw]*G[{1/(yu*yv)}, yw]^2*G[{0, 1/(yu*yv)}, yw] + 
     2*G[{1}, yu^(-1)]*G[{1/(yu*yv)}, yw]^2*G[{0, 1/(yu*yv)}, yw] + 
     2*G[{1}, yv^(-1)]*G[{1/(yu*yv)}, yw]^2*G[{0, 1/(yu*yv)}, yw] - 
     2*G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw]^2*G[{0, 1/(yu*yv)}, yw] + 
     2*G[{1}, yu^(-1)]*G[{0, 1}, yu^(-1)]*G[{0, 1/(yu*yv)}, yw] + 
     2*G[{1}, yw]*G[{0, 1}, yu^(-1)]*G[{0, 1/(yu*yv)}, yw] - 
     2*G[{yu}, yv^(-1)]*G[{0, 1}, yu^(-1)]*G[{0, 1/(yu*yv)}, yw] - 
     2*G[{0}, yu^(-1)]*G[{0, 1}, yv^(-1)]*G[{0, 1/(yu*yv)}, yw] - 
     2*G[{0}, yv^(-1)]*G[{0, 1}, yv^(-1)]*G[{0, 1/(yu*yv)}, yw] + 
     2*G[{0}, yw]*G[{0, 1}, yv^(-1)]*G[{0, 1/(yu*yv)}, yw] + 
     4*G[{1}, yu^(-1)]*G[{0, 1}, yv^(-1)]*G[{0, 1/(yu*yv)}, yw] + 
     2*G[{1}, yv^(-1)]*G[{0, 1}, yv^(-1)]*G[{0, 1/(yu*yv)}, yw] - 
     2*G[{yu}, yv^(-1)]*G[{0, 1}, yv^(-1)]*G[{0, 1/(yu*yv)}, yw] - 
     2*G[{1/(yu*yv)}, yw]*G[{0, 1}, yv^(-1)]*G[{0, 1/(yu*yv)}, yw] - 
     2*G[{1}, yv^(-1)]*G[{0, 1}, yw]*G[{0, 1/(yu*yv)}, yw] + 
     2*G[{1}, yw]*G[{0, 1}, yw]*G[{0, 1/(yu*yv)}, yw] + 
     2*G[{yu}, yv^(-1)]*G[{0, 1}, yw]*G[{0, 1/(yu*yv)}, yw] + 
     2*G[{1}, yv^(-1)]*G[{0, yu^(-1)}, yw]*G[{0, 1/(yu*yv)}, yw] - 
     2*G[{1}, yw]*G[{0, yu^(-1)}, yw]*G[{0, 1/(yu*yv)}, yw] - 
     2*G[{yu}, yv^(-1)]*G[{0, yu^(-1)}, yw]*G[{0, 1/(yu*yv)}, yw] + 
     2*G[{0}, yu^(-1)]*G[{0, yu}, yv^(-1)]*G[{0, 1/(yu*yv)}, yw] + 
     2*G[{0}, yv^(-1)]*G[{0, yu}, yv^(-1)]*G[{0, 1/(yu*yv)}, yw] - 
     2*G[{0}, yw]*G[{0, yu}, yv^(-1)]*G[{0, 1/(yu*yv)}, yw] - 
     4*G[{1}, yu^(-1)]*G[{0, yu}, yv^(-1)]*G[{0, 1/(yu*yv)}, yw] - 
     2*G[{1}, yv^(-1)]*G[{0, yu}, yv^(-1)]*G[{0, 1/(yu*yv)}, yw] + 
     2*G[{yu}, yv^(-1)]*G[{0, yu}, yv^(-1)]*G[{0, 1/(yu*yv)}, yw] + 
     2*G[{1/(yu*yv)}, yw]*G[{0, yu}, yv^(-1)]*G[{0, 1/(yu*yv)}, yw] + 
     2*G[{1}, yv^(-1)]*G[{0, yv^(-1)}, yw]*G[{0, 1/(yu*yv)}, yw] - 
     2*G[{1}, yw]*G[{0, yv^(-1)}, yw]*G[{0, 1/(yu*yv)}, yw] - 
     2*G[{yu}, yv^(-1)]*G[{0, yv^(-1)}, yw]*G[{0, 1/(yu*yv)}, yw] - 
     G[{1}, yv^(-1)]*G[{0, 1/(yu*yv)}, yw]^2 + 
     G[{1}, yw]*G[{0, 1/(yu*yv)}, yw]^2 + G[{yu}, yv^(-1)]*
      G[{0, 1/(yu*yv)}, yw]^2 + 2*G[{0}, yu^(-1)]*G[{0, 1}, yw]*
      G[{1, yu}, yv^(-1)] + 2*G[{0}, yv^(-1)]*G[{0, 1}, yw]*
      G[{1, yu}, yv^(-1)] - 2*G[{0}, yw]*G[{0, 1}, yw]*G[{1, yu}, yv^(-1)] - 
     4*G[{1}, yu^(-1)]*G[{0, 1}, yw]*G[{1, yu}, yv^(-1)] + 
     2*G[{1}, yw]*G[{0, 1}, yw]*G[{1, yu}, yv^(-1)] + 
     2*G[{1/(yu*yv)}, yw]*G[{0, 1}, yw]*G[{1, yu}, yv^(-1)] - 
     2*G[{0}, yu^(-1)]*G[{0, yu^(-1)}, yw]*G[{1, yu}, yv^(-1)] - 
     2*G[{0}, yv^(-1)]*G[{0, yu^(-1)}, yw]*G[{1, yu}, yv^(-1)] + 
     2*G[{0}, yw]*G[{0, yu^(-1)}, yw]*G[{1, yu}, yv^(-1)] + 
     4*G[{1}, yu^(-1)]*G[{0, yu^(-1)}, yw]*G[{1, yu}, yv^(-1)] + 
     4*G[{1}, yv^(-1)]*G[{0, yu^(-1)}, yw]*G[{1, yu}, yv^(-1)] - 
     2*G[{1}, yw]*G[{0, yu^(-1)}, yw]*G[{1, yu}, yv^(-1)] - 
     2*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1)}, yw]*G[{1, yu}, yv^(-1)] + 
     2*G[{0}, yu^(-1)]*G[{0, yv^(-1)}, yw]*G[{1, yu}, yv^(-1)] + 
     2*G[{0}, yv^(-1)]*G[{0, yv^(-1)}, yw]*G[{1, yu}, yv^(-1)] - 
     2*G[{0}, yw]*G[{0, yv^(-1)}, yw]*G[{1, yu}, yv^(-1)] - 
     4*G[{1}, yu^(-1)]*G[{0, yv^(-1)}, yw]*G[{1, yu}, yv^(-1)] - 
     4*G[{1}, yv^(-1)]*G[{0, yv^(-1)}, yw]*G[{1, yu}, yv^(-1)] + 
     2*G[{1}, yw]*G[{0, yv^(-1)}, yw]*G[{1, yu}, yv^(-1)] + 
     2*G[{1/(yu*yv)}, yw]*G[{0, yv^(-1)}, yw]*G[{1, yu}, yv^(-1)] - 
     2*G[{0}, yu^(-1)]*G[{0, 1/(yu*yv)}, yw]*G[{1, yu}, yv^(-1)] - 
     2*G[{0}, yv^(-1)]*G[{0, 1/(yu*yv)}, yw]*G[{1, yu}, yv^(-1)] + 
     2*G[{0}, yw]*G[{0, 1/(yu*yv)}, yw]*G[{1, yu}, yv^(-1)] + 
     4*G[{1}, yu^(-1)]*G[{0, 1/(yu*yv)}, yw]*G[{1, yu}, yv^(-1)] - 
     2*G[{1}, yw]*G[{0, 1/(yu*yv)}, yw]*G[{1, yu}, yv^(-1)] - 
     2*G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv)}, yw]*G[{1, yu}, yv^(-1)] - 
     Pi^2*G[{0, 0, 1}, yu^(-1)] - 2*G[{0}, yu^(-1)]^2*G[{0, 0, 1}, yu^(-1)] - 
     4*G[{0}, yu^(-1)]*G[{0}, yv^(-1)]*G[{0, 0, 1}, yu^(-1)] - 
     2*G[{0}, yv^(-1)]^2*G[{0, 0, 1}, yu^(-1)] + 4*G[{0}, yu^(-1)]*G[{0}, yw]*
      G[{0, 0, 1}, yu^(-1)] + 4*G[{0}, yv^(-1)]*G[{0}, yw]*
      G[{0, 0, 1}, yu^(-1)] - 2*G[{0}, yw]^2*G[{0, 0, 1}, yu^(-1)] + 
     2*G[{0}, yu^(-1)]*G[{1}, yu^(-1)]*G[{0, 0, 1}, yu^(-1)] + 
     2*G[{0}, yv^(-1)]*G[{1}, yu^(-1)]*G[{0, 0, 1}, yu^(-1)] - 
     2*G[{0}, yw]*G[{1}, yu^(-1)]*G[{0, 0, 1}, yu^(-1)] + 
     2*G[{0}, yu^(-1)]*G[{1}, yv^(-1)]*G[{0, 0, 1}, yu^(-1)] + 
     2*G[{0}, yv^(-1)]*G[{1}, yv^(-1)]*G[{0, 0, 1}, yu^(-1)] - 
     2*G[{0}, yw]*G[{1}, yv^(-1)]*G[{0, 0, 1}, yu^(-1)] - 
     2*G[{0}, yu^(-1)]*G[{1}, yw]*G[{0, 0, 1}, yu^(-1)] - 
     2*G[{0}, yv^(-1)]*G[{1}, yw]*G[{0, 0, 1}, yu^(-1)] + 
     2*G[{0}, yw]*G[{1}, yw]*G[{0, 0, 1}, yu^(-1)] - 
     2*G[{0}, yu^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, 0, 1}, yu^(-1)] - 
     2*G[{0}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, 0, 1}, yu^(-1)] + 
     2*G[{0}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 0, 1}, yu^(-1)] - 
     2*G[{0, 1}, yu^(-1)]*G[{0, 0, 1}, yu^(-1)] - 2*G[{0, 1}, yv^(-1)]*
      G[{0, 0, 1}, yu^(-1)] - 2*G[{0, 1}, yw]*G[{0, 0, 1}, yu^(-1)] + 
     2*G[{0, yu^(-1)}, yw]*G[{0, 0, 1}, yu^(-1)] + 2*G[{0, yu}, yv^(-1)]*
      G[{0, 0, 1}, yu^(-1)] + 2*G[{0, yv^(-1)}, yw]*G[{0, 0, 1}, yu^(-1)] - 
     2*G[{0, 1/(yu*yv)}, yw]*G[{0, 0, 1}, yu^(-1)] - 
     (Pi^2*G[{0, 0, 1}, yw])/3 + 2*G[{0}, yu^(-1)]*G[{1}, yu^(-1)]*
      G[{0, 0, 1}, yw] + 2*G[{0}, yv^(-1)]*G[{1}, yu^(-1)]*G[{0, 0, 1}, yw] - 
     2*G[{0}, yw]*G[{1}, yu^(-1)]*G[{0, 0, 1}, yw] - 
     2*G[{1}, yu^(-1)]^2*G[{0, 0, 1}, yw] - 2*G[{0}, yu^(-1)]*G[{1}, yv^(-1)]*
      G[{0, 0, 1}, yw] - 2*G[{0}, yv^(-1)]*G[{1}, yv^(-1)]*G[{0, 0, 1}, yw] + 
     2*G[{0}, yw]*G[{1}, yv^(-1)]*G[{0, 0, 1}, yw] + 
     2*G[{1}, yv^(-1)]^2*G[{0, 0, 1}, yw] + 2*G[{0}, yu^(-1)]*G[{1}, yw]*
      G[{0, 0, 1}, yw] + 2*G[{0}, yv^(-1)]*G[{1}, yw]*G[{0, 0, 1}, yw] - 
     2*G[{0}, yw]*G[{1}, yw]*G[{0, 0, 1}, yw] - 4*G[{1}, yv^(-1)]*G[{1}, yw]*
      G[{0, 0, 1}, yw] + 2*G[{1}, yw]^2*G[{0, 0, 1}, yw] - 
     2*G[{0}, yu^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, 0, 1}, yw] - 
     2*G[{0}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, 0, 1}, yw] + 
     2*G[{0}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 0, 1}, yw] + 
     4*G[{1}, yu^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, 0, 1}, yw] - 
     2*G[{1/(yu*yv)}, yw]^2*G[{0, 0, 1}, yw] - 2*G[{0, 1}, yu^(-1)]*
      G[{0, 0, 1}, yw] - 2*G[{0, 1}, yv^(-1)]*G[{0, 0, 1}, yw] - 
     2*G[{0, 1}, yw]*G[{0, 0, 1}, yw] + 2*G[{0, yu^(-1)}, yw]*
      G[{0, 0, 1}, yw] + 2*G[{0, yu}, yv^(-1)]*G[{0, 0, 1}, yw] + 
     2*G[{0, yv^(-1)}, yw]*G[{0, 0, 1}, yw] - 2*G[{0, 1/(yu*yv)}, yw]*
      G[{0, 0, 1}, yw] + (Pi^2*G[{0, 0, yu^(-1)}, yw])/3 - 
     2*G[{0}, yu^(-1)]*G[{1}, yu^(-1)]*G[{0, 0, yu^(-1)}, yw] - 
     2*G[{0}, yv^(-1)]*G[{1}, yu^(-1)]*G[{0, 0, yu^(-1)}, yw] + 
     2*G[{0}, yw]*G[{1}, yu^(-1)]*G[{0, 0, yu^(-1)}, yw] + 
     2*G[{1}, yu^(-1)]^2*G[{0, 0, yu^(-1)}, yw] + 
     2*G[{0}, yu^(-1)]*G[{1}, yv^(-1)]*G[{0, 0, yu^(-1)}, yw] + 
     2*G[{0}, yv^(-1)]*G[{1}, yv^(-1)]*G[{0, 0, yu^(-1)}, yw] - 
     2*G[{0}, yw]*G[{1}, yv^(-1)]*G[{0, 0, yu^(-1)}, yw] - 
     2*G[{1}, yv^(-1)]^2*G[{0, 0, yu^(-1)}, yw] - 
     2*G[{0}, yu^(-1)]*G[{1}, yw]*G[{0, 0, yu^(-1)}, yw] - 
     2*G[{0}, yv^(-1)]*G[{1}, yw]*G[{0, 0, yu^(-1)}, yw] + 
     2*G[{0}, yw]*G[{1}, yw]*G[{0, 0, yu^(-1)}, yw] + 
     4*G[{1}, yv^(-1)]*G[{1}, yw]*G[{0, 0, yu^(-1)}, yw] - 
     2*G[{1}, yw]^2*G[{0, 0, yu^(-1)}, yw] + 2*G[{0}, yu^(-1)]*
      G[{1/(yu*yv)}, yw]*G[{0, 0, yu^(-1)}, yw] + 
     2*G[{0}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, 0, yu^(-1)}, yw] - 
     2*G[{0}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 0, yu^(-1)}, yw] - 
     4*G[{1}, yu^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, 0, yu^(-1)}, yw] + 
     2*G[{1/(yu*yv)}, yw]^2*G[{0, 0, yu^(-1)}, yw] + 
     2*G[{0, 1}, yu^(-1)]*G[{0, 0, yu^(-1)}, yw] + 2*G[{0, 1}, yv^(-1)]*
      G[{0, 0, yu^(-1)}, yw] + 2*G[{0, 1}, yw]*G[{0, 0, yu^(-1)}, yw] - 
     2*G[{0, yu^(-1)}, yw]*G[{0, 0, yu^(-1)}, yw] - 
     2*G[{0, yu}, yv^(-1)]*G[{0, 0, yu^(-1)}, yw] - 
     2*G[{0, yv^(-1)}, yw]*G[{0, 0, yu^(-1)}, yw] + 
     2*G[{0, 1/(yu*yv)}, yw]*G[{0, 0, yu^(-1)}, yw] + 
     (Pi^2*G[{0, 0, yv^(-1)}, yw])/3 - 2*G[{0}, yu^(-1)]*G[{1}, yu^(-1)]*
      G[{0, 0, yv^(-1)}, yw] - 2*G[{0}, yv^(-1)]*G[{1}, yu^(-1)]*
      G[{0, 0, yv^(-1)}, yw] + 2*G[{0}, yw]*G[{1}, yu^(-1)]*
      G[{0, 0, yv^(-1)}, yw] + 2*G[{1}, yu^(-1)]^2*G[{0, 0, yv^(-1)}, yw] + 
     2*G[{0}, yu^(-1)]*G[{1}, yv^(-1)]*G[{0, 0, yv^(-1)}, yw] + 
     2*G[{0}, yv^(-1)]*G[{1}, yv^(-1)]*G[{0, 0, yv^(-1)}, yw] - 
     2*G[{0}, yw]*G[{1}, yv^(-1)]*G[{0, 0, yv^(-1)}, yw] - 
     2*G[{1}, yv^(-1)]^2*G[{0, 0, yv^(-1)}, yw] - 
     2*G[{0}, yu^(-1)]*G[{1}, yw]*G[{0, 0, yv^(-1)}, yw] - 
     2*G[{0}, yv^(-1)]*G[{1}, yw]*G[{0, 0, yv^(-1)}, yw] + 
     2*G[{0}, yw]*G[{1}, yw]*G[{0, 0, yv^(-1)}, yw] + 
     4*G[{1}, yv^(-1)]*G[{1}, yw]*G[{0, 0, yv^(-1)}, yw] - 
     2*G[{1}, yw]^2*G[{0, 0, yv^(-1)}, yw] + 2*G[{0}, yu^(-1)]*
      G[{1/(yu*yv)}, yw]*G[{0, 0, yv^(-1)}, yw] + 
     2*G[{0}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, 0, yv^(-1)}, yw] - 
     2*G[{0}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 0, yv^(-1)}, yw] - 
     4*G[{1}, yu^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, 0, yv^(-1)}, yw] + 
     2*G[{1/(yu*yv)}, yw]^2*G[{0, 0, yv^(-1)}, yw] + 
     2*G[{0, 1}, yu^(-1)]*G[{0, 0, yv^(-1)}, yw] + 2*G[{0, 1}, yv^(-1)]*
      G[{0, 0, yv^(-1)}, yw] + 2*G[{0, 1}, yw]*G[{0, 0, yv^(-1)}, yw] - 
     2*G[{0, yu^(-1)}, yw]*G[{0, 0, yv^(-1)}, yw] - 
     2*G[{0, yu}, yv^(-1)]*G[{0, 0, yv^(-1)}, yw] - 
     2*G[{0, yv^(-1)}, yw]*G[{0, 0, yv^(-1)}, yw] + 
     2*G[{0, 1/(yu*yv)}, yw]*G[{0, 0, yv^(-1)}, yw] - 
     (Pi^2*G[{0, 0, 1/(yu*yv)}, yw])/3 + 2*G[{0}, yu^(-1)]*G[{1}, yu^(-1)]*
      G[{0, 0, 1/(yu*yv)}, yw] + 2*G[{0}, yv^(-1)]*G[{1}, yu^(-1)]*
      G[{0, 0, 1/(yu*yv)}, yw] - 2*G[{0}, yw]*G[{1}, yu^(-1)]*
      G[{0, 0, 1/(yu*yv)}, yw] - 2*G[{1}, yu^(-1)]^2*
      G[{0, 0, 1/(yu*yv)}, yw] - 2*G[{0}, yu^(-1)]*G[{1}, yv^(-1)]*
      G[{0, 0, 1/(yu*yv)}, yw] - 2*G[{0}, yv^(-1)]*G[{1}, yv^(-1)]*
      G[{0, 0, 1/(yu*yv)}, yw] + 2*G[{0}, yw]*G[{1}, yv^(-1)]*
      G[{0, 0, 1/(yu*yv)}, yw] + 2*G[{1}, yv^(-1)]^2*
      G[{0, 0, 1/(yu*yv)}, yw] + 2*G[{0}, yu^(-1)]*G[{1}, yw]*
      G[{0, 0, 1/(yu*yv)}, yw] + 2*G[{0}, yv^(-1)]*G[{1}, yw]*
      G[{0, 0, 1/(yu*yv)}, yw] - 2*G[{0}, yw]*G[{1}, yw]*
      G[{0, 0, 1/(yu*yv)}, yw] - 4*G[{1}, yv^(-1)]*G[{1}, yw]*
      G[{0, 0, 1/(yu*yv)}, yw] + 2*G[{1}, yw]^2*G[{0, 0, 1/(yu*yv)}, yw] - 
     2*G[{0}, yu^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, 0, 1/(yu*yv)}, yw] - 
     2*G[{0}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, 0, 1/(yu*yv)}, yw] + 
     2*G[{0}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 0, 1/(yu*yv)}, yw] + 
     4*G[{1}, yu^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, 0, 1/(yu*yv)}, yw] - 
     2*G[{1/(yu*yv)}, yw]^2*G[{0, 0, 1/(yu*yv)}, yw] - 
     2*G[{0, 1}, yu^(-1)]*G[{0, 0, 1/(yu*yv)}, yw] - 
     2*G[{0, 1}, yv^(-1)]*G[{0, 0, 1/(yu*yv)}, yw] - 
     2*G[{0, 1}, yw]*G[{0, 0, 1/(yu*yv)}, yw] + 2*G[{0, yu^(-1)}, yw]*
      G[{0, 0, 1/(yu*yv)}, yw] + 2*G[{0, yu}, yv^(-1)]*
      G[{0, 0, 1/(yu*yv)}, yw] + 2*G[{0, yv^(-1)}, yw]*
      G[{0, 0, 1/(yu*yv)}, yw] - 2*G[{0, 1/(yu*yv)}, yw]*
      G[{0, 0, 1/(yu*yv)}, yw] + (Pi^2*G[{0, 1, 1}, yu^(-1)])/3 - 
     2*G[{0}, yu^(-1)]*G[{1}, yu^(-1)]*G[{0, 1, 1}, yu^(-1)] - 
     2*G[{0}, yv^(-1)]*G[{1}, yu^(-1)]*G[{0, 1, 1}, yu^(-1)] + 
     2*G[{0}, yw]*G[{1}, yu^(-1)]*G[{0, 1, 1}, yu^(-1)] + 
     2*G[{1}, yu^(-1)]^2*G[{0, 1, 1}, yu^(-1)] + 2*G[{0}, yu^(-1)]*
      G[{1}, yv^(-1)]*G[{0, 1, 1}, yu^(-1)] + 2*G[{0}, yv^(-1)]*
      G[{1}, yv^(-1)]*G[{0, 1, 1}, yu^(-1)] - 2*G[{0}, yw]*G[{1}, yv^(-1)]*
      G[{0, 1, 1}, yu^(-1)] - 2*G[{1}, yv^(-1)]^2*G[{0, 1, 1}, yu^(-1)] - 
     2*G[{0}, yu^(-1)]*G[{1}, yw]*G[{0, 1, 1}, yu^(-1)] - 
     2*G[{0}, yv^(-1)]*G[{1}, yw]*G[{0, 1, 1}, yu^(-1)] + 
     2*G[{0}, yw]*G[{1}, yw]*G[{0, 1, 1}, yu^(-1)] + 
     4*G[{1}, yv^(-1)]*G[{1}, yw]*G[{0, 1, 1}, yu^(-1)] - 
     2*G[{1}, yw]^2*G[{0, 1, 1}, yu^(-1)] + 2*G[{0}, yu^(-1)]*
      G[{1/(yu*yv)}, yw]*G[{0, 1, 1}, yu^(-1)] + 2*G[{0}, yv^(-1)]*
      G[{1/(yu*yv)}, yw]*G[{0, 1, 1}, yu^(-1)] - 
     2*G[{0}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1, 1}, yu^(-1)] - 
     4*G[{1}, yu^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, 1, 1}, yu^(-1)] + 
     2*G[{1/(yu*yv)}, yw]^2*G[{0, 1, 1}, yu^(-1)] + 
     2*G[{0, 1}, yu^(-1)]*G[{0, 1, 1}, yu^(-1)] + 2*G[{0, 1}, yv^(-1)]*
      G[{0, 1, 1}, yu^(-1)] + 2*G[{0, 1}, yw]*G[{0, 1, 1}, yu^(-1)] - 
     2*G[{0, yu^(-1)}, yw]*G[{0, 1, 1}, yu^(-1)] - 2*G[{0, yu}, yv^(-1)]*
      G[{0, 1, 1}, yu^(-1)] + 2*G[{0, yv^(-1)}, yw]*G[{0, 1, 1}, yu^(-1)] - 
     2*G[{0, 1/(yu*yv)}, yw]*G[{0, 1, 1}, yu^(-1)] + 
     (4*Pi^2*G[{0, 1, 1}, yv^(-1)])/3 + 2*G[{0}, yu^(-1)]^2*
      G[{0, 1, 1}, yv^(-1)] + 4*G[{0}, yu^(-1)]*G[{0}, yv^(-1)]*
      G[{0, 1, 1}, yv^(-1)] + 2*G[{0}, yv^(-1)]^2*G[{0, 1, 1}, yv^(-1)] - 
     4*G[{0}, yu^(-1)]*G[{0}, yw]*G[{0, 1, 1}, yv^(-1)] - 
     4*G[{0}, yv^(-1)]*G[{0}, yw]*G[{0, 1, 1}, yv^(-1)] + 
     2*G[{0}, yw]^2*G[{0, 1, 1}, yv^(-1)] - 8*G[{0}, yu^(-1)]*G[{1}, yu^(-1)]*
      G[{0, 1, 1}, yv^(-1)] - 8*G[{0}, yv^(-1)]*G[{1}, yu^(-1)]*
      G[{0, 1, 1}, yv^(-1)] + 8*G[{0}, yw]*G[{1}, yu^(-1)]*
      G[{0, 1, 1}, yv^(-1)] + 8*G[{1}, yu^(-1)]^2*G[{0, 1, 1}, yv^(-1)] - 
     2*G[{1}, yv^(-1)]^2*G[{0, 1, 1}, yv^(-1)] + 4*G[{1}, yv^(-1)]*G[{1}, yw]*
      G[{0, 1, 1}, yv^(-1)] - 2*G[{1}, yw]^2*G[{0, 1, 1}, yv^(-1)] + 
     4*G[{0}, yu^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, 1, 1}, yv^(-1)] + 
     4*G[{0}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, 1, 1}, yv^(-1)] - 
     4*G[{0}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1, 1}, yv^(-1)] - 
     8*G[{1}, yu^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, 1, 1}, yv^(-1)] + 
     2*G[{1/(yu*yv)}, yw]^2*G[{0, 1, 1}, yv^(-1)] + 
     4*G[{0, 1}, yv^(-1)]*G[{0, 1, 1}, yv^(-1)] + 
     4*G[{0, 1}, yw]*G[{0, 1, 1}, yv^(-1)] - 4*G[{0, yv^(-1)}, yw]*
      G[{0, 1, 1}, yv^(-1)] - (4*Pi^2*G[{0, 1, 1}, yw])/3 - 
     2*G[{0}, yu^(-1)]^2*G[{0, 1, 1}, yw] - 4*G[{0}, yu^(-1)]*G[{0}, yv^(-1)]*
      G[{0, 1, 1}, yw] - 2*G[{0}, yv^(-1)]^2*G[{0, 1, 1}, yw] + 
     4*G[{0}, yu^(-1)]*G[{0}, yw]*G[{0, 1, 1}, yw] + 
     4*G[{0}, yv^(-1)]*G[{0}, yw]*G[{0, 1, 1}, yw] - 
     2*G[{0}, yw]^2*G[{0, 1, 1}, yw] + 8*G[{0}, yu^(-1)]*G[{1}, yu^(-1)]*
      G[{0, 1, 1}, yw] + 8*G[{0}, yv^(-1)]*G[{1}, yu^(-1)]*G[{0, 1, 1}, yw] - 
     8*G[{0}, yw]*G[{1}, yu^(-1)]*G[{0, 1, 1}, yw] - 
     8*G[{1}, yu^(-1)]^2*G[{0, 1, 1}, yw] + 6*G[{0}, yu^(-1)]*G[{1}, yv^(-1)]*
      G[{0, 1, 1}, yw] + 6*G[{0}, yv^(-1)]*G[{1}, yv^(-1)]*G[{0, 1, 1}, yw] - 
     6*G[{0}, yw]*G[{1}, yv^(-1)]*G[{0, 1, 1}, yw] - 
     12*G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*G[{0, 1, 1}, yw] - 
     4*G[{1}, yv^(-1)]^2*G[{0, 1, 1}, yw] - 2*G[{1}, yv^(-1)]*G[{1}, yw]*
      G[{0, 1, 1}, yw] + 2*G[{1}, yw]^2*G[{0, 1, 1}, yw] - 
     6*G[{0}, yu^(-1)]*G[{yu}, yv^(-1)]*G[{0, 1, 1}, yw] - 
     6*G[{0}, yv^(-1)]*G[{yu}, yv^(-1)]*G[{0, 1, 1}, yw] + 
     6*G[{0}, yw]*G[{yu}, yv^(-1)]*G[{0, 1, 1}, yw] + 
     12*G[{1}, yu^(-1)]*G[{yu}, yv^(-1)]*G[{0, 1, 1}, yw] + 
     12*G[{1}, yv^(-1)]*G[{yu}, yv^(-1)]*G[{0, 1, 1}, yw] + 
     2*G[{1}, yw]*G[{yu}, yv^(-1)]*G[{0, 1, 1}, yw] - 
     6*G[{yu}, yv^(-1)]^2*G[{0, 1, 1}, yw] - 4*G[{0}, yu^(-1)]*
      G[{1/(yu*yv)}, yw]*G[{0, 1, 1}, yw] - 4*G[{0}, yv^(-1)]*
      G[{1/(yu*yv)}, yw]*G[{0, 1, 1}, yw] + 4*G[{0}, yw]*G[{1/(yu*yv)}, yw]*
      G[{0, 1, 1}, yw] + 8*G[{1}, yu^(-1)]*G[{1/(yu*yv)}, yw]*
      G[{0, 1, 1}, yw] + 6*G[{1}, yv^(-1)]*G[{1/(yu*yv)}, yw]*
      G[{0, 1, 1}, yw] - 6*G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw]*
      G[{0, 1, 1}, yw] - 2*G[{1/(yu*yv)}, yw]^2*G[{0, 1, 1}, yw] - 
     4*G[{0, 1}, yv^(-1)]*G[{0, 1, 1}, yw] - 2*G[{0, yu^(-1)}, yw]*
      G[{0, 1, 1}, yw] + 4*G[{0, yu}, yv^(-1)]*G[{0, 1, 1}, yw] + 
     2*G[{0, yv^(-1)}, yw]*G[{0, 1, 1}, yw] - 2*G[{0, 1/(yu*yv)}, yw]*
      G[{0, 1, 1}, yw] - 4*G[{1, yu}, yv^(-1)]*G[{0, 1, 1}, yw] + 
     Pi^2*G[{0, 1, yu^(-1)}, yw] + 2*G[{0}, yu^(-1)]^2*
      G[{0, 1, yu^(-1)}, yw] + 4*G[{0}, yu^(-1)]*G[{0}, yv^(-1)]*
      G[{0, 1, yu^(-1)}, yw] + 2*G[{0}, yv^(-1)]^2*G[{0, 1, yu^(-1)}, yw] - 
     4*G[{0}, yu^(-1)]*G[{0}, yw]*G[{0, 1, yu^(-1)}, yw] - 
     4*G[{0}, yv^(-1)]*G[{0}, yw]*G[{0, 1, yu^(-1)}, yw] + 
     2*G[{0}, yw]^2*G[{0, 1, yu^(-1)}, yw] - 6*G[{0}, yu^(-1)]*
      G[{1}, yu^(-1)]*G[{0, 1, yu^(-1)}, yw] - 6*G[{0}, yv^(-1)]*
      G[{1}, yu^(-1)]*G[{0, 1, yu^(-1)}, yw] + 6*G[{0}, yw]*G[{1}, yu^(-1)]*
      G[{0, 1, yu^(-1)}, yw] + 6*G[{1}, yu^(-1)]^2*G[{0, 1, yu^(-1)}, yw] - 
     6*G[{0}, yu^(-1)]*G[{1}, yv^(-1)]*G[{0, 1, yu^(-1)}, yw] - 
     6*G[{0}, yv^(-1)]*G[{1}, yv^(-1)]*G[{0, 1, yu^(-1)}, yw] + 
     6*G[{0}, yw]*G[{1}, yv^(-1)]*G[{0, 1, yu^(-1)}, yw] + 
     8*G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*G[{0, 1, yu^(-1)}, yw] + 
     4*G[{1}, yv^(-1)]^2*G[{0, 1, yu^(-1)}, yw] + 
     2*G[{0}, yu^(-1)]*G[{1}, yw]*G[{0, 1, yu^(-1)}, yw] + 
     2*G[{0}, yv^(-1)]*G[{1}, yw]*G[{0, 1, yu^(-1)}, yw] - 
     2*G[{0}, yw]*G[{1}, yw]*G[{0, 1, yu^(-1)}, yw] - 
     4*G[{1}, yv^(-1)]*G[{1}, yw]*G[{0, 1, yu^(-1)}, yw] + 
     4*G[{0}, yu^(-1)]*G[{yu}, yv^(-1)]*G[{0, 1, yu^(-1)}, yw] + 
     4*G[{0}, yv^(-1)]*G[{yu}, yv^(-1)]*G[{0, 1, yu^(-1)}, yw] - 
     4*G[{0}, yw]*G[{yu}, yv^(-1)]*G[{0, 1, yu^(-1)}, yw] - 
     8*G[{1}, yu^(-1)]*G[{yu}, yv^(-1)]*G[{0, 1, yu^(-1)}, yw] - 
     8*G[{1}, yv^(-1)]*G[{yu}, yv^(-1)]*G[{0, 1, yu^(-1)}, yw] + 
     4*G[{yu}, yv^(-1)]^2*G[{0, 1, yu^(-1)}, yw] + 
     2*G[{0}, yu^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, 1, yu^(-1)}, yw] + 
     2*G[{0}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, 1, yu^(-1)}, yw] - 
     2*G[{0}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1, yu^(-1)}, yw] - 
     4*G[{1}, yu^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, 1, yu^(-1)}, yw] - 
     4*G[{1}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, 1, yu^(-1)}, yw] + 
     4*G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, 1, yu^(-1)}, yw] - 
     2*G[{0, 1}, yu^(-1)]*G[{0, 1, yu^(-1)}, yw] + 2*G[{0, 1}, yv^(-1)]*
      G[{0, 1, yu^(-1)}, yw] + 2*G[{0, 1}, yw]*G[{0, 1, yu^(-1)}, yw] + 
     4*G[{0, yu^(-1)}, yw]*G[{0, 1, yu^(-1)}, yw] - 
     2*G[{0, yu}, yv^(-1)]*G[{0, 1, yu^(-1)}, yw] + 
     4*G[{1, yu}, yv^(-1)]*G[{0, 1, yu^(-1)}, yw] - 
     Pi^2*G[{0, 1, yu}, yv^(-1)] - 2*G[{0}, yu^(-1)]^2*
      G[{0, 1, yu}, yv^(-1)] - 4*G[{0}, yu^(-1)]*G[{0}, yv^(-1)]*
      G[{0, 1, yu}, yv^(-1)] - 2*G[{0}, yv^(-1)]^2*G[{0, 1, yu}, yv^(-1)] + 
     4*G[{0}, yu^(-1)]*G[{0}, yw]*G[{0, 1, yu}, yv^(-1)] + 
     4*G[{0}, yv^(-1)]*G[{0}, yw]*G[{0, 1, yu}, yv^(-1)] - 
     2*G[{0}, yw]^2*G[{0, 1, yu}, yv^(-1)] + 6*G[{0}, yu^(-1)]*
      G[{1}, yu^(-1)]*G[{0, 1, yu}, yv^(-1)] + 6*G[{0}, yv^(-1)]*
      G[{1}, yu^(-1)]*G[{0, 1, yu}, yv^(-1)] - 6*G[{0}, yw]*G[{1}, yu^(-1)]*
      G[{0, 1, yu}, yv^(-1)] - 6*G[{1}, yu^(-1)]^2*G[{0, 1, yu}, yv^(-1)] + 
     2*G[{0}, yu^(-1)]*G[{1}, yv^(-1)]*G[{0, 1, yu}, yv^(-1)] + 
     2*G[{0}, yv^(-1)]*G[{1}, yv^(-1)]*G[{0, 1, yu}, yv^(-1)] - 
     2*G[{0}, yw]*G[{1}, yv^(-1)]*G[{0, 1, yu}, yv^(-1)] - 
     2*G[{0}, yu^(-1)]*G[{1}, yw]*G[{0, 1, yu}, yv^(-1)] - 
     2*G[{0}, yv^(-1)]*G[{1}, yw]*G[{0, 1, yu}, yv^(-1)] + 
     2*G[{0}, yw]*G[{1}, yw]*G[{0, 1, yu}, yv^(-1)] - 
     2*G[{0}, yu^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, 1, yu}, yv^(-1)] - 
     2*G[{0}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, 1, yu}, yv^(-1)] + 
     2*G[{0}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1, yu}, yv^(-1)] + 
     4*G[{1}, yu^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, 1, yu}, yv^(-1)] + 
     2*G[{0, 1}, yu^(-1)]*G[{0, 1, yu}, yv^(-1)] - 2*G[{0, 1}, yv^(-1)]*
      G[{0, 1, yu}, yv^(-1)] - 4*G[{0, 1}, yw]*G[{0, 1, yu}, yv^(-1)] + 
     4*G[{0, yv^(-1)}, yw]*G[{0, 1, yu}, yv^(-1)] - 
     4*G[{0}, yu^(-1)]*G[{1}, yv^(-1)]*G[{0, 1, yv^(-1)}, yw] - 
     4*G[{0}, yv^(-1)]*G[{1}, yv^(-1)]*G[{0, 1, yv^(-1)}, yw] + 
     4*G[{0}, yw]*G[{1}, yv^(-1)]*G[{0, 1, yv^(-1)}, yw] + 
     8*G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*G[{0, 1, yv^(-1)}, yw] + 
     4*G[{1}, yv^(-1)]^2*G[{0, 1, yv^(-1)}, yw] + 
     4*G[{0}, yu^(-1)]*G[{yu}, yv^(-1)]*G[{0, 1, yv^(-1)}, yw] + 
     4*G[{0}, yv^(-1)]*G[{yu}, yv^(-1)]*G[{0, 1, yv^(-1)}, yw] - 
     4*G[{0}, yw]*G[{yu}, yv^(-1)]*G[{0, 1, yv^(-1)}, yw] - 
     8*G[{1}, yu^(-1)]*G[{yu}, yv^(-1)]*G[{0, 1, yv^(-1)}, yw] - 
     8*G[{1}, yv^(-1)]*G[{yu}, yv^(-1)]*G[{0, 1, yv^(-1)}, yw] + 
     4*G[{yu}, yv^(-1)]^2*G[{0, 1, yv^(-1)}, yw] - 
     4*G[{1}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, 1, yv^(-1)}, yw] + 
     4*G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, 1, yv^(-1)}, yw] + 
     4*G[{0, yu^(-1)}, yw]*G[{0, 1, yv^(-1)}, yw] + 
     2*G[{0}, yu^(-1)]*G[{1}, yv^(-1)]*G[{0, 1, 1/(yu*yv)}, yw] + 
     2*G[{0}, yv^(-1)]*G[{1}, yv^(-1)]*G[{0, 1, 1/(yu*yv)}, yw] - 
     2*G[{0}, yw]*G[{1}, yv^(-1)]*G[{0, 1, 1/(yu*yv)}, yw] - 
     4*G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*G[{0, 1, 1/(yu*yv)}, yw] - 
     2*G[{1}, yv^(-1)]^2*G[{0, 1, 1/(yu*yv)}, yw] + 
     2*G[{1}, yv^(-1)]*G[{1}, yw]*G[{0, 1, 1/(yu*yv)}, yw] - 
     2*G[{0}, yu^(-1)]*G[{yu}, yv^(-1)]*G[{0, 1, 1/(yu*yv)}, yw] - 
     2*G[{0}, yv^(-1)]*G[{yu}, yv^(-1)]*G[{0, 1, 1/(yu*yv)}, yw] + 
     2*G[{0}, yw]*G[{yu}, yv^(-1)]*G[{0, 1, 1/(yu*yv)}, yw] + 
     4*G[{1}, yu^(-1)]*G[{yu}, yv^(-1)]*G[{0, 1, 1/(yu*yv)}, yw] + 
     4*G[{1}, yv^(-1)]*G[{yu}, yv^(-1)]*G[{0, 1, 1/(yu*yv)}, yw] - 
     2*G[{1}, yw]*G[{yu}, yv^(-1)]*G[{0, 1, 1/(yu*yv)}, yw] - 
     2*G[{yu}, yv^(-1)]^2*G[{0, 1, 1/(yu*yv)}, yw] + 
     2*G[{1}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, 1, 1/(yu*yv)}, yw] - 
     2*G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, 1, 1/(yu*yv)}, yw] - 
     2*G[{0, yu^(-1)}, yw]*G[{0, 1, 1/(yu*yv)}, yw] - 
     2*G[{0, 1/(yu*yv)}, yw]*G[{0, 1, 1/(yu*yv)}, yw] + 
     Pi^2*G[{0, yu^(-1), 1}, yw] + 2*G[{0}, yu^(-1)]^2*
      G[{0, yu^(-1), 1}, yw] + 4*G[{0}, yu^(-1)]*G[{0}, yv^(-1)]*
      G[{0, yu^(-1), 1}, yw] + 2*G[{0}, yv^(-1)]^2*G[{0, yu^(-1), 1}, yw] - 
     4*G[{0}, yu^(-1)]*G[{0}, yw]*G[{0, yu^(-1), 1}, yw] - 
     4*G[{0}, yv^(-1)]*G[{0}, yw]*G[{0, yu^(-1), 1}, yw] + 
     2*G[{0}, yw]^2*G[{0, yu^(-1), 1}, yw] - 6*G[{0}, yu^(-1)]*
      G[{1}, yu^(-1)]*G[{0, yu^(-1), 1}, yw] - 6*G[{0}, yv^(-1)]*
      G[{1}, yu^(-1)]*G[{0, yu^(-1), 1}, yw] + 6*G[{0}, yw]*G[{1}, yu^(-1)]*
      G[{0, yu^(-1), 1}, yw] + 6*G[{1}, yu^(-1)]^2*G[{0, yu^(-1), 1}, yw] - 
     4*G[{0}, yu^(-1)]*G[{1}, yv^(-1)]*G[{0, yu^(-1), 1}, yw] - 
     4*G[{0}, yv^(-1)]*G[{1}, yv^(-1)]*G[{0, yu^(-1), 1}, yw] + 
     4*G[{0}, yw]*G[{1}, yv^(-1)]*G[{0, yu^(-1), 1}, yw] + 
     4*G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*G[{0, yu^(-1), 1}, yw] + 
     2*G[{1}, yv^(-1)]^2*G[{0, yu^(-1), 1}, yw] + 
     2*G[{0}, yu^(-1)]*G[{1}, yw]*G[{0, yu^(-1), 1}, yw] + 
     2*G[{0}, yv^(-1)]*G[{1}, yw]*G[{0, yu^(-1), 1}, yw] - 
     2*G[{0}, yw]*G[{1}, yw]*G[{0, yu^(-1), 1}, yw] - 
     2*G[{1}, yv^(-1)]*G[{1}, yw]*G[{0, yu^(-1), 1}, yw] + 
     2*G[{0}, yu^(-1)]*G[{yu}, yv^(-1)]*G[{0, yu^(-1), 1}, yw] + 
     2*G[{0}, yv^(-1)]*G[{yu}, yv^(-1)]*G[{0, yu^(-1), 1}, yw] - 
     2*G[{0}, yw]*G[{yu}, yv^(-1)]*G[{0, yu^(-1), 1}, yw] - 
     4*G[{1}, yu^(-1)]*G[{yu}, yv^(-1)]*G[{0, yu^(-1), 1}, yw] - 
     4*G[{1}, yv^(-1)]*G[{yu}, yv^(-1)]*G[{0, yu^(-1), 1}, yw] - 
     2*G[{1}, yw]*G[{yu}, yv^(-1)]*G[{0, yu^(-1), 1}, yw] + 
     2*G[{yu}, yv^(-1)]^2*G[{0, yu^(-1), 1}, yw] + 
     2*G[{0}, yu^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1), 1}, yw] + 
     2*G[{0}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1), 1}, yw] - 
     2*G[{0}, yw]*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1), 1}, yw] - 
     4*G[{1}, yu^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1), 1}, yw] - 
     2*G[{1}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1), 1}, yw] + 
     2*G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1), 1}, yw] - 
     2*G[{0, 1}, yu^(-1)]*G[{0, yu^(-1), 1}, yw] + 2*G[{0, 1}, yv^(-1)]*
      G[{0, yu^(-1), 1}, yw] + 2*G[{0, 1}, yw]*G[{0, yu^(-1), 1}, yw] - 
     2*G[{0, yu^(-1)}, yw]*G[{0, yu^(-1), 1}, yw] - 
     2*G[{0, yu}, yv^(-1)]*G[{0, yu^(-1), 1}, yw] - 
     2*G[{0, yv^(-1)}, yw]*G[{0, yu^(-1), 1}, yw] + 
     2*G[{0, 1/(yu*yv)}, yw]*G[{0, yu^(-1), 1}, yw] + 
     4*G[{1, yu}, yv^(-1)]*G[{0, yu^(-1), 1}, yw] - 
     (2*Pi^2*G[{0, yu^(-1), yu^(-1)}, yw])/3 - 2*G[{0}, yu^(-1)]^2*
      G[{0, yu^(-1), yu^(-1)}, yw] - 4*G[{0}, yu^(-1)]*G[{0}, yv^(-1)]*
      G[{0, yu^(-1), yu^(-1)}, yw] - 2*G[{0}, yv^(-1)]^2*
      G[{0, yu^(-1), yu^(-1)}, yw] + 4*G[{0}, yu^(-1)]*G[{0}, yw]*
      G[{0, yu^(-1), yu^(-1)}, yw] + 4*G[{0}, yv^(-1)]*G[{0}, yw]*
      G[{0, yu^(-1), yu^(-1)}, yw] - 2*G[{0}, yw]^2*G[{0, yu^(-1), yu^(-1)}, 
       yw] + 4*G[{0}, yu^(-1)]*G[{1}, yu^(-1)]*G[{0, yu^(-1), yu^(-1)}, yw] + 
     4*G[{0}, yv^(-1)]*G[{1}, yu^(-1)]*G[{0, yu^(-1), yu^(-1)}, yw] - 
     4*G[{0}, yw]*G[{1}, yu^(-1)]*G[{0, yu^(-1), yu^(-1)}, yw] - 
     4*G[{1}, yu^(-1)]^2*G[{0, yu^(-1), yu^(-1)}, yw] + 
     4*G[{0}, yu^(-1)]*G[{1}, yv^(-1)]*G[{0, yu^(-1), yu^(-1)}, yw] + 
     4*G[{0}, yv^(-1)]*G[{1}, yv^(-1)]*G[{0, yu^(-1), yu^(-1)}, yw] - 
     4*G[{0}, yw]*G[{1}, yv^(-1)]*G[{0, yu^(-1), yu^(-1)}, yw] - 
     2*G[{1}, yv^(-1)]^2*G[{0, yu^(-1), yu^(-1)}, yw] - 
     4*G[{0}, yu^(-1)]*G[{1}, yw]*G[{0, yu^(-1), yu^(-1)}, yw] - 
     4*G[{0}, yv^(-1)]*G[{1}, yw]*G[{0, yu^(-1), yu^(-1)}, yw] + 
     4*G[{0}, yw]*G[{1}, yw]*G[{0, yu^(-1), yu^(-1)}, yw] + 
     8*G[{1}, yv^(-1)]*G[{1}, yw]*G[{0, yu^(-1), yu^(-1)}, yw] - 
     2*G[{1}, yw]^2*G[{0, yu^(-1), yu^(-1)}, yw] + 2*G[{1/(yu*yv)}, yw]^2*
      G[{0, yu^(-1), yu^(-1)}, yw] + 4*G[{0, 1}, yu^(-1)]*
      G[{0, yu^(-1), yu^(-1)}, yw] - 4*G[{0, 1}, yw]*G[{0, yu^(-1), yu^(-1)}, 
       yw] + 4*G[{0, yu^(-1)}, yw]*G[{0, yu^(-1), yu^(-1)}, yw] - 
     4*G[{1, yu}, yv^(-1)]*G[{0, yu^(-1), yu^(-1)}, yw] + 
     2*G[{0}, yu^(-1)]*G[{1}, yv^(-1)]*G[{0, yu^(-1), 1/(yu*yv)}, yw] + 
     2*G[{0}, yv^(-1)]*G[{1}, yv^(-1)]*G[{0, yu^(-1), 1/(yu*yv)}, yw] - 
     2*G[{0}, yw]*G[{1}, yv^(-1)]*G[{0, yu^(-1), 1/(yu*yv)}, yw] - 
     4*G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*G[{0, yu^(-1), 1/(yu*yv)}, yw] - 
     2*G[{1}, yv^(-1)]^2*G[{0, yu^(-1), 1/(yu*yv)}, yw] - 
     2*G[{1}, yv^(-1)]*G[{1}, yw]*G[{0, yu^(-1), 1/(yu*yv)}, yw] - 
     2*G[{0}, yu^(-1)]*G[{yu}, yv^(-1)]*G[{0, yu^(-1), 1/(yu*yv)}, yw] - 
     2*G[{0}, yv^(-1)]*G[{yu}, yv^(-1)]*G[{0, yu^(-1), 1/(yu*yv)}, yw] + 
     2*G[{0}, yw]*G[{yu}, yv^(-1)]*G[{0, yu^(-1), 1/(yu*yv)}, yw] + 
     4*G[{1}, yu^(-1)]*G[{yu}, yv^(-1)]*G[{0, yu^(-1), 1/(yu*yv)}, yw] + 
     4*G[{1}, yv^(-1)]*G[{yu}, yv^(-1)]*G[{0, yu^(-1), 1/(yu*yv)}, yw] + 
     2*G[{1}, yw]*G[{yu}, yv^(-1)]*G[{0, yu^(-1), 1/(yu*yv)}, yw] - 
     2*G[{yu}, yv^(-1)]^2*G[{0, yu^(-1), 1/(yu*yv)}, yw] + 
     2*G[{1}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1), 1/(yu*yv)}, yw] - 
     2*G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1), 1/(yu*yv)}, yw] - 
     2*G[{0, yv^(-1)}, yw]*G[{0, yu^(-1), 1/(yu*yv)}, yw] + 
     2*G[{0, 1/(yu*yv)}, yw]*G[{0, yu^(-1), 1/(yu*yv)}, yw] - 
     Pi^2*G[{0, yu, 1}, yv^(-1)] - 2*G[{0}, yu^(-1)]^2*
      G[{0, yu, 1}, yv^(-1)] - 4*G[{0}, yu^(-1)]*G[{0}, yv^(-1)]*
      G[{0, yu, 1}, yv^(-1)] - 2*G[{0}, yv^(-1)]^2*G[{0, yu, 1}, yv^(-1)] + 
     4*G[{0}, yu^(-1)]*G[{0}, yw]*G[{0, yu, 1}, yv^(-1)] + 
     4*G[{0}, yv^(-1)]*G[{0}, yw]*G[{0, yu, 1}, yv^(-1)] - 
     2*G[{0}, yw]^2*G[{0, yu, 1}, yv^(-1)] + 6*G[{0}, yu^(-1)]*
      G[{1}, yu^(-1)]*G[{0, yu, 1}, yv^(-1)] + 6*G[{0}, yv^(-1)]*
      G[{1}, yu^(-1)]*G[{0, yu, 1}, yv^(-1)] - 6*G[{0}, yw]*G[{1}, yu^(-1)]*
      G[{0, yu, 1}, yv^(-1)] - 6*G[{1}, yu^(-1)]^2*G[{0, yu, 1}, yv^(-1)] + 
     2*G[{0}, yu^(-1)]*G[{1}, yv^(-1)]*G[{0, yu, 1}, yv^(-1)] + 
     2*G[{0}, yv^(-1)]*G[{1}, yv^(-1)]*G[{0, yu, 1}, yv^(-1)] - 
     2*G[{0}, yw]*G[{1}, yv^(-1)]*G[{0, yu, 1}, yv^(-1)] - 
     2*G[{0}, yu^(-1)]*G[{1}, yw]*G[{0, yu, 1}, yv^(-1)] - 
     2*G[{0}, yv^(-1)]*G[{1}, yw]*G[{0, yu, 1}, yv^(-1)] + 
     2*G[{0}, yw]*G[{1}, yw]*G[{0, yu, 1}, yv^(-1)] - 
     2*G[{0}, yu^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, yu, 1}, yv^(-1)] - 
     2*G[{0}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, yu, 1}, yv^(-1)] + 
     2*G[{0}, yw]*G[{1/(yu*yv)}, yw]*G[{0, yu, 1}, yv^(-1)] + 
     4*G[{1}, yu^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, yu, 1}, yv^(-1)] + 
     2*G[{0, 1}, yu^(-1)]*G[{0, yu, 1}, yv^(-1)] - 2*G[{0, 1}, yv^(-1)]*
      G[{0, yu, 1}, yv^(-1)] - 4*G[{0, 1}, yw]*G[{0, yu, 1}, yv^(-1)] + 
     2*G[{0, yu}, yv^(-1)]*G[{0, yu, 1}, yv^(-1)] + 
     4*G[{0, yv^(-1)}, yw]*G[{0, yu, 1}, yv^(-1)] + 
     (2*Pi^2*G[{0, yu, yu}, yv^(-1)])/3 + 2*G[{0}, yu^(-1)]^2*
      G[{0, yu, yu}, yv^(-1)] + 4*G[{0}, yu^(-1)]*G[{0}, yv^(-1)]*
      G[{0, yu, yu}, yv^(-1)] + 2*G[{0}, yv^(-1)]^2*G[{0, yu, yu}, yv^(-1)] - 
     4*G[{0}, yu^(-1)]*G[{0}, yw]*G[{0, yu, yu}, yv^(-1)] - 
     4*G[{0}, yv^(-1)]*G[{0}, yw]*G[{0, yu, yu}, yv^(-1)] + 
     2*G[{0}, yw]^2*G[{0, yu, yu}, yv^(-1)] - 4*G[{0}, yu^(-1)]*
      G[{1}, yu^(-1)]*G[{0, yu, yu}, yv^(-1)] - 4*G[{0}, yv^(-1)]*
      G[{1}, yu^(-1)]*G[{0, yu, yu}, yv^(-1)] + 4*G[{0}, yw]*G[{1}, yu^(-1)]*
      G[{0, yu, yu}, yv^(-1)] + 4*G[{1}, yu^(-1)]^2*G[{0, yu, yu}, yv^(-1)] - 
     4*G[{0}, yu^(-1)]*G[{1}, yv^(-1)]*G[{0, yu, yu}, yv^(-1)] - 
     4*G[{0}, yv^(-1)]*G[{1}, yv^(-1)]*G[{0, yu, yu}, yv^(-1)] + 
     4*G[{0}, yw]*G[{1}, yv^(-1)]*G[{0, yu, yu}, yv^(-1)] + 
     2*G[{1}, yv^(-1)]^2*G[{0, yu, yu}, yv^(-1)] + 
     4*G[{0}, yu^(-1)]*G[{1}, yw]*G[{0, yu, yu}, yv^(-1)] + 
     4*G[{0}, yv^(-1)]*G[{1}, yw]*G[{0, yu, yu}, yv^(-1)] - 
     4*G[{0}, yw]*G[{1}, yw]*G[{0, yu, yu}, yv^(-1)] - 
     4*G[{1}, yv^(-1)]*G[{1}, yw]*G[{0, yu, yu}, yv^(-1)] + 
     2*G[{1}, yw]^2*G[{0, yu, yu}, yv^(-1)] - 2*G[{1/(yu*yv)}, yw]^2*
      G[{0, yu, yu}, yv^(-1)] - 4*G[{0, 1}, yu^(-1)]*
      G[{0, yu, yu}, yv^(-1)] + 4*G[{0, 1}, yw]*G[{0, yu, yu}, yv^(-1)] - 
     4*G[{0, yv^(-1)}, yw]*G[{0, yu, yu}, yv^(-1)] - 
     2*G[{0}, yu^(-1)]*G[{1}, yv^(-1)]*G[{0, yv^(-1), 1}, yw] - 
     2*G[{0}, yv^(-1)]*G[{1}, yv^(-1)]*G[{0, yv^(-1), 1}, yw] + 
     2*G[{0}, yw]*G[{1}, yv^(-1)]*G[{0, yv^(-1), 1}, yw] + 
     4*G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*G[{0, yv^(-1), 1}, yw] + 
     2*G[{1}, yv^(-1)]^2*G[{0, yv^(-1), 1}, yw] + 
     2*G[{1}, yv^(-1)]*G[{1}, yw]*G[{0, yv^(-1), 1}, yw] + 
     2*G[{0}, yu^(-1)]*G[{yu}, yv^(-1)]*G[{0, yv^(-1), 1}, yw] + 
     2*G[{0}, yv^(-1)]*G[{yu}, yv^(-1)]*G[{0, yv^(-1), 1}, yw] - 
     2*G[{0}, yw]*G[{yu}, yv^(-1)]*G[{0, yv^(-1), 1}, yw] - 
     4*G[{1}, yu^(-1)]*G[{yu}, yv^(-1)]*G[{0, yv^(-1), 1}, yw] - 
     4*G[{1}, yv^(-1)]*G[{yu}, yv^(-1)]*G[{0, yv^(-1), 1}, yw] - 
     2*G[{1}, yw]*G[{yu}, yv^(-1)]*G[{0, yv^(-1), 1}, yw] + 
     2*G[{yu}, yv^(-1)]^2*G[{0, yv^(-1), 1}, yw] - 
     2*G[{1}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, yv^(-1), 1}, yw] + 
     2*G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, yv^(-1), 1}, yw] + 
     2*G[{0, 1/(yu*yv)}, yw]*G[{0, yv^(-1), 1}, yw] + 
     (4*Pi^2*G[{0, yv^(-1), yv^(-1)}, yw])/3 + 2*G[{0}, yu^(-1)]^2*
      G[{0, yv^(-1), yv^(-1)}, yw] + 4*G[{0}, yu^(-1)]*G[{0}, yv^(-1)]*
      G[{0, yv^(-1), yv^(-1)}, yw] + 2*G[{0}, yv^(-1)]^2*
      G[{0, yv^(-1), yv^(-1)}, yw] - 4*G[{0}, yu^(-1)]*G[{0}, yw]*
      G[{0, yv^(-1), yv^(-1)}, yw] - 4*G[{0}, yv^(-1)]*G[{0}, yw]*
      G[{0, yv^(-1), yv^(-1)}, yw] + 2*G[{0}, yw]^2*G[{0, yv^(-1), yv^(-1)}, 
       yw] - 8*G[{0}, yu^(-1)]*G[{1}, yu^(-1)]*G[{0, yv^(-1), yv^(-1)}, yw] - 
     8*G[{0}, yv^(-1)]*G[{1}, yu^(-1)]*G[{0, yv^(-1), yv^(-1)}, yw] + 
     8*G[{0}, yw]*G[{1}, yu^(-1)]*G[{0, yv^(-1), yv^(-1)}, yw] + 
     8*G[{1}, yu^(-1)]^2*G[{0, yv^(-1), yv^(-1)}, yw] - 
     2*G[{1}, yv^(-1)]^2*G[{0, yv^(-1), yv^(-1)}, yw] - 
     2*G[{1}, yw]^2*G[{0, yv^(-1), yv^(-1)}, yw] + 
     4*G[{0}, yu^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, yv^(-1), yv^(-1)}, yw] + 
     4*G[{0}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, yv^(-1), yv^(-1)}, yw] - 
     4*G[{0}, yw]*G[{1/(yu*yv)}, yw]*G[{0, yv^(-1), yv^(-1)}, yw] - 
     8*G[{1}, yu^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, yv^(-1), yv^(-1)}, yw] + 
     2*G[{1/(yu*yv)}, yw]^2*G[{0, yv^(-1), yv^(-1)}, yw] + 
     4*G[{0, 1}, yv^(-1)]*G[{0, yv^(-1), yv^(-1)}, yw] - 
     4*G[{0, yu}, yv^(-1)]*G[{0, yv^(-1), yv^(-1)}, yw] + 
     4*G[{1, yu}, yv^(-1)]*G[{0, yv^(-1), yv^(-1)}, yw] - 
     Pi^2*G[{0, yv^(-1), 1/(yu*yv)}, yw] - 2*G[{0}, yu^(-1)]^2*
      G[{0, yv^(-1), 1/(yu*yv)}, yw] - 4*G[{0}, yu^(-1)]*G[{0}, yv^(-1)]*
      G[{0, yv^(-1), 1/(yu*yv)}, yw] - 2*G[{0}, yv^(-1)]^2*
      G[{0, yv^(-1), 1/(yu*yv)}, yw] + 4*G[{0}, yu^(-1)]*G[{0}, yw]*
      G[{0, yv^(-1), 1/(yu*yv)}, yw] + 4*G[{0}, yv^(-1)]*G[{0}, yw]*
      G[{0, yv^(-1), 1/(yu*yv)}, yw] - 2*G[{0}, yw]^2*
      G[{0, yv^(-1), 1/(yu*yv)}, yw] + 6*G[{0}, yu^(-1)]*G[{1}, yu^(-1)]*
      G[{0, yv^(-1), 1/(yu*yv)}, yw] + 6*G[{0}, yv^(-1)]*G[{1}, yu^(-1)]*
      G[{0, yv^(-1), 1/(yu*yv)}, yw] - 6*G[{0}, yw]*G[{1}, yu^(-1)]*
      G[{0, yv^(-1), 1/(yu*yv)}, yw] - 6*G[{1}, yu^(-1)]^2*
      G[{0, yv^(-1), 1/(yu*yv)}, yw] + 4*G[{0}, yu^(-1)]*G[{1}, yv^(-1)]*
      G[{0, yv^(-1), 1/(yu*yv)}, yw] + 4*G[{0}, yv^(-1)]*G[{1}, yv^(-1)]*
      G[{0, yv^(-1), 1/(yu*yv)}, yw] - 4*G[{0}, yw]*G[{1}, yv^(-1)]*
      G[{0, yv^(-1), 1/(yu*yv)}, yw] - 4*G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*
      G[{0, yv^(-1), 1/(yu*yv)}, yw] - 2*G[{1}, yv^(-1)]^2*
      G[{0, yv^(-1), 1/(yu*yv)}, yw] - 2*G[{0}, yu^(-1)]*G[{1}, yw]*
      G[{0, yv^(-1), 1/(yu*yv)}, yw] - 2*G[{0}, yv^(-1)]*G[{1}, yw]*
      G[{0, yv^(-1), 1/(yu*yv)}, yw] + 2*G[{0}, yw]*G[{1}, yw]*
      G[{0, yv^(-1), 1/(yu*yv)}, yw] + 2*G[{1}, yv^(-1)]*G[{1}, yw]*
      G[{0, yv^(-1), 1/(yu*yv)}, yw] - 2*G[{0}, yu^(-1)]*G[{yu}, yv^(-1)]*
      G[{0, yv^(-1), 1/(yu*yv)}, yw] - 2*G[{0}, yv^(-1)]*G[{yu}, yv^(-1)]*
      G[{0, yv^(-1), 1/(yu*yv)}, yw] + 2*G[{0}, yw]*G[{yu}, yv^(-1)]*
      G[{0, yv^(-1), 1/(yu*yv)}, yw] + 4*G[{1}, yu^(-1)]*G[{yu}, yv^(-1)]*
      G[{0, yv^(-1), 1/(yu*yv)}, yw] + 4*G[{1}, yv^(-1)]*G[{yu}, yv^(-1)]*
      G[{0, yv^(-1), 1/(yu*yv)}, yw] + 2*G[{1}, yw]*G[{yu}, yv^(-1)]*
      G[{0, yv^(-1), 1/(yu*yv)}, yw] - 2*G[{yu}, yv^(-1)]^2*
      G[{0, yv^(-1), 1/(yu*yv)}, yw] - 2*G[{0}, yu^(-1)]*G[{1/(yu*yv)}, yw]*
      G[{0, yv^(-1), 1/(yu*yv)}, yw] - 2*G[{0}, yv^(-1)]*G[{1/(yu*yv)}, yw]*
      G[{0, yv^(-1), 1/(yu*yv)}, yw] + 2*G[{0}, yw]*G[{1/(yu*yv)}, yw]*
      G[{0, yv^(-1), 1/(yu*yv)}, yw] + 4*G[{1}, yu^(-1)]*G[{1/(yu*yv)}, yw]*
      G[{0, yv^(-1), 1/(yu*yv)}, yw] + 2*G[{1}, yv^(-1)]*G[{1/(yu*yv)}, yw]*
      G[{0, yv^(-1), 1/(yu*yv)}, yw] - 2*G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw]*
      G[{0, yv^(-1), 1/(yu*yv)}, yw] + 2*G[{0, 1}, yu^(-1)]*
      G[{0, yv^(-1), 1/(yu*yv)}, yw] - 2*G[{0, 1}, yv^(-1)]*
      G[{0, yv^(-1), 1/(yu*yv)}, yw] - 2*G[{0, 1}, yw]*
      G[{0, yv^(-1), 1/(yu*yv)}, yw] + 2*G[{0, yu^(-1)}, yw]*
      G[{0, yv^(-1), 1/(yu*yv)}, yw] + 2*G[{0, yu}, yv^(-1)]*
      G[{0, yv^(-1), 1/(yu*yv)}, yw] + 2*G[{0, yv^(-1)}, yw]*
      G[{0, yv^(-1), 1/(yu*yv)}, yw] + 2*G[{0, 1/(yu*yv)}, yw]*
      G[{0, yv^(-1), 1/(yu*yv)}, yw] - 4*G[{1, yu}, yv^(-1)]*
      G[{0, yv^(-1), 1/(yu*yv)}, yw] + (Pi^2*G[{0, 1/(yu*yv), 1}, yw])/3 - 
     2*G[{0}, yu^(-1)]*G[{1}, yu^(-1)]*G[{0, 1/(yu*yv), 1}, yw] - 
     2*G[{0}, yv^(-1)]*G[{1}, yu^(-1)]*G[{0, 1/(yu*yv), 1}, yw] + 
     2*G[{0}, yw]*G[{1}, yu^(-1)]*G[{0, 1/(yu*yv), 1}, yw] + 
     2*G[{1}, yu^(-1)]^2*G[{0, 1/(yu*yv), 1}, yw] + 
     4*G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*G[{0, 1/(yu*yv), 1}, yw] - 
     2*G[{0}, yu^(-1)]*G[{1}, yw]*G[{0, 1/(yu*yv), 1}, yw] - 
     2*G[{0}, yv^(-1)]*G[{1}, yw]*G[{0, 1/(yu*yv), 1}, yw] + 
     2*G[{0}, yw]*G[{1}, yw]*G[{0, 1/(yu*yv), 1}, yw] + 
     2*G[{1}, yv^(-1)]*G[{1}, yw]*G[{0, 1/(yu*yv), 1}, yw] - 
     2*G[{1}, yw]^2*G[{0, 1/(yu*yv), 1}, yw] + 2*G[{0}, yu^(-1)]*
      G[{yu}, yv^(-1)]*G[{0, 1/(yu*yv), 1}, yw] + 
     2*G[{0}, yv^(-1)]*G[{yu}, yv^(-1)]*G[{0, 1/(yu*yv), 1}, yw] - 
     2*G[{0}, yw]*G[{yu}, yv^(-1)]*G[{0, 1/(yu*yv), 1}, yw] - 
     4*G[{1}, yu^(-1)]*G[{yu}, yv^(-1)]*G[{0, 1/(yu*yv), 1}, yw] - 
     4*G[{1}, yv^(-1)]*G[{yu}, yv^(-1)]*G[{0, 1/(yu*yv), 1}, yw] + 
     2*G[{1}, yw]*G[{yu}, yv^(-1)]*G[{0, 1/(yu*yv), 1}, yw] + 
     2*G[{yu}, yv^(-1)]^2*G[{0, 1/(yu*yv), 1}, yw] + 
     2*G[{0}, yu^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv), 1}, yw] + 
     2*G[{0}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv), 1}, yw] - 
     2*G[{0}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv), 1}, yw] - 
     4*G[{1}, yu^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv), 1}, yw] - 
     2*G[{1}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv), 1}, yw] + 
     2*G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv), 1}, yw] + 
     2*G[{1/(yu*yv)}, yw]^2*G[{0, 1/(yu*yv), 1}, yw] + 
     2*G[{0, 1}, yu^(-1)]*G[{0, 1/(yu*yv), 1}, yw] + 
     2*G[{0, 1}, yv^(-1)]*G[{0, 1/(yu*yv), 1}, yw] - 
     2*G[{0, 1}, yw]*G[{0, 1/(yu*yv), 1}, yw] + 2*G[{0, yu^(-1)}, yw]*
      G[{0, 1/(yu*yv), 1}, yw] - 2*G[{0, yu}, yv^(-1)]*
      G[{0, 1/(yu*yv), 1}, yw] + 2*G[{0, yv^(-1)}, yw]*
      G[{0, 1/(yu*yv), 1}, yw] - 2*G[{0, 1/(yu*yv)}, yw]*
      G[{0, 1/(yu*yv), 1}, yw] - (Pi^2*G[{0, 1/(yu*yv), yu^(-1)}, yw])/3 + 
     2*G[{0}, yu^(-1)]*G[{1}, yu^(-1)]*G[{0, 1/(yu*yv), yu^(-1)}, yw] + 
     2*G[{0}, yv^(-1)]*G[{1}, yu^(-1)]*G[{0, 1/(yu*yv), yu^(-1)}, yw] - 
     2*G[{0}, yw]*G[{1}, yu^(-1)]*G[{0, 1/(yu*yv), yu^(-1)}, yw] - 
     2*G[{1}, yu^(-1)]^2*G[{0, 1/(yu*yv), yu^(-1)}, yw] + 
     2*G[{0}, yu^(-1)]*G[{1}, yv^(-1)]*G[{0, 1/(yu*yv), yu^(-1)}, yw] + 
     2*G[{0}, yv^(-1)]*G[{1}, yv^(-1)]*G[{0, 1/(yu*yv), yu^(-1)}, yw] - 
     2*G[{0}, yw]*G[{1}, yv^(-1)]*G[{0, 1/(yu*yv), yu^(-1)}, yw] - 
     8*G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*G[{0, 1/(yu*yv), yu^(-1)}, yw] - 
     2*G[{1}, yv^(-1)]^2*G[{0, 1/(yu*yv), yu^(-1)}, yw] + 
     2*G[{0}, yu^(-1)]*G[{1}, yw]*G[{0, 1/(yu*yv), yu^(-1)}, yw] + 
     2*G[{0}, yv^(-1)]*G[{1}, yw]*G[{0, 1/(yu*yv), yu^(-1)}, yw] - 
     2*G[{0}, yw]*G[{1}, yw]*G[{0, 1/(yu*yv), yu^(-1)}, yw] - 
     4*G[{1}, yv^(-1)]*G[{1}, yw]*G[{0, 1/(yu*yv), yu^(-1)}, yw] + 
     2*G[{1}, yw]^2*G[{0, 1/(yu*yv), yu^(-1)}, yw] - 
     4*G[{0}, yu^(-1)]*G[{yu}, yv^(-1)]*G[{0, 1/(yu*yv), yu^(-1)}, yw] - 
     4*G[{0}, yv^(-1)]*G[{yu}, yv^(-1)]*G[{0, 1/(yu*yv), yu^(-1)}, yw] + 
     4*G[{0}, yw]*G[{yu}, yv^(-1)]*G[{0, 1/(yu*yv), yu^(-1)}, yw] + 
     8*G[{1}, yu^(-1)]*G[{yu}, yv^(-1)]*G[{0, 1/(yu*yv), yu^(-1)}, yw] + 
     8*G[{1}, yv^(-1)]*G[{yu}, yv^(-1)]*G[{0, 1/(yu*yv), yu^(-1)}, yw] - 
     4*G[{yu}, yv^(-1)]^2*G[{0, 1/(yu*yv), yu^(-1)}, yw] - 
     2*G[{0}, yu^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv), yu^(-1)}, yw] - 
     2*G[{0}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv), yu^(-1)}, yw] + 
     2*G[{0}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv), yu^(-1)}, yw] + 
     4*G[{1}, yu^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv), yu^(-1)}, yw] + 
     4*G[{1}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv), yu^(-1)}, yw] - 
     4*G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv), yu^(-1)}, yw] - 
     2*G[{1/(yu*yv)}, yw]^2*G[{0, 1/(yu*yv), yu^(-1)}, yw] - 
     2*G[{0, 1}, yu^(-1)]*G[{0, 1/(yu*yv), yu^(-1)}, yw] - 
     2*G[{0, 1}, yv^(-1)]*G[{0, 1/(yu*yv), yu^(-1)}, yw] + 
     2*G[{0, 1}, yw]*G[{0, 1/(yu*yv), yu^(-1)}, yw] - 
     2*G[{0, yu^(-1)}, yw]*G[{0, 1/(yu*yv), yu^(-1)}, yw] + 
     2*G[{0, yu}, yv^(-1)]*G[{0, 1/(yu*yv), yu^(-1)}, yw] - 
     2*G[{0, yv^(-1)}, yw]*G[{0, 1/(yu*yv), yu^(-1)}, yw] + 
     2*G[{0, 1/(yu*yv)}, yw]*G[{0, 1/(yu*yv), yu^(-1)}, yw] - 
     (4*Pi^2*G[{0, 1/(yu*yv), yv^(-1)}, yw])/3 - 2*G[{0}, yu^(-1)]^2*
      G[{0, 1/(yu*yv), yv^(-1)}, yw] - 4*G[{0}, yu^(-1)]*G[{0}, yv^(-1)]*
      G[{0, 1/(yu*yv), yv^(-1)}, yw] - 2*G[{0}, yv^(-1)]^2*
      G[{0, 1/(yu*yv), yv^(-1)}, yw] + 4*G[{0}, yu^(-1)]*G[{0}, yw]*
      G[{0, 1/(yu*yv), yv^(-1)}, yw] + 4*G[{0}, yv^(-1)]*G[{0}, yw]*
      G[{0, 1/(yu*yv), yv^(-1)}, yw] - 2*G[{0}, yw]^2*
      G[{0, 1/(yu*yv), yv^(-1)}, yw] + 8*G[{0}, yu^(-1)]*G[{1}, yu^(-1)]*
      G[{0, 1/(yu*yv), yv^(-1)}, yw] + 8*G[{0}, yv^(-1)]*G[{1}, yu^(-1)]*
      G[{0, 1/(yu*yv), yv^(-1)}, yw] - 8*G[{0}, yw]*G[{1}, yu^(-1)]*
      G[{0, 1/(yu*yv), yv^(-1)}, yw] - 8*G[{1}, yu^(-1)]^2*
      G[{0, 1/(yu*yv), yv^(-1)}, yw] + 4*G[{0}, yu^(-1)]*G[{1}, yv^(-1)]*
      G[{0, 1/(yu*yv), yv^(-1)}, yw] + 4*G[{0}, yv^(-1)]*G[{1}, yv^(-1)]*
      G[{0, 1/(yu*yv), yv^(-1)}, yw] - 4*G[{0}, yw]*G[{1}, yv^(-1)]*
      G[{0, 1/(yu*yv), yv^(-1)}, yw] - 8*G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*
      G[{0, 1/(yu*yv), yv^(-1)}, yw] - 2*G[{1}, yv^(-1)]^2*
      G[{0, 1/(yu*yv), yv^(-1)}, yw] + 2*G[{1}, yw]^2*
      G[{0, 1/(yu*yv), yv^(-1)}, yw] - 4*G[{0}, yu^(-1)]*G[{yu}, yv^(-1)]*
      G[{0, 1/(yu*yv), yv^(-1)}, yw] - 4*G[{0}, yv^(-1)]*G[{yu}, yv^(-1)]*
      G[{0, 1/(yu*yv), yv^(-1)}, yw] + 4*G[{0}, yw]*G[{yu}, yv^(-1)]*
      G[{0, 1/(yu*yv), yv^(-1)}, yw] + 8*G[{1}, yu^(-1)]*G[{yu}, yv^(-1)]*
      G[{0, 1/(yu*yv), yv^(-1)}, yw] + 8*G[{1}, yv^(-1)]*G[{yu}, yv^(-1)]*
      G[{0, 1/(yu*yv), yv^(-1)}, yw] - 4*G[{yu}, yv^(-1)]^2*
      G[{0, 1/(yu*yv), yv^(-1)}, yw] - 4*G[{0}, yu^(-1)]*G[{1/(yu*yv)}, yw]*
      G[{0, 1/(yu*yv), yv^(-1)}, yw] - 4*G[{0}, yv^(-1)]*G[{1/(yu*yv)}, yw]*
      G[{0, 1/(yu*yv), yv^(-1)}, yw] + 4*G[{0}, yw]*G[{1/(yu*yv)}, yw]*
      G[{0, 1/(yu*yv), yv^(-1)}, yw] + 8*G[{1}, yu^(-1)]*G[{1/(yu*yv)}, yw]*
      G[{0, 1/(yu*yv), yv^(-1)}, yw] + 4*G[{1}, yv^(-1)]*G[{1/(yu*yv)}, yw]*
      G[{0, 1/(yu*yv), yv^(-1)}, yw] - 4*G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw]*
      G[{0, 1/(yu*yv), yv^(-1)}, yw] - 2*G[{1/(yu*yv)}, yw]^2*
      G[{0, 1/(yu*yv), yv^(-1)}, yw] - 4*G[{0, 1}, yv^(-1)]*
      G[{0, 1/(yu*yv), yv^(-1)}, yw] + 4*G[{0, yu}, yv^(-1)]*
      G[{0, 1/(yu*yv), yv^(-1)}, yw] - 4*G[{1, yu}, yv^(-1)]*
      G[{0, 1/(yu*yv), yv^(-1)}, yw] + Pi^2*G[{0, 1/(yu*yv), 1/(yu*yv)}, 
       yw] + 2*G[{0}, yu^(-1)]^2*G[{0, 1/(yu*yv), 1/(yu*yv)}, yw] + 
     4*G[{0}, yu^(-1)]*G[{0}, yv^(-1)]*G[{0, 1/(yu*yv), 1/(yu*yv)}, yw] + 
     2*G[{0}, yv^(-1)]^2*G[{0, 1/(yu*yv), 1/(yu*yv)}, yw] - 
     4*G[{0}, yu^(-1)]*G[{0}, yw]*G[{0, 1/(yu*yv), 1/(yu*yv)}, yw] - 
     4*G[{0}, yv^(-1)]*G[{0}, yw]*G[{0, 1/(yu*yv), 1/(yu*yv)}, yw] + 
     2*G[{0}, yw]^2*G[{0, 1/(yu*yv), 1/(yu*yv)}, yw] - 
     6*G[{0}, yu^(-1)]*G[{1}, yu^(-1)]*G[{0, 1/(yu*yv), 1/(yu*yv)}, yw] - 
     6*G[{0}, yv^(-1)]*G[{1}, yu^(-1)]*G[{0, 1/(yu*yv), 1/(yu*yv)}, yw] + 
     6*G[{0}, yw]*G[{1}, yu^(-1)]*G[{0, 1/(yu*yv), 1/(yu*yv)}, yw] + 
     6*G[{1}, yu^(-1)]^2*G[{0, 1/(yu*yv), 1/(yu*yv)}, yw] - 
     8*G[{0}, yu^(-1)]*G[{1}, yv^(-1)]*G[{0, 1/(yu*yv), 1/(yu*yv)}, yw] - 
     8*G[{0}, yv^(-1)]*G[{1}, yv^(-1)]*G[{0, 1/(yu*yv), 1/(yu*yv)}, yw] + 
     8*G[{0}, yw]*G[{1}, yv^(-1)]*G[{0, 1/(yu*yv), 1/(yu*yv)}, yw] + 
     12*G[{1}, yu^(-1)]*G[{1}, yv^(-1)]*G[{0, 1/(yu*yv), 1/(yu*yv)}, yw] + 
     6*G[{1}, yv^(-1)]^2*G[{0, 1/(yu*yv), 1/(yu*yv)}, yw] + 
     2*G[{0}, yu^(-1)]*G[{1}, yw]*G[{0, 1/(yu*yv), 1/(yu*yv)}, yw] + 
     2*G[{0}, yv^(-1)]*G[{1}, yw]*G[{0, 1/(yu*yv), 1/(yu*yv)}, yw] - 
     2*G[{0}, yw]*G[{1}, yw]*G[{0, 1/(yu*yv), 1/(yu*yv)}, yw] - 
     2*G[{1}, yv^(-1)]*G[{1}, yw]*G[{0, 1/(yu*yv), 1/(yu*yv)}, yw] + 
     6*G[{0}, yu^(-1)]*G[{yu}, yv^(-1)]*G[{0, 1/(yu*yv), 1/(yu*yv)}, yw] + 
     6*G[{0}, yv^(-1)]*G[{yu}, yv^(-1)]*G[{0, 1/(yu*yv), 1/(yu*yv)}, yw] - 
     6*G[{0}, yw]*G[{yu}, yv^(-1)]*G[{0, 1/(yu*yv), 1/(yu*yv)}, yw] - 
     12*G[{1}, yu^(-1)]*G[{yu}, yv^(-1)]*G[{0, 1/(yu*yv), 1/(yu*yv)}, yw] - 
     12*G[{1}, yv^(-1)]*G[{yu}, yv^(-1)]*G[{0, 1/(yu*yv), 1/(yu*yv)}, yw] - 
     2*G[{1}, yw]*G[{yu}, yv^(-1)]*G[{0, 1/(yu*yv), 1/(yu*yv)}, yw] + 
     6*G[{yu}, yv^(-1)]^2*G[{0, 1/(yu*yv), 1/(yu*yv)}, yw] + 
     2*G[{0}, yu^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv), 1/(yu*yv)}, yw] + 
     2*G[{0}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv), 1/(yu*yv)}, yw] - 
     2*G[{0}, yw]*G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv), 1/(yu*yv)}, yw] - 
     4*G[{1}, yu^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv), 1/(yu*yv)}, yw] - 
     6*G[{1}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv), 1/(yu*yv)}, yw] + 
     6*G[{yu}, yv^(-1)]*G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv), 1/(yu*yv)}, yw] - 
     2*G[{0, 1}, yu^(-1)]*G[{0, 1/(yu*yv), 1/(yu*yv)}, yw] + 
     2*G[{0, 1}, yv^(-1)]*G[{0, 1/(yu*yv), 1/(yu*yv)}, yw] + 
     2*G[{0, 1}, yw]*G[{0, 1/(yu*yv), 1/(yu*yv)}, yw] - 
     2*G[{0, yu^(-1)}, yw]*G[{0, 1/(yu*yv), 1/(yu*yv)}, yw] - 
     2*G[{0, yu}, yv^(-1)]*G[{0, 1/(yu*yv), 1/(yu*yv)}, yw] - 
     2*G[{0, yv^(-1)}, yw]*G[{0, 1/(yu*yv), 1/(yu*yv)}, yw] + 
     2*G[{0, 1/(yu*yv)}, yw]*G[{0, 1/(yu*yv), 1/(yu*yv)}, yw] + 
     4*G[{1, yu}, yv^(-1)]*G[{0, 1/(yu*yv), 1/(yu*yv)}, yw] - 
     2*G[{0, 1}, yw]*G[{1, 1, yu}, yv^(-1)] - 2*G[{0, yu^(-1)}, yw]*
      G[{1, 1, yu}, yv^(-1)] + 2*G[{0, yv^(-1)}, yw]*G[{1, 1, yu}, yv^(-1)] + 
     2*G[{0, 1/(yu*yv)}, yw]*G[{1, 1, yu}, yv^(-1)] - 
     4*G[{0, yu^(-1)}, yw]*G[{1, yu, yu}, yv^(-1)] + 
     4*G[{0, yv^(-1)}, yw]*G[{1, yu, yu}, yv^(-1)] + 
     4*G[{0}, yu^(-1)]*G[{0, 0, 1, 1}, yu^(-1)] + 
     4*G[{0}, yv^(-1)]*G[{0, 0, 1, 1}, yu^(-1)] - 
     4*G[{0}, yw]*G[{0, 0, 1, 1}, yu^(-1)] - 4*G[{1}, yu^(-1)]*
      G[{0, 0, 1, 1}, yu^(-1)] + 4*G[{1/(yu*yv)}, yw]*
      G[{0, 0, 1, 1}, yu^(-1)] + 4*G[{1}, yv^(-1)]*G[{0, 0, 1, 1}, yv^(-1)] - 
     4*G[{1}, yw]*G[{0, 0, 1, 1}, yv^(-1)] + 4*G[{1}, yv^(-1)]*
      G[{0, 0, 1, 1}, yw] - 4*G[{1}, yw]*G[{0, 0, 1, 1}, yw] - 
     4*G[{yu}, yv^(-1)]*G[{0, 0, 1, 1}, yw] - 4*G[{1}, yv^(-1)]*
      G[{0, 0, 1, yu^(-1)}, yw] + 4*G[{1}, yw]*G[{0, 0, 1, yu^(-1)}, yw] + 
     4*G[{yu}, yv^(-1)]*G[{0, 0, 1, yu^(-1)}, yw] - 
     4*G[{1}, yv^(-1)]*G[{0, 0, 1, yu}, yv^(-1)] + 
     4*G[{1}, yw]*G[{0, 0, 1, yu}, yv^(-1)] - 4*G[{1}, yv^(-1)]*
      G[{0, 0, 1, yv^(-1)}, yw] + 4*G[{1}, yw]*G[{0, 0, 1, yv^(-1)}, yw] + 
     4*G[{yu}, yv^(-1)]*G[{0, 0, 1, yv^(-1)}, yw] + 
     4*G[{1}, yv^(-1)]*G[{0, 0, 1, 1/(yu*yv)}, yw] - 
     4*G[{1}, yw]*G[{0, 0, 1, 1/(yu*yv)}, yw] - 4*G[{yu}, yv^(-1)]*
      G[{0, 0, 1, 1/(yu*yv)}, yw] - 4*G[{1}, yv^(-1)]*
      G[{0, 0, yu^(-1), 1}, yw] + 4*G[{1}, yw]*G[{0, 0, yu^(-1), 1}, yw] + 
     4*G[{yu}, yv^(-1)]*G[{0, 0, yu^(-1), 1}, yw] - 
     4*G[{1}, yw]*G[{0, 0, yu^(-1), yu^(-1)}, yw] - 
     4*G[{1}, yw]*G[{0, 0, yu^(-1), yv^(-1)}, yw] + 
     4*G[{1}, yw]*G[{0, 0, yu^(-1), 1/(yu*yv)}, yw] - 
     4*G[{1}, yv^(-1)]*G[{0, 0, yu, 1}, yv^(-1)] + 
     4*G[{1}, yw]*G[{0, 0, yu, 1}, yv^(-1)] + 4*G[{1}, yv^(-1)]*
      G[{0, 0, yu, yu}, yv^(-1)] - 4*G[{1}, yw]*G[{0, 0, yu, yu}, yv^(-1)] - 
     4*G[{1}, yv^(-1)]*G[{0, 0, yv^(-1), 1}, yw] + 
     4*G[{1}, yw]*G[{0, 0, yv^(-1), 1}, yw] + 4*G[{yu}, yv^(-1)]*
      G[{0, 0, yv^(-1), 1}, yw] - 4*G[{1}, yw]*G[{0, 0, yv^(-1), yu^(-1)}, 
       yw] + 4*G[{0}, yu^(-1)]*G[{0, 0, yv^(-1), yv^(-1)}, yw] + 
     4*G[{0}, yv^(-1)]*G[{0, 0, yv^(-1), yv^(-1)}, yw] - 
     4*G[{0}, yw]*G[{0, 0, yv^(-1), yv^(-1)}, yw] - 
     8*G[{1}, yu^(-1)]*G[{0, 0, yv^(-1), yv^(-1)}, yw] + 
     4*G[{1/(yu*yv)}, yw]*G[{0, 0, yv^(-1), yv^(-1)}, yw] - 
     4*G[{0}, yu^(-1)]*G[{0, 0, yv^(-1), 1/(yu*yv)}, yw] - 
     4*G[{0}, yv^(-1)]*G[{0, 0, yv^(-1), 1/(yu*yv)}, yw] + 
     4*G[{0}, yw]*G[{0, 0, yv^(-1), 1/(yu*yv)}, yw] + 
     8*G[{1}, yu^(-1)]*G[{0, 0, yv^(-1), 1/(yu*yv)}, yw] - 
     4*G[{1/(yu*yv)}, yw]*G[{0, 0, yv^(-1), 1/(yu*yv)}, yw] + 
     4*G[{1}, yv^(-1)]*G[{0, 0, 1/(yu*yv), 1}, yw] - 
     4*G[{1}, yw]*G[{0, 0, 1/(yu*yv), 1}, yw] - 4*G[{yu}, yv^(-1)]*
      G[{0, 0, 1/(yu*yv), 1}, yw] + 4*G[{1}, yw]*
      G[{0, 0, 1/(yu*yv), yu^(-1)}, yw] - 4*G[{0}, yu^(-1)]*
      G[{0, 0, 1/(yu*yv), yv^(-1)}, yw] - 4*G[{0}, yv^(-1)]*
      G[{0, 0, 1/(yu*yv), yv^(-1)}, yw] + 4*G[{0}, yw]*
      G[{0, 0, 1/(yu*yv), yv^(-1)}, yw] + 8*G[{1}, yu^(-1)]*
      G[{0, 0, 1/(yu*yv), yv^(-1)}, yw] - 4*G[{1/(yu*yv)}, yw]*
      G[{0, 0, 1/(yu*yv), yv^(-1)}, yw] + 4*G[{0}, yu^(-1)]*
      G[{0, 0, 1/(yu*yv), 1/(yu*yv)}, yw] + 4*G[{0}, yv^(-1)]*
      G[{0, 0, 1/(yu*yv), 1/(yu*yv)}, yw] - 4*G[{0}, yw]*
      G[{0, 0, 1/(yu*yv), 1/(yu*yv)}, yw] - 8*G[{1}, yu^(-1)]*
      G[{0, 0, 1/(yu*yv), 1/(yu*yv)}, yw] - 4*G[{1}, yv^(-1)]*
      G[{0, 0, 1/(yu*yv), 1/(yu*yv)}, yw] + 4*G[{yu}, yv^(-1)]*
      G[{0, 0, 1/(yu*yv), 1/(yu*yv)}, yw] + 4*G[{1/(yu*yv)}, yw]*
      G[{0, 0, 1/(yu*yv), 1/(yu*yv)}, yw] - 2*G[{1}, yv^(-1)]*
      G[{0, 1, 0, yu^(-1)}, yw] + 2*G[{yu}, yv^(-1)]*
      G[{0, 1, 0, yu^(-1)}, yw] + 2*G[{0}, yu^(-1)]*G[{0, 1, 0, yv^(-1)}, 
       yw] + 2*G[{0}, yv^(-1)]*G[{0, 1, 0, yv^(-1)}, yw] - 
     2*G[{0}, yw]*G[{0, 1, 0, yv^(-1)}, yw] - 4*G[{1}, yu^(-1)]*
      G[{0, 1, 0, yv^(-1)}, yw] - 2*G[{1}, yv^(-1)]*G[{0, 1, 0, yv^(-1)}, 
       yw] + 2*G[{1}, yw]*G[{0, 1, 0, yv^(-1)}, yw] + 
     2*G[{yu}, yv^(-1)]*G[{0, 1, 0, yv^(-1)}, yw] + 
     2*G[{1/(yu*yv)}, yw]*G[{0, 1, 0, yv^(-1)}, yw] - 
     2*G[{0}, yu^(-1)]*G[{0, 1, 0, 1/(yu*yv)}, yw] - 
     2*G[{0}, yv^(-1)]*G[{0, 1, 0, 1/(yu*yv)}, yw] + 
     2*G[{0}, yw]*G[{0, 1, 0, 1/(yu*yv)}, yw] + 4*G[{1}, yu^(-1)]*
      G[{0, 1, 0, 1/(yu*yv)}, yw] + 4*G[{1}, yv^(-1)]*
      G[{0, 1, 0, 1/(yu*yv)}, yw] - 2*G[{1}, yw]*G[{0, 1, 0, 1/(yu*yv)}, 
       yw] - 4*G[{yu}, yv^(-1)]*G[{0, 1, 0, 1/(yu*yv)}, yw] - 
     2*G[{1/(yu*yv)}, yw]*G[{0, 1, 0, 1/(yu*yv)}, yw] - 
     6*G[{0}, yu^(-1)]*G[{0, 1, 1, 1}, yv^(-1)] - 
     6*G[{0}, yv^(-1)]*G[{0, 1, 1, 1}, yv^(-1)] + 
     6*G[{0}, yw]*G[{0, 1, 1, 1}, yv^(-1)] + 12*G[{1}, yu^(-1)]*
      G[{0, 1, 1, 1}, yv^(-1)] + 6*G[{1}, yv^(-1)]*G[{0, 1, 1, 1}, yv^(-1)] - 
     6*G[{1}, yw]*G[{0, 1, 1, 1}, yv^(-1)] - 6*G[{1/(yu*yv)}, yw]*
      G[{0, 1, 1, 1}, yv^(-1)] + 6*G[{0}, yu^(-1)]*G[{0, 1, 1, 1}, yw] + 
     6*G[{0}, yv^(-1)]*G[{0, 1, 1, 1}, yw] - 6*G[{0}, yw]*
      G[{0, 1, 1, 1}, yw] - 12*G[{1}, yu^(-1)]*G[{0, 1, 1, 1}, yw] - 
     6*G[{1}, yv^(-1)]*G[{0, 1, 1, 1}, yw] - 6*G[{1}, yw]*
      G[{0, 1, 1, 1}, yw] + 6*G[{yu}, yv^(-1)]*G[{0, 1, 1, 1}, yw] + 
     6*G[{1/(yu*yv)}, yw]*G[{0, 1, 1, 1}, yw] - 6*G[{0}, yu^(-1)]*
      G[{0, 1, 1, yu^(-1)}, yw] - 6*G[{0}, yv^(-1)]*G[{0, 1, 1, yu^(-1)}, 
       yw] + 6*G[{0}, yw]*G[{0, 1, 1, yu^(-1)}, yw] + 
     12*G[{1}, yu^(-1)]*G[{0, 1, 1, yu^(-1)}, yw] + 
     12*G[{1}, yv^(-1)]*G[{0, 1, 1, yu^(-1)}, yw] + 
     2*G[{1}, yw]*G[{0, 1, 1, yu^(-1)}, yw] - 12*G[{yu}, yv^(-1)]*
      G[{0, 1, 1, yu^(-1)}, yw] - 6*G[{1/(yu*yv)}, yw]*
      G[{0, 1, 1, yu^(-1)}, yw] + 6*G[{0}, yu^(-1)]*
      G[{0, 1, 1, yu}, yv^(-1)] + 6*G[{0}, yv^(-1)]*
      G[{0, 1, 1, yu}, yv^(-1)] - 6*G[{0}, yw]*G[{0, 1, 1, yu}, yv^(-1)] - 
     12*G[{1}, yu^(-1)]*G[{0, 1, 1, yu}, yv^(-1)] - 
     2*G[{1}, yv^(-1)]*G[{0, 1, 1, yu}, yv^(-1)] + 
     2*G[{1}, yw]*G[{0, 1, 1, yu}, yv^(-1)] + 6*G[{1/(yu*yv)}, yw]*
      G[{0, 1, 1, yu}, yv^(-1)] - 8*G[{0}, yu^(-1)]*G[{0, 1, 1, yv^(-1)}, 
       yw] - 8*G[{0}, yv^(-1)]*G[{0, 1, 1, yv^(-1)}, yw] + 
     8*G[{0}, yw]*G[{0, 1, 1, yv^(-1)}, yw] + 16*G[{1}, yu^(-1)]*
      G[{0, 1, 1, yv^(-1)}, yw] + 12*G[{1}, yv^(-1)]*
      G[{0, 1, 1, yv^(-1)}, yw] - 12*G[{yu}, yv^(-1)]*
      G[{0, 1, 1, yv^(-1)}, yw] - 8*G[{1/(yu*yv)}, yw]*
      G[{0, 1, 1, yv^(-1)}, yw] + 4*G[{0}, yu^(-1)]*G[{0, 1, 1, 1/(yu*yv)}, 
       yw] + 4*G[{0}, yv^(-1)]*G[{0, 1, 1, 1/(yu*yv)}, yw] - 
     4*G[{0}, yw]*G[{0, 1, 1, 1/(yu*yv)}, yw] - 8*G[{1}, yu^(-1)]*
      G[{0, 1, 1, 1/(yu*yv)}, yw] - 10*G[{1}, yv^(-1)]*
      G[{0, 1, 1, 1/(yu*yv)}, yw] + 10*G[{yu}, yv^(-1)]*
      G[{0, 1, 1, 1/(yu*yv)}, yw] + 4*G[{1/(yu*yv)}, yw]*
      G[{0, 1, 1, 1/(yu*yv)}, yw] - 4*G[{0}, yu^(-1)]*
      G[{0, 1, yu^(-1), 1}, yw] - 4*G[{0}, yv^(-1)]*G[{0, 1, yu^(-1), 1}, 
       yw] + 4*G[{0}, yw]*G[{0, 1, yu^(-1), 1}, yw] + 
     8*G[{1}, yu^(-1)]*G[{0, 1, yu^(-1), 1}, yw] + 
     8*G[{1}, yv^(-1)]*G[{0, 1, yu^(-1), 1}, yw] - 
     8*G[{yu}, yv^(-1)]*G[{0, 1, yu^(-1), 1}, yw] - 
     4*G[{1/(yu*yv)}, yw]*G[{0, 1, yu^(-1), 1}, yw] + 
     4*G[{0}, yu^(-1)]*G[{0, 1, yu^(-1), yu^(-1)}, yw] + 
     4*G[{0}, yv^(-1)]*G[{0, 1, yu^(-1), yu^(-1)}, yw] - 
     4*G[{0}, yw]*G[{0, 1, yu^(-1), yu^(-1)}, yw] - 
     8*G[{1}, yu^(-1)]*G[{0, 1, yu^(-1), yu^(-1)}, yw] - 
     8*G[{1}, yv^(-1)]*G[{0, 1, yu^(-1), yu^(-1)}, yw] + 
     4*G[{1}, yw]*G[{0, 1, yu^(-1), yu^(-1)}, yw] + 
     8*G[{yu}, yv^(-1)]*G[{0, 1, yu^(-1), yu^(-1)}, yw] + 
     4*G[{1/(yu*yv)}, yw]*G[{0, 1, yu^(-1), yu^(-1)}, yw] + 
     4*G[{0}, yu^(-1)]*G[{0, 1, yu^(-1), yv^(-1)}, yw] + 
     4*G[{0}, yv^(-1)]*G[{0, 1, yu^(-1), yv^(-1)}, yw] - 
     4*G[{0}, yw]*G[{0, 1, yu^(-1), yv^(-1)}, yw] - 
     8*G[{1}, yu^(-1)]*G[{0, 1, yu^(-1), yv^(-1)}, yw] - 
     8*G[{1}, yv^(-1)]*G[{0, 1, yu^(-1), yv^(-1)}, yw] + 
     8*G[{yu}, yv^(-1)]*G[{0, 1, yu^(-1), yv^(-1)}, yw] + 
     4*G[{1/(yu*yv)}, yw]*G[{0, 1, yu^(-1), yv^(-1)}, yw] + 
     4*G[{1}, yv^(-1)]*G[{0, 1, yu^(-1), 1/(yu*yv)}, yw] - 
     4*G[{yu}, yv^(-1)]*G[{0, 1, yu^(-1), 1/(yu*yv)}, yw] + 
     4*G[{0}, yu^(-1)]*G[{0, 1, yu, 1}, yv^(-1)] + 
     4*G[{0}, yv^(-1)]*G[{0, 1, yu, 1}, yv^(-1)] - 
     4*G[{0}, yw]*G[{0, 1, yu, 1}, yv^(-1)] - 8*G[{1}, yu^(-1)]*
      G[{0, 1, yu, 1}, yv^(-1)] + 4*G[{1/(yu*yv)}, yw]*
      G[{0, 1, yu, 1}, yv^(-1)] - 4*G[{0}, yu^(-1)]*
      G[{0, 1, yu, yu}, yv^(-1)] - 4*G[{0}, yv^(-1)]*
      G[{0, 1, yu, yu}, yv^(-1)] + 4*G[{0}, yw]*G[{0, 1, yu, yu}, yv^(-1)] + 
     8*G[{1}, yu^(-1)]*G[{0, 1, yu, yu}, yv^(-1)] - 
     4*G[{1}, yv^(-1)]*G[{0, 1, yu, yu}, yv^(-1)] + 
     4*G[{1}, yw]*G[{0, 1, yu, yu}, yv^(-1)] - 4*G[{1/(yu*yv)}, yw]*
      G[{0, 1, yu, yu}, yv^(-1)] - 4*G[{0}, yu^(-1)]*
      G[{0, 1, yv^(-1), 1}, yw] - 4*G[{0}, yv^(-1)]*G[{0, 1, yv^(-1), 1}, 
       yw] + 4*G[{0}, yw]*G[{0, 1, yv^(-1), 1}, yw] + 
     8*G[{1}, yu^(-1)]*G[{0, 1, yv^(-1), 1}, yw] + 
     8*G[{1}, yv^(-1)]*G[{0, 1, yv^(-1), 1}, yw] - 
     8*G[{yu}, yv^(-1)]*G[{0, 1, yv^(-1), 1}, yw] - 
     4*G[{1/(yu*yv)}, yw]*G[{0, 1, yv^(-1), 1}, yw] + 
     4*G[{0}, yu^(-1)]*G[{0, 1, yv^(-1), yu^(-1)}, yw] + 
     4*G[{0}, yv^(-1)]*G[{0, 1, yv^(-1), yu^(-1)}, yw] - 
     4*G[{0}, yw]*G[{0, 1, yv^(-1), yu^(-1)}, yw] - 
     8*G[{1}, yu^(-1)]*G[{0, 1, yv^(-1), yu^(-1)}, yw] - 
     8*G[{1}, yv^(-1)]*G[{0, 1, yv^(-1), yu^(-1)}, yw] + 
     8*G[{yu}, yv^(-1)]*G[{0, 1, yv^(-1), yu^(-1)}, yw] + 
     4*G[{1/(yu*yv)}, yw]*G[{0, 1, yv^(-1), yu^(-1)}, yw] - 
     8*G[{1}, yv^(-1)]*G[{0, 1, yv^(-1), yv^(-1)}, yw] + 
     8*G[{yu}, yv^(-1)]*G[{0, 1, yv^(-1), yv^(-1)}, yw] + 
     4*G[{1}, yv^(-1)]*G[{0, 1, yv^(-1), 1/(yu*yv)}, yw] - 
     4*G[{yu}, yv^(-1)]*G[{0, 1, yv^(-1), 1/(yu*yv)}, yw] + 
     2*G[{0}, yu^(-1)]*G[{0, 1, 1/(yu*yv), 1}, yw] + 
     2*G[{0}, yv^(-1)]*G[{0, 1, 1/(yu*yv), 1}, yw] - 
     2*G[{0}, yw]*G[{0, 1, 1/(yu*yv), 1}, yw] - 4*G[{1}, yu^(-1)]*
      G[{0, 1, 1/(yu*yv), 1}, yw] - 6*G[{1}, yv^(-1)]*
      G[{0, 1, 1/(yu*yv), 1}, yw] + 2*G[{1}, yw]*G[{0, 1, 1/(yu*yv), 1}, 
       yw] + 6*G[{yu}, yv^(-1)]*G[{0, 1, 1/(yu*yv), 1}, yw] + 
     2*G[{1/(yu*yv)}, yw]*G[{0, 1, 1/(yu*yv), 1}, yw] - 
     2*G[{0}, yu^(-1)]*G[{0, 1, 1/(yu*yv), yu^(-1)}, yw] - 
     2*G[{0}, yv^(-1)]*G[{0, 1, 1/(yu*yv), yu^(-1)}, yw] + 
     2*G[{0}, yw]*G[{0, 1, 1/(yu*yv), yu^(-1)}, yw] + 
     4*G[{1}, yu^(-1)]*G[{0, 1, 1/(yu*yv), yu^(-1)}, yw] + 
     4*G[{1}, yv^(-1)]*G[{0, 1, 1/(yu*yv), yu^(-1)}, yw] - 
     2*G[{1}, yw]*G[{0, 1, 1/(yu*yv), yu^(-1)}, yw] - 
     4*G[{yu}, yv^(-1)]*G[{0, 1, 1/(yu*yv), yu^(-1)}, yw] - 
     2*G[{1/(yu*yv)}, yw]*G[{0, 1, 1/(yu*yv), yu^(-1)}, yw] + 
     4*G[{1}, yv^(-1)]*G[{0, 1, 1/(yu*yv), yv^(-1)}, yw] - 
     4*G[{yu}, yv^(-1)]*G[{0, 1, 1/(yu*yv), yv^(-1)}, yw] - 
     2*G[{1}, yv^(-1)]*G[{0, 1, 1/(yu*yv), 1/(yu*yv)}, yw] + 
     2*G[{yu}, yv^(-1)]*G[{0, 1, 1/(yu*yv), 1/(yu*yv)}, yw] - 
     2*G[{0}, yu^(-1)]*G[{0, yu^(-1), 0, yv^(-1)}, yw] - 
     2*G[{0}, yv^(-1)]*G[{0, yu^(-1), 0, yv^(-1)}, yw] + 
     2*G[{0}, yw]*G[{0, yu^(-1), 0, yv^(-1)}, yw] + 
     4*G[{1}, yu^(-1)]*G[{0, yu^(-1), 0, yv^(-1)}, yw] - 
     2*G[{1}, yw]*G[{0, yu^(-1), 0, yv^(-1)}, yw] - 
     2*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1), 0, yv^(-1)}, yw] + 
     2*G[{0}, yu^(-1)]*G[{0, yu^(-1), 0, 1/(yu*yv)}, yw] + 
     2*G[{0}, yv^(-1)]*G[{0, yu^(-1), 0, 1/(yu*yv)}, yw] - 
     2*G[{0}, yw]*G[{0, yu^(-1), 0, 1/(yu*yv)}, yw] - 
     4*G[{1}, yu^(-1)]*G[{0, yu^(-1), 0, 1/(yu*yv)}, yw] - 
     2*G[{1}, yv^(-1)]*G[{0, yu^(-1), 0, 1/(yu*yv)}, yw] + 
     2*G[{1}, yw]*G[{0, yu^(-1), 0, 1/(yu*yv)}, yw] + 
     2*G[{yu}, yv^(-1)]*G[{0, yu^(-1), 0, 1/(yu*yv)}, yw] + 
     2*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1), 0, 1/(yu*yv)}, yw] - 
     2*G[{0}, yu^(-1)]*G[{0, yu^(-1), 1, 1}, yw] - 
     2*G[{0}, yv^(-1)]*G[{0, yu^(-1), 1, 1}, yw] + 
     2*G[{0}, yw]*G[{0, yu^(-1), 1, 1}, yw] + 4*G[{1}, yu^(-1)]*
      G[{0, yu^(-1), 1, 1}, yw] + 2*G[{1}, yv^(-1)]*G[{0, yu^(-1), 1, 1}, 
       yw] + 2*G[{1}, yw]*G[{0, yu^(-1), 1, 1}, yw] - 
     2*G[{yu}, yv^(-1)]*G[{0, yu^(-1), 1, 1}, yw] - 
     2*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1), 1, 1}, yw] + 
     2*G[{0}, yu^(-1)]*G[{0, yu^(-1), 1, yu^(-1)}, yw] + 
     2*G[{0}, yv^(-1)]*G[{0, yu^(-1), 1, yu^(-1)}, yw] - 
     2*G[{0}, yw]*G[{0, yu^(-1), 1, yu^(-1)}, yw] - 
     4*G[{1}, yu^(-1)]*G[{0, yu^(-1), 1, yu^(-1)}, yw] - 
     4*G[{1}, yv^(-1)]*G[{0, yu^(-1), 1, yu^(-1)}, yw] + 
     2*G[{1}, yw]*G[{0, yu^(-1), 1, yu^(-1)}, yw] + 
     4*G[{yu}, yv^(-1)]*G[{0, yu^(-1), 1, yu^(-1)}, yw] + 
     2*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1), 1, yu^(-1)}, yw] + 
     4*G[{0}, yu^(-1)]*G[{0, yu^(-1), 1, yv^(-1)}, yw] + 
     4*G[{0}, yv^(-1)]*G[{0, yu^(-1), 1, yv^(-1)}, yw] - 
     4*G[{0}, yw]*G[{0, yu^(-1), 1, yv^(-1)}, yw] - 
     8*G[{1}, yu^(-1)]*G[{0, yu^(-1), 1, yv^(-1)}, yw] - 
     4*G[{1}, yv^(-1)]*G[{0, yu^(-1), 1, yv^(-1)}, yw] + 
     4*G[{yu}, yv^(-1)]*G[{0, yu^(-1), 1, yv^(-1)}, yw] + 
     4*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1), 1, yv^(-1)}, yw] + 
     2*G[{1}, yv^(-1)]*G[{0, yu^(-1), 1, 1/(yu*yv)}, yw] - 
     2*G[{yu}, yv^(-1)]*G[{0, yu^(-1), 1, 1/(yu*yv)}, yw] - 
     4*G[{1}, yv^(-1)]*G[{0, yu^(-1), yu^(-1), 1}, yw] + 
     4*G[{1}, yw]*G[{0, yu^(-1), yu^(-1), 1}, yw] + 
     4*G[{yu}, yv^(-1)]*G[{0, yu^(-1), yu^(-1), 1}, yw] - 
     8*G[{1}, yw]*G[{0, yu^(-1), yu^(-1), yu^(-1)}, yw] - 
     4*G[{0}, yu^(-1)]*G[{0, yu^(-1), yu^(-1), 1/(yu*yv)}, yw] - 
     4*G[{0}, yv^(-1)]*G[{0, yu^(-1), yu^(-1), 1/(yu*yv)}, yw] + 
     4*G[{0}, yw]*G[{0, yu^(-1), yu^(-1), 1/(yu*yv)}, yw] + 
     8*G[{1}, yu^(-1)]*G[{0, yu^(-1), yu^(-1), 1/(yu*yv)}, yw] + 
     4*G[{1}, yv^(-1)]*G[{0, yu^(-1), yu^(-1), 1/(yu*yv)}, yw] - 
     4*G[{yu}, yv^(-1)]*G[{0, yu^(-1), yu^(-1), 1/(yu*yv)}, yw] - 
     4*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1), yu^(-1), 1/(yu*yv)}, yw] + 
     2*G[{0}, yu^(-1)]*G[{0, yu^(-1), 1/(yu*yv), 1}, yw] + 
     2*G[{0}, yv^(-1)]*G[{0, yu^(-1), 1/(yu*yv), 1}, yw] - 
     2*G[{0}, yw]*G[{0, yu^(-1), 1/(yu*yv), 1}, yw] - 
     4*G[{1}, yu^(-1)]*G[{0, yu^(-1), 1/(yu*yv), 1}, yw] - 
     2*G[{1}, yv^(-1)]*G[{0, yu^(-1), 1/(yu*yv), 1}, yw] - 
     2*G[{1}, yw]*G[{0, yu^(-1), 1/(yu*yv), 1}, yw] + 
     2*G[{yu}, yv^(-1)]*G[{0, yu^(-1), 1/(yu*yv), 1}, yw] + 
     2*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1), 1/(yu*yv), 1}, yw] - 
     2*G[{0}, yu^(-1)]*G[{0, yu^(-1), 1/(yu*yv), yu^(-1)}, yw] - 
     2*G[{0}, yv^(-1)]*G[{0, yu^(-1), 1/(yu*yv), yu^(-1)}, yw] + 
     2*G[{0}, yw]*G[{0, yu^(-1), 1/(yu*yv), yu^(-1)}, yw] + 
     4*G[{1}, yu^(-1)]*G[{0, yu^(-1), 1/(yu*yv), yu^(-1)}, yw] + 
     4*G[{1}, yv^(-1)]*G[{0, yu^(-1), 1/(yu*yv), yu^(-1)}, yw] + 
     2*G[{1}, yw]*G[{0, yu^(-1), 1/(yu*yv), yu^(-1)}, yw] - 
     4*G[{yu}, yv^(-1)]*G[{0, yu^(-1), 1/(yu*yv), yu^(-1)}, yw] - 
     2*G[{1/(yu*yv)}, yw]*G[{0, yu^(-1), 1/(yu*yv), yu^(-1)}, yw] + 
     4*G[{1}, yv^(-1)]*G[{0, yu^(-1), 1/(yu*yv), yv^(-1)}, yw] - 
     4*G[{yu}, yv^(-1)]*G[{0, yu^(-1), 1/(yu*yv), yv^(-1)}, yw] - 
     2*G[{1}, yv^(-1)]*G[{0, yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] + 
     2*G[{yu}, yv^(-1)]*G[{0, yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] + 
     2*G[{0}, yu^(-1)]*G[{0, yu, 1, 1}, yv^(-1)] + 
     2*G[{0}, yv^(-1)]*G[{0, yu, 1, 1}, yv^(-1)] - 
     2*G[{0}, yw]*G[{0, yu, 1, 1}, yv^(-1)] - 4*G[{1}, yu^(-1)]*
      G[{0, yu, 1, 1}, yv^(-1)] - 2*G[{1}, yv^(-1)]*
      G[{0, yu, 1, 1}, yv^(-1)] + 2*G[{1}, yw]*G[{0, yu, 1, 1}, yv^(-1)] + 
     2*G[{1/(yu*yv)}, yw]*G[{0, yu, 1, 1}, yv^(-1)] - 
     2*G[{0}, yu^(-1)]*G[{0, yu, 1, yu}, yv^(-1)] - 
     2*G[{0}, yv^(-1)]*G[{0, yu, 1, yu}, yv^(-1)] + 
     2*G[{0}, yw]*G[{0, yu, 1, yu}, yv^(-1)] + 4*G[{1}, yu^(-1)]*
      G[{0, yu, 1, yu}, yv^(-1)] - 2*G[{1}, yv^(-1)]*
      G[{0, yu, 1, yu}, yv^(-1)] + 2*G[{1}, yw]*G[{0, yu, 1, yu}, yv^(-1)] - 
     2*G[{1/(yu*yv)}, yw]*G[{0, yu, 1, yu}, yv^(-1)] - 
     4*G[{1}, yv^(-1)]*G[{0, yu, yu, 1}, yv^(-1)] + 
     4*G[{1}, yw]*G[{0, yu, yu, 1}, yv^(-1)] + 8*G[{1}, yv^(-1)]*
      G[{0, yu, yu, yu}, yv^(-1)] - 8*G[{1}, yw]*G[{0, yu, yu, yu}, 
       yv^(-1)] - 2*G[{1}, yv^(-1)]*G[{0, yv^(-1), 0, 1/(yu*yv)}, yw] + 
     2*G[{yu}, yv^(-1)]*G[{0, yv^(-1), 0, 1/(yu*yv)}, yw] - 
     2*G[{0}, yu^(-1)]*G[{0, yv^(-1), 1, 1}, yw] - 
     2*G[{0}, yv^(-1)]*G[{0, yv^(-1), 1, 1}, yw] + 
     2*G[{0}, yw]*G[{0, yv^(-1), 1, 1}, yw] + 4*G[{1}, yu^(-1)]*
      G[{0, yv^(-1), 1, 1}, yw] + 2*G[{1}, yv^(-1)]*G[{0, yv^(-1), 1, 1}, 
       yw] + 2*G[{1}, yw]*G[{0, yv^(-1), 1, 1}, yw] - 
     2*G[{yu}, yv^(-1)]*G[{0, yv^(-1), 1, 1}, yw] - 
     2*G[{1/(yu*yv)}, yw]*G[{0, yv^(-1), 1, 1}, yw] + 
     2*G[{0}, yu^(-1)]*G[{0, yv^(-1), 1, yu^(-1)}, yw] + 
     2*G[{0}, yv^(-1)]*G[{0, yv^(-1), 1, yu^(-1)}, yw] - 
     2*G[{0}, yw]*G[{0, yv^(-1), 1, yu^(-1)}, yw] - 
     4*G[{1}, yu^(-1)]*G[{0, yv^(-1), 1, yu^(-1)}, yw] - 
     4*G[{1}, yv^(-1)]*G[{0, yv^(-1), 1, yu^(-1)}, yw] - 
     2*G[{1}, yw]*G[{0, yv^(-1), 1, yu^(-1)}, yw] + 
     4*G[{yu}, yv^(-1)]*G[{0, yv^(-1), 1, yu^(-1)}, yw] + 
     2*G[{1/(yu*yv)}, yw]*G[{0, yv^(-1), 1, yu^(-1)}, yw] - 
     4*G[{1}, yv^(-1)]*G[{0, yv^(-1), 1, yv^(-1)}, yw] + 
     4*G[{yu}, yv^(-1)]*G[{0, yv^(-1), 1, yv^(-1)}, yw] + 
     2*G[{1}, yv^(-1)]*G[{0, yv^(-1), 1, 1/(yu*yv)}, yw] - 
     2*G[{yu}, yv^(-1)]*G[{0, yv^(-1), 1, 1/(yu*yv)}, yw] - 
     4*G[{1}, yv^(-1)]*G[{0, yv^(-1), yv^(-1), 1}, yw] + 
     4*G[{1}, yw]*G[{0, yv^(-1), yv^(-1), 1}, yw] + 
     4*G[{yu}, yv^(-1)]*G[{0, yv^(-1), yv^(-1), 1}, yw] + 
     8*G[{0}, yu^(-1)]*G[{0, yv^(-1), yv^(-1), yv^(-1)}, yw] + 
     8*G[{0}, yv^(-1)]*G[{0, yv^(-1), yv^(-1), yv^(-1)}, yw] - 
     8*G[{0}, yw]*G[{0, yv^(-1), yv^(-1), yv^(-1)}, yw] - 
     16*G[{1}, yu^(-1)]*G[{0, yv^(-1), yv^(-1), yv^(-1)}, yw] + 
     8*G[{1/(yu*yv)}, yw]*G[{0, yv^(-1), yv^(-1), yv^(-1)}, yw] - 
     4*G[{0}, yu^(-1)]*G[{0, yv^(-1), yv^(-1), 1/(yu*yv)}, yw] - 
     4*G[{0}, yv^(-1)]*G[{0, yv^(-1), yv^(-1), 1/(yu*yv)}, yw] + 
     4*G[{0}, yw]*G[{0, yv^(-1), yv^(-1), 1/(yu*yv)}, yw] + 
     8*G[{1}, yu^(-1)]*G[{0, yv^(-1), yv^(-1), 1/(yu*yv)}, yw] + 
     4*G[{1}, yv^(-1)]*G[{0, yv^(-1), yv^(-1), 1/(yu*yv)}, yw] - 
     4*G[{yu}, yv^(-1)]*G[{0, yv^(-1), yv^(-1), 1/(yu*yv)}, yw] - 
     4*G[{1/(yu*yv)}, yw]*G[{0, yv^(-1), yv^(-1), 1/(yu*yv)}, yw] + 
     2*G[{0}, yu^(-1)]*G[{0, yv^(-1), 1/(yu*yv), 1}, yw] + 
     2*G[{0}, yv^(-1)]*G[{0, yv^(-1), 1/(yu*yv), 1}, yw] - 
     2*G[{0}, yw]*G[{0, yv^(-1), 1/(yu*yv), 1}, yw] - 
     4*G[{1}, yu^(-1)]*G[{0, yv^(-1), 1/(yu*yv), 1}, yw] - 
     2*G[{1}, yv^(-1)]*G[{0, yv^(-1), 1/(yu*yv), 1}, yw] - 
     2*G[{1}, yw]*G[{0, yv^(-1), 1/(yu*yv), 1}, yw] + 
     2*G[{yu}, yv^(-1)]*G[{0, yv^(-1), 1/(yu*yv), 1}, yw] + 
     2*G[{1/(yu*yv)}, yw]*G[{0, yv^(-1), 1/(yu*yv), 1}, yw] - 
     2*G[{0}, yu^(-1)]*G[{0, yv^(-1), 1/(yu*yv), yu^(-1)}, yw] - 
     2*G[{0}, yv^(-1)]*G[{0, yv^(-1), 1/(yu*yv), yu^(-1)}, yw] + 
     2*G[{0}, yw]*G[{0, yv^(-1), 1/(yu*yv), yu^(-1)}, yw] + 
     4*G[{1}, yu^(-1)]*G[{0, yv^(-1), 1/(yu*yv), yu^(-1)}, yw] + 
     4*G[{1}, yv^(-1)]*G[{0, yv^(-1), 1/(yu*yv), yu^(-1)}, yw] - 
     2*G[{1}, yw]*G[{0, yv^(-1), 1/(yu*yv), yu^(-1)}, yw] - 
     4*G[{yu}, yv^(-1)]*G[{0, yv^(-1), 1/(yu*yv), yu^(-1)}, yw] - 
     2*G[{1/(yu*yv)}, yw]*G[{0, yv^(-1), 1/(yu*yv), yu^(-1)}, yw] - 
     4*G[{0}, yu^(-1)]*G[{0, yv^(-1), 1/(yu*yv), yv^(-1)}, yw] - 
     4*G[{0}, yv^(-1)]*G[{0, yv^(-1), 1/(yu*yv), yv^(-1)}, yw] + 
     4*G[{0}, yw]*G[{0, yv^(-1), 1/(yu*yv), yv^(-1)}, yw] + 
     8*G[{1}, yu^(-1)]*G[{0, yv^(-1), 1/(yu*yv), yv^(-1)}, yw] + 
     4*G[{1}, yv^(-1)]*G[{0, yv^(-1), 1/(yu*yv), yv^(-1)}, yw] - 
     4*G[{yu}, yv^(-1)]*G[{0, yv^(-1), 1/(yu*yv), yv^(-1)}, yw] - 
     4*G[{1/(yu*yv)}, yw]*G[{0, yv^(-1), 1/(yu*yv), yv^(-1)}, yw] - 
     2*G[{1}, yv^(-1)]*G[{0, yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] + 
     2*G[{yu}, yv^(-1)]*G[{0, yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] - 
     2*G[{0}, yu^(-1)]*G[{0, 1/(yu*yv), 1, 1}, yw] - 
     2*G[{0}, yv^(-1)]*G[{0, 1/(yu*yv), 1, 1}, yw] + 
     2*G[{0}, yw]*G[{0, 1/(yu*yv), 1, 1}, yw] + 4*G[{1}, yu^(-1)]*
      G[{0, 1/(yu*yv), 1, 1}, yw] + 2*G[{1}, yv^(-1)]*
      G[{0, 1/(yu*yv), 1, 1}, yw] + 2*G[{1}, yw]*G[{0, 1/(yu*yv), 1, 1}, 
       yw] - 2*G[{yu}, yv^(-1)]*G[{0, 1/(yu*yv), 1, 1}, yw] - 
     2*G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv), 1, 1}, yw] + 
     2*G[{0}, yu^(-1)]*G[{0, 1/(yu*yv), 1, yu^(-1)}, yw] + 
     2*G[{0}, yv^(-1)]*G[{0, 1/(yu*yv), 1, yu^(-1)}, yw] - 
     2*G[{0}, yw]*G[{0, 1/(yu*yv), 1, yu^(-1)}, yw] - 
     4*G[{1}, yu^(-1)]*G[{0, 1/(yu*yv), 1, yu^(-1)}, yw] - 
     4*G[{1}, yv^(-1)]*G[{0, 1/(yu*yv), 1, yu^(-1)}, yw] - 
     2*G[{1}, yw]*G[{0, 1/(yu*yv), 1, yu^(-1)}, yw] + 
     4*G[{yu}, yv^(-1)]*G[{0, 1/(yu*yv), 1, yu^(-1)}, yw] + 
     2*G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv), 1, yu^(-1)}, yw] + 
     4*G[{0}, yu^(-1)]*G[{0, 1/(yu*yv), 1, yv^(-1)}, yw] + 
     4*G[{0}, yv^(-1)]*G[{0, 1/(yu*yv), 1, yv^(-1)}, yw] - 
     4*G[{0}, yw]*G[{0, 1/(yu*yv), 1, yv^(-1)}, yw] - 
     8*G[{1}, yu^(-1)]*G[{0, 1/(yu*yv), 1, yv^(-1)}, yw] - 
     4*G[{1}, yv^(-1)]*G[{0, 1/(yu*yv), 1, yv^(-1)}, yw] + 
     4*G[{yu}, yv^(-1)]*G[{0, 1/(yu*yv), 1, yv^(-1)}, yw] + 
     4*G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv), 1, yv^(-1)}, yw] - 
     4*G[{0}, yu^(-1)]*G[{0, 1/(yu*yv), 1, 1/(yu*yv)}, yw] - 
     4*G[{0}, yv^(-1)]*G[{0, 1/(yu*yv), 1, 1/(yu*yv)}, yw] + 
     4*G[{0}, yw]*G[{0, 1/(yu*yv), 1, 1/(yu*yv)}, yw] + 
     8*G[{1}, yu^(-1)]*G[{0, 1/(yu*yv), 1, 1/(yu*yv)}, yw] + 
     6*G[{1}, yv^(-1)]*G[{0, 1/(yu*yv), 1, 1/(yu*yv)}, yw] - 
     6*G[{yu}, yv^(-1)]*G[{0, 1/(yu*yv), 1, 1/(yu*yv)}, yw] - 
     4*G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv), 1, 1/(yu*yv)}, yw] + 
     4*G[{0}, yu^(-1)]*G[{0, 1/(yu*yv), yu^(-1), 1}, yw] + 
     4*G[{0}, yv^(-1)]*G[{0, 1/(yu*yv), yu^(-1), 1}, yw] - 
     4*G[{0}, yw]*G[{0, 1/(yu*yv), yu^(-1), 1}, yw] - 
     8*G[{1}, yu^(-1)]*G[{0, 1/(yu*yv), yu^(-1), 1}, yw] - 
     4*G[{1}, yv^(-1)]*G[{0, 1/(yu*yv), yu^(-1), 1}, yw] - 
     4*G[{1}, yw]*G[{0, 1/(yu*yv), yu^(-1), 1}, yw] + 
     4*G[{yu}, yv^(-1)]*G[{0, 1/(yu*yv), yu^(-1), 1}, yw] + 
     4*G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv), yu^(-1), 1}, yw] - 
     4*G[{0}, yu^(-1)]*G[{0, 1/(yu*yv), yu^(-1), yu^(-1)}, yw] - 
     4*G[{0}, yv^(-1)]*G[{0, 1/(yu*yv), yu^(-1), yu^(-1)}, yw] + 
     4*G[{0}, yw]*G[{0, 1/(yu*yv), yu^(-1), yu^(-1)}, yw] + 
     8*G[{1}, yu^(-1)]*G[{0, 1/(yu*yv), yu^(-1), yu^(-1)}, yw] + 
     8*G[{1}, yv^(-1)]*G[{0, 1/(yu*yv), yu^(-1), yu^(-1)}, yw] + 
     4*G[{1}, yw]*G[{0, 1/(yu*yv), yu^(-1), yu^(-1)}, yw] - 
     8*G[{yu}, yv^(-1)]*G[{0, 1/(yu*yv), yu^(-1), yu^(-1)}, yw] - 
     4*G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv), yu^(-1), yu^(-1)}, yw] - 
     4*G[{0}, yu^(-1)]*G[{0, 1/(yu*yv), yu^(-1), yv^(-1)}, yw] - 
     4*G[{0}, yv^(-1)]*G[{0, 1/(yu*yv), yu^(-1), yv^(-1)}, yw] + 
     4*G[{0}, yw]*G[{0, 1/(yu*yv), yu^(-1), yv^(-1)}, yw] + 
     8*G[{1}, yu^(-1)]*G[{0, 1/(yu*yv), yu^(-1), yv^(-1)}, yw] + 
     8*G[{1}, yv^(-1)]*G[{0, 1/(yu*yv), yu^(-1), yv^(-1)}, yw] - 
     8*G[{yu}, yv^(-1)]*G[{0, 1/(yu*yv), yu^(-1), yv^(-1)}, yw] - 
     4*G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv), yu^(-1), yv^(-1)}, yw] + 
     4*G[{0}, yu^(-1)]*G[{0, 1/(yu*yv), yu^(-1), 1/(yu*yv)}, yw] + 
     4*G[{0}, yv^(-1)]*G[{0, 1/(yu*yv), yu^(-1), 1/(yu*yv)}, yw] - 
     4*G[{0}, yw]*G[{0, 1/(yu*yv), yu^(-1), 1/(yu*yv)}, yw] - 
     8*G[{1}, yu^(-1)]*G[{0, 1/(yu*yv), yu^(-1), 1/(yu*yv)}, yw] - 
     8*G[{1}, yv^(-1)]*G[{0, 1/(yu*yv), yu^(-1), 1/(yu*yv)}, yw] + 
     8*G[{yu}, yv^(-1)]*G[{0, 1/(yu*yv), yu^(-1), 1/(yu*yv)}, yw] + 
     4*G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv), yu^(-1), 1/(yu*yv)}, yw] + 
     4*G[{0}, yu^(-1)]*G[{0, 1/(yu*yv), yv^(-1), 1}, yw] + 
     4*G[{0}, yv^(-1)]*G[{0, 1/(yu*yv), yv^(-1), 1}, yw] - 
     4*G[{0}, yw]*G[{0, 1/(yu*yv), yv^(-1), 1}, yw] - 
     8*G[{1}, yu^(-1)]*G[{0, 1/(yu*yv), yv^(-1), 1}, yw] - 
     4*G[{1}, yv^(-1)]*G[{0, 1/(yu*yv), yv^(-1), 1}, yw] - 
     4*G[{1}, yw]*G[{0, 1/(yu*yv), yv^(-1), 1}, yw] + 
     4*G[{yu}, yv^(-1)]*G[{0, 1/(yu*yv), yv^(-1), 1}, yw] + 
     4*G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv), yv^(-1), 1}, yw] - 
     4*G[{0}, yu^(-1)]*G[{0, 1/(yu*yv), yv^(-1), yu^(-1)}, yw] - 
     4*G[{0}, yv^(-1)]*G[{0, 1/(yu*yv), yv^(-1), yu^(-1)}, yw] + 
     4*G[{0}, yw]*G[{0, 1/(yu*yv), yv^(-1), yu^(-1)}, yw] + 
     8*G[{1}, yu^(-1)]*G[{0, 1/(yu*yv), yv^(-1), yu^(-1)}, yw] + 
     8*G[{1}, yv^(-1)]*G[{0, 1/(yu*yv), yv^(-1), yu^(-1)}, yw] - 
     8*G[{yu}, yv^(-1)]*G[{0, 1/(yu*yv), yv^(-1), yu^(-1)}, yw] - 
     4*G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv), yv^(-1), yu^(-1)}, yw] - 
     8*G[{0}, yu^(-1)]*G[{0, 1/(yu*yv), yv^(-1), yv^(-1)}, yw] - 
     8*G[{0}, yv^(-1)]*G[{0, 1/(yu*yv), yv^(-1), yv^(-1)}, yw] + 
     8*G[{0}, yw]*G[{0, 1/(yu*yv), yv^(-1), yv^(-1)}, yw] + 
     16*G[{1}, yu^(-1)]*G[{0, 1/(yu*yv), yv^(-1), yv^(-1)}, yw] + 
     8*G[{1}, yv^(-1)]*G[{0, 1/(yu*yv), yv^(-1), yv^(-1)}, yw] - 
     8*G[{yu}, yv^(-1)]*G[{0, 1/(yu*yv), yv^(-1), yv^(-1)}, yw] - 
     8*G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv), yv^(-1), yv^(-1)}, yw] + 
     4*G[{0}, yu^(-1)]*G[{0, 1/(yu*yv), yv^(-1), 1/(yu*yv)}, yw] + 
     4*G[{0}, yv^(-1)]*G[{0, 1/(yu*yv), yv^(-1), 1/(yu*yv)}, yw] - 
     4*G[{0}, yw]*G[{0, 1/(yu*yv), yv^(-1), 1/(yu*yv)}, yw] - 
     8*G[{1}, yu^(-1)]*G[{0, 1/(yu*yv), yv^(-1), 1/(yu*yv)}, yw] - 
     8*G[{1}, yv^(-1)]*G[{0, 1/(yu*yv), yv^(-1), 1/(yu*yv)}, yw] + 
     8*G[{yu}, yv^(-1)]*G[{0, 1/(yu*yv), yv^(-1), 1/(yu*yv)}, yw] + 
     4*G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv), yv^(-1), 1/(yu*yv)}, yw] - 
     6*G[{0}, yu^(-1)]*G[{0, 1/(yu*yv), 1/(yu*yv), 1}, yw] - 
     6*G[{0}, yv^(-1)]*G[{0, 1/(yu*yv), 1/(yu*yv), 1}, yw] + 
     6*G[{0}, yw]*G[{0, 1/(yu*yv), 1/(yu*yv), 1}, yw] + 
     12*G[{1}, yu^(-1)]*G[{0, 1/(yu*yv), 1/(yu*yv), 1}, yw] + 
     10*G[{1}, yv^(-1)]*G[{0, 1/(yu*yv), 1/(yu*yv), 1}, yw] + 
     2*G[{1}, yw]*G[{0, 1/(yu*yv), 1/(yu*yv), 1}, yw] - 
     10*G[{yu}, yv^(-1)]*G[{0, 1/(yu*yv), 1/(yu*yv), 1}, yw] - 
     6*G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv), 1/(yu*yv), 1}, yw] + 
     6*G[{0}, yu^(-1)]*G[{0, 1/(yu*yv), 1/(yu*yv), yu^(-1)}, yw] + 
     6*G[{0}, yv^(-1)]*G[{0, 1/(yu*yv), 1/(yu*yv), yu^(-1)}, yw] - 
     6*G[{0}, yw]*G[{0, 1/(yu*yv), 1/(yu*yv), yu^(-1)}, yw] - 
     12*G[{1}, yu^(-1)]*G[{0, 1/(yu*yv), 1/(yu*yv), yu^(-1)}, yw] - 
     12*G[{1}, yv^(-1)]*G[{0, 1/(yu*yv), 1/(yu*yv), yu^(-1)}, yw] + 
     2*G[{1}, yw]*G[{0, 1/(yu*yv), 1/(yu*yv), yu^(-1)}, yw] + 
     12*G[{yu}, yv^(-1)]*G[{0, 1/(yu*yv), 1/(yu*yv), yu^(-1)}, yw] + 
     6*G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv), 1/(yu*yv), yu^(-1)}, yw] + 
     4*G[{0}, yu^(-1)]*G[{0, 1/(yu*yv), 1/(yu*yv), yv^(-1)}, yw] + 
     4*G[{0}, yv^(-1)]*G[{0, 1/(yu*yv), 1/(yu*yv), yv^(-1)}, yw] - 
     4*G[{0}, yw]*G[{0, 1/(yu*yv), 1/(yu*yv), yv^(-1)}, yw] - 
     8*G[{1}, yu^(-1)]*G[{0, 1/(yu*yv), 1/(yu*yv), yv^(-1)}, yw] - 
     12*G[{1}, yv^(-1)]*G[{0, 1/(yu*yv), 1/(yu*yv), yv^(-1)}, yw] + 
     12*G[{yu}, yv^(-1)]*G[{0, 1/(yu*yv), 1/(yu*yv), yv^(-1)}, yw] + 
     4*G[{1/(yu*yv)}, yw]*G[{0, 1/(yu*yv), 1/(yu*yv), yv^(-1)}, yw] + 
     6*G[{1}, yv^(-1)]*G[{0, 1/(yu*yv), 1/(yu*yv), 1/(yu*yv)}, yw] - 
     6*G[{yu}, yv^(-1)]*G[{0, 1/(yu*yv), 1/(yu*yv), 1/(yu*yv)}, yw] + 
     12*G[{0, 0, 0, 1, 1}, yu^(-1)] + 12*G[{0, 0, 0, 1, 1}, yw] - 
     12*G[{0, 0, 0, 1, yu^(-1)}, yw] - 12*G[{0, 0, 0, 1, yv^(-1)}, yw] + 
     12*G[{0, 0, 0, 1, 1/(yu*yv)}, yw] - 12*G[{0, 0, 0, yu^(-1), 1}, yw] + 
     12*G[{0, 0, 0, yu^(-1), yu^(-1)}, yw] + 
     12*G[{0, 0, 0, yu^(-1), yv^(-1)}, yw] - 
     12*G[{0, 0, 0, yu^(-1), 1/(yu*yv)}, yw] - 
     12*G[{0, 0, 0, yv^(-1), 1}, yw] + 12*G[{0, 0, 0, yv^(-1), yu^(-1)}, 
       yw] + 12*G[{0, 0, 0, yv^(-1), yv^(-1)}, yw] - 
     12*G[{0, 0, 0, yv^(-1), 1/(yu*yv)}, yw] + 
     12*G[{0, 0, 0, 1/(yu*yv), 1}, yw] - 12*G[{0, 0, 0, 1/(yu*yv), yu^(-1)}, 
       yw] - 12*G[{0, 0, 0, 1/(yu*yv), yv^(-1)}, yw] + 
     12*G[{0, 0, 0, 1/(yu*yv), 1/(yu*yv)}, yw] + 
     4*G[{0, 0, 1, 0, 1}, yu^(-1)] + 4*G[{0, 0, 1, 0, 1}, yw] - 
     4*G[{0, 0, 1, 0, yu^(-1)}, yw] - 4*G[{0, 0, 1, 0, yv^(-1)}, yw] + 
     4*G[{0, 0, 1, 0, 1/(yu*yv)}, yw] - 12*G[{0, 0, 1, 1, 1}, yu^(-1)] - 
     24*G[{0, 0, 1, 1, 1}, yv^(-1)] + 12*G[{0, 0, 1, 1, 1}, yw] - 
     12*G[{0, 0, 1, 1, yu^(-1)}, yw] + 8*G[{0, 0, 1, 1, yu}, yv^(-1)] - 
     12*G[{0, 0, 1, 1, yv^(-1)}, yw] + 8*G[{0, 0, 1, 1, 1/(yu*yv)}, yw] - 
     8*G[{0, 0, 1, yu^(-1), 1}, yw] - 8*G[{0, 0, 1, yu^(-1), yu^(-1)}, yw] - 
     4*G[{0, 0, 1, yu^(-1), yv^(-1)}, yw] + 
     4*G[{0, 0, 1, yu^(-1), 1/(yu*yv)}, yw] + 
     8*G[{0, 0, 1, yu, 1}, yv^(-1)] - 8*G[{0, 0, 1, yv^(-1), 1}, yw] - 
     4*G[{0, 0, 1, yv^(-1), yu^(-1)}, yw] + 
     4*G[{0, 0, 1, yv^(-1), 1/(yu*yv)}, yw] + 
     8*G[{0, 0, 1, 1/(yu*yv), 1}, yw] + 4*G[{0, 0, 1, 1/(yu*yv), 1/(yu*yv)}, 
       yw] - 4*G[{0, 0, yu^(-1), 0, 1}, yw] + 
     4*G[{0, 0, yu^(-1), 0, yu^(-1)}, yw] + 
     4*G[{0, 0, yu^(-1), 0, yv^(-1)}, yw] - 
     4*G[{0, 0, yu^(-1), 0, 1/(yu*yv)}, yw] - 
     8*G[{0, 0, yu^(-1), 1, 1}, yw] + 4*G[{0, 0, yu^(-1), 1, yu^(-1)}, yw] + 
     12*G[{0, 0, yu^(-1), yu^(-1), 1}, yw] - 
     16*G[{0, 0, yu^(-1), yu^(-1), yu^(-1)}, yw] - 
     4*G[{0, 0, yu^(-1), yu^(-1), 1/(yu*yv)}, yw] + 
     4*G[{0, 0, yu^(-1), yv^(-1), 1}, yw] - 
     4*G[{0, 0, yu^(-1), 1/(yu*yv), 1}, yw] + 
     4*G[{0, 0, yu^(-1), 1/(yu*yv), yv^(-1)}, yw] - 
     4*G[{0, 0, yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] + 
     8*G[{0, 0, yu, 1, 1}, yv^(-1)] - 4*G[{0, 0, yu, 1, yu}, yv^(-1)] - 
     8*G[{0, 0, yu, yu, 1}, yv^(-1)] - 4*G[{0, 0, yv^(-1), 0, 1}, yw] + 
     4*G[{0, 0, yv^(-1), 0, yu^(-1)}, yw] + 
     4*G[{0, 0, yv^(-1), 0, yv^(-1)}, yw] - 
     4*G[{0, 0, yv^(-1), 0, 1/(yu*yv)}, yw] - 
     8*G[{0, 0, yv^(-1), 1, 1}, yw] + 4*G[{0, 0, yv^(-1), 1, yu^(-1)}, yw] + 
     4*G[{0, 0, yv^(-1), yu^(-1), 1}, yw] - 
     4*G[{0, 0, yv^(-1), yv^(-1), 1}, yw] + 
     8*G[{0, 0, yv^(-1), yv^(-1), yv^(-1)}, yw] - 
     12*G[{0, 0, yv^(-1), yv^(-1), 1/(yu*yv)}, yw] - 
     8*G[{0, 0, yv^(-1), 1/(yu*yv), yv^(-1)}, yw] - 
     4*G[{0, 0, yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] + 
     4*G[{0, 0, 1/(yu*yv), 0, 1}, yw] - 4*G[{0, 0, 1/(yu*yv), 0, yu^(-1)}, 
       yw] - 4*G[{0, 0, 1/(yu*yv), 0, yv^(-1)}, yw] + 
     4*G[{0, 0, 1/(yu*yv), 0, 1/(yu*yv)}, yw] + 
     8*G[{0, 0, 1/(yu*yv), 1, 1}, yw] - 4*G[{0, 0, 1/(yu*yv), 1, yu^(-1)}, 
       yw] - 4*G[{0, 0, 1/(yu*yv), yu^(-1), 1}, yw] - 
     8*G[{0, 0, 1/(yu*yv), yv^(-1), yv^(-1)}, yw] + 
     4*G[{0, 0, 1/(yu*yv), yv^(-1), 1/(yu*yv)}, yw] - 
     4*G[{0, 0, 1/(yu*yv), 1/(yu*yv), 1}, yw] + 
     8*G[{0, 0, 1/(yu*yv), 1/(yu*yv), yv^(-1)}, yw] - 
     12*G[{0, 0, 1/(yu*yv), 1/(yu*yv), 1/(yu*yv)}, yw] - 
     4*G[{0, 1, 0, 1, 1}, yu^(-1)] - 8*G[{0, 1, 0, 1, 1}, yv^(-1)] + 
     2*G[{0, 1, 0, 1, 1}, yw] - 4*G[{0, 1, 0, 1, yu^(-1)}, yw] + 
     2*G[{0, 1, 0, 1, yu}, yv^(-1)] - 6*G[{0, 1, 0, 1, yv^(-1)}, yw] + 
     4*G[{0, 1, 0, 1, 1/(yu*yv)}, yw] - 2*G[{0, 1, 0, yu^(-1), 1}, yw] - 
     4*G[{0, 1, 0, yu^(-1), yu^(-1)}, yw] - 
     2*G[{0, 1, 0, yu^(-1), yv^(-1)}, yw] + 
     2*G[{0, 1, 0, yu^(-1), 1/(yu*yv)}, yw] + 
     2*G[{0, 1, 0, yu, 1}, yv^(-1)] - 4*G[{0, 1, 0, yv^(-1), 1}, yw] - 
     2*G[{0, 1, 0, yv^(-1), yu^(-1)}, yw] + 
     4*G[{0, 1, 0, yv^(-1), yv^(-1)}, yw] + 
     6*G[{0, 1, 0, 1/(yu*yv), 1}, yw] - 2*G[{0, 1, 0, 1/(yu*yv), yu^(-1)}, 
       yw] - 4*G[{0, 1, 0, 1/(yu*yv), yv^(-1)}, yw] + 
     4*G[{0, 1, 0, 1/(yu*yv), 1/(yu*yv)}, yw] + 
     2*G[{0, 1, 1, 0, yu^(-1)}, yw] - 4*G[{0, 1, 1, 0, yu}, yv^(-1)] - 
     2*G[{0, 1, 1, 0, yv^(-1)}, yw] + 2*G[{0, 1, 1, 0, 1/(yu*yv)}, yw] + 
     6*G[{0, 1, 1, 1, yu^(-1)}, yw] - 6*G[{0, 1, 1, 1, yu}, yv^(-1)] + 
     12*G[{0, 1, 1, 1, yv^(-1)}, yw] - 6*G[{0, 1, 1, 1, 1/(yu*yv)}, yw] + 
     10*G[{0, 1, 1, yu^(-1), 1}, yw] - 12*G[{0, 1, 1, yu^(-1), yu^(-1)}, 
       yw] - 12*G[{0, 1, 1, yu^(-1), yv^(-1)}, yw] + 
     6*G[{0, 1, 1, yu^(-1), 1/(yu*yv)}, yw] - 
     10*G[{0, 1, 1, yu, 1}, yv^(-1)] + 12*G[{0, 1, 1, yu, yu}, yv^(-1)] + 
     12*G[{0, 1, 1, yv^(-1), 1}, yw] - 12*G[{0, 1, 1, yv^(-1), yu^(-1)}, 
       yw] - 16*G[{0, 1, 1, yv^(-1), yv^(-1)}, yw] + 
     8*G[{0, 1, 1, yv^(-1), 1/(yu*yv)}, yw] - 
     10*G[{0, 1, 1, 1/(yu*yv), 1}, yw] + 10*G[{0, 1, 1, 1/(yu*yv), yu^(-1)}, 
       yw] + 8*G[{0, 1, 1, 1/(yu*yv), yv^(-1)}, yw] - 
     4*G[{0, 1, 1, 1/(yu*yv), 1/(yu*yv)}, yw] - 
     6*G[{0, 1, yu^(-1), 0, yu^(-1)}, yw] - 
     2*G[{0, 1, yu^(-1), 0, yv^(-1)}, yw] + 
     2*G[{0, 1, yu^(-1), 0, 1/(yu*yv)}, yw] + 
     8*G[{0, 1, yu^(-1), 1, 1}, yw] - 8*G[{0, 1, yu^(-1), 1, yu^(-1)}, yw] - 
     8*G[{0, 1, yu^(-1), 1, yv^(-1)}, yw] + 
     4*G[{0, 1, yu^(-1), 1, 1/(yu*yv)}, yw] - 
     12*G[{0, 1, yu^(-1), yu^(-1), 1}, yw] + 
     8*G[{0, 1, yu^(-1), yu^(-1), yu^(-1)}, yw] + 
     8*G[{0, 1, yu^(-1), yu^(-1), yv^(-1)}, yw] - 
     4*G[{0, 1, yu^(-1), yu^(-1), 1/(yu*yv)}, yw] - 
     8*G[{0, 1, yu^(-1), yv^(-1), 1}, yw] + 
     8*G[{0, 1, yu^(-1), yv^(-1), yu^(-1)}, yw] + 
     8*G[{0, 1, yu^(-1), yv^(-1), yv^(-1)}, yw] - 
     4*G[{0, 1, yu^(-1), yv^(-1), 1/(yu*yv)}, yw] + 
     4*G[{0, 1, yu^(-1), 1/(yu*yv), 1}, yw] - 
     4*G[{0, 1, yu^(-1), 1/(yu*yv), yu^(-1)}, yw] + 
     2*G[{0, 1, yu, 0, yu}, yv^(-1)] - 8*G[{0, 1, yu, 1, 1}, yv^(-1)] + 
     8*G[{0, 1, yu, 1, yu}, yv^(-1)] + 12*G[{0, 1, yu, yu, 1}, yv^(-1)] - 
     8*G[{0, 1, yu, yu, yu}, yv^(-1)] - 4*G[{0, 1, yv^(-1), 0, yu^(-1)}, 
       yw] + 8*G[{0, 1, yv^(-1), 1, 1}, yw] - 
     8*G[{0, 1, yv^(-1), 1, yu^(-1)}, yw] - 
     8*G[{0, 1, yv^(-1), 1, yv^(-1)}, yw] + 
     4*G[{0, 1, yv^(-1), 1, 1/(yu*yv)}, yw] - 
     8*G[{0, 1, yv^(-1), yu^(-1), 1}, yw] + 
     8*G[{0, 1, yv^(-1), yu^(-1), yu^(-1)}, yw] + 
     8*G[{0, 1, yv^(-1), yu^(-1), yv^(-1)}, yw] - 
     4*G[{0, 1, yv^(-1), yu^(-1), 1/(yu*yv)}, yw] - 
     8*G[{0, 1, yv^(-1), yv^(-1), 1}, yw] + 
     8*G[{0, 1, yv^(-1), yv^(-1), yu^(-1)}, yw] + 
     4*G[{0, 1, yv^(-1), 1/(yu*yv), 1}, yw] - 
     4*G[{0, 1, yv^(-1), 1/(yu*yv), yu^(-1)}, yw] + 
     2*G[{0, 1, 1/(yu*yv), 0, yu^(-1)}, yw] + 
     2*G[{0, 1, 1/(yu*yv), 0, 1/(yu*yv)}, yw] - 
     8*G[{0, 1, 1/(yu*yv), 1, 1}, yw] + 6*G[{0, 1, 1/(yu*yv), 1, yu^(-1)}, 
       yw] + 4*G[{0, 1, 1/(yu*yv), 1, yv^(-1)}, yw] - 
     2*G[{0, 1, 1/(yu*yv), 1, 1/(yu*yv)}, yw] + 
     6*G[{0, 1, 1/(yu*yv), yu^(-1), 1}, yw] - 
     4*G[{0, 1, 1/(yu*yv), yu^(-1), yu^(-1)}, yw] - 
     4*G[{0, 1, 1/(yu*yv), yu^(-1), yv^(-1)}, yw] + 
     2*G[{0, 1, 1/(yu*yv), yu^(-1), 1/(yu*yv)}, yw] + 
     4*G[{0, 1, 1/(yu*yv), yv^(-1), 1}, yw] - 
     4*G[{0, 1, 1/(yu*yv), yv^(-1), yu^(-1)}, yw] - 
     2*G[{0, 1, 1/(yu*yv), 1/(yu*yv), 1}, yw] + 
     2*G[{0, 1, 1/(yu*yv), 1/(yu*yv), yu^(-1)}, yw] + 
     4*G[{0, yu^(-1), 0, yu^(-1), 1}, yw] - 
     8*G[{0, yu^(-1), 0, yu^(-1), yu^(-1)}, yw] - 
     2*G[{0, yu^(-1), 0, yu^(-1), 1/(yu*yv)}, yw] + 
     2*G[{0, yu^(-1), 0, yv^(-1), 1}, yw] - 
     4*G[{0, yu^(-1), 0, yv^(-1), yv^(-1)}, yw] + 
     2*G[{0, yu^(-1), 0, yv^(-1), 1/(yu*yv)}, yw] - 
     4*G[{0, yu^(-1), 0, 1/(yu*yv), 1}, yw] + 
     2*G[{0, yu^(-1), 0, 1/(yu*yv), yu^(-1)}, yw] + 
     6*G[{0, yu^(-1), 0, 1/(yu*yv), yv^(-1)}, yw] - 
     4*G[{0, yu^(-1), 0, 1/(yu*yv), 1/(yu*yv)}, yw] - 
     2*G[{0, yu^(-1), 1, 1, yu^(-1)}, yw] - 
     4*G[{0, yu^(-1), 1, 1, yv^(-1)}, yw] + 
     2*G[{0, yu^(-1), 1, 1, 1/(yu*yv)}, yw] - 
     6*G[{0, yu^(-1), 1, yu^(-1), 1}, yw] + 
     4*G[{0, yu^(-1), 1, yu^(-1), yu^(-1)}, yw] + 
     4*G[{0, yu^(-1), 1, yu^(-1), yv^(-1)}, yw] - 
     2*G[{0, yu^(-1), 1, yu^(-1), 1/(yu*yv)}, yw] - 
     4*G[{0, yu^(-1), 1, yv^(-1), 1}, yw] + 
     4*G[{0, yu^(-1), 1, yv^(-1), yu^(-1)}, yw] + 
     8*G[{0, yu^(-1), 1, yv^(-1), yv^(-1)}, yw] - 
     4*G[{0, yu^(-1), 1, yv^(-1), 1/(yu*yv)}, yw] + 
     2*G[{0, yu^(-1), 1, 1/(yu*yv), 1}, yw] - 
     2*G[{0, yu^(-1), 1, 1/(yu*yv), yu^(-1)}, yw] + 
     4*G[{0, yu^(-1), yu^(-1), 0, yv^(-1)}, yw] - 
     4*G[{0, yu^(-1), yu^(-1), 0, 1/(yu*yv)}, yw] - 
     8*G[{0, yu^(-1), yu^(-1), 1, 1}, yw] + 
     4*G[{0, yu^(-1), yu^(-1), 1, yu^(-1)}, yw] + 
     8*G[{0, yu^(-1), yu^(-1), yu^(-1), 1}, yw] + 
     4*G[{0, yu^(-1), yu^(-1), 1/(yu*yv), 1}, yw] - 
     4*G[{0, yu^(-1), yu^(-1), 1/(yu*yv), yu^(-1)}, yw] - 
     8*G[{0, yu^(-1), yu^(-1), 1/(yu*yv), yv^(-1)}, yw] + 
     4*G[{0, yu^(-1), yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] + 
     2*G[{0, yu^(-1), 1/(yu*yv), 0, yv^(-1)}, yw] - 
     2*G[{0, yu^(-1), 1/(yu*yv), 0, 1/(yu*yv)}, yw] + 
     2*G[{0, yu^(-1), 1/(yu*yv), 1, yu^(-1)}, yw] + 
     4*G[{0, yu^(-1), 1/(yu*yv), 1, yv^(-1)}, yw] - 
     2*G[{0, yu^(-1), 1/(yu*yv), 1, 1/(yu*yv)}, yw] + 
     2*G[{0, yu^(-1), 1/(yu*yv), yu^(-1), 1}, yw] - 
     4*G[{0, yu^(-1), 1/(yu*yv), yu^(-1), yu^(-1)}, yw] - 
     4*G[{0, yu^(-1), 1/(yu*yv), yu^(-1), yv^(-1)}, yw] + 
     2*G[{0, yu^(-1), 1/(yu*yv), yu^(-1), 1/(yu*yv)}, yw] + 
     4*G[{0, yu^(-1), 1/(yu*yv), yv^(-1), 1}, yw] - 
     4*G[{0, yu^(-1), 1/(yu*yv), yv^(-1), yu^(-1)}, yw] - 
     2*G[{0, yu^(-1), 1/(yu*yv), 1/(yu*yv), 1}, yw] + 
     2*G[{0, yu^(-1), 1/(yu*yv), 1/(yu*yv), yu^(-1)}, yw] - 
     2*G[{0, yu, 0, yu, 1}, yv^(-1)] + 2*G[{0, yu, 1, 1, yu}, yv^(-1)] + 
     6*G[{0, yu, 1, yu, 1}, yv^(-1)] - 4*G[{0, yu, 1, yu, yu}, yv^(-1)] + 
     8*G[{0, yu, yu, 1, 1}, yv^(-1)] - 4*G[{0, yu, yu, 1, yu}, yv^(-1)] - 
     8*G[{0, yu, yu, yu, 1}, yv^(-1)] - 2*G[{0, yv^(-1), 0, yv^(-1), 1}, 
       yw] - 4*G[{0, yv^(-1), 0, yv^(-1), 1/(yu*yv)}, yw] - 
     2*G[{0, yv^(-1), 0, 1/(yu*yv), 1}, yw] + 
     2*G[{0, yv^(-1), 0, 1/(yu*yv), yu^(-1)}, yw] - 
     4*G[{0, yv^(-1), 0, 1/(yu*yv), 1/(yu*yv)}, yw] - 
     2*G[{0, yv^(-1), 1, 0, 1/(yu*yv)}, yw] - 
     2*G[{0, yv^(-1), 1, 1, yu^(-1)}, yw] - 
     4*G[{0, yv^(-1), 1, 1, yv^(-1)}, yw] + 
     2*G[{0, yv^(-1), 1, 1, 1/(yu*yv)}, yw] - 
     2*G[{0, yv^(-1), 1, yu^(-1), 1}, yw] + 
     4*G[{0, yv^(-1), 1, yu^(-1), yu^(-1)}, yw] + 
     4*G[{0, yv^(-1), 1, yu^(-1), yv^(-1)}, yw] - 
     2*G[{0, yv^(-1), 1, yu^(-1), 1/(yu*yv)}, yw] - 
     4*G[{0, yv^(-1), 1, yv^(-1), 1}, yw] + 
     4*G[{0, yv^(-1), 1, yv^(-1), yu^(-1)}, yw] + 
     2*G[{0, yv^(-1), 1, 1/(yu*yv), 1}, yw] - 
     2*G[{0, yv^(-1), 1, 1/(yu*yv), yu^(-1)}, yw] - 
     8*G[{0, yv^(-1), yv^(-1), 1, 1}, yw] + 
     4*G[{0, yv^(-1), yv^(-1), 1, yu^(-1)}, yw] + 
     16*G[{0, yv^(-1), yv^(-1), yv^(-1), yv^(-1)}, yw] - 
     8*G[{0, yv^(-1), yv^(-1), yv^(-1), 1/(yu*yv)}, yw] + 
     4*G[{0, yv^(-1), yv^(-1), 1/(yu*yv), 1}, yw] - 
     4*G[{0, yv^(-1), yv^(-1), 1/(yu*yv), yu^(-1)}, yw] - 
     8*G[{0, yv^(-1), yv^(-1), 1/(yu*yv), yv^(-1)}, yw] + 
     4*G[{0, yv^(-1), yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] - 
     4*G[{0, yv^(-1), 1/(yu*yv), 0, 1/(yu*yv)}, yw] + 
     2*G[{0, yv^(-1), 1/(yu*yv), 1, yu^(-1)}, yw] + 
     4*G[{0, yv^(-1), 1/(yu*yv), 1, yv^(-1)}, yw] - 
     2*G[{0, yv^(-1), 1/(yu*yv), 1, 1/(yu*yv)}, yw] + 
     6*G[{0, yv^(-1), 1/(yu*yv), yu^(-1), 1}, yw] - 
     4*G[{0, yv^(-1), 1/(yu*yv), yu^(-1), yu^(-1)}, yw] - 
     4*G[{0, yv^(-1), 1/(yu*yv), yu^(-1), yv^(-1)}, yw] + 
     2*G[{0, yv^(-1), 1/(yu*yv), yu^(-1), 1/(yu*yv)}, yw] + 
     4*G[{0, yv^(-1), 1/(yu*yv), yv^(-1), 1}, yw] - 
     4*G[{0, yv^(-1), 1/(yu*yv), yv^(-1), yu^(-1)}, yw] - 
     8*G[{0, yv^(-1), 1/(yu*yv), yv^(-1), yv^(-1)}, yw] + 
     4*G[{0, yv^(-1), 1/(yu*yv), yv^(-1), 1/(yu*yv)}, yw] - 
     2*G[{0, yv^(-1), 1/(yu*yv), 1/(yu*yv), 1}, yw] + 
     2*G[{0, yv^(-1), 1/(yu*yv), 1/(yu*yv), yu^(-1)}, yw] - 
     2*G[{0, 1/(yu*yv), 0, 1/(yu*yv), yu^(-1)}, yw] - 
     4*G[{0, 1/(yu*yv), 0, 1/(yu*yv), 1/(yu*yv)}, yw] - 
     2*G[{0, 1/(yu*yv), 1, 1, yu^(-1)}, yw] - 
     4*G[{0, 1/(yu*yv), 1, 1, yv^(-1)}, yw] + 
     2*G[{0, 1/(yu*yv), 1, 1, 1/(yu*yv)}, yw] - 
     2*G[{0, 1/(yu*yv), 1, yu^(-1), 1}, yw] + 
     4*G[{0, 1/(yu*yv), 1, yu^(-1), yu^(-1)}, yw] + 
     4*G[{0, 1/(yu*yv), 1, yu^(-1), yv^(-1)}, yw] - 
     2*G[{0, 1/(yu*yv), 1, yu^(-1), 1/(yu*yv)}, yw] - 
     4*G[{0, 1/(yu*yv), 1, yv^(-1), 1}, yw] + 
     4*G[{0, 1/(yu*yv), 1, yv^(-1), yu^(-1)}, yw] + 
     8*G[{0, 1/(yu*yv), 1, yv^(-1), yv^(-1)}, yw] - 
     4*G[{0, 1/(yu*yv), 1, yv^(-1), 1/(yu*yv)}, yw] + 
     6*G[{0, 1/(yu*yv), 1, 1/(yu*yv), 1}, yw] - 
     6*G[{0, 1/(yu*yv), 1, 1/(yu*yv), yu^(-1)}, yw] - 
     8*G[{0, 1/(yu*yv), 1, 1/(yu*yv), yv^(-1)}, yw] + 
     4*G[{0, 1/(yu*yv), 1, 1/(yu*yv), 1/(yu*yv)}, yw] + 
     4*G[{0, 1/(yu*yv), yu^(-1), 1, yu^(-1)}, yw] + 
     8*G[{0, 1/(yu*yv), yu^(-1), 1, yv^(-1)}, yw] - 
     4*G[{0, 1/(yu*yv), yu^(-1), 1, 1/(yu*yv)}, yw] + 
     4*G[{0, 1/(yu*yv), yu^(-1), yu^(-1), 1}, yw] - 
     8*G[{0, 1/(yu*yv), yu^(-1), yu^(-1), yu^(-1)}, yw] - 
     8*G[{0, 1/(yu*yv), yu^(-1), yu^(-1), yv^(-1)}, yw] + 
     4*G[{0, 1/(yu*yv), yu^(-1), yu^(-1), 1/(yu*yv)}, yw] + 
     8*G[{0, 1/(yu*yv), yu^(-1), yv^(-1), 1}, yw] - 
     8*G[{0, 1/(yu*yv), yu^(-1), yv^(-1), yu^(-1)}, yw] - 
     8*G[{0, 1/(yu*yv), yu^(-1), yv^(-1), yv^(-1)}, yw] + 
     4*G[{0, 1/(yu*yv), yu^(-1), yv^(-1), 1/(yu*yv)}, yw] - 
     8*G[{0, 1/(yu*yv), yu^(-1), 1/(yu*yv), 1}, yw] + 
     8*G[{0, 1/(yu*yv), yu^(-1), 1/(yu*yv), yu^(-1)}, yw] + 
     8*G[{0, 1/(yu*yv), yu^(-1), 1/(yu*yv), yv^(-1)}, yw] - 
     4*G[{0, 1/(yu*yv), yu^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] + 
     4*G[{0, 1/(yu*yv), yv^(-1), 1, yu^(-1)}, yw] + 
     8*G[{0, 1/(yu*yv), yv^(-1), 1, yv^(-1)}, yw] - 
     4*G[{0, 1/(yu*yv), yv^(-1), 1, 1/(yu*yv)}, yw] + 
     8*G[{0, 1/(yu*yv), yv^(-1), yu^(-1), 1}, yw] - 
     8*G[{0, 1/(yu*yv), yv^(-1), yu^(-1), yu^(-1)}, yw] - 
     8*G[{0, 1/(yu*yv), yv^(-1), yu^(-1), yv^(-1)}, yw] + 
     4*G[{0, 1/(yu*yv), yv^(-1), yu^(-1), 1/(yu*yv)}, yw] + 
     8*G[{0, 1/(yu*yv), yv^(-1), yv^(-1), 1}, yw] - 
     8*G[{0, 1/(yu*yv), yv^(-1), yv^(-1), yu^(-1)}, yw] - 
     16*G[{0, 1/(yu*yv), yv^(-1), yv^(-1), yv^(-1)}, yw] + 
     8*G[{0, 1/(yu*yv), yv^(-1), yv^(-1), 1/(yu*yv)}, yw] - 
     8*G[{0, 1/(yu*yv), yv^(-1), 1/(yu*yv), 1}, yw] + 
     8*G[{0, 1/(yu*yv), yv^(-1), 1/(yu*yv), yu^(-1)}, yw] + 
     8*G[{0, 1/(yu*yv), yv^(-1), 1/(yu*yv), yv^(-1)}, yw] - 
     4*G[{0, 1/(yu*yv), yv^(-1), 1/(yu*yv), 1/(yu*yv)}, yw] + 
     8*G[{0, 1/(yu*yv), 1/(yu*yv), 1, 1}, yw] - 
     10*G[{0, 1/(yu*yv), 1/(yu*yv), 1, yu^(-1)}, yw] - 
     12*G[{0, 1/(yu*yv), 1/(yu*yv), 1, yv^(-1)}, yw] + 
     6*G[{0, 1/(yu*yv), 1/(yu*yv), 1, 1/(yu*yv)}, yw] - 
     14*G[{0, 1/(yu*yv), 1/(yu*yv), yu^(-1), 1}, yw] + 
     12*G[{0, 1/(yu*yv), 1/(yu*yv), yu^(-1), yu^(-1)}, yw] + 
     12*G[{0, 1/(yu*yv), 1/(yu*yv), yu^(-1), yv^(-1)}, yw] - 
     6*G[{0, 1/(yu*yv), 1/(yu*yv), yu^(-1), 1/(yu*yv)}, yw] - 
     12*G[{0, 1/(yu*yv), 1/(yu*yv), yv^(-1), 1}, yw] + 
     12*G[{0, 1/(yu*yv), 1/(yu*yv), yv^(-1), yu^(-1)}, yw] + 
     8*G[{0, 1/(yu*yv), 1/(yu*yv), yv^(-1), yv^(-1)}, yw] - 
     4*G[{0, 1/(yu*yv), 1/(yu*yv), yv^(-1), 1/(yu*yv)}, yw] + 
     6*G[{0, 1/(yu*yv), 1/(yu*yv), 1/(yu*yv), 1}, yw] - 
     6*G[{0, 1/(yu*yv), 1/(yu*yv), 1/(yu*yv), yu^(-1)}, yw] - 
     (4*Pi^2*Zeta[3])/3 - 2*G[{0}, yu^(-1)]^2*Zeta[3] - 
     4*G[{0}, yu^(-1)]*G[{0}, yv^(-1)]*Zeta[3] - 2*G[{0}, yv^(-1)]^2*
      Zeta[3] + 4*G[{0}, yu^(-1)]*G[{0}, yw]*Zeta[3] + 
     4*G[{0}, yv^(-1)]*G[{0}, yw]*Zeta[3] - 2*G[{0}, yw]^2*Zeta[3] + 
     4*G[{0}, yu^(-1)]*G[{1}, yu^(-1)]*Zeta[3] + 4*G[{0}, yv^(-1)]*
      G[{1}, yu^(-1)]*Zeta[3] - 4*G[{0}, yw]*G[{1}, yu^(-1)]*Zeta[3] - 
     2*G[{1}, yu^(-1)]^2*Zeta[3] + 2*G[{1}, yv^(-1)]^2*Zeta[3] - 
     4*G[{1}, yv^(-1)]*G[{1}, yw]*Zeta[3] + 2*G[{1}, yw]^2*Zeta[3] - 
     4*G[{0}, yu^(-1)]*G[{1/(yu*yv)}, yw]*Zeta[3] - 
     4*G[{0}, yv^(-1)]*G[{1/(yu*yv)}, yw]*Zeta[3] + 
     4*G[{0}, yw]*G[{1/(yu*yv)}, yw]*Zeta[3] + 4*G[{1}, yu^(-1)]*
      G[{1/(yu*yv)}, yw]*Zeta[3] - 2*G[{1/(yu*yv)}, yw]^2*Zeta[3] - 
     4*G[{0, 1}, yu^(-1)]*Zeta[3] - 4*G[{0, 1}, yv^(-1)]*Zeta[3] - 
     4*G[{0, 1}, yw]*Zeta[3] + 4*G[{0, yu^(-1)}, yw]*Zeta[3] + 
     4*G[{0, yu}, yv^(-1)]*Zeta[3] + 4*G[{0, yv^(-1)}, yw]*Zeta[3] - 
     4*G[{0, 1/(yu*yv)}, yw]*Zeta[3] - 4*Zeta[5]
