(****************************************************************)
(*  This file contains the near-collinear expansions of the     *)
(*  hexagon basis functions through weight five.                *)
(*                                                              *)
(*  We use the variables S, F, and T, which are related to      *)
(*  the cross ratios u, v, and w, by,                           *)
(*                                                              *)
(*  u = (F*S^2)/((1+T^2)*(F+F*S^2+S*T+F^2*S*T+F*T^2)),          *)
(*  v = T^2/(1+T^2),                                            *)
(*  w = F/(F+F*S^2+S*T+F^2*S*T+F*T^2) .                         *)
(*                                                              *)
(*  The variables yu, yv, and yw, are related by,               *)
(*                                                              *)
(*  yu = (F*S+T)/(F*(S+F*T)),                                   *)
(*  yv = ((S+F*T)*(1+F*S*T+T^2))/((F*S+T)*(F+S*T+F*T^2)),       *)
(*  yw = (F+S*T+F*T^2)/(F*(1+F*S*T+T^2)) .                      *)
(*                                                              *)
(*  There are 30 expansions presented here. The notation is     *)
(*                                                              *)
(*  FuvwT2 = F(u,v,w)|_{T^2}, FuwvT2 = F(u,w,v)|_{T^2}, etc.    *)
(*                                                              *)
(*  where "_{T^2}" means an expansion around T=0 through        *)
(*  order T^2. The function F is one of,                        *)
(*                                                              *)
(*    Weight 3: Phi6tilde = \tilde{\Phi}_ 6                     *)
(*    Weight 4: F1 = F_ 1, Omega2 = \Omega_2                    *)
(*    Weight 5: G, H1 = H_ 1, J1 = J_ 1, K1 = K_ 1,             *)
(*              N, O, Qep = Q_{ep}, M1 = M_ 1                   *)
(*                                                              *)
(*  We denote by HPL[{w1,...,wn},z] the harmonic polylogarithm  *)
(*  with weight vector {w1,...,wn} and argument z.              *)
(****************************************************************)


Phi6tildeuvwT2 = ((-1 + F^(-2))*F*(1 + S^2)*T*HPL[{0}, S^2]*HPL[{1}, -S^2])/S - 
     ((-1 + F^(-4))*F^2*(1 + S^4)*T^2*HPL[{0}, S^2]*HPL[{1}, -S^2])/(2*S^2) + 
     ((-1 + F^(-2))*F*(1 + S^2)*T*HPL[{1}, -S^2]^2)/S - 
     ((-1 + F^(-4))*F^2*(1 + S^4)*T^2*HPL[{1}, -S^2]^2)/(2*S^2) - 
     2*(-1 + F^(-2))*F*S*T*HPL[{0}, S^2]*(-1 + Log[T]) - 
     (2*(-1 + F^(-2))*F*(1 + S^2)*T*HPL[{1}, -S^2]*(-1 + Log[T]))/S + 
     ((-1 + F^(-4))*F^2*T^2*(-1 + 2*Log[T]))/2 + 
     ((-1 + F^(-4))*F^2*T^2*HPL[{0}, S^2]*(-1 - S^2 + 2*S^2*Log[T]))/2 + 
     ((-1 + F^(-4))*F^2*T^2*HPL[{1}, -S^2]*(-(1 + S^2)^2 + 
        2*(1 + S^4)*Log[T]))/(2*S^2)
 
Omega2uvwT2 = Pi^4/36 - (F^2*Pi^2*(S^2*(-1 + S^2) + (S^2*(-1 + S^2))/F^4 + 
        (2*(2 + S^2 + S^4))/F^2)*T^2)/(12*(1 + S^2)) - 
     ((1 + F^(-2))*F*Pi^2*S*T*HPL[{0}, S^2])/6 + 
     (F^2*Pi^2*(-4/F^2 + S^2 + S^2/F^4)*T^2*HPL[{0}, S^2])/12 + 
     (Pi^2*HPL[{0}, S^2]^2)/12 - 
     (F^2*(S^4 + S^4/F^4 + (2*(1 + S^2 + S^4))/F^2)*T^2*HPL[{0}, S^2]^2)/
      (4*(1 + S^2)) - ((1 + F^(-2))*F*Pi^2*S*T*HPL[{1}, -S^2])/3 + 
     (F^2*Pi^2*(-4/F^2 + S^2 + S^2/F^4)*T^2*HPL[{1}, -S^2])/6 - 
     ((1 + F^(-2))*F*S*T*HPL[{0}, S^2]^2*HPL[{1}, -S^2])/2 + 
     (F^2*(-4/F^2 + S^2 + S^2/F^4)*T^2*HPL[{0}, S^2]^2*HPL[{1}, -S^2])/4 - 
     (1 + F^(-2))*F*S*T*HPL[{0}, S^2]*HPL[{1}, -S^2]^2 + 
     (F^2*(-4/F^2 + S^2 + S^2/F^4)*T^2*HPL[{0}, S^2]*HPL[{1}, -S^2]^2)/2 - 
     (2*(1 + F^(-2))*F*S*T*HPL[{1}, -S^2]^3)/3 + 
     (F^2*(-4/F^2 + S^2 + S^2/F^4)*T^2*HPL[{1}, -S^2]^3)/3 + 
     (Pi^2*HPL[{2}, -S^2])/3 - (F^2*(S^4 + S^4/F^4 + (2*(1 + S^2 + S^4))/F^2)*
       T^2*HPL[{2}, -S^2])/(2*(1 + S^2)) + (HPL[{0}, S^2]^2*HPL[{2}, -S^2])/
      2 - (1 + F^(-2))*F*S*T*HPL[{1}, -S^2]*HPL[{2}, -S^2] + 
     (F^2*(-4/F^2 + S^2 + S^2/F^4)*T^2*HPL[{1}, -S^2]*HPL[{2}, -S^2])/2 + 
     HPL[{2}, -S^2]^2/2 - HPL[{0}, S^2]*HPL[{3}, -S^2] + HPL[{4}, -S^2] + 
     2*(1 + F^(-2))*F*S*T*HPL[{2, 1}, -S^2] - F^2*(-4/F^2 + S^2 + S^2/F^4)*
      T^2*HPL[{2, 1}, -S^2] + 2*HPL[{0}, S^2]*HPL[{2, 1}, -S^2] - 
     4*HPL[{3, 1}, -S^2] + 4*HPL[{2, 1, 1}, -S^2] - 
     2*HPL[{0}, S^2]*HPL[{2}, -S^2]*Log[T] + 2*HPL[{3}, -S^2]*Log[T] - 
     4*HPL[{2, 1}, -S^2]*Log[T] + (Pi^2*Log[T]^2)/3 + 
     HPL[{0}, S^2]^2*Log[T]^2 + 2*HPL[{2}, -S^2]*Log[T]^2 + 
     ((1 + F^(-2))*F*T*HPL[{0}, S^2]*HPL[{1}, -S^2]*
       (-1 - S^2 + 2*S^2*Log[T]))/S + ((1 + F^(-2))*F*T*HPL[{1}, -S^2]^2*
       (-1 - S^2 + 2*S^2*Log[T]))/S + (F^2*T^2*HPL[{1}, -S^2]^2*
       (1 + S^2 + 5*S^4 + S^6 - (4*S^2*(2 + S^2 + S^4))/F^2 + 
        (1 + S^2 + 5*S^4 + S^6)/F^4 - 4*S^2*(1 + S^2)*(-4/F^2 + S^2 + 
          S^2/F^4)*Log[T]))/(4*S^2*(1 + S^2)) - 
     (F^2*T^2*HPL[{0}, S^2]*HPL[{1}, -S^2]*(-1 - S^2 - 5*S^4 - S^6 + 
        (4*S^2*(2 + S^2 + S^4))/F^2 - (1 + S^2 + 5*S^4 + S^6)/F^4 + 
        4*S^2*(1 + S^2)*(-4/F^2 + S^2 + S^2/F^4)*Log[T]))/(4*S^2*(1 + S^2)) - 
     2*(1 + F^(-2))*F*S*T*HPL[{0}, S^2]*(1 - Log[T] + Log[T]^2) - 
     (2*(1 + F^(-2))*F*T*HPL[{1}, -S^2]*(1 + S^2 - (1 + S^2)*Log[T] + 
        S^2*Log[T]^2))/S + (F^2*T^2*((1 + F^(-4) - 4/F^2)*(1 + S^2) - 
        2*(1 + F^(-4) - 4/F^2)*(1 + S^2)*Log[T] - (8*Log[T]^2)/F^2 + 
        4*S^2*Log[T]^2 + (4*S^2*Log[T]^2)/F^4))/(4*(1 + S^2)) + 
     (F^2*T^2*HPL[{0}, S^2]*((1 + S^2)*(1 + 3*S^2 - (4*(1 + 2*S^2))/F^2 + 
          (1 + 3*S^2)/F^4) - 2*(S^2*(3 + S^2) + (S^2*(3 + S^2))/F^4 - 
          (4*(1 + S^2 + S^4))/F^2)*Log[T] + 4*(1 + S^2)*
         (-4/F^2 + S^2 + S^2/F^4)*Log[T]^2))/(4*(1 + S^2)) + 
     (F^2*T^2*HPL[{1}, -S^2]*((1 + S^2)^2*(1 + 3*S^2 - (8*S^2)/F^2 + 
          (1 + 3*S^2)/F^4) - 2*(1 + S^2 + 5*S^4 + S^6 - 
          (4*S^2*(2 + S^2 + S^4))/F^2 + (1 + S^2 + 5*S^4 + S^6)/F^4)*Log[T] + 
        4*S^2*(1 + S^2)*(-4/F^2 + S^2 + S^2/F^4)*Log[T]^2))/
      (4*S^2*(1 + S^2)) - 2*(1 + F^(-2))*F*S*T*Zeta[3] + 
     F^2*(-4/F^2 + S^2 + S^2/F^4)*T^2*Zeta[3] + 2*HPL[{0}, S^2]*Zeta[3] + 
     4*Log[T]*Zeta[3]
 
Omega2vwuT2 = (F^2*Pi^2*(1 + F^(-4) - (2*S^2)/F^2)*T^2)/(12*(1 + S^2)) - 
     ((1 + F^(-2))*F*Pi^2*T*HPL[{1}, -S^2])/(6*S) + 
     ((1 + F^(-4))*F^2*Pi^2*T^2*HPL[{1}, -S^2])/(12*S^2) - 
     ((1 + F^(-2))*F*T*HPL[{0}, S^2]*HPL[{1}, -S^2]^2)/S + 
     ((1 + F^(-4))*F^2*T^2*HPL[{0}, S^2]*HPL[{1}, -S^2]^2)/(2*S^2) - 
     (2*(1 + F^(-2))*F*T*HPL[{1}, -S^2]^3)/(3*S) + 
     ((1 + F^(-4))*F^2*T^2*HPL[{1}, -S^2]^3)/(3*S^2) - 
     (Pi^2*HPL[{2}, -S^2])/6 + (F^2*(1 + F^(-4) + (2*(1 + S^2 + S^4))/F^2)*
       T^2*HPL[{2}, -S^2])/(2*S^2*(1 + S^2)) - 
     ((1 + F^(-2))*F*T*HPL[{0}, S^2]*HPL[{2}, -S^2])/S + 
     ((1 + F^(-4))*F^2*T^2*HPL[{0}, S^2]*HPL[{2}, -S^2])/(2*S^2) + 
     ((1 + F^(-2))*F*T*HPL[{1}, -S^2]*HPL[{2}, -S^2])/S - 
     ((1 + F^(-4))*F^2*T^2*HPL[{1}, -S^2]*HPL[{2}, -S^2])/(2*S^2) + 
     HPL[{2}, -S^2]^2/2 + (2*(1 + F^(-2))*F*T*HPL[{3}, -S^2])/S - 
     ((1 + F^(-4))*F^2*T^2*HPL[{3}, -S^2])/S^2 - 
     HPL[{0}, S^2]*HPL[{3}, -S^2] + 3*HPL[{4}, -S^2] - 
     (2*(1 + F^(-2))*F*T*HPL[{2, 1}, -S^2])/S + 
     ((1 + F^(-4))*F^2*T^2*HPL[{2, 1}, -S^2])/S^2 - 
     2*HPL[{0}, S^2]*HPL[{2, 1}, -S^2] - 4*HPL[{2, 1, 1}, -S^2] - 
     ((1 + F^(-2))*F*T*HPL[{0}, S^2]*HPL[{1}, -S^2]*(1 + S^2 - 2*Log[T]))/S - 
     ((1 + F^(-2))*F*T*HPL[{1}, -S^2]^2*(1 + S^2 - 2*Log[T]))/S + 
     2*(1 + F^(-2))*F*S*T*HPL[{0}, S^2]*(-1 + Log[T]) + 
     2*HPL[{0}, S^2]*HPL[{2}, -S^2]*Log[T] - 2*HPL[{3}, -S^2]*Log[T] + 
     4*HPL[{2, 1}, -S^2]*Log[T] - 2*HPL[{2}, -S^2]*Log[T]^2 + 
     (F^2*T^2*HPL[{0}, S^2]*HPL[{1}, -S^2]*(1 + 5*S^2 + S^4 + S^6 - 
        (4*(1 + S^2 + 2*S^4))/F^2 + (1 + 5*S^2 + S^4 + S^6)/F^4 - 
        4*(1 + F^(-4))*(1 + S^2)*Log[T]))/(4*S^2*(1 + S^2)) + 
     (F^2*T^2*HPL[{1}, -S^2]^2*(1 + 5*S^2 + S^4 + S^6 - 
        (4*(1 + S^2 + 2*S^4))/F^2 + (1 + 5*S^2 + S^4 + S^6)/F^4 - 
        4*(1 + F^(-4))*(1 + S^2)*Log[T]))/(4*S^2*(1 + S^2)) + 
     (F^2*T^2*HPL[{0}, S^2]*((1 + S^2)*(3 - 4/F^2 + S^2 + (3 + S^2)/F^4) - 
        2*(2 + S^2 - (4*S^2)/F^2 + S^4 + (2 + S^2 + S^4)/F^4)*Log[T]))/
      (4*(1 + S^2)) + (2*(1 + F^(-2))*F*T*HPL[{1}, -S^2]*
       (-1 - S^2 + (1 + S^2)*Log[T] - Log[T]^2))/S - 
     (F^2*T^2*HPL[{1}, -S^2]*(-((1 + S^2)^2*(3 - 8/F^2 + S^2 + 
           (3 + S^2)/F^4)) + 2*(1 + 5*S^2 + S^4 + S^6 - (4*(1 + S^2 + 2*S^4))/
           F^2 + (1 + 5*S^2 + S^4 + S^6)/F^4)*Log[T] - 
        4*(1 + F^(-4))*(1 + S^2)*Log[T]^2))/(4*S^2*(1 + S^2)) + 
     (F^2*T^2*((1 + F^(-4) - 4/F^2)*(1 + S^2) - 2*(1 + F^(-4) - 4/F^2)*
         (1 + S^2)*Log[T] + 4*(Log[T]^2 + Log[T]^2/F^4 - 
          (2*S^2*Log[T]^2)/F^2)))/(4*(1 + S^2))
 
Omega2wuvT2 = -((1 + F^(-2))^2*F^2*Pi^2*(-1 + S^2)*T^2)/12 - 
     ((1 + F^(-2))^2*F^2*(-1 + S^2)*T^2*HPL[{0}, S^2]^2)/4 - 
     ((1 + F^(-2))*F*Pi^2*(1 + S^2)*T*HPL[{1}, -S^2])/(6*S) + 
     (F^2*Pi^2*(1 - (4*S^2)/F^2 + S^4 + (1 + S^4)/F^4)*T^2*HPL[{1}, -S^2])/
      (12*S^2) + ((1 + S^2)^2*T^2*HPL[{0}, S^2]*HPL[{1}, -S^2])/S^2 - 
     ((1 + F^(-2))*F*(1 + S^2)*T*HPL[{0}, S^2]^2*HPL[{1}, -S^2])/(2*S) + 
     (F^2*(1 - (4*S^2)/F^2 + S^4 + (1 + S^4)/F^4)*T^2*HPL[{0}, S^2]^2*
       HPL[{1}, -S^2])/(4*S^2) + ((1 + S^2)^2*T^2*HPL[{1}, -S^2]^2)/S^2 - 
     ((1 + F^(-2))^2*F^2*(-1 + S^4)*T^2*HPL[{2}, -S^2])/(2*S^2) + 
     ((1 + F^(-2))*F*(1 + S^2)*T*HPL[{0}, S^2]*HPL[{2}, -S^2])/S - 
     (F^2*(1 - (4*S^2)/F^2 + S^4 + (1 + S^4)/F^4)*T^2*HPL[{0}, S^2]*
       HPL[{2}, -S^2])/(2*S^2) - (F^2*(1 + S^2)*T^2*HPL[{0}, S^2]*
       (1 + F^(-4) - 4/F^2 + (4*Log[T])/F^2))/2 - 
     (F^2*(1 + S^2)^2*T^2*HPL[{1}, -S^2]*(1 + F^(-4) - 4/F^2 + 
        (4*Log[T])/F^2))/(2*S^2)
 
F1uvwT2 = -((-1 + F^(-2))*F*Pi^2*(1 + S^2)*T*HPL[{1}, -S^2])/(3*S) + 
     ((-1 + F^(-4))*F^2*Pi^2*(1 + S^4)*T^2*HPL[{1}, -S^2])/(6*S^2) + 
     (-1 + F^(-4))*F^2*S^2*T^2*HPL[{1}, -S^2]^2 + 
     ((-1 + F^(-2))*F*(1 + S^2)*T*HPL[{0}, S^2]*HPL[{1}, -S^2]^2)/S - 
     ((-1 + F^(-4))*F^2*(1 + S^4)*T^2*HPL[{0}, S^2]*HPL[{1}, -S^2]^2)/
      (2*S^2) + ((-1 + F^(-2))*F*(1 + S^2)*T*HPL[{1}, -S^2]^3)/(3*S) - 
     ((-1 + F^(-4))*F^2*(1 + S^4)*T^2*HPL[{1}, -S^2]^3)/(6*S^2) - 
     (2*(-1 + F^(-2))*F*(1 + S^2)*T*HPL[{1}, -S^2]*HPL[{2}, -S^2])/S + 
     ((-1 + F^(-4))*F^2*(1 + S^4)*T^2*HPL[{1}, -S^2]*HPL[{2}, -S^2])/S^2 + 
     (2*(-1 + F^(-2))*F*(1 + S^2)*T*HPL[{2, 1}, -S^2])/S - 
     ((-1 + F^(-4))*F^2*(1 + S^4)*T^2*HPL[{2, 1}, -S^2])/S^2 + 
     (2*(-1 + F^(-2))*F*Pi^2*S*T*(-1 + Log[T]))/3 - 
     (2*(-1 + F^(-4))*F^2*S^4*T^2*HPL[{0}, S^2]*(-1 + Log[T]))/(1 + S^2) - 
     2*(-1 + F^(-2))*F*S*T*HPL[{0}, S^2]*HPL[{1}, -S^2]*(-1 + Log[T]) + 
     4*(-1 + F^(-2))*F*S*T*HPL[{2}, -S^2]*(-1 + Log[T]) - 
     ((-1 + F^(-4))*F^2*Pi^2*T^2*(-1 - S^2 + 2*S^2*Log[T]))/6 - 
     (-1 + F^(-4))*F^2*T^2*HPL[{2}, -S^2]*(-1 - S^2 + 2*S^2*Log[T]) + 
     ((-1 + F^(-4))*F^2*T^2*HPL[{0}, S^2]*HPL[{1}, -S^2]*
       (-1 + S^2 + 2*S^2*Log[T]))/2 - ((-1 + F^(-4))*F^2*T^2*HPL[{1}, -S^2]*
       (1 - 4*S^2 + (-2 + 4*S^2)*Log[T]))/2 - 2*(-1 + F^(-2))*F*S*T*Zeta[3] + 
     (-1 + F^(-4))*F^2*S^2*T^2*Zeta[3]
 
F1vwuT2 = -((-1 + F^(-4))*F^2*Pi^2*T^2)/6 + 
     ((-1 + F^(-2))*F*Pi^2*S*T*HPL[{0}, S^2])/3 - 
     ((-1 + F^(-4))*F^2*Pi^2*S^2*T^2*HPL[{0}, S^2])/6 + 
     ((-1 + F^(-2))*F*Pi^2*(1 + S^2)*T*HPL[{1}, -S^2])/(3*S) - 
     ((-1 + F^(-4))*F^2*Pi^2*(1 + S^4)*T^2*HPL[{1}, -S^2])/(6*S^2) + 
     ((-1 + F^(-2))*F*(1 + S^2)*T*HPL[{0}, S^2]*HPL[{1}, -S^2]^2)/S - 
     ((-1 + F^(-4))*F^2*(1 + S^4)*T^2*HPL[{0}, S^2]*HPL[{1}, -S^2]^2)/
      (2*S^2) + (2*(-1 + F^(-2))*F*(1 + S^2)*T*HPL[{1}, -S^2]^3)/(3*S) - 
     ((-1 + F^(-4))*F^2*(1 + S^4)*T^2*HPL[{1}, -S^2]^3)/(3*S^2) + 
     2*(-1 + F^(-2))*F*S*T*HPL[{0}, S^2]*HPL[{2}, -S^2] - 
     (-1 + F^(-4))*F^2*S^2*T^2*HPL[{0}, S^2]*HPL[{2}, -S^2] - 
     2*(-1 + F^(-2))*F*S*T*HPL[{3}, -S^2] + (-1 + F^(-4))*F^2*S^2*T^2*
      HPL[{3}, -S^2] + (2*(-1 + F^(-2))*F*(-1 + S^2)*T*HPL[{2, 1}, -S^2])/S - 
     ((-1 + F^(-4))*F^2*(-1 + S^4)*T^2*HPL[{2, 1}, -S^2])/S^2 - 
     2*(-1 + F^(-2))*F*S*T*Zeta[3] + (-1 + F^(-4))*F^2*S^2*T^2*Zeta[3]
 
F1wuvT2 = ((-1 + F^(-4))*F^2*T^2*HPL[{1}, -S^2]^2)/S^2 + 
     ((-1 + F^(-2))*F*(1 + S^2)*T*HPL[{1}, -S^2]^3)/(3*S) - 
     ((-1 + F^(-4))*F^2*(1 + S^4)*T^2*HPL[{1}, -S^2]^3)/(6*S^2) + 
     (2*(-1 + F^(-2))*F*(1 + S^2)*T*HPL[{1}, -S^2]*HPL[{2}, -S^2])/S - 
     ((-1 + F^(-4))*F^2*(1 + S^4)*T^2*HPL[{1}, -S^2]*HPL[{2}, -S^2])/S^2 + 
     (2*(-1 + F^(-2))*F*(1 + S^2)*T*HPL[{3}, -S^2])/S - 
     ((-1 + F^(-4))*F^2*(1 + S^4)*T^2*HPL[{3}, -S^2])/S^2 - 
     (2*(-1 + F^(-2))*F*(1 + S^2)*T*HPL[{2, 1}, -S^2])/S + 
     ((-1 + F^(-4))*F^2*(1 + S^4)*T^2*HPL[{2, 1}, -S^2])/S^2 - 
     ((-1 + F^(-4))*F^2*T^2*HPL[{2}, -S^2]*(1 + S^2 - 2*Log[T]))/S^2 + 
     ((-1 + F^(-4))*F^2*T^2*HPL[{0}, S^2]*HPL[{1}, -S^2]*
       (3 + S^2 - 2*Log[T]))/(2*S^2) + (2*(-1 + F^(-2))*F*T*HPL[{0}, S^2]*
       HPL[{1}, -S^2]*(-1 + Log[T]))/S - (4*(-1 + F^(-2))*F*T*HPL[{2}, -S^2]*
       (-1 + Log[T]))/S + ((-1 + F^(-4))*F^2*T^2*HPL[{1}, -S^2]*
       (4 - S^2 + 2*(-2 + S^2)*Log[T]))/(2*S^2) + 
     ((-1 + F^(-4))*F^2*T^2*HPL[{0}, S^2]*(3 - S^2 + 2*(-1 + S^2)*Log[T]))/
      (2*(1 + S^2)) + 2*(-1 + F^(-2))*F*S*T*Zeta[3] - 
     (-1 + F^(-4))*F^2*S^2*T^2*Zeta[3]
 
QepuvwT2 = ((1 + F^(-2))*F*Pi^2*S*T*HPL[{0}, S^2])/96 - 
     (F^2*Pi^2*(2 + S^2 - (4*S^2)/F^2 + S^4 + (2 + S^2 + S^4)/F^4)*T^2*
       HPL[{0}, S^2])/(384*(1 + S^2)) + ((1 + F^(-2))*F*Pi^2*T*HPL[{0}, S^2]*
       HPL[{1}, -S^2])/(96*S) - ((1 + F^(-4))*F^2*Pi^2*T^2*HPL[{0}, S^2]*
       HPL[{1}, -S^2])/(192*S^2) + ((1 + F^(-2))*F*T*HPL[{0}, S^2]^2*
       HPL[{1}, -S^2]^2)/(32*S) - ((1 + F^(-4))*F^2*T^2*HPL[{0}, S^2]^2*
       HPL[{1}, -S^2]^2)/(64*S^2) + ((1 + F^(-2))*F*T*HPL[{0}, S^2]*
       HPL[{1}, -S^2]^3)/(24*S) - ((1 + F^(-4))*F^2*T^2*HPL[{0}, S^2]*
       HPL[{1}, -S^2]^3)/(48*S^2) + ((1 + F^(-2))*F*T*HPL[{1}, -S^2]^4)/
      (192*S) - ((1 + F^(-4))*F^2*T^2*HPL[{1}, -S^2]^4)/(384*S^2) - 
     ((1 + F^(-2))*F*Pi^2*T*HPL[{2}, -S^2])/(96*S) + 
     ((1 + F^(-4))*F^2*Pi^2*T^2*HPL[{2}, -S^2])/(192*S^2) + 
     (Pi^2*HPL[{0}, S^2]*HPL[{2}, -S^2])/96 + 
     ((1 + F^(-2))*F*S*T*HPL[{0}, S^2]*HPL[{2}, -S^2])/16 - 
     (F^2*(4 + 2*S^2 + S^4 + S^6 + (4*(2 + 2*S^2 + S^4))/F^2 + 
        (4 + 2*S^2 + S^4 + S^6)/F^4)*T^2*HPL[{0}, S^2]*HPL[{2}, -S^2])/
      (64*S^2*(1 + S^2)) + ((1 + F^(-2))*F*T*HPL[{0}, S^2]^2*HPL[{2}, -S^2])/
      (32*S) - ((1 + F^(-4))*F^2*T^2*HPL[{0}, S^2]^2*HPL[{2}, -S^2])/
      (64*S^2) - ((1 + F^(-2))*F*T*HPL[{0}, S^2]*HPL[{1}, -S^2]*
       HPL[{2}, -S^2])/(16*S) + ((1 + F^(-4))*F^2*T^2*HPL[{0}, S^2]*
       HPL[{1}, -S^2]*HPL[{2}, -S^2])/(32*S^2) - 
     ((1 + F^(-2))*F*T*HPL[{1}, -S^2]^2*HPL[{2}, -S^2])/(8*S) + 
     ((1 + F^(-4))*F^2*T^2*HPL[{1}, -S^2]^2*HPL[{2}, -S^2])/(16*S^2) + 
     ((1 + F^(-2))*F*T*HPL[{2}, -S^2]^2)/(32*S) - 
     ((1 + F^(-4))*F^2*T^2*HPL[{2}, -S^2]^2)/(64*S^2) - 
     (HPL[{0}, S^2]*HPL[{2}, -S^2]^2)/32 - (Pi^2*HPL[{3}, -S^2])/48 - 
     (3*(1 + F^(-2))*F*T*HPL[{0}, S^2]*HPL[{3}, -S^2])/(16*S) + 
     (3*(1 + F^(-4))*F^2*T^2*HPL[{0}, S^2]*HPL[{3}, -S^2])/(32*S^2) + 
     (HPL[{0}, S^2]^2*HPL[{3}, -S^2])/32 - 
     ((1 + F^(-2))*F*T*HPL[{1}, -S^2]*HPL[{3}, -S^2])/(8*S) + 
     ((1 + F^(-4))*F^2*T^2*HPL[{1}, -S^2]*HPL[{3}, -S^2])/(16*S^2) - 
     (HPL[{2}, -S^2]*HPL[{3}, -S^2])/8 + (3*(1 + F^(-2))*F*T*HPL[{4}, -S^2])/
      (16*S) - (3*(1 + F^(-4))*F^2*T^2*HPL[{4}, -S^2])/(32*S^2) - 
     (HPL[{0}, S^2]*HPL[{4}, -S^2])/4 + (7*HPL[{5}, -S^2])/16 + 
     (HPL[{0}, S^2]^2*HPL[{2, 1}, -S^2])/16 + 
     (3*(1 + F^(-2))*F*T*HPL[{1}, -S^2]*HPL[{2, 1}, -S^2])/(16*S) - 
     (3*(1 + F^(-4))*F^2*T^2*HPL[{1}, -S^2]*HPL[{2, 1}, -S^2])/(32*S^2) - 
     (HPL[{2}, -S^2]*HPL[{2, 1}, -S^2])/4 - (HPL[{0}, S^2]*HPL[{3, 1}, -S^2])/
      8 + (3*HPL[{3, 2}, -S^2])/8 + (7*HPL[{4, 1}, -S^2])/8 - 
     ((1 + F^(-2))*F*T*HPL[{2, 1, 1}, -S^2])/(4*S) + 
     ((1 + F^(-4))*F^2*T^2*HPL[{2, 1, 1}, -S^2])/(8*S^2) + 
     (HPL[{0}, S^2]*HPL[{2, 1, 1}, -S^2])/4 + (7*HPL[{2, 2, 1}, -S^2])/16 + 
     (13*HPL[{3, 1, 1}, -S^2])/16 + HPL[{2, 1, 1, 1}, -S^2]/8 - 
     ((1 + F^(-2))*F*T*HPL[{3}, -S^2]*(2 + 3*S^2 - 4*Log[T]))/(16*S) + 
     ((1 + F^(-2))*F*T*HPL[{0}, S^2]^2*HPL[{1}, -S^2]*(1 + S^2 - 2*Log[T]))/
      (32*S) + ((1 + F^(-2))*F*T*HPL[{0}, S^2]*HPL[{1}, -S^2]^2*
       (1 + S^2 - 2*Log[T]))/(8*S) + ((1 + F^(-2))*F*T*HPL[{1}, -S^2]^3*
       (1 + S^2 - 2*Log[T]))/(24*S) - (3*(1 + F^(-2))*F*T*HPL[{1}, -S^2]*
       HPL[{2}, -S^2]*(1 + S^2 - 2*Log[T]))/(16*S) + 
     ((1 + F^(-2))*F*T*HPL[{2, 1}, -S^2]*(1 + 2*S^2 - 2*Log[T]))/(8*S) + 
     ((1 + F^(-2))*F*Pi^2*S*T*(-1 + Log[T]))/48 - 
     ((1 + F^(-2))*F*S*T*HPL[{0}, S^2]^2*(-1 + Log[T]))/16 + 
     ((1 + F^(-2))*F*Pi^2*T*HPL[{1}, -S^2]*Log[T])/(192*S) - 
     ((1 + F^(-4))*F^2*Pi^2*T^2*HPL[{1}, -S^2]*Log[T])/(384*S^2) + 
     (Pi^2*HPL[{2}, -S^2]*Log[T])/192 - (HPL[{0}, S^2]^2*HPL[{2}, -S^2]*
       Log[T])/16 + (3*HPL[{2}, -S^2]^2*Log[T])/16 + 
     (HPL[{0}, S^2]*HPL[{3}, -S^2]*Log[T])/8 + (HPL[{4}, -S^2]*Log[T])/8 - 
     (HPL[{0}, S^2]*HPL[{2, 1}, -S^2]*Log[T])/2 + (HPL[{3, 1}, -S^2]*Log[T])/
      4 - (HPL[{2, 1, 1}, -S^2]*Log[T])/2 + 
     (3*(1 + F^(-2))*F*S*T*HPL[{0}, S^2]*(-1 + Log[T])*Log[T])/8 + 
     (3*HPL[{0}, S^2]*HPL[{2}, -S^2]*Log[T]^2)/8 - (HPL[{3}, -S^2]*Log[T]^2)/
      2 + (5*HPL[{2, 1}, -S^2]*Log[T]^2)/8 - (3*HPL[{2}, -S^2]*Log[T]^3)/16 + 
     (F^2*T^2*HPL[{1}, -S^2]*HPL[{2}, -S^2]*(5 + 13*S^2 + 3*S^4 + 3*S^6 - 
        (8*(1 + 2*S^2 + 3*S^4))/F^2 + (5 + 13*S^2 + 3*S^4 + 3*S^6)/F^4 - 
        12*(1 + F^(-4))*(1 + S^2)*Log[T]))/(64*S^2*(1 + S^2)) - 
     (F^2*T^2*HPL[{1}, -S^2]^3*(9 + 11*S^2 + 2*S^4 + 2*S^6 - 
        (2*(-3 + 3*S^2 + 8*S^4))/F^2 + (9 + 11*S^2 + 2*S^4 + 2*S^6)/F^4 - 
        8*(1 + F^(-4))*(1 + S^2)*Log[T]))/(192*S^2*(1 + S^2)) + 
     (F^2*T^2*HPL[{3}, -S^2]*(6 + 10*S^2 + 3*S^4 - (8*S^4)/F^2 + 3*S^6 + 
        (6 + 10*S^2 + 3*S^4 + 3*S^6)/F^4 - 8*(1 + F^(-4))*(1 + S^2)*Log[T]))/
      (64*S^2*(1 + S^2)) - (F^2*T^2*HPL[{0}, S^2]^2*HPL[{1}, -S^2]*
       (1 + 5*S^2 + S^4 + S^6 - (4*(1 + S^2 + 2*S^4))/F^2 + 
        (1 + 5*S^2 + S^4 + S^6)/F^4 - 4*(1 + F^(-4))*(1 + S^2)*Log[T]))/
      (128*S^2*(1 + S^2)) - (F^2*T^2*HPL[{0}, S^2]*HPL[{1}, -S^2]^2*
       (3 + 5*S^2 + S^4 + S^6 - (4*(S^2 + 2*S^4))/F^2 + 
        (3 + 5*S^2 + S^4 + S^6)/F^4 - 4*(1 + F^(-4))*(1 + S^2)*Log[T]))/
      (32*S^2*(1 + S^2)) - (F^2*T^2*HPL[{2, 1}, -S^2]*
       (3 + 6*S^2 + 2*S^4 - (6*S^4)/F^2 + 2*S^6 + (3 + 6*S^2 + 2*S^4 + 2*S^6)/
         F^4 - 4*(1 + F^(-4))*(1 + S^2)*Log[T]))/(32*S^2*(1 + S^2)) + 
     (F^2*T^2*HPL[{0}, S^2]^2*(-((1 + S^2)*(3 - 4/F^2 + S^2 + 
           (3 + S^2)/F^4)) + 2*(2 + S^2 - (4*S^2)/F^2 + S^4 + 
          (2 + S^2 + S^4)/F^4)*Log[T]))/(128*(1 + S^2)) + 
     (F^2*Pi^2*T^2*((1 + S^2)*(2 - 9/F^2 + S^2 + (2 + S^2)/F^4) - 
        (1 + 2*S^2 + 2*S^4 - (9 + 11*S^2)/F^2 + (1 + 2*S^2 + 2*S^4)/F^4)*
         Log[T]))/(384*(1 + S^2)) - ((1 + F^(-2))*F*T*HPL[{1}, -S^2]^2*
       (-1 - S^2 + 4*(1 + S^2)*Log[T] - 5*Log[T]^2))/(16*S) - 
     (3*(1 + F^(-2))*F*T*HPL[{0}, S^2]*HPL[{1}, -S^2]*
       (-1 - S^2 + 2*(1 + S^2)*Log[T] - 2*Log[T]^2))/(16*S) + 
     ((1 + F^(-2))*F*T*HPL[{2}, -S^2]*(-2 - S^2 + (2 + S^2)*Log[T] - 
        Log[T]^2))/(8*S) - (3*(1 + F^(-2))*F*T*HPL[{1}, -S^2]*Log[T]*
       (2*(1 + S^2) - 2*(1 + S^2)*Log[T] + Log[T]^2))/(16*S) + 
     (3*(1 + F^(-2))^2*F^2*T^2*Log[T]*(1 + S^2 - 2*Log[T] - 2*S^2*Log[T] + 
        2*Log[T]^2))/(64*(1 + S^2)) + (F^2*T^2*HPL[{1}, -S^2]^2*
       ((1 + F^(-4))*(-9 + S^2)*(1 + S^2)^2 + 8*(3 + 5*S^2 + S^4 + S^6 - 
          (4*(S^2 + 2*S^4))/F^2 + (3 + 5*S^2 + S^4 + S^6)/F^4)*Log[T] - 
        20*(1 + F^(-4))*(1 + S^2)*Log[T]^2))/(128*S^2*(1 + S^2)) - 
     (F^2*T^2*HPL[{2}, -S^2]*(-((1 + S^2)*(6 + 5*S^2 + S^4 - 
           (16 + 15*S^2)/F^2 + (6 + 5*S^2 + S^4)/F^4)) + 
        2*(2 + 8*S^2 + S^4 + S^6 - (2*(4 + 7*S^2 + 9*S^4))/F^2 + 
          (2 + 8*S^2 + S^4 + S^6)/F^4)*Log[T] - 4*(1 + F^(-4))*(1 + S^2)*
         Log[T]^2))/(64*S^2*(1 + S^2)) - 
     (F^2*T^2*HPL[{0}, S^2]*HPL[{1}, -S^2]*
       ((1 + S^2)^2*(15 - 16/F^2 + S^2 + (15 + S^2)/F^4) - 
        4*(7 + 15*S^2 + 3*S^4 + 3*S^6 - (4*(1 + 3*S^2 + 6*S^4))/F^2 + 
          (7 + 15*S^2 + 3*S^4 + 3*S^6)/F^4)*Log[T] + 24*(1 + F^(-4))*
         (1 + S^2)*Log[T]^2))/(128*S^2*(1 + S^2)) - 
     (F^2*T^2*HPL[{0}, S^2]*(-((1 + S^2)*(-11 + 4*S^2 - (8*S^2)/F^2 + 
           (-11 + 4*S^2)/F^4)) - 2*(1 + S^2)*(14 - 8/F^2 + S^2 + 
          (14 + S^2)/F^4)*Log[T] + 12*(2 + S^2 - (4*S^2)/F^2 + S^4 + 
          (2 + S^2 + S^4)/F^4)*Log[T]^2))/(128*(1 + S^2)) - 
     (F^2*T^2*HPL[{1}, -S^2]*(-2*(1 + S^2)^2*(-3 + S^2 + (-3 + S^2)/F^4 - 
          (2*(1 + S^2))/F^2) - (1 + S^2)^2*(15 - 16/F^2 + S^2 + 
          (15 + S^2)/F^4)*Log[T] + 2*(5 + 15*S^2 + 3*S^4 + 3*S^6 - 
          (4*(2 + 3*S^2 + 6*S^4))/F^2 + (5 + 15*S^2 + 3*S^4 + 3*S^6)/F^4)*
         Log[T]^2 - 6*(1 + F^(-4))*(1 + S^2)*Log[T]^3))/(64*S^2*(1 + S^2)) + 
     (3*Pi^2*Zeta[3])/256 - ((1 + F^(-2))*F*S*T*Zeta[3])/4 + 
     (F^2*(3 + 4*S^2 + 4*S^4 - (2*(10 + 13*S^2))/F^2 + (3 + 4*S^2 + 4*S^4)/
         F^4)*T^2*Zeta[3])/(64*(1 + S^2)) - 
     (3*(1 + F^(-2))*F*T*HPL[{1}, -S^2]*Zeta[3])/(32*S) + 
     (3*(1 + F^(-4))*F^2*T^2*HPL[{1}, -S^2]*Zeta[3])/(64*S^2) - 
     (3*HPL[{2}, -S^2]*Zeta[3])/32 + (21*Zeta[5])/64
 
QepuwvT2 = -((1 + F^(-2))*F*Pi^2*S*T*HPL[{0}, S^2])/48 + 
     (F^2*Pi^2*(2 + S^2 - (4*S^2)/F^2 + S^4 + (2 + S^2 + S^4)/F^4)*T^2*
       HPL[{0}, S^2])/(192*(1 + S^2)) - ((1 + F^(-2))*F*Pi^2*T*HPL[{0}, S^2]*
       HPL[{1}, -S^2])/(48*S) + ((1 + F^(-4))*F^2*Pi^2*T^2*HPL[{0}, S^2]*
       HPL[{1}, -S^2])/(96*S^2) - (37*(1 + F^(-2))*F*Pi^2*T*HPL[{1}, -S^2]^2)/
      (1536*S) + (37*(1 + F^(-4))*F^2*Pi^2*T^2*HPL[{1}, -S^2]^2)/(3072*S^2) + 
     ((1 + F^(-2))*F*T*HPL[{0}, S^2]^2*HPL[{1}, -S^2]^2)/(32*S) - 
     ((1 + F^(-4))*F^2*T^2*HPL[{0}, S^2]^2*HPL[{1}, -S^2]^2)/(64*S^2) - 
     ((1 + F^(-2))*F*T*HPL[{0}, S^2]*HPL[{1}, -S^2]^3)/(12*S) + 
     ((1 + F^(-4))*F^2*T^2*HPL[{0}, S^2]*HPL[{1}, -S^2]^3)/(24*S^2) - 
     (41*(1 + F^(-2))*F*T*HPL[{1}, -S^2]^4)/(768*S) + 
     (41*(1 + F^(-4))*F^2*T^2*HPL[{1}, -S^2]^4)/(1536*S^2) + 
     ((1 + F^(-2))*F*Pi^2*T*HPL[{2}, -S^2])/(256*S) - 
     ((1 + F^(-4))*F^2*Pi^2*T^2*HPL[{2}, -S^2])/(512*S^2) - 
     (Pi^2*HPL[{0}, S^2]*HPL[{2}, -S^2])/48 - 
     ((1 + F^(-2))*F*S*T*HPL[{0}, S^2]*HPL[{2}, -S^2])/8 + 
     (F^2*(1 + 5*S^2 + S^4 + S^6 + (2 + 2*S^2 - 8*S^4)/F^2 + 
        (1 + 5*S^2 + S^4 + S^6)/F^4)*T^2*HPL[{0}, S^2]*HPL[{2}, -S^2])/
      (32*S^2*(1 + S^2)) + ((1 + F^(-2))*F*T*HPL[{0}, S^2]^2*HPL[{2}, -S^2])/
      (32*S) - ((1 + F^(-4))*F^2*T^2*HPL[{0}, S^2]^2*HPL[{2}, -S^2])/
      (64*S^2) - ((1 + F^(-2))^2*F^2*(-1 + 7*S^2)*T^2*HPL[{1}, -S^2]*
       HPL[{2}, -S^2])/(128*S^2*(1 + S^2)) - 
     ((1 + F^(-2))*F*T*HPL[{0}, S^2]*HPL[{1}, -S^2]*HPL[{2}, -S^2])/(4*S) + 
     ((1 + F^(-4))*F^2*T^2*HPL[{0}, S^2]*HPL[{1}, -S^2]*HPL[{2}, -S^2])/
      (8*S^2) + ((1 + F^(-2))*F*T*HPL[{1}, -S^2]^2*HPL[{2}, -S^2])/(16*S) - 
     ((1 + F^(-4))*F^2*T^2*HPL[{1}, -S^2]^2*HPL[{2}, -S^2])/(32*S^2) - 
     (5*(1 + F^(-2))*F*T*HPL[{2}, -S^2]^2)/(128*S) + 
     (5*(1 + F^(-4))*F^2*T^2*HPL[{2}, -S^2]^2)/(256*S^2) - 
     (HPL[{0}, S^2]*HPL[{2}, -S^2]^2)/8 + (19*Pi^2*HPL[{3}, -S^2])/768 + 
     (HPL[{0}, S^2]^2*HPL[{3}, -S^2])/32 + 
     (11*(1 + F^(-2))*F*T*HPL[{1}, -S^2]*HPL[{3}, -S^2])/(32*S) - 
     (11*(1 + F^(-4))*F^2*T^2*HPL[{1}, -S^2]*HPL[{3}, -S^2])/(64*S^2) + 
     (11*HPL[{2}, -S^2]*HPL[{3}, -S^2])/32 - (HPL[{0}, S^2]*HPL[{4}, -S^2])/
      16 + HPL[{5}, -S^2]/16 - (37*Pi^2*HPL[{2, 1}, -S^2])/768 + 
     (3*(1 + F^(-2))*F*T*HPL[{0}, S^2]*HPL[{2, 1}, -S^2])/(8*S) - 
     (3*(1 + F^(-4))*F^2*T^2*HPL[{0}, S^2]*HPL[{2, 1}, -S^2])/(16*S^2) + 
     (HPL[{0}, S^2]^2*HPL[{2, 1}, -S^2])/16 - 
     (3*(1 + F^(-2))*F*T*HPL[{1}, -S^2]*HPL[{2, 1}, -S^2])/(16*S) + 
     (3*(1 + F^(-4))*F^2*T^2*HPL[{1}, -S^2]*HPL[{2, 1}, -S^2])/(32*S^2) + 
     (HPL[{2}, -S^2]*HPL[{2, 1}, -S^2])/8 - 
     (9*(1 + F^(-2))*F*T*HPL[{3, 1}, -S^2])/(32*S) + 
     (9*(1 + F^(-4))*F^2*T^2*HPL[{3, 1}, -S^2])/(64*S^2) + 
     (HPL[{0}, S^2]*HPL[{3, 1}, -S^2])/4 - (33*HPL[{3, 2}, -S^2])/64 - 
     (25*HPL[{4, 1}, -S^2])/16 + (29*(1 + F^(-2))*F*T*HPL[{2, 1, 1}, -S^2])/
      (64*S) - (29*(1 + F^(-4))*F^2*T^2*HPL[{2, 1, 1}, -S^2])/(128*S^2) - 
     (HPL[{0}, S^2]*HPL[{2, 1, 1}, -S^2])/2 - (5*HPL[{2, 2, 1}, -S^2])/16 + 
     HPL[{3, 1, 1}, -S^2]/64 - (41*HPL[{2, 1, 1, 1}, -S^2])/32 - 
     ((1 + F^(-2))*F*Pi^2*T*HPL[{1}, -S^2]*(3 + 3*S^2 - 4*Log[T]))/(96*S) + 
     ((1 + F^(-2))*F*T*HPL[{0}, S^2]^2*HPL[{1}, -S^2]*(1 + S^2 - 2*Log[T]))/
      (32*S) - ((1 + F^(-2))*F*T*HPL[{0}, S^2]*HPL[{1}, -S^2]^2*
       (1 + S^2 - 2*Log[T]))/(16*S) - ((1 + F^(-2))*F*T*HPL[{1}, -S^2]^3*
       (1 + S^2 - 2*Log[T]))/(12*S) + ((1 + F^(-2))*F*T*HPL[{3}, -S^2]*
       (1 + 3*S^2 - 2*Log[T]))/(16*S) + 
     ((1 + F^(-2))*F*Pi^2*S*T*(-1 + Log[T]))/48 - 
     ((1 + F^(-2))*F*S*T*HPL[{0}, S^2]^2*(-1 + Log[T]))/16 + 
     (Pi^2*HPL[{2}, -S^2]*Log[T])/24 - (HPL[{0}, S^2]^2*HPL[{2}, -S^2]*
       Log[T])/16 + (HPL[{0}, S^2]*HPL[{3}, -S^2]*Log[T])/8 - 
     (HPL[{4}, -S^2]*Log[T])/4 + (HPL[{0}, S^2]*HPL[{2, 1}, -S^2]*Log[T])/4 - 
     (HPL[{3, 1}, -S^2]*Log[T])/2 + HPL[{2, 1, 1}, -S^2]*Log[T] + 
     (3*HPL[{3}, -S^2]*Log[T]^2)/32 - (3*HPL[{2, 1}, -S^2]*Log[T]^2)/16 - 
     ((1 + F^(-2))*F*T*HPL[{2, 1}, -S^2]*(-1 + S^2 + 2*Log[T]))/(8*S) + 
     (F^2*T^2*HPL[{1}, -S^2]^3*(33 + 115*S^2 + 16*S^4 + 16*S^6 - 
        (2*(15 - 3*S^2 + 64*S^4))/F^2 + (33 + 115*S^2 + 16*S^4 + 16*S^6)/
         F^4 - 64*(1 + F^(-4))*(1 + S^2)*Log[T]))/(768*S^2*(1 + S^2)) + 
     (F^2*Pi^2*T^2*HPL[{1}, -S^2]*(23 + 60*S^2 + 12*S^4 + 12*S^6 - 
        (2*(13 + 24*S^2 + 48*S^4))/F^2 + (23 + 60*S^2 + 12*S^4 + 12*S^6)/
         F^4 - 32*(1 + F^(-4))*(1 + S^2)*Log[T]))/(1536*S^2*(1 + S^2)) - 
     (F^2*T^2*HPL[{0}, S^2]^2*HPL[{1}, -S^2]*(1 + 5*S^2 + S^4 + S^6 - 
        (4*(1 + S^2 + 2*S^4))/F^2 + (1 + 5*S^2 + S^4 + S^6)/F^4 - 
        4*(1 + F^(-4))*(1 + S^2)*Log[T]))/(128*S^2*(1 + S^2)) + 
     (F^2*T^2*HPL[{0}, S^2]*HPL[{1}, -S^2]^2*(3 + 11*S^2 + S^4 + S^6 - 
        (8*S^2*(-1 + S^2))/F^2 + (3 + 11*S^2 + S^4 + S^6)/F^4 - 
        4*(1 + F^(-4))*(1 + S^2)*Log[T]))/(64*S^2*(1 + S^2)) - 
     (F^2*T^2*HPL[{3}, -S^2]*(3 + 14*S^2 + 3*S^4 + 3*S^6 + 
        (S^2 - 21*S^4)/F^2 + (3 + 14*S^2 + 3*S^4 + 3*S^6)/F^4 - 
        4*(1 + F^(-4))*(1 + S^2)*Log[T]))/(64*S^2*(1 + S^2)) + 
     (F^2*T^2*HPL[{2, 1}, -S^2]*(-3 + 3*S^2 + 2*S^4 + 2*S^6 + 
        (6 + 8*S^2 - 10*S^4)/F^2 + (-3 + 3*S^2 + 2*S^4 + 2*S^6)/F^4 + 
        8*(1 + F^(-4))*(1 + S^2)*Log[T]))/(64*S^2*(1 + S^2)) + 
     (F^2*T^2*HPL[{0}, S^2]*HPL[{1}, -S^2]*
       ((1 + S^2)^2*(3 + 8/F^2 + S^2 + (3 + S^2)/F^4) - 
        4*(1 + F^(-2))^2*(1 + 3*S^2)*Log[T]))/(64*S^2*(1 + S^2)) + 
     (F^2*T^2*HPL[{0}, S^2]*(5 + 2*S^2 - (4*(-3 + S^2))/F^2 + 
        (5 + 2*S^2)/F^4 - 2*(2 + 4/F^2 + S^2 + (2 + S^2)/F^4)*Log[T]))/64 + 
     (F^2*T^2*HPL[{0}, S^2]^2*(-((1 + S^2)*(3 - 4/F^2 + S^2 + 
           (3 + S^2)/F^4)) + 2*(2 + S^2 - (4*S^2)/F^2 + S^4 + 
          (2 + S^2 + S^4)/F^4)*Log[T]))/(128*(1 + S^2)) + 
     (F^2*Pi^2*T^2*((1 + F^(-4))*(5 + 6*S^2 + S^4) - 
        2*(4 + S^2 + S^4 - (4*(-1 + S^2))/F^2 + (4 + S^2 + S^4)/F^4)*Log[T]))/
      (384*(1 + S^2)) + ((1 + F^(-2))*F*T*HPL[{1}, -S^2]^2*
       (-4*(1 + S^2) + 4*(1 + S^2)*Log[T] - 3*Log[T]^2))/(32*S) + 
     ((1 + F^(-2))*F*T*HPL[{2}, -S^2]*(4 - 4*S^2 + 4*(-1 + S^2)*Log[T] + 
        3*Log[T]^2))/(32*S) - (F^2*T^2*HPL[{2}, -S^2]*
       (-((-1 + S^2)*(3 - 8/F^2 + S^2 + (3 + S^2)/F^4)) + 
        2*(-1 + S^2)*(1 - 4/F^2 + S^2 + (1 + S^2)/F^4)*Log[T] + 
        3*(1 + F^(-4))*Log[T]^2))/(64*S^2) + 
     (F^2*T^2*HPL[{1}, -S^2]^2*(2*(1 + F^(-4))*(1 + S^2)^2*(3 + S^2) - 
        2*(3 + 11*S^2 + S^4 + S^6 - (8*S^2*(-1 + S^2))/F^2 + 
          (3 + 11*S^2 + S^4 + S^6)/F^4)*Log[T] + 3*(1 + F^(-4))*(1 + S^2)*
         Log[T]^2))/(64*S^2*(1 + S^2)) - 
     (F^2*T^2*HPL[{1}, -S^2]*(-2*(1 + S^2)^2*(3 + S^2 - (2*(-5 + S^2))/F^2 + 
          (3 + S^2)/F^4) + 2*(1 + S^2)^2*(3 + 8/F^2 + S^2 + (3 + S^2)/F^4)*
         Log[T] - 3*(1 + F^(-2))^2*(1 + 3*S^2)*Log[T]^2))/
      (64*S^2*(1 + S^2)) + ((1 + F^(-2))*F*S*T*Zeta[3])/8 + 
     (F^2*(1 - 2*S^2 - 2*S^4 + (2*(9 + 8*S^2))/F^2 + (1 - 2*S^2 - 2*S^4)/F^4)*
       T^2*Zeta[3])/(64*(1 + S^2)) - ((1 + F^(-2))*F*T*HPL[{1}, -S^2]*
       Zeta[3])/(32*S) + ((1 + F^(-4))*F^2*T^2*HPL[{1}, -S^2]*Zeta[3])/
      (64*S^2) - (HPL[{2}, -S^2]*Zeta[3])/32 + (9*Zeta[5])/32
 
QepvwuT2 = -(F^2*Pi^2*(1 + F^(-4) + (2*(2 + 2*S^2 + S^4))/F^2)*T^2*
        HPL[{0}, S^2])/(192*(1 + S^2)) + 
     (F^2*Pi^2*(11 + 16*S^2 + 24*S^4 + (11 + 16*S^2 + 24*S^4)/F^4 - 
        (2*(13 + 56*S^2 + 48*S^4 + 24*S^6))/F^2)*T^2*HPL[{1}, -S^2])/
      (1536*S^2*(1 + S^2)) + ((1 + F^(-2))*F*Pi^2*T*HPL[{0}, S^2]*
       HPL[{1}, -S^2])/(96*S) - ((1 + F^(-4))*F^2*Pi^2*T^2*HPL[{0}, S^2]*
       HPL[{1}, -S^2])/(192*S^2) + (3*(1 + F^(-2))^2*F^2*(1 + 3*S^2)*T^2*
       HPL[{0}, S^2]^2*HPL[{1}, -S^2])/(256*S^2*(1 + S^2)) - 
     ((1 + F^(-2))*F*Pi^2*(-11 + 8*S^2)*T*HPL[{1}, -S^2]^2)/(1536*S) + 
     (F^2*Pi^2*(-11 - (32*S^2)/F^2 + 8*S^4 + (-11 + 8*S^4)/F^4)*T^2*
       HPL[{1}, -S^2]^2)/(3072*S^2) + 
     (F^2*(S^2*(-5 - 6*S^2 + S^4) + (S^2*(-5 - 6*S^2 + S^4))/F^4 + 
        (2*(4 + 7*S^2 + 6*S^4 + 5*S^6))/F^2)*T^2*HPL[{0}, S^2]*
       HPL[{1}, -S^2]^2)/(64*S^2*(1 + S^2)) - 
     (3*(1 + F^(-2))*F*T*HPL[{0}, S^2]^2*HPL[{1}, -S^2]^2)/(128*S) + 
     (3*(1 + F^(-4))*F^2*T^2*HPL[{0}, S^2]^2*HPL[{1}, -S^2]^2)/(256*S^2) + 
     (F^2*(1 - 49*S^2 - 40*S^4 + 4*S^6 + (1 - 49*S^2 - 40*S^4 + 4*S^6)/F^4 + 
        (2*(33 + 47*S^2 + 56*S^4 + 36*S^6))/F^2)*T^2*HPL[{1}, -S^2]^3)/
      (768*S^2*(1 + S^2)) + ((1 + F^(-2))*F*S*T*HPL[{0}, S^2]*
       HPL[{1}, -S^2]^3)/48 - (F^2*(-4/F^2 + S^2 + S^2/F^4)*T^2*HPL[{0}, S^2]*
       HPL[{1}, -S^2]^3)/96 + ((1 + F^(-2))*F*(7 + 4*S^2)*T*HPL[{1}, -S^2]^4)/
      (768*S) - (F^2*(7 - (16*S^2)/F^2 + 4*S^4 + (7 + 4*S^4)/F^4)*T^2*
       HPL[{1}, -S^2]^4)/(1536*S^2) - (5*(1 + F^(-2))*F*Pi^2*T*
       HPL[{2}, -S^2])/(768*S) + (5*(1 + F^(-4))*F^2*Pi^2*T^2*HPL[{2}, -S^2])/
      (1536*S^2) + (Pi^2*HPL[{0}, S^2]*HPL[{2}, -S^2])/96 - 
     (F^2*(2 + 3*S^2 - S^4 + (2 + 3*S^2 - S^4)/F^4 + 
        (2*(2 + 5*S^2 + 3*S^4 + 2*S^6))/F^2)*T^2*HPL[{0}, S^2]*
       HPL[{2}, -S^2])/(64*S^2*(1 + S^2)) + 
     (3*(1 + F^(-2))*F*T*HPL[{0}, S^2]^2*HPL[{2}, -S^2])/(128*S) - 
     (3*(1 + F^(-4))*F^2*T^2*HPL[{0}, S^2]^2*HPL[{2}, -S^2])/(256*S^2) + 
     (F^2*(2 + 6*S^2 + 7*S^4 + (2 + 6*S^2 + 7*S^4)/F^4 - 
        (2*(4 + 12*S^2 + 11*S^4 + 6*S^6))/F^2)*T^2*HPL[{1}, -S^2]*
       HPL[{2}, -S^2])/(64*S^2*(1 + S^2)) + 
     ((1 + F^(-2))*F*T*HPL[{0}, S^2]*HPL[{1}, -S^2]*HPL[{2}, -S^2])/(16*S) - 
     ((1 + F^(-4))*F^2*T^2*HPL[{0}, S^2]*HPL[{1}, -S^2]*HPL[{2}, -S^2])/
      (32*S^2) - ((1 + F^(-2))*F*(-1 + 2*S^2)*T*HPL[{1}, -S^2]^2*
       HPL[{2}, -S^2])/(64*S) - (F^2*(1 + (8*S^2)/F^2 - 2*S^4 + 
        (1 - 2*S^4)/F^4)*T^2*HPL[{1}, -S^2]^2*HPL[{2}, -S^2])/(128*S^2) + 
     ((1 + F^(-2))*F*(-3 + 4*S^2)*T*HPL[{2}, -S^2]^2)/(128*S) + 
     (F^2*(3 + (16*S^2)/F^2 - 4*S^4 + (3 - 4*S^4)/F^4)*T^2*HPL[{2}, -S^2]^2)/
      (256*S^2) + (HPL[{0}, S^2]*HPL[{2}, -S^2]^2)/32 - 
     (13*Pi^2*HPL[{3}, -S^2])/768 + 
     (F^2*(4 + 6*S^2 + 3*S^4 - (2*S^2*(2 + S^2))/F^2 + (4 + 6*S^2 + 3*S^4)/
         F^4)*T^2*HPL[{3}, -S^2])/(128*S^2*(1 + S^2)) + 
     ((1 + F^(-2))*F*(-8 + S^2)*T*HPL[{0}, S^2]*HPL[{3}, -S^2])/(64*S) - 
     (F^2*(-8 - (4*S^2)/F^2 + S^4 + (-8 + S^4)/F^4)*T^2*HPL[{0}, S^2]*
       HPL[{3}, -S^2])/(128*S^2) + (3*HPL[{0}, S^2]^2*HPL[{3}, -S^2])/128 - 
     ((1 + F^(-2))*F*(2 + 3*S^2)*T*HPL[{1}, -S^2]*HPL[{3}, -S^2])/(64*S) + 
     (F^2*(2 - (12*S^2)/F^2 + 3*S^4 + (2 + 3*S^4)/F^4)*T^2*HPL[{1}, -S^2]*
       HPL[{3}, -S^2])/(128*S^2) + (HPL[{2}, -S^2]*HPL[{3}, -S^2])/64 - 
     ((1 + F^(-2))*F*(-3 + S^2)*T*HPL[{4}, -S^2])/(16*S) + 
     (F^2*(-3 - (4*S^2)/F^2 + S^4 + (-3 + S^4)/F^4)*T^2*HPL[{4}, -S^2])/
      (32*S^2) - (3*HPL[{0}, S^2]*HPL[{4}, -S^2])/16 + 
     (7*HPL[{5}, -S^2])/16 + (19*Pi^2*HPL[{2, 1}, -S^2])/768 - 
     (F^2*(5 + 5*S^2 + 5*S^4 + 4*S^6 - (2*(3 + 15*S^2 + 11*S^4))/F^2 + 
        (5 + 5*S^2 + 5*S^4 + 4*S^6)/F^4)*T^2*HPL[{2, 1}, -S^2])/
      (64*S^2*(1 + S^2)) - ((1 + F^(-2))*F*(-4 + 3*S^2)*T*HPL[{0}, S^2]*
       HPL[{2, 1}, -S^2])/(32*S) + 
     (F^2*(-4 - (12*S^2)/F^2 + 3*S^4 + (-4 + 3*S^4)/F^4)*T^2*HPL[{0}, S^2]*
       HPL[{2, 1}, -S^2])/(64*S^2) - (3*HPL[{0}, S^2]^2*HPL[{2, 1}, -S^2])/
      64 + ((1 + F^(-2))*F*S*T*HPL[{1}, -S^2]*HPL[{2, 1}, -S^2])/32 - 
     (F^2*(-4/F^2 + S^2 + S^2/F^4)*T^2*HPL[{1}, -S^2]*HPL[{2, 1}, -S^2])/64 + 
     (3*HPL[{2}, -S^2]*HPL[{2, 1}, -S^2])/32 + 
     ((1 + F^(-2))*F*(-9 + 8*S^2)*T*HPL[{3, 1}, -S^2])/(32*S) + 
     (F^2*(9 + (32*S^2)/F^2 - 8*S^4 + (9 - 8*S^4)/F^4)*T^2*HPL[{3, 1}, -S^2])/
      (64*S^2) + (5*HPL[{0}, S^2]*HPL[{3, 1}, -S^2])/16 - 
     (13*HPL[{3, 2}, -S^2])/64 - (5*HPL[{4, 1}, -S^2])/4 - 
     ((1 + F^(-2))*F*(-13 + 16*S^2)*T*HPL[{2, 1, 1}, -S^2])/(64*S) - 
     (F^2*(13 + (64*S^2)/F^2 - 16*S^4 + (13 - 16*S^4)/F^4)*T^2*
       HPL[{2, 1, 1}, -S^2])/(128*S^2) - (HPL[{0}, S^2]*HPL[{2, 1, 1}, -S^2])/
      8 - HPL[{2, 2, 1}, -S^2]/8 + (13*HPL[{3, 1, 1}, -S^2])/64 + 
     (3*HPL[{2, 1, 1, 1}, -S^2])/32 + (F^2*Pi^2*(1 + S^2)*T^2*
       (1 + F^(-4) - 4/F^2 + (4*Log[T])/F^2))/96 + 
     (F^2*(1 + S^2)*(1 + 2*S^2)*T^2*HPL[{2}, -S^2]*(1 + F^(-4) - 4/F^2 + 
        (4*Log[T])/F^2))/(32*S^2) - (F^2*(1 + S^2)^2*T^2*HPL[{1}, -S^2]^2*
       (1 + F^(-4) - 8/F^2 + (8*Log[T])/F^2))/(32*S^2) - 
     (F^2*(1 + S^2)*T^2*HPL[{0}, S^2]*HPL[{1}, -S^2]*
       (S^2 + S^2/F^4 - (2*(1 + 3*S^2))/F^2 + (2*(1 + 3*S^2)*Log[T])/F^2))/
      (16*S^2) + (F^2*(1 + S^2)*T^2*HPL[{0}, S^2]*(1 + F^(-4) + 6/F^2 - 
        (8*Log[T])/F^2 + (4*Log[T]^2)/F^2))/32 + 
     (F^2*(1 + S^2)^2*T^2*HPL[{1}, -S^2]*(1 + F^(-4) + 6/F^2 - 
        (8*Log[T])/F^2 + (4*Log[T]^2)/F^2))/(32*S^2) + 
     (F^2*(5 + 4*S^4 + (2 - 16*S^2)/F^2 + (5 + 4*S^4)/F^4)*T^2*Zeta[3])/
      (64*(1 + S^2)) + ((1 + F^(-2))*F*(-5 + 4*S^2)*T*HPL[{1}, -S^2]*Zeta[3])/
      (32*S) - (F^2*(-5 - (16*S^2)/F^2 + 4*S^4 + (-5 + 4*S^4)/F^4)*T^2*
       HPL[{1}, -S^2]*Zeta[3])/(64*S^2) - (9*HPL[{2}, -S^2]*Zeta[3])/32 + 
     (9*Zeta[5])/32
 
QepvuwT2 = (F^2*Pi^2*(3*(2 + S^4) + (3*(2 + S^4))/F^4 - 
        (2*(2 + 16*S^2 + 5*S^4))/F^2)*T^2*HPL[{0}, S^2])/(1536*(1 + S^2)) + 
     (3*(1 + F^(-2))^2*F^2*T^2*HPL[{0}, S^2]^3)/(256*(1 + S^2)) + 
     ((1 + F^(-2))^2*F^2*Pi^2*(-4 - 8*S^2 + 3*S^4)*T^2*HPL[{1}, -S^2])/
      (1536*(1 + S^2)) + ((1 + F^(-2))*F*Pi^2*(-2 + S^2)*T*HPL[{0}, S^2]*
       HPL[{1}, -S^2])/(256*S) - (F^2*Pi^2*(-2 - (4*S^2)/F^2 + S^4 + 
        (-2 + S^4)/F^4)*T^2*HPL[{0}, S^2]*HPL[{1}, -S^2])/(512*S^2) - 
     (F^2*(2 + 3*S^2 + 6*S^4 + (2 + 3*S^2 + 6*S^4)/F^4 - 
        (2*(4 + 15*S^2 + 12*S^4 + 6*S^6))/F^2)*T^2*HPL[{0}, S^2]^2*
       HPL[{1}, -S^2])/(128*S^2*(1 + S^2)) - 
     (3*(1 + F^(-2))*F*T*HPL[{0}, S^2]^3*HPL[{1}, -S^2])/(128*S) + 
     (3*(1 + F^(-4))*F^2*T^2*HPL[{0}, S^2]^3*HPL[{1}, -S^2])/(256*S^2) + 
     (7*(1 + F^(-2))*F*Pi^2*S*T*HPL[{1}, -S^2]^2)/1536 - 
     (7*F^2*Pi^2*(-4/F^2 + S^2 + S^2/F^4)*T^2*HPL[{1}, -S^2]^2)/3072 + 
     (F^2*(S^2*(-16 - 29*S^2 + S^4) + (S^2*(-16 - 29*S^2 + S^4))/F^4 + 
        (32 + 64*S^2 + 38*S^4 + 34*S^6)/F^2)*T^2*HPL[{0}, S^2]*
       HPL[{1}, -S^2]^2)/(256*S^2*(1 + S^2)) + 
     ((1 + F^(-2))*F*(-2 + 3*S^2)*T*HPL[{0}, S^2]^2*HPL[{1}, -S^2]^2)/
      (128*S) + (F^2*(2 + (12*S^2)/F^2 - 3*S^4 + (2 - 3*S^4)/F^4)*T^2*
       HPL[{0}, S^2]^2*HPL[{1}, -S^2]^2)/(256*S^2) + 
     (F^2*(4 - 40*S^2 - 49*S^4 + S^6 + (4 - 40*S^2 - 49*S^4 + S^6)/F^4 + 
        (2*(36 + 56*S^2 + 47*S^4 + 33*S^6))/F^2)*T^2*HPL[{1}, -S^2]^3)/
      (768*S^2*(1 + S^2)) + (7*(1 + F^(-2))*F*S*T*HPL[{0}, S^2]*
       HPL[{1}, -S^2]^3)/192 - (7*F^2*(-4/F^2 + S^2 + S^2/F^4)*T^2*
       HPL[{0}, S^2]*HPL[{1}, -S^2]^3)/384 + 
     ((1 + F^(-2))*F*(4 + 7*S^2)*T*HPL[{1}, -S^2]^4)/(768*S) - 
     (F^2*(4 - (28*S^2)/F^2 + 7*S^4 + (4 + 7*S^4)/F^4)*T^2*HPL[{1}, -S^2]^4)/
      (1536*S^2) - ((1 + F^(-2))*F*Pi^2*(-8 + S^2)*T*HPL[{2}, -S^2])/
      (768*S) + (F^2*Pi^2*(-8 - (4*S^2)/F^2 + S^4 + (-8 + S^4)/F^4)*T^2*
       HPL[{2}, -S^2])/(1536*S^2) - (3*Pi^2*HPL[{0}, S^2]*HPL[{2}, -S^2])/
      256 + (F^2*(4 - 5*S^2 + S^4 + (4 - 5*S^2 + S^4)/F^4 - 
        (2*(-4 + 7*S^2 + S^4))/F^2)*T^2*HPL[{0}, S^2]*HPL[{2}, -S^2])/
      (64*S^2) + ((1 + F^(-2))*F*(8 + 3*S^2)*T*HPL[{0}, S^2]^2*
       HPL[{2}, -S^2])/(128*S) - (F^2*(8 - (12*S^2)/F^2 + 3*S^4 + 
        (8 + 3*S^4)/F^4)*T^2*HPL[{0}, S^2]^2*HPL[{2}, -S^2])/(256*S^2) - 
     (3*HPL[{0}, S^2]^3*HPL[{2}, -S^2])/128 - 
     (F^2*(S^2*(7 + 6*S^2 + 2*S^4) + (S^2*(7 + 6*S^2 + 2*S^4))/F^4 - 
        (2*(6 + 11*S^2 + 12*S^4 + 4*S^6))/F^2)*T^2*HPL[{1}, -S^2]*
       HPL[{2}, -S^2])/(64*S^2*(1 + S^2)) + 
     ((1 + F^(-2))*F*(1 + S^2)*T*HPL[{0}, S^2]*HPL[{1}, -S^2]*HPL[{2}, -S^2])/
      (32*S) - (F^2*(1 - (4*S^2)/F^2 + S^4 + (1 + S^4)/F^4)*T^2*HPL[{0}, S^2]*
       HPL[{1}, -S^2]*HPL[{2}, -S^2])/(64*S^2) - 
     ((1 + F^(-2))*F*(-2 + S^2)*T*HPL[{1}, -S^2]^2*HPL[{2}, -S^2])/(64*S) + 
     (F^2*(-2 - (4*S^2)/F^2 + S^4 + (-2 + S^4)/F^4)*T^2*HPL[{1}, -S^2]^2*
       HPL[{2}, -S^2])/(128*S^2) - ((1 + F^(-2))*F*(-4 + 3*S^2)*T*
       HPL[{2}, -S^2]^2)/(128*S) + 
     (F^2*(-4 - (12*S^2)/F^2 + 3*S^4 + (-4 + 3*S^4)/F^4)*T^2*
       HPL[{2}, -S^2]^2)/(256*S^2) + (3*Pi^2*HPL[{3}, -S^2])/128 - 
     (F^2*(8 + 7*S^2 + 4*S^4 + 6*S^6 - (2*S^2*(21 + 28*S^2 + 6*S^4))/F^2 + 
        (8 + 7*S^2 + 4*S^4 + 6*S^6)/F^4)*T^2*HPL[{3}, -S^2])/
      (128*S^2*(1 + S^2)) - ((1 + F^(-2))*F*(-4 + 7*S^2)*T*HPL[{0}, S^2]*
       HPL[{3}, -S^2])/(64*S) - (F^2*(4 + (28*S^2)/F^2 - 7*S^4 + 
        (4 - 7*S^4)/F^4)*T^2*HPL[{0}, S^2]*HPL[{3}, -S^2])/(128*S^2) + 
     (7*HPL[{0}, S^2]^2*HPL[{3}, -S^2])/64 - 
     ((1 + F^(-2))*F*(1 + 2*S^2)*T*HPL[{1}, -S^2]*HPL[{3}, -S^2])/(64*S) + 
     (F^2*(1 - (8*S^2)/F^2 + 2*S^4 + (1 + 2*S^4)/F^4)*T^2*HPL[{1}, -S^2]*
       HPL[{3}, -S^2])/(128*S^2) + (HPL[{2}, -S^2]*HPL[{3}, -S^2])/64 + 
     ((1 + F^(-2))*F*(-12 + 11*S^2)*T*HPL[{4}, -S^2])/(64*S) - 
     (F^2*(-12 - (44*S^2)/F^2 + 11*S^4 + (-12 + 11*S^4)/F^4)*T^2*
       HPL[{4}, -S^2])/(128*S^2) - (3*HPL[{0}, S^2]*HPL[{4}, -S^2])/64 - 
     (5*HPL[{5}, -S^2])/16 - (7*Pi^2*HPL[{2, 1}, -S^2])/768 + 
     (F^2*(4 + 5*S^2 + 5*S^4 + 5*S^6 - (2*S^2*(11 + 15*S^2 + 3*S^4))/F^2 + 
        (4 + 5*S^2 + 5*S^4 + 5*S^6)/F^4)*T^2*HPL[{2, 1}, -S^2])/
      (64*S^2*(1 + S^2)) - ((1 + F^(-2))*F*(-8 + 5*S^2)*T*HPL[{0}, S^2]*
       HPL[{2, 1}, -S^2])/(64*S) + 
     (F^2*(-8 - (20*S^2)/F^2 + 5*S^4 + (-8 + 5*S^4)/F^4)*T^2*HPL[{0}, S^2]*
       HPL[{2, 1}, -S^2])/(128*S^2) - (5*HPL[{0}, S^2]^2*HPL[{2, 1}, -S^2])/
      64 - ((1 + F^(-2))*F*T*HPL[{1}, -S^2]*HPL[{2, 1}, -S^2])/(32*S) + 
     ((1 + F^(-4))*F^2*T^2*HPL[{1}, -S^2]*HPL[{2, 1}, -S^2])/(64*S^2) + 
     (3*HPL[{2}, -S^2]*HPL[{2, 1}, -S^2])/32 - 
     (5*(1 + F^(-2))*F*S*T*HPL[{3, 1}, -S^2])/64 + 
     (5*F^2*(-4/F^2 + S^2 + S^2/F^4)*T^2*HPL[{3, 1}, -S^2])/128 + 
     (23*HPL[{0}, S^2]*HPL[{3, 1}, -S^2])/64 + (5*HPL[{3, 2}, -S^2])/64 - 
     HPL[{4, 1}, -S^2]/8 - ((1 + F^(-2))*F*(-16 + 13*S^2)*T*
       HPL[{2, 1, 1}, -S^2])/(64*S) - 
     (F^2*(16 + (52*S^2)/F^2 - 13*S^4 + (16 - 13*S^4)/F^4)*T^2*
       HPL[{2, 1, 1}, -S^2])/(128*S^2) - 
     (7*HPL[{0}, S^2]*HPL[{2, 1, 1}, -S^2])/32 - HPL[{2, 2, 1}, -S^2]/8 + 
     (19*HPL[{3, 1, 1}, -S^2])/64 - (3*HPL[{2, 1, 1, 1}, -S^2])/32 - 
     (F^2*Pi^2*(1 + S^2)*T^2*(1 + F^(-4) - 4/F^2 + (4*Log[T])/F^2))/192 - 
     (3*F^2*(1 + S^2)*T^2*HPL[{0}, S^2]^2*(1 + F^(-4) - 4/F^2 + 
        (4*Log[T])/F^2))/64 - (F^2*(1 + S^2)*(2 + S^2)*T^2*HPL[{2}, -S^2]*
       (1 + F^(-4) - 4/F^2 + (4*Log[T])/F^2))/(32*S^2) - 
     (F^2*(1 + S^2)^2*T^2*HPL[{1}, -S^2]^2*(1 + F^(-4) - 8/F^2 + 
        (8*Log[T])/F^2))/(32*S^2) - (F^2*(1 + S^2)*T^2*HPL[{0}, S^2]*
       HPL[{1}, -S^2]*(S^2 + S^2/F^4 - (2*(1 + 3*S^2))/F^2 + 
        (2*(1 + 3*S^2)*Log[T])/F^2))/(16*S^2) + 
     (F^2*(1 + S^2)*T^2*HPL[{0}, S^2]*(1 + F^(-4) + 6/F^2 - (8*Log[T])/F^2 + 
        (4*Log[T]^2)/F^2))/32 + (F^2*(1 + S^2)^2*T^2*HPL[{1}, -S^2]*
       (1 + F^(-4) + 6/F^2 - (8*Log[T])/F^2 + (4*Log[T]^2)/F^2))/(32*S^2) + 
     (3*Pi^2*Zeta[3])/256 + (F^2*(-5*(1 + S^4) - (5*(1 + S^4))/F^4 + 
        (6 + 32*S^2 + 6*S^4)/F^2)*T^2*Zeta[3])/(64*(1 + S^2)) - 
     (5*(1 + F^(-2))*F*(-1 + S^2)*T*HPL[{1}, -S^2]*Zeta[3])/(32*S) + 
     (5*F^2*(-1 - (4*S^2)/F^2 + S^4 + (-1 + S^4)/F^4)*T^2*HPL[{1}, -S^2]*
       Zeta[3])/(64*S^2) + (5*HPL[{2}, -S^2]*Zeta[3])/16 + (21*Zeta[5])/64
 
QepwuvT2 = -((1 + F^(-2))*F*Pi^4*S*T)/768 + 
     (F^2*Pi^4*(-4/F^2 + S^2 + S^2/F^4)*T^2)/1536 + 
     (Pi^4*HPL[{0}, S^2])/768 - (3*(1 + F^(-2))*F*Pi^2*S*T*HPL[{0}, S^2]^2)/
      256 + (3*F^2*Pi^2*(-4/F^2 + S^2 + S^2/F^4)*T^2*HPL[{0}, S^2]^2)/512 + 
     (Pi^2*HPL[{0}, S^2]^3)/256 - (3*T^2*HPL[{0}, S^2]^3)/128 - 
     (25*(1 + F^(-2))*F*Pi^2*S*T*HPL[{0}, S^2]*HPL[{1}, -S^2])/768 + 
     (25*F^2*Pi^2*(-4/F^2 + S^2 + S^2/F^4)*T^2*HPL[{0}, S^2]*HPL[{1}, -S^2])/
      1536 - (53*(1 + F^(-2))*F*Pi^2*S*T*HPL[{1}, -S^2]^2)/1536 + 
     (53*F^2*Pi^2*(-4/F^2 + S^2 + S^2/F^4)*T^2*HPL[{1}, -S^2]^2)/3072 - 
     (9*(1 + F^(-2))*F*S*T*HPL[{0}, S^2]^2*HPL[{1}, -S^2]^2)/128 + 
     (9*F^2*(-4/F^2 + S^2 + S^2/F^4)*T^2*HPL[{0}, S^2]^2*HPL[{1}, -S^2]^2)/
      256 - (25*(1 + F^(-2))*F*S*T*HPL[{0}, S^2]*HPL[{1}, -S^2]^3)/192 + 
     (25*F^2*(-4/F^2 + S^2 + S^2/F^4)*T^2*HPL[{0}, S^2]*HPL[{1}, -S^2]^3)/
      384 - (41*(1 + F^(-2))*F*S*T*HPL[{1}, -S^2]^4)/768 + 
     (41*F^2*(-4/F^2 + S^2 + S^2/F^4)*T^2*HPL[{1}, -S^2]^4)/1536 - 
     (13*(1 + F^(-2))*F*Pi^2*S*T*HPL[{2}, -S^2])/768 + 
     (13*F^2*Pi^2*(-4/F^2 + S^2 + S^2/F^4)*T^2*HPL[{2}, -S^2])/1536 + 
     (25*Pi^2*HPL[{0}, S^2]*HPL[{2}, -S^2])/768 - 
     (3*(1 + F^(-2))*F*S*T*HPL[{0}, S^2]^2*HPL[{2}, -S^2])/64 + 
     (3*F^2*(-4/F^2 + S^2 + S^2/F^4)*T^2*HPL[{0}, S^2]^2*HPL[{2}, -S^2])/
      128 - ((1 + F^(-2))^2*F^2*S^2*(-7 + S^2)*T^2*HPL[{1}, -S^2]*
       HPL[{2}, -S^2])/(128*(1 + S^2)) - (3*(1 + F^(-2))*F*S*T*HPL[{0}, S^2]*
       HPL[{1}, -S^2]*HPL[{2}, -S^2])/16 + 
     (3*F^2*(-4/F^2 + S^2 + S^2/F^4)*T^2*HPL[{0}, S^2]*HPL[{1}, -S^2]*
       HPL[{2}, -S^2])/32 - ((1 + F^(-2))*F*S*T*HPL[{1}, -S^2]^2*
       HPL[{2}, -S^2])/16 + (F^2*(-4/F^2 + S^2 + S^2/F^4)*T^2*
       HPL[{1}, -S^2]^2*HPL[{2}, -S^2])/32 - 
     (5*(1 + F^(-2))*F*S*T*HPL[{2}, -S^2]^2)/128 + 
     (5*F^2*(-4/F^2 + S^2 + S^2/F^4)*T^2*HPL[{2}, -S^2]^2)/256 + 
     (3*HPL[{0}, S^2]*HPL[{2}, -S^2]^2)/32 - (Pi^2*HPL[{3}, -S^2])/64 - 
     (3*(1 + F^(-2))*F*S*T*HPL[{0}, S^2]*HPL[{3}, -S^2])/64 + 
     (3*F^2*(-4/F^2 + S^2 + S^2/F^4)*T^2*HPL[{0}, S^2]*HPL[{3}, -S^2])/128 + 
     (3*HPL[{0}, S^2]^2*HPL[{3}, -S^2])/64 + 
     (5*(1 + F^(-2))*F*S*T*HPL[{1}, -S^2]*HPL[{3}, -S^2])/32 - 
     (5*F^2*(-4/F^2 + S^2 + S^2/F^4)*T^2*HPL[{1}, -S^2]*HPL[{3}, -S^2])/64 - 
     (5*HPL[{2}, -S^2]*HPL[{3}, -S^2])/32 + 
     (7*(1 + F^(-2))*F*S*T*HPL[{4}, -S^2])/64 - 
     (7*F^2*(-4/F^2 + S^2 + S^2/F^4)*T^2*HPL[{4}, -S^2])/128 - 
     (3*HPL[{0}, S^2]*HPL[{4}, -S^2])/64 - HPL[{5}, -S^2]/16 + 
     (53*Pi^2*HPL[{2, 1}, -S^2])/768 + (7*(1 + F^(-2))*F*S*T*HPL[{0}, S^2]*
       HPL[{2, 1}, -S^2])/64 - (7*F^2*(-4/F^2 + S^2 + S^2/F^4)*T^2*
       HPL[{0}, S^2]*HPL[{2, 1}, -S^2])/128 + 
     (9*HPL[{0}, S^2]^2*HPL[{2, 1}, -S^2])/64 + 
     (3*(1 + F^(-2))*F*S*T*HPL[{1}, -S^2]*HPL[{2, 1}, -S^2])/16 - 
     (3*F^2*(-4/F^2 + S^2 + S^2/F^4)*T^2*HPL[{1}, -S^2]*HPL[{2, 1}, -S^2])/
      32 + (HPL[{2}, -S^2]*HPL[{2, 1}, -S^2])/8 + 
     (11*(1 + F^(-2))*F*S*T*HPL[{3, 1}, -S^2])/64 - 
     (11*F^2*(-4/F^2 + S^2 + S^2/F^4)*T^2*HPL[{3, 1}, -S^2])/128 - 
     (25*HPL[{0}, S^2]*HPL[{3, 1}, -S^2])/64 + (13*HPL[{3, 2}, -S^2])/64 + 
     (5*HPL[{4, 1}, -S^2])/8 - (29*(1 + F^(-2))*F*S*T*HPL[{2, 1, 1}, -S^2])/
      64 + (29*F^2*(-4/F^2 + S^2 + S^2/F^4)*T^2*HPL[{2, 1, 1}, -S^2])/128 + 
     (25*HPL[{0}, S^2]*HPL[{2, 1, 1}, -S^2])/32 - (5*HPL[{2, 2, 1}, -S^2])/
      16 - (81*HPL[{3, 1, 1}, -S^2])/64 + (41*HPL[{2, 1, 1, 1}, -S^2])/32 + 
     ((1 + F^(-2))*F*Pi^2*S*T*HPL[{0}, S^2]*(-1 + Log[T]))/48 - 
     (Pi^4*Log[T])/288 - (Pi^2*HPL[{0}, S^2]^2*Log[T])/96 - 
     (Pi^2*HPL[{2}, -S^2]*Log[T])/24 - (3*HPL[{0}, S^2]^2*HPL[{2}, -S^2]*
       Log[T])/16 + (HPL[{0}, S^2]*HPL[{3}, -S^2]*Log[T])/8 + 
     (HPL[{4}, -S^2]*Log[T])/4 - (3*HPL[{0}, S^2]*HPL[{2, 1}, -S^2]*Log[T])/
      4 + (HPL[{3, 1}, -S^2]*Log[T])/2 - HPL[{2, 1, 1}, -S^2]*Log[T] + 
     (Pi^2*HPL[{0}, S^2]*Log[T]^2)/64 + (3*HPL[{0}, S^2]^3*Log[T]^2)/64 + 
     (3*HPL[{0}, S^2]*HPL[{2}, -S^2]*Log[T]^2)/16 - 
     (3*HPL[{3}, -S^2]*Log[T]^2)/32 + (3*HPL[{2, 1}, -S^2]*Log[T]^2)/16 + 
     ((1 + F^(-2))*F*S*T*HPL[{0}, S^2]*HPL[{2}, -S^2]*(-1 + 2*Log[T]))/8 + 
     (3*(1 + F^(-2))*F*T*HPL[{0}, S^2]^2*HPL[{1}, -S^2]*
       (-1 - S^2 + 2*S^2*Log[T]))/(32*S) + 
     (3*(1 + F^(-2))*F*T*HPL[{0}, S^2]*HPL[{1}, -S^2]^2*
       (-1 - S^2 + 2*S^2*Log[T]))/(16*S) + 
     ((1 + F^(-2))*F*T*HPL[{1}, -S^2]^3*(-1 - S^2 + 2*S^2*Log[T]))/(12*S) + 
     ((1 + F^(-2))*F*T*HPL[{2, 1}, -S^2]*(1 - S^2 + 2*S^2*Log[T]))/(8*S) + 
     ((1 + F^(-2))*F*Pi^2*T*HPL[{1}, -S^2]*(-3*(1 + S^2) + 4*S^2*Log[T]))/
      (96*S) - ((1 + F^(-2))*F*T*HPL[{3}, -S^2]*(-1 - 3*S^2 + 6*S^2*Log[T]))/
      (16*S) + (F^2*Pi^2*T^2*HPL[{0}, S^2]*(S^2*(42 + 17*S^2) + 
        (S^2*(42 + 17*S^2))/F^4 - (2*(22 + 4*S^2 + 7*S^4))/F^2 - 
        16*(1 + S^2)*(-4/F^2 + S^2 + S^2/F^4)*Log[T]))/(1536*(1 + S^2)) - 
     (F^2*T^2*HPL[{0}, S^2]*HPL[{2}, -S^2]*
       (-3*(S^2*(7 + 3*S^2) + (S^2*(7 + 3*S^2))/F^4 - (2*(2 - S^2 + S^4))/
           F^2) + 16*(1 + S^2)*(-4/F^2 + S^2 + S^2/F^4)*Log[T]))/
      (128*(1 + S^2)) + (F^2*T^2*HPL[{0}, S^2]*HPL[{1}, -S^2]^2*
       (12 + 12*S^2 + 71*S^4 + 21*S^6 - (2*S^2*(48 + 13*S^2 + 15*S^4))/F^2 + 
        (12 + 12*S^2 + 71*S^4 + 21*S^6)/F^4 - 48*S^2*(1 + S^2)*
         (-4/F^2 + S^2 + S^2/F^4)*Log[T]))/(256*S^2*(1 + S^2)) - 
     (F^2*T^2*HPL[{3}, -S^2]*(1 + S^2 + 11*S^4 + 6*S^6 - 
        (S^2*(11 + 7*S^2 + 6*S^4))/F^2 + (1 + S^2 + 11*S^4 + 6*S^6)/F^4 - 
        12*S^2*(1 + S^2)*(-4/F^2 + S^2 + S^2/F^4)*Log[T]))/
      (64*S^2*(1 + S^2)) - (3*F^2*T^2*HPL[{0}, S^2]^2*HPL[{1}, -S^2]*
       (-1 - S^2 - 4*S^4 - S^6 - (1 + S^2 + 4*S^4 + S^6)/F^4 + 
        (8*S^2 + 6*S^4 + 4*S^6)/F^2 + 4*S^2*(1 + S^2)*(-4/F^2 + S^2 + 
          S^2/F^4)*Log[T]))/(128*S^2*(1 + S^2)) - 
     (F^2*T^2*HPL[{2, 1}, -S^2]*(2 + 2*S^2 + 3*S^4 - 3*S^6 + 
        (2*S^2*(-5 + 4*S^2 + 3*S^4))/F^2 + (2 + 2*S^2 + 3*S^4 - 3*S^6)/F^4 + 
        8*S^2*(1 + S^2)*(-4/F^2 + S^2 + S^2/F^4)*Log[T]))/
      (64*S^2*(1 + S^2)) - (F^2*Pi^2*T^2*HPL[{1}, -S^2]*
       (-12 - 12*S^2 - 74*S^4 - 21*S^6 - (12 + 12*S^2 + 74*S^4 + 21*S^6)/
         F^4 + (96*S^2 + 20*S^4 + 30*S^6)/F^2 + 32*S^2*(1 + S^2)*
         (-4/F^2 + S^2 + S^2/F^4)*Log[T]))/(1536*S^2*(1 + S^2)) - 
     (F^2*T^2*HPL[{1}, -S^2]^3*(-16 - 16*S^2 - 115*S^4 - 33*S^6 + 
        (2*S^2*(64 - 3*S^2 + 15*S^4))/F^2 - (16 + 16*S^2 + 115*S^4 + 33*S^6)/
         F^4 + 64*S^2*(1 + S^2)*(-4/F^2 + S^2 + S^2/F^4)*Log[T]))/
      (768*S^2*(1 + S^2)) - ((1 + F^(-2))*F*Pi^2*S*T*
       (4 - 4*Log[T] + 3*Log[T]^2))/192 - 
     (3*(1 + F^(-2))*F*S*T*HPL[{0}, S^2]^2*(4 - 4*Log[T] + 3*Log[T]^2))/64 - 
     ((1 + F^(-2))*F*T*HPL[{2}, -S^2]*(4*(-1 + S^2) - 4*(-1 + S^2)*Log[T] + 
        3*S^2*Log[T]^2))/(32*S) - ((1 + F^(-2))*F*T*HPL[{0}, S^2]*
       HPL[{1}, -S^2]*(4*(1 + S^2) - 4*(1 + S^2)*Log[T] + 3*S^2*Log[T]^2))/
      (16*S) - ((1 + F^(-2))*F*T*HPL[{1}, -S^2]^2*(4*(1 + S^2) - 
        4*(1 + S^2)*Log[T] + 3*S^2*Log[T]^2))/(32*S) + 
     (F^2*T^2*HPL[{0}, S^2]*((1 + S^2)*(3 + 6*S^2 + (4*(1 + 5*S^2))/F^2 + 
          (3 + 6*S^2)/F^4) - 2*(1 + S^2)*(2 + 3*S^2 + (2 + 3*S^2)/F^4 + 
          (4 + 8*S^2)/F^2)*Log[T] + 3*(1 + F^(-2))^2*S^2*(3 + S^2)*Log[T]^2))/
      (64*(1 + S^2)) + (F^2*T^2*HPL[{1}, -S^2]*
       (2*(1 + S^2)^2*(1 + 3*S^2 + (1 + 3*S^2)/F^4 + (2*(-1 + 5*S^2))/F^2) - 
        2*(1 + S^2)^2*(1 + 3*S^2 + (8*S^2)/F^2 + (1 + 3*S^2)/F^4)*Log[T] + 
        3*(1 + F^(-2))^2*S^4*(3 + S^2)*Log[T]^2))/(64*S^2*(1 + S^2)) + 
     (F^2*Pi^2*T^2*((1 + S^2)*((-8*(-1 + S^2))/F^2 + 3*(1 + S^2) + 
          (3*(1 + S^2))/F^4) - 2*S^2*(5 + S^2 - (4*(-1 + S^2))/F^2 + 
          (5 + S^2)/F^4)*Log[T] + 3*(1 + S^2)*(-4/F^2 + S^2 + S^2/F^4)*
         Log[T]^2))/(384*(1 + S^2)) + (F^2*T^2*HPL[{0}, S^2]^2*
       ((1 + S^2)*(3 + 9*S^2 - (4*(1 + 6*S^2))/F^2 + (3 + 9*S^2)/F^4) - 
        2*(3*S^2*(3 + S^2) + (3*S^2*(3 + S^2))/F^4 - (4*(2 + 2*S^2 + 3*S^4))/
           F^2)*Log[T] + 9*(1 + S^2)*(-4/F^2 + S^2 + S^2/F^4)*Log[T]^2))/
      (128*(1 + S^2)) + (F^2*T^2*HPL[{1}, -S^2]^2*
       (2*(1 + F^(-4))*(1 + S^2)^2*(1 + 3*S^2) - 
        2*(1 + S^2 + 11*S^4 + 3*S^6 + (8*S^2*(-1 + S^2))/F^2 + 
          (1 + S^2 + 11*S^4 + 3*S^6)/F^4)*Log[T] + 3*S^2*(1 + S^2)*
         (-4/F^2 + S^2 + S^2/F^4)*Log[T]^2))/(64*S^2*(1 + S^2)) + 
     (F^2*T^2*HPL[{0}, S^2]*HPL[{1}, -S^2]*
       ((1 + S^2)^2*(3 + 9*S^2 - (8*S^2)/F^2 + (3 + 9*S^2)/F^4) - 
        4*(1 + S^2 + 8*S^4 + 2*S^6 - (2*S^2*(4 - S^2 + S^4))/F^2 + 
          (1 + S^2 + 8*S^4 + 2*S^6)/F^4)*Log[T] + 6*S^2*(1 + S^2)*
         (-4/F^2 + S^2 + S^2/F^4)*Log[T]^2))/(64*S^2*(1 + S^2)) + 
     (F^2*T^2*HPL[{2}, -S^2]*((-1 + S^2)*(1 + 3*S^2 - (8*S^2)/F^2 + 
          (1 + 3*S^2)/F^4) - 2*(-1 + S^2)*(1 + S^2 - (4*S^2)/F^2 + 
          (1 + S^2)/F^4)*Log[T] + 3*((-4*S^2)/F^2 + S^4 + S^4/F^4)*Log[T]^2))/
      (64*S^2) + (5*Pi^2*Zeta[3])/768 - (5*(1 + F^(-2))*F*S*T*HPL[{0}, S^2]*
       Zeta[3])/16 + (5*F^2*(-4/F^2 + S^2 + S^2/F^4)*T^2*HPL[{0}, S^2]*
       Zeta[3])/32 + (5*HPL[{0}, S^2]^2*Zeta[3])/32 - 
     (7*(1 + F^(-2))*F*S*T*HPL[{1}, -S^2]*Zeta[3])/32 + 
     (7*F^2*(-4/F^2 + S^2 + S^2/F^4)*T^2*HPL[{1}, -S^2]*Zeta[3])/64 + 
     (7*HPL[{2}, -S^2]*Zeta[3])/32 + (HPL[{0}, S^2]*Log[T]*Zeta[3])/4 - 
     (3*Log[T]^2*Zeta[3])/16 - ((1 + F^(-2))*F*S*T*(-1 + 2*Log[T])*Zeta[3])/
      8 + (F^2*T^2*(4*S^2 - 3*S^4 + (4*S^2 - 3*S^4)/F^4 + 
        (6 + 26*S^2 + 6*S^4)/F^2 + 8*(1 + S^2)*(-4/F^2 + S^2 + S^2/F^4)*
         Log[T])*Zeta[3])/(64*(1 + S^2)) - Zeta[5]/64
 
QepwvuT2 = ((1 + F^(-2))*F*Pi^4*S*T)/576 - 
     (F^2*Pi^4*(-4/F^2 + S^2 + S^2/F^4)*T^2)/1152 - 
     (Pi^4*HPL[{0}, S^2])/576 + ((1 + F^(-2))*F*Pi^2*S*T*HPL[{1}, -S^2]^2)/
      48 - (F^2*Pi^2*(-4/F^2 + S^2 + S^2/F^4)*T^2*HPL[{1}, -S^2]^2)/96 - 
     ((1 + F^(-2))^2*F^2*S^2*(1 + 3*S^2)*T^2*HPL[{0}, S^2]*HPL[{1}, -S^2]^2)/
      (64*(1 + S^2)) - ((1 + F^(-2))*F*S*T*HPL[{0}, S^2]*HPL[{1}, -S^2]^3)/
      48 + (F^2*(-4/F^2 + S^2 + S^2/F^4)*T^2*HPL[{0}, S^2]*HPL[{1}, -S^2]^3)/
      96 + ((1 + F^(-2))*F*S*T*HPL[{1}, -S^2]^4)/192 - 
     (F^2*(-4/F^2 + S^2 + S^2/F^4)*T^2*HPL[{1}, -S^2]^4)/384 + 
     ((1 + F^(-2))*F*Pi^2*S*T*HPL[{2}, -S^2])/48 - 
     (F^2*Pi^2*(-4/F^2 + S^2 + S^2/F^4)*T^2*HPL[{2}, -S^2])/96 + 
     ((1 + F^(-2))*F*S*T*HPL[{1}, -S^2]^2*HPL[{2}, -S^2])/8 - 
     (F^2*(-4/F^2 + S^2 + S^2/F^4)*T^2*HPL[{1}, -S^2]^2*HPL[{2}, -S^2])/16 + 
     ((1 + F^(-2))*F*S*T*HPL[{2}, -S^2]^2)/32 - 
     (F^2*(-4/F^2 + S^2 + S^2/F^4)*T^2*HPL[{2}, -S^2]^2)/64 - 
     (Pi^2*HPL[{3}, -S^2])/48 + ((1 + F^(-2))*F*T*HPL[{3}, -S^2])/(16*S) - 
     (F^2*(1 + S^2 - (4*S^2)/F^2 + 2*S^4 + (1 + S^2 + 2*S^4)/F^4)*T^2*
       HPL[{3}, -S^2])/(64*S^2*(1 + S^2)) + 
     ((1 + F^(-2))*F*S*T*HPL[{1}, -S^2]*HPL[{3}, -S^2])/16 - 
     (F^2*(-4/F^2 + S^2 + S^2/F^4)*T^2*HPL[{1}, -S^2]*HPL[{3}, -S^2])/32 - 
     (HPL[{2}, -S^2]*HPL[{3}, -S^2])/16 + ((1 + F^(-2))*F*S*T*HPL[{4}, -S^2])/
      16 - (F^2*(-4/F^2 + S^2 + S^2/F^4)*T^2*HPL[{4}, -S^2])/32 - 
     HPL[{5}, -S^2]/16 - (Pi^2*HPL[{2, 1}, -S^2])/24 + 
     ((1 + F^(-2))*F*S*T*HPL[{0}, S^2]*HPL[{2, 1}, -S^2])/16 - 
     (F^2*(-4/F^2 + S^2 + S^2/F^4)*T^2*HPL[{0}, S^2]*HPL[{2, 1}, -S^2])/32 - 
     (3*(1 + F^(-2))*F*S*T*HPL[{1}, -S^2]*HPL[{2, 1}, -S^2])/16 + 
     (3*F^2*(-4/F^2 + S^2 + S^2/F^4)*T^2*HPL[{1}, -S^2]*HPL[{2, 1}, -S^2])/
      32 - (HPL[{2}, -S^2]*HPL[{2, 1}, -S^2])/4 - 
     ((1 + F^(-2))*F*S*T*HPL[{3, 1}, -S^2])/4 + 
     (F^2*(-4/F^2 + S^2 + S^2/F^4)*T^2*HPL[{3, 1}, -S^2])/8 - 
     (HPL[{0}, S^2]*HPL[{3, 1}, -S^2])/16 + HPL[{3, 2}, -S^2]/16 + 
     (7*HPL[{4, 1}, -S^2])/16 + ((1 + F^(-2))*F*S*T*HPL[{2, 1, 1}, -S^2])/4 - 
     (F^2*(-4/F^2 + S^2 + S^2/F^4)*T^2*HPL[{2, 1, 1}, -S^2])/8 + 
     (HPL[{0}, S^2]*HPL[{2, 1, 1}, -S^2])/8 + (7*HPL[{2, 2, 1}, -S^2])/16 + 
     (15*HPL[{3, 1, 1}, -S^2])/16 - HPL[{2, 1, 1, 1}, -S^2]/8 + 
     (Pi^4*Log[T])/384 + (Pi^2*HPL[{0}, S^2]^2*Log[T])/128 + 
     (11*Pi^2*HPL[{2}, -S^2]*Log[T])/192 + (3*HPL[{2}, -S^2]^2*Log[T])/16 + 
     (HPL[{0}, S^2]*HPL[{3}, -S^2]*Log[T])/8 - (HPL[{4}, -S^2]*Log[T])/8 - 
     (HPL[{3, 1}, -S^2]*Log[T])/4 + (HPL[{2, 1, 1}, -S^2]*Log[T])/2 - 
     (Pi^2*HPL[{0}, S^2]*Log[T]^2)/48 - (HPL[{0}, S^2]*HPL[{2}, -S^2]*
       Log[T]^2)/4 + (HPL[{3}, -S^2]*Log[T]^2)/8 - 
     (5*HPL[{2, 1}, -S^2]*Log[T]^2)/8 + (Pi^2*Log[T]^3)/32 + 
     (3*HPL[{0}, S^2]^2*Log[T]^3)/32 + (3*HPL[{2}, -S^2]*Log[T]^3)/16 - 
     ((1 + F^(-2))*F*S*T*HPL[{0}, S^2]*HPL[{2}, -S^2]*(-1 + 2*Log[T]))/16 - 
     ((1 + F^(-2))*F*Pi^2*S*T*HPL[{0}, S^2]*(-2 + 3*Log[T]))/192 - 
     (3*T^2*HPL[{0}, S^2]^2*(-1 + 4*Log[T]))/128 + 
     ((1 + F^(-2))*F*T*HPL[{2, 1}, -S^2]*(-2 - S^2 + 2*S^2*Log[T]))/(8*S) - 
     ((1 + F^(-2))*F*T*HPL[{1}, -S^2]^3*(-1 - S^2 + 2*S^2*Log[T]))/(24*S) - 
     (3*(1 + F^(-2))*F*T*HPL[{1}, -S^2]*HPL[{2}, -S^2]*
       (-1 - S^2 + 2*S^2*Log[T]))/(16*S) - 
     ((1 + F^(-2))*F*Pi^2*T*HPL[{1}, -S^2]*(-6*(1 + S^2) + 11*S^2*Log[T]))/
      (192*S) - (F^2*T^2*HPL[{0}, S^2]*HPL[{2}, -S^2]*
       (-8/F^2 + 3*S^2 + (3*S^2)/F^4 - 4*(-4/F^2 + S^2 + S^2/F^4)*Log[T]))/
      64 + (F^2*Pi^2*T^2*HPL[{0}, S^2]*(8/F^2 - 3*S^2 - (3*S^2)/F^4 + 
        3*(-4/F^2 + S^2 + S^2/F^4)*Log[T]))/384 - 
     (F^2*Pi^2*T^2*HPL[{1}, -S^2]*(3 + 3*S^2 + 13*S^4 + 5*S^6 - 
        (8*S^2*(3 + 2*S^2 + S^4))/F^2 + (3 + 3*S^2 + 13*S^4 + 5*S^6)/F^4 - 
        11*S^2*(1 + S^2)*(-4/F^2 + S^2 + S^2/F^4)*Log[T]))/
      (384*S^2*(1 + S^2)) - (F^2*T^2*HPL[{1}, -S^2]^3*(2 + 2*S^2 + 11*S^4 + 
        9*S^6 + (2*S^2*(-8 - 3*S^2 + 3*S^4))/F^2 + 
        (2 + 2*S^2 + 11*S^4 + 9*S^6)/F^4 - 8*S^2*(1 + S^2)*
         (-4/F^2 + S^2 + S^2/F^4)*Log[T]))/(192*S^2*(1 + S^2)) + 
     (F^2*T^2*HPL[{2, 1}, -S^2]*(2 + 2*S^2 - (6*S^2)/F^2 + 6*S^4 + 3*S^6 + 
        (2 + 2*S^2 + 6*S^4 + 3*S^6)/F^4 - 4*S^2*(1 + S^2)*
         (-4/F^2 + S^2 + S^2/F^4)*Log[T]))/(32*S^2*(1 + S^2)) + 
     (F^2*T^2*HPL[{1}, -S^2]*HPL[{2}, -S^2]*(-3 - 3*S^2 - 13*S^4 - 5*S^6 + 
        (8*S^2*(3 + 2*S^2 + S^4))/F^2 - (3 + 3*S^2 + 13*S^4 + 5*S^6)/F^4 + 
        12*S^2*(1 + S^2)*(-4/F^2 + S^2 + S^2/F^4)*Log[T]))/
      (64*S^2*(1 + S^2)) + ((1 + F^(-2))*F*Pi^2*S*T*(2 - 2*Log[T] + 
        Log[T]^2))/48 - (3*(1 + F^(-2))*F*S*T*HPL[{0}, S^2]*Log[T]*
       (2 - 2*Log[T] + Log[T]^2))/16 - (3*(1 + F^(-2))*F*T*HPL[{1}, -S^2]*
       Log[T]*(2*(1 + S^2) - 2*(1 + S^2)*Log[T] + S^2*Log[T]^2))/(16*S) + 
     ((1 + F^(-2))*F*T*HPL[{2}, -S^2]*(1 + 2*S^2 - (1 + 2*S^2)*Log[T] + 
        S^2*Log[T]^2))/(8*S) + (3*(1 + F^(-2))^2*F^2*T^2*Log[T]*
       (1 + S^2 - 2*Log[T] - 2*S^2*Log[T] + 2*S^2*Log[T]^2))/(64*(1 + S^2)) + 
     ((1 + F^(-2))*F*T*HPL[{0}, S^2]*HPL[{1}, -S^2]*
       (-1 - S^2 - 2*(1 + S^2)*Log[T] + 4*S^2*Log[T]^2))/(16*S) + 
     ((1 + F^(-2))*F*T*HPL[{1}, -S^2]^2*(1 + S^2 - 4*(1 + S^2)*Log[T] + 
        5*S^2*Log[T]^2))/(16*S) - 
     (F^2*Pi^2*T^2*((1 + S^2)*(3 + 6*S^2 + (3 + 6*S^2)/F^4 - 
          (2*(3 + 8*S^2))/F^2) + (-(S^2*(15 + 4*S^2)) - (S^2*(15 + 4*S^2))/
           F^4 + (25 + 19*S^2 + 16*S^4)/F^2)*Log[T] + 
        4*(1 + S^2)*(-4/F^2 + S^2 + S^2/F^4)*Log[T]^2))/(384*(1 + S^2)) - 
     (F^2*T^2*HPL[{2}, -S^2]*((1 + S^2)*(1 + 5*S^2 + 6*S^4 - 
          (S^2*(15 + 16*S^2))/F^2 + (1 + 5*S^2 + 6*S^4)/F^4) - 
        2*(1 + S^2 + 8*S^4 + 2*S^6 - (2*S^2*(9 + 7*S^2 + 4*S^4))/F^2 + 
          (1 + S^2 + 8*S^4 + 2*S^6)/F^4)*Log[T] + 4*S^2*(1 + S^2)*
         (-4/F^2 + S^2 + S^2/F^4)*Log[T]^2))/(64*S^2*(1 + S^2)) - 
     (F^2*T^2*HPL[{1}, -S^2]^2*((1 + F^(-4))*(1 + S^2)^2*(-1 + 9*S^2) - 
        8*(1 + S^2 + 5*S^4 + 3*S^6 - (4*S^2*(2 + S^2))/F^2 + 
          (1 + S^2 + 5*S^4 + 3*S^6)/F^4)*Log[T] + 20*S^2*(1 + S^2)*
         (-4/F^2 + S^2 + S^2/F^4)*Log[T]^2))/(128*S^2*(1 + S^2)) - 
     (F^2*T^2*HPL[{0}, S^2]*HPL[{1}, -S^2]*
       ((1 + S^2)*((16*S^2)/F^2 + 3*(-1 + S^2) + (3*(-1 + S^2))/F^4) - 
        4*(1 + 5*S^4 + (4*S^2*(-2 + S^2))/F^2 + (1 + 5*S^4)/F^4)*Log[T] + 
        16*((-4*S^2)/F^2 + S^4 + S^4/F^4)*Log[T]^2))/(128*S^2) + 
     (F^2*T^2*HPL[{0}, S^2]*(-((1 + S^2)*(-3 + 12*S^2 + (8*(2 + S^2))/F^2 + 
           (3*(-1 + 4*S^2))/F^4)) + 2*(1 + S^2)*(2 + 15*S^2 - 
          (8*(1 + 2*S^2))/F^2 + (2 + 15*S^2)/F^4)*Log[T] - 
        4*(S^2*(9 + 5*S^2) + (S^2*(9 + 5*S^2))/F^4 - (4*(3 + 3*S^2 + 2*S^4))/
           F^2)*Log[T]^2 + 12*(1 + S^2)*(-4/F^2 + S^2 + S^2/F^4)*Log[T]^3))/
      (128*(1 + S^2)) - (F^2*T^2*HPL[{1}, -S^2]*
       (2*(1 + S^2)^2*(-1 + 3*S^2 + (2*(1 + S^2))/F^2 + (-1 + 3*S^2)/F^4) - 
        (1 + S^2)^2*(1 + 15*S^2 - (16*S^2)/F^2 + (1 + 15*S^2)/F^4)*Log[T] + 
        2*(3 + 3*S^2 + 15*S^4 + 5*S^6 - (4*S^2*(6 + 3*S^2 + 2*S^4))/F^2 + 
          (3 + 3*S^2 + 15*S^4 + 5*S^6)/F^4)*Log[T]^2 - 
        6*S^2*(1 + S^2)*(-4/F^2 + S^2 + S^2/F^4)*Log[T]^3))/
      (64*S^2*(1 + S^2)) + (5*Pi^2*Zeta[3])/768 + 
     (3*(1 + F^(-2))*F*S*T*HPL[{0}, S^2]*Zeta[3])/32 - 
     (3*F^2*(-4/F^2 + S^2 + S^2/F^4)*T^2*HPL[{0}, S^2]*Zeta[3])/64 - 
     (3*HPL[{0}, S^2]^2*Zeta[3])/64 + (3*(1 + F^(-2))*F*S*T*HPL[{1}, -S^2]*
       Zeta[3])/32 - (3*F^2*(-4/F^2 + S^2 + S^2/F^4)*T^2*HPL[{1}, -S^2]*
       Zeta[3])/64 - (3*HPL[{2}, -S^2]*Zeta[3])/32 + 
     (HPL[{0}, S^2]*Log[T]*Zeta[3])/4 + (5*Log[T]^2*Zeta[3])/8 - 
     ((1 + F^(-2))*F*S*T*(-1 + 2*Log[T])*Zeta[3])/8 + 
     (F^2*T^2*(-3*S^2*(3 + 2*S^2) - (3*S^2*(3 + 2*S^2))/F^4 - 
        (2*(7 + 10*S^2))/F^2 + 8*(1 + S^2)*(-4/F^2 + S^2 + S^2/F^4)*Log[T])*
       Zeta[3])/(64*(1 + S^2)) - Zeta[5]/64
 
M1uvwT2 = -((1 + F^(-2))*F*Pi^4*S^3*T)/(10*(1 + S^2)) + 
     (F^2*Pi^4*S^2*(2 + S^2)*(-2/F^2 + S^2 + S^2/F^4)*T^2)/(20*(1 + S^2)^2) + 
     ((1 + F^(-2))^2*F^2*Pi^2*S^6*T^2*HPL[{0}, S^2])/(2*(1 + S^2)^2) - 
     (Pi^4*HPL[{1}, -S^2])/10 + (F^2*Pi^2*(2 + 2*S^2 + S^4 + 3*S^6 + 
        (2*S^2*(-4 - 5*S^2 + S^4))/F^2 + (2 + 2*S^2 + S^4 + 3*S^6)/F^4)*T^2*
       HPL[{1}, -S^2])/(6*(1 + S^2)^2) + 
     ((1 + F^(-2))*F*Pi^2*S^3*T*HPL[{0}, S^2]*HPL[{1}, -S^2])/(1 + S^2) - 
     (F^2*Pi^2*S^2*(2 + S^2)*(-2/F^2 + S^2 + S^2/F^4)*T^2*HPL[{0}, S^2]*
       HPL[{1}, -S^2])/(2*(1 + S^2)^2) + 
     ((1 + F^(-2))*F*Pi^2*S^3*T*HPL[{1}, -S^2]^2)/(3*(1 + S^2)) - 
     (F^2*Pi^2*S^2*(2 + S^2)*(-2/F^2 + S^2 + S^2/F^4)*T^2*HPL[{1}, -S^2]^2)/
      (6*(1 + S^2)^2) + (Pi^2*HPL[{0}, S^2]*HPL[{1}, -S^2]^2)/2 + 
     (F^2*(-2 - 2*S^2 - S^4 + S^6 + (2*S^2*(4 + 5*S^2 + 3*S^4))/F^2 + 
        (-2 - 2*S^2 - S^4 + S^6)/F^4)*T^2*HPL[{0}, S^2]*HPL[{1}, -S^2]^2)/
      (2*(1 + S^2)^2) + (Pi^2*HPL[{1}, -S^2]^3)/9 - 
     (F^2*(2 + 2*S^2 + S^4 - S^6 - (2*S^2*(4 + 5*S^2 + 3*S^4))/F^2 + 
        (2 + 2*S^2 + S^4 - S^6)/F^4)*T^2*HPL[{1}, -S^2]^3)/(6*(1 + S^2)^2) + 
     (2*(1 + F^(-2))*F*S^3*T*HPL[{0}, S^2]*HPL[{1}, -S^2]^3)/(3*(1 + S^2)) - 
     (F^2*S^2*(2 + S^2)*(-2/F^2 + S^2 + S^2/F^4)*T^2*HPL[{0}, S^2]*
       HPL[{1}, -S^2]^3)/(3*(1 + S^2)^2) + 
     ((1 + F^(-2))*F*S^3*T*HPL[{1}, -S^2]^4)/(6*(1 + S^2)) - 
     (F^2*S^2*(2 + S^2)*(-2/F^2 + S^2 + S^2/F^4)*T^2*HPL[{1}, -S^2]^4)/
      (12*(1 + S^2)^2) + (HPL[{0}, S^2]*HPL[{1}, -S^2]^4)/6 + 
     HPL[{1}, -S^2]^5/30 - (2*(1 + F^(-2))*F*Pi^2*S*(-1 + 2*S^2)*T*
       HPL[{2}, -S^2])/(3*(1 + S^2)) - 
     (F^2*Pi^2*S^2*(1 - 4*S^2 - 2*S^4 + (6*(2 + S^2))/F^2 + 
        (1 - 4*S^2 - 2*S^4)/F^4)*T^2*HPL[{2}, -S^2])/(3*(1 + S^2)^2) + 
     ((1 + F^(-2))^2*F^2*S^4*(-2 + S^2)*T^2*HPL[{0}, S^2]*HPL[{2}, -S^2])/
      (1 + S^2)^2 - 2*Pi^2*HPL[{1}, -S^2]*HPL[{2}, -S^2] + 
     (F^2*(2 + S^4 - (2*S^2*(4 + S^2))/F^2 + (2 + S^4)/F^4)*T^2*
       HPL[{1}, -S^2]*HPL[{2}, -S^2])/(1 + S^2) + 
     (2*(1 + F^(-2))*F*S*(-1 + 2*S^2)*T*HPL[{0}, S^2]*HPL[{1}, -S^2]*
       HPL[{2}, -S^2])/(1 + S^2) + 
     (F^2*S^2*(1 - 4*S^2 - 2*S^4 + (6*(2 + S^2))/F^2 + (1 - 4*S^2 - 2*S^4)/
         F^4)*T^2*HPL[{0}, S^2]*HPL[{1}, -S^2]*HPL[{2}, -S^2])/(1 + S^2)^2 + 
     3*HPL[{0}, S^2]*HPL[{1}, -S^2]^2*HPL[{2}, -S^2] - 
     (2*(1 + F^(-2))*F*S*(-1 + S^2)*T*HPL[{2}, -S^2]^2)/(1 + S^2) + 
     (F^2*S^2*(-1 + 2*S^2 + S^4 - (4*(2 + S^2))/F^2 + (-1 + 2*S^2 + S^4)/F^4)*
       T^2*HPL[{2}, -S^2]^2)/(1 + S^2)^2 - 4*HPL[{1}, -S^2]*
      HPL[{2}, -S^2]^2 + (2*(1 + F^(-2))^2*F^2*S^4*T^2*HPL[{3}, -S^2])/
      (1 + S^2)^2 - (2*(1 + F^(-2))*F*S*(-1 + S^2)*T*HPL[{1}, -S^2]*
       HPL[{3}, -S^2])/(1 + S^2) + 
     (F^2*S^2*(-1 + 2*S^2 + S^4 - (4*(2 + S^2))/F^2 + (-1 + 2*S^2 + S^4)/F^4)*
       T^2*HPL[{1}, -S^2]*HPL[{3}, -S^2])/(1 + S^2)^2 - 
     2*HPL[{1}, -S^2]^2*HPL[{3}, -S^2] + 3*Pi^2*HPL[{2, 1}, -S^2] - 
     (F^2*(2 + 2*S^2 + 5*S^4 + 2*S^6 - (2*S^2*(4 + S^2))/F^2 + 
        (2 + 2*S^2 + 5*S^4 + 2*S^6)/F^4)*T^2*HPL[{2, 1}, -S^2])/(1 + S^2)^2 - 
     (6*(1 + F^(-2))*F*S^3*T*HPL[{0}, S^2]*HPL[{2, 1}, -S^2])/(1 + S^2) + 
     (3*F^2*S^2*(2 + S^2)*(-2/F^2 + S^2 + S^2/F^4)*T^2*HPL[{0}, S^2]*
       HPL[{2, 1}, -S^2])/(1 + S^2)^2 + (2*(1 + F^(-2))*F*S*(-2 + S^2)*T*
       HPL[{1}, -S^2]*HPL[{2, 1}, -S^2])/(1 + S^2) - 
     (F^2*S^2*(-2 + 2*S^2 + S^4 - (6*(2 + S^2))/F^2 + (-2 + 2*S^2 + S^4)/F^4)*
       T^2*HPL[{1}, -S^2]*HPL[{2, 1}, -S^2])/(1 + S^2)^2 - 
     6*HPL[{0}, S^2]*HPL[{1}, -S^2]*HPL[{2, 1}, -S^2] + 
     3*HPL[{1}, -S^2]^2*HPL[{2, 1}, -S^2] + 14*HPL[{2}, -S^2]*
      HPL[{2, 1}, -S^2] + (4*(1 + F^(-2))*F*S*(-1 + 2*S^2)*T*
       HPL[{3, 1}, -S^2])/(1 + S^2) + 
     (2*F^2*S^2*(1 - 4*S^2 - 2*S^4 + (6*(2 + S^2))/F^2 + 
        (1 - 4*S^2 - 2*S^4)/F^4)*T^2*HPL[{3, 1}, -S^2])/(1 + S^2)^2 + 
     12*HPL[{1}, -S^2]*HPL[{3, 1}, -S^2] - 
     (8*(1 + F^(-2))*F*S*(-1 + S^2)*T*HPL[{2, 1, 1}, -S^2])/(1 + S^2) + 
     (4*F^2*S^2*(-1 + 2*S^2 + S^4 - (4*(2 + S^2))/F^2 + 
        (-1 + 2*S^2 + S^4)/F^4)*T^2*HPL[{2, 1, 1}, -S^2])/(1 + S^2)^2 - 
     16*HPL[{1}, -S^2]*HPL[{2, 1, 1}, -S^2] - 20*HPL[{2, 2, 1}, -S^2] - 
     60*HPL[{3, 1, 1}, -S^2] + 24*HPL[{2, 1, 1, 1}, -S^2] + 
     (F^2*Pi^2*S^2*T^2*(1 + F^(-4) - 4/F^2 + (4*Log[T])/F^2))/3 - 
     F^2*S^2*T^2*HPL[{0}, S^2]*HPL[{1}, -S^2]*(1 + F^(-4) - 4/F^2 + 
       (4*Log[T])/F^2) + 2*F^2*S^2*T^2*HPL[{2}, -S^2]*
      (1 + F^(-4) - 4/F^2 + (4*Log[T])/F^2) - (Pi^2*Zeta[3])/3 + 
     (F^2*S^2*((-2*(2 + S^2))/F^2 + S^2*(3 + 2*S^2) + (S^2*(3 + 2*S^2))/F^4)*
       T^2*Zeta[3])/(1 + S^2)^2 + (2*(1 + F^(-2))*F*S^3*T*HPL[{0}, S^2]*
       Zeta[3])/(1 + S^2) - (F^2*S^2*(2 + S^2)*(-2/F^2 + S^2 + S^2/F^4)*T^2*
       HPL[{0}, S^2]*Zeta[3])/(1 + S^2)^2 + 
     (2*(1 + F^(-2))*F*S*(2 + S^2)*T*HPL[{1}, -S^2]*Zeta[3])/(1 + S^2) - 
     (F^2*S^2*(2 + 2*S^2 + S^4 + (2*(2 + S^2))/F^2 + (2 + 2*S^2 + S^4)/F^4)*
       T^2*HPL[{1}, -S^2]*Zeta[3])/(1 + S^2)^2 + 
     2*HPL[{0}, S^2]*HPL[{1}, -S^2]*Zeta[3] - HPL[{1}, -S^2]^2*Zeta[3] - 
     2*HPL[{2}, -S^2]*Zeta[3] + 2*Zeta[5]
 
M1uwvT2 = -((1 + F^(-2))*F*Pi^4*S^3*T)/(18*(1 + S^2)) + 
     (F^2*Pi^4*S^2*(2 + S^2)*(-2/F^2 + S^2 + S^2/F^4)*T^2)/(36*(1 + S^2)^2) + 
     ((1 + F^(-2))^2*F^2*Pi^2*S^6*T^2*HPL[{0}, S^2])/(6*(1 + S^2)^2) - 
     (Pi^4*HPL[{1}, -S^2])/18 + ((1 + F^(-2))*F*Pi^2*S^3*T*HPL[{0}, S^2]*
       HPL[{1}, -S^2])/(3*(1 + S^2)) - 
     (F^2*Pi^2*S^2*(2 + S^2)*(-2/F^2 + S^2 + S^2/F^4)*T^2*HPL[{0}, S^2]*
       HPL[{1}, -S^2])/(6*(1 + S^2)^2) + (2*(1 + F^(-2))*F*Pi^2*(1 + S^4)*T*
       HPL[{1}, -S^2]^2)/(3*S*(1 + S^2)) - 
     (F^2*Pi^2*(1 + 2*S^2 + 2*S^6 + S^8 - (4*S^4*(2 + S^2))/F^2 + 
        (1 + 2*S^2 + 2*S^6 + S^8)/F^4)*T^2*HPL[{1}, -S^2]^2)/
      (3*S^2*(1 + S^2)^2) + (Pi^2*HPL[{0}, S^2]*HPL[{1}, -S^2]^2)/6 + 
     (4*Pi^2*HPL[{1}, -S^2]^3)/9 - (2*(1 + F^(-2))*F*(3 + 4*S^4)*T*
       HPL[{0}, S^2]*HPL[{1}, -S^2]^3)/(3*S*(1 + S^2)) + 
     (F^2*(3 + 6*S^2 + 8*S^6 + 4*S^8 - (14*S^4*(2 + S^2))/F^2 + 
        (3 + 6*S^2 + 8*S^6 + 4*S^8)/F^4)*T^2*HPL[{0}, S^2]*HPL[{1}, -S^2]^3)/
      (3*S^2*(1 + S^2)^2) - ((1 + F^(-2))*F*(4 + 7*S^4)*T*HPL[{1}, -S^2]^4)/
      (6*S*(1 + S^2)) + (F^2*(4 + 8*S^2 + 14*S^6 + 7*S^8 - 
        (22*S^4*(2 + S^2))/F^2 + (4 + 8*S^2 + 14*S^6 + 7*S^8)/F^4)*T^2*
       HPL[{1}, -S^2]^4)/(12*S^2*(1 + S^2)^2) - 
     (7*HPL[{0}, S^2]*HPL[{1}, -S^2]^4)/6 - (11*HPL[{1}, -S^2]^5)/30 + 
     (2*(1 + F^(-2))*F*Pi^2*T*HPL[{2}, -S^2])/(3*(S + S^3)) - 
     (F^2*Pi^2*(1 + 2*S^2 - (2*S^4*(2 + S^2))/F^2 + (1 + 2*S^2)/F^4)*T^2*
       HPL[{2}, -S^2])/(3*S^2*(1 + S^2)^2) + 
     (2*Pi^2*HPL[{1}, -S^2]*HPL[{2}, -S^2])/3 - 
     (2*(1 + F^(-2))*F*(1 + 2*S^4)*T*HPL[{0}, S^2]*HPL[{1}, -S^2]*
       HPL[{2}, -S^2])/(S*(1 + S^2)) + 
     (F^2*(1 + 2*S^2 + 4*S^6 + 2*S^8 - (6*S^4*(2 + S^2))/F^2 + 
        (1 + 2*S^2 + 4*S^6 + 2*S^8)/F^4)*T^2*HPL[{0}, S^2]*HPL[{1}, -S^2]*
       HPL[{2}, -S^2])/(S^2*(1 + S^2)^2) + 
     (2*(1 + F^(-2))*F*(2 + S^4)*T*HPL[{1}, -S^2]^2*HPL[{2}, -S^2])/
      (S*(1 + S^2)) - (F^2*(2 + 4*S^2 + 2*S^6 + S^8 - (6*S^4*(2 + S^2))/F^2 + 
        (2 + 4*S^2 + 2*S^6 + S^8)/F^4)*T^2*HPL[{1}, -S^2]^2*HPL[{2}, -S^2])/
      (S^2*(1 + S^2)^2) - 3*HPL[{0}, S^2]*HPL[{1}, -S^2]^2*HPL[{2}, -S^2] + 
     2*HPL[{1}, -S^2]^3*HPL[{2}, -S^2] + (2*(1 + F^(-2))*F*(1 + S^4)*T*
       HPL[{2}, -S^2]^2)/(S*(1 + S^2)) - 
     (F^2*(1 + 2*S^2 + 2*S^6 + S^8 - (4*S^4*(2 + S^2))/F^2 + 
        (1 + 2*S^2 + 2*S^6 + S^8)/F^4)*T^2*HPL[{2}, -S^2]^2)/
      (S^2*(1 + S^2)^2) + 4*HPL[{1}, -S^2]*HPL[{2}, -S^2]^2 + 
     (2*Pi^2*HPL[{3}, -S^2])/3 - (2*(1 + F^(-2))*F*S^3*T*HPL[{0}, S^2]*
       HPL[{3}, -S^2])/(1 + S^2) + 
     (F^2*S^2*(2 + S^2)*(-2/F^2 + S^2 + S^2/F^4)*T^2*HPL[{0}, S^2]*
       HPL[{3}, -S^2])/(1 + S^2)^2 + (2*(1 + F^(-2))*F*(1 + S^4)*T*
       HPL[{1}, -S^2]*HPL[{3}, -S^2])/(S*(1 + S^2)) - 
     (F^2*(1 + 2*S^2 + 2*S^6 + S^8 - (4*S^4*(2 + S^2))/F^2 + 
        (1 + 2*S^2 + 2*S^6 + S^8)/F^4)*T^2*HPL[{1}, -S^2]*HPL[{3}, -S^2])/
      (S^2*(1 + S^2)^2) - 2*HPL[{0}, S^2]*HPL[{1}, -S^2]*HPL[{3}, -S^2] + 
     2*HPL[{1}, -S^2]^2*HPL[{3}, -S^2] + 
     (4*(1 + F^(-2))*F*S^3*T*HPL[{4}, -S^2])/(1 + S^2) - 
     (2*F^2*S^2*(2 + S^2)*(-2/F^2 + S^2 + S^2/F^4)*T^2*HPL[{4}, -S^2])/
      (1 + S^2)^2 + 4*HPL[{1}, -S^2]*HPL[{4}, -S^2] - 
     (Pi^2*HPL[{2, 1}, -S^2])/3 + (2*(1 + F^(-2))*F*S^3*T*HPL[{0}, S^2]*
       HPL[{2, 1}, -S^2])/(1 + S^2) - 
     (F^2*S^2*(2 + S^2)*(-2/F^2 + S^2 + S^2/F^4)*T^2*HPL[{0}, S^2]*
       HPL[{2, 1}, -S^2])/(1 + S^2)^2 - (2*(1 + F^(-2))*F*(4 + S^4)*T*
       HPL[{1}, -S^2]*HPL[{2, 1}, -S^2])/(S*(1 + S^2)) + 
     (F^2*(4 + 8*S^2 + 2*S^6 + S^8 - (10*S^4*(2 + S^2))/F^2 + 
        (4 + 8*S^2 + 2*S^6 + S^8)/F^4)*T^2*HPL[{1}, -S^2]*HPL[{2, 1}, -S^2])/
      (S^2*(1 + S^2)^2) + 2*HPL[{0}, S^2]*HPL[{1}, -S^2]*HPL[{2, 1}, -S^2] - 
     5*HPL[{1}, -S^2]^2*HPL[{2, 1}, -S^2] - 6*HPL[{2}, -S^2]*
      HPL[{2, 1}, -S^2] - (4*(1 + F^(-2))*F*(1 + S^4)*T*HPL[{3, 1}, -S^2])/
      (S*(1 + S^2)) + (2*F^2*(1 + 2*S^2 + 2*S^6 + S^8 - 
        (4*S^4*(2 + S^2))/F^2 + (1 + 2*S^2 + 2*S^6 + S^8)/F^4)*T^2*
       HPL[{3, 1}, -S^2])/(S^2*(1 + S^2)^2) - 8*HPL[{1}, -S^2]*
      HPL[{3, 1}, -S^2] + 4*HPL[{3, 2}, -S^2] + 4*HPL[{4, 1}, -S^2] + 
     (8*(1 + F^(-2))*F*T*HPL[{2, 1, 1}, -S^2])/(S + S^3) - 
     (4*F^2*(1 + 2*S^2 - (2*S^4*(2 + S^2))/F^2 + (1 + 2*S^2)/F^4)*T^2*
       HPL[{2, 1, 1}, -S^2])/(S^2*(1 + S^2)^2) + 8*HPL[{1}, -S^2]*
      HPL[{2, 1, 1}, -S^2] + 4*HPL[{2, 2, 1}, -S^2] + 
     20*HPL[{3, 1, 1}, -S^2] - 8*HPL[{2, 1, 1, 1}, -S^2] - 
     (4*Pi^2*HPL[{1}, -S^2]^2*Log[T])/3 + 4*HPL[{0}, S^2]*HPL[{1}, -S^2]^3*
      Log[T] + (4*HPL[{1}, -S^2]^4*Log[T])/3 - (4*Pi^2*HPL[{2}, -S^2]*Log[T])/
      3 + (4*(1 + F^(-2))*F*S^3*T*HPL[{0}, S^2]*HPL[{2}, -S^2]*Log[T])/
      (1 + S^2) + 4*HPL[{0}, S^2]*HPL[{1}, -S^2]*HPL[{2}, -S^2]*Log[T] - 
     8*HPL[{1}, -S^2]^2*HPL[{2}, -S^2]*Log[T] - 4*HPL[{2}, -S^2]^2*Log[T] - 
     (4*(1 + F^(-2))*F*S^3*T*HPL[{3}, -S^2]*Log[T])/(1 + S^2) - 
     4*HPL[{1}, -S^2]*HPL[{3}, -S^2]*Log[T] + 16*HPL[{1}, -S^2]*
      HPL[{2, 1}, -S^2]*Log[T] + 8*HPL[{3, 1}, -S^2]*Log[T] - 
     16*HPL[{2, 1, 1}, -S^2]*Log[T] + (4*Pi^2*HPL[{1}, -S^2]*Log[T]^2)/3 - 
     (4*(1 + F^(-2))*F*S^3*T*HPL[{1}, -S^2]^2*Log[T]^2)/(1 + S^2) - 
     4*HPL[{0}, S^2]*HPL[{1}, -S^2]^2*Log[T]^2 - 
     (4*HPL[{1}, -S^2]^3*Log[T]^2)/3 + 8*HPL[{1}, -S^2]*HPL[{2}, -S^2]*
      Log[T]^2 - 8*HPL[{2, 1}, -S^2]*Log[T]^2 + 
     (2*F^2*S^2*T^2*HPL[{3}, -S^2]*((1 + F^(-2))^2 + 
        (2 + S^2)*(-2/F^2 + S^2 + S^2/F^4)*Log[T]))/(1 + S^2)^2 - 
     (F^2*S^2*T^2*HPL[{0}, S^2]*HPL[{2}, -S^2]*((1 + F^(-2))^2*(2 + S^4) + 
        2*(2 + S^2)*(-2/F^2 + S^2 + S^2/F^4)*Log[T]))/(1 + S^2)^2 - 
     (2*(1 + F^(-2))*F*Pi^2*T*HPL[{1}, -S^2]*(-(1 + S^2)^2 + 
        2*(1 + S^4)*Log[T]))/(3*S*(1 + S^2)) - 
     (4*(1 + F^(-2))*F*T*HPL[{1}, -S^2]*HPL[{2}, -S^2]*
       (-(1 + S^2)^2 + 2*(1 + S^4)*Log[T]))/(S*(1 + S^2)) + 
     (4*(1 + F^(-2))*F*T*HPL[{2, 1}, -S^2]*(-(1 + S^2)^2 + 
        2*(1 + S^4)*Log[T]))/(S*(1 + S^2)) + 
     (2*(1 + F^(-2))*F*T*HPL[{0}, S^2]*HPL[{1}, -S^2]^2*
       (-(1 + S^2)^2 + (2 + 4*S^4)*Log[T]))/(S*(1 + S^2)) + 
     (2*(1 + F^(-2))*F*T*HPL[{1}, -S^2]^3*(-(1 + S^2)^2 + 
        (2 + 6*S^4)*Log[T]))/(3*S*(1 + S^2)) - 
     (F^2*Pi^2*T^2*HPL[{1}, -S^2]*(1 + 8*S^2 + 6*S^4 + 7*S^6 + 
        (1 + 8*S^2 + 6*S^4 + 7*S^6)/F^4 - 
        (2*(2 + 4*S^2 + 12*S^4 + 5*S^6 + 3*S^8))/F^2 - 
        4*(1 + 2*S^2 + 2*S^6 + S^8 - (4*S^4*(2 + S^2))/F^2 + 
          (1 + 2*S^2 + 2*S^6 + S^8)/F^4)*Log[T]))/(6*S^2*(1 + S^2)^2) + 
     (F^2*T^2*HPL[{2, 1}, -S^2]*(1 + 8*S^2 + 6*S^4 + 7*S^6 + 3*S^8 - 
        (2*(2 + 4*S^2 + 12*S^4 + 5*S^6))/F^2 + 
        (1 + 8*S^2 + 6*S^4 + 7*S^6 + 3*S^8)/F^4 - 
        4*(1 + 2*S^2 + 2*S^6 + S^8 - (4*S^4*(2 + S^2))/F^2 + 
          (1 + 2*S^2 + 2*S^6 + S^8)/F^4)*Log[T]))/(S^2*(1 + S^2)^2) + 
     (F^2*T^2*HPL[{1}, -S^2]*HPL[{2}, -S^2]*(-1 - 8*S^2 - 6*S^4 - 7*S^6 - 
        2*S^8 + (2*(2 + 4*S^2 + 12*S^4 + 5*S^6 + S^8))/F^2 - 
        (1 + 8*S^2 + 6*S^4 + 7*S^6 + 2*S^8)/F^4 + 
        4*(1 + 2*S^2 + 2*S^6 + S^8 - (4*S^4*(2 + S^2))/F^2 + 
          (1 + 2*S^2 + 2*S^6 + S^8)/F^4)*Log[T]))/(S^2*(1 + S^2)^2) - 
     (F^2*T^2*HPL[{0}, S^2]*HPL[{1}, -S^2]^2*(-1 - 8*S^2 - 2*S^4 - 7*S^6 + 
        2*S^8 + (-1 - 8*S^2 - 2*S^4 - 7*S^6 + 2*S^8)/F^4 + 
        (2*(2 + 4*S^2 + 16*S^4 + 5*S^6 + 5*S^8))/F^2 + 
        4*(1 + 2*S^2 + 4*S^6 + 2*S^8 - (6*S^4*(2 + S^2))/F^2 + 
          (1 + 2*S^2 + 4*S^6 + 2*S^8)/F^4)*Log[T]))/(2*S^2*(1 + S^2)^2) - 
     (F^2*T^2*HPL[{1}, -S^2]^3*(-1 - 8*S^2 + 2*S^4 - 7*S^6 + 6*S^8 + 
        (-1 - 8*S^2 + 2*S^4 - 7*S^6 + 6*S^8)/F^4 + 
        (2*(2 + 4*S^2 + 20*S^4 + 5*S^6 + 9*S^8))/F^2 + 
        4*(1 + 2*S^2 + 6*S^6 + 3*S^8 - (8*S^4*(2 + S^2))/F^2 + 
          (1 + 2*S^2 + 6*S^6 + 3*S^8)/F^4)*Log[T]))/(6*S^2*(1 + S^2)^2) + 
     (4*(1 + F^(-2))*F*Pi^2*S*T*(1 + S^2 - (1 + S^2)*Log[T] + S^2*Log[T]^2))/
      (3*(1 + S^2)) - (4*(1 + F^(-2))^2*F^2*S^4*T^2*HPL[{0}, S^2]*
       (1 + S^2 - (1 + S^2)*Log[T] + S^2*Log[T]^2))/(1 + S^2)^2 + 
     (8*(1 + F^(-2))*F*S*T*HPL[{2}, -S^2]*(1 + S^2 - (1 + S^2)*Log[T] + 
        S^2*Log[T]^2))/(1 + S^2) - (4*(1 + F^(-2))*F*S*T*HPL[{0}, S^2]*
       HPL[{1}, -S^2]*(1 + S^2 - (1 + S^2)*Log[T] + 2*S^2*Log[T]^2))/
      (1 + S^2) - (F^2*T^2*HPL[{1}, -S^2]*
       ((1 + S^2)^2*(-1 + 8*S^2 + (8*(-1 + 2*S^2))/F^2 + (-1 + 8*S^2)/F^4) - 
        2*(1 + S^2)^2*(-1 + 4*S^2 + (-1 + 4*S^2)/F^4 + (-4 + 8*S^2)/F^2)*
         Log[T] + 8*(1 + F^(-2))^2*S^6*Log[T]^2))/(2*(1 + S^2)^2) + 
     (2*F^2*S^2*T^2*HPL[{1}, -S^2]^2*(-((1 + F^(-2))^2*(1 + S^2)^2) + 
        2*(1 + F^(-2))^2*(1 + S^4)*Log[T] + (2 + S^2)*(-2/F^2 + S^2 + 
          S^2/F^4)*Log[T]^2))/(1 + S^2)^2 - 
     (F^2*Pi^2*T^2*((1 + S^2)^2*(3*(1 + S^2) + (3*(1 + S^2))/F^4 - 
          (4*(1 + 2*S^2))/F^2) - 2*(2 + 3*S^2 + 6*S^4 + S^6 - 
          (4*S^2*(2 + S^2 + S^4))/F^2 + (2 + 3*S^2 + 6*S^4 + S^6)/F^4)*
         Log[T] + 4*S^2*(2 + S^2)*(-2/F^2 + S^2 + S^2/F^4)*Log[T]^2))/
      (6*(1 + S^2)^2) - (F^2*T^2*HPL[{2}, -S^2]*
       ((1 + S^2)^2*(3*(1 + S^2) + (3*(1 + S^2))/F^4 - (4*(1 + 2*S^2))/F^2) - 
        2*(2 + 3*S^2 + 6*S^4 + S^6 - (4*S^2*(2 + S^2 + S^4))/F^2 + 
          (2 + 3*S^2 + 6*S^4 + S^6)/F^4)*Log[T] + 4*S^2*(2 + S^2)*
         (-2/F^2 + S^2 + S^2/F^4)*Log[T]^2))/(1 + S^2)^2 + 
     (F^2*T^2*HPL[{0}, S^2]*HPL[{1}, -S^2]*
       (-((1 + S^2)^2*(-3 + S^2 + (-3 + S^2)/F^4 + (4*(1 + 4*S^2))/F^2)) + 
        2*(-2 + S^2 - 6*S^4 + 3*S^6 + (4*S^2*(4 + S^2 + 3*S^4))/F^2 + 
          (-2 + S^2 - 6*S^4 + 3*S^6)/F^4)*Log[T] + 8*S^2*(2 + S^2)*
         (-2/F^2 + S^2 + S^2/F^4)*Log[T]^2))/(2*(1 + S^2)^2) - 
     (Pi^2*Zeta[3])/3 + (2*(1 + F^(-2))*F*S^3*T*HPL[{0}, S^2]*Zeta[3])/
      (1 + S^2) - (F^2*S^2*(2 + S^2)*(-2/F^2 + S^2 + S^2/F^4)*T^2*
       HPL[{0}, S^2]*Zeta[3])/(1 + S^2)^2 + 
     (2*(1 + F^(-2))*F*(2 + S^4)*T*HPL[{1}, -S^2]*Zeta[3])/(S*(1 + S^2)) - 
     (F^2*(2 + 4*S^2 + 2*S^6 + S^8 - (6*S^4*(2 + S^2))/F^2 + 
        (2 + 4*S^2 + 2*S^6 + S^8)/F^4)*T^2*HPL[{1}, -S^2]*Zeta[3])/
      (S^2*(1 + S^2)^2) + 2*HPL[{0}, S^2]*HPL[{1}, -S^2]*Zeta[3] + 
     3*HPL[{1}, -S^2]^2*Zeta[3] + 2*HPL[{2}, -S^2]*Zeta[3] - 
     8*HPL[{1}, -S^2]*Log[T]*Zeta[3] - 
     (4*(1 + F^(-2))*F*S*T*(-1 - S^2 + 2*S^2*Log[T])*Zeta[3])/(1 + S^2) + 
     (F^2*T^2*(-2 - 3*S^2 - 7*S^4 - 3*S^6 + (2*S^2*(4 + S^2))/F^2 - 
        (2 + 3*S^2 + 7*S^4 + 3*S^6)/F^4 + 4*S^2*(2 + S^2)*
         (-2/F^2 + S^2 + S^2/F^4)*Log[T])*Zeta[3])/(1 + S^2)^2 + 2*Zeta[5]
 
M1vwuT2 = (Pi^4*T^2)/18 + (2*Pi^2*T^2*HPL[{0}, S^2])/3 - 
     (Pi^2*T^2*HPL[{0}, S^2]^2)/3 + (2*Pi^2*(1 + S^2)*T^2*HPL[{1}, -S^2])/
      (3*S^2) + (2*(1 + S^2)*T^2*HPL[{0}, S^2]*HPL[{1}, -S^2]^2)/S^2 + 
     (4*(1 + S^2)*T^2*HPL[{1}, -S^2]^3)/(3*S^2) - (2*Pi^2*T^2*HPL[{2}, -S^2])/
      3 + 4*T^2*HPL[{0}, S^2]*HPL[{2}, -S^2] - 4*T^2*HPL[{3}, -S^2] - 
     4*T^2*HPL[{0}, S^2]*HPL[{3}, -S^2] + 8*T^2*HPL[{4}, -S^2] + 
     (4*(-1 + S^2)*T^2*HPL[{2, 1}, -S^2])/S^2 - 4*T^2*HPL[{0}, S^2]*
      HPL[{2, 1}, -S^2] - 8*T^2*HPL[{2, 1, 1}, -S^2] - (Pi^2*Zeta[3])/3 + 
     4*T^2*HPL[{0}, S^2]*Zeta[3] - 2*T^2*(1 + 2*Log[T])*Zeta[3] + 2*Zeta[5]
 
M1vuwT2 = (Pi^4*T^2)/10 + (2*Pi^2*S^2*T^2*HPL[{0}, S^2])/3 + 
     (2*Pi^2*(1 + S^2)*T^2*HPL[{1}, -S^2])/3 + 2*(1 + S^2)*T^2*HPL[{0}, S^2]*
      HPL[{1}, -S^2]^2 + (4*(1 + S^2)*T^2*HPL[{1}, -S^2]^3)/3 + 
     (2*Pi^2*T^2*HPL[{2}, -S^2])/3 + 4*S^2*T^2*HPL[{0}, S^2]*HPL[{2}, -S^2] - 
     4*S^2*T^2*HPL[{3}, -S^2] + 4*(-1 + S^2)*T^2*HPL[{2, 1}, -S^2] + 
     4*T^2*HPL[{0}, S^2]*HPL[{2, 1}, -S^2] - 8*T^2*HPL[{3, 1}, -S^2] + 
     8*T^2*HPL[{2, 1, 1}, -S^2] - (Pi^2*Zeta[3])/3 - 
     2*T^2*(-1 + 2*S^2 + 2*Log[T])*Zeta[3] + 2*Zeta[5]
 
M1wuvT2 = -(Pi^4*HPL[{1}, -S^2])/15 + ((1 + F^(-2))^2*F^2*Pi^2*T^2*
       HPL[{1}, -S^2])/(3*S^2*(1 + S^2)^2) - 
     (F^2*Pi^2*T*((-2*(S + S^3))/F^3 - (2*(S + S^3))/F + T + 2*S^2*T + 
        (2*S^2*T)/F^2 + (T + 2*S^2*T)/F^4)*HPL[{1}, -S^2]^2)/
      (6*S^2*(1 + S^2)^2) + (Pi^2*HPL[{1}, -S^2]^3)/9 - 
     (2*HPL[{0}, S^2]*HPL[{1}, -S^2]^4)/3 - (11*HPL[{1}, -S^2]^5)/30 - 
     (F^2*Pi^2*T*((-2*(S + S^3))/F^3 - (2*(S + S^3))/F + T + 2*S^2*T + 
        (2*S^2*T)/F^2 + (T + 2*S^2*T)/F^4)*HPL[{2}, -S^2])/
      (3*S^2*(1 + S^2)^2) + (2*Pi^2*HPL[{1}, -S^2]*HPL[{2}, -S^2])/3 - 
     4*HPL[{0}, S^2]*HPL[{1}, -S^2]^2*HPL[{2}, -S^2] - 
     2*HPL[{1}, -S^2]^3*HPL[{2}, -S^2] + 4*HPL[{1}, -S^2]*HPL[{2}, -S^2]^2 + 
     (2*Pi^2*HPL[{3}, -S^2])/3 - 6*HPL[{0}, S^2]*HPL[{1}, -S^2]*
      HPL[{3}, -S^2] - 3*HPL[{1}, -S^2]^2*HPL[{3}, -S^2] + 
     2*HPL[{2}, -S^2]*HPL[{3}, -S^2] - 
     (2*F^2*T*((-2*(S + S^3))/F^3 - (2*(S + S^3))/F + T + 2*S^2*T + 
        (2*S^2*T)/F^2 + (T + 2*S^2*T)/F^4)*HPL[{4}, -S^2])/
      (S^2*(1 + S^2)^2) - 4*HPL[{0}, S^2]*HPL[{4}, -S^2] + 
     4*HPL[{1}, -S^2]*HPL[{4}, -S^2] + 8*HPL[{5}, -S^2] - 
     (2*Pi^2*HPL[{2, 1}, -S^2])/3 - 
     (2*F^2*T*((-2*(S + S^3))/F^3 - (2*(S + S^3))/F + T + 2*S^2*T + 
        (2*S^2*T)/F^2 + (T + 2*S^2*T)/F^4)*HPL[{0}, S^2]*HPL[{2, 1}, -S^2])/
      (S^2*(1 + S^2)^2) + 4*HPL[{0}, S^2]*HPL[{1}, -S^2]*HPL[{2, 1}, -S^2] + 
     5*HPL[{1}, -S^2]^2*HPL[{2, 1}, -S^2] - 6*HPL[{2}, -S^2]*
      HPL[{2, 1}, -S^2] + 4*HPL[{0}, S^2]*HPL[{3, 1}, -S^2] - 
     8*HPL[{4, 1}, -S^2] - 8*HPL[{1}, -S^2]*HPL[{2, 1, 1}, -S^2] + 
     4*HPL[{2, 2, 1}, -S^2] + 12*HPL[{3, 1, 1}, -S^2] + 
     8*HPL[{2, 1, 1, 1}, -S^2] + (2*F^2*HPL[{3, 1}, -S^2]*
       (T*((2*S*(-1 + S^2))/F^3 + (2*S*(-1 + S^2))/F + T + (4*S^2*T)/F^2 - 
          S^4*T + (T - S^4*T)/F^4) - (4*S^2*Log[T])/F^2))/S^2 + 
     (F^2*Pi^4*(T*((-2*(S^3 + S^5))/F^3 - (2*(S^3 + S^5))/F + 
          S^4*(2 + S^2)*T + (S^4*(2 + S^2)*T)/F^4 - (2*(1 + 4*S^2 + 2*S^4)*T)/
           F^2) + (4*(1 + S^2)^2*Log[T])/F^2))/(30*(1 + S^2)^2) + 
     (3*F^2*HPL[{1}, -S^2]*HPL[{3}, -S^2]*
       (T*((-2*(S^3 + S^5))/F^3 - (2*(S^3 + S^5))/F + S^4*(2 + S^2)*T + 
          (S^4*(2 + S^2)*T)/F^4 - (2*(1 + 4*S^2 + 2*S^4)*T)/F^2) + 
        (4*(1 + S^2)^2*Log[T])/F^2))/(1 + S^2)^2 + 
     (4*F^2*HPL[{2, 1, 1}, -S^2]*(T*((-2*(S^3 + S^5))/F^3 - 
          (2*(S^3 + S^5))/F + S^4*(2 + S^2)*T + (S^4*(2 + S^2)*T)/F^4 - 
          (2*(1 + 4*S^2 + 2*S^4)*T)/F^2) + (4*(1 + S^2)^2*Log[T])/F^2))/
      (1 + S^2)^2 - (F^2*HPL[{1}, -S^2]^2*HPL[{2}, -S^2]*
       (T*((2*(S + S^3 + 2*S^5 + 2*S^7))/F^3 + (2*(S + S^3 + 2*S^5 + 2*S^7))/
           F + (2*S^2*(1 + 8*S^2 + 4*S^4)*T)/F^2 - 
          (1 + 2*S^2 + 4*S^6 + 2*S^8)*T - ((1 + 2*S^2 + 4*S^6 + 2*S^8)*T)/
           F^4) - (8*S^2*(1 + S^2)^2*Log[T])/F^2))/(S^2*(1 + S^2)^2) - 
     (F^2*HPL[{0}, S^2]*HPL[{3}, -S^2]*
       (T*((2*S*(2 + 2*S^2 + S^4 + S^6))/F^3 + (2*S*(2 + 2*S^2 + S^4 + S^6))/
           F + (2*S^2*(-1 + 4*S^2 + 2*S^4)*T)/F^2 - (2 + 4*S^2 + 2*S^6 + S^8)*
           T - ((2 + 4*S^2 + 2*S^6 + S^8)*T)/F^4) - 
        (4*S^2*(1 + S^2)^2*Log[T])/F^2))/(S^2*(1 + S^2)^2) - 
     (F^2*HPL[{0}, S^2]*HPL[{1}, -S^2]^3*
       (T*((2*S*(3 + 3*S^2 + S^4 + S^6))/F^3 + (2*S*(3 + 3*S^2 + S^4 + S^6))/
           F + (4*S^2*(-1 + 2*S^2 + S^4)*T)/F^2 - (3 + 6*S^2 + 2*S^6 + S^8)*
           T - ((3 + 6*S^2 + 2*S^6 + S^8)*T)/F^4) - 
        (4*S^2*(1 + S^2)^2*Log[T])/F^2))/(3*S^2*(1 + S^2)^2) - 
     (F^2*HPL[{2}, -S^2]^2*(T*((-2*(S + S^3 + S^5 + S^7))/F^3 - 
          (2*(S + S^3 + S^5 + S^7))/F - (4*S^4*(2 + S^2)*T)/F^2 + 
          (1 + 2*S^2 + 2*S^6 + S^8)*T + ((1 + 2*S^2 + 2*S^6 + S^8)*T)/F^4) + 
        (4*S^2*(1 + S^2)^2*Log[T])/F^2))/(S^2*(1 + S^2)^2) + 
     (F^2*HPL[{0}, S^2]*HPL[{1}, -S^2]*HPL[{2}, -S^2]*
       (T*((-2*S*(3 + 3*S^2 + S^4 + S^6))/F^3 - (2*S*(3 + 3*S^2 + S^4 + S^6))/
           F - (4*S^2*(-1 + 2*S^2 + S^4)*T)/F^2 + (3 + 6*S^2 + 2*S^6 + S^8)*
           T + ((3 + 6*S^2 + 2*S^6 + S^8)*T)/F^4) + 
        (4*S^2*(1 + S^2)^2*Log[T])/F^2))/(S^2*(1 + S^2)^2) - 
     (F^2*HPL[{1}, -S^2]*HPL[{2, 1}, -S^2]*
       (T*((-2*(S + S^3 + 4*S^5 + 4*S^7))/F^3 - (2*(S + S^3 + 4*S^5 + 4*S^7))/
           F - (2*S^2*(3 + 16*S^2 + 8*S^4)*T)/F^2 + 
          (1 + 2*S^2 + 8*S^6 + 4*S^8)*T + ((1 + 2*S^2 + 8*S^6 + 4*S^8)*T)/
           F^4) + (16*S^2*(1 + S^2)^2*Log[T])/F^2))/(S^2*(1 + S^2)^2) + 
     (F^2*HPL[{1}, -S^2]^4*(T*((-2*S*(7 + 7*S^2 + 4*S^4 + 4*S^6))/F^3 - 
          (2*S*(7 + 7*S^2 + 4*S^4 + 4*S^6))/F - (2*S^2*(-3 + 16*S^2 + 8*S^4)*
            T)/F^2 + (7 + 14*S^2 + 8*S^6 + 4*S^8)*T + 
          ((7 + 14*S^2 + 8*S^6 + 4*S^8)*T)/F^4) + (16*S^2*(1 + S^2)^2*Log[T])/
         F^2))/(12*S^2*(1 + S^2)^2) + 
     (F^2*T^2*HPL[{0}, S^2]*(-7 + S^2 + (-7 + S^2)/F^4 + (8*(-1 + S^2))/F^2 - 
        2*(-3 + S^2 + (-3 + S^2)/F^4 + (4*(-1 + S^2))/F^2)*Log[T]))/
      (2*(1 + S^2)) + (F^2*T*HPL[{0}, S^2]*HPL[{1}, -S^2]*
       (-((1 + S^2)^2*((-8*S)/F^3 - (8*S)/F - (4*S^2*T)/F^2 + (7 + 3*S^2)*T + 
           ((7 + 3*S^2)*T)/F^4)) + 2*((-4*S*(1 + S^2)^2)/F^3 - 
          (4*S*(1 + S^2)^2)/F - (4*(-1 + S^2)*T)/F^2 + 
          (5 + 6*S^2 + 7*S^4 + 2*S^6)*T + ((5 + 6*S^2 + 7*S^4 + 2*S^6)*T)/
           F^4)*Log[T]))/(2*S^2*(1 + S^2)^2) - 
     (2*F^2*T*HPL[{0}, S^2]*HPL[{1}, -S^2]^2*((1 + F^(-2))^2*(1 + S^4)*T + 
        ((-2*(S + S^3))/F^3 - (2*(S + S^3))/F + T + 2*S^2*T + (2*S^2*T)/F^2 + 
          (T + 2*S^2*T)/F^4)*Log[T]))/(S^2*(1 + S^2)^2) - 
     (2*F^2*T*HPL[{0}, S^2]*HPL[{2}, -S^2]*((1 + F^(-2))^2*(1 + S^4)*T + 
        ((-2*(S + S^3))/F^3 - (2*(S + S^3))/F + T + 2*S^2*T + (2*S^2*T)/F^2 + 
          (T + 2*S^2*T)/F^4)*Log[T]))/(S^2*(1 + S^2)^2) - 
     (F^2*T^2*HPL[{1}, -S^2]*(-((1 + S^2)^2*(-8 + S^2 + (-8 + S^2)/F^4 + 
           (8*(-2 + S^2))/F^2)) + 2*(1 + S^2)^2*(-4 + S^2 + (-4 + S^2)/F^4 + 
          (4*(-2 + S^2))/F^2)*Log[T] + 8*(1 + F^(-2))^2*Log[T]^2))/
      (2*S^2*(1 + S^2)^2) + (F^2*HPL[{1}, -S^2]*HPL[{2}, -S^2]*
       (T*((-4*S*(1 + S^2)^3)/F^3 - (4*S*(1 + S^2)^3)/F + 
          (2 + 7*S^2 + 6*S^4 + 8*S^6 + S^8)*T + 
          ((2 + 7*S^2 + 6*S^4 + 8*S^6 + S^8)*T)/F^4 - 
          (2*(1 + 5*S^2 + 12*S^4 + 4*S^6 + 2*S^8)*T)/F^2) - 
        4*T*((-2*(S + S^3 + S^5 + S^7))/F^3 - (2*(S + S^3 + S^5 + S^7))/F - 
          (4*S^4*(2 + S^2)*T)/F^2 + (1 + 2*S^2 + 2*S^6 + S^8)*T + 
          ((1 + 2*S^2 + 2*S^6 + S^8)*T)/F^4)*Log[T] - 
        (8*S^2*(1 + S^2)^2*Log[T]^2)/F^2))/(S^2*(1 + S^2)^2) + 
     (F^2*HPL[{2, 1}, -S^2]*(T*((4*S*(1 + S^2)^3)/F^3 + (4*S*(1 + S^2)^3)/F + 
          (2*S^2*(5 + 12*S^2 + 4*S^4 + 2*S^6)*T)/F^2 - 
          (3 + 7*S^2 + 6*S^4 + 8*S^6 + S^8)*T - 
          ((3 + 7*S^2 + 6*S^4 + 8*S^6 + S^8)*T)/F^4) + 
        4*T*((-2*(S + S^3 + S^5 + S^7))/F^3 - (2*(S + S^3 + S^5 + S^7))/F - 
          (4*S^4*(2 + S^2)*T)/F^2 + (1 + 2*S^2 + 2*S^6 + S^8)*T + 
          ((1 + 2*S^2 + 2*S^6 + S^8)*T)/F^4)*Log[T] + 
        (8*S^2*(1 + S^2)^2*Log[T]^2)/F^2))/(S^2*(1 + S^2)^2) - 
     (F^2*HPL[{1}, -S^2]^3*(T*((4*S*(1 + S^2)^3)/F^3 + (4*S*(1 + S^2)^3)/F - 
          (-6 + 7*S^2 - 2*S^4 + 8*S^6 + S^8)*T - 
          ((-6 + 7*S^2 - 2*S^4 + 8*S^6 + S^8)*T)/F^4 + 
          (2*(9 + 5*S^2 + 20*S^4 + 4*S^6 + 2*S^8)*T)/F^2) + 
        4*T*((-2*S*(3 + 3*S^2 + S^4 + S^6))/F^3 - 
          (2*S*(3 + 3*S^2 + S^4 + S^6))/F - (4*S^2*(-1 + 2*S^2 + S^4)*T)/
           F^2 + (3 + 6*S^2 + 2*S^6 + S^8)*T + ((3 + 6*S^2 + 2*S^6 + S^8)*T)/
           F^4)*Log[T] + (8*S^2*(1 + S^2)^2*Log[T]^2)/F^2))/
      (6*S^2*(1 + S^2)^2) - (F^2*HPL[{3}, -S^2]*
       (T*((4*S*(1 + S^2)^3)/F^3 + (4*S*(1 + S^2)^3)/F + 
          (2*S^2*(5 + 10*S^2 + 4*S^4 + 2*S^6)*T)/F^2 - 
          (3 + 7*S^2 + 8*S^4 + 8*S^6 + S^8)*T - 
          ((3 + 7*S^2 + 8*S^4 + 8*S^6 + S^8)*T)/F^4) + 
        2*T*((-2*(S + S^3 + 2*S^5 + 2*S^7))/F^3 - 
          (2*(S + S^3 + 2*S^5 + 2*S^7))/F - (2*S^2*(1 + 8*S^2 + 4*S^4)*T)/
           F^2 + (1 + 2*S^2 + 4*S^6 + 2*S^8)*T + ((1 + 2*S^2 + 4*S^6 + 2*S^8)*
            T)/F^4)*Log[T] + (8*S^2*(1 + S^2)^2*Log[T]^2)/F^2))/
      (S^2*(1 + S^2)^2) - (F^2*T*HPL[{2}, -S^2]*
       (-((1 + S^2)^2*((-8*S)/F^3 - (8*S)/F + 3*(1 + S^2)*T + 
           (3*(1 + S^2)*T)/F^4 - (4*(2 + S^2)*T)/F^2)) + 
        2*((-4*S*(1 + S^2)^2)/F^3 - (4*S*(1 + S^2)^2)/F - 
          (4*(1 + S^2 + 2*S^4)*T)/F^2 + (1 + 6*S^2 + 3*S^4 + 2*S^6)*T + 
          ((1 + 6*S^2 + 3*S^4 + 2*S^6)*T)/F^4)*Log[T] - 
        4*((-2*(S + S^3))/F^3 - (2*(S + S^3))/F + T + 2*S^2*T + 
          (2*S^2*T)/F^2 + (T + 2*S^2*T)/F^4)*Log[T]^2))/(S^2*(1 + S^2)^2) + 
     (2*F^2*T*HPL[{1}, -S^2]^2*(-((1 + F^(-2))^2*(1 + S^2)^2*T) + 
        2*(1 + F^(-2))^2*(1 + S^4)*T*Log[T] + 
        ((-2*(S + S^3))/F^3 - (2*(S + S^3))/F + T + 2*S^2*T + (2*S^2*T)/F^2 + 
          (T + 2*S^2*T)/F^4)*Log[T]^2))/(S^2*(1 + S^2)^2) + 
     (2*Pi^2*Zeta[3])/3 - 2*HPL[{1}, -S^2]^2*Zeta[3] + 
     (2*F^2*HPL[{1}, -S^2]*(T*((-2*(S^3 + S^5))/F^3 - (2*(S^3 + S^5))/F + 
          S^4*(2 + S^2)*T + (S^4*(2 + S^2)*T)/F^4 - (2*(1 + 4*S^2 + 2*S^4)*T)/
           F^2) + (4*(1 + S^2)^2*Log[T])/F^2)*Zeta[3])/(1 + S^2)^2 + 
     (F^2*(T*((-4*S*(1 + S^2)^2)/F^3 - (4*S*(1 + S^2)^2)/F + 
          S^2*(3 + 6*S^2 + S^4)*T + (S^2*(3 + 6*S^2 + S^4)*T)/F^4 - 
          (4*(2 + 4*S^2 + 2*S^4 + S^6)*T)/F^2) + 
        4*T*((2*(S^3 + S^5))/F^3 + (2*(S^3 + S^5))/F - S^4*(2 + S^2)*T - 
          (S^4*(2 + S^2)*T)/F^4 + (2*(1 + 4*S^2 + 2*S^4)*T)/F^2)*Log[T] - 
        (8*(1 + S^2)^2*Log[T]^2)/F^2)*Zeta[3])/(1 + S^2)^2 - 4*Zeta[5]
 
NuvwT2 = -((1 + F^(-2))*F*Pi^4*S*T)/15 + (F^2*Pi^4*(-4/F^2 + S^2 + S^2/F^4)*
       T^2)/30 + (Pi^4*HPL[{0}, S^2])/15 + 2*(1 + F^(-2))^2*F^2*T^2*
      HPL[{0}, S^2]*HPL[{1}, -S^2]^2 + (4*(1 + F^(-2))^2*F^2*T^2*
       HPL[{1}, -S^2]^3)/3 + (2*(1 + F^(-2))*F*(-1 + S^2)*T*HPL[{0}, S^2]*
       HPL[{3}, -S^2])/S - (F^2*(-1 - (4*S^2)/F^2 + S^4 + (-1 + S^4)/F^4)*T^2*
       HPL[{0}, S^2]*HPL[{3}, -S^2])/S^2 - 
     (4*(1 + F^(-2))*F*(-1 + S^2)*T*HPL[{4}, -S^2])/S + 
     (2*F^2*(-1 - (4*S^2)/F^2 + S^4 + (-1 + S^4)/F^4)*T^2*HPL[{4}, -S^2])/
      S^2 - 4*HPL[{0}, S^2]*HPL[{4}, -S^2] + 12*HPL[{5}, -S^2] + 
     (4*(1 + F^(-2))*F*(-1 + S^2)*T*HPL[{0}, S^2]*HPL[{2, 1}, -S^2])/S - 
     (2*F^2*(-1 - (4*S^2)/F^2 + S^4 + (-1 + S^4)/F^4)*T^2*HPL[{0}, S^2]*
       HPL[{2, 1}, -S^2])/S^2 - (4*(1 + F^(-2))*F*(-1 + S^2)*T*
       HPL[{3, 1}, -S^2])/S + (2*F^2*(-1 - (4*S^2)/F^2 + S^4 + 
        (-1 + S^4)/F^4)*T^2*HPL[{3, 1}, -S^2])/S^2 - 
     8*HPL[{0}, S^2]*HPL[{3, 1}, -S^2] + 16*HPL[{4, 1}, -S^2] + 
     (8*(1 + F^(-2))*F*(-1 + S^2)*T*HPL[{2, 1, 1}, -S^2])/S - 
     (4*F^2*(-1 - (4*S^2)/F^2 + S^4 + (-1 + S^4)/F^4)*T^2*
       HPL[{2, 1, 1}, -S^2])/S^2 - 16*HPL[{3, 1, 1}, -S^2] + 
     (2*Pi^4*Log[T])/15 - (4*(1 + F^(-2))*F*(-1 + S^2)*T*HPL[{0}, S^2]*
       HPL[{2}, -S^2]*Log[T])/S + (4*(1 + F^(-2))*F*(-1 + S^2)*T*
       HPL[{3}, -S^2]*Log[T])/S + 8*HPL[{0}, S^2]*HPL[{3}, -S^2]*Log[T] - 
     16*HPL[{4}, -S^2]*Log[T] - (8*(1 + F^(-2))*F*(-1 + S^2)*T*
       HPL[{2, 1}, -S^2]*Log[T])/S + 
     (4*F^2*(-1 - (4*S^2)/F^2 + S^4 + (-1 + S^4)/F^4)*T^2*HPL[{2, 1}, -S^2]*
       Log[T])/S^2 + 16*HPL[{3, 1}, -S^2]*Log[T] - 
     2*F^2*(1 + S^2)*T^2*HPL[{0}, S^2]*(-1 - F^(-4) - 6/F^2 + 
       (1 + F^(-4) + 4/F^2)*Log[T]) - (2*F^2*(1 + S^2)^2*T^2*HPL[{1}, -S^2]*
       (-1 - F^(-4) - 6/F^2 + (1 + F^(-4) + 4/F^2)*Log[T]))/S^2 + 
     (F^2*T^2*HPL[{0}, S^2]*HPL[{1}, -S^2]*
       ((1 + F^(-4) + 4/F^2)*(1 + S^2)^2 - 4*(1 + F^(-2))^2*S^2*Log[T]))/
      S^2 + (F^2*T^2*HPL[{1}, -S^2]^2*((1 + F^(-4) + 4/F^2)*(1 + S^2)^2 - 
        4*(1 + F^(-2))^2*S^2*Log[T]))/S^2 + 
     (2*F^2*T^2*HPL[{0}, S^2]*HPL[{2}, -S^2]*((1 + F^(-2))^2*S^2 + 
        (-1 - (4*S^2)/F^2 + S^4 + (-1 + S^4)/F^4)*Log[T]))/S^2 - 
     (2*F^2*T^2*HPL[{3}, -S^2]*((1 + F^(-2))^2*S^2 + 
        (-1 - (4*S^2)/F^2 + S^4 + (-1 + S^4)/F^4)*Log[T]))/S^2 + 
     (4*Pi^2*Zeta[3])/3 + 8*(1 + F^(-2))*F*S*T*Log[T]*Zeta[3] - 
     4*F^2*(-4/F^2 + S^2 + S^2/F^4)*T^2*Log[T]*Zeta[3] - 
     8*HPL[{0}, S^2]*Log[T]*Zeta[3] - 8*Zeta[5]
 
OuvwT2 = (-17*(1 + F^(-2))*F*Pi^4*S^3*T)/(360*(1 + S^2)) + 
     (17*F^2*Pi^4*(2/F^2 + S^4*(2 + S^2) + (S^4*(2 + S^2))/F^4)*T^2)/
      (720*(1 + S^2)^2) + ((1 + F^(-2))^2*F^2*Pi^2*S^4*T^2*HPL[{0}, S^2])/
      (12*(1 + S^2)) - ((1 + F^(-2))*F*Pi^2*S^3*T*HPL[{0}, S^2]^2)/
      (12*(1 + S^2)) + (F^2*Pi^2*S^2*(2 + S^2)*(-2/F^2 + S^2 + S^2/F^4)*T^2*
       HPL[{0}, S^2]^2)/(24*(1 + S^2)^2) - (17*Pi^4*HPL[{1}, -S^2])/360 + 
     ((1 + F^(-2))^2*F^2*Pi^2*(2 + 3*S^6)*T^2*HPL[{1}, -S^2])/
      (12*S^2*(1 + S^2)) - (Pi^2*HPL[{0}, S^2]^2*HPL[{1}, -S^2])/12 + 
     ((1 + F^(-2))*F*(2 + S^4)*T*HPL[{0}, S^2]^2*HPL[{1}, -S^2]^2)/
      (4*S*(1 + S^2)) - (F^2*(2 + 4*S^2 + 2*S^6 + S^8 - 
        (2*S^2*(-2 + 2*S^2 + S^4))/F^2 + (2 + 4*S^2 + 2*S^6 + S^8)/F^4)*T^2*
       HPL[{0}, S^2]^2*HPL[{1}, -S^2]^2)/(8*S^2*(1 + S^2)^2) - 
     ((1 + F^(-2))*F*(2 + 3*S^4)*T*HPL[{0}, S^2]*HPL[{1}, -S^2]^3)/
      (6*S*(1 + S^2)) + (F^2*(2 + 4*S^2 + 6*S^6 + 3*S^8 - 
        (2*S^2*(-2 + 6*S^2 + 3*S^4))/F^2 + (2 + 4*S^2 + 6*S^6 + 3*S^8)/F^4)*
       T^2*HPL[{0}, S^2]*HPL[{1}, -S^2]^3)/(12*S^2*(1 + S^2)^2) + 
     (HPL[{0}, S^2]^2*HPL[{1}, -S^2]^3)/4 - 
     (5*(1 + F^(-2))*F*(1 + S^4)*T*HPL[{1}, -S^2]^4)/(24*S*(1 + S^2)) + 
     (5*F^2*(1 + 2*S^2 + 2*S^6 + S^8 - (2*S^2*(-1 + 2*S^2 + S^4))/F^2 + 
        (1 + 2*S^2 + 2*S^6 + S^8)/F^4)*T^2*HPL[{1}, -S^2]^4)/
      (48*S^2*(1 + S^2)^2) - (5*HPL[{0}, S^2]*HPL[{1}, -S^2]^4)/24 - 
     HPL[{1}, -S^2]^5/12 - ((1 + F^(-2))*F*Pi^2*(-2 + 3*S^4)*T*
       HPL[{2}, -S^2])/(6*S*(1 + S^2)) - 
     (F^2*Pi^2*(2 + 4*S^2 - 6*S^6 - 3*S^8 + (2*S^2*(2 + 6*S^2 + 3*S^4))/F^2 + 
        (2 + 4*S^2 - 6*S^6 - 3*S^8)/F^4)*T^2*HPL[{2}, -S^2])/
      (12*S^2*(1 + S^2)^2) + (Pi^2*HPL[{0}, S^2]*HPL[{2}, -S^2])/6 - 
     ((1 + F^(-2))*F*S^3*T*HPL[{0}, S^2]^2*HPL[{2}, -S^2])/(2*(1 + S^2)) + 
     (F^2*S^2*(2 + S^2)*(-2/F^2 + S^2 + S^2/F^4)*T^2*HPL[{0}, S^2]^2*
       HPL[{2}, -S^2])/(4*(1 + S^2)^2) - (Pi^2*HPL[{1}, -S^2]*HPL[{2}, -S^2])/
      6 + ((1 + F^(-2))^2*F^2*(-1 + S^6)*T^2*HPL[{1}, -S^2]*HPL[{2}, -S^2])/
      (2*S^2*(1 + S^2)) - ((1 + F^(-2))*F*(5 + 2*S^4)*T*HPL[{0}, S^2]*
       HPL[{1}, -S^2]*HPL[{2}, -S^2])/(S*(1 + S^2)) + 
     (F^2*(5 + 10*S^2 + 4*S^6 + 2*S^8 - (2*S^2*(-5 + 4*S^2 + 2*S^4))/F^2 + 
        (5 + 10*S^2 + 4*S^6 + 2*S^8)/F^4)*T^2*HPL[{0}, S^2]*HPL[{1}, -S^2]*
       HPL[{2}, -S^2])/(2*S^2*(1 + S^2)^2) - 
     (HPL[{0}, S^2]^2*HPL[{1}, -S^2]*HPL[{2}, -S^2])/2 - 
     (7*HPL[{0}, S^2]*HPL[{1}, -S^2]^2*HPL[{2}, -S^2])/2 - 
     ((1 + F^(-2))*F*(1 + S^4)*T*HPL[{2}, -S^2]^2)/(2*S*(1 + S^2)) + 
     (F^2*(1 + 2*S^2 + 2*S^6 + S^8 - (2*S^2*(-1 + 2*S^2 + S^4))/F^2 + 
        (1 + 2*S^2 + 2*S^6 + S^8)/F^4)*T^2*HPL[{2}, -S^2]^2)/
      (4*S^2*(1 + S^2)^2) - 2*HPL[{0}, S^2]*HPL[{2}, -S^2]^2 - 
     HPL[{1}, -S^2]*HPL[{2}, -S^2]^2 + (Pi^2*HPL[{3}, -S^2])/6 - 
     2*T^2*HPL[{0}, S^2]*HPL[{3}, -S^2] + 
     ((1 + F^(-2))*F*(5 + 2*S^4)*T*HPL[{1}, -S^2]*HPL[{3}, -S^2])/
      (S*(1 + S^2)) - (F^2*(5 + 10*S^2 + 4*S^6 + 2*S^8 - 
        (2*S^2*(-5 + 4*S^2 + 2*S^4))/F^2 + (5 + 10*S^2 + 4*S^6 + 2*S^8)/F^4)*
       T^2*HPL[{1}, -S^2]*HPL[{3}, -S^2])/(2*S^2*(1 + S^2)^2) + 
     (7*HPL[{1}, -S^2]^2*HPL[{3}, -S^2])/2 + 5*HPL[{2}, -S^2]*
      HPL[{3}, -S^2] + (2*(1 + F^(-2))*F*(-1 + S^2)*T*HPL[{4}, -S^2])/S - 
     (F^2*(-1 - (6*S^2)/F^2 + S^4 + (-1 + S^4)/F^4)*T^2*HPL[{4}, -S^2])/S^2 - 
     2*HPL[{5}, -S^2] + (Pi^2*HPL[{2, 1}, -S^2])/3 - 
     ((1 + F^(-2))^2*F^2*(-2 - 3*S^2 + 3*S^4 + 2*S^6)*T^2*HPL[{2, 1}, -S^2])/
      (2*S^2*(1 + S^2)) - ((1 + F^(-2))*F*(-8 + S^4)*T*HPL[{0}, S^2]*
       HPL[{2, 1}, -S^2])/(S*(1 + S^2)) + 
     (F^2*(-8 - 16*S^2 + 2*S^6 + S^8 - (2*S^2*(8 + 2*S^2 + S^4))/F^2 + 
        (-8 - 16*S^2 + 2*S^6 + S^8)/F^4)*T^2*HPL[{0}, S^2]*HPL[{2, 1}, -S^2])/
      (2*S^2*(1 + S^2)^2) + 2*HPL[{0}, S^2]^2*HPL[{2, 1}, -S^2] + 
     (3*(1 + F^(-2))*F*(-1 + S^2)*T*HPL[{1}, -S^2]*HPL[{2, 1}, -S^2])/S - 
     (3*F^2*(-1 - (2*S^2)/F^2 + S^4 + (-1 + S^4)/F^4)*T^2*HPL[{1}, -S^2]*
       HPL[{2, 1}, -S^2])/(2*S^2) + 7*HPL[{0}, S^2]*HPL[{1}, -S^2]*
      HPL[{2, 1}, -S^2] + 4*HPL[{2}, -S^2]*HPL[{2, 1}, -S^2] + 
     (6*(1 + F^(-2))*F*(-1 + S^2)*T*HPL[{3, 1}, -S^2])/S + 
     (F^2*(3 + (2*S^2)/F^2 - 3*S^4 - (3*(-1 + S^4))/F^4)*T^2*
       HPL[{3, 1}, -S^2])/S^2 + 4*HPL[{0}, S^2]*HPL[{3, 1}, -S^2] - 
     7*HPL[{3, 2}, -S^2] - 24*HPL[{4, 1}, -S^2] - 
     (12*(1 + F^(-2))*F*(-1 + S^2)*T*HPL[{2, 1, 1}, -S^2])/S + 
     (6*F^2*(-1 - (2*S^2)/F^2 + S^4 + (-1 + S^4)/F^4)*T^2*
       HPL[{2, 1, 1}, -S^2])/S^2 - 5*HPL[{0}, S^2]*HPL[{2, 1, 1}, -S^2] - 
     14*HPL[{2, 2, 1}, -S^2] - 25*HPL[{3, 1, 1}, -S^2] - 
     (F^2*T^2*HPL[{0}, S^2]*HPL[{2}, -S^2]*(-3 + 4*S^2 + S^4 + S^6 + 
        (2*S^2*(10 + 4*S^2 + S^4))/F^2 + (-3 + 4*S^2 + S^4 + S^6)/F^4 - 
        (12*(1 + S^2)^2*Log[T])/F^2))/(2*(1 + S^2)^2) + 
     (F^2*T^2*HPL[{0}, S^2]^2*HPL[{1}, -S^2]*(-1 + 2*S^2 + 2*S^4 + 2*S^6 + 
        (-1 + 2*S^2 + 2*S^4 + 2*S^6)/F^4 + (8*S^2 + 6*S^4 + 4*S^6)/F^2 - 
        (4*(1 + S^2)^2*Log[T])/F^2))/(4*(1 + S^2)^2) + 
     (F^2*T^2*HPL[{0}, S^2]*HPL[{1}, -S^2]^2*(1 - 2*S^2 + 3*S^4 + S^6 + 
        (2*(-2 - 8*S^2 + S^6))/F^2 + (1 - 2*S^2 + 3*S^4 + S^6)/F^4 + 
        (12*(1 + S^2)^2*Log[T])/F^2))/(4*(1 + S^2)^2) - 
     (F^2*T^2*HPL[{3}, -S^2]*(2 + 5*S^2 - 4*S^4 + (2 + 5*S^2 - 4*S^4)/F^4 + 
        (4 + 4*S^2 - 20*S^4 - 6*S^6)/F^2 + (12*S^2*(1 + S^2)^2*Log[T])/F^2))/
      (2*S^2*(1 + S^2)^2) + (F^2*T^2*HPL[{1}, -S^2]^3*
       (1 + 4*S^2 - 4*S^4 + 4*S^6 + S^8 + 
        (2*(1 - 2*S^2 - 16*S^4 - 2*S^6 + S^8))/F^2 + 
        (1 + 4*S^2 - 4*S^4 + 4*S^6 + S^8)/F^4 + (24*S^2*(1 + S^2)^2*Log[T])/
         F^2))/(12*S^2*(1 + S^2)^2) + T^2*HPL[{1}, -S^2]^2*
      (-1 + 2*Log[T] - 2*Log[T]^2) + (Pi^2*T^2*(1 - 2*Log[T] + 2*Log[T]^2))/
      6 - T^2*HPL[{0}, S^2]*HPL[{1}, -S^2]*(1 - 2*Log[T] + 2*Log[T]^2) - 
     (4*Pi^2*Zeta[3])/3 + ((1 + F^(-2))*F*S^3*T*HPL[{0}, S^2]*Zeta[3])/
      (1 + S^2) - (F^2*S^2*(2 + S^2)*(-2/F^2 + S^2 + S^2/F^4)*T^2*
       HPL[{0}, S^2]*Zeta[3])/(2*(1 + S^2)^2) + 
     (3*(1 + F^(-2))*F*(2 + S^4)*T*HPL[{1}, -S^2]*Zeta[3])/(S*(1 + S^2)) - 
     (F^2*((2*S^2*(10 + 2*S^2 + S^4))/F^2 + 3*(2 + 4*S^2 + 2*S^6 + S^8) + 
        (3*(2 + 4*S^2 + 2*S^6 + S^8))/F^4)*T^2*HPL[{1}, -S^2]*Zeta[3])/
      (2*S^2*(1 + S^2)^2) + HPL[{0}, S^2]*HPL[{1}, -S^2]*Zeta[3] + 
     (9*HPL[{1}, -S^2]^2*Zeta[3])/2 + 5*HPL[{2}, -S^2]*Zeta[3] + 
     (F^2*T^2*(-6 - S^4 + 2*S^6 + (2*(-5 + 2*S^2 + 2*S^6))/F^2 + 
        (-6 - S^4 + 2*S^6)/F^4 - (4*(1 + S^2)^2*Log[T])/F^2)*Zeta[3])/
      (2*(1 + S^2)^2) + 17*Zeta[5]
 
GuvwT2 = -((-1 + F^(-2))*F*Pi^2*(1 + S^2)*T*HPL[{0}, S^2]*HPL[{1}, -S^2])/
      (3*S) + ((-1 + F^(-4))*F^2*Pi^2*(1 + S^4)*T^2*HPL[{0}, S^2]*
       HPL[{1}, -S^2])/(6*S^2) - ((-1 + F^(-2))*F*Pi^2*(1 + S^2)*T*
       HPL[{1}, -S^2]^2)/(3*S) + ((-1 + F^(-4))*F^2*Pi^2*(1 + S^4)*T^2*
       HPL[{1}, -S^2]^2)/(6*S^2) + (2*(-1 + F^(-2))*F*(1 + S^2)*T*
       HPL[{0}, S^2]*HPL[{1}, -S^2]^3)/(3*S) - 
     ((-1 + F^(-4))*F^2*(1 + S^4)*T^2*HPL[{0}, S^2]*HPL[{1}, -S^2]^3)/
      (3*S^2) + ((-1 + F^(-2))*F*(1 + S^2)*T*HPL[{1}, -S^2]^4)/(3*S) - 
     ((-1 + F^(-4))*F^2*(1 + S^4)*T^2*HPL[{1}, -S^2]^4)/(6*S^2) + 
     (2*(-1 + F^(-2))*F*(1 + S^2)*T*HPL[{0}, S^2]*HPL[{1}, -S^2]*
       HPL[{2}, -S^2])/S - ((-1 + F^(-4))*F^2*(1 + S^4)*T^2*HPL[{0}, S^2]*
       HPL[{1}, -S^2]*HPL[{2}, -S^2])/S^2 - 
     (2*(-1 + F^(-2))*F*(1 + S^2)*T*HPL[{1}, -S^2]*HPL[{3}, -S^2])/S + 
     ((-1 + F^(-4))*F^2*(1 + S^4)*T^2*HPL[{1}, -S^2]*HPL[{3}, -S^2])/S^2 - 
     (2*(-1 + F^(-2))*F*(1 + S^2)*T*HPL[{0}, S^2]*HPL[{2, 1}, -S^2])/S + 
     ((-1 + F^(-4))*F^2*(1 + S^4)*T^2*HPL[{0}, S^2]*HPL[{2, 1}, -S^2])/S^2 + 
     (2*(-1 + F^(-2))*F*Pi^2*S*T*HPL[{0}, S^2]*(-1 + Log[T]))/3 + 
     (2*(-1 + F^(-2))*F*Pi^2*(1 + S^2)*T*HPL[{1}, -S^2]*(-1 + Log[T]))/
      (3*S) - (2*(-1 + F^(-2))*F*(1 + S^2)*T*HPL[{0}, S^2]*HPL[{1}, -S^2]^2*
       (-1 + Log[T]))/S - (4*(-1 + F^(-2))*F*(1 + S^2)*T*HPL[{1}, -S^2]^3*
       (-1 + Log[T]))/(3*S) - 4*(-1 + F^(-2))*F*S*T*HPL[{0}, S^2]*
      HPL[{2}, -S^2]*(-1 + Log[T]) + 4*(-1 + F^(-2))*F*S*T*HPL[{3}, -S^2]*
      (-1 + Log[T]) - (4*(-1 + F^(-2))*F*(-1 + S^2)*T*HPL[{2, 1}, -S^2]*
       (-1 + Log[T]))/S - ((-1 + F^(-4))*F^2*Pi^2*T^2*(-1 + 2*Log[T]))/6 + 
     ((-1 + F^(-4))*F^2*(-1 + S^4)*T^2*HPL[{2, 1}, -S^2]*(-1 + 2*Log[T]))/
      S^2 - ((-1 + F^(-4))*F^2*Pi^2*T^2*HPL[{0}, S^2]*
       (-1 - S^2 + 2*S^2*Log[T]))/6 + (-1 + F^(-4))*F^2*T^2*HPL[{0}, S^2]*
      HPL[{2}, -S^2]*(-1 - S^2 + 2*S^2*Log[T]) - (-1 + F^(-4))*F^2*T^2*
      HPL[{3}, -S^2]*(-1 - S^2 + 2*S^2*Log[T]) - 
     ((-1 + F^(-4))*F^2*Pi^2*T^2*HPL[{1}, -S^2]*(-(1 + S^2)^2 + 
        2*(1 + S^4)*Log[T]))/(6*S^2) + ((-1 + F^(-4))*F^2*T^2*HPL[{0}, S^2]*
       HPL[{1}, -S^2]^2*(-(1 + S^2)^2 + 2*(1 + S^4)*Log[T]))/(2*S^2) + 
     ((-1 + F^(-4))*F^2*T^2*HPL[{1}, -S^2]^3*(-(1 + S^2)^2 + 
        2*(1 + S^4)*Log[T]))/(3*S^2) + 2*(-1 + F^(-2))*F*S*T*HPL[{0}, S^2]*
      Zeta[3] - (-1 + F^(-4))*F^2*S^2*T^2*HPL[{0}, S^2]*Zeta[3] + 
     4*(-1 + F^(-2))*F*S*T*(-1 + Log[T])*Zeta[3] - (-1 + F^(-4))*F^2*S^2*T^2*
      (-1 + 2*Log[T])*Zeta[3]
 
H1uvwT2 = -((-1 + F^(-4))*F^2*(1 + S^2)^2*T^2*HPL[{0}, S^2]*HPL[{1}, -S^2])/
      (2*S^2) - ((-1 + F^(-2))*F*Pi^2*(1 + S^2)*T*HPL[{1}, -S^2]^2)/(6*S) - 
     ((-1 + F^(-4))*F^2*(1 + S^2)^2*T^2*HPL[{1}, -S^2]^2)/(2*S^2) + 
     ((-1 + F^(-4))*F^2*Pi^2*(1 + S^4)*T^2*HPL[{1}, -S^2]^2)/(12*S^2) - 
     ((-1 + F^(-2))*F*(1 + S^2)*T*HPL[{0}, S^2]^2*HPL[{1}, -S^2]^2)/(2*S) + 
     ((-1 + F^(-4))*F^2*(1 + S^4)*T^2*HPL[{0}, S^2]^2*HPL[{1}, -S^2]^2)/
      (4*S^2) - ((-1 + F^(-4))*F^2*(-1 + S^4)*T^2*HPL[{1}, -S^2]*
       HPL[{2}, -S^2])/S^2 + (2*(-1 + F^(-2))*F*(1 + S^2)*T*HPL[{0}, S^2]*
       HPL[{1}, -S^2]*HPL[{2}, -S^2])/S - 
     ((-1 + F^(-4))*F^2*(1 + S^4)*T^2*HPL[{0}, S^2]*HPL[{1}, -S^2]*
       HPL[{2}, -S^2])/S^2 - ((-1 + F^(-4))*F^2*(-1 + S^4)*T^2*
       HPL[{3}, -S^2])/(2*S^2) + ((-1 + F^(-2))*F*(1 + S^2)*T*HPL[{0}, S^2]*
       HPL[{3}, -S^2])/S - ((-1 + F^(-4))*F^2*(1 + S^4)*T^2*HPL[{0}, S^2]*
       HPL[{3}, -S^2])/(2*S^2) + ((-1 + F^(-4))*F^2*(-1 + S^4)*T^2*
       HPL[{2, 1}, -S^2])/S^2 - (2*(-1 + F^(-2))*F*(1 + S^2)*T*HPL[{0}, S^2]*
       HPL[{2, 1}, -S^2])/S + ((-1 + F^(-4))*F^2*(1 + S^4)*T^2*HPL[{0}, S^2]*
       HPL[{2, 1}, -S^2])/S^2 + ((-1 + F^(-4))*F^2*Pi^2*(-1 + S^2)*T^2*
       (-1 + Log[T]))/6 + ((-1 + F^(-4))*F^2*(-1 + S^2)*T^2*HPL[{0}, S^2]^2*
       (-1 + Log[T]))/2 + ((-1 + F^(-2))*F*Pi^2*(1 + S^2)*T*HPL[{1}, -S^2]*
       (-1 + Log[T]))/(3*S) + ((-1 + F^(-2))*F*(1 + S^2)*T*HPL[{0}, S^2]^2*
       HPL[{1}, -S^2]*(-1 + Log[T]))/S + ((-1 + F^(-4))*F^2*(-1 + S^4)*T^2*
       HPL[{2}, -S^2]*(-1 + Log[T]))/S^2 - 
     (2*(-1 + F^(-2))*F*(1 + S^2)*T*HPL[{0}, S^2]*HPL[{2}, -S^2]*
       (-1 + Log[T]))/S + ((-1 + F^(-4))*F^2*(1 + S^2)*T^2*HPL[{0}, S^2]*
       (-3 + 2*Log[T]))/2 + ((-1 + F^(-4))*F^2*(1 + S^2)^2*T^2*HPL[{1}, -S^2]*
       (-3 + 2*Log[T]))/(2*S^2) - ((-1 + F^(-4))*F^2*Pi^2*T^2*HPL[{1}, -S^2]*
       (-1 - S^2 + (1 + S^4)*Log[T]))/(6*S^2) - 
     ((-1 + F^(-4))*F^2*T^2*HPL[{0}, S^2]^2*HPL[{1}, -S^2]*
       (-1 - S^2 + (1 + S^4)*Log[T]))/(2*S^2) + 
     ((-1 + F^(-4))*F^2*T^2*HPL[{0}, S^2]*HPL[{2}, -S^2]*
       (-(1 + S^2)^2 + 2*(1 + S^4)*Log[T]))/(2*S^2) - 
     (-1 + F^(-4))*F^2*(-1 + S^2)*T^2*Zeta[3] - 
     (2*(-1 + F^(-2))*F*(1 + S^2)*T*HPL[{1}, -S^2]*Zeta[3])/S + 
     ((-1 + F^(-4))*F^2*(1 + S^4)*T^2*HPL[{1}, -S^2]*Zeta[3])/S^2
 
H1vwuT2 = ((-1 + F^(-2))*F*Pi^4*S*T)/36 - ((-1 + F^(-4))*F^2*Pi^4*S^2*T^2)/
      72 - ((-1 + F^(-2))*F*Pi^2*S*T*HPL[{0}, S^2])/6 - 
     ((-1 + F^(-4))*F^2*Pi^2*S^2*T^2*HPL[{0}, S^2])/24 + 
     ((-1 + F^(-2))*F*Pi^2*S*T*HPL[{0}, S^2]^2)/12 - 
     ((-1 + F^(-4))*F^2*Pi^2*S^2*T^2*HPL[{0}, S^2]^2)/24 - 
     ((-1 + F^(-2))*F*Pi^2*(1 + S^2)*T*HPL[{1}, -S^2])/(3*S) - 
     ((-1 + F^(-4))*F^2*Pi^2*(-1 + S^4)*T^2*HPL[{1}, -S^2])/(12*S^2) - 
     ((-1 + F^(-2))*F*(1 + S^2)*T*HPL[{0}, S^2]^2*HPL[{1}, -S^2])/(2*S) - 
     ((-1 + F^(-4))*F^2*(-1 + S^4)*T^2*HPL[{0}, S^2]^2*HPL[{1}, -S^2])/
      (8*S^2) - ((-1 + F^(-2))*F*(1 + S^2)*T*HPL[{0}, S^2]*HPL[{1}, -S^2]^2)/
      S - ((-1 + F^(-4))*F^2*(-1 + S^4)*T^2*HPL[{0}, S^2]*HPL[{1}, -S^2]^2)/
      (4*S^2) - (2*(-1 + F^(-2))*F*(1 + S^2)*T*HPL[{1}, -S^2]^3)/(3*S) - 
     ((-1 + F^(-4))*F^2*(-1 + S^4)*T^2*HPL[{1}, -S^2]^3)/(6*S^2) + 
     ((-1 + F^(-2))*F*Pi^2*S*T*HPL[{2}, -S^2])/3 - 
     ((-1 + F^(-4))*F^2*Pi^2*S^2*T^2*HPL[{2}, -S^2])/6 + 
     ((-1 + F^(-2))*F*S*T*HPL[{0}, S^2]^2*HPL[{2}, -S^2])/2 - 
     ((-1 + F^(-4))*F^2*S^2*T^2*HPL[{0}, S^2]^2*HPL[{2}, -S^2])/4 - 
     ((-1 + F^(-2))*F*(1 + S^2)*T*HPL[{1}, -S^2]*HPL[{2}, -S^2])/S - 
     ((-1 + F^(-4))*F^2*(-1 + S^4)*T^2*HPL[{1}, -S^2]*HPL[{2}, -S^2])/
      (4*S^2) + ((-1 + F^(-2))*F*S*T*HPL[{2}, -S^2]^2)/2 - 
     ((-1 + F^(-4))*F^2*S^2*T^2*HPL[{2}, -S^2]^2)/4 - 
     (-1 + F^(-2))*F*S*T*HPL[{0}, S^2]*HPL[{3}, -S^2] + 
     ((-1 + F^(-4))*F^2*S^2*T^2*HPL[{0}, S^2]*HPL[{3}, -S^2])/2 - 
     ((-1 + F^(-4))*F^2*S^2*T^2*HPL[{4}, -S^2])/2 - 
     (-((S*T)/F) + F*S*T)*HPL[{4}, -S^2] + 2*(-1 + F^(-2))*F*S*T*
      HPL[{0}, S^2]*HPL[{2, 1}, -S^2] - (-1 + F^(-4))*F^2*S^2*T^2*
      HPL[{0}, S^2]*HPL[{2, 1}, -S^2] - 4*(-1 + F^(-2))*F*S*T*
      HPL[{3, 1}, -S^2] + 2*(-1 + F^(-4))*F^2*S^2*T^2*HPL[{3, 1}, -S^2] + 
     4*(-1 + F^(-2))*F*S*T*HPL[{2, 1, 1}, -S^2] - 2*(-1 + F^(-4))*F^2*S^2*T^2*
      HPL[{2, 1, 1}, -S^2] + ((-1 + F^(-2))*F*Pi^2*S*T*(-1 + Log[T])*Log[T])/
      3 + (-1 + F^(-2))*F*S*T*HPL[{0}, S^2]^2*(-1 + Log[T])*Log[T] + 
     2*(-1 + F^(-2))*F*S*T*HPL[{2}, -S^2]*(-1 + Log[T])*Log[T] + 
     ((-1 + F^(-2))*F*(1 + S^2)*T*HPL[{0}, S^2]*HPL[{1}, -S^2]*
       (-3 + 2*Log[T]))/S + ((-1 + F^(-2))*F*(1 + S^2)*T*HPL[{1}, -S^2]^2*
       (-3 + 2*Log[T]))/S - (-1 + F^(-2))*F*S*T*HPL[{0}, S^2]*HPL[{2}, -S^2]*
      (-1 + 2*Log[T]) + (-1 + F^(-2))*F*S*T*HPL[{3}, -S^2]*(-1 + 2*Log[T]) + 
     ((-1 + F^(-4))*F^2*S^2*T^2*HPL[{0}, S^2]*HPL[{2}, -S^2]*(-3 + 4*Log[T]))/
      4 - ((-1 + F^(-4))*F^2*S^2*T^2*HPL[{3}, -S^2]*(-3 + 4*Log[T]))/4 - 
     (2*(-1 + F^(-2))*F*T*HPL[{2, 1}, -S^2]*(-1 - 2*S^2 + 2*S^2*Log[T]))/S + 
     ((-1 + F^(-4))*F^2*T^2*HPL[{2, 1}, -S^2]*(-1 - 2*S^4 + 4*S^4*Log[T]))/
      (2*S^2) + ((-1 + F^(-4))*F^2*(1 + S^2)*T^2*HPL[{0}, S^2]*HPL[{1}, -S^2]*
       (3 + S^2 + 4*(-1 + S^2)*Log[T]))/(8*S^2) + 
     ((-1 + F^(-4))*F^2*(1 + S^2)*T^2*HPL[{1}, -S^2]^2*
       (3 + S^2 + 4*(-1 + S^2)*Log[T]))/(8*S^2) - 2*(-1 + F^(-2))*F*S*T*
      HPL[{0}, S^2]*(3 - 3*Log[T] + Log[T]^2) - 
     (2*(-1 + F^(-2))*F*(1 + S^2)*T*HPL[{1}, -S^2]*(3 - 3*Log[T] + Log[T]^2))/
      S + ((-1 + F^(-4))*F^2*T^2*(3 - 6*Log[T] + 4*Log[T]^2))/8 - 
     ((-1 + F^(-4))*F^2*Pi^2*T^2*(-1 + 2*S^2 - 3*S^2*Log[T] + 
        2*S^2*Log[T]^2))/12 - ((-1 + F^(-4))*F^2*T^2*HPL[{0}, S^2]^2*
       (-1 + 4*S^2 - 6*S^2*Log[T] + 4*S^2*Log[T]^2))/8 - 
     ((-1 + F^(-4))*F^2*T^2*HPL[{2}, -S^2]*(-1 + 4*S^2 - 6*S^2*Log[T] + 
        4*S^2*Log[T]^2))/4 - ((-1 + F^(-4))*F^2*T^2*HPL[{0}, S^2]*
       (-3 - 9*S^2 + 2*(2 + S^2)*Log[T] + 4*S^2*Log[T]^2))/8 - 
     ((-1 + F^(-4))*F^2*(1 + S^2)*T^2*HPL[{1}, -S^2]*
       (-3 - 9*S^2 + 2*(3 + S^2)*Log[T] + 4*(-1 + S^2)*Log[T]^2))/(8*S^2) + 
     2*(-1 + F^(-2))*F*S*T*HPL[{0}, S^2]*Zeta[3] - (-1 + F^(-4))*F^2*S^2*T^2*
      HPL[{0}, S^2]*Zeta[3] + 4*(-1 + F^(-2))*F*S*T*(-1 + Log[T])*Zeta[3] - 
     (-1 + F^(-4))*F^2*S^2*T^2*(-1 + 2*Log[T])*Zeta[3]
 
H1wuvT2 = ((-1 + F^(-4))*F^2*Pi^2*T^2)/24 - 
     ((-1 + F^(-2))*F*Pi^2*S*T*HPL[{0}, S^2])/6 + 
     ((-1 + F^(-4))*F^2*Pi^2*S^2*T^2*HPL[{0}, S^2])/24 - 
     ((-1 + F^(-2))*F*Pi^2*(1 + S^2)*T*HPL[{1}, -S^2])/(6*S) + 
     ((-1 + F^(-4))*F^2*Pi^2*(-1 + S^4)*T^2*HPL[{1}, -S^2])/(24*S^2) - 
     ((-1 + F^(-2))*F*(1 + S^2)*T*HPL[{0}, S^2]*HPL[{1}, -S^2]^2)/S + 
     ((-1 + F^(-4))*F^2*(-1 + S^4)*T^2*HPL[{0}, S^2]*HPL[{1}, -S^2]^2)/
      (4*S^2) - (2*(-1 + F^(-2))*F*(1 + S^2)*T*HPL[{1}, -S^2]^3)/(3*S) + 
     ((-1 + F^(-4))*F^2*(-1 + S^4)*T^2*HPL[{1}, -S^2]^3)/(6*S^2) - 
     ((-1 + F^(-2))*F*Pi^2*T*HPL[{2}, -S^2])/(6*S) + 
     ((-1 + F^(-4))*F^2*Pi^2*T^2*HPL[{2}, -S^2])/(12*S^2) + 
     ((-1 + F^(-2))*F*(1 + S^2)*T*HPL[{1}, -S^2]*HPL[{2}, -S^2])/S - 
     ((-1 + F^(-4))*F^2*(-1 + S^4)*T^2*HPL[{1}, -S^2]*HPL[{2}, -S^2])/
      (4*S^2) + ((-1 + F^(-2))*F*T*HPL[{2}, -S^2]^2)/(2*S) - 
     ((-1 + F^(-4))*F^2*T^2*HPL[{2}, -S^2]^2)/(4*S^2) - 
     ((-1 + F^(-2))*F*T*HPL[{0}, S^2]*HPL[{3}, -S^2])/S + 
     ((-1 + F^(-4))*F^2*T^2*HPL[{0}, S^2]*HPL[{3}, -S^2])/(2*S^2) + 
     (3*(-1 + F^(-2))*F*T*HPL[{4}, -S^2])/S - 
     (3*(-1 + F^(-4))*F^2*T^2*HPL[{4}, -S^2])/(2*S^2) - 
     (2*(-1 + F^(-2))*F*T*HPL[{0}, S^2]*HPL[{2, 1}, -S^2])/S + 
     ((-1 + F^(-4))*F^2*T^2*HPL[{0}, S^2]*HPL[{2, 1}, -S^2])/S^2 - 
     (4*(-1 + F^(-2))*F*T*HPL[{2, 1, 1}, -S^2])/S + 
     (2*(-1 + F^(-4))*F^2*T^2*HPL[{2, 1, 1}, -S^2])/S^2 + 
     ((-1 + F^(-4))*F^2*T^2*HPL[{0}, S^2]*HPL[{2}, -S^2]*
       (2 + S^4 - 4*Log[T]))/(4*S^2) + 
     ((-1 + F^(-4))*F^2*T^2*HPL[{2, 1}, -S^2]*(2 + S^4 - 4*Log[T]))/(2*S^2) - 
     ((-1 + F^(-4))*F^2*T^2*HPL[{3}, -S^2]*(1 + 2*S^4 - 4*Log[T]))/(4*S^2) - 
     ((-1 + F^(-2))*F*T*HPL[{0}, S^2]*HPL[{2}, -S^2]*(2 + S^2 - 2*Log[T]))/
      S - (2*(-1 + F^(-2))*F*T*HPL[{2, 1}, -S^2]*(2 + S^2 - 2*Log[T]))/S + 
     ((-1 + F^(-2))*F*T*HPL[{3}, -S^2]*(3 + 2*S^2 - 2*Log[T]))/S - 
     (2*(-1 + F^(-2))*F*T*HPL[{2}, -S^2]*(-1 + Log[T])*Log[T])/S + 
     ((-1 + F^(-2))*F*(1 + S^2)*T*HPL[{0}, S^2]*HPL[{1}, -S^2]*
       (-3 + 2*Log[T]))/S + ((-1 + F^(-2))*F*(1 + S^2)*T*HPL[{1}, -S^2]^2*
       (-3 + 2*Log[T]))/S - ((-1 + F^(-4))*F^2*(1 + S^2)*T^2*HPL[{0}, S^2]*
       HPL[{1}, -S^2]*(-1 - 3*S^2 + 4*(-1 + S^2)*Log[T]))/(8*S^2) - 
     ((-1 + F^(-4))*F^2*(1 + S^2)*T^2*HPL[{1}, -S^2]^2*
       (-1 - 3*S^2 + 4*(-1 + S^2)*Log[T]))/(8*S^2) - 
     ((-1 + F^(-4))*F^2*T^2*HPL[{2}, -S^2]*(-4 + S^2 + 6*Log[T] - 
        4*Log[T]^2))/(4*S^2) - 2*(-1 + F^(-2))*F*S*T*HPL[{0}, S^2]*
      (3 - 3*Log[T] + Log[T]^2) - (2*(-1 + F^(-2))*F*(1 + S^2)*T*
       HPL[{1}, -S^2]*(3 - 3*Log[T] + Log[T]^2))/S + 
     ((-1 + F^(-4))*F^2*T^2*(3 - 6*Log[T] + 4*Log[T]^2))/8 + 
     ((-1 + F^(-4))*F^2*T^2*HPL[{0}, S^2]*(3*(3 + S^2) - 
        2*(2 + 3*S^2)*Log[T] + 4*S^2*Log[T]^2))/8 + 
     ((-1 + F^(-4))*F^2*(1 + S^2)*T^2*HPL[{1}, -S^2]*
       (3*(3 + S^2) - 2*(1 + 3*S^2)*Log[T] + 4*(-1 + S^2)*Log[T]^2))/
      (8*S^2) + 2*(-1 + F^(-2))*F*S*T*Zeta[3] - 
     ((-1 + F^(-4))*F^2*S^2*T^2*Zeta[3])/2
 
J1uvwT2 = (-2*(-1 + F^(-2))*F*Pi^2*(1 + S^2)*T*HPL[{0}, S^2]*HPL[{1}, -S^2])/
      (3*S) + ((-1 + F^(-4))*F^2*Pi^2*(1 + S^4)*T^2*HPL[{0}, S^2]*
       HPL[{1}, -S^2])/(3*S^2) - ((-1 + F^(-4))*F^2*(-1 + S^4)*T^2*
       HPL[{0}, S^2]^2*HPL[{1}, -S^2])/S^2 + 
     (2*(-1 + F^(-2))*F*(1 + S^2)*T*HPL[{0}, S^2]^3*HPL[{1}, -S^2])/(3*S) - 
     ((-1 + F^(-4))*F^2*(1 + S^4)*T^2*HPL[{0}, S^2]^3*HPL[{1}, -S^2])/
      (3*S^2) - (4*(-1 + F^(-2))*F*Pi^2*(1 + S^2)*T*HPL[{1}, -S^2]^2)/(3*S) + 
     (2*(-1 + F^(-4))*F^2*Pi^2*(1 + S^4)*T^2*HPL[{1}, -S^2]^2)/(3*S^2) - 
     (4*(-1 + F^(-4))*F^2*(-1 + S^4)*T^2*HPL[{1}, -S^2]*HPL[{2}, -S^2])/S^2 + 
     (8*(-1 + F^(-2))*F*(1 + S^2)*T*HPL[{1}, -S^2]*HPL[{3}, -S^2])/S - 
     (4*(-1 + F^(-4))*F^2*(1 + S^4)*T^2*HPL[{1}, -S^2]*HPL[{3}, -S^2])/S^2 + 
     (8*(-1 + F^(-2))*F*(1 + S^2)*T*HPL[{4}, -S^2])/S - 
     (4*(-1 + F^(-4))*F^2*(1 + S^4)*T^2*HPL[{4}, -S^2])/S^2 + 
     (4*(-1 + F^(-4))*F^2*(-1 + S^4)*T^2*HPL[{2, 1}, -S^2])/S^2 - 
     (8*(-1 + F^(-2))*F*(1 + S^2)*T*HPL[{3, 1}, -S^2])/S + 
     (4*(-1 + F^(-4))*F^2*(1 + S^4)*T^2*HPL[{3, 1}, -S^2])/S^2 + 
     (4*(-1 + F^(-2))*F*Pi^2*S*T*HPL[{0}, S^2]*(-1 + Log[T]))/3 - 
     (4*(-1 + F^(-2))*F*S*T*HPL[{0}, S^2]^3*(-1 + Log[T]))/3 + 
     (8*(-1 + F^(-2))*F*Pi^2*(1 + S^2)*T*HPL[{1}, -S^2]*(-1 + Log[T]))/
      (3*S) + (4*(-1 + F^(-4))*F^2*(-1 + S^4)*T^2*HPL[{2}, -S^2]*
       (-1 + Log[T]))/S^2 - (8*(-1 + F^(-2))*F*(1 + S^2)*T*HPL[{3}, -S^2]*
       (-1 + Log[T]))/S + (-1 + F^(-4))*F^2*T^2*HPL[{0}, S^2]^2*
      (1 - 2*S^2 + 2*S^2*Log[T]) - ((-1 + F^(-4))*F^2*Pi^2*T^2*HPL[{0}, S^2]*
       (-1 - S^2 + 2*S^2*Log[T]))/3 + ((-1 + F^(-4))*F^2*T^2*HPL[{0}, S^2]^3*
       (-1 - S^2 + 2*S^2*Log[T]))/3 + ((-1 + F^(-4))*F^2*Pi^2*T^2*
       (3 - 2*S^2 + 2*(-2 + S^2)*Log[T]))/3 + 
     (4*(-1 + F^(-4))*F^2*T^2*HPL[{3}, -S^2]*(-(S^2*(1 + S^2)) + 
        (1 + S^4)*Log[T]))/S^2 - ((-1 + F^(-4))*F^2*Pi^2*T^2*HPL[{1}, -S^2]*
       (-3 - 4*S^2 - S^4 + 4*(1 + S^4)*Log[T]))/(3*S^2) - 
     4*(-1 + F^(-4))*F^2*S^2*T^2*Zeta[3] + 8*(-1 + F^(-2))*F*S*T*
      HPL[{0}, S^2]*Zeta[3] - 4*(-1 + F^(-4))*F^2*S^2*T^2*HPL[{0}, S^2]*
      Zeta[3]
 
J1vwuT2 = ((-1 + F^(-2))*F*Pi^4*S*T)/9 - ((-1 + F^(-4))*F^2*Pi^4*S^2*T^2)/
      18 - (2*(-1 + F^(-2))*F*Pi^2*S*T*HPL[{0}, S^2])/3 - 
     ((-1 + F^(-4))*F^2*Pi^2*S^2*T^2*HPL[{0}, S^2])/6 + 
     ((-1 + F^(-2))*F*Pi^2*S*T*HPL[{0}, S^2]^2)/3 - 
     ((-1 + F^(-4))*F^2*Pi^2*S^2*T^2*HPL[{0}, S^2]^2)/6 - 
     (4*(-1 + F^(-2))*F*Pi^2*(1 + S^2)*T*HPL[{1}, -S^2])/(3*S) - 
     ((-1 + F^(-4))*F^2*Pi^2*(-1 + S^4)*T^2*HPL[{1}, -S^2])/(3*S^2) + 
     (2*(-1 + F^(-2))*F*(1 + S^2)*T*HPL[{0}, S^2]^3*HPL[{1}, -S^2])/(3*S) - 
     ((-1 + F^(-4))*F^2*(1 + S^4)*T^2*HPL[{0}, S^2]^3*HPL[{1}, -S^2])/
      (3*S^2) + (2*(-1 + F^(-2))*F*(1 + S^2)*T*HPL[{0}, S^2]^2*
       HPL[{1}, -S^2]^2)/S - ((-1 + F^(-4))*F^2*(1 + S^4)*T^2*HPL[{0}, S^2]^2*
       HPL[{1}, -S^2]^2)/S^2 + (8*(-1 + F^(-2))*F*(1 + S^2)*T*HPL[{0}, S^2]*
       HPL[{1}, -S^2]^3)/(3*S) - (4*(-1 + F^(-4))*F^2*(1 + S^4)*T^2*
       HPL[{0}, S^2]*HPL[{1}, -S^2]^3)/(3*S^2) + 
     (4*(-1 + F^(-2))*F*(1 + S^2)*T*HPL[{1}, -S^2]^4)/(3*S) - 
     (2*(-1 + F^(-4))*F^2*(1 + S^4)*T^2*HPL[{1}, -S^2]^4)/(3*S^2) + 
     (4*(-1 + F^(-2))*F*Pi^2*S*T*HPL[{2}, -S^2])/3 - 
     (2*(-1 + F^(-4))*F^2*Pi^2*S^2*T^2*HPL[{2}, -S^2])/3 + 
     2*(-1 + F^(-2))*F*S*T*HPL[{0}, S^2]^2*HPL[{2}, -S^2] - 
     (-1 + F^(-4))*F^2*S^2*T^2*HPL[{0}, S^2]^2*HPL[{2}, -S^2] + 
     (4*(-1 + F^(-2))*F*(1 + S^2)*T*HPL[{0}, S^2]*HPL[{1}, -S^2]*
       HPL[{2}, -S^2])/S - (2*(-1 + F^(-4))*F^2*(1 + S^4)*T^2*HPL[{0}, S^2]*
       HPL[{1}, -S^2]*HPL[{2}, -S^2])/S^2 + 
     (4*(-1 + F^(-2))*F*(1 + S^2)*T*HPL[{1}, -S^2]^2*HPL[{2}, -S^2])/S - 
     (2*(-1 + F^(-4))*F^2*(1 + S^4)*T^2*HPL[{1}, -S^2]^2*HPL[{2}, -S^2])/
      S^2 + 2*(-1 + F^(-2))*F*S*T*HPL[{2}, -S^2]^2 - 
     (-1 + F^(-4))*F^2*S^2*T^2*HPL[{2}, -S^2]^2 + 4*(-1 + F^(-2))*F*S*T*
      HPL[{3}, -S^2] + (-1 + F^(-4))*F^2*S^2*T^2*HPL[{3}, -S^2] - 
     4*(-1 + F^(-2))*F*S*T*HPL[{4}, -S^2] + 2*(-1 + F^(-4))*F^2*S^2*T^2*
      HPL[{4}, -S^2] - (8*(-1 + F^(-2))*F*T*HPL[{0}, S^2]*HPL[{2, 1}, -S^2])/
      S + (4*(-1 + F^(-4))*F^2*T^2*HPL[{0}, S^2]*HPL[{2, 1}, -S^2])/S^2 - 
     (8*(-1 + F^(-2))*F*(1 + S^2)*T*HPL[{1}, -S^2]*HPL[{2, 1}, -S^2])/S + 
     (4*(-1 + F^(-4))*F^2*(1 + S^4)*T^2*HPL[{1}, -S^2]*HPL[{2, 1}, -S^2])/
      S^2 - 8*(-1 + F^(-2))*F*S*T*HPL[{3, 1}, -S^2] + 
     4*(-1 + F^(-4))*F^2*S^2*T^2*HPL[{3, 1}, -S^2] + 
     16*(-1 + F^(-2))*F*S*T*HPL[{2, 1, 1}, -S^2] - 8*(-1 + F^(-4))*F^2*S^2*
      T^2*HPL[{2, 1, 1}, -S^2] + (2*(-1 + F^(-4))*F^2*T^2*HPL[{2, 1}, -S^2]*
       (1 + 2*S^2 - 4*Log[T]))/S^2 - (4*(-1 + F^(-2))*F*S*T*HPL[{0}, S^2]^3*
       (-1 + Log[T]))/3 + (4*(-1 + F^(-2))*F*Pi^2*S*T*(-1 + Log[T])*Log[T])/
      3 + 4*(-1 + F^(-2))*F*S*T*HPL[{0}, S^2]^2*(-1 + Log[T])*Log[T] + 
     8*(-1 + F^(-2))*F*S*T*HPL[{2}, -S^2]*(-1 + Log[T])*Log[T] - 
     (2*(-1 + F^(-2))*F*(1 + S^2)*T*HPL[{0}, S^2]^2*HPL[{1}, -S^2]*
       (-1 + 2*Log[T]))/S - (4*(-1 + F^(-2))*F*(1 + S^2)*T*HPL[{0}, S^2]*
       HPL[{1}, -S^2]^2*(-1 + 2*Log[T]))/S - 
     (8*(-1 + F^(-2))*F*(1 + S^2)*T*HPL[{1}, -S^2]^3*(-1 + 2*Log[T]))/(3*S) - 
     4*(-1 + F^(-2))*F*S*T*HPL[{0}, S^2]*HPL[{2}, -S^2]*(-1 + 2*Log[T]) - 
     (4*(-1 + F^(-2))*F*(1 + S^2)*T*HPL[{1}, -S^2]*HPL[{2}, -S^2]*
       (-1 + 2*Log[T]))/S + (8*(-1 + F^(-2))*F*T*HPL[{2, 1}, -S^2]*
       (-1 + 2*Log[T]))/S + ((-1 + F^(-4))*F^2*T^2*HPL[{0}, S^2]^3*
       (-1 - S^2 + 2*S^2*Log[T]))/3 + (-1 + F^(-4))*F^2*T^2*HPL[{0}, S^2]*
      HPL[{2}, -S^2]*(-2 - 3*S^2 + 4*S^2*Log[T]) + 
     ((-1 + F^(-4))*F^2*T^2*HPL[{0}, S^2]^2*HPL[{1}, -S^2]*
       (-1 - 4*S^2 - 3*S^4 + 4*(1 + S^4)*Log[T]))/(2*S^2) + 
     ((-1 + F^(-4))*F^2*T^2*HPL[{0}, S^2]*HPL[{1}, -S^2]^2*
       (-1 - 4*S^2 - 3*S^4 + 4*(1 + S^4)*Log[T]))/S^2 + 
     (2*(-1 + F^(-4))*F^2*T^2*HPL[{1}, -S^2]^3*(-1 - 4*S^2 - 3*S^4 + 
        4*(1 + S^4)*Log[T]))/(3*S^2) + ((-1 + F^(-4))*F^2*T^2*HPL[{1}, -S^2]*
       HPL[{2}, -S^2]*(-1 - 4*S^2 - 3*S^4 + 4*(1 + S^4)*Log[T]))/S^2 + 
     (4*(-1 + F^(-2))*F*(1 + S^2)*T*HPL[{0}, S^2]*HPL[{1}, -S^2]*
       (1 - 2*Log[T] + 2*Log[T]^2))/S + (4*(-1 + F^(-2))*F*(1 + S^2)*T*
       HPL[{1}, -S^2]^2*(1 - 2*Log[T] + 2*Log[T]^2))/S - 
     ((-1 + F^(-4))*F^2*Pi^2*T^2*(-1 + 2*S^2 - 3*S^2*Log[T] + 
        2*S^2*Log[T]^2))/3 - ((-1 + F^(-4))*F^2*T^2*HPL[{0}, S^2]^2*
       (1 + 4*S^2 - 2*(2 + 3*S^2)*Log[T] + 4*S^2*Log[T]^2))/2 - 
     (-1 + F^(-4))*F^2*T^2*HPL[{2}, -S^2]*(1 + 4*S^2 - 2*(2 + 3*S^2)*Log[T] + 
       4*S^2*Log[T]^2) - ((-1 + F^(-4))*F^2*T^2*HPL[{0}, S^2]*HPL[{1}, -S^2]*
       (1 + 8*S^2 + 7*S^4 - 4*(1 + 4*S^2 + 3*S^4)*Log[T] + 
        8*(1 + S^4)*Log[T]^2))/(2*S^2) - 
     ((-1 + F^(-4))*F^2*T^2*HPL[{1}, -S^2]^2*(1 + 8*S^2 + 7*S^4 - 
        4*(1 + 4*S^2 + 3*S^4)*Log[T] + 8*(1 + S^4)*Log[T]^2))/(2*S^2) - 
     (8*(-1 + F^(-2))*F*S*T*HPL[{0}, S^2]*(-3 + 3*Log[T] - 3*Log[T]^2 + 
        2*Log[T]^3))/3 - (8*(-1 + F^(-2))*F*(1 + S^2)*T*HPL[{1}, -S^2]*
       (-3 + 3*Log[T] - 3*Log[T]^2 + 2*Log[T]^3))/(3*S) + 
     ((-1 + F^(-4))*F^2*T^2*(-3 + 6*Log[T] - 12*Log[T]^2 + 16*Log[T]^3))/6 + 
     ((-1 + F^(-4))*F^2*T^2*HPL[{0}, S^2]*(-3*(1 + 7*S^2) + 
        6*(2 + 7*S^2)*Log[T] - 12*(2 + 3*S^2)*Log[T]^2 + 16*S^2*Log[T]^3))/
      6 + ((-1 + F^(-4))*F^2*T^2*HPL[{1}, -S^2]*(-3*(1 + 8*S^2 + 7*S^4) + 
        6*(1 + 8*S^2 + 7*S^4)*Log[T] - 12*(1 + 4*S^2 + 3*S^4)*Log[T]^2 + 
        16*(1 + S^4)*Log[T]^3))/(6*S^2)
 
J1wuvT2 = (-2*(-1 + F^(-2))*F*Pi^2*(1 + S^2)*T*HPL[{0}, S^2]*HPL[{1}, -S^2])/
      (3*S) + ((-1 + F^(-4))*F^2*Pi^2*(1 + S^4)*T^2*HPL[{0}, S^2]*
       HPL[{1}, -S^2])/(3*S^2) - (2*(-1 + F^(-2))*F*Pi^2*(1 + S^2)*T*
       HPL[{1}, -S^2]^2)/(3*S) + ((-1 + F^(-4))*F^2*Pi^2*(1 + S^4)*T^2*
       HPL[{1}, -S^2]^2)/(3*S^2) + (8*(-1 + F^(-2))*F*(1 + S^2)*T*
       HPL[{0}, S^2]*HPL[{1}, -S^2]^3)/(3*S) - 
     (4*(-1 + F^(-4))*F^2*(1 + S^4)*T^2*HPL[{0}, S^2]*HPL[{1}, -S^2]^3)/
      (3*S^2) + (4*(-1 + F^(-2))*F*(1 + S^2)*T*HPL[{1}, -S^2]^4)/(3*S) - 
     (2*(-1 + F^(-4))*F^2*(1 + S^4)*T^2*HPL[{1}, -S^2]^4)/(3*S^2) - 
     (2*(-1 + F^(-2))*F*Pi^2*T*HPL[{2}, -S^2])/(3*S) + 
     ((-1 + F^(-4))*F^2*Pi^2*T^2*HPL[{2}, -S^2])/(3*S^2) + 
     (4*(-1 + F^(-2))*F*(1 + S^2)*T*HPL[{0}, S^2]*HPL[{1}, -S^2]*
       HPL[{2}, -S^2])/S - (2*(-1 + F^(-4))*F^2*(1 + S^4)*T^2*HPL[{0}, S^2]*
       HPL[{1}, -S^2]*HPL[{2}, -S^2])/S^2 - 
     (4*(-1 + F^(-2))*F*(1 + S^2)*T*HPL[{1}, -S^2]^2*HPL[{2}, -S^2])/S + 
     (2*(-1 + F^(-4))*F^2*(1 + S^4)*T^2*HPL[{1}, -S^2]^2*HPL[{2}, -S^2])/
      S^2 + (2*(-1 + F^(-2))*F*T*HPL[{2}, -S^2]^2)/S - 
     ((-1 + F^(-4))*F^2*T^2*HPL[{2}, -S^2]^2)/S^2 - 
     (8*(-1 + F^(-2))*F*(1 + S^2)*T*HPL[{1}, -S^2]*HPL[{3}, -S^2])/S + 
     (4*(-1 + F^(-4))*F^2*(1 + S^4)*T^2*HPL[{1}, -S^2]*HPL[{3}, -S^2])/S^2 + 
     (4*(-1 + F^(-2))*F*T*HPL[{4}, -S^2])/S - 
     (2*(-1 + F^(-4))*F^2*T^2*HPL[{4}, -S^2])/S^2 - 
     (8*(-1 + F^(-2))*F*T*HPL[{0}, S^2]*HPL[{2, 1}, -S^2])/S + 
     (4*(-1 + F^(-4))*F^2*T^2*HPL[{0}, S^2]*HPL[{2, 1}, -S^2])/S^2 + 
     (8*(-1 + F^(-2))*F*(1 + S^2)*T*HPL[{1}, -S^2]*HPL[{2, 1}, -S^2])/S - 
     (4*(-1 + F^(-4))*F^2*(1 + S^4)*T^2*HPL[{1}, -S^2]*HPL[{2, 1}, -S^2])/
      S^2 + (8*(-1 + F^(-2))*F*T*HPL[{3, 1}, -S^2])/S - 
     (4*(-1 + F^(-4))*F^2*T^2*HPL[{3, 1}, -S^2])/S^2 - 
     (16*(-1 + F^(-2))*F*T*HPL[{2, 1, 1}, -S^2])/S + 
     (8*(-1 + F^(-4))*F^2*T^2*HPL[{2, 1, 1}, -S^2])/S^2 - 
     (8*(-1 + F^(-2))*F*T*HPL[{2}, -S^2]*(-1 + Log[T])*Log[T])/S + 
     (2*(-1 + F^(-2))*F*Pi^2*S*T*HPL[{0}, S^2]*(-3 + 2*Log[T]))/3 + 
     (2*(-1 + F^(-2))*F*Pi^2*(1 + S^2)*T*HPL[{1}, -S^2]*(-3 + 2*Log[T]))/
      (3*S) - (4*(-1 + F^(-2))*F*(1 + S^2)*T*HPL[{0}, S^2]*HPL[{1}, -S^2]^2*
       (-1 + 2*Log[T]))/S - (8*(-1 + F^(-2))*F*(1 + S^2)*T*HPL[{1}, -S^2]^3*
       (-1 + 2*Log[T]))/(3*S) - 4*(-1 + F^(-2))*F*S*T*HPL[{0}, S^2]*
      HPL[{2}, -S^2]*(-1 + 2*Log[T]) + (4*(-1 + F^(-2))*F*(1 + S^2)*T*
       HPL[{1}, -S^2]*HPL[{2}, -S^2]*(-1 + 2*Log[T]))/S - 
     8*(-1 + F^(-2))*F*S*T*HPL[{2, 1}, -S^2]*(-1 + 2*Log[T]) - 
     ((-1 + F^(-4))*F^2*Pi^2*T^2*(-3 + 4*Log[T]))/6 - 
     ((-1 + F^(-4))*F^2*Pi^2*T^2*HPL[{0}, S^2]*(-2 - 3*S^2 + 4*S^2*Log[T]))/
      6 + (4*(-1 + F^(-2))*F*T*HPL[{3}, -S^2]*(1 - 2*S^2 + 4*S^2*Log[T]))/S + 
     (-1 + F^(-4))*F^2*T^2*HPL[{0}, S^2]*HPL[{2}, -S^2]*
      (-2 - S^2 + 4*S^2*Log[T]) + 2*(-1 + F^(-4))*F^2*T^2*HPL[{2, 1}, -S^2]*
      (-2 - S^2 + 4*S^2*Log[T]) - ((-1 + F^(-4))*F^2*T^2*HPL[{3}, -S^2]*
       (-1 - 4*S^2 - 2*S^4 + 8*S^4*Log[T]))/S^2 - 
     ((-1 + F^(-4))*F^2*Pi^2*T^2*HPL[{1}, -S^2]*(-1 - 4*S^2 - 3*S^4 + 
        4*(1 + S^4)*Log[T]))/(6*S^2) + ((-1 + F^(-4))*F^2*T^2*HPL[{0}, S^2]*
       HPL[{1}, -S^2]^2*(-3 - 4*S^2 - S^4 + 4*(1 + S^4)*Log[T]))/S^2 + 
     (2*(-1 + F^(-4))*F^2*T^2*HPL[{1}, -S^2]^3*(-3 - 4*S^2 - S^4 + 
        4*(1 + S^4)*Log[T]))/(3*S^2) - ((-1 + F^(-4))*F^2*T^2*HPL[{1}, -S^2]*
       HPL[{2}, -S^2]*(-3 - 4*S^2 - S^4 + 4*(1 + S^4)*Log[T]))/S^2 - 
     ((-1 + F^(-4))*F^2*T^2*HPL[{2}, -S^2]*(-4 - S^2 + (6 + 4*S^2)*Log[T] - 
        4*Log[T]^2))/S^2 + (4*(-1 + F^(-2))*F*(1 + S^2)*T*HPL[{0}, S^2]*
       HPL[{1}, -S^2]*(1 - 2*Log[T] + 2*Log[T]^2))/S + 
     (4*(-1 + F^(-2))*F*(1 + S^2)*T*HPL[{1}, -S^2]^2*
       (1 - 2*Log[T] + 2*Log[T]^2))/S - ((-1 + F^(-4))*F^2*T^2*HPL[{0}, S^2]*
       HPL[{1}, -S^2]*(7 + 8*S^2 + S^4 - 4*(3 + 4*S^2 + S^4)*Log[T] + 
        8*(1 + S^4)*Log[T]^2))/(2*S^2) - 
     ((-1 + F^(-4))*F^2*T^2*HPL[{1}, -S^2]^2*(7 + 8*S^2 + S^4 - 
        4*(3 + 4*S^2 + S^4)*Log[T] + 8*(1 + S^4)*Log[T]^2))/(2*S^2) - 
     (8*(-1 + F^(-2))*F*S*T*HPL[{0}, S^2]*(-3 + 3*Log[T] - 3*Log[T]^2 + 
        2*Log[T]^3))/3 - (8*(-1 + F^(-2))*F*(1 + S^2)*T*HPL[{1}, -S^2]*
       (-3 + 3*Log[T] - 3*Log[T]^2 + 2*Log[T]^3))/(3*S) + 
     ((-1 + F^(-4))*F^2*T^2*(-3 + 6*Log[T] - 12*Log[T]^2 + 16*Log[T]^3))/6 + 
     ((-1 + F^(-4))*F^2*T^2*HPL[{0}, S^2]*(-3*(7 + S^2) + 
        6*(6 + S^2)*Log[T] - 12*(2 + S^2)*Log[T]^2 + 16*S^2*Log[T]^3))/6 + 
     ((-1 + F^(-4))*F^2*T^2*HPL[{1}, -S^2]*(-3*(7 + 8*S^2 + S^4) + 
        6*(7 + 8*S^2 + S^4)*Log[T] - 12*(3 + 4*S^2 + S^4)*Log[T]^2 + 
        16*(1 + S^4)*Log[T]^3))/(6*S^2) - 
     (8*(-1 + F^(-2))*F*(1 + S^2)*T*HPL[{1}, -S^2]*Zeta[3])/S + 
     (4*(-1 + F^(-4))*F^2*(1 + S^4)*T^2*HPL[{1}, -S^2]*Zeta[3])/S^2 + 
     8*(-1 + F^(-2))*F*S*T*(-1 + 2*Log[T])*Zeta[3] - 
     2*(-1 + F^(-4))*F^2*T^2*(-2 - S^2 + 4*S^2*Log[T])*Zeta[3]
 
K1uvwT2 = ((-1 + F^(-2))*F*Pi^2*(1 + S^2)*T*HPL[{1}, -S^2]^2)/(3*S) - 
     ((-1 + F^(-4))*F^2*Pi^2*(1 + S^4)*T^2*HPL[{1}, -S^2]^2)/(6*S^2) + 
     ((-1 + F^(-2))*F*(1 + S^2)*T*HPL[{0}, S^2]^2*HPL[{1}, -S^2]^2)/S - 
     ((-1 + F^(-4))*F^2*(1 + S^4)*T^2*HPL[{0}, S^2]^2*HPL[{1}, -S^2]^2)/
      (2*S^2) + (4*(-1 + F^(-2))*F*(1 + S^2)*T*HPL[{0}, S^2]*
       HPL[{1}, -S^2]^3)/(3*S) - (2*(-1 + F^(-4))*F^2*(1 + S^4)*T^2*
       HPL[{0}, S^2]*HPL[{1}, -S^2]^3)/(3*S^2) + 
     (2*(-1 + F^(-2))*F*(1 + S^2)*T*HPL[{1}, -S^2]^4)/(3*S) - 
     ((-1 + F^(-4))*F^2*(1 + S^4)*T^2*HPL[{1}, -S^2]^4)/(3*S^2) + 
     (2*(-1 + F^(-4))*F^2*(-1 + S^4)*T^2*HPL[{1}, -S^2]*HPL[{2}, -S^2])/S^2 - 
     (2*(-1 + F^(-2))*F*(1 + S^2)*T*HPL[{0}, S^2]*HPL[{3}, -S^2])/S + 
     ((-1 + F^(-4))*F^2*(1 + S^4)*T^2*HPL[{0}, S^2]*HPL[{3}, -S^2])/S^2 - 
     (4*(-1 + F^(-2))*F*(1 + S^2)*T*HPL[{1}, -S^2]*HPL[{3}, -S^2])/S + 
     (2*(-1 + F^(-4))*F^2*(1 + S^4)*T^2*HPL[{1}, -S^2]*HPL[{3}, -S^2])/S^2 - 
     (2*(-1 + F^(-2))*F*Pi^2*(1 + S^2)*T*HPL[{1}, -S^2]*(-1 + Log[T]))/
      (3*S) + (2*(-1 + F^(-4))*F^2*(1 + S^2)^2*T^2*HPL[{0}, S^2]*
       HPL[{1}, -S^2]*(-1 + Log[T]))/S^2 - 
     (2*(-1 + F^(-2))*F*(1 + S^2)*T*HPL[{0}, S^2]^2*HPL[{1}, -S^2]*
       (-1 + Log[T]))/S + (2*(-1 + F^(-4))*F^2*(1 + S^2)^2*T^2*
       HPL[{1}, -S^2]^2*(-1 + Log[T]))/S^2 - 
     (4*(-1 + F^(-2))*F*(1 + S^2)*T*HPL[{0}, S^2]*HPL[{1}, -S^2]^2*
       (-1 + Log[T]))/S - (8*(-1 + F^(-2))*F*(1 + S^2)*T*HPL[{1}, -S^2]^3*
       (-1 + Log[T]))/(3*S) - (4*(-1 + F^(-2))*F*(-1 + S^2)*T*HPL[{0}, S^2]*
       HPL[{2}, -S^2]*(-1 + Log[T]))/S + 8*(-1 + F^(-2))*F*S*T*HPL[{3}, -S^2]*
      (-1 + Log[T]) - (8*(-1 + F^(-2))*F*(-1 + S^2)*T*HPL[{2, 1}, -S^2]*
       (-1 + Log[T]))/S + (4*(-1 + F^(-4))*F^2*(-1 + S^4)*T^2*
       HPL[{2, 1}, -S^2]*(-1 + Log[T]))/S^2 + 
     ((-1 + F^(-4))*F^2*Pi^2*T^2*(-3 + 2*Log[T]))/6 + 
     ((-1 + F^(-4))*F^2*T^2*HPL[{0}, S^2]^2*(-3 + 2*Log[T]))/2 + 
     ((-1 + F^(-4))*F^2*(-1 + S^4)*T^2*HPL[{0}, S^2]*HPL[{2}, -S^2]*
       (-1 + 2*Log[T]))/S^2 - 4*(-1 + F^(-4))*F^2*T^2*HPL[{3}, -S^2]*
      (-1 - S^2 + S^2*Log[T]) + (2*(-1 + F^(-4))*F^2*T^2*HPL[{0}, S^2]*
       HPL[{1}, -S^2]^2*(-(1 + S^2)^2 + (1 + S^4)*Log[T]))/S^2 + 
     (4*(-1 + F^(-4))*F^2*T^2*HPL[{1}, -S^2]^3*(-(1 + S^2)^2 + 
        (1 + S^4)*Log[T]))/(3*S^2) + ((-1 + F^(-4))*F^2*Pi^2*T^2*
       HPL[{1}, -S^2]*(-3 - 4*S^2 - S^4 + 2*(1 + S^4)*Log[T]))/(6*S^2) + 
     ((-1 + F^(-4))*F^2*T^2*HPL[{0}, S^2]^2*HPL[{1}, -S^2]*
       (-3 - 4*S^2 - S^4 + 2*(1 + S^4)*Log[T]))/(2*S^2) + 
     8*(-1 + F^(-2))*F*S*T*(-1 + Log[T])*Zeta[3] - 4*(-1 + F^(-4))*F^2*S^2*
      T^2*(-1 + Log[T])*Zeta[3]
 
K1vwuT2 = (-8*(-1 + F^(-2))*F*Pi^4*S*T)/45 + 
     (4*(-1 + F^(-4))*F^2*Pi^4*S^2*T^2)/45 + 
     ((-1 + F^(-4))*F^2*Pi^2*(1 + 2*S^2)*T^2*HPL[{0}, S^2])/6 - 
     ((-1 + F^(-2))*F*Pi^2*S*T*HPL[{0}, S^2]^2)/3 + 
     ((-1 + F^(-4))*F^2*Pi^2*S^2*T^2*HPL[{0}, S^2]^2)/6 - 
     ((-1 + F^(-2))*F*Pi^2*(1 + S^2)*T*HPL[{0}, S^2]*HPL[{1}, -S^2])/(3*S) + 
     ((-1 + F^(-4))*F^2*Pi^2*(1 + S^4)*T^2*HPL[{0}, S^2]*HPL[{1}, -S^2])/
      (6*S^2) - (2*(-1 + F^(-2))*F*Pi^2*(1 + S^2)*T*HPL[{1}, -S^2]^2)/(3*S) + 
     ((-1 + F^(-4))*F^2*Pi^2*(1 + S^4)*T^2*HPL[{1}, -S^2]^2)/(3*S^2) + 
     (2*(-1 + F^(-2))*F*(1 + S^2)*T*HPL[{0}, S^2]*HPL[{1}, -S^2]^2)/S + 
     ((-1 + F^(-4))*F^2*(-1 + S^4)*T^2*HPL[{0}, S^2]*HPL[{1}, -S^2]^2)/
      (2*S^2) - ((-1 + F^(-2))*F*(1 + S^2)*T*HPL[{0}, S^2]^2*
       HPL[{1}, -S^2]^2)/S + ((-1 + F^(-4))*F^2*(1 + S^4)*T^2*HPL[{0}, S^2]^2*
       HPL[{1}, -S^2]^2)/(2*S^2) + (4*(-1 + F^(-2))*F*(1 + S^2)*T*
       HPL[{1}, -S^2]^3)/(3*S) + ((-1 + F^(-4))*F^2*(-1 + S^4)*T^2*
       HPL[{1}, -S^2]^3)/(3*S^2) - (4*(-1 + F^(-2))*F*Pi^2*S*T*
       HPL[{2}, -S^2])/3 + (2*(-1 + F^(-4))*F^2*Pi^2*S^2*T^2*HPL[{2}, -S^2])/
      3 - 2*(-1 + F^(-2))*F*S*T*HPL[{0}, S^2]^2*HPL[{2}, -S^2] + 
     (-1 + F^(-4))*F^2*S^2*T^2*HPL[{0}, S^2]^2*HPL[{2}, -S^2] + 
     (2*(-1 + F^(-2))*F*(1 + S^2)*T*HPL[{0}, S^2]*HPL[{1}, -S^2]*
       HPL[{2}, -S^2])/S - ((-1 + F^(-4))*F^2*(1 + S^4)*T^2*HPL[{0}, S^2]*
       HPL[{1}, -S^2]*HPL[{2}, -S^2])/S^2 - 
     (2*(-1 + F^(-2))*F*(1 + S^2)*T*HPL[{1}, -S^2]^2*HPL[{2}, -S^2])/S + 
     ((-1 + F^(-4))*F^2*(1 + S^4)*T^2*HPL[{1}, -S^2]^2*HPL[{2}, -S^2])/S^2 - 
     2*(-1 + F^(-2))*F*S*T*HPL[{2}, -S^2]^2 + (-1 + F^(-4))*F^2*S^2*T^2*
      HPL[{2}, -S^2]^2 + 2*(-1 + F^(-2))*F*S*T*HPL[{0}, S^2]*HPL[{3}, -S^2] - 
     (-1 + F^(-4))*F^2*S^2*T^2*HPL[{0}, S^2]*HPL[{3}, -S^2] - 
     (2*(-1 + F^(-2))*F*(1 + S^2)*T*HPL[{1}, -S^2]*HPL[{3}, -S^2])/S + 
     ((-1 + F^(-4))*F^2*(1 + S^4)*T^2*HPL[{1}, -S^2]*HPL[{3}, -S^2])/S^2 - 
     4*(-1 + F^(-2))*F*S*T*HPL[{0}, S^2]*HPL[{2, 1}, -S^2] + 
     2*(-1 + F^(-4))*F^2*S^2*T^2*HPL[{0}, S^2]*HPL[{2, 1}, -S^2] + 
     (4*(-1 + F^(-2))*F*(1 + S^2)*T*HPL[{1}, -S^2]*HPL[{2, 1}, -S^2])/S - 
     (2*(-1 + F^(-4))*F^2*(1 + S^4)*T^2*HPL[{1}, -S^2]*HPL[{2, 1}, -S^2])/
      S^2 + 4*(-1 + F^(-2))*F*S*T*HPL[{3, 1}, -S^2] - 
     2*(-1 + F^(-4))*F^2*S^2*T^2*HPL[{3, 1}, -S^2] - 
     8*(-1 + F^(-2))*F*S*T*HPL[{2, 1, 1}, -S^2] + 4*(-1 + F^(-4))*F^2*S^2*T^2*
      HPL[{2, 1, 1}, -S^2] - 4*(-1 + F^(-2))*F*S*T*HPL[{0}, S^2]*
      HPL[{2}, -S^2]*(-1 + Log[T]) + 4*(-1 + F^(-2))*F*S*T*HPL[{3}, -S^2]*
      (-1 + Log[T]) + (2*(-1 + F^(-2))*F*Pi^2*(1 + S^2)*T*HPL[{1}, -S^2]*
       Log[T])/(3*S) + (2*(-1 + F^(-2))*F*(1 + S^2)*T*HPL[{0}, S^2]^2*
       HPL[{1}, -S^2]*Log[T])/S - ((-1 + F^(-4))*F^2*(1 + S^4)*T^2*
       HPL[{0}, S^2]^2*HPL[{1}, -S^2]*Log[T])/S^2 + 
     (4*(-1 + F^(-2))*F*(1 + S^2)*T*HPL[{1}, -S^2]*HPL[{2}, -S^2]*Log[T])/S - 
     (2*(-1 + F^(-4))*F^2*(1 + S^4)*T^2*HPL[{1}, -S^2]*HPL[{2}, -S^2]*Log[T])/
      S^2 - (4*(-1 + F^(-2))*F*Pi^2*S*T*(-1 + Log[T])*Log[T])/3 - 
     4*(-1 + F^(-2))*F*S*T*HPL[{0}, S^2]^2*(-1 + Log[T])*Log[T] + 
     4*(-1 + F^(-4))*F^2*(1 + S^2)*T^2*HPL[{1}, -S^2]*(-1 + Log[T])*Log[T] - 
     (4*(-1 + F^(-2))*F*(1 + S^2)*T*HPL[{0}, S^2]*HPL[{1}, -S^2]*
       (-1 + Log[T])*Log[T])/S - (4*(-1 + F^(-2))*F*(1 + S^2)*T*
       HPL[{1}, -S^2]^2*(-1 + Log[T])*Log[T])/S - 8*(-1 + F^(-2))*F*S*T*
      HPL[{2}, -S^2]*(-1 + Log[T])*Log[T] + 
     ((-1 + F^(-4))*F^2*Pi^2*T^2*Log[T]*(-1 - S^2 + 2*S^2*Log[T]))/3 + 
     (-1 + F^(-4))*F^2*T^2*HPL[{0}, S^2]^2*Log[T]*(-1 - S^2 + 2*S^2*Log[T]) + 
     2*(-1 + F^(-4))*F^2*T^2*HPL[{2}, -S^2]*Log[T]*
      (-1 - S^2 + 2*S^2*Log[T]) - (4*(-1 + F^(-2))*F*T*HPL[{2, 1}, -S^2]*
       (1 - S^2 + 2*S^2*Log[T]))/S + (-1 + F^(-4))*F^2*T^2*HPL[{0}, S^2]*
      HPL[{2}, -S^2]*(-1 + S^2 + 2*S^2*Log[T]) - (-1 + F^(-4))*F^2*T^2*
      HPL[{3}, -S^2]*(-1 + S^2 + 2*S^2*Log[T]) + 
     ((-1 + F^(-4))*F^2*T^2*HPL[{2, 1}, -S^2]*((-1 + S^2)^2 + 4*S^4*Log[T]))/
      S^2 + (-1 + F^(-4))*F^2*T^2*HPL[{0}, S^2]*Log[T]*
      (-1 - 4*S^2 + (2 + 4*S^2)*Log[T]) - 
     ((-1 + F^(-4))*F^2*Pi^2*T^2*HPL[{1}, -S^2]*(-(S^2*(1 + S^2)) + 
        (1 + S^4)*Log[T]))/(3*S^2) + ((-1 + F^(-4))*F^2*T^2*HPL[{0}, S^2]*
       HPL[{1}, -S^2]*Log[T]*(-1 - 4*S^2 - 3*S^4 + 2*(1 + S^4)*Log[T]))/S^2 + 
     ((-1 + F^(-4))*F^2*T^2*HPL[{1}, -S^2]^2*Log[T]*(-1 - 4*S^2 - 3*S^4 + 
        2*(1 + S^4)*Log[T]))/S^2 + 4*(-1 + F^(-2))*F*S*T*HPL[{0}, S^2]*
      Zeta[3] - 2*(-1 + F^(-4))*F^2*S^2*T^2*HPL[{0}, S^2]*Zeta[3] + 
     4*(-1 + F^(-2))*F*S*T*(-1 + 2*Log[T])*Zeta[3] - 
     (-1 + F^(-4))*F^2*S^2*T^2*(1 + 4*Log[T])*Zeta[3]
 
K1wuvT2 = ((-1 + F^(-4))*F^2*Pi^2*T^2*HPL[{0}, S^2])/6 + 
     ((-1 + F^(-4))*F^2*Pi^2*(1 + S^2)*T^2*HPL[{1}, -S^2])/(3*S^2) - 
     ((-1 + F^(-2))*F*Pi^2*(1 + S^2)*T*HPL[{0}, S^2]*HPL[{1}, -S^2])/(3*S) + 
     ((-1 + F^(-4))*F^2*Pi^2*(1 + S^4)*T^2*HPL[{0}, S^2]*HPL[{1}, -S^2])/
      (6*S^2) - ((-1 + F^(-2))*F*Pi^2*(1 + S^2)*T*HPL[{1}, -S^2]^2)/(3*S) + 
     ((-1 + F^(-4))*F^2*Pi^2*(1 + S^4)*T^2*HPL[{1}, -S^2]^2)/(6*S^2) + 
     (2*(-1 + F^(-2))*F*(1 + S^2)*T*HPL[{0}, S^2]*HPL[{1}, -S^2]^2)/S - 
     ((-1 + F^(-4))*F^2*(-1 + S^4)*T^2*HPL[{0}, S^2]*HPL[{1}, -S^2]^2)/
      (2*S^2) + (4*(-1 + F^(-2))*F*(1 + S^2)*T*HPL[{1}, -S^2]^3)/(3*S) - 
     ((-1 + F^(-4))*F^2*(-1 + S^4)*T^2*HPL[{1}, -S^2]^3)/(3*S^2) + 
     (2*(-1 + F^(-2))*F*Pi^2*T*HPL[{2}, -S^2])/(3*S) - 
     ((-1 + F^(-4))*F^2*Pi^2*T^2*HPL[{2}, -S^2])/(3*S^2) + 
     (2*(-1 + F^(-2))*F*(1 + S^2)*T*HPL[{0}, S^2]*HPL[{1}, -S^2]*
       HPL[{2}, -S^2])/S - ((-1 + F^(-4))*F^2*(1 + S^4)*T^2*HPL[{0}, S^2]*
       HPL[{1}, -S^2]*HPL[{2}, -S^2])/S^2 + 
     (2*(-1 + F^(-2))*F*(1 + S^2)*T*HPL[{1}, -S^2]^2*HPL[{2}, -S^2])/S - 
     ((-1 + F^(-4))*F^2*(1 + S^4)*T^2*HPL[{1}, -S^2]^2*HPL[{2}, -S^2])/S^2 - 
     (2*(-1 + F^(-2))*F*T*HPL[{2}, -S^2]^2)/S + 
     ((-1 + F^(-4))*F^2*T^2*HPL[{2}, -S^2]^2)/S^2 + 
     2*(-1 + F^(-2))*F*S*T*HPL[{0}, S^2]*HPL[{3}, -S^2] - 
     (-1 + F^(-4))*F^2*S^2*T^2*HPL[{0}, S^2]*HPL[{3}, -S^2] + 
     (2*(-1 + F^(-2))*F*(1 + S^2)*T*HPL[{1}, -S^2]*HPL[{3}, -S^2])/S - 
     ((-1 + F^(-4))*F^2*(1 + S^4)*T^2*HPL[{1}, -S^2]*HPL[{3}, -S^2])/S^2 - 
     4*(-1 + F^(-2))*F*S*T*HPL[{0}, S^2]*HPL[{2, 1}, -S^2] + 
     2*(-1 + F^(-4))*F^2*S^2*T^2*HPL[{0}, S^2]*HPL[{2, 1}, -S^2] - 
     (4*(-1 + F^(-2))*F*(1 + S^2)*T*HPL[{1}, -S^2]*HPL[{2, 1}, -S^2])/S + 
     (2*(-1 + F^(-4))*F^2*(1 + S^4)*T^2*HPL[{1}, -S^2]*HPL[{2, 1}, -S^2])/
      S^2 - (4*(-1 + F^(-2))*F*T*HPL[{3, 1}, -S^2])/S + 
     (2*(-1 + F^(-4))*F^2*T^2*HPL[{3, 1}, -S^2])/S^2 + 
     (8*(-1 + F^(-2))*F*T*HPL[{2, 1, 1}, -S^2])/S - 
     (4*(-1 + F^(-4))*F^2*T^2*HPL[{2, 1, 1}, -S^2])/S^2 - 
     4*(-1 + F^(-2))*F*S*T*HPL[{0}, S^2]*HPL[{2}, -S^2]*(-1 + Log[T]) - 
     (4*(-1 + F^(-2))*F*(1 + S^2)*T*HPL[{1}, -S^2]*HPL[{2}, -S^2]*Log[T])/S + 
     (2*(-1 + F^(-4))*F^2*(1 + S^4)*T^2*HPL[{1}, -S^2]*HPL[{2}, -S^2]*Log[T])/
      S^2 + (2*(-1 + F^(-4))*F^2*T^2*HPL[{2}, -S^2]*(1 + S^2 - 2*Log[T])*
       Log[T])/S^2 + (4*(-1 + F^(-4))*F^2*(1 + S^2)*T^2*HPL[{1}, -S^2]*
       (-1 + Log[T])*Log[T])/S^2 - (4*(-1 + F^(-2))*F*(1 + S^2)*T*
       HPL[{0}, S^2]*HPL[{1}, -S^2]*(-1 + Log[T])*Log[T])/S - 
     (4*(-1 + F^(-2))*F*(1 + S^2)*T*HPL[{1}, -S^2]^2*(-1 + Log[T])*Log[T])/
      S + (8*(-1 + F^(-2))*F*T*HPL[{2}, -S^2]*(-1 + Log[T])*Log[T])/S - 
     (4*(-1 + F^(-2))*F*T*HPL[{3}, -S^2]*(S^2 + Log[T]))/S + 
     (-1 + F^(-4))*F^2*T^2*HPL[{0}, S^2]*Log[T]*(-3 + 2*Log[T]) + 
     (4*(-1 + F^(-2))*F*T*HPL[{2, 1}, -S^2]*(-1 + S^2 + 2*Log[T]))/S + 
     ((-1 + F^(-4))*F^2*T^2*HPL[{3}, -S^2]*(-S^2 + S^4 + 2*Log[T]))/S^2 - 
     ((-1 + F^(-4))*F^2*T^2*HPL[{2, 1}, -S^2]*((-1 + S^2)^2 + 4*Log[T]))/
      S^2 + (-1 + F^(-4))*F^2*T^2*HPL[{0}, S^2]*HPL[{2}, -S^2]*
      (1 - S^2 + 2*S^2*Log[T]) + ((-1 + F^(-4))*F^2*T^2*HPL[{0}, S^2]*
       HPL[{1}, -S^2]*Log[T]*(-3 - 4*S^2 - S^4 + 2*(1 + S^4)*Log[T]))/S^2 + 
     ((-1 + F^(-4))*F^2*T^2*HPL[{1}, -S^2]^2*Log[T]*(-3 - 4*S^2 - S^4 + 
        2*(1 + S^4)*Log[T]))/S^2 - 4*(-1 + F^(-2))*F*S*T*Zeta[3] + 
     (-1 + F^(-4))*F^2*(-2 + S^2)*T^2*Zeta[3] + 4*(-1 + F^(-2))*F*S*T*
      HPL[{0}, S^2]*Zeta[3] - 2*(-1 + F^(-4))*F^2*S^2*T^2*HPL[{0}, S^2]*
      Zeta[3] + (4*(-1 + F^(-2))*F*(1 + S^2)*T*HPL[{1}, -S^2]*Zeta[3])/S - 
     (2*(-1 + F^(-4))*F^2*(1 + S^4)*T^2*HPL[{1}, -S^2]*Zeta[3])/S^2
